%% This is file `qurantext-de.translation.def',
%%
%% Copyright © 2015-2021
%% Seiied-Mohammad-Javad Razavian <javadr@gmail.com>
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%%
%% This work is “author-maintained” (as per LPPL maintenance status).
%%
%% The Current Maintainer of this work is Seiied-Mohammad-Javad Razavian.
%%
%% to one who has devoted his life to Quran
%%
\qt@newcmd\qurantrans@de@i{Im Namen Allahs, des Allerbarmers, des Barmherzigen!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@ii{Alles Lob gebührt Allah, dem Herrn der Welten\qt@no{(2)}}
\qt@newcmd\qurantrans@de@iii{dem Allerbarmer, dem Barmherzigen\qt@no{(3)}}
\qt@newcmd\qurantrans@de@iv{dem Herrscher am Tage des Gerichts!\qt@no{(4)}}
\qt@newcmd\qurantrans@de@v{Dir (allein) dienen wir, und Dich (allein) bitten wir um Hilfe.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@vi{Führe uns den geraden Weg\qt@no{(6)}}
\qt@newcmd\qurantrans@de@vii{den Weg derer, denen Du Gnade erwiesen hast, nicht (den Weg) derer, die(Deinen) Zorn erregt haben, und nicht (den Weg) der Irregehenden.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@viii{\basmalahde Alif Lam Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@ix{Dies ist (ganz gewiß) das Buch (Allahs), das keinen Anlaß zum Zweifel gibt, (es ist) eine Rechtleitung für die Gottesfürchtigen\qt@no{(2)}}
\qt@newcmd\qurantrans@de@x{die an das Verborgene glauben und das Gebet verrichten und von dem ausgeben, was Wir ihnen beschert haben\qt@no{(3)}}
\qt@newcmd\qurantrans@de@xi{und die an das glauben, was auf dich und vor dir herabgesandt wurde, und die mit dem Jenseits fest rechnen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@xii{Diese folgen der Leitung ihres Herrn und diese sind die Erfolgreichen.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@xiii{Wahrlich, denen, die ungläubig sind, ist es gleich, ob du sie warnst oder nicht warnst: sie glauben nicht.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@xiv{Versiegelt hat Allah ihre Herzen und ihr Gehör; und über ihren Augen liegt ein Schleier; ihnen wird eine gewaltige Strafe zuteil sein.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@xv{Und manche Menschen sagen: ``Wir glauben an Allah und an den Jüngsten Tag", doch sie sind keine Gläubigen.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@xvi{Sie versuchen, Allah und die Gläubigen zu betrügen, und doch betrügen sie nur sich selbst, ohne daß sie dies empfinden.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@xvii{In ihren Herzen ist eine Krankheit, und Allah mehrt ihre Krankheit, und für sie ist eine schmerzliche Strafe dafür (bestimmt), daß sie logen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@xviii{Und wenn ihnen gesagt wird: ``Stiftet kein Unheil auf der Erde", so sagen sie: ``Wir sind doch die, die Gutes tun."\qt@no{(11)}}
\qt@newcmd\qurantrans@de@xix{Gewiß jedoch sind sie die, die Unheil stiften, aber sie empfinden es nicht.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@xx{Und wenn ihnen gesagt wird: ``Glaubt wie die Menschen geglaubt haben", sagen sie: ``Sollen wir etwa wie die Toren glauben?" Gewiß jedoch sind sie selbst die Toren, aber sie wissen es nicht.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@xxi{Und wenn sie mit den Gläubigen zusammentreffen, so sagen sie: ``Wir glauben". Wenn sie aber mit ihren Satanen allein sind, sagen sie: ``Wir sind ja mit euch; wir treiben ja nur Spott."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@xxii{Allah verspottet sie und läßt sie weiter verblendet umherirren.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@xxiii{Diese sind es, die das Irregehen gegen die Rechtleitung eingetauscht haben, doch ihr Handel brachte ihnen weder Gewinn, noch werden sie rechtgeleitet.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@xxiv{Ihr Beispiel ist dem Beispiel dessen gleich, der ein Feuer anzündet; und als es nun alles um ihn herum erleuchtet hatte, ließ Allah ihr Licht verschwinden und ließ sie in Finsternissen zurück, und sie sahen nichts\qt@no{(17)}}
\qt@newcmd\qurantrans@de@xxv{taub, stumm und blind; und so kehrten sie nicht um.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@xxvi{Oder (ihr Beispiel ist) gleich (jenen bei) einem Regenguß vom Himmel, voller Finsternisse, Donner und Blitz; sie stecken ihre Finger in ihre Ohren in Todesangst vor den Donnerschlägen. Und Allah hat die Ungläubigen in Seiner Gewalt.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@xxvii{Der Blitz raubt ihnen beinahe ihr Augenlicht: Sooft er ihnen Licht gibt, gehen sie hindurch, und wenn es dunkel um sie wird, so bleiben sie stehen. Und wenn Allah wollte, hätte Er ihnen gewiß Gehör und Augenlicht genommen. Wahrlich, Allah ist über alle Dinge Mächtig.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@xxviii{O ihr Menschen, dient eurem Herrn, Der euch und diejenigen vor euch erschaffen hat, damit ihr gottesfürchtig sein möget\qt@no{(21)}}
\qt@newcmd\qurantrans@de@xxix{Der euch die Erde zu einer Ruhestätte und den Himmel zu einem Bau gemacht hat und vom Himmel Wasser herniedersandte und dadurch Früchte als Gabe für euch hervorbrachte, darum setzt Allah nichts gleich, wo ihr doch wisset.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@xxx{Und wenn ihr im Zweifel seid über das, was Wir auf Unseren Diener herabgesandt haben, so bringt doch eine Sura gleicher Art herbei und beruft euch auf eure Zeugen außer Allah, wenn ihr wahrhaftig seid.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@xxxi{Und wenn ihr es aber nicht tut und ihr werdet es bestimmt nicht tun so fürchtet das Feuer, dessen Brennstoff Menschen und Steine sind; es ist für die Ungläubigen vorbereitet.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@xxxii{Und verkünde die frohe Botschaft denjenigen, die glauben und Gutes tun, auf daß ihnen Gärten zuteil werden, in deren Niederungen Bäche fließen; und sooft sie eine Frucht daraus bekommen, sagen sie: ``Das ist doch das, was wir schon früher zu essen bekamen." Doch ihnen wird nur Ähnliches gegeben. Und ihnen gehören darin Gattinnen vollkommener Reinheit und sie werden ewig darin bleiben.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@xxxiii{Wahrlich, Allah schämt sich nicht, irgendein Gleichnis zu prägen von einer Mücke oder von etwas Höherem. Nun diejenigen, die glauben, wissen, daß es die Wahrheit von ihrem Herrn ist. Diejenigen aber, die ungläubig sind, sagen: ``Was wollte denn Allah mit einem solchen Gleichnis?" Er führt damit viele irre und leitet viele auch damit recht. Doch die Frevler führt Er damit irre\qt@no{(26)}}
\qt@newcmd\qurantrans@de@xxxiv{die den Bund Allahs brechen, nachdem dieser geschlossen wurde, und die zerreißen, was nach Allahs Gebot zusammengehalten werden soll, und Unheil auf der Erde anrichten. Diese sind die Verlierer.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@xxxv{Wie könnt ihr Allah leugnen, wo ihr doch tot waret und Er euch lebendig machte und euch dann sterben läßt und euch dann (am Jüngsten Tag) lebendig macht, an dem ihr zu Ihm zurückkehrt?\qt@no{(28)}}
\qt@newcmd\qurantrans@de@xxxvi{Er ist es, Der für euch alles auf der Erde erschuf; als dann wandte Er Sich den Himmeln zu und richtete sie zu sieben Himmeln auf; und Er ist aller (Dinge) kundig.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@xxxvii{Und als dein Herr zu den Engeln sprach: ``Wahrlich, Ich werde auf der Erde einen Nachfolger einsetzen", sagten sie: ``Willst Du auf ihr jemanden einsetzen, der auf ihr Unheil anrichtet und Blut vergießt, wo wir doch Dein Lob preisen und Deine Herrlichkeit rühmen?" Er sagte: ``Wahrlich, Ich weiß, was ihr nicht wisset."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@xxxviii{Und Er brachte Adam alle Namen bei, dann brachte Er diese vor die Engel und sagte: ``Nennt mir die Namen dieser Dinge, wenn ihr wahrhaftig seid!"\qt@no{(31)}}
\qt@newcmd\qurantrans@de@xxxix{Sie sprachen: ``Gepriesen seist Du. Wir haben kein Wissen außer dem, was Du uns gelehrt hast; wahrlich, Du bist der Allwissende, der Allweise."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@xl{Er sprach: ``O Adam, nenne ihnen ihre Namen!" Und als er ihnen ihre Namen nannte, sprach Er: ``Habe Ich nicht gesagt, daß Ich das Verborgene der Himmel und der Erde kenne, und daß Ich kenne, was ihr offenbart und was ihr verborgen gehalten habt."\qt@no{(33)}}
\qt@newcmd\qurantrans@de@xli{Und als Wir zu den Engeln sprachen: ``Werft euch vor Adam nieder", da warfen sie sich nieder bis auf Iblis; er weigerte sich und war hochmütig. Und damit wurde er einer der Ungläubigen.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@xlii{Und Wir sprachen: ``O Adam, verweile du und deine Gattin im Paradies und esset uneingeschränkt von seinen Früchten, wo immer ihr wollt! Kommt jedoch diesem Baum nicht nahe, sonst würdet ihr zu den Ungerechten gehören."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@xliii{Doch Satan ließ sie dort straucheln und brachte sie aus dem Zustand heraus, in dem sie waren. Da sprachen Wir: ``Geht (vom Paradies) hinunter! Der eine von euch sei des anderen Feind. Und ihr sollt auf der Erde Wohnstätten und Versorgung auf beschränkte Dauer haben."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@xliv{Da empfing Adam von seinem Herrn Worte, worauf Er ihm verzieh; wahrlich, Er ist der Allverzeihende, der Barmherzige.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@xlv{Wir sprachen: ``Geht hinunter von hier allesamt!" Und wenn dann zu euch Meine Rechtleitung kommt, brauchen diejenigen, die Meiner Rechtleitung folgen, weder Angst zu haben, noch werden sie traurig sein.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@xlvi{Diejenigen aber, die ungläubig sind und Unsere Zeichen für Lüge erklären, werden Bewohner des Feuers sein, in dem sie auf ewig verweilen sollen.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@xlvii{O ihr Kinder Israels! Gedenkt Meiner Gnade, die Ich euch erwiesen habe und erfüllt euer Versprechen Mir gegenüber, so erfülle Ich Mein Versprechen euch gegenüber. Und Mich allein sollt ihr fürchten.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@xlviii{Und glaubt an das, was Ich als Bestätigung dessen herabgesandt habe, was bei euch ist, und seid nicht die ersten, die dies verleugnen! Und tauscht Meine Zeichen nicht ein gegen einen geringen Preis, und Mir allein gegenüber sollt ihr ehrfürchtig sein.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@xlix{Und mischt nicht Wahrheit mit Unrecht durcheinander! Und verschweigt nicht die Wahrheit, wo ihr (sie) doch kennt.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@l{Und verrichtet das Gebet und entrichtet die Zakah und verneigt euch mit den Sich- Verneigenden.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@li{Wollt ihr den Menschen Aufrichtigkeit gebieten und euch selbst vergessen, wo ihr doch das Buch lest! Habt ihr denn keinen Verstand?\qt@no{(44)}}
\qt@newcmd\qurantrans@de@lii{Und helft euch durch Geduld und Gebet; dies ist wahrlich schwer, außer für Demütige\qt@no{(45)}}
\qt@newcmd\qurantrans@de@liii{welche es ahnen, daß sie ihrem Herrn begegnen und daß sie zu Ihm heimkehren werden.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@liv{O ihr Kinder Israels! Gedenkt Meiner Gnade, mit der Ich euch begnadete und (denkt daran,) daß Ich euch allen Welten vorgezogen habe.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@lv{Und meidet den Tag, an dem keine Seele für eine andere bürgen kann und von ihr weder Fürsprache noch Lösegeld angenommen wird; und ihnen wird nicht geholfen.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@lvi{Und denkt daran, daß Wir euch vor den Leuten des Pharao retteten, die euch schlimme Pein zufügten, indem sie eure Söhne abschlachteten und eure Frauen am Leben ließen. Darin lag eine schwere Prüfung von eurem Herrn.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@lvii{Und denkt daran, daß Wir für euch das Meer teilten und euch retteten, während Wir die Leute des Pharao vor euren Augen ertrinken ließen.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@lviii{Und denkt daran, daß Wir Uns mit Moses vierzig Nächte verabredeten, als ihr dann hinter seinem Rücken das Kalb nahmt und damit Unrecht begingt.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@lix{Alsdann vergaben Wir euch, auf daß ihr dankbar sein möget.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@lx{Und denkt daran, daß Wir Moses das Buch gaben, sowie die Unterscheidung, auf daß ihr rechtgeleitet werden möget.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@lxi{Und da sagte Moses zu seinen Leuten: ``O meine Leute! Ihr habt auf euch selbst eine schwere Schuld geladen, indem ihr euch das Kalb nahmt; so kehrt reumütig zu eurem Schöpfer zurück und tötet selbst eure Schuldigen. Dies ist für euch besser bei eurem Schöpfer." Alsdann vergab Er euch; wahrlich, Er ist der Allvergebende, der Barmherzige.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@lxii{Und als ihr sagtet: ``O Moses! Wir werden dir gewiß nicht glauben, bis wir Allah unverhüllt sehen", da traf euch der Blitzschlag, während ihr zuschautet.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@lxiii{Dann erweckten Wir euch wieder nach eurem Tode, auf daß ihr dankbar sein möget\qt@no{(56)}}
\qt@newcmd\qurantrans@de@lxiv{und Wir ließen die Wolken über euch Schatten werfen und sandten euch Manna und Wachteln herab: ``Esset von den guten Dingen, die Wir euch gegeben haben"; sie schadeten Uns aber nicht; vielmehr schadeten sie sich selbst.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@lxv{Und Wir sagten: ``Tretet ein in diese Stadt und esset von dort wo immer ihr wollt nach Herzenslust, und tretet durch das Tor ein, indem ihr euch niederwerft und sagt: ``Vergebung!", auf daß Wir euch eure Missetaten vergeben. Und Wir werden den Rechtschaffenen mehr geben.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@lxvi{Doch die Ungerechten vertauschen das Wort mit einem, das ihnen nicht gesagt wurde. Da sandten Wir auf die Ungerechten eine Strafe vom Himmel herab, weil sie gefrevelt hatten.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@lxvii{Und als Moses für sein Volk um Wasser bat, da sagten Wir: ``Schlag mit deinem Stock auf den Felsen." Da sprudelten aus ihm zwölf Quellen heraus. So kannte jeder Stamm seine Trinkstelle. ``Esset und trinkt von dem, was Allah euch gegeben hat, und richtet auf Erden kein Unheil an."\qt@no{(60)}}
\qt@newcmd\qurantrans@de@lxviii{Und als ihr sagtet: ``O Moses, wir können uns mit einer einzigen Speise nicht mehr zufriedengeben. Bitte also deinen Herrn für uns, daß Er uns (Speise) von dem hervorbringe, was die Erde wachsen läßt, (von) Kräutern, Gurken, Knoblauch, Linsen und Zwiebeln Da sagte er: ``Wollt ihr etwa das, was geringer ist, in Tausch nehmen für das, was besser ist? Geht doch zurück in eine Stadt. Dort werdet ihr das erhalten, was ihr verlangt!" Und Schande und Elend kamen über sie und sie verfielen dem Zorn Allahs. Dies (geschah deshalb), weil sie immer wieder die Zeichen Allahs leugneten und die Propheten zu Unrecht töteten; dies (geschah), weil sie sich auflehnten und immer wieder übertraten.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@lxix{Wahrlich, diejenigen, die glauben, und die Juden, die Christen und die Sabäer, wer an Allah und den Jüngsten Tag glaubt und Gutes tut diese haben ihren Lohn bei ihrem Herrn und sie werden weder Angst haben noch werden sie traurig sein.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@lxx{Und als Wir mit euch einen Bund schlossen und über euch den Berg emporragen ließen (und zu euch sagten): ``Haltet fest an dem, was Wir euch gebracht haben, und gedenkt dessen, was darin enthalten ist; vielleicht werdet ihr gottesfürchtig sein"\qt@no{(63)}}
\qt@newcmd\qurantrans@de@lxxi{da habt ihr euch abgewandt; und wenn nicht die Gnade Allahs und Seine Barmherzigkeit über euch gewesen wären, so wäret ihr gewiß unter den Verlierenden gewesen.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@lxxii{Und gewiß habt ihr diejenigen unter euch gekannt, die das SabbatGebot brachen. Da sprachen Wir zu ihnen: ``Werdet ausgestoßene Affen."\qt@no{(65)}}
\qt@newcmd\qurantrans@de@lxxiii{Und Wir machten dies zu einem warnenden Beispiel für alle Zeiten und zu einer Lehre für die Gottesfürchtigen.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@lxxiv{Und als Moses zu seinem Volk sagte: ``Wahrlich, Allah befiehlt euch, eine Kuh zu schlachten" sagten sie: ``Willst du dich über uns lustig machen?" Er sagte: ``Allah bewahre mich davor, einer der Unwissenden zu sein."\qt@no{(67)}}
\qt@newcmd\qurantrans@de@lxxv{Sie sagten: ``Bitte für uns deinen Herrn, daß Er uns erkläre, wie sie sein soll." Er sagte: ``Wahrlich, Er sagt, sie soll eine Kuh sein, die nicht zu alt und nicht zu jung ist, sondern ein Alter dazwischen hat. So tut das, was euch befohlen wird."\qt@no{(68)}}
\qt@newcmd\qurantrans@de@lxxvi{Sie sagten: ``Rufe für uns deinen Herrn an, daß Er uns erkläre, welche Farbe sie haben soll." Er (Moses) sagte: ``Wahrlich, Er sagt, es soll eine gelbe Kuh sein von lebhafter Farbe, die die Schauenden erfreut."\qt@no{(69)}}
\qt@newcmd\qurantrans@de@lxxvii{Sie sagten: ``Rufe für uns deinen Herrn an, daß Er uns erkläre, wie sie sein soll. Für uns sind die Kühe einander ähnlich; und wenn Allah will, werden wir gewiß rechtgeleitet sein!"\qt@no{(70)}}
\qt@newcmd\qurantrans@de@lxxviii{Er (Moses) sagte: ``Wahrlich, Er sagt, es soll eine Kuh sein, die nicht abgerichtet ist, die weder den Boden pflügt noch den Acker bewässert, makellos, ohne jeglichen Flecken." Da sagten sie: ``Jetzt bist du mit der Wahrheit gekommen." So schlachteten sie sie, und beinahe hätten sie es nicht getan.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@lxxix{Und als ihr jemanden getötet und darüber untereinander gestritten hattet, da sollte Allah ans Licht bringen, was ihr verborgen hieltet.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@lxxx{Da sagten Wir: ``Berührt ihn mit einem Stück von ihr!" So bringt Allah die Toten wieder zum Leben und zeigt euch Seine Zeichen; vielleicht werdet ihr es begreifen.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@lxxxi{Sodann verhärteten sich eure Herzen, so daß sie wie Steine wurden oder noch härter. Es gibt doch Steine, aus denen Bäche hervorsprudeln, und es gibt auch welche unter ihnen, die bersten und aus denen Wasser herausfließt. Und es gibt welche unter ihnen, die herniederstürzen aus Furcht vor Allah. Und Allah ist eures Tuns nicht achtlos.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@lxxxii{Verlangt ihr denn, daß sie euch glauben, wo doch eine Schar von ihnen das Wort Allahs bereits gehört und es dann, nachdem sie es begriffen hatten, bewußt verfälschten?\qt@no{(75)}}
\qt@newcmd\qurantrans@de@lxxxiii{Und wenn sie mit denen zusammentreffen, die glauben, so sagen sie: ``Wir glauben". Und wenn sie aber untereinander allein sind, sagen sie: ``Sprecht ihr zu ihnen über das, was Allah euch eröffnet hat, damit sie es vor eurem Herrn als Argument gegen euch verwenden? Begreift ihr denn nicht?"\qt@no{(76)}}
\qt@newcmd\qurantrans@de@lxxxiv{Als ob sie nicht wüßten, daß Allah weiß, was sie verheimlichen und was sie kundtun!\qt@no{(77)}}
\qt@newcmd\qurantrans@de@lxxxv{Es gibt Ungelehrte unter ihnen, die das Buch nicht kennen, sondern nur Wunschvorstellungen; und sie stellen nichts anderes als Vermutungen an.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@lxxxvi{Doch wehe denen, die das Buch mit ihren eigenen Händen schreiben und dann sagen: ``Dies ist von Allah", um dafür einen geringen Preis zu erlangen! Wehe ihnen also ob dessen, was ihre Hände geschrieben und wehe ihnen ob dessen, was sie erworben haben!\qt@no{(79)}}
\qt@newcmd\qurantrans@de@lxxxvii{Und sie sagen: ``Gewiß wird uns das Feuer nicht berühren, außer auf abgezählte Tage!" Sprich: ``Habt ihr etwa ein Versprechen (darüber) von Allah erhalten? Dann wird Allah Sein Versprechen bestimmt nicht brechen oder wollt ihr über Allah (etwas) sagen, wovon ihr kein Wissen besitzt?"\qt@no{(80)}}
\qt@newcmd\qurantrans@de@lxxxviii{Doch! Wer sich Übeles erworben hat und sich in seiner Sündhaftigkeit eingefangen hält diese werden Bewohner des Feuers sein. Darin werden sie ewig bleiben.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@lxxxix{Diejenigen aber, die glauben und gute Werke tun, werden die Bewohner des Paradieses sein. Darin werden sie ewig bleiben.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@xc{Und als Wir mit den Kindern Israels einen Bund schlossen: ``Ihr sollt niemanden außer Allah anbeten, euch den Eltern, Verwandten, Waisen und Armen gegenüber wohltätig erweisen, freundlich zu den Menschen sprechen, das Gebet verrichten und die Zakah entrichten", so habt ihr euch danach abgewendet bis auf wenige unter euch, indem ihr abtrünnig bliebt.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@xci{Und als Wir mit euch einen Bund schlossen: ``Ihr sollt weder euer Blut vergießen noch euch gegenseitig aus euren Häusern vertreiben", habt ihr es dann zugesagt und es bezeugt.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@xcii{Dennoch seid gerade ihr es, die ihr euch gegenseitig tötet und einen Teil von euch aus seinen Häusern vertreibt, indem ihr gemeinsam gegen sie vorgeht in Sünde und Unrecht. Wenn sie jedoch als Gefangene zu euch kommen, kauft ihr sie los, wo euch doch ihre Vertreibung verboten worden ist. Glaubt ihr denn an einen Teil des Buches und leugnet einen anderen Teil? Für diejenigen unter euch, die solches tun, gibt es aber keine andere Vergeltung außer Schande in diesem Leben; und am Tage der Auferstehung werden sie der strengsten Bestrafung zugeführt werden. Und Allah ist eures Tuns nicht achtlos.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@xciii{Diese sind es, die das diesseitige Leben um das jenseitige erkauft haben; deshalb wird ihnen die Strafe nicht erleichtert und ihnen nicht geholfen werden.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@xciv{Wahrlich, Wir gaben Moses das Buch und ließen ihm die Gesandten nachfolgen; und Wir gaben Jesus, dem Sohn Marias, die klaren Beweise und unterstützten ihn durch heilige Eingebung. Doch sooft euch ein Gesandter etwas brachte, was euch nicht behagte, waret ihr hochmütig und erklärtet einige für Lügner und erschluget andere!\qt@no{(87)}}
\qt@newcmd\qurantrans@de@xcv{Und sie sagten: ``Unsere Herzen sind unempfindlich." Aber nein! Allah hat sie wegen ihres Unglaubens verflucht. Darum sind sie wenig gläubig.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@xcvi{Und als zu ihnen ein Buch von Allah kam, das bestätigend, was ihnen vorlag und zuvor hatten sie (Ihn) um den Sieg angefleht über diejenigen, die ungläubig waren; als aber zu ihnen das kam, was sie schon kannten, da leugneten sie es. Darum laste der Fluch Allahs auf den Ungläubigen!\qt@no{(89)}}
\qt@newcmd\qurantrans@de@xcvii{Schlecht ist das, wofür sie ihre Seelen verkauft haben, indem sie das leugnen, was Allah herabgesandt hat, aus Mißgunst, daß Allah etwas von Seiner Huld herabkommen lasse auf wen von Seinen Dienern Er auch immer will. So haben sie Zorn über Zorn auf sich geladen, und den Ungläubigen wird eine erniedrigende Strafe zuteil sein.\qt@no{(90)}}
\qt@newcmd\qurantrans@de@xcviii{Wenn ihnen gesagt wird: ``Glaubt an das, was Allah herabgesandt hat", sagen sie: ``Wir glauben an das, was uns herabgesandt wurde", während sie das leugnen, was danach kam, obgleich es um die Wahrheit geht, die das bestätigt, was in ihrem Besitz ist. Sprich: ``Warum habt ihr also die Propheten Allahs vordem getötet, wenn ihr Gläubige seid?"\qt@no{(91)}}
\qt@newcmd\qurantrans@de@xcix{Und Moses war zu euch mit den klaren Beweisen gekommen. Dann nahmt ihr euch das Kalb, nachdem er weggegangen war, und habt unrecht getan.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@c{Und als Wir mit euch einen Bund schlossen und über euch den Berg emporragen ließen: ``Haltet fest an dem, was Wir euch gegeben haben und höret", da sagten sie: ``Wir hören, doch wir widersetzen uns." Und sie wurden in ihren Herzen durch das Kalb trunken gemacht um ihres Unglaubens willen. Sprich: ``Schlecht ist das, was euer Glaube euch befiehlt, wenn ihr Gläubige seid."\qt@no{(93)}}
\qt@newcmd\qurantrans@de@ci{Sprich: ``Wenn die Wohnstätte des Jenseits bei Allah nur euch gehört, unter Ausschluß anderer Menschen, dann wünscht euch den Tod, wenn ihr wahrhaftig seid!"\qt@no{(94)}}
\qt@newcmd\qurantrans@de@cii{Doch nie werden sie ihn herbeiwünschen wegen dessen, was ihre Hände vorausgeschickt haben, und Allah kennt die Ungerechten.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@ciii{Und bestimmt wirst du sie unter allen Menschen am gierigsten nach Leben finden, und mehr noch als diejenigen, die Götzen anbeten. Manch einer von ihnen möchte, daß ihm ein Leben von tausend Jahren gewährt wird; doch er hält sich dadurch von der Strafe nicht fern, (auch) wenn ihm ein hohes Alter gewährt würde. Und Allah sieht wohl, was sie tun.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@civ{Sprich: ``Wer auch immer Gabriel zum Feind nimmt, so hat er ihn (den Quran) doch mit Ermächtigung Allahs in dein Herz herabgesandt als Bestätigung dessen, was vor ihm war, und als Rechtleitung und frohe Botschaft für die Gläubigen."\qt@no{(97)}}
\qt@newcmd\qurantrans@de@cv{Wer auch immer zum Feind wurde gegen Allah und Seine Engel und Seine Gesandten und Gabriel und Michael, so ist wahrlich Allah den Ungläubigen ein Feind.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@cvi{Und Wir haben dir gewiß klare Zeichen herabgesandt und niemand leugnet sie außer den Frevlern.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@cvii{Ist es denn nicht immer so, daß jedesmal, wenn sie ein Bündnis eingegangen sind, ein Teil von ihnen es verwirft? Die meisten von ihnen glauben es doch nicht.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@cviii{Und als nunmehr zu ihnen ein Gesandter von Allah kam, das bestätigend, was in ihrem Besitz ist, da hat ein Teil von ihnen, denen das Buch gegeben wurde, das Buch Allahs hinter ihren Rücken geworfen, als ob sie nichts wüßten.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@cix{Und sie folgten dem, was die Satane während der Herrschaft Salomos vortrugen; doch nicht Salomo war ungläubig, sondern. die Satane waren ungläubig; sie brachten den Menschen die Zauberei bei sowie das, was den beiden Engeln in Babel, Harut und Marut, herabgesandt wurde. Die beiden jedoch haben niemanden etwas gelehrt, ohne daß sie gesagt hätten: ``Wir sind nur eine Versuchung, so werde nicht ungläubig!" Und sie lernten von den beiden das, womit man zwischen dem Mann und seiner Gattin Zwietracht herbeiführt. Doch sie fügten damit niemandem Schaden zu, es sei denn mit der Ermächtigung Allahs. Und sie lernten, was ihnen schadet und ihnen nichts nützt. Und doch wußten sie, daß, wer es erkauft, keinen Anteil am Jenseits hat. Schlecht ist das wahrlich, wofür sie ihre Seelen verkauft haben, hätten sie es (nur) gewußt!\qt@no{(102)}}
\qt@newcmd\qurantrans@de@cx{Hätten sie aber geglaubt und wären gottesfürchtig gewesen, so wäre eine Belohnung (für sie) von Allah besser gewesen, hätten sie es nur gewußt!\qt@no{(103)}}
\qt@newcmd\qurantrans@de@cxi{O ihr, die ihr glaubt, sagt nicht: ``Achte auf uns!" sondern sagt: ``Schau auf uns!" und hört (auf den Propheten) Und den Ungläubigen wird eine schmerzliche Strafe zuteil sein.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@cxii{Diejenigen, die ungläubig sind unter den Besitzern des Buches und den Götzenanbetern, möchten nicht, daß euch etwas Gutes von eurem Herrn herabgesandt werde, doch Allah zeichnet mit Seiner Barmherzigkeit aus, wen Er will, und Allah besitzt die große Huld.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@cxiii{Wenn Wir eine Aya aufheben oder der Vergessenheit anheimfallen lassen, so bringen Wir eine bessere als sie oder eine gleichwertige hervor. Weißt du denn nicht, daß Allah Macht über alle Dinge hat?\qt@no{(106)}}
\qt@newcmd\qurantrans@de@cxiv{Weißt du denn nicht, daß Allah die Herrschaft über die Himmel und die Erde gehört? Und außer Allah habt ihr weder Freund noch Helfer.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@cxv{Oder wollt ihr euren Gesandten ausfragen, wie früher Moses ausgefragt wurde? Und wer den Unglauben gegen den Glauben eintauscht, der ist gewiß vom rechten Weg abgeirrt.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@cxvi{Viele von den Besitzern des Buches möchten euch, nachdem ihr gläubig geworden seid, gern wieder zu Ungläubigen machen, aus Neid in ihren Seelen, nachdem ihnen die Wahrheit klar gemacht wurde. Doch vergebt und seid nachsichtig, bis Allah Seine Entscheidung ergehen läßt. Wahrlich, Allah hat zu allem die Macht.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@cxvii{Und verrichtet das Gebet und gebt die Zakah, und was ihr für euch an Gutem vorausschickt, das werdet ihr bei Allah vorfinden. Wahrlich! Allah sieht wohl, was ihr tut.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@cxviii{Und sie sagen: ``Es wird niemand in das Paradies eingehen außer Juden und Christen." Dies sind Wunschvorstellungen. Sprich: ``Bringt euren Beweis her, wenn ihr wahrhaftig seid!"\qt@no{(111)}}
\qt@newcmd\qurantrans@de@cxix{Doch wer sich Allah hingibt und Gutes tut, der hat seinen Lohn bei seinem Herrn; und diese werden weder Angst haben noch werden sie traurig sein.\qt@no{(112)}}
\qt@newcmd\qurantrans@de@cxx{Und die Juden sagen: ``Die Christen stützen sich auf nichts", und die Christen sagen: ``Die Juden stützen sich auf nichts", wobei sie doch das Buch lesen. Genau so, wie sie reden, redeten diejenigen, die kein Wissen besitzen. Allah wird dann am Tag der Auferstehung zwischen ihnen über das richten, worüber sie gestritten haben.\qt@no{(113)}}
\qt@newcmd\qurantrans@de@cxxi{Wer begeht mehr Unrecht als derjenige, der verhindert, daß in den Gebetsstätten Allahs Sein Name gerufen wird, und der für ihre Zerstörung eifert? Jene dürfen sie nicht anders als in Furcht betreten. Für sie gibt es im Diesseits Schande und im Jenseits wird ihnen eine schwere Strafe zuteil sein.\qt@no{(114)}}
\qt@newcmd\qurantrans@de@cxxii{Und Allah gehört der Osten und der Westen; wo immer ihr euch also hinwendet, dort ist das Antlitz Allahs. Wahrlich, Allah ist Allumfassend, Allwissend.\qt@no{(115)}}
\qt@newcmd\qurantrans@de@cxxiii{Und sie sagen: ``Allah hat Sich einen Sohn genommen." Gepriesen sei Er! Wahrlich, Ihm gehört, was in den Himmeln und auf der Erde ist alles ist Ihm untertan\qt@no{(116)}}
\qt@newcmd\qurantrans@de@cxxiv{Dem Schöpfer der Himmel und der Erde! Wenn Er eine Sache beschließt, so sagt Er nur zu ihr: ``Sei!" und sie ist.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@cxxv{Und diejenigen, die kein Wissen besitzen, sagen: ``Warum spricht Allah nicht zu uns und sendet uns kein Zeichen?" So, wie sie reden, redeten auch diejenigen vor ihnen. Ihre Herzen sind einander gleich. Wir haben die Ayat klargemacht für Leute mit sicherem Glauben.\qt@no{(118)}}
\qt@newcmd\qurantrans@de@cxxvi{Wir haben dich mit der Wahrheit gesandt als Verkünder der frohen Botschaft und Warner, und du bist für die Gefährten der Gahim nicht verantwortlich.\qt@no{(119)}}
\qt@newcmd\qurantrans@de@cxxvii{Mit dir werden weder die Juden noch die Christen zufrieden sein, bis du ihrem Bekenntnis gefolgt bist. Sprich: ``Die Rechtleitung Allahs ist doch die wahre Rechtleitung." Und wenn du ihrem Ansinnen folgst, nachdem zu dir das Wissen gekommen ist, so wirst du vor Allah weder Freund noch Helfer haben.\qt@no{(120)}}
\qt@newcmd\qurantrans@de@cxxviii{Diejenigen, denen Wir das Buch gegeben haben, lesen es, wie man es lesen soll. Diese glauben daran. Wer aber daran nicht glaubt diese sind doch die Verlierenden.\qt@no{(121)}}
\qt@newcmd\qurantrans@de@cxxix{O ihr Kinder Israels! Gedenkt Meiner Gnade, die Ich euch gewährt habe, und (denkt daran,) daß Ich euch den Vorrang vor den Völkern gegeben habe.\qt@no{(122)}}
\qt@newcmd\qurantrans@de@cxxx{Und fürchtet den Tag, an dem keine Seele für eine andere etwas übernehmen kann und von ihr weder Lösegeld angenommen noch eine Fürsprache ihr (etwas) nützen wird. Diesen wird kein Beistand zuteil.\qt@no{(123)}}
\qt@newcmd\qurantrans@de@cxxxi{Und als Abraham von seinem Herrn durch Worte geprüft wurde und er diese vollbrachte, (da) sprach Er: ``Ich werde dich zu einem Imam für die Menschen machen." Da bat Abraham: ``Auch von meiner Nachkommenschaft." Er sprach: ``Mein Versprechen erstreckt sich nicht auf die, die Unrecht tun. ``\qt@no{(124)}}
\qt@newcmd\qurantrans@de@cxxxii{Und als Wir das Haus zu einem Ort der Einkehr für die Menschen machten sowie zu einer Sicherheit (sprachen Wir): ``Nehmt euch die Stätte Abrahams zum Gebetsort." Und Wir haben Abraham und Ismael auferlegt: ``Reinigt Mein Haus für die es Umkreisenden und (sich dorthin) Zurückziehenden, die Sich-Verneigenden und SichNiederwerfenden."\qt@no{(125)}}
\qt@newcmd\qurantrans@de@cxxxiii{Und als Abraham sagte: ``Mein Herr, mach dies zu einem sicheren Ort und gib Früchte den dort Wohnenden, wer von ihnen an Allah und den Jüngsten Tag glaubt", sagte Er: ``Auch den, der ungläubig ist, werde Ich für kurze Zeit versorgen, als dann ihn ausliefern der Bestrafung des Feuers; und welch ein schlechtes Los ist das!"\qt@no{(126)}}
\qt@newcmd\qurantrans@de@cxxxiv{Und als Abraham mit Ismael die Grundmauern des Hauses errichtete (, sagte er): ``Unser Herr, nimm von uns an; denn wahrlich, Du bist der Allhörende, der Allwissende.\qt@no{(127)}}
\qt@newcmd\qurantrans@de@cxxxv{Und, unser Herr, mach uns Dir ergeben und aus unserer Nachkommenschaft eine Gemeinde, die Dir ergeben ist. Und zeige uns, wie wir Dich anbeten sollen und wende uns Deine Gnade wieder zu; denn wahrlich, Du bist der gnädig Sich-wieder- Zuwendende, der Barmherzige.\qt@no{(128)}}
\qt@newcmd\qurantrans@de@cxxxvi{Und, unser Herr, erwecke unter ihnen einen Gesandten aus ihrer Mitte, der ihnen Deine Worte verliest und sie das Buch und die Weisheit lehrt und sie läutert; denn wahrlich, Du bist der Allmächtige, der Allweise."\qt@no{(129)}}
\qt@newcmd\qurantrans@de@cxxxvii{Und wer verschmäht den Glauben Abrahams außer dem, der sich selbst zum Toren macht? Denn Wir hatten ihn bereits im Diesseits auserwählt, und im Jenseits wird er gewiß unter den Rechtschaffenen sein.\qt@no{(130)}}
\qt@newcmd\qurantrans@de@cxxxviii{Als sein Herr zu ihm sagte: ``Ergib dich!" sagte er: ``Ich ergebe mich dem Herrn der Welten."\qt@no{(131)}}
\qt@newcmd\qurantrans@de@cxxxix{Und Abraham befahl es seinen Söhnen an und ebenso Jakob: ``Meine Söhne, Allah hat für euch die Religion auserwählt, deshalb sterbt nicht anders als (Allah) ergeben zu sein."\qt@no{(132)}}
\qt@newcmd\qurantrans@de@cxl{Waret ihr etwa Zeugen als Jakob im Sterben lag, und als er zu seinen Söhnen sagte: ``Wem werdet ihr dienen, wenn ich weg bin?" sagten sie: ``Wir dienen deinem Gott, dem Gott deiner Väter Abraham, Ismael und Isaak, dem Einzigen Gott, und Ihm sind wir ergeben."\qt@no{(133)}}
\qt@newcmd\qurantrans@de@cxli{Dies ist eine Gemeinde der Vergangenheit; ihr wird zuteil, was sie sich erworben hat, und euch wird zuteil, was ihr euch erworben habt. Und ihr werdet nicht für das verantwortlich sein, was jene getan haben.\qt@no{(134)}}
\qt@newcmd\qurantrans@de@cxlii{Und sie sagen: ``Seid ihr Juden oder Christen, dann werdet ihr rechtgeleitet sein." Sprich: ``Doch! Die Religion Abrahams, der rechtgläubig war und nicht den Götzenanbetern angehörte."\qt@no{(135)}}
\qt@newcmd\qurantrans@de@cxliii{Sprecht: ``Wir glauben an Allah und an das, was uns herabgesandt worden ist, und was Abraham, Ismael, Isaak, Jakob und den Stämmen (Israels) herabgesandt wurde, und was Moses und Jesus gegeben wurde, und was den Propheten von ihrem Herrn gegeben worden ist. Wir machen zwischen ihnen keinen Unterschied und Ihm sind wir ergeben.\qt@no{(136)}}
\qt@newcmd\qurantrans@de@cxliv{enn sie so glauben, wie ihr glaubt, dann werden sie rechtgeleitet sein; wenn sie sich aber abwenden, so sind sie nur in Abspaltung geraten. Doch Allah wird dir wider sie genügen, und Er ist der Allhörende, der Allwissende.\qt@no{(137)}}
\qt@newcmd\qurantrans@de@cxlv{Dies ist die Weisung Allahs, und wer hat eine schönere Weisung als Allah! Und Ihm dienen wir.\qt@no{(138)}}
\qt@newcmd\qurantrans@de@cxlvi{Sprich: ``Wollt ihr etwa mit uns über Allah streiten, wo Er unser Herr und euer Herr ist? Doch wir haben unsere Taten und ihr habt eure Taten, und Ihm sind wir aufrichtig zugetan.\qt@no{(139)}}
\qt@newcmd\qurantrans@de@cxlvii{Oder wollt ihr etwa sagen, daß Abraham, Ismael, Isaak, Jakob und die Stämme (Israels) Juden oder Christen waren?" Sprich: ``Wisset ihr es besser oder Allah?" Und wer ist ungerechter als derjenige, der ein Zeugnis verbirgt, das er von Allah erhalten hat! Und Allah ist dessen nicht achtlos, was ihr tut.\qt@no{(140)}}
\qt@newcmd\qurantrans@de@cxlviii{Dies ist eine Gemeinde der Vergangenheit; ihr wird zuteil, was sie sich erworben hat, und euch wird zuteil, was ihr euch erworben habt. Und ihr werdet nicht für das verantwortlich sein, was jene getan haben.\qt@no{(141)}}
\qt@newcmd\qurantrans@de@cxlix{Die Toren unter den Menschen werden sagen: ``Was hat sie bewogen, sich von ihrer Qibla abzuwenden, nach der sie sich bisher gerichtet hatten?" Sprich: ``Allah gehört der Osten und der Westen; Er leitet, wen Er will, zu einem geraden Weg."\qt@no{(142)}}
\qt@newcmd\qurantrans@de@cl{Und so machten Wir euch zu einer Gemeinde der Mitte, auf daß ihr Zeugen seiet über die Menschen und auf daß der Gesandte Zeuge sei über euch. Und Wir haben die Qibla, nach der du dich bisher gerichtet hattest, nur gemacht, damit Wir denjenigen, der dem Gesandten folgt, von demjenigen unterscheiden, der auf seinen Fersen eine Kehrtwendung macht; und dies war wahrlich schwer, außer für diejenigen, die Allah rechtgeleitet hat. Und es ist nicht Allah, Der euren Glauben verloren gehen läßt; wahrlich, Allah ist gegenüber den Menschen Mitleidig, Barmherzig.\qt@no{(143)}}
\qt@newcmd\qurantrans@de@cli{Wir sehen, wie dein Gesicht sich dem Himmel suchend zukehrt, und Wir werden dich nun zu einer Qibla wenden, mit der du zufrieden sein wirst. So wende dein Gesicht in Richtung der heiligen Moschee, und wo immer ihr auch seid, wendet eure Gesichter in ihre Richtung. Diejenigen, denen das Buch gegeben wurde, wissen bestimmt, daß es die Wahrheit von ihrem Herrn ist. Und Allah ist dessen nicht achtlos, was sie tun.\qt@no{(144)}}
\qt@newcmd\qurantrans@de@clii{Doch, wenn du denjenigen, denen das Buch gegeben wurde, alle Beweise brächtest, würden sie deine Qibla nicht befolgen. Und du befolgst ihre Qibla nicht; sie befolgen ja selbst untereinander ihre jeweilige Qibla nicht. Doch solltest du ihrem Ansinnen folgen nach dem, was dir an Wissen zugekommen ist, so würdest du bestimmt zu denen gehören, die Unrecht tun.\qt@no{(145)}}
\qt@newcmd\qurantrans@de@cliii{Diejenigen, denen Wir das Buch gegeben haben, kennen es, wie sie ihre eigenen Söhne kennen; und dennoch verbergen einige von ihnen die Wahrheit, wo sie (sie) doch kennen.\qt@no{(146)}}
\qt@newcmd\qurantrans@de@cliv{Dies ist die Wahrheit von deinem Herrn, darum sei nicht einer von denen, die daran zweifeln.\qt@no{(147)}}
\qt@newcmd\qurantrans@de@clv{Jeder hat eine Richtung, der er sich zuwendet. So wetteifert miteinander in guten Werken. Wo immer ihr auch seid, Allah wird euch allesamt herbeiführen; wahrlich, Allah hat Macht über alle Dinge.\qt@no{(148)}}
\qt@newcmd\qurantrans@de@clvi{Und von wo du auch herkommst, wende dein Gesicht in Richtung der heiligen Moschee; denn dies ist gewiß die Wahrheit von deinem Herrn. Und Allah ist dessen nicht achtlos, was ihr tut.\qt@no{(149)}}
\qt@newcmd\qurantrans@de@clvii{Und von wo du auch herkommst, wende dein Gesicht in Richtung der heiligen Moschee. Und wo immer ihr auch seid, wendet eure Gesichter in ihre Richtung, damit die Menschen keinen Beweisgrund gegen euch haben außer denjenigen unter ihnen, die unrecht tun; so fürchtet nicht sie, sondern fürchtet Mich. Und damit Ich Meine Gnade an euch vollende und damit ihr euch vielleicht werdet rechtleiten lassen.\qt@no{(150)}}
\qt@newcmd\qurantrans@de@clviii{Wie Wir auch unter euch einen Gesandten aus eurer Mitte erstehen ließen, der euch Unsere Verse verliest und euch läutert und euch das Buch und die Weisheit lehrt und euch lehrt, was ihr nicht wußtet\qt@no{(151)}}
\qt@newcmd\qurantrans@de@clix{so gedenkt also Meiner, damit Ich euer gedenke; und seid Mir dankbar und verleugnet Mich nicht.\qt@no{(152)}}
\qt@newcmd\qurantrans@de@clx{O ihr, die ihr glaubt, sucht Hilfe in der Geduld und im Gebet; wahrlich Allah ist mit den Geduldigen.\qt@no{(153)}}
\qt@newcmd\qurantrans@de@clxi{Und nennt nicht diejenigen, die auf Allahs Weg getötet wurden, ``Tote". Denn sie leben, ihr aber nehmt es nicht wahr.\qt@no{(154)}}
\qt@newcmd\qurantrans@de@clxii{Und gewiß werden Wir euch prüfen durch etwas Angst, Hunger und Minderung an Besitz, Menschenleben und Früchten. Doch verkünde den Geduldigen eine frohe Botschaft\qt@no{(155)}}
\qt@newcmd\qurantrans@de@clxiii{die, wenn sie ein Unglück trifft, sagen: ``Wir gehören Allah und zu Ihm kehren wir zurück."\qt@no{(156)}}
\qt@newcmd\qurantrans@de@clxiv{Auf diese läßt ihr Herr Segnungen und Barmherzigkeit herab und diese werden rechtgeleitet sein.\qt@no{(157)}}
\qt@newcmd\qurantrans@de@clxv{Wahrlich, As Safa und Al-Marwa gehören zu den Kultstätten Allahs; und wer zu dem Hause pilgert oder die `Umra vollzieht, für den ist es kein Vergehen, wenn er zwischen beiden hin- und herschreitet. Und wenn einer freiwillig Gutes tut, so ist Allah Erkenntlich, Allwissend.\qt@no{(158)}}
\qt@newcmd\qurantrans@de@clxvi{Diejenigen, die verbergen, was Wir von den klaren Beweisen und der Rechtleitung herabsandten, nachdem Wir es den Menschen im Buch erklärt hatten, diese verflucht Allah, und diese verfluchen auch die Fluchenden\qt@no{(159)}}
\qt@newcmd\qurantrans@de@clxvii{außer denjenigen, die sich reuevoll zuwenden, sich bessern und klarstellen. Denen wende Ich Meine Gnade wieder zu; denn Ich bin der gnädig Sich-wieder-Zuwendende, der Barmherzige.\qt@no{(160)}}
\qt@newcmd\qurantrans@de@clxviii{Wahrlich, diejenigen, die ungläubig sind und in ihrem Unglauben sterben, auf denen lastet der Fluch Allahs und der Engel und der Menschen insgesamt.\qt@no{(161)}}
\qt@newcmd\qurantrans@de@clxix{Darin werden sie ewig sein. Die Strafe wird ihnen nicht erleichtert, und es wird ihnen kein Aufschub gewährt.\qt@no{(162)}}
\qt@newcmd\qurantrans@de@clxx{Euer Gott ist ein Einziger Gott, es ist kein Gott außer Ihm, dem Sich-Erbarmenden, dem Barmherzigen.\qt@no{(163)}}
\qt@newcmd\qurantrans@de@clxxi{Wahrlich, im Erschaffen der Himmel und der Erde und im Wechsel von Nacht und Tag und in den Schiffen, die im Meer fahren mit dem, was den Menschen nützt, und in dem, was Allah vom Himmel an Wasser herniedersandte und Er gab der Erde damit Leben, nachdem sie tot war und ließ auf ihr allerlei Getier sich ausbreiten und im Wechsel der Winde und den dienstbaren Wolken zwischen Himmel und Erde, (in all dem) sind Zeichen für Leute, die begreifen.\qt@no{(164)}}
\qt@newcmd\qurantrans@de@clxxii{Und es gibt unter den Menschen einige, die sich außer Allah Seinesgleichen (zum Anbeten) nehmen und lieben, wie man (nur) Allah lieben soll. Die aber, die glauben, lieben Allah noch mehr. Und wenn diejenigen, die Unrecht tun, angesichts der Strafe sehen, daß die Macht gänzlich bei Allah ist und daß Allah streng in der Bestrafung ist!\qt@no{(165)}}
\qt@newcmd\qurantrans@de@clxxiii{(Dereinst,) wenn sich diejenigen, denen (im Diesseits) gefolgt wurde, von jenen lossagen, die ihnen gefolgt sind, und sie die Strafe sehen, während ihnen die Bindungen abgeschnitten sind!\qt@no{(166)}}
\qt@newcmd\qurantrans@de@clxxiv{Und (wenn) diejenigen, die (ihnen) gefolgt sind, sagen: ``Wenn wir zurückkehren könnten, so würden wir uns von ihnen lossagen, wie sie sich von uns losgesagt haben!" So zeigt ihnen Allah ihre Taten als gramvolle Reue, und sie kommen aus dem Feuer nicht heraus.\qt@no{(167)}}
\qt@newcmd\qurantrans@de@clxxv{O ihr Menschen, esset von dem, was es auf der Erde an Erlaubtem und Gutem gibt, und folgt nicht den Fußstapfen des Satans; denn er ist euer offenkundiger Feind.\qt@no{(168)}}
\qt@newcmd\qurantrans@de@clxxvi{Er gebietet euch nur Böses und Abscheuliches, und daß ihr über Allah sagen sollt, was ihr nicht wisset.\qt@no{(169)}}
\qt@newcmd\qurantrans@de@clxxvii{Und wenn ihnen gesagt wird: ``Folgt dem, was Allah herabgesandt hat", so sagen sie: ``Wir folgen doch dem, bei dem wir unsere Väter vorgefunden haben", auch, wenn ihre Väter nichts begriffen hätten und nicht rechtgeleitet gewesen wären?\qt@no{(170)}}
\qt@newcmd\qurantrans@de@clxxviii{Das Gleichnis derjenigen, die ungläubig sind, ist wie das Gleichnis derjenigen, die irgendein (Tier) anschreien, das nichts hört außer Lauten und Zurufen. Taub, stumm und blind sind sie, darum begreifen sie nichts.\qt@no{(171)}}
\qt@newcmd\qurantrans@de@clxxix{O ihr, die ihr glaubt, esset von den guten Dingen, die Wir euch bereitet haben, und seid Allah dankbar, wenn ihr Ihm allein dient.\qt@no{(172)}}
\qt@newcmd\qurantrans@de@clxxx{Verboten hat Er euch nur (den Genuß von) natürlich Verendetem, Blut, Schweinefleisch und dem, worüber etwas anderes als Allah angerufen worden ist. Wenn aber jemand (dazu) gezwungen ist, ohne (es) zu begehren und ohne das Maß zu überschreiten, so trifft ihn keine Schuld; wahrlich, Allah ist Allverzeihend, Barmherzig.\qt@no{(173)}}
\qt@newcmd\qurantrans@de@clxxxi{Diejenigen, die verbergen, was Allah von dem Buch herabgesandt hat, und es um einen geringen Preis verkaufen, diese verzehren in ihren Bäuchen nichts als Feuer. Und Allah wird zu ihnen am Tage der Auferstehung weder sprechen noch wird Er sie läutern; und ihnen wird eine schmerzliche Strafe zuteil sein.\qt@no{(174)}}
\qt@newcmd\qurantrans@de@clxxxii{Sie sind es, die den Irrtum für die Rechtleitung erkauft haben und die Strafe für die Vergebung. Wie können sie dem Feuer gegenüber standhaft sein!\qt@no{(175)}}
\qt@newcmd\qurantrans@de@clxxxiii{Dies geschieht darum weil Allah das Buch mit der Wahrheit herabgesandt hat. Und diejenigen, die sich über das Buch streiten, befinden sich gewiß in großer Feindschaft.\qt@no{(176)}}
\qt@newcmd\qurantrans@de@clxxxiv{Es ist keine Frömmigkeit, wenn ihr eure Angesichter in Richtung Osten oder Westen wendet; Frömmigkeit ist vielmehr, daß man an Allah glaubt, den Jüngsten Tag, die Engel, das Buch und die Propheten und vom Besitz obwohl man ihn liebt den Verwandten gibt, den Waisen, den Armen, dem Sohn des Weges, den Bettlern und (für den Freikauf von) Sklaven, daß man das Gebet verrichtet und die Zakah entrichtet. Es sind diejenigen, die ihr Versprechen einhalten, wenn sie es gegeben haben; und diejenigen, die in Elend, Not und in Kriegszeiten geduldig sind; sie sind es, die wahrhaftig und gottesfürchtig sind.\qt@no{(177)}}
\qt@newcmd\qurantrans@de@clxxxv{O ihr, die ihr glaubt! Es ist euch die Wiedervergeltung vorgeschrieben für die Getöteten: der Freie für den Freien, der Sklave für den Sklaven, das Weibliche für das Weibliche. Doch wenn jemandem von seinem Bruder etwas vergeben wird, so soll der Vollzug auf geziemende Art und die Leistung ihm gegenüber auf wohltätige Weise geschehen. Dies ist eine Erleichterung von eurem Herrn und eine Barmherzigkeit. Wer nun von jetzt an (die Gesetze) übertritt, dem wird eine schmerzliche Strafe zuteil sein.\qt@no{(178)}}
\qt@newcmd\qurantrans@de@clxxxvi{In der Wiedervergeltung ist Leben für euch, o ihr, die ihr einsichtig seid! Vielleicht werdet ihr Allah fürchten.\qt@no{(179)}}
\qt@newcmd\qurantrans@de@clxxxvii{Es ist euch vorgeschrieben, daß, wenn sich bei einem von euch der Tod einstellt, sofern er Gut hinterläßt, den Eltern und den Verwandten auf geziemende Art ein Vermächtnis gemacht wird. Dies ist eine Verpflichtung gegenüber den Gottesfürchtigen.\qt@no{(180)}}
\qt@newcmd\qurantrans@de@clxxxviii{Doch wer es umändert, nachdem er es gehört hat so liegt die Schuld dafür nur bei denen, die es umändern. Wahrlich, Allah ist Allhörend, Allwissend.\qt@no{(181)}}
\qt@newcmd\qurantrans@de@clxxxix{Wer aber seitens des Erblassers Unrecht oder Vergehen befürchtet und zwischen ihnen Frieden stiftet, so trifft ihn keine Schuld. Wahrlich, Allah ist Allverzeihend, Barmherzig.\qt@no{(182)}}
\qt@newcmd\qurantrans@de@cxc{O ihr, die ihr glaubt! Das Fasten ist euch vorgeschrieben, so wie es denen vorgeschrieben war, die vor euch waren. Vielleicht werdet ihr (Allah) fürchten.\qt@no{(183)}}
\qt@newcmd\qurantrans@de@cxci{Es sind nur abgezählte Tage. Und wer von euch krank ist oder sich auf einer Reise befindet, soll eine Anzahl anderer Tage (fasten) Und denen, die es mit großer Mühe ertragen können, ist als Ersatz die Speisung eines Armen auferlegt. Und wenn jemand freiwillig Gutes tut, so ist es besser für ihn. Und daß ihr fastet, ist besser für euch, wenn ihr es (nur) wüßtet!\qt@no{(184)}}
\qt@newcmd\qurantrans@de@cxcii{Der Monat Ramadan ist es, in dem der Quran als Rechtleitung für die Menschen herabgesandt worden ist und als klarer Beweis der Rechtleitung und der Unterscheidung. Wer also von euch in dem Monat zugegen ist, der soll in ihm fasten. Und wer krank ist oder sich auf einer Reise befindet, soll eine Anzahl anderer Tage (fasten) Allah will es euch leicht, Er will es euch nicht schwer machen damit ihr die Frist vollendet und Allah rühmt, daß Er euch geleitet hat. Vielleicht werdet ihr dankbar sein.\qt@no{(185)}}
\qt@newcmd\qurantrans@de@cxciii{Und wenn dich Meine Diener über Mich befragen, so bin Ich nahe; Ich höre den Ruf des Rufenden, wenn er Mich ruft. Deshalb sollen sie auf Mich hören und an Mich glauben. Vielleicht werden sie den rechten Weg einschlagen.\qt@no{(186)}}
\qt@newcmd\qurantrans@de@cxciv{Es ist euch erlaubt, euch in der Nacht des Fastens euren Frauen zu nähern; sie sind Geborgenheit für euch und ihr seid Geborgenheit für sie. Allah weiß, daß ihr gegen euch selbst trügerisch gehandelt habt, und Er wandte euch Seine Gnade wieder zu und vergab euch. So pflegt nun Verkehr mit ihnen und trachtet nach dem, was Allah für euch bestimmt hat. Und esset und trinkt, bis der weiße Faden von dem schwarzen Faden der Morgendämmerung für euch erkennbar wird. Danach vollendet das Fasten bis zur Nacht. Und pflegt keinen Verkehr mit ihnen, während ihr euch in die Moscheen zurückgezogen habt. Dies sind die Schranken Allahs, so kommt ihnen nicht nahe! So erklärt Allah den Menschen Seine Zeichen. Vielleicht werden sie (Ihn) fürchten.\qt@no{(187)}}
\qt@newcmd\qurantrans@de@cxcv{Und verschlingt nicht euren Besitz untereinander in ungerechter Weise und bietet ihn nicht den Behörden an, um einen Teil vom Besitz der Menschen in sündhafter Weise zu verschlingen, wo ihr doch wisset.\qt@no{(188)}}
\qt@newcmd\qurantrans@de@cxcvi{Sie fragen dich nach den Neumonden. Sprich: ``Sie sind festgesetzte Zeiten für die Menschen und den Hagg." Und es ist keine Frömmigkeit, wenn ihr Häuser von der Rückseite betretet. Frömmigkeit ist vielmehr, (Allah) zu fürchten. So geht in die Häuser durch ihre Türen hinein und fürchtet Allah. Vielleicht werdet ihr erfolgreich sein.\qt@no{(189)}}
\qt@newcmd\qurantrans@de@cxcvii{Und kämpft auf dem Weg Allahs gegen diejenigen, die gegen euch kämpfen, doch übertretet nicht. Wahrlich, Allah liebt nicht diejenigen, die übertreten.\qt@no{(190)}}
\qt@newcmd\qurantrans@de@cxcviii{Und tötet sie, wo immer ihr auf sie stoßt, und vertreibt sie, von wo sie euch vertrieben haben; denn die Verführung (zum Unglauben) ist schlimmer als Töten. Und kämpft nicht gegen sie bei der heiligen Moschee, bis sie dort gegen euch kämpfen. Wenn sie aber gegen euch kämpfen, dann tötet sie. Solcherart ist der Lohn der Ungläubigen.\qt@no{(191)}}
\qt@newcmd\qurantrans@de@cxcix{Wenn sie aber aufhören, so ist Allah Allverzeihend, Barmherzig.\qt@no{(192)}}
\qt@newcmd\qurantrans@de@cc{Und kämpft gegen sie, bis es keine Verwirrung (mehr) gibt und die Religion Allah gehört. Wenn sie aber aufhören, so soll es keine Gewalttätigkeit geben außer gegen diejenigen, die Unrecht tun.\qt@no{(193)}}
\qt@newcmd\qurantrans@de@cci{Der heilige Monat ist für den heiligen Monat, und für die geschützten Dinge ist Wiedervergeltung (bestimmt) Wer nun gegen euch gewalttätig handelt, gegen den handelt in gleichem Maße gewalttätig, wie er gegen euch gewalttätig war, und fürchtet Allah und wisset, daß Allah mit den Gottesfürchtigen ist.\qt@no{(194)}}
\qt@newcmd\qurantrans@de@ccii{Und spendet auf dem Weg Allahs und stürzt euch nicht mit eigenen Händen ins Verderben und tut Gutes! Wahrlich, Allah liebt diejenigen, die Gutes tun.\qt@no{(195)}}
\qt@newcmd\qurantrans@de@cciii{Und vollendet den Hagg und die `Umra für Allah. Und wenn ihr daran gehindert werdet, so bringt ein Opfertier dar, das euch (zu opfern) leicht fällt. Und schert nicht eure Häupter, bis das Opfertier seinen Bestimmungsort erreicht hat. Und wer von euch krank ist oder an seinem Haupt ein Leiden hat, der soll Ersatz leisten durch Fasten, Mildtätigkeit oder Darbringen eines Schlachtopfers. Und wenn ihr euch sicher fühlt, dann soll der, der die 'Umra mit dem Hagg vollziehen möchte, ein Opfertier (darbringen), das ihm (zu opfern) leicht fällt. Und wer keines zu finden vermag, soll drei Tage während des Hagg fasten und sieben, wenn ihr zurückgekehrt seid. Dies sind zehn insgesamt. Dies gilt für den, dessen Angehörige nicht nahe der heiligen Moschee wohnen. Und seid gottesfürchtig und wisset, daß Allah streng ist im Strafen.\qt@no{(196)}}
\qt@newcmd\qurantrans@de@cciv{Für den Hagg sind bekannte Monate (vorgesehen) Wer sich in ihnen zum Hagg entschlossen hat, der enthalte sich des Beischlafs und begehe weder Frevel noch unziemliche Rede wahrend des Hagg. Und was ihr an Gutem tut, Allah weiß es. Und sorgt für die Reise, doch wahrlich, die beste Vorsorge ist Gottesfurcht. Und fürchtet Mich, o ihr, die ihr einsichtig seid!\qt@no{(197)}}
\qt@newcmd\qurantrans@de@ccv{Es ist kein Vergehen von euch, wenn ihr nach der Gunst eures Herrn strebt. Und wenn ihr von `Arafat herbeieilt, dann gedenkt Allahs bei AI-Masari-l- haram. Und gedenkt Seiner, wie Er euch rechtgeleitet hat, obwohl ihr wahrlich vordem unter jenen waret, die irregingen.\qt@no{(198)}}
\qt@newcmd\qurantrans@de@ccvi{Dann eilt dorthin weiter, von wo die Menschen weitereilen, und bittet Allah um Vergebung. Wahrlich, Allah ist Allverzeihend, Barmherzig.\qt@no{(199)}}
\qt@newcmd\qurantrans@de@ccvii{Und wenn ihr eure heiligen Riten beendet habt, dann gedenkt Allahs, so wie ihr eurer Väter zu gedenken pflegt oder vielmehr mit noch stärkerem Gedenken. Denn unter den Menschen sind welche, die sagen: ``Unser Herr, gib uns Gutes in dieser Welt." Doch haben sie nicht im Jenseits Anteil am Guten.\qt@no{(200)}}
\qt@newcmd\qurantrans@de@ccviii{Und unter ihnen sind manche, die sagen: ``Unser Herr, gib uns in dieser Welt Gutes und im Jenseits Gutes und verschone uns vor der Strafe des Feuers!"\qt@no{(201)}}
\qt@newcmd\qurantrans@de@ccix{Diesen wird ein Anteil von dem (gewährt), was sie erworben haben; und Allah ist schnell im Abrechnen.\qt@no{(202)}}
\qt@newcmd\qurantrans@de@ccx{Und gedenkt Allahs während einer bestimmten Anzahl von Tagen; und wer eilig in zwei Tagen aufbricht, den trifft keine Schuld, und wer länger bleibt, den trifft keine Schuld, wenn er gottesfürchtig ist. Und fürchtet Allah und wisset, daß ihr zu Ihm geführt werdet.\qt@no{(203)}}
\qt@newcmd\qurantrans@de@ccxi{Und unter den Menschen gibt es manch einen, dessen Rede über diese Welt dich in Verwunderung versetzen mag; und er ruft Allah zum Zeugen an für das, was in seinem Herzen ist. Und dabei ist er der streitsüchtigste Widersacher.\qt@no{(204)}}
\qt@newcmd\qurantrans@de@ccxii{Wenn er sich abwendet, bemüht er sich, überall auf der Erde Unheil zu stiften, und vernichtet das Ackerland und die Nachkommenschaft. Und Allah liebt das Unheil nicht.\qt@no{(205)}}
\qt@newcmd\qurantrans@de@ccxiii{Und wenn ihm gesagt wird: ``Fürchte Allah", überwältigt ihn sündhafter Stolz. Gahannam ist ein angemessenes Entgelt für ihn was für eine schlechte Ruhestätte!\qt@no{(206)}}
\qt@newcmd\qurantrans@de@ccxiv{Und unter den Menschen ist manch einer, der sich selbst hergibt im Verlangen nach Allahs Wohlgefallen. Und Allah ist wahrlich gütig gegen die Diener.\qt@no{(207)}}
\qt@newcmd\qurantrans@de@ccxv{O ihr, die ihr glaubt! Tretet allesamt ein in das Heil und folgt nicht den Fußstapfen des Satans; wahrlich, er ist euer offenkundiger Feind.\qt@no{(208)}}
\qt@newcmd\qurantrans@de@ccxvi{Und wenn ihr straucheln solltet, nachdem die Beweise zu euch gekommen sind, dann wisset, daß Allah Allmächtig ist und Allweise.\qt@no{(209)}}
\qt@newcmd\qurantrans@de@ccxvii{Erwarten sie etwa, daß Allah ihnen beschirmt von Wolken erscheine und mit Ihm die Engel doch dann ist die Sache schon entschieden. Und zu Allah werden alle Dinge zurückgeführt.\qt@no{(210)}}
\qt@newcmd\qurantrans@de@ccxviii{Frage die Kinder Israels, wieviel klare Beweise Wir ihnen gegeben haben. Doch wer die Gnade Allahs eintauscht, nachdem sie ihm zuteil geworden ist dann ist Allah wahrlich streng im Strafen.\qt@no{(211)}}
\qt@newcmd\qurantrans@de@ccxix{Anziehend erscheint denen, die ungläubig sind, das diesseitige Leben, und sie verhöhnen diejenigen, die glauben. Doch diejenigen, die gottesfürchtig sind, werden am Tag der Auferstehung über ihnen stehen. Und Allah beschert, wem Er will, ohne Maß.\qt@no{(212)}}
\qt@newcmd\qurantrans@de@ccxx{Die Menschen waren eine einzige Gemeinschaft. Dann entsandte Allah die Propheten als Bringer froher Botschaft und als Warner. Und Er offenbarte ihnen das Buch mit der Wahrheit, um zwischen den Menschen zu richten über das, worüber sie uneins waren. Uneins aber waren nur jene, denen es gegeben wurde, nachdem klare Beweise zu ihnen gekommen waren, aus Mißgunst untereinander. Doch Allah leitet mit Seiner Erlaubnis diejenigen, die gläubig sind, zur Wahrheit, über die sie uneins waren. Und Allah leitet, wen Er will, auf einen geraden Weg.\qt@no{(213)}}
\qt@newcmd\qurantrans@de@ccxxi{Oder meint ihr etwa, ihr würdet ins Paradies eingehen, ohne (daß etwas) Ähnliches über euch gekommen sei wie über diejenigen, die vor euch dahingegangen sind? Not und Unheil erfaßte sie, und sie sind erschüttert worden, bis der Gesandte und diejenigen, die mit ihm gläubig waren, sagten: ``Wann kommt die Hilfe Allahs?" Doch wahrlich, Allahs Hilfe ist nahe.\qt@no{(214)}}
\qt@newcmd\qurantrans@de@ccxxii{Sie befragen dich, was sie spenden sollen. Sprich: ``Was immer ihr spendet an Gutem, das sei für die Eltern und Verwandten und die Waisen und die Armen und den Sohn des Weges. Und was immer ihr an Gutem tut, wahrlich, Allah weiß es wohl."\qt@no{(215)}}
\qt@newcmd\qurantrans@de@ccxxiii{Zu kämpfen ist euch vorgeschrieben auch wenn es euch widerwärtig ist. Doch es mag sein, daß euch etwas widerwärtig ist, was gut für euch ist, und es mag sein, daß euch etwas lieb ist, was übel für euch ist. Und Allah weiß es, doch ihr wisset es nicht.\qt@no{(216)}}
\qt@newcmd\qurantrans@de@ccxxiv{Sie befragen dich über das Kämpfen im heiligen Monat. Sprich: ``Das Kämpfen in ihm ist schwerwiegend. Doch das Abbringen vom Weg Allahs und nicht an Ihn zu glauben und (den Zutritt) zur heiligen Moschee (zu verwehren) und deren Bewohner daraus zu vertreiben, ist schwerwiegender vor Allah. Und die Verführung ist schwerwiegender als Töten." Und sie werden nicht ablassen, gegen euch zu kämpfen, bis sie euch von eurem Glauben abbringen, wenn sie dazu imstande sind. Wer sich aber von euch von seinem Glauben abbringen läßt und als Ungläubiger stirbt das sind diejenigen, deren Taten wertlos sein werden in dieser Welt und im Jenseits. Sie werden die Bewohner des Feuers sein, und darin werden sie ewig verweilen.\qt@no{(217)}}
\qt@newcmd\qurantrans@de@ccxxv{Wahrlich, jene, die glauben und ausgewandert sind und sich auf dem Weg Allahs mit aller Kraft einsetzen, die sind es, die auf die Barmherzigkeit Allahs hoffen. Und Allah ist Allverzeihend, Barmherzig.\qt@no{(218)}}
\qt@newcmd\qurantrans@de@ccxxvi{Sie befragen dich über Berauschendes und Glücksspiel. Sprich: ``In beiden liegt großes Übel und Nutzen für die Menschen. Doch ihr Übel ist größer als ihr Nutzen." Und sie befragen dich was sie spenden sollen. Sprich: ``Den Überschuß." So macht euch Allah die Zeichen klar, damit ihr nachdenken möget\qt@no{(219)}}
\qt@newcmd\qurantrans@de@ccxxvii{über diese Welt und das Jenseits. Sie befragen dich über die Waisen. Sprich: ``Ihre Lage zu verbessern ist gut. Und wenn ihr ihre Angelegenheiten mit den euren zusammentut, so sind sie eure Geschwister." Und Allah weiß den Unheilstifter von dem zu unterscheiden, der Gutes tut. Und wenn Allah es gewollt hätte, hätte Er euch in Bedrängnis gebracht. Wahrlich, Allah ist Allmächtig, Allweise.\qt@no{(220)}}
\qt@newcmd\qurantrans@de@ccxxviii{Und heiratet keine Götzenanbeterinnen, ehe sie glauben. Und eine gläubige Dienerin ist besser als eine Götzenanbeterin, mag sie euch auch noch so gut gefallen. Und verheiratet nicht (gläubige Frauen) mit Götzenanbetern, ehe sie glauben. Und ein gläubiger Diener ist besser als ein Götzenanbeter, mag er euch auch noch so gut gefallen. Jene rufen zum Feuer, doch Allah ruft zum Paradies und zur Verzeihung mit Seiner Erlaubnis und macht den Menschen Seine Zeichen klar, damit sie Seiner gedenken mögen.\qt@no{(221)}}
\qt@newcmd\qurantrans@de@ccxxix{Und sie befragen dich über die Menstruation. Sprich: ``Sie ist ein Leiden. So haltet euch von den Frauen während der Menstruation fern und kommt ihnen nicht nahe, bis sie rein sind; und wenn sie rein sind, dann geht zu ihnen, wie Allah es euch geboten hat. Wahrlich, Allah liebt diejenigen, die sich (Ihm) reuevoll zuwenden und die sich reinigen."\qt@no{(222)}}
\qt@newcmd\qurantrans@de@ccxxx{Eure Frauen sind ein Saatfeld für euch: darum bestellt euer Saatfeld wie ihr wollt. Doch schickt (Gutes) für euch voraus. Und fürchtet Allah und wisset, daß ihr Ihm begegnen werdet. Und verheiße den Gläubigen die frohe Botschaft.\qt@no{(223)}}
\qt@newcmd\qurantrans@de@ccxxxi{Und macht Allah nicht bei euren Schwüren zum Hinderungsgrund, ehrlich und gottesfürchtig zu sein und Frieden zwischen den Menschen zu stiften. Und Allah ist Allhörend, Allwissend.\qt@no{(224)}}
\qt@newcmd\qurantrans@de@ccxxxii{Allah wird euch nicht Unachtsamkeit in euren Schwüren zum Vorwurf machen, doch macht Er euch das zum Vorwurf, was eure Herzen erworben haben. Und Allah ist Allverzeihend, Nachsichtig.\qt@no{(225)}}
\qt@newcmd\qurantrans@de@ccxxxiii{Diejenigen, die Enthaltsamkeit von ihren Frauen beschwören, sollen vier Monate warten. Wenn sie sich dann von ihrem Schwur entbinden wollen, ist Allah wahrlich Allverzeihend, Barmherzig.\qt@no{(226)}}
\qt@newcmd\qurantrans@de@ccxxxiv{Doch wenn sie den festen Entschluß zur Scheidung gefaßt haben, dann ist Allah wahrlich Allhörend, Allwissend.\qt@no{(227)}}
\qt@newcmd\qurantrans@de@ccxxxv{Geschiedene Frauen sollen selbst drei Perioden abwarten, und es ist ihnen nicht erlaubt, zu verbergen, was Allah in ihrer Gebärmutter erschaffen hat, wenn sie an Allah und an den Jüngsten Tag glauben. Und ihre Ehemänner haben vorrangig das Anrecht, sie dann zurückzunehmen, wenn sie eine Versöhnung anstreben. Und den (Frauen) stehen die gleichen Rechte zu wie sie (die Männer) zur gütigen Ausübung über sie haben. Doch die Männer stehen eine Stufe über ihnen. Und Allah ist Allmächtig, Allweise.\qt@no{(228)}}
\qt@newcmd\qurantrans@de@ccxxxvi{Die Scheidung ist zweimal. Dann (sollen die Männer die Frauen) in angemessener Weise behalten oder im Guten entlassen. Und es ist euch nicht erlaubt, irgend etwas von dem zurückzunehmen, was ihr ihnen (als Brautgabe) gegeben habt, es sei denn, beide (Mann und Frau) befürchten, die Schranken Allahs nicht einhalten zu können. Und wenn ihr befürchtet, daß sie die Schranken Allahs nicht einhalten können, dann liegt kein Vergehen für sie beide in dem, was sie hingibt, um sich damit loszukaufen. Dies sind die Schranken Allahs, so übertretet sie nicht. Und wer die Schranken Allahs übertritt das sind diejenigen, die Unrecht tun.\qt@no{(229)}}
\qt@newcmd\qurantrans@de@ccxxxvii{Und wenn er sie entläßt, dann ist sie ihm nicht mehr erlaubt, solange sie nicht einen anderen Mann geheiratet hat. Wenn dieser sie entläßt, ist es kein Vergehen für beide, wenn sie zueinander zurückkehren, sofern sie annehmen, daß sie die Gebote Allahs einhalten können. Dies sind die Schranken Allahs, die Er denjenigen klarmacht, die wissen.\qt@no{(230)}}
\qt@newcmd\qurantrans@de@ccxxxviii{Und wenn ihr euch von den Frauen scheidet und sie sich der Erfüllung ihrer Wartezeit nähern, dann behaltet sie in gütiger Weise oder entlaßt sie in gütiger Weise. Doch behaltet sie nicht aus Schikane, um zu übertreten. Und wer dies tut, der fügt sich selbst Unrecht zu. Und macht euch nicht über die Zeichen Allahs lustig, und gedenkt der Gnade Allahs, die Er euch erwiesen hat und dessen, was Er euch vom Buch und der Weisheit herabgesandt hat, um euch damit zu ermahnen. Und fürchtet Allah und wisset, daß Allah über alles Bescheid weiß.\qt@no{(231)}}
\qt@newcmd\qurantrans@de@ccxxxix{Und wenn ihr die Frauen entlaßt und sie ihren Termin erreichen, dann haltet sie nicht davon ab, ihre Gatten zu heiraten, wenn sie sich in gütiger Weise einigen. Dies ist eine Ermahnung für denjenigen unter euch, der an Allah und an den Jüngsten Tag glaubt. Das ist besser für eure Lauterkeit und Reinheit. Und Allah weiß, doch ihr wisset nicht.\qt@no{(232)}}
\qt@newcmd\qurantrans@de@ccxl{Und die Mütter stillen ihre Kinder zwei volle Jahre. (Das gilt) für die, die das Stillen vollenden wollen. Und es obliegt dem, dem das Kind geboren wurde, für ihre Nahrung und Kleidung auf gütige Weise Sorge zu tragen. Von keiner Seele soll etwas gefordert werden über das hinaus, was sie zu leisten vermag. Einer Mutter soll nicht wegen ihres Kindes Schaden zugefügt werden, und dem, dem das Kind geboren wurde, nicht wegen seines Kindes. Und für den Erben gilt das gleiche. Und wenn sie beide in gegenseitigem Einvernehmen und nach Beratung (das Kind vorzeitig) entwöhnen wollen, dann liegt darin kein Vergehen für sie. Und wenn ihr eure Kinder stillen lassen wollt, so ist es kein Vergehen für euch, sofern ihr das, was ihr vereinbart habt, in gütiger Weise bezahlt. Und fürchtet Allah und wisset, daß Allah wohl sieht, was ihr tut.\qt@no{(233)}}
\qt@newcmd\qurantrans@de@ccxli{Und wenn diejenigen von euch, die abberufen werden, Gattinnen zurücklassen, so sollen diese (Witwen) vier Monate und zehn Tage abwarten. Und wenn sie dann ihren Termin erreicht haben, so ist es kein Vergehen für euch, wenn sie in gütiger Weise über sich selbst verfügen. Und Allah ist wohl vertraut mit dem, was ihr tut.\qt@no{(234)}}
\qt@newcmd\qurantrans@de@ccxlii{Und es ist kein Vergehen für euch, wenn ihr ihnen gegenüber Heiratsabsichten andeutet oder euch insgeheim mit diesem Gedanken tragt. Allah wußte, daß ihr an sie denken werdet. Doch verabredet euch nicht heimlich mit ihnen, außer ihr sprecht ein geziemendes Wort. Und faßt keinen festen Entschluß zum Ehebund, bevor die Wartezeit erfüllt ist. Und wisset, daß Allah dessen gewahr ist, was in euren Seelen ist. Darum seid vor Ihm auf der Hut. Und wisset, daß Allah Allverzeihend und Nachsichtig ist.\qt@no{(235)}}
\qt@newcmd\qurantrans@de@ccxliii{Es ist kein Vergehen für euch, wenn ihr die Frauen entlaßt, bevor ihr sie berührt oder ihnen eine Brautgabe gewahrt habt. Doch gewährt ihnen Versorgung: der Wohlhabende (nach dem,) was er vermag, und der Minderbemittelte nach dem, was er vermag eine Versorgung auf gütige Weise. (Dies ist) eine Verpflichtung für die Gütigen.\qt@no{(236)}}
\qt@newcmd\qurantrans@de@ccxliv{Und wenn ihr sie entlaßt, bevor ihr sie berührt habt, jedoch nachdem ihr ihnen eine Brautgabe ausgesetzt habt, dann zahlt die Hälfte dessen, was ihr ausgesetzt habt, es sei denn, sie erlassen es (euch) oder der, in dessen Hand der Ehebund ist, erläßt es. Und wenn ihr es erlaßt, so kommt das der Gottesfürchtigkeit näher. Und vergesset nicht, einander Güte zu erweisen. Wahrlich, Allah sieht wohl, was ihr tut.\qt@no{(237)}}
\qt@newcmd\qurantrans@de@ccxlv{Haltet die Gebete ein, so wie das mittlere Gebet. Und steht in demütiger Ergebenheit vor Allah.\qt@no{(238)}}
\qt@newcmd\qurantrans@de@ccxlvi{Doch wenn ihr in Furcht seid, dann betet zu Fuß oder im Reiten. Und wenn ihr in Sicherheit seid, gedenkt Allahs, wie Er euch das gelehrt hat, was ihr nicht wußtet.\qt@no{(239)}}
\qt@newcmd\qurantrans@de@ccxlvii{Und diejenigen von euch, die abberufen werden und Gattinnen zurücklassen, sollen ihren Gattinnen Versorgung für ein Jahr vermachen, ohne daß sie vertrieben werden. Gehen sie jedoch weg, so ist es kein Vergehen für euch, wenn sie zu ihrem Besten über sich selbst verfügen. Und Allah ist Erhaben, Allweise.\qt@no{(240)}}
\qt@newcmd\qurantrans@de@ccxlviii{Und den geschiedenen Frauen eine Versorgung auf gütige Weise (zu geben, ist) eine Verpflichtung für die Gottesfürchtigen.\qt@no{(241)}}
\qt@newcmd\qurantrans@de@ccxlix{So macht euch Allah Seine Zeichen klar; vielleicht werdet ihr (es) begreifen.\qt@no{(242)}}
\qt@newcmd\qurantrans@de@ccl{Hast du nicht über jene nachgedacht, die in Todesfurcht zu Tausenden aus ihren Häusern auszogen? Allah sprach zu ihnen: ``Sterbt!" Dann gab Er ihnen das Leben (wieder) Wahrlich, Allah ist huldvoll gegen die Menschen, doch die meisten Menschen sind nicht dankbar.\qt@no{(243)}}
\qt@newcmd\qurantrans@de@ccli{Und kämpft auf dem Weg Allahs und wisset, daß Allah Allhörend und Allwissend ist.\qt@no{(244)}}
\qt@newcmd\qurantrans@de@cclii{Wer ist es, der Allah ein gutes Darlehen gibt, damit Er es ihm um ein vielfaches verdoppele? Und Allah schmälert und mehrt, und zu Ihm werdet ihr zurückgebracht.\qt@no{(245)}}
\qt@newcmd\qurantrans@de@ccliii{Hast du nicht nachgedacht über die Vornehmen von den Kindern Israels (in der Zeit) nach Moses, als sie zu einem Propheten unter ihnen sagten: ``Setze für uns einen König ein, damit wir auf dem Weg Allahs kämpfen!" Er sagte: ``Ist es nicht möglich, daß ihr, wenn euch vorgeschrieben ist zu kämpfen, doch nicht kämpfen werdet?" Sie sagten: ``Was sollte uns dazu bewegen, daß wir nicht auf dem Weg Allahs kämpfen, wo wir doch aus unseren Häusern vertrieben und von unseren Söhnen (getrennt) worden sind?" Doch als ihnen vorgeschrieben wurde zu kämpfen, da wandten sie sich ab bis auf wenige von ihnen. Und Allah kennt die Ungerechten.\qt@no{(246)}}
\qt@newcmd\qurantrans@de@ccliv{Und ihr Prophet sagte zu ihnen: ``Wahrlich, Allah hat bereits Saul zum König über euch eingesetzt." Da fragten sie: ``Wie kann ihm die Herrschaft über uns zustehen, wo wir doch das (größere) Anrecht auf die Herrschaft haben als er und ihm nicht genügend Besitz gegeben ist?" Er sagte: ``Wahrlich, Allah hat ihn vor euch auserwählt und hat ihm reichlich Wissen und körperliche Vorzüge verliehen. Und Allah gibt Seine Herrschaft, wem Er will." Und Allah ist Allumfassend, Allwissend.\qt@no{(247)}}
\qt@newcmd\qurantrans@de@cclv{Und ihr Prophet sagte zu ihnen: ``Wahrlich, ein Zeichen für seine Herrschaft soll sein, daß die Bundeslade zu euch (zurück) kommen wird; darin ist Frieden von eurem Herrn und ein Vermächtnis von dem, was die Nachkommen von Moses und die Nachkommen von Aaron hinterlassen haben. Sie wird von Engeln getragen. Wahrlich, darin ist ein Zeichen für euch, wenn ihr Gläubige seid."\qt@no{(248)}}
\qt@newcmd\qurantrans@de@cclvi{Und als Saul mit den Heerscharen auszog, sagte er: ``Wahrlich, Allah wird euch an einem Fluß prüfen. Wer aus ihm trinkt, gehört nicht zu mir, und wer nicht davon kostet, der gehört wahrlich zu mir, außer dem, der nur eine Handvoll mit seiner Hand (daraus) schöpft." Und sie tranken davon bis auf wenige von ihnen. Und als sie den Fluß überquert hatten, er und diejenigen, die mit ihm gläubig waren, sagten sie: ``Wir haben heute keine Kraft gegen Goliath und seine Heerscharen." Doch diejenigen, die damit rechneten, daß sie Allah begegnen würden, sagten: ``Wie oft hat nicht eine geringe Schar über eine große Schar gesiegt mit Allahs Erlaubnis! Und Allah ist mit den Geduldigen."\qt@no{(249)}}
\qt@newcmd\qurantrans@de@cclvii{Und als sie gegen Goliath und seine Heerscharen in den Kampf zogen, sagten sie: ``Unser Herr, verleih uns reichlich Geduld und festige unsere Schritte und hilf uns gegen das Volk der Ungläubigen."\qt@no{(250)}}
\qt@newcmd\qurantrans@de@cclviii{Und sie schlugen sie mit Allahs Erlaubnis, und David erschlug Goliath, und Allah gab ihm die Herrschaft und die Weisheit, und Er lehrte ihn, was Er wollte. Und wenn Allah nicht die einen Menschen durch die anderen zurückgehalten hätte, dann wäre die Erde wahrhaftig von Unheil erfüllt. Doch Allah ist huldvoll gegen alle Welten.\qt@no{(251)}}
\qt@newcmd\qurantrans@de@cclix{Dies sind die Zeichen Allahs. Wir tragen sie dir in Wahrheit vor. Und wahrlich, du bist einer der Gesandten.\qt@no{(252)}}
\qt@newcmd\qurantrans@de@cclx{Dies sind die Gesandten. Wir haben einigen von ihnen den Vorrang über andere gegeben. Unter ihnen sind welche, zu denen Allah gesprochen hat, und einige, die Er um Rangstufen erhöht hat. Und Wir gaben Jesus, dem Sohn Marias, die klaren Beweise und unterstützten ihn durch heilige Eingebung, und wenn Allah es so gewollt hätte, dann hätten sich diejenigen, die nach ihnen kamen, nicht gegenseitig bekämpft, nachdem klare Beweise zu ihnen gekommen waren. Sie wurden jedoch uneins. Die einen von ihnen waren gläubig, die anderen ungläubig. Wenn Allah es so gewollt hätte, dann hätten sie sich nicht gegenseitig bekämpft. Doch Allah tut, was Er will.\qt@no{(253)}}
\qt@newcmd\qurantrans@de@cclxi{O ihr, die ihr glaubt! Spendet von dem, was Wir euch (an Gut) beschert haben, bevor ein Tag kommt, an dem es kein Handeln, keine Freundschaft und keine Fürsprache (mehr) geben wird. Die Ungläubigen sind es, die Unrecht tun.\qt@no{(254)}}
\qt@newcmd\qurantrans@de@cclxii{Allah kein Gott ist da außer Ihm, dem Lebendigen, dem Ewigen. Ihn ergreift weder Schlummer noch Schlaf. Ihm gehört, was in den Himmeln und was auf der Erde ist. Wer ist es, der bei Ihm Fürsprache einlegen könnte außer mit Seiner Erlaubnis? Er weiß, was vor ihnen und was hinter ihnen liegt; sie aber begreifen nichts von Seinem Wissen, es sei denn das, was Er will. Weit reicht Sein Thron über die Himmel und die Erde, und es fällt Ihm nicht schwer, sie (beide) zu bewahren. Und Er ist der Hohe, der Erhabene.\qt@no{(255)}}
\qt@newcmd\qurantrans@de@cclxiii{Es gibt keinen Zwang im Glauben. Der richtige Weg ist nun klar erkennbar geworden gegenüber dem unrichtigen. Der also, der nicht an falsche Götter glaubt, aber an Allah glaubt, hat gewiß den sichersten Halt ergriffen, bei dem es kein Zerreißen gibt. Und Allah ist Allhörend, Allwissend.\qt@no{(256)}}
\qt@newcmd\qurantrans@de@cclxiv{Allah ist der Beschützer derjenigen, die glauben. Er führt sie aus der Finsternis ins Licht. Diejenigen aber die ungläubig sind, deren Freunde sind die Götzen. Sie führen sie aus dem Licht in die Finsternis. Sie werden die Bewohner des Feuers sein, darin werden sie ewig bleiben.\qt@no{(257)}}
\qt@newcmd\qurantrans@de@cclxv{Hast du nicht über jenen nachgedacht, der über seinen Herrn mit Abraham ein Wortgefecht führte, weil Allah ihm die Herrschaft gegeben hatte? Als Abraham sagte: ``Mein Herr ist Derjenige, Der lebendig macht und sterben läßt", sagte er: ``Ich bin es, der lebendig macht und sterben läßt." Da sagte Abraham: ``Doch es ist Allah Der die Sonne im Osten aufgehen läßt; so laß du sie im Westen aufgehen." Da war der Ungläubige verwirrt. Und Allah leitet nicht die ungerechten Leute.\qt@no{(258)}}
\qt@newcmd\qurantrans@de@cclxvi{Oder (hast du auch nicht über) den (nachgedacht), der an einer Stadt vorüberkam, die wüst in Trümmern lag? Da sagte er: ``Oh, wie soll Allah dieser nach ihrer Zerstörung wieder Leben geben?" Und Allah ließ ihn für hundert Jahre tot sein. Dann erweckte Er ihn wieder. Er sprach: ``Wie lange hast du verharrt?" Er sagte: ``Ich verharrte einen Tag oder den Teil eines Tages." Da sprach Er: ``Doch du verharrtest einhundert Jahre. Nun betrachte deine Speise und deinen Trank. Sie sind nicht verdorben. Und betrachte deinen Esel. Wir machen dich damit zu einem Zeichen für die Menschen. Und betrachte die Knochen, wie Wir sie zusammensetzen und dann mit Fleisch bekleiden." Und als ihm dies klargemacht worden war, sagte er: ``Ich weiß, daß Allah Macht hat über alle Dinge."\qt@no{(259)}}
\qt@newcmd\qurantrans@de@cclxvii{Und gedenke, als Abraham sagte: ``Mein Herr, laß mich sehen, wie Du die Toten wieder zum Leben bringst", sprach Er: ``Glaubst du denn nicht?" Er sagte: ``Doch! Aber (ich frage) um mein Herz zu beruhigen." Er sagte: ``Nimm dir vier Vögel und zerstückle sie, dann setze auf jeden Berg einige Teile davon. Hierauf rufe sie. Sie werden eilends zu dir kommen. Und wisse, daß Allah Allmächtig und Allweise ist!"\qt@no{(260)}}
\qt@newcmd\qurantrans@de@cclxviii{Das Gleichnis derjenigen, die ihr Vermögen auf dem Weg Allahs ausgeben, ist wie das Gleichnis eines Samenkorns, das sieben Ähren wachsen läßt, in jeder Ähre hundert Körner. Und Allah vervielfacht es, wem Er will. Und Allah ist Allumfassend, Allwissend.\qt@no{(261)}}
\qt@newcmd\qurantrans@de@cclxix{Diejenigen, die ihren Besitz auf dem Weg Allahs spenden, dann dem, was sie gespendet haben, weder Vorhaltungen noch Ungebührlichkeiten folgen lassen, denen wird ihr Lohn von ihrem Herrn zuteil werden, und weder Angst wird über sie kommen noch werden sie traurig sein.\qt@no{(262)}}
\qt@newcmd\qurantrans@de@cclxx{Gütige Rede und Verzeihung sind besser als ein Almosen, das von einem Übel befolgt wird; und Allah ist Reich und Milde.\qt@no{(263)}}
\qt@newcmd\qurantrans@de@cclxxi{O ihr, die ihr glaubt, vereitelt nicht eure Almosen durch Vorhaltungen und Ungemach, gleich dem, der sein Gut ausgibt, um von den Leuten gesehen zu werden, und nicht an Allah glaubt und an den Jüngsten Tag. Das Gleichnis dessen ist das Gleichnis eines Felsens mit Erdreich darüber, und es trifft ihn ein Platzregen und läßt ihn hart. Sie richten nichts aus mit ihrem Verdienst; denn Allah leitet nicht die ungläubigen Leute.\qt@no{(264)}}
\qt@newcmd\qurantrans@de@cclxxii{Das Gleichnis jener aber, die ihr Gut ausgeben im Trachten nach Allahs Wohlgefallen und zur Stärkung ihrer Seele, ist das Gleichnis eines Gartens auf einem Hügel: es trifft ihn ein Platzregen, und da bringt er seine Früchte zweifach (hervor) Und wenn ihn kein Platzregen trifft, so doch Tau. Und Allah durchschaut euer Tun.\qt@no{(265)}}
\qt@newcmd\qurantrans@de@cclxxiii{Wünscht einer von euch, daß er einen Garten besitze mit Palmen und Reben, durcheilt von Bächen, in dem er allerlei Früchte habe, und daß ihn das Alter treffe, während er (noch) schwache Sprößlinge habe, und (daß) ihn (den Garten) ein feuriger Wirbelsturm da treffe und er verbrenne? So erklärt euch Allah die Zeichen. vielleicht denkt ihr (darüber) nach.\qt@no{(266)}}
\qt@newcmd\qurantrans@de@cclxxiv{O ihr, die ihr glaubt, spendet von dem Guten, das ihr erwarbt, und von dem, was Wir für euch aus der Erde hervorkommen lassen, und sucht darunter zum Spenden nicht das Schlechte aus, das ihr selber nicht nähmet, ohne dabei die Augen zuzudrücken; und wisset, Allah ist Reich und Gepriesen.\qt@no{(267)}}
\qt@newcmd\qurantrans@de@cclxxv{Satan droht euch Armut an und befiehlt euch Schändliches, Allah aber verheißt euch Seine Vergebung und Huld. Und Allah ist Allumfassend und Allwissend.\qt@no{(268)}}
\qt@newcmd\qurantrans@de@cclxxvi{Er gibt die Weisheit, wem Er will, und wem da Weisheit gegeben wurde, dem wurde hohes Gut gegeben; aber diejenigen, die sich mahnen lassen, sind die, die Verstand haben.\qt@no{(269)}}
\qt@newcmd\qurantrans@de@cclxxvii{Und was ihr an Spende gebt oder als Gelübde versprecht, seht, Allah weiß es, und die Ungerechten finden keine Helfer.\qt@no{(270)}}
\qt@newcmd\qurantrans@de@cclxxviii{Wenn ihr Almosen offenkundig gebt, so ist es angenehm, und wenn ihr sie verbergt und sie den Armen gebt, so ist es besser für euch und sühnt eure Missetaten. Und Allah ist eures Tuns kundig.\qt@no{(271)}}
\qt@newcmd\qurantrans@de@cclxxix{Ihre Rechtleitung obliegt nicht dir, sondern Allah leitet recht, wen Er will. Was immer ihr an Gutem spendet, das ist für euch selbst, und ihr (sollt) nicht spenden, es sei denn aus Verlangen nach dem Angesicht Allahs. Und was immer ihr an Gutem spendet, das soll euch voll zurückerstattet werden, und es soll euch kein Unrecht zugefügt werden.\qt@no{(272)}}
\qt@newcmd\qurantrans@de@cclxxx{(Dies ist) für die Armen, die auf dem Weg Allahs (daran) gehindert werden, sich frei im Land zu bewegen. Der Unwissende hält sie für reich wegen (ihrer) Zurückhaltung. Du aber erkennst sie an ihrem Auftreten. Sie betteln die Menschen nicht aufdringlich an. Und was immer ihr an Gutem spendet, wahrlich, Allah weiß es.\qt@no{(273)}}
\qt@newcmd\qurantrans@de@cclxxxi{Diejenigen, die ihren Besitz bei Nacht und Tag, geheim oder offen, spenden denen ist ihr Lohn von ihrem Herrn (gewiß), und sie brauchen keine Angst zu haben noch werden sie traurig sein.\qt@no{(274)}}
\qt@newcmd\qurantrans@de@cclxxxii{Diejenigen, die Zinsen verschlingen, sollen nicht anders dastehen als wie einer, der vom Satan erfaßt und zum Wahnsinn getrieben wird. Dies (soll so sein,) weil sie sagen: ``Handel ist dasselbe wie Zinsnehmen." Doch Allah hat den Handel erlaubt und das Zinsnehmen verboten. Und wenn zu jemandem eine Ermahnung von seinem Herrn kommt und er dann aufhört dem soll verbleiben, was bereits geschehen ist. Und seine Sache ist bei Allah. Wer es aber von neuem tut die werden Bewohner des Feuers sein, darin werden sie ewig SO bleiben.\qt@no{(275)}}
\qt@newcmd\qurantrans@de@cclxxxiii{Allah wird den Zins dahinschwinden lassen und die Mildtätigkeit vermehren. Und Allah liebt keinen, der ein hartnäckiger Ungläubiger und Übeltäter ist.\qt@no{(276)}}
\qt@newcmd\qurantrans@de@cclxxxiv{Wahrlich, denjenigen, die gläubig sind und gute Werke tun und das Gebet verrichten und die Zakah entrichten, ist ihr Lohn von ihrem Herrn (gewiß,) und sie brauchen keine Angst haben noch werden sie traurig sein.\qt@no{(277)}}
\qt@newcmd\qurantrans@de@cclxxxv{O ihr, die ihr glaubt, fürchtet Allah und verzichtet auf das, was noch übrig ist an Zinsen, wenn ihr Gläubige seid.\qt@no{(278)}}
\qt@newcmd\qurantrans@de@cclxxxvi{Und wenn ihr dies nicht tut, dann ist euch Krieg angesagt von Allah und Seinem Gesandten. Doch wenn ihr bereut, dann soll euch euer Kapital zustehen, so daß weder ihr Unrecht tut, noch euch Unrecht zugefügt wird.\qt@no{(279)}}
\qt@newcmd\qurantrans@de@cclxxxvii{Wenn jemand in Schwierigkeiten ist, dann gewährt ihm Aufschub, bis eine Erleichterung (eintritt) Doch wenn ihr mildtätig seid, so ist es besser für euch, wenn ihr es nur wüßtet.\qt@no{(280)}}
\qt@newcmd\qurantrans@de@cclxxxviii{Und fürchtet den Tag, an dem ihr zu Allah zurückgebracht werdet. Dann wird jeder Seele das zurückerstattet, was sie erworben hat, und ihnen wird kein Unrecht geschehen.\qt@no{(281)}}
\qt@newcmd\qurantrans@de@cclxxxix{O ihr, die ihr glaubt, wenn ihr eine Anleihe gewährt oder aufnehmt zu einer festgesetzten Frist, dann schreibt es nieder. Und ein Schreiber soll es in eurem Beisein getreulich niederschreiben. Und kein Schreiber soll sich weigern zu schreiben, so wie Allah es gelehrt hat. So schreibe er also, und der Schuldner soll es diktieren und Allah, seinen Herrn, fürchten und nichts davon weglassen. Und wenn der Schuldner schwachsinnig oder schwach ist oder unfähig, selbst zu diktieren, dann soll sein Sachwalter getreulich für ihn diktieren. Und lasset zwei Zeugen unter euren Männern es bezeugen, und wenn es keine zwei Männer gibt, dann (sollen es bezeugen) ein Mann und zwei Frauen von denen, die euch als Zeugen geeignet erscheinen, damit, wenn sich eine der beiden irrt, die andere von ihnen sie (daran) erinnert. Und die Zeugen sollen sich nicht weigern, wenn sie gerufen werden. Und verschmäht nicht, es niederzuschreiben (seien es) große oder kleine (Beträge) bis zur festgesetzten Frist. Das ist rechtschaffener vor Allah und zuverlässiger, was die Bezeugung angeht und bewahrt euch eher vor Zweifeln, es sei denn es handelt sich um eine sogleich verfügbare Ware, die von Hand zu Hand geht unter euch; dann ist es kein Vergehen für euch, wenn ihr es nicht niederschreibt. Und nehmt Zeugen, wenn ihr miteinander Handel treibt. Und weder dem Schreiber noch dem Zeugen soll Schaden zugefügt werden. Und wenn ihr es tut, dann ist es wahrlich ein Frevel von euch. Und fürchtet Allah. Und Allah lehrt euch, und Allah ist über alles kundig.\qt@no{(282)}}
\qt@newcmd\qurantrans@de@ccxc{Und wenn ihr auf einer Reise seid und keinen Schreiber findet, dann soll ein Pfand in Empfang genommen werden. Und wenn einer von euch dem anderen (etwas) anvertraut, dann soll der, dem es anvertraut wurde, das ihm Anvertraute zurückgeben und Allah, seinen Herrn, fürchten. Und unterdrückt das Zeugnis nicht. Und wer es verbirgt, dessen Herz ist wahrlich mit Schuld befleckt. Und Allah ist dessen kundig, was ihr tut.\qt@no{(283)}}
\qt@newcmd\qurantrans@de@ccxci{Allah gehört das, was in den Himmeln und was in der Erde ist. Und ob ihr kundtut, was in euren Seelen ist, oder es geheimhaltet, Allah wird euch dafür zur Rechenschaft ziehen. Dann verzeiht Er, wem Er will, und bestraft, wen Er will. Und Allah hat Macht über alle Dinge.\qt@no{(284)}}
\qt@newcmd\qurantrans@de@ccxcii{Der Gesandte glaubt an das, was ihm von seinem Herrn herabgesandt worden ist, ebenso die Gläubigen; sie alle glauben an Allah und an Seine Engel und an Seine Bücher und an Seine Gesandten. Wir machen keinen Unterschied zwischen Seinen Gesandten. Und sie sagen: ``Wir hören und gehorchen. Gewähre uns Deine Vergebung, unser Herr, und zu Dir ist die Heimkehr.\qt@no{(285)}}
\qt@newcmd\qurantrans@de@ccxciii{Allah fordert von keiner Seele etwas über das hinaus, was sie zu leisten vermag. Ihr wird zuteil, was sie erworben hat, und über sie kommt, was sie sich zuschulden kommen läßt. Unser Herr, mache uns nicht zum Vorwurf, wenn wir (etwas) vergessen oder Fehler begehen. Unser Herr, und erlege uns keine Bürde auf, so wie Du sie jenen aufgebürdet hast, die vor uns waren. Unser Herr, und lade uns nichts auf, wofür wir keine Kraft haben. Und verzeihe uns und vergib uns und erbarme Dich unser. Du bist unser Beschützer. So hilf uns gegen das Volk der Ungläubigen!"\qt@no{(286)}}
\qt@newcmd\qurantrans@de@ccxciv{\basmalahde Alif Lam Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@ccxcv{Allah kein Gott ist da außer Ihm, dem Lebendigen, dem Beständigen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@ccxcvi{Er hat das Buch mit der Wahrheit auf dich herabgesandt als Bestätigung dessen, was vor ihm war. Und Er hat die Thora und das Evangelium herabgesandt\qt@no{(3)}}
\qt@newcmd\qurantrans@de@ccxcvii{vordem als Rechtleitung für die Menschen, und Er hat (das Buch zur) Unterscheidung herabgesandt. Wahrlich, denjenigen, die die Zeichen Allahs verleugnen, wird eine strenge Strafe zuteil sein. Und Allah ist Allmächtig und Herr der Vergeltung.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@ccxcviii{Vor Allah ist wahrlich nichts verborgen, weder in der Erde noch im Himmel.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@ccxcix{Er ist es, Der euch im Mutterschoß gestaltet, wie Er will. Es ist kein Gott außer Ihm, dem Allmächtigen, dem Allweisen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@ccc{Er ist es, Der dir das Buch herabgesandt hat. Darin sind eindeutig klare Verse sie sind die Grundlage des Buches und andere, die verschieden zu deuten sind. Doch diejenigen, in deren Herzen (Neigung zur) Abkehr ist, folgen dem, was darin verschieden zu deuten ist, um Zwietracht herbeizuführen und Deutelei zu suchen, (indem sie) nach ihrer abwegigen Deutung trachten. Aber niemand kennt ihre Deutung außer Allah. Diejenigen aber, die ein tiefbegründetes Wissen haben, sagen: ``Wir glauben wahrlich daran. Alles ist von unserem Herrn." Doch niemand bedenkt dies außer den Einsichtigen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@ccci{Unser Herr, laß unsere Herzen sich nicht (von Dir) abkehren, nachdem Du uns rechtgeleitet hast. Und schenke uns Barmherzigkeit von Dir; denn Du bist ja wahrlich der unablässig Gebende.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@cccii{Unser Herr, Du wirst die Menschen zusammenführen an einem Tag, über den es keinen Zweifel gibt. Wahrlich, Allah verfehlt niemals Seinen Termin.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@ccciii{Wahrlich, denen, die ungläubig sind, werden weder ihr Vermögen noch ihre Kinder bei Allah etwas helfen. Sie sind es, die zum Brennstoff des Feuers werden.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@ccciv{Nach dem Brauch des Volkes Pharaos und derer, die vor ihnen waren, verwarfen sie Unsere Zeichen als Lüge. Da ergriff Allah sie in ihrer Schuld. Und Allah ist streng im Strafen.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@cccv{Sprich zu denen, die ungläubig sind: ``Bald schon werdet ihr besiegt sein und in Gahannam versammelt werden was für eine schlechte Ruhestätte!"\qt@no{(12)}}
\qt@newcmd\qurantrans@de@cccvi{Es war euch ein Zeichen zuteil geworden in den beiden Scharen, die aufeinandertrafen: Die eine Schar kämpfte auf dem Weg Allahs, die andere war ungläubig. Sie sahen mit eigenen Augen (ihre Gegner) doppelt (so zahlreich) Und Allah stärkt mit Seinem Beistand, wen Er will. Wahrlich, darin liegt eine Lehre für die, die Einsicht haben.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@cccvii{Zum Genuß wird den Menschen die Freude gemacht an ihrem Trieb zu Frauen und Kindern und aufgespeicherten Mengen von Gold und Silber und Rassepferden und Vieh und Saatfeldern. Dies ist der Genuß des irdischen Lebens; doch bei Allah ist die schönste Heimkehr.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@cccviii{Sprich: ``Soll ich euch Besseres als dies verkünden?" Für die Gottesfürchtigen gibt es bei ihrem Herrn Gärten, durcheilt von Bächen, darin werden sie auf ewig bleiben, sowie reine Gattinnen und Allahs Wohlgefallen. Und Allah durchschaut die Diener\qt@no{(15)}}
\qt@newcmd\qurantrans@de@cccix{die sagen: ``Unser Herr, siehe, wir glauben; darum vergib uns unsere Sünden und behüte uns vor der Strafe des Feuers."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@cccx{Die Geduldigen und die Wahrhaften und die Andachtsvollen und die Spendenden und diejenigen, die um Vergebung bitten im Morgengrauen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@cccxi{Bezeugt hat Allah, daß kein Gott da ist außer Ihm Selbst; und die Engel und die Wissenden (bezeugen es); Er sorgt für die Gerechtigkeit. Es ist kein Gott außer Ihm, dem Allmächtigen, dem Allweisen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@cccxii{Wahrlich, die Religion bei Allah ist der Islam. Und diejenigen, denen die Schrift gegeben wurde, wurden erst uneins, als das Wissen zu ihnen gekommen war aus Mißgunst untereinander. Und wer die Zeichen Allahs verleugnet siehe, Allah ist schnell im Rechnen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@cccxiii{Und wenn sie mit dir streiten, so sprich: ``Ich habe mich ganz und gar Allah ergeben, und ebenso, wer mir nachfolgt." Und sprich zu jenen, denen die Schrift gegeben wurde, und zu den Unbelehrten: ``Werdet ihr Muslime?" Und wenn sie Muslime werden, sind sie geleitet; kehren sie sich jedoch ab, so obliegt dir nur die Verkündigung. Und Allah durchschaut die Diener.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@cccxiv{Wahrlich, jenen, die nicht an Allahs Zeichen glauben und die Propheten ohne rechtlichen Grund töten und jene Menschen töten, die zur Rechtschaffenheit ermahnen, denen verkünde schmerzliche Strafe.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@cccxv{Sie sind es, deren Werke nichtig sind in dieser Welt und im Jenseits; und sie haben keine Helfer.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@cccxvi{Sahst du nicht auf jene, denen ein Teil von der Schrift gegeben wurde, als sie aufgefordert wurden zum Buch Allahs, daß es richte zwischen ihnen? Alsdann kehrte ein Teil von ihnen den Rücken und wandte sich ab\qt@no{(23)}}
\qt@newcmd\qurantrans@de@cccxvii{indem sie sagten: ``Nimmer wird uns das Feuer berühren, es sei denn für abgezählte Tage." Und es betrog sie in ihrem Glauben, was sie selber erdachten.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@cccxviii{Aber wie, wenn Wir sie versammeln an einem Tag, über den kein Zweifel herrscht, und jeder Seele vergolten wird, was sie verdient hat, und sie kein Unrecht erleiden sollen?\qt@no{(25)}}
\qt@newcmd\qurantrans@de@cccxix{Sprich: ``O Allah, Herrscher des Königtums, Du gibst das Königtum, wem Du willst, und nimmst das Königtum, wem Du willst; und Du ehrst, wen Du willst, und erniedrigst, wen Du willst. In Deiner Hand ist das Gute; wahrlich, Du hast Macht über alle Dinge.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@cccxx{Du läßt die Nacht übergehen in den Tag und läßt den Tag übergehen in die Nacht; und Du läßt das Lebendige aus dem Toten erstehen und läßt das Tote aus dem Lebendigen erstehen, und versorgst, wen Du willst, ohne Maß."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@cccxxi{Die Gläubigen sollen die Ungläubigen nicht statt der Gläubigen zu Beschützern nehmen; und wer solches tut, der findet von Allah in nichts Hilfe außer ihr fürchtet euch vor ihnen. Und Allah warnt euch vor Sich Selber, und zu Allah ist die Heimkehr.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@cccxxii{Sprich: ``Ob ihr verbergt, was in eurer Brust ist, oder ob ihr es kundtut, Allah weiß es; Er weiß, was in den Himmeln und was auf der Erde ist; und Allah hat Macht über alle Dinge."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@cccxxiii{An jenem Tage wird jede Seele bereit finden, was sie an Gutem getan hat; und was sie an Bösem getan hat wünschen wird sie, daß zwischen ihr und ihm eine weite Zeitspanne läge. Und Allah warnt euch vor Sich Selber; und Allah ist gütig gegen Seine Diener.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@cccxxiv{Sprich: ``Wenn ihr Allah liebt, so folgt mir. Lieben wird euch Allah und euch eure Sünden vergeben; denn Allah ist Allvergebend, Barmherzig."\qt@no{(31)}}
\qt@newcmd\qurantrans@de@cccxxv{Sprich: ``Gehorcht Allah und dem Gesandten"; denn wenn sie den Rücken kehren siehe, Allah liebt die Ungläubigen nicht.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@cccxxvi{Wahrlich, Allah erwählte Adam und Noah und das Haus Abraham und das Haus `Imran vor allen Welten\qt@no{(33)}}
\qt@newcmd\qurantrans@de@cccxxvii{ein Geschlecht, von dem einer aus dem anderen stammt, und Allah ist Allhörend, Allwissend.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@cccxxviii{Damals sagte die Frau `lmrans: ``Mein Herr, siehe, ich gelobe Dir, was in meinem Leibe ist, zu weihen; so nimm es von mir an; siehe, Du bist der Allhörende, der Allwissende."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@cccxxix{Und als sie es geboren hatte, sagte sie: ``Mein Herr, siehe, ich habe es als Mädchen geboren." Und Allah wußte wohl, was sie geboren hatte; denn der Knabe ist nicht wie das Mädchen. ``Und ich habe sie Maria genannt, und siehe, ich möchte, daß sie und ihre Nachkommen bei Dir Zuflucht nehmen vor dem gesteinigten Satan."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@cccxxx{Und so nahm sie Allah gnädig an und ließ sie in schöner Weise in der Obhut des Zacharias heranwachsen. Sooft Zacharias zu ihr in den Tempel hineintrat, fand er Speise bei ihr. Da sagte er: ``O Maria, woher kommt dir dies zu?" Sie sagte: ``Es ist von Allah; siehe, Allah versorgt unbegrenzt, wen Er will."\qt@no{(37)}}
\qt@newcmd\qurantrans@de@cccxxxi{Dort rief Zacharias seinen Herrn an und sagte: ``Mein Herr, gib mir als Geschenk von Dir gute Nachkommenschaft, wahrlich, Du bist Der Erhörer des Gebets."\qt@no{(38)}}
\qt@newcmd\qurantrans@de@cccxxxii{Und da riefen ihm die Engel zu, während er zum Gebet in dem Tempel stand: ``Siehe, Allah verheißt dir Johannes, den Bestätiger eines Wortes von Allah, einen Vornehmen, einen Asketen und Propheten, einen von den Rechtschaffenen."\qt@no{(39)}}
\qt@newcmd\qurantrans@de@cccxxxiii{Er sagte: ``Mein Herr, soll mir ein Knabe (geschenkt) werden, wo mich das Alter doch überkommen hat und meine Frau unfruchtbar ist?" Er sprach: ``Allah tut ebenso, was Er will."\qt@no{(40)}}
\qt@newcmd\qurantrans@de@cccxxxiv{Er sagte: ``Mein Herr, gib mir ein Zeichen." Er sprach: ``Dein Zeichen ist, daß du drei Tage lang zu den Menschen nicht sprechen wirst außer durch Gesten. Und gedenke deines Herrn häufig und preise Ihn am Abend und am Morgen."\qt@no{(41)}}
\qt@newcmd\qurantrans@de@cccxxxv{Und damals sprachen die Engel: ``O Maria, siehe, Allah hat dich auserwählt und gereinigt und erwählt vor den Frauen der Welten.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@cccxxxvi{O Maria, sei vor deinem Herrn voller Andacht und wirf dich nieder und beuge dich mit den Sich- Beugenden."\qt@no{(43)}}
\qt@newcmd\qurantrans@de@cccxxxvii{Dies ist eine der Verkündungen des Verborgenen, die Wir dir offenbaren. Denn du warst nicht bei ihnen, als sie ihre Losröhrchen warfen, wer von ihnen Maria pflegen sollte. Und du warst nicht bei ihnen, als sie miteinander stritten.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@cccxxxviii{Damals sprachen die Engel: ``O Maria siehe, Allah verkündet dir ein Wort von Ihm; sein Name ist der Messias, Jesus, der Sohn der Maria, angesehen im Diesseits und im Jenseits, und einer von denen, die (Allah) nahestehen.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@cccxxxix{Und reden wird er in der Wiege zu den Menschen und auch als Erwachsener, und er wird einer der Rechtschaffenen sein."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@cccxl{Sie sagte: ``Mein Herr, soll mir ein Sohn (geboren) werden, wo mich doch kein Mann berührte?" Er sprach: ``Allah schafft ebenso, was Er will; wenn Er etwas beschlossen hat, spricht Er nur zu ihm: ``Sei!" und es ist."\qt@no{(47)}}
\qt@newcmd\qurantrans@de@cccxli{Und Er wird ihn das Buch lehren und die Weisheit und die Thora und das Evangelium\qt@no{(48)}}
\qt@newcmd\qurantrans@de@cccxlii{und wird ihn entsenden zu den Kindern Israels. (Sprechen wird er:) ``Seht, ich bin zu euch mit einem Zeichen von eurem Herrn gekommen. Seht, ich erschaffe für euch aus Ton die Gestalt eines Vogels und werde in sie hauchen, und sie soll mit Allahs Erlaubnis ein Vogel werden; und ich heile den Blindgeborenen und den Aussätzigen und mache die Toten mit Allahs Erlaubnis lebendig, und ich verkünde euch, was ihr esset und was ihr in eueren Häusern speichert. Wahrlich, darin ist ein Zeichen für euch, wenn ihr gläubig seid.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@cccxliii{Und als ein Bestätiger der Thora, die vor mir da war, und um euch einen Teil von dem zu erlauben, was euch verboten war, bin ich zu euch gekommen mit einem Zeichen von eurem Herrn. So fürchtet Allah und gehorcht mir\qt@no{(50)}}
\qt@newcmd\qurantrans@de@cccxliv{wahrlich, Allah ist mein Herr und euer Herr, darum dienet Ihm. Dies ist ein gerader Weg."\qt@no{(51)}}
\qt@newcmd\qurantrans@de@cccxlv{Und als Jesus ihren Unglauben wahrnahm, sagte er: ``Wer ist mein Helfer (auf dem Weg) zu Allah?" Die Jünger sagten: ``Wir sind Allahs Helfer; wir glauben an Allah, und (du sollst) bezeugen, daß wir (Ihm) ergeben sind.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@cccxlvi{Unser Herr, wir glauben an das, was Du herabgesandt hast, und folgen dem Gesandten. Darum führe uns unter den Bezeugenden auf."\qt@no{(53)}}
\qt@newcmd\qurantrans@de@cccxlvii{Und sie schmiedeten eine List, und Allah schmiedete eine List; und Allah ist der beste Listenschmied.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@cccxlviii{Damals sprach Allah: ``O Jesus, siehe, Ich will dich verscheiden lassen und will dich zu Mir erhöhen und will dich von den Ungläubigen befreien und will deine Anhänger über die Ungläubigen setzen bis zum Tag der Auferstehung. Alsdann werdet ihr zu Mir wiederkehren, und Ich will zwischen euch richten über das, worüber ihr uneins waret.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@cccxlix{Was aber die Ungläubigen anbelangt, so werde Ich sie schwer im Diesseits und im Jenseits bestrafen; und sie werden keine Helfer finden."\qt@no{(56)}}
\qt@newcmd\qurantrans@de@cccl{Was aber diejenigen anbelangt, die glauben und gute Werke tun, so wird Er ihnen ihren vollen Lohn geben. Und Allah liebt nicht die Ungerechten.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@cccli{Dies verlesen Wir dir von den Zeichen und der weisen Ermahnung.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@ccclii{Wahrlich, Jesus ist vor Allah gleich Adam; Er erschuf ihn aus Erde, als dann sprach Er zu ihm: ``Sei!" und da war er.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@cccliii{(Dies) ist die Wahrheit von deinem Herrn! Darum sei keiner der Zweifler.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@cccliv{Und wenn sich jemand mit dir über sie streitet, nachdem das Wissen zu dir kam, so sprich: ``Kommt her, lasset uns rufen unsre Söhne und eure Söhne, unsre Frauen und eure Frauen und unsre Seelen und eure Seelen. Alsdann wollen wir zu Allah flehen und mit Allahs Fluch die Lügner bestrafen."\qt@no{(61)}}
\qt@newcmd\qurantrans@de@ccclv{Wahrlich, dies ist die Geschichte der Wahrheit, und es ist kein Gott außer Allah, und Allah Er ist wahrlich der Allmächtige, der Allweise.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@ccclvi{Und wenn sie sich abwenden, so kennt Allah die Missetäter.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@ccclvii{Sprich: ``O Volk der Schrift, kommt herbei zu einem gleichen Wort zwischen uns und euch, daß wir nämlich Allah allein dienen und nichts neben Ihn stellen und daß nicht die einen von uns die anderen zu Herren nehmen außer Allah." Und wenn sie sich abwenden, so sprecht: ``Bezeugt, daß wir (Ihm) ergeben sind."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@ccclviii{O Volk der Schrift, warum streitet ihr über Abraham, wo die Thora und das Evangelium doch erst (später) nach ihm herabgesandt worden sind? Habt ihr denn keinen Verstand?\qt@no{(65)}}
\qt@newcmd\qurantrans@de@ccclix{Ihr habt da über etwas gestritten, wovon ihr Wissen habt; weshalb aber streitet ihr über das, wovon ihr kein Wissen habt? Allah weiß, ihr aber wisset nicht.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@ccclx{Abraham war weder Jude noch Christ; vielmehr war er lauteren Glaubens, ein Muslim, und keiner von denen, die (Allah) Gefährten beigesellen.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@ccclxi{Wahrlich, die Menschen, die Abraham am nächsten stehen, sind jene, die ihm folgen, und dieser Prophet (Muhammad) und die Gläubigen. Und Allah ist der Beschützer der Gläubigen.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@ccclxii{Eine Gruppe von den Leuten der Schrift möchte euch gern verführen, doch verführen sie nur sich selber und wissen es nicht.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@ccclxiii{Ihr Leute der Schrift, warum verleugnet ihr die Zeichen Allahs, wo ihr sie doch bezeugt?\qt@no{(70)}}
\qt@newcmd\qurantrans@de@ccclxiv{Ihr Leute der Schrift, weshalb vermengt ihr die Wahrheit mit der Lüge und verbergt die Wahrheit gegen euer Wissen?\qt@no{(71)}}
\qt@newcmd\qurantrans@de@ccclxv{Und da sagte eine Gruppe von den Leuten der Schrift: ``Glaubt bei Tagesanbruch an das, was zu den Gläubigen hinabgesandt wurde, und leugnet es ab bei seinem Ende; vielleicht werden sie umkehren.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@ccclxvi{Und glaubt nur denen, die eure Religion befolgen." Sprich: ``Seht, die (wahre) Rechtleitung ist die Rechtleitung Allahs." Daß (auch) einem (anderen) gegeben werde was euch gegeben worden ist, oder wenn sie mit euch vor eurem Herrn streiten, so sprich: ``Seht, die Huld ist in Allahs Hand, Er gewährt sie, wem Er will. Und Allah ist Allumfassend und Allwissend.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@ccclxvii{Er zeichnet mit Seiner Barmherzigkeit aus, wen Er will. Und Allah ist voll großer Huld."\qt@no{(74)}}
\qt@newcmd\qurantrans@de@ccclxviii{Und unter den Leuten der Schrift gibt es welche, die, wenn du ihnen eine große Summe anvertraust, dir diese aushändigen. Und unter ihnen gibt es auch solche, die, wenn du ihnen einen Dinar anvertraust, ihn dir nur aushändigen, wenn du stets hinter ihnen her bist. Dies geschieht deshalb, weil sie sagen: ``Uns obliegt gegen die Unbelehrbaren keine Pflicht." Und sie sprechen eine Lüge gegen Allah und wissen es.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@ccclxix{Wer jedoch seiner Verpflichtung nachkommt und gottesfürchtig ist siehe, Allah liebt die Gottesfürchtigen.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@ccclxx{Wahrlich, diejenigen, welche ihren Bund mit Allah und ihre Eide um einen geringen Preis verkaufen, haben keinen Anteil am Jenseits, und Allah spricht nicht zu ihnen, und Er schaut sie nicht an am Tag der Auferstehung, und Er reinigt sie nicht, und ihnen wird eine schmerzliche Strafe zuteil sein.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@ccclxxi{Wahrlich, ein Teil von ihnen verdreht seine Zunge mit der Schrift, damit ihr es für einen Teil der Schrift haltet, obwohl es nicht zur Schrift gehört: Und sie sagen: ``Es ist von Allah"; jedoch ist es nicht von Allah, und sie sprechen eine Lüge gegen Allah, obwohl sie es wissen.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@ccclxxii{Es darf nicht sein, daß ein Mensch, dem Allah die Schrift und die Weisheit und das Prophetentum gegeben hat, als dann zu den Leuten spräche: ``Seid meine Diener neben Allah." Vielmehr (soll er sagen): ``Seid Gottesgelehrte mit dem, was ihr gelehrt habt und mit dem, was ihr studiert habt."\qt@no{(79)}}
\qt@newcmd\qurantrans@de@ccclxxiii{Und Er gebietet euch nicht, euch die Engel oder die Propheten zu Herren zu nehmen. Sollte Er euch den Unglauben gebieten, nachdem ihr (Ihm) ergeben geworden seid?\qt@no{(80)}}
\qt@newcmd\qurantrans@de@ccclxxiv{Und da nahm Allah von den Propheten den Bund entgegen (des Inhalts:) ``Wenn Ich euch das Buch und die Weisheit gebe, dann wird zu euch ein Gesandter kommen und das bestätigen, was ihr habt. Wahrlich, ihr sollt ihm glauben und sollt ihm helfen." Er sprach: ``Erkennt ihr das an und nehmt ihr unter dieser (Bedingung) das Bündnis mit Mir an?" Sie sagten: ``Wir erkennen es an." Er sprach: ``So bezeugt es, und Ich will mit euch (ein Zeuge) unter den Zeugen sein."\qt@no{(81)}}
\qt@newcmd\qurantrans@de@ccclxxv{Wer sich nach diesem abwendet das sind die Frevler.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@ccclxxvi{Verlangen sie etwa eine andere als Allahs Religion? Ihm ergibt sich, was in den Himmeln und auf der Erde ist, gehorsam oder wider Willen, und zu Ihm kehren sie zurück.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@ccclxxvii{Sprich: ``Wir glauben an Allah und an das, was auf uns herabgesandt worden ist, und was herabgesandt worden ist auf Abraham und Ismael und Isaak und Jakob und die Stämme (Israels), und was gegeben worden ist Moses und Jesus und den Propheten von ihrem Herrn; wir machen keinen Unterschied zwischen ihnen, und Ihm sind wir ergeben."\qt@no{(84)}}
\qt@newcmd\qurantrans@de@ccclxxviii{Und wer eine andere Religion als den Islam begehrt: nimmer soll sie von ihm angenommen werden, und im Jenseits wird er unter den Verlierern sein.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@ccclxxix{Wie soll Allah ein Volk leiten, das ungläubig wurde nach seinem Glauben und nachdem es bezeugt hatte, daß der Gesandte wahrhaftig sei, und nachdem die deutlichen Zeichen zu ihnen gekommen waren? Und Allah leitet die Ungerechten nicht.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@ccclxxx{Ihr Lohn ist, daß auf ihnen der Fluch Allahs und der Engel und der Menschen insgesamt lastet.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@ccclxxxi{Ewig bleiben sie darin; ihnen wird die Strafe nicht erleichtert und ihnen wird kein Aufschub gewährt\qt@no{(88)}}
\qt@newcmd\qurantrans@de@ccclxxxii{außer denen, die danach umkehren und gute Werke verrichten. Denn siehe, Allah ist Allverzeihend und Barmherzig.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@ccclxxxiii{Siehe, wer nach seinem Glauben ungläubig wird und immer mehr dem Unglauben verfällt dessen Reue wird nicht angenommen, und dies sind die Irrenden.\qt@no{(90)}}
\qt@newcmd\qurantrans@de@ccclxxxiv{Wahrlich, jene, die ungläubig sind und im Unglauben sterben niemals wird von ihnen eine Erde voll Gold angenommen werden, auch wenn sie sich damit loskaufen wollten. Diese haben eine schmerzhafte Strafe, und sie werden keine Helfer haben.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@ccclxxxv{Ihr werdet das Gütigsein nicht erlangen, ehe ihr nicht von dem spendet, was ihr liebt; und was immer ihr spendet, seht, Allah weiß es.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@ccclxxxvi{Alle Speise war den Kindern Israels erlaubt, außer was Israel sich selber verwehrte, bevor die Thora herabgesandt wurde. Sprich: ``So bringt die Thora und lest sie, wenn ihr wahrhaftig seid."\qt@no{(93)}}
\qt@newcmd\qurantrans@de@ccclxxxvii{Und diejenigen, die danach eine Lüge gegen Allah erdichten, sind die Ungerechten.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@ccclxxxviii{Sprich: ``Allah spricht die Wahrheit. So folgt der Religion Abrahams, des Lauteren im Glauben, der neben Allah keine Götter setzte."\qt@no{(95)}}
\qt@newcmd\qurantrans@de@ccclxxxix{Wahrlich, das erste Haus, das für die Menschen gegründet wurde, ist das in Bakka ein gesegnetes und eine Leitung für die Welten.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@cccxc{In ihm sind deutliche Zeichen die Stätte Abrahams. Und wer es betritt, ist sicher. Und der Menschen Pflicht gegenüber Allah ist die Pilgerfahrt zum Hause, wer da den Weg zu ihm machen kann. Wer aber ungläubig ist wahrlich, Allah ist nicht auf die Welten angewiesen.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@cccxci{Sprich: ``O Leute der Schrift, warum verleugnet ihr die Zeichen Allahs, wo Allah Zeuge eures Tuns ist?"\qt@no{(98)}}
\qt@newcmd\qurantrans@de@cccxcii{Sprich: ``O Leute der Schrift, warumwendet ihr die Gläubigen von Allahs Weg ab? Ihr trachtet ihn krumm zu machen, wo ihr ihn doch bezeugt. Doch Allah ist eures Tuns nicht achtlos."\qt@no{(99)}}
\qt@newcmd\qurantrans@de@cccxciii{O ihr, die ihr glaubt, wenn ihr einem Teil jener, denen die Schrift gegeben wurde, gehorcht, so werden sie euch nach eurem Glauben wieder ungläubig machen.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@cccxciv{Wie aber werdet ihr ungläubig werden, wo euch die Verse Allahs verlesen werden und unter euch Sein Gesandter weilt? Und wer an Allah festhält, der ist auf den rechten Weg geleitet.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@cccxcv{O ihr, die ihr glaubt, fürchtet Allah in geziemender Furcht und sterbt nicht anders denn als Muslime.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@cccxcvi{Und haltet insgesamt an Allahs Seil fest und zerfallet nicht und gedenkt der Gnade Allahs gegen euch, da ihr Feinde waret und Er eure Herzen so zusammenschloß, daß ihr durch Seine Gnade Brüder wurdet; und da ihr am Rande einer Feuergrube waret und Er euch ihr entriß. So macht Allah euch Seine Zeichen klar, auf daß ihr würdet euch rechtleiten lassen\qt@no{(103)}}
\qt@newcmd\qurantrans@de@cccxcvii{Und aus euch soll eine Gemeinde werden, die zum Guten einlädt und das gebietet, was Rechtens ist, und das Unrecht verbietet; und diese sind die Erfolgreichen.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@cccxcviii{Und seid nicht wie jene, die gespalten und uneins sind, nachdem die deutlichen Zeichen zu ihnen kamen; und jene erwartet eine schmerzliche Strafe\qt@no{(105)}}
\qt@newcmd\qurantrans@de@cccxcix{an einem Tag, da Gesichter weiß werden und Gesichter schwarz werden. Und was jene anbelangt, deren Gesichter schwarz werden: ``Wurdet ihr nach eurem Glauben ungläubig? So kostet darum die Strafe, weil ihr ungläubig wurdet."\qt@no{(106)}}
\qt@newcmd\qurantrans@de@cd{Und was jene anbelangt, deren Gesichter weiß werden: diese sollen in Allahs Gnade sein, und darin werden sie ewig bleiben.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@cdi{Dies sind die Zeichen Allahs; Wir verkünden sie dir in Wahrheit. Und Allah will keine Ungerechtigkeit gegen die Welten.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@cdii{Und Allahs ist, was in den Himmeln und was auf der Erde ist, und zu Allah kehren alle Dinge zurück.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@cdiii{Ihr seid die beste Gemeinde, die für die Menschen entstand. Ihr gebietet das, was Rechtens ist, und ihr verbietet das Unrecht, und ihr glaubt an Allah. Und wenn die Leute der Schrift geglaubt hätten, wahrlich, es wäre gut für sie gewesen! Unter ihnen sind Gläubige, aber die Mehrzahl von ihnen sind Frevler.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@cdiv{Niemals werden sie euch ein Leid zufügen, es sei denn einen (geringen) Schaden, und wenn sie gegen euch kämpfen, werden sie euch den Rücken kehren; als dann werden sie nicht siegreich werden.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@cdv{Erniedrigung ist für sie vorgeschrieben, wo immer sie getroffen werden, außer sie wären in Sicherheit (auf Grund) ihrer Verbindung mit Allah oder mit den Menschen. Und sie ziehen sich den Zorn Allahs zu, und für sie ist die Armut vorgeschrieben, weil sie Allahs Zeichen verleugneten und die Propheten ungerechterweise ermordeten. Solches (geschieht), da sie widerspenstig und Übertreter waren.\qt@no{(112)}}
\qt@newcmd\qurantrans@de@cdvi{Sie sind aber nicht (alle) gleich. Unter den Leuten der Schrift gibt es (auch) eine Gemeinschaft, die stets die Verse Allahs zur Zeit der Nacht verlesen und sich dabei niederwerfen.\qt@no{(113)}}
\qt@newcmd\qurantrans@de@cdvii{Diese glauben an Allah und an den Jüngsten Tag und gebieten das, was Rechtens ist, und verbieten das Unrecht und wetteifern in guten Werken; und diese gehören zu den Rechtschaffenen.\qt@no{(114)}}
\qt@newcmd\qurantrans@de@cdviii{Und was sie an Gutem tun, wird ihnen niemals bestritten; und Allah kennt die Gottesfürchtigen.\qt@no{(115)}}
\qt@newcmd\qurantrans@de@cdix{Wahrlich, denjenigen, die ungläubig sind, werden ihr Gut und ihre Kinder keinesfalls etwas vor Allah helfen; und jene sind die Gefährten des Feuers, und ewig sollen sie darin bleiben.\qt@no{(116)}}
\qt@newcmd\qurantrans@de@cdx{Das Gleichnis dessen, was sie in diesem irdischen Leben spenden, ist das Gleichnis des eiskalten Windes, welcher den Acker von Leuten trifft, die gegen sich selber sündigten. Und so vernichtet er ihn, und nicht Allah war gegen sie ungerecht, sondern gegen sich selber waren sie ungerecht.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@cdxi{O ihr, die ihr glaubt, schließt keine Freundschaft, außer mit euresgleichen. Sie werden nicht zaudern, euch zu verderben, und wünschen euren Untergang. Schon wurde Haß aus ihrem Mund offenkundig, aber das, was ihr Inneres verbirgt, ist schlimmer. Schon machten Wir euch die Zeichen klar, wenn ihr es begreift.\qt@no{(118)}}
\qt@newcmd\qurantrans@de@cdxii{Seht da! Ihr seid es, die ihr sie liebt, doch sie lieben euch nicht; und ihr glaubt an das ganze Buch. Und wenn sie euch begegnen, sagen sie: ``Wir glauben"; sind sie jedoch allein, so beißen sie sich in die Fingerspitzen aus Grimm gegen euch. Sprich: ``Sterbt an eurem Grimm." Siehe, Allah kennt das Innerste eurer Herzen.\qt@no{(119)}}
\qt@newcmd\qurantrans@de@cdxiii{Wenn euch etwas Gutes trifft, empfinden sie es als Übel, und wenn euch ein Übel trifft, so freuen sie sich dessen. Aber wenn ihr geduldig und gottesfürchtig seid, wird ihre List euch keinen Schaden zufügen. Seht, Allah umfaßt (mit Seinem Wissen) das, was sie tun.\qt@no{(120)}}
\qt@newcmd\qurantrans@de@cdxiv{Und damals verließest du deine Familie in der Frühe, um die Gläubigen in die Stellungen des Kampfes einzuweisen; und Allah ist Allhörend, Allwissend.\qt@no{(121)}}
\qt@newcmd\qurantrans@de@cdxv{Da verloren zwei Gruppen von euch beinahe den Mut, und Allah war beider Beschützer. Und auf Allah sollen sich die Gläubigen verlassen.\qt@no{(122)}}
\qt@newcmd\qurantrans@de@cdxvi{Und da verhalf Allah euch bei Badr zum Sieg, während ihr verächtlich erschient; darum fürchtet Allah; vielleicht werdet ihr dankbar sein.\qt@no{(123)}}
\qt@newcmd\qurantrans@de@cdxvii{Als du zu den Gläubigen sagtest: ``Genügt es euch denn nicht, daß euer Herr euch mit dreitausend herniedergesandten Engeln hilft?\qt@no{(124)}}
\qt@newcmd\qurantrans@de@cdxviii{Ja, wenn ihr geduldig und gottesfürchtig seid und sie sofort über euch kommen, wird euer Herr euch mit fünftausend Engeln in Kampfbereitschaft helfen."\qt@no{(125)}}
\qt@newcmd\qurantrans@de@cdxix{Und dies machte Allah allein als frohe Botschaft für euch, und auf daß eure Herzen ruhig wären denn der Sieg kommt nur von Allah, dem Allmächtigen, dem Allweisen\qt@no{(126)}}
\qt@newcmd\qurantrans@de@cdxx{auf daß Er den Ungläubigen einen Teil (ihrer Macht) abschneide oder sie niederwerfe, so daß sie enttäuscht heimkehren.\qt@no{(127)}}
\qt@newcmd\qurantrans@de@cdxxi{Von dir ist es gar nicht abhängig, ob Er Sich ihnen wieder verzeihend zuwendet oder ob Er sie straft; denn sie sind ja Frevler.\qt@no{(128)}}
\qt@newcmd\qurantrans@de@cdxxii{Und Allahs ist, was in den Himmeln und was auf der Erde ist; Er verzeiht, wem Er will, und straft, wen Er will, und Allah ist Allverzeihend und Barmherzig.\qt@no{(129)}}
\qt@newcmd\qurantrans@de@cdxxiii{O ihr, die ihr glaubt, verschlingt nicht die Zinsen in mehrfacher Verdoppelung, sondern fürchtet Allah; vielleicht werdet ihr erfolgreich sein.\qt@no{(130)}}
\qt@newcmd\qurantrans@de@cdxxiv{Und fürchtet das Feuer, das für die Ungläubigen vorbereitet ist\qt@no{(131)}}
\qt@newcmd\qurantrans@de@cdxxv{und gehorcht Allah und dem Gesandten; vielleicht werdet ihr Erbarmen finden.\qt@no{(132)}}
\qt@newcmd\qurantrans@de@cdxxvi{Und wetteifert nach der Vergebung eures Herrn und nach einem Garten, dessen Breite der von Himmel und Erde entspricht, der für die Gottesfürchtigen vorbereitet ist\qt@no{(133)}}
\qt@newcmd\qurantrans@de@cdxxvii{die da spenden in Freud und Leid und den Groll unterdrücken und den Menschen vergeben. Und Allah liebt die Rechtschaffenen.\qt@no{(134)}}
\qt@newcmd\qurantrans@de@cdxxviii{Und diejenigen, die wenn sie etwas Schändliches getan oder gegen sich gesündigt haben Allahs gedenken und für ihre Sünden um Vergebung flehen; und wer vergibt die Sünden außer Allah? und diejenigen, die nicht auf dem beharren, was sie wissentlich taten\qt@no{(135)}}
\qt@newcmd\qurantrans@de@cdxxix{für diese besteht ihr Lohn aus Vergebung von ihrem Herrn und aus Gärten, durch die Bäche fließen; darin werden sie ewig sein, und herrlich ist der Lohn der Wirkenden.\qt@no{(136)}}
\qt@newcmd\qurantrans@de@cdxxx{Schon vor euch hat es Lebensweisen gegeben. So durchwandert die Erde und schaut, wie der Ausgang derer war, welche (die Wahrheit) für eine Lüge erklärt haben.\qt@no{(137)}}
\qt@newcmd\qurantrans@de@cdxxxi{Dies ist eine Bekanntmachung an die Menschen und eine Leitung und eine Ermahnung für die Gottesfürchtigen.\qt@no{(138)}}
\qt@newcmd\qurantrans@de@cdxxxii{Und seid nicht verzagt und traurig; ihr werdet siegen, wenn ihr gläubig seid.\qt@no{(139)}}
\qt@newcmd\qurantrans@de@cdxxxiii{Wenn euch eine Härte getroffen hat, so hat eine Härte gleich schon andere Leute getroffen. Und diese Tage (des Sieges und der Niederlage) lassen Wir wechseln unter den Menschen, damit Allah die Gläubigen erkennt und Sich aus euch Zeugen erwählt. Und Allah liebt die Ungerechten nicht.\qt@no{(140)}}
\qt@newcmd\qurantrans@de@cdxxxiv{Und damit Allah die Gläubigen läutert und die Ungläubigen dahinschwinden läßt.\qt@no{(141)}}
\qt@newcmd\qurantrans@de@cdxxxv{Oder meint ihr, in das Paradies einzugehen, ohne daß Allah diejenigen erkennt, die unter euch gekämpft haben, und (ohne) daß Er die Geduldigen erkennt?\qt@no{(142)}}
\qt@newcmd\qurantrans@de@cdxxxvi{Und ihr wünschtet doch auch den Tod, bevor ihr ihm begegnetet. Nun sahet ihr ihn mit eigenen Augen.\qt@no{(143)}}
\qt@newcmd\qurantrans@de@cdxxxvii{Und Muhammad ist nur ein Gesandter; schon vor ihm gingen die Gesandten dahin. Und ob er stirbt oder getötet wird, werdet ihr auf euren Fersen umkehren? Und wer auf seinen Fersen umkehrt nimmer schadet er Allah etwas; aber Allah wird wahrlich die Dankbaren belohnen.\qt@no{(144)}}
\qt@newcmd\qurantrans@de@cdxxxviii{Keiner wird sterben ohne Allahs Erlaubnis; (denn dies geschieht) gemäß einer zeitlichen Vorherbestimmung. Und dem, der den Lohn der Welt begehrt, geben Wir davon, und dem, der den Lohn des Jenseits begehrt, geben Wir davon; wahrlich, Wir werden die Dankbaren belohnen.\qt@no{(145)}}
\qt@newcmd\qurantrans@de@cdxxxix{Und wie viele Propheten kämpften gegen (einen Feind,) gefolgt von vielen Gottesfürchtigen. Aber sie verzagten nicht bei dem, was sie auf Allahs Weg traf, und sie wurden weder schwach noch demütigten sie sich. Und Allah liebt die Geduldigen.\qt@no{(146)}}
\qt@newcmd\qurantrans@de@cdxl{Und ihr Wort war nicht anders, als daß sie sagten: ``Unser Herr, vergib uns unsre Sünden und unser Vergehen in unserer Sache; und festige unsere Schritte und hilf uns gegen das ungläubige Volk."\qt@no{(147)}}
\qt@newcmd\qurantrans@de@cdxli{Und Allah gab ihnen den Lohn dieser Welt und den schönsten Lohn des Jenseits. Und Allah liebt diejenigen, die Gutes tun.\qt@no{(148)}}
\qt@newcmd\qurantrans@de@cdxlii{O ihr, die ihr glaubt, wenn ihr den Ungläubigen gehorcht, kehren sie euch auf euren Fersen um, und ihr werdet die Verlierer sein.\qt@no{(149)}}
\qt@newcmd\qurantrans@de@cdxliii{Doch Allah ist euer Beschützer, und Er ist der beste Helfer.\qt@no{(150)}}
\qt@newcmd\qurantrans@de@cdxliv{Wir werden in die Herzen der Ungläubigen Schrecken werfen; deshalb, weil sie Allah Götter (zur Seite) setzten, wozu Er keine Ermächtnis niedersandte; und ihre Wohnstätte wird das Feuer sein, und schlimm ist die Herberge der Ungerechten!\qt@no{(151)}}
\qt@newcmd\qurantrans@de@cdxlv{Und wahrlich, Allah hatte euch gegenüber schon Sein Versprechen gehalten, als ihr sie mit Seiner Erlaubnis vernichtetet, bis daß ihr verzagtet und über die Sache strittet und ungehorsam wurdet, nachdem Er euch hatte sehen lassen, was ihr wünschtet. Einige von euch verlangten nach dieser Welt und andere verlangten nach dem Jenseits. Alsdann kehrte Er euch von ihnen (zur Flucht) ab, um euch zu prüfen; und wahrlich, jetzt hat Er euch vergeben. Denn Allah ist voller Huld gegen die Gläubigen.\qt@no{(152)}}
\qt@newcmd\qurantrans@de@cdxlvi{Als ihr hinaufstiegt und auf niemanden achtetet, während der Gesandte hinter euch her rief, da belohnte Er euch mit Kummer für Kummer, damit ihr nicht traurig sein solltet über das euch Entgangene und über das, was ihr erlitten habt. Und Allah kennt das, was ihr tut.\qt@no{(153)}}
\qt@newcmd\qurantrans@de@cdxlvii{Alsdann sandte Er auf euch nach dem Kummer Sicherheit (in der Art von) Schläfrigkeit nieder. Müdigkeit überkam eine Gruppe von euch; eine andere Gruppe war aber sorgenvoll mit sich selbst beschäftigt; ungerecht denken sie über Allah in heidnischem Denken. Sie sagten: ``Haben wir irgend etwas von der Sache?" Sprich: ``Seht, die ganze Sache ist Allahs." Sie verbargen in ihren Seelen, was sie dir nicht kundtaten, indem sie sagten: ``Hätten wir etwas von der Sache gehabt, lägen wir hier nicht erschlagen!" Sprich: ``Wäret ihr auch in euren Häusern gewesen, wahrlich, jene wären hinaus gezogen, denen der Tod bei ihren Ruhestätten vorgezeichnet war und (es geschah,) damit Allah prüfe, was in eurem Innern war, und erforsche, was in euren Herzen war. Und Allah kennt das Innerste (der Menschen)."\qt@no{(154)}}
\qt@newcmd\qurantrans@de@cdxlviii{Wahrlich, diejenigen von euch, welche am Tage des Zusammenstoßes der beiden Scharen (Allah) den Rücken kehrten nur Satan verleitete sie zum Straucheln für etwas von ihrem Tun. Aber wahrlich, nunmehr hat Allah ihnen vergeben; seht, Allah ist Allverzeihend und Milde.\qt@no{(155)}}
\qt@newcmd\qurantrans@de@cdxlix{O ihr, die ihr glaubt, seid nicht gleich den Ungläubigen, die da sprechen von ihren Brüdern, als sie das Land durchwanderten oder Streiter waren: ``Wären sie bei uns geblieben, wären sie nicht gestorben und nicht erschlagen worden." Allah bestimmte dies als Kummer für ihre Herzen. Und Allah macht lebendig und läßt sterben, und Allah durchschaut euer Tun.\qt@no{(156)}}
\qt@newcmd\qurantrans@de@cdl{Und wahrlich, wenn ihr auf dem Wege Allahs erschlagen werdet oder sterbt, wahrlich, Allahs Vergebung und Barmherzigkeit ist besser als das, was ihr zusammenscharrt.\qt@no{(157)}}
\qt@newcmd\qurantrans@de@cdli{Und wenn ihr sterbt oder erschlagen werdet, werdet ihr vor Allah versammelt.\qt@no{(158)}}
\qt@newcmd\qurantrans@de@cdlii{Und in Anbetracht der Barmherzigkeit Allahs warst du mild zu ihnen; wärst du aber rauh und harten Herzens gewesen, so wären sie dir davongelaufen. Darum vergib ihnen und bitte für sie um Verzeihung und ziehe sie in der Sache zu Rate; und wenn du entschlossen bist, dann vertrau auf Allah; denn wahrlich, Allah liebt diejenigen, die auf Ihn vertrauen.\qt@no{(159)}}
\qt@newcmd\qurantrans@de@cdliii{Wahrlich, wenn Allah euch zum Sieg verhilft, so gibt es keinen, der über euch siegen könnte; wenn Er euch aber im Stich läßt, wer könnte euch da helfen ohne Ihn? Wahrlich, auf Allah sollen die Gläubigen vertrauen.\qt@no{(160)}}
\qt@newcmd\qurantrans@de@cdliv{Und kein Prophet darf (etwas von der Beute) unterschlagen. Und wer (etwas) unterschlägt, soll das, was er unterschlagen hat, (zu seiner eigenen Belastung) am Tag der Auferstehung bringen. Alsdann wird jeder Seele nach ihrem Verdienst vergolten werden, und es soll ihnen kein Unrecht geschehen.\qt@no{(161)}}
\qt@newcmd\qurantrans@de@cdlv{Und ist denn der, welcher das Wohlgefallen Allahs erstrebte, wie der, welcher sich den Zorn Allahs zuzog und dessen Herberge Gahannam ist? Und schlimm ist das Ende!\qt@no{(162)}}
\qt@newcmd\qurantrans@de@cdlvi{Sie stehen in verschiedenem Rang bei Allah, und Allah durchschaut ihr Tun.\qt@no{(163)}}
\qt@newcmd\qurantrans@de@cdlvii{Wahrlich, huldreich war Allah gegen die Gläubigen, da Er unter ihnen einen Gesandten aus ihrer Mitte erweckte, um ihnen Seine Verse zu verlesen und sie zu reinigen und das Buch und die Weisheit zu lehren; denn siehe, sie hatten sich zuvor in einem offenkundigen Irrtum befunden.\qt@no{(164)}}
\qt@newcmd\qurantrans@de@cdlviii{Und als euch ein Unglück traf, nachdem ihr das Doppelte erlangtet, sprachet ihr da etwa: ``Woher (kommt) dies?" Sprich: ``Es kommt von euch selber." Siehe, Allah hat Macht über alle Dinge.\qt@no{(165)}}
\qt@newcmd\qurantrans@de@cdlix{Und was euch am Tage des Zusammenstoßes der beiden Scharen traf, das geschah mit Allahs Erlaubnis, und damit Er die Gläubigen erkennt\qt@no{(166)}}
\qt@newcmd\qurantrans@de@cdlx{und (damit) Er die Heuchler erkennt, zu denen gesprochen wurde: ``Heran! Kämpft auf Allahs Weg oder wehrt ab!" Sie aber sagten: ``Wenn wir zu kämpfen gewußt hätten, wahrlich, wir wären euch gefolgt!" Sie waren an jenem Tage dem Unglauben näher als dem Glauben. Sie sagten mit ihrem Munde das, was nicht in ihren Herzen lag; und Allah weiß wohl, was sie verbergen.\qt@no{(167)}}
\qt@newcmd\qurantrans@de@cdlxi{(Das sind) diejenigen, die zu ihren Brüdern sagten, während sie daheim blieben: ``Hätten sie uns gehorcht, wären sie nicht erschlagen worden." Sprich: ``So wehrt von euch den Tod ab, wenn ihr wahrhaftig seid."\qt@no{(168)}}
\qt@newcmd\qurantrans@de@cdlxii{Und betrachte nicht diejenigen, die auf Allahs Weg gefallen sind, als tot; doch sie leben bei ihrem Herrn, und sie werden dort versorgt.\qt@no{(169)}}
\qt@newcmd\qurantrans@de@cdlxiii{Sie freuen sich über das, was Allah ihnen von Seiner Huld gab, und von Freude erfüllt (sind sie) über diejenigen, die ihnen noch nicht gefolgt sind, so daß keine Furcht über sie kommen wird und sie nicht trauern werden.\qt@no{(170)}}
\qt@newcmd\qurantrans@de@cdlxiv{Von Freude erfüllt (sind sie) über die Gnade von Allah und über Seine Huld und darüber, daß Allah den Lohn der Gläubigen nicht verlorengehen läßt.\qt@no{(171)}}
\qt@newcmd\qurantrans@de@cdlxv{Diejenigen, die da auf Allah und den Gesandten hörten, nachdem sie eine Niederlage erlitten hatten: Für diejenigen von ihnen, welche Gutes taten und gottesfürchtig waren, ist großer Lohn.\qt@no{(172)}}
\qt@newcmd\qurantrans@de@cdlxvi{Diejenigen, zu denen die Leute sagten: ``Seht, die Leute haben sich bereits gegen euch geschart; fürchtet sie darum!" nur stärker wurden sie im Glauben und sagten: ``Uns genügt Allah, und Er ist der beste Anwalt!"\qt@no{(173)}}
\qt@newcmd\qurantrans@de@cdlxvii{Daher kehrten sie mit Allahs Gnade und Huld zurück, ohne daß sie ein Übel getroffen hätte, und sie folgten dem Wohlgefallen Allahs; und Allah ist voll großer Huld.\qt@no{(174)}}
\qt@newcmd\qurantrans@de@cdlxviii{Jener Satan will nur seine Helfer fürchten lassen; fürchtet sie aber nicht, sondern fürchtet Mich, wenn ihr gläubig seid.\qt@no{(175)}}
\qt@newcmd\qurantrans@de@cdlxix{Und laß dich nicht von jenen betrüben, die energisch dem Unglauben nacheilen; siehe, nimmer können sie Allah etwas zuleide tun. Allah will ihnen keinen Anteil am Jenseits geben, und für sie ist eine große Strafe (bestimmt).\qt@no{(176)}}
\qt@newcmd\qurantrans@de@cdlxx{Wahrlich, wer den Glauben für den Unglauben verkauft nimmer vermögen sie Allah etwas zuleide zu tun, und für sie ist eine schmerzliche Strafe (bereitet).\qt@no{(177)}}
\qt@newcmd\qurantrans@de@cdlxxi{Und die Ungläubigen sollen nicht wähnen, daß das, was Wir ihnen an Frist gewähren, für sie gut sei; Wir geben ihnen nur langes Leben, so daß sie in Sünde wachsen. Und für sie ist eine schändende Strafe (bestimmt).\qt@no{(178)}}
\qt@newcmd\qurantrans@de@cdlxxii{Allah gedenkt die Gläubigen nur so lange in der Lage zu belassen, in welcher ihr seid, bis daß Er die Schlechten von den Guten gesondert hat. Und Allah gedenkt nicht, euch das Verborgene zu offenbaren, sondern Allah erwählt von Seinen Gesandten, wen Er will; so glaubt an Allah und Seine Gesandten; und wenn ihr glaubt und gottesfürchtig seid, so wird euch ein gewaltiger Lohn zuteil sein.\qt@no{(179)}}
\qt@newcmd\qurantrans@de@cdlxxiii{Und diejenigen, die mit dem geizen, was Allah (ihnen) von Seiner Huld gegeben hat, sollen ja nicht meinen, das sei so besser für sie. Nein, zum Bösen soll es ihnen dienen. Als Halsband sollen sie am Tag der Auferstehung das tragen, womit sie geizig waren. Und Allahs ist das Erbe der Himmel und der Erde, und Allah kennt euer Tun.\qt@no{(180)}}
\qt@newcmd\qurantrans@de@cdlxxiv{Wahrlich, Allah hat das Wort jener gehört, die da sagten: ``Siehe, Allah ist arm und wir sind reich." Wir wollen ihre Worte und ihr ungerechtes Ermorden der Propheten niederschreiben und sprechen: ``Kostet die Strafe des Brennens.\qt@no{(181)}}
\qt@newcmd\qurantrans@de@cdlxxv{Dies ist für das, was eure Hände vorausschickten, und Allah ist nicht ungerecht gegen die Diener\qt@no{(182)}}
\qt@newcmd\qurantrans@de@cdlxxvi{die da sagen: ``Siehe, Allah hat uns verpflichtet, keinem Gesandten zu glauben, bevor er uns ein Opfer bringt, welches das Feuer verzehrt!"" Sprich: ``Schon vor mir kamen zu euch Gesandte mit den deutlichen Zeichen und mit dem, wovon ihr sprecht. Weshalb denn ermordetet ihr sie, wenn ihr wahrhaftig seid?"\qt@no{(183)}}
\qt@newcmd\qurantrans@de@cdlxxvii{Und wenn sie dich der Lüge bezichtigen, so sind schon vor dir Gesandte der Lüge bezichtigt worden, obwohl sie mit den deutlichen Zeichen, den Schriften und dem erleuchtenden Buch kamen.\qt@no{(184)}}
\qt@newcmd\qurantrans@de@cdlxxviii{Jede Seele wird den Tod kosten, und euch wird euer Lohn am Tag der Auferstehung vollständig gegeben; und wer da vom Feuer ferngehalten und ins Paradies geführt wird, der soll glücklich sein. Und das irdische Leben ist nichts als ein trügerischer Nießbrauch.\qt@no{(185)}}
\qt@newcmd\qurantrans@de@cdlxxix{Wahrlich, ihr sollt geprüft werden in eurem Gut und an euch selber, und wahrlich, ihr sollt viele verletzende Äußerungen von denen hören, welchen die Schrift vor euch gegeben wurde und von denen, die Allah Gefährten (zur Seite) setzten. Wenn ihr jedoch geduldig und gottesfürchtig seid dies gehört wahrlich zu den Dingen der Entschlossenheit.\qt@no{(186)}}
\qt@newcmd\qurantrans@de@cdlxxx{Und als Allah den Bund mit denen schloß, welchen die Schrift gegeben wurde, (und sprach:) ``Wahrlich, tut sie den Menschen kund und verbergt sie nicht" da warfen sie sie über ihre Schulter und verkauften sie für einen winzigen Preis. Und schlimm ist das, was sie (dafür) erkaufen!\qt@no{(187)}}
\qt@newcmd\qurantrans@de@cdlxxxi{Du sollst nicht meinen, daß diejenigen, die sich ihrer Tat freuen und gerühmt zu werden wünschen für das, was sie nicht getan haben, der Strafe entronnen seien. Ihnen wird eine schmerzliche Strafe zuteil sein.\qt@no{(188)}}
\qt@newcmd\qurantrans@de@cdlxxxii{Und Allahs ist das Reich der Himmel und der Erde, und Allah hat Macht über alle Dinge.\qt@no{(189)}}
\qt@newcmd\qurantrans@de@cdlxxxiii{Wahrlich, in der Schöpfung der Himmel und der Erde und in dem Wechsel der Nacht und des Tages, liegen wahre Zeichen für die Verständigen\qt@no{(190)}}
\qt@newcmd\qurantrans@de@cdlxxxiv{die Allahs gedenken im Stehen und im Sitzen und (Liegen) auf ihren Seiten und über die Schöpfung der Himmel und der Erde nachdenken (und sagen): ``Unser Herr, Du hast dieses nicht umsonst erschaffen. Gepriesen seist Du, darum hüte uns vor der Strafe des Feuers.\qt@no{(191)}}
\qt@newcmd\qurantrans@de@cdlxxxv{Unser Herr, wahrlich, wen Du ins Feuer führst, den führst Du in Schande, und die Ungerechten haben keine Helfer.\qt@no{(192)}}
\qt@newcmd\qurantrans@de@cdlxxxvi{Unser Herr, wahrlich, wir hörten einen Rufer, der zum Glauben aufrief (und sprach:) ``Glaubt an euren Herrn!" und so glauben wir. Unser Herr, und vergib uns darum unsere Sünden und tilge unsere Missetaten und laß uns mit den Frommen verscheiden.\qt@no{(193)}}
\qt@newcmd\qurantrans@de@cdlxxxvii{Unser Herr, und gib uns, was Du uns durch Deine Gesandten versprochen hast, und führe uns nicht in Schande am Tag der Auferstehung. Wahrlich, Du brichst nicht (Dein) Versprechen."\qt@no{(194)}}
\qt@newcmd\qurantrans@de@cdlxxxviii{Da erhörte sie ihr Herr (und sprach): ``Seht, Ich lasse kein Werk der Wirkenden unter euch verlorengehen, sei es von Mann oder Frau; die einen von euch sind von den anderen. Und diejenigen, die da auswanderten und aus ihren Häusern vertrieben wurden und auf Meinem Weg litten und kämpften und fielen wahrlich, tilgen will Ich ihre Missetaten, und wahrlich, führen will Ich sie in Gärten, durch die Bäche eilen, als Lohn von Allah." Und bei Allah ist die beste Belohnung.\qt@no{(195)}}
\qt@newcmd\qurantrans@de@cdlxxxix{Laß dich nicht trügen durch den Wandel der Ungläubigen in den Ländern.\qt@no{(196)}}
\qt@newcmd\qurantrans@de@cdxc{Ein winziger Nießbrauch dann ist Gahannam ihre Herberge, und schlimm ist das Lager!\qt@no{(197)}}
\qt@newcmd\qurantrans@de@cdxci{Wer jedoch seinen Herrn fürchtet denen werden Gärten zuteil sein, durcheilt von Bächen; ewig werden sie darin bleiben, eine Bewirtung von Allah und was bei Allah bereitsteht, ist für die Frommen besser.\qt@no{(198)}}
\qt@newcmd\qurantrans@de@cdxcii{Und wahrlich, unter den Leuten der Schrift gibt es solche, die an Allah glauben und an das, was zu euch hinabgesandt worden ist, und was hinabgesandt worden ist zu ihnen. Dabei sind sie demütig gegen Allah und verkaufen Seine Zeichen nicht gegen einen winzigen Preis. Jene haben ihren Lohn bei ihrem Herrn. Wahrlich, Allah ist schnell im Abrechnen.\qt@no{(199)}}
\qt@newcmd\qurantrans@de@cdxciii{O ihr, die ihr glaubt, übt Geduld und wetteifert in Geduld und seid standhaft und fürchtet Allah; vielleicht werdet ihr erfolgreich sein.\qt@no{(200)}}
\qt@newcmd\qurantrans@de@cdxciv{\basmalahde O ihr Menschen, fürchtet euren Herrn, Der euch erschaffen hat aus einem einzigen Wesen und aus ihm erschuf Er seine Gattin, und aus den beiden ließ Er viele Männer und Frauen entstehen. Und fürchtet Allah, in Dessen Namen ihr einander bittet, sowie (im Namen eurer) Blutsverwandtschaft. Wahrlich, Allah wacht über euch.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@cdxcv{Und gebt den Waisen ihr Gut, und tauscht nicht (euer) Schlechtes mit (ihrem) Guten ein, und zehrt nicht ihr Gut zu dem eurigen hinzu; seht, das ist ein großes Verbrechen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@cdxcvi{Und wenn ihr fürchtet, nicht gerecht gegen die Waisen zu sein, so heiratet, was euch an Frauen gut ansteht, zwei, drei oder vier; und wenn ihr fürchtet, nicht billig zu sein, (heiratet) eine oder was im Besitz eurer rechten (Hand ist). So könnt ihr am ehesten Ungerechtigkeit vermeiden.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@cdxcvii{Und gebt den Frauen ihre Brautgabe als Schenkung. Und wenn sie euch gern etwas davon erlassen, so könnt ihr dies unbedenklich zum Wohlsein verbrauchen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@cdxcviii{Und gebt nicht den Schwachsinnigen euer Gut, das Allah euch zum Unterhalt gegeben hat. Versorgt sie davon und kleidet sie und sprecht zu ihnen mit freundlichen Worten.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@cdxcix{Und prüft die Waisen, bis sie die Ehereife erreicht haben; und wenn ihr in ihnen Vernunft wahrnehmt, so händigt ihnen ihr Gut aus. Und zehrt nicht auf verschwenderisch und in Eile (in der Erwartung), daß sie nicht großjährig würden. Und wer (als Vormund) reich ist, der soll sich zurückhalten, und wer arm ist, der soll nach Billigkeit zehren. Und wenn ihr ihnen ihr Gut aushändigt, lasset dies vor ihnen bezeugen. Es genügt jedoch, daß Allah die Rechenschaft vornimmt.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@d{Den Männern steht ein Teil von der Hinterlassenschaft ihrer Eltern und Verwandten zu, und ebenfalls den Frauen steht ein Teil von der Hinterlassenschaft ihrer Eltern und Verwandten zu. Sei es wenig oder viel. (Das gilt) als vorgeschriebener Anteil.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@di{Und wenn bei der Teilung die Verwandten und die Waisen und die Armen anwesend sind, so schenkt ihnen etwas davon und sprecht freundliche Worte zu ihnen.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@dii{Und fürchten sollen sich diejenigen, die, wenn sie schwache Nachkommen hinterließen, für sie bangen würden; Allah sollen sie fürchten und geziemende Worte sprechen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@diii{Wahrlich, diejenigen, die der Waisen Gut ungerecht aufzehren, die zehren (in Wirklichkeit) Feuer in ihre Bäuche auf und werden in einem Höllenfeuer brennen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@div{Allah schreibt euch hinsichtlich eurer Kinder vor: Auf eines männlichen Geschlechts kommt (bei der Erbteilung) gleichviel wie auf zwei weiblichen Geschlechts. Sind es aber (nur) Frauen, mehr als zwei, sollen sie zwei Drittel der Hinterlassenschaft erhalten. Ist es nur eine, soll sie die Hälfte haben. Und jedes Elternteil soll den sechsten Teil der Hinterlassenschaft erhalten, wenn er (der Verstorbene) Kinder hat; hat er jedoch keine Kinder, und seine Eltern beerben ihn, steht seiner Mutter der dritte Teil zu. Und wenn er Brüder hat, soll seine Mutter den sechsten Teil, nach Bezahlung eines etwa gemachten Vermächtnisses oder einer Schuld, erhalten. Eure Eltern und eure Kinder ihr wisset nicht, wer von beiden euch an Nutzen naher steht. (Dies ist) ein Gebot von Allah; wahrlich, Allah ist Allwissend, Allweise.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@dv{Und ihr bekommt die Hälfte von dem, was eure Frauen hinterlassen, falls sie keine Kinder haben; haben sie aber Kinder, dann erhaltet ihr ein Viertel von ihrer Erbschaft, nach allen etwa von ihnen gemachten Vermächtnissen oder Schulden. Und ihnen steht ein Viertel von eurer Erbschaft zu, falls ihr keine Kinder habt; habt ihr aber Kinder, dann erhalten sie ein Achtel von eurer Erbschaft, nach allen etwa von euch gemachten Vermächtnissen oder Schulden. Und wenn es sich um einen Mann handelt oder eine Frau, dessen Erbschaft geteilt werden soll, und der weder Eltern noch Kinder, aber einen Bruder oder eine Schwester hat, dann erhalten diese je ein Sechstel. Sind aber mehr (Geschwister) vorhanden, dann sollen sie sich ein Drittel teilen, nach allen etwa gemachten Vermächtnissen oder Schulden, ohne Beeinträchtigung (dies ist) eine Vorschrift von Allah, und Allah ist Allwissend, Milde.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@dvi{Dies sind die Schranken Allahs; und den, der Allah und Seinem Gesandten gehorcht, führt Er in Gärten ein, durch die Bäche fließen; darin sollen sie ewig weilen; und das ist die große Glückseligkeit.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@dvii{Und wer Allah und Seinem Gesandten den Gehorsam versagt und Seine Schranken übertritt, den führt Er ins Feuer; darin muß er ewig bleiben; und ihm wird eine schmähliche Strafe zuteil.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@dviii{Und wenn einige eurer Frauen eine Hurerei begehen, dann ruft vier von euch als Zeugen gegen sie auf; bezeugen sie es, dann schließt sie in die Häuser ein, bis der Tod sie ereilt oder Allah ihnen einen Ausweg gibt.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@dix{Und wenn zwei von euch (Männern) es begehen, dann fügt ihnen Übel zu. Wenn sie (aber) umkehren und sich bessern, dann lasset ab von ihnen; denn Allah ist Gnädig und Barmherzig.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@dx{Nur diejenigen haben bei Allah Vergebung zu erwarten, die in Unwissenheit Böses tun und hierauf beizeiten umkehren. Diesen wendet Sich Allah wieder gnädig zu; und Allah weiß Bescheid und ist Allweise.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@dxi{Diejenigen aber haben keine Vergebung zu erwarten, die schlechte Taten begehen, und die erst, wenn sie zum Sterben kommen, sagen: ``Jetzt kehre ich um." Auch diejenigen nicht, die als Ungläubige sterben. Für sie haben Wir eine schmerzhafte Strafe bereitet.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@dxii{O ihr, die ihr glaubt, euch ist nicht erlaubt, Frauen gegen ihren Willen zu beerben. Und hindert sie nicht (an der Verheiratung mit einem anderen), um einen Teil von dem zu nehmen, was ihr ihnen (als Brautgabe) gabt, es sei denn, sie hätten offenkundig Hurerei begangen. Verkehrt in Billigkeit mit ihnen; und wenn ihr Abscheu gegen sie empfindet, empfindet ihr vielleicht Abscheu gegen etwas, in das Allah reiches Gut gelegt hat.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@dxiii{Und wenn ihr eine Gattin gegen eine andere eintauschen wollt und ihr habt der einen ein Talent (als Brautgabe) gegeben, so nehmt nichts von ihm fort. Wollt ihr es etwa in Verleumdung und offenbarer Sünde fortnehmen?\qt@no{(20)}}
\qt@newcmd\qurantrans@de@dxiv{Und wie könntet ihr es fortnehmen, wo ihr einander bereits beiwohntet, und sie mit euch einen festen Bund schlossen?\qt@no{(21)}}
\qt@newcmd\qurantrans@de@dxv{Und heiratet keine Frauen, die eure Väter geheiratet hatten, es sei denn, es geschah bereits zuvor. Wahrlich, es ist eine Schande und ein Abscheu und ein übler Weg.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@dxvi{erboten sind euch (zur Heirat) eure Mütter, eure Töchter, eure Schwestern, eure Vaterschwestern und Mutterschwestern, eure Brudertöchter und Schwestertöchter, eure Nährmütter, die euch gestillt haben, und eure Milchschwestern und die Mütter eurer Frauen und eure Stieftöchter, die in eurem Schutze sind, von euren Frauen, mit denen ihr (die eheliche Beziehung) vollzogen habt. Habt ihr dies jedoch noch nicht mit ihnen vollzogen, so ist es keine Sünde. Ferner die Ehefrauen eurer Söhne aus eurer Abstammung, und ihr sollt nicht zwei Schwestern zusammen haben, es sei denn (es ist) bereits geschehen. Seht, Allah ist Allverzeihend und Barmherzig.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@dxvii{Und (verwehrt sind euch) verheiratete Frauen außer denen, die ihr von Rechts wegen besitzt. Dies ist Allahs Vorschrift für euch. Und erlaubt ist euch außer diesem, daß ihr mit eurem Geld Frauen begehrt, zur Ehe und nicht zur Hurerei. Und gebt denen, die ihr genossen habt, ihre Brautgabe. Dies ist eine Vorschrift; doch soll es keine Sünde sein, wenn ihr über die Vorschrift hinaus miteinander eine Übereinkunft trefft. Seht, Allah ist Allwissend und Allweise.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@dxviii{Und wer von euch nicht vermögend genug ist, um gläubige Frauen zu heiraten, der heirate von dem Besitz eurer rechten Hand unter euren gläubigen Mägden; und Allah kennt euren Glauben sehr wohl. Ihr seid einer vom anderen. Darum heiratet sie mit Erlaubnis ihrer Familien und gebt ihnen ihre Brautgabe nach Billigkeit, wenn sie keusch sind, weder Unzucht treiben noch insgeheim Liebhaber nehmen. Und wenn sie, nachdem sie verheiratet sind, der Unzucht schuldig werden, dann sollen sie die Hälfte der Strafe erleiden, die für freie Frauen vorgeschrieben ist. Diese (Erleichterung) ist für diejenigen von euch (vorgesehen), die fürchten, in Bedrängnis zu kommen. Daß ihr Geduld übt, ist besser für euch; und Allah ist Allverzeihend, Barmherzig.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@dxix{Allah will euch die Wege derer klar machen, die vor euch waren, und euch dahin leiten und Sich in Gnade zu euch kehren. Und Allah ist Allwissend, Allweise.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@dxx{Und Allah will Sich in Gnade zu euch kehren; und diejenigen aber, die den niederen Gelüsten folgen, wollen, daß ihr (vom rechten Weg) völlig abweicht.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@dxxi{Allah will eure Bürde erleichtern; denn der Mensch ist schwach erschaffen.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@dxxii{O Ihr Gläubigen! Bringt euch nicht untereinander in betrügerischer Weise um euer Vermögen! Anders ist es, wenn es sich um ein Geschäft handelt, das ihr in gegenseitigem Übereinkommen abschließt. Und tötet euch nicht (gegenseitig)! Allah verfährt barmherzig mit euch.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@dxxiii{Wenn einer dies in Übertretung und in frevelhafter Weise tut, werden Wir ihn im Feuer brennen lassen, und das ist Allah ein leichtes.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@dxxiv{Wenn ihr euch von den schwereren unter den euch verbotenen Dingen fernhaltet, dann werden Wir eure geringeren Übel von euch hinwegnehmen und euch an einen ehrenvollen Platz führen.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@dxxv{Und begehrt nicht das, womit Allah die einen von euch vor den anderen ausgezeichnet hat. Die Männer sollen ihren Anteil nach ihrem Verdienst erhalten, und die Frauen sollen ihren Anteil nach ihrem Verdienst erhalten. Und bittet Allah um Seine Huld. Wahrlich, Allah hat vollkommene Kenntnis von allen Dingen.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@dxxvi{Und einem jeden haben Wir Erben bestimmt für das, was Eltern und Verwandte und jene, mit denen eure Eide einen Bund bekräftigten, hinterlassen haben. So gebt ihnen denn ihren Anteil. Seht, Allah ist von allem Zeuge.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@dxxvii{Die Männer stehen den Frauen in Verantwortung vor, weil Allah die einen vor den anderen ausgezeichnet hat und weil sie von ihrem Vermögen hingeben. Darum sind tugendhafte Frauen die Gehorsamen und diejenigen, die (ihrer Gatten) Geheimnisse mit Allahs Hilfe wahren. Und jene, deren Widerspenstigkeit ihr befürchtet: ermahnt sie, meidet sie im Ehebett und schlagt sie! Wenn sie euch dann gehorchen, so sucht gegen sie keine Ausrede. Wahrlich, Allah ist Erhaben und Groß.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@dxxviii{Und wenn ihr einen Bruch zwischen beiden befürchtet, dann sendet einen Schiedsrichter von seiner Familie und einen Schiedsrichter von ihrer Familie. Wollen sie sich aussöhnen, so wird Allah Frieden zwischen ihnen stiften. Wahrlich, Allah ist Allwissend, Allkundig.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@dxxix{Und dient Allah und setzt Ihm nichts zur Seite; und seid gut zu den Eltern und zu den Verwandten, den Waisen, den Armen, dem Nachbar, sei er verwandt oder aus der Fremde, dem Begleiter an der Seite, dem Sohn des Weges und zu dem (Sklaven), den ihr von Rechts wegen besitzt. Seht, Allah liebt nicht den Hochmütigen, den Prahler\qt@no{(36)}}
\qt@newcmd\qurantrans@de@dxxx{die da geizig sind und den Leuten gebieten, geizig zu sein, und verbergen, was Allah ihnen in Seiner Huld gegeben hat; und den Ungläubigen haben Wir eine schändende Strafe bereitet.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@dxxxi{(Ebenfalls) denjenigen, die da ihr Gut spenden, um von den Menschen gesehen zu werden, und nicht an Allah glauben und an den Jüngsten Tag; und wer den Satan zum Nächsten hat, der hat einen schlimmen Nächsten.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@dxxxii{Was aber käme über sie, wenn sie an Allah glaubten und an den Jüngsten Tag und von dem spendeten, was Allah ihnen beschert hat? Und Allah weiß über sie Bescheid.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@dxxxiii{Wahrlich, Allah tut kein Unrecht; auch nicht vom Gewicht eines Stäubchens. Und ist da irgendeine gute Tat, so vervielfacht Er sie und gibt von Sich aus gewaltigen Lohn.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@dxxxiv{Und wie, wenn Wir aus jedem Volk einen Zeugen herbeibringen und dich als Zeugen gegen diese herbeibringen?\qt@no{(41)}}
\qt@newcmd\qurantrans@de@dxxxv{An jenem Tag werden diejenigen, welche ungläubig waren und dem Gesandten den Gehorsam versagten, wünschen, daß doch die Erde über ihnen geebnet werde, und sie werden kein Wort vor Allah verbergen können.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@dxxxvi{O ihr, die ihr glaubt, nahet nicht dem Gebet, wenn ihr betrunken seid, bis ihr versteht, was ihr sprecht, noch im Zustande der Unreinheit ausgenommen als Reisende unterwegs, bis ihr den Gusl vorgenommen habt. Und wenn ihr krank seid oder euch auf einer Reise befindet oder einer von euch von der Notdurft zurückkommt, oder wenn ihr die Frauen berührt habt und kein Wasser findet, dann sucht guten (reinen) Sand und reibt euch dann Gesicht und Hände ab. Wahrlich, Allah ist Allverzeihend, Allvergebend\qt@no{(43)}}
\qt@newcmd\qurantrans@de@dxxxvii{Hast du nicht jene gesehen, denen ein Teil der Schrift gegeben wurde? Sie erkaufen Irrtum und wünschen, daß ihr auch vom Wege abirrt.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@dxxxviii{Und Allah kennt am besten eure Feinde, und Allah genügt als Beschützer, und Allah genügt als Helfer.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@dxxxix{Es gibt welche unter den Juden, die Worte aus ihren Stellungen verdrehen und sagen: ``Wir hören und wir gehorchen nicht", und ``Höre, ohne gehört zu werden", und ``Sei uns nachsichtig", indem sie mit ihren Zungen lügen und den Glauben lästern. Und hätten sie gesagt: ``Wir hören und wir gehorchen", und ``Höre", und ``Schaue gnädig auf uns", wäre es besser für sie gewesen und aufrechter. Aber Allah hat sie zur Strafe für ihren Unglauben verflucht; darum glauben sie nur wenig.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@dxl{O ihr, denen die Schrift gegeben wurde, glaubt an das, was Wir herabgesandt haben und welches das bestätigt, was euch schon vorliegt, bevor Wir manche Gesichter vernichten und sie auf ihre Rücken werfen oder sie verfluchen, wie Wir die Sabbatleute verfluchten. Und Allahs Befehl wird mit Sicherheit ausgeführt.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@dxli{Wahrlich, Allah wird es nicht vergeben, daß Ihm Götter zur Seite gestellt werden; doch Er vergibt das, was geringer ist als dies, wem Er will. Und wer Allah Götter zur Seite stellt, der hat wahrhaftig eine gewaltige Sünde begangen.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@dxlii{Hast du nicht jene gesehen, die sich selber reinsprechen? Allah ist es aber, der reinspricht, wen Er will, und ihnen wird kein Fädchen Unrecht getan.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@dxliii{Schau, wie sie Lügen gegen Allah erdichten. Und das allein genügt als offenkundige Sünde.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@dxliv{Hast du nicht jene gesehen, denen ein Teil der Schrift gegeben wurde? Sie glauben an Zauberei und Götzen, und sie sagen von den Ungläubigen: ``Sie sind in der Lehre besser geleitet als die Gläubigen."\qt@no{(51)}}
\qt@newcmd\qurantrans@de@dxlv{Diese sind es, die Allah verflucht hat; und für den, den Allah verflucht, wirst du keinen Helfer finden.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@dxlvi{Oder haben sie (etwa) Anteil an der Herrschaft? Dann würden sie den Menschen nicht einmal so viel wie die Rille eines Dattelkerns abgeben.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@dxlvii{Oder beneiden sie die Menschen um das, was Allah ihnen aus Seiner Huld gegeben hat? Nun, Wir gaben wohl dem Haus Abrahams das Buch und die Weisheit, und Wir gaben ihnen ein mächtiges Reich.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@dxlviii{Und einige von ihnen glaubten daran, andere aber wandten sich davon ab. Und Gahannam ist schlimm genug als ein Flammenfeuer.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@dxlix{Diejenigen, die nicht an Unsere Zeichen glauben, die werden Wir im Feuer brennen lassen: Sooft ihre Haut verbrannt ist, geben Wir ihnen eine andere Haut, damit sie die Strafe kosten. Wahrlich, Allah ist Allmächtig, Allweise.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@dl{Diejenigen aber, die glauben und gute Werke tun, wollen Wir in Gärten eingehen lassen, durch die Bäche fließen, darin werden sie ewig weilen; dort sollen sie reine Gattinnen haben, und Wir werden sie in einen wohltätigen Ort mit reichlich Schatten eingehen lassen.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@dli{Allah befiehlt euch, die anvertrauten Güter ihren Eigentümern zurückzugeben; und wenn ihr zwischen Menschen richtet, nach Gerechtigkeit zu richten. Wahrlich, billig ist, wozu Allah euch ermahnt. Allah ist Allhörend, Allsehend.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@dlii{O ihr, die ihr glaubt, gehorcht Allah und gehorcht dem Gesandten und denen, die unter euch Befehlsgewalt besitzen. Und wenn ihr über etwas streitet, so bringt es vor Allah und den Gesandten, wenn ihr an Allah glaubt und an den Jüngsten Tag. Das ist das Beste und nimmt am ehesten einen guten Ausgang.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@dliii{Hast du nicht jene gesehen, die behaupteten, an das zu glauben, was zu dir und was vor dir hinabgesandt worden ist? Sie wollen (nun) eine rechtswirksame Entscheidung beim Teufel suchen, wo ihnen doch befohlen worden ist, nicht daran zu glauben; und Satan will sie weit verwirren lassen.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@dliv{Und wenn ihnen gesagt wird: ``Kommt her zu dem, was Allah herabgesandt hat, und zu dem Gesandten", siehst du die Heuchler sich in Widerwillen von dir abwenden.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@dlv{Aber wie, wenn ein Unheil sie trifft für die früheren Werke ihrer Hände, dann kommen sie zu dir und schwören bei Allah: ``Wir wollten es ja nur gut machen und (zwischen ihnen) schlichten."\qt@no{(62)}}
\qt@newcmd\qurantrans@de@dlvi{Diese sind es, von denen Allah wohl Bescheid weiß, was in ihren Herzen ist. So wende dich von ihnen ab und ermahne sie und sprich zu ihnen über sie selbst ein eindringliches Wort.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@dlvii{Und Wir haben keinen Gesandten geschickt, ohne daß ihm mit Allahs Erlaubnis gehorcht worden wäre. Und wären sie zu dir gekommen, nachdem sie sich gegen sich selber vergangen hatten, und hätten sie zu Allah um Verzeihung gefleht, und hätte der Gesandte für sie um Verzeihung gebeten, hätten sie gewiß Allah Allvergebend, Barmherzig gefunden.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@dlviii{Doch nein, bei deinem Herrn; sie sind nicht eher Gläubige, bis sie dich zum Richter über alles machen, was zwischen ihnen strittig ist, und dann in ihren Herzen keine Bedenken gegen deine Entscheidung finden und sich voller Ergebung fügen.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@dlix{Und hätten Wir ihnen vorgeschrieben: ``Tötet euch selbst oder verlaßt eure Häuser", so würden sie es nicht tun, ausgenommen einige wenige von ihnen; hätten sie aber das getan, wozu sie aufgefordert worden waren, so wäre es wahrlich besser für sie gewesen und stärkend (für ihren Glauben)\qt@no{(66)}}
\qt@newcmd\qurantrans@de@dlx{Dann würden Wir ihnen gewiß einen großen Lohn von Uns aus geben\qt@no{(67)}}
\qt@newcmd\qurantrans@de@dlxi{Und Wir würden sie sicher auf den geraden Weg leiten.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@dlxii{Und wer Allah und dem Gesandten gehorcht, soll unter denen sein, denen Allah Seine Huld gewahrt, unter den Propheten, den Wahrhaftigen, den Zeugen und den Rechtschaffenen welch gute Gefährten!\qt@no{(69)}}
\qt@newcmd\qurantrans@de@dlxiii{Derart ist eine Gnade von Allah, und Allah genügt als Allwissender.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@dlxiv{O ihr, die ihr glaubt, seid auf eurer Hut! Dann zieht entweder truppweise aus oder alle zusammen.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@dlxv{Unter euch ist wohl mancher, der zurückbleibt, und wenn euch ein Unglück trifft, sagt er: ``Wahrlich, Allah ist gnädig zu mir gewesen, daß ich nicht bei ihnen zugegen war."\qt@no{(72)}}
\qt@newcmd\qurantrans@de@dlxvi{Wenn euch aber eine Huld von Allah beschieden ist, dann sagt er, als sei keine Freundschaft zwischen euch und ihm: ``Wäre ich doch bei ihnen gewesen, dann hätte ich einen großen Erfolg errungen!"\qt@no{(73)}}
\qt@newcmd\qurantrans@de@dlxvii{Laßt also für Allahs Sache diejenigen kämpfen, die das irdische Leben um den Preis des jenseitigen Lebens verkaufen. Und wer für Allahs Sache kämpft, als dann getötet wird oder siegt, dem werden Wir einen gewaltigen Lohn geben.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@dlxviii{Und warum wollt ihr nicht für Allahs Sache kämpfen und für die der Schwachen Männer, Frauen und Kinder, die sagen: ``Unser Herr, führe uns heraus aus dieser Stadt, deren Bewohner Bedrücker sind, und gib uns von Dir einen Beschützer, und gib uns von Dir einen Helfer?"\qt@no{(75)}}
\qt@newcmd\qurantrans@de@dlxix{Die da glauben, kämpfen für Allahs Sache, und die nicht glauben, kämpfen für die Sache des Teufels; darum kämpft gegen die Anhänger des Satans! Wahrlich, die List des Satans ist schwach.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@dlxx{Hast du nicht jene gesehen, zu denen man sagte: ``Haltet eure Hände zurück, verrichtet das Gebet und entrichtet die Zakah." Doch wenn ihnen der Kampf verordnet wurde, da fürchtete ein Teil von ihnen die Menschen wie in Furcht vor Allah oder mit noch größerer Furcht; und sie sagten: ``Unser Herr, warum hast Du uns den Kampf verordnet? Möchtest Du uns nicht noch eine Weile Aufschub gewähren?" Sprich: ``Die Nutznießung dieser Welt ist gering, und das Jenseits wird für die Gottesfürchtigen besser sein; und kein Fädchen Unrecht sollt ihr erleiden."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@dlxxi{Wo auch immer ihr seid, der Tod ereilt euch doch, und wäret ihr in hohen Burgen. Und wenn ihnen Gutes begegnet, sagen sie: ``Das ist von Allah"; und wenn ihnen Schlimmes begegnet, sagen sie: ``Das ist von dir." Sprich: ``Alles ist von Allah." Warum verstehen denn diese Leute kaum etwas von dem, was ihnen gesagt wird?\qt@no{(78)}}
\qt@newcmd\qurantrans@de@dlxxii{Was dich an Gutem trifft, kommt von Allah, und was dich an Schlimmem trifft, kommt von dir selbst. Und Wir haben dich als einen Gesandten zu den Menschen entsandt. Und Allah genügt als Zeuge.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@dlxxiii{Wer dem Gesandten gehorcht, der hat Allah gehorcht; und wenn sich jemand abwendet, so haben Wir dich nicht zum Hüter über sie gesandt.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@dlxxiv{Und sie sagen: ``Gehorsam"; doch wenn sie von dir weggehen, dann munkelt ein Teil von ihnen von etwas anderem, als von dem, was du sagst. Allah aber zeichnet auf, worüber sie munkeln. So wende dich von ihnen ab und vertraue auf Allah. Und Allah genügt als Sachwalter.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@dlxxv{Sie machen sich keine Gedanken über den Quran. Wäre er von einem anderen als Allah, so würden sie darin gewiß viel Widerspruch finden.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@dlxxvi{Und wenn ihnen etwas zu Ohren kommt, das Sicherheit oder Furcht betrifft, machen sie es bekannt. Hätten sie es aber vor den Gesandten und vor jene gebracht, die unter ihnen die Befehlsgewalt besitzen, dann würden es sicherlich die unter ihnen, die es entschleiern könnten, wissen. Und wäre nicht Allahs Gnade über euch und Seine Barmherzigkeit, wäret ihr alle dem Satan gefolgt, bis auf wenige Ausnahmen.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@dlxxvii{Kämpfe darum für Allahs Sache du wirst für keinen verantwortlich gemacht außer für dich selbst und feuere die Gläubigen zum Kampf an. Vielleicht wird Allah die Gewalt derer, die ungläubig sind, aufhalten; und Allahs Gewalt ist viel größer und Er ist strenger im Strafen.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@dlxxviii{Wer eine gute Fürsprache einlegt, dem soll ein Anteil daran zukommen, und wer eine schlechte Fürsprache einlegt, bekommt, was ihr entspricht. Und Allah hat Macht über alle Dinge.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@dlxxix{Und wenn ihr mit einem Gruß gegrüßt werdet, so grüßt mit einem schöneren wieder oder erwidert ihn. Wahrlich, Allah legt Rechenschaft über alle Dinge ab.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@dlxxx{(Er ist) Allah; es ist kein Gott außer Ihm. Er wird euch versammeln am Tage der Auferstehung, über den es keinen Zweifel gibt. Und wer ist glaubwürdiger in der Aussage als Allah?\qt@no{(87)}}
\qt@newcmd\qurantrans@de@dlxxxi{Was ist euch denn widerfahren, daß ihr in der Angelegenheit der Heuchler in zwei Parteien gespalten seid? Und Allah hat sie verstoßen wegen dem was sie begangen haben. Wollt ihr denn rechtleiten, wen Allah ins Verderben hat gehen lassen? Und für den, den Allah ins Verderben gehen läßt, findest du keinen Weg.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@dlxxxii{Sie wünschen, daß ihr ungläubig werdet, wie sie ungläubig sind, so daß ihr alle gleich werdet. Nehmt euch daher keine Beschützer von ihnen, solange sie nicht auf Allahs Weg wandern. Und wenn sie sich abwenden, dann ergreift sie und tötet sie, wo immer ihr sie auffindet; und nehmt euch keinen von ihnen zum Beschützer oder zum Helfer\qt@no{(89)}}
\qt@newcmd\qurantrans@de@dlxxxiii{mit Ausnahme derer, die zu Leuten gelangen, mit denen ihr ein Bündnis habt, und die zu euch kommen, weil ihre Herzen davor zurückschrecken, gegen euch oder gegen ihr eigenes Volk zu kämpfen. Und wenn Allah es gewollt hätte, hätte Er ihnen Macht über euch geben können; dann hätten sie sicherlich gegen euch gekämpft. Darum, wenn sie sich von euch fernhalten und nicht gegen euch kämpfen, sondern euch Frieden bieten; dann hat Allah euch keinen Grund gegen sie gegeben.\qt@no{(90)}}
\qt@newcmd\qurantrans@de@dlxxxiv{Ihr werdet andere finden, die vor euch und vor ihren Leuten Sicherheit haben wollen. Sooft sie wieder zur Feindseligkeit verleitet werden, stürzen sie kopfüber hinein. Wenn sie sich also weder von euch fernhalten noch euch Frieden bieten noch ihre Hände zügeln, dann ergreift sie und tötet sie, wo immer ihr sie auffindet. Denn gegen diese haben Wir euch volle Gewalt gegeben.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@dlxxxv{Keinem Gläubigen steht es zu, einen anderen Gläubigen zu töten, es sei denn aus Versehen. Und wer einen Gläubigen aus Versehen tötet: dann soll er einen gläubigen Sklaven befreien und Blutgeld an seine Erben zahlen, es sei denn, sie erlassen es aus Mildtätigkeit. War er (der Getötete) aber von einem Volk, das euer Feind ist, und ist der (der ihn getötet hat) gläubig: dann soll er einen gläubigen Sklaven befreien; war er aber von einem Volk, mit dem ihr ein Bündnis habt: dann soll er Blutgeld an seine Erben zahlen und einen gläubigen Sklaven befreien. Wer (das) nicht kann: dann (soll er) zwei Monate hintereinander fasten (dies ist) eine Vergebung von Allah. Und Allah ist Allwissend, Allweise.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@dlxxxvi{Und wer einen Gläubigen vorsätzlich tötet, dessen Lohn ist Gahannam, worin er auf ewig bleibt. Allah wird ihm zürnen und ihn von Sich weisen und ihm eine schwere Strafe bereiten.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@dlxxxvii{O ihr, die ihr glaubt, wenn ihr auszieht auf dem Weg Allahs, so stellt erst gehörig Nachforschungen an und sagt zu keinem, der euch den Friedensgruß bietet: ``Du bist kein Gläubiger." Ihr trachtet nach den Gütern des irdischen Lebens, doch bei Allah ist des Guten Fülle. So waret ihr einst, dann aber hat Allah euch Seine Huld erwiesen; darum stellt erst gehörig Nachforschungen an. Seht, Allah ist eures Tuns wohl kundig.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@dlxxxviii{Diejenigen unter den Gläubigen, die daheim bleiben ausgenommen die Gebrechlichen, und die, welche für Allahs Sache ihr Gut und Blut im Kampf einsetzen, sind nicht gleich. Allah hat die mit ihrem Gut und Blut Kämpfenden über die, die daheim bleiben, im Rang um eine Stufe erhöht. Jeden von beiden aber hat Allah Gutes verheißen; doch die Kämpfenden hat Allah vor den Daheimbleibenden durch großen Lohn ausgezeichnet\qt@no{(95)}}
\qt@newcmd\qurantrans@de@dlxxxix{(mit) Rangstufen von Ihm und Vergebung und Barmherzigkeit; und Allah ist Allvergebend, Barmherzig.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@dxc{Zu jenen, die Unrecht gegen sich selbst verübt haben, sagen die Engel, wenn sie sie abberufen: ``In welchen Umständen habt ihr euch befunden?" Sie antworten: ``Wir wurden als Schwache im Lande behandelt." Da sprechen jene: ``War Allahs Erde nicht weit genug für euch, daß ihr darin hättet auswandern können?" Sie sind es, deren Herberge Gahannam sein wird, und schlimm ist das Ende!\qt@no{(97)}}
\qt@newcmd\qurantrans@de@dxci{Ausgenommen davon sind die unterdrückten Männer, Frauen und Kinder, die über keinerlei Möglichkeit verfügen und keinen Ausweg finden.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@dxcii{Diese sind es, denen Allah vergeben möge; denn Allah ist Allvergebend, Allverzeihend.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@dxciii{Und wer für die Sache Allahs auswandert, der wird auf Erden genug Stätten der Zuflucht und der Fülle finden. Und wer seine Wohnung verläßt und zu Allah und Seinem Gesandten auswandert und dabei vom Tode ereilt wird, für dessen Lohn sorgt Allah, und Allah ist Allverzeihend, Barmherzig.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@dxciv{Und wenn ihr durch das Land zieht, so ist es keine Sünde für euch, wenn ihr das Gebet verkürzt, wenn ihr fürchtet, die Ungläubigen könnten euch bedrängen. Wahrlich, die Ungläubigen sind eure offenkundigen Feinde.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@dxcv{Und wenn du unter ihnen bist und für sie das Gebet anführst, so soll ein Teil von ihnen (für das Gebet) bei dir stehen, doch sollen sie ihre Waffen tragen. Und wenn sie sich niederwerfen, so sollen sie hinter euch treten und eine andere Abteilung, die noch nicht gebetet hat, soll mit dir beten; doch sollen sie auf der Hut sein und ihre Waffen bei sich haben. Die Ungläubigen sähen es gerne, daß ihr eure Waffen und euer Gepäck außer acht ließet, so daß sie euch auf einmal überfallen könnten. Und es ist keine Sünde für euch, wenn ihr eure Waffen ablegt, falls ihr unter Regen leidet oder krank seid. Seid jedoch (immer) auf eurer Hut. Wahrlich, Allah hat für die Ungläubigen eine schmähliche Strafe bereitet.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@dxcvi{Und wenn ihr das Gebet verrichtet habt, dann gedenket Allahs im Stehen, Sitzen und im Liegen. Und wenn ihr in Sicherheit seid, dann verrichtet das Gebet; wahrlich das Gebet zu bestimmten Zeiten ist für die Gläubigen eine Pflicht.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@dxcvii{Und lasset nicht nach, die Schar (der Ungläubigen) aufzuspüren. Leidet ihr, so leiden sie gerade so, wie ihr leidet. Doch ihr erhoffet von Allah, was sie nicht erhoffen. Und Allah ist Allwissend, Allweise.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@dxcviii{Wahrlich, zu dir haben Wir das Buch mit der Wahrheit niedergesandt, auf daß du zwischen den Menschen richten mögest, wie Allah es dir gezeigt hat. Sei also nicht ein Verfechter der Treulosen.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@dxcix{Und bitte Allah um Vergebung. Wahrlich, Allah ist Allverzeihend, Barmherzig.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@dc{Und setze dich nicht für diejenigen ein, die sich selbst betrügen. Wahrlich, Allah liebt nicht denjenigen, der ein Betrüger, ein Sünder ist.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@dci{Sie möchten sich vor den Menschen verbergen, doch vor Allah können sie sich nicht verborgen halten; und Er ist bei ihnen, wenn sie sich auf verwerfliche Intrigen vorbereiten. Und Allah ist ihres Tuns kundig.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@dcii{Ihr habt euch also für sie in diesem irdischen Leben eingesetzt. Wer aber wird sich für sie vor Allah am Tage der Auferstehung einsetzen? Oder wer wird ihr Beschützer sein?\qt@no{(109)}}
\qt@newcmd\qurantrans@de@dciii{Und wer Böses tut oder sich gegen sich selbst vergeht und dann Allah um Vergebung bittet, der findet Allah Allvergebend, Barmherzig.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@dciv{Und wer eine Sünde begeht, der begeht sie gegen sich selbst; und Allah ist Allwissend, Allweise.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@dcv{Und wer einen Fehler oder eine Sünde begeht und sie dann einem Unschuldigen zur Last legt, der trägt eine Verleumdung und eine offenkundige Sünde.\qt@no{(112)}}
\qt@newcmd\qurantrans@de@dcvi{Und wäre dir nicht Allahs Huld und Barmherzigkeit zuteil gewesen, so hätte eine Schar von ihnen beschlossen, dich irrezuführen. Doch zum Irrweg führen sie sich selbst; und dir können sie keinerlei Schaden zufügen, und Allah hat das Buch und die Weisheit auf dich herabgesandt und dich gelehrt, was du nicht wußtest, und Allahs Huld, die Er dich erwiesen hat, ist wahrlich großartig.\qt@no{(113)}}
\qt@newcmd\qurantrans@de@dcvii{Nichts Gutes ist in vielen ihrer Besprechungen, es sei denn in solchen, die zur Mildtätigkeit oder zur Güte oder zum Friedenstiften unter den Menschen ermahnen. Und wer das im Trachten nach Allahs Wohlgefallen tut, dem werden Wir einen großen Lohn geben.\qt@no{(114)}}
\qt@newcmd\qurantrans@de@dcviii{Wer sich aber mit dem Gesandten verfeindet, nachdem ihm der rechte Weg klar geworden ist, und einen anderen Weg befolgt als den der Gläubigen, den werden Wir verfolgen lassen, was er verfolgt, und werden ihn dann in Gahannam brennen lassen; und schlimm ist sein Ende.\qt@no{(115)}}
\qt@newcmd\qurantrans@de@dcix{Wahrlich, Allah wird es nicht vergeben, daß Ihm Götter zur Seite gestellt werden: doch Er vergibt, was geringer ist als dies, wem Er will. Und wer Allah Götter zur Seite stellt, der ist in der Tat weit irregegangen.\qt@no{(116)}}
\qt@newcmd\qurantrans@de@dcx{Wahrlich, sie rufen statt Seiner nur weibliche Wesen an; dabei rufen sie nur einen rebellischen Satan\qt@no{(117)}}
\qt@newcmd\qurantrans@de@dcxi{den Allah verflucht hat und der dies erwiderte: ``Ich werde von Deinen Dienern einen bestimmten Teil nehmen\qt@no{(118)}}
\qt@newcmd\qurantrans@de@dcxii{und ich werde sie irreleiten und ihre Hoffnungen anregen und ihnen Befehle erteilen, dem Vieh die Ohren aufzuschlitzen, und ich werde ihnen befehlen, und sie werden Allahs Schöpfung verändern." Und wer sich Satan statt Allah zum Beschützer nimmt, der hat sicherlich einen offenkundigen Verlust erlitten\qt@no{(119)}}
\qt@newcmd\qurantrans@de@dcxiii{er macht ihnen Versprechungen und erweckt Wünsche in ihnen, und was Satan ihnen verspricht, ist Trug.\qt@no{(120)}}
\qt@newcmd\qurantrans@de@dcxiv{Diese haben Gahannam zur Herberge, und sie werden keinen Ausweg daraus finden.\qt@no{(121)}}
\qt@newcmd\qurantrans@de@dcxv{Diejenigen aber, die glauben und gute Werke tun, wollen Wir in Gärten führen, durch welche Bäche fließen, darin werden sie auf ewig und immerdar verweilen (dies ist) eine wahrhaftige Verheißung Allahs; und wer ist glaubwürdiger in der Aussage als Allah?\qt@no{(122)}}
\qt@newcmd\qurantrans@de@dcxvi{Es ist weder nach euren Wünschen noch nach den Wünschen der Leute der Schrift. Wer Böses tut, dem wird es vergolten werden; und er wird für sich außer Allah weder Freund noch Helfer finden.\qt@no{(123)}}
\qt@newcmd\qurantrans@de@dcxvii{Diejenigen aber, die handeln, wie es recht ist sei es Mann oder Frau und dabei gläubig sind, werden ins Paradies eingehen und nicht im geringsten Unrecht erleiden.\qt@no{(124)}}
\qt@newcmd\qurantrans@de@dcxviii{Und wer hat eine schönere Religion als jener, der sich Allah ergibt und dabei Güte übt und dem Glauben Abrahams folgt, des Aufrechten? Und Allah nahm Sich Abraham zum Freund.\qt@no{(125)}}
\qt@newcmd\qurantrans@de@dcxix{Allahs ist alles, was in den Himmeln und was auf Erden ist; und Allah umfaßt alle Dinge.\qt@no{(126)}}
\qt@newcmd\qurantrans@de@dcxx{Und sie fragen dich um Belehrung über die Frauen. Sprich: ``Allah hat euch über sie belehrt; und das, was euch in dem Buch verlesen wird, betrifft die Waisenmädchen, denen ihr nicht gebt, was für sie vorgeschrieben ist, und die ihr doch zu heiraten wünscht, und die Schwachen unter den Kindern und daß ihr euch nach Billigkeit für die Waisen einsetzt. Und was ihr an Gutem tut, Allah weiß darüber Bescheid."\qt@no{(127)}}
\qt@newcmd\qurantrans@de@dcxxi{Und wenn eine Frau von ihrem Ehemann rohe Behandlung oder Gleichgültigkeit befürchtet, so soll es keine Sünde für beide sein, wenn sie sich auf geziemende Art miteinander versöhnen; denn Versöhnung ist gut. Die Menschen sind auf Habsucht eingestellt. Tut ihr jedoch Gutes und seid gottesfürchtig, dann ist Allah eures Tuns kundig.\qt@no{(128)}}
\qt@newcmd\qurantrans@de@dcxxii{Und ihr könnt zwischen den Frauen keine Gerechtigkeit ausüben, so sehr ihr es auch wünschen mögt. Aber neigt euch nicht gänzlich (einer) zu, so daß ihr die andere gleichsam in der Schwebe lasset. Und wenn ihr es wiedergutmacht und gottesfürchtig seid, so ist Allah Allverzeihend, Barmherzig.\qt@no{(129)}}
\qt@newcmd\qurantrans@de@dcxxiii{Und wenn sie sich trennen, so wird Allah beiden aus Seiner Fülle Genüge tun; denn Allah ist Huldreich und Allweise.\qt@no{(130)}}
\qt@newcmd\qurantrans@de@dcxxiv{Und Allahs ist, was in den Himmeln und was auf Erden ist. Und Wir haben jenen, denen vor euch die Schrift gegeben wurde, und euch selbst auferlegt, Allah zu fürchten. Wenn ihr jedoch ungläubig werdet, dann ist Allahs, was in den Himmeln und was auf Erden ist; und Allah ist auf keinen angewiesen und des Lobes würdig.\qt@no{(131)}}
\qt@newcmd\qurantrans@de@dcxxv{Allahs ist, was in den Himmeln und auf Erden ist, und Allah genügt als Beschützer.\qt@no{(132)}}
\qt@newcmd\qurantrans@de@dcxxvi{Wenn Er will, so wird Er euch fortschaffen, ihr Menschen, und andere bringen; und Allah ist dessen Mächtig.\qt@no{(133)}}
\qt@newcmd\qurantrans@de@dcxxvii{Wer den Lohn dieser Welt begehrt so ist der Lohn dieser und jener Welt bei Allah; und Allah ist Allhörend, Allsehend.\qt@no{(134)}}
\qt@newcmd\qurantrans@de@dcxxviii{O ihr, die ihr glaubt, seid auf der Hut bei der Wahrnehmung der Gerechtigkeit und seid Zeugen für Allah, auch dann, wenn es gegen euch selbst oder gegen Eltern und Verwandte geht. Ob der eine reich oder arm ist, so ist Allah beiden näher; darum folgt nicht der persönlichen Neigung, auf daß ihr gerecht handeln könnt. Und wenn ihr aber (die Wahrheit) verdreht oder euch von (der Wahrheit) abwendet, so ist Allah eures Tuns kundig.\qt@no{(135)}}
\qt@newcmd\qurantrans@de@dcxxix{O ihr, die ihr gläubig geworden seid, glaubt an Allah und Seinen Gesandten und an das Buch, das Er auf Seinen Gesandten herabgesandt hat, und an die Schrift, die Er zuvor herabsandte. Und wer nicht an Allah und Seine Engel und Seine Bücher und Seine Gesandten und an den Jüngsten Tag glaubt, der ist wahrlich weit irregegangen.\qt@no{(136)}}
\qt@newcmd\qurantrans@de@dcxxx{Wahrlich, diejenigen, die gläubig sind und hernach ungläubig werden, dann wieder glauben, dann abermals ungläubig werden und noch heftiger im Unglauben werden, denen wird Allah nimmermehr vergeben noch sie des Weges leiten.\qt@no{(137)}}
\qt@newcmd\qurantrans@de@dcxxxi{Verkündige den Heuchlern die ``frohe" Botschaft, daß ihnen schmerzliche Strafe zuteil werde\qt@no{(138)}}
\qt@newcmd\qurantrans@de@dcxxxii{jenen, die sich Ungläubige als Beschützer vor den Gläubigen nehmen. Suchen sie etwa Macht und Ansehen bei ihnen? Wahrlich, Allah allein gehört alle Erhabenheit.\qt@no{(139)}}
\qt@newcmd\qurantrans@de@dcxxxiii{Und Er hat euch schon in dem Buch herabgesandt, daß wenn ihr hört, daß die Zeichen Allahs geleugnet und verspottet werden ihr nicht bei ihnen sitzt, bis sie zu einem anderen Gespräch übergehen; ihr wäret sonst wie sie. Wahrlich, Allah wird die Heuchler und die Ungläubigen allesamt in Gahannam versammeln\qt@no{(140)}}
\qt@newcmd\qurantrans@de@dcxxxiv{die auf Nachrichten über euch harren. Wenn euch ein Sieg von Allah beschieden wird, sagen sie: ``Waren wir nicht mit euch?" Haben aber die Ungläubigen einen Anteil (am Erfolg), sagen sie (zu den Ungläubigen): ``Haben wir nicht Oberhand über euch bekommen und euch vor den Gläubigen beschützt?" Allah wird als dann zwischen euch am Tage der Auferstehung richten; und Allah wird niemals den Ungläubigen die Oberhand über die Gläubigen geben.\qt@no{(141)}}
\qt@newcmd\qurantrans@de@dcxxxv{Wahrlich, die Heuchler versuchen, Allah zu überlisten; doch Er wird sie überlisten. Und wenn sie sich zum Gebet hinstellen, dann stehen sie ungern auf; (sie tun dies nur), um von den Menschen gesehen zu werden, und sie gedenken Allahs nur selten.\qt@no{(142)}}
\qt@newcmd\qurantrans@de@dcxxxvi{Unentschlossen schwanken sie zwischen diesen und jenen und gelangen weder zu diesen noch zu jenen. Und wen Allah irreführt, für den wirst du nimmermehr einen Ausweg finden.\qt@no{(143)}}
\qt@newcmd\qurantrans@de@dcxxxvii{O ihr, die ihr glaubt, nehmt euch keine Ungläubigen zu Beschützern anstelle der Gläubigen. Wollt ihr Allah offenkundige Beweise gegen euch selbst geben?\qt@no{(144)}}
\qt@newcmd\qurantrans@de@dcxxxviii{Wahrlich, die Heuchler befinden sich auf dem untersten Grund des Höllenfeuers; und du findest für sie keinen Helfer\qt@no{(145)}}
\qt@newcmd\qurantrans@de@dcxxxix{außer jenen, die es bereut haben und sich bessern und zu Allah Zuflucht nehmen und die sich mit ihrem Glauben nur an Allah richten. Diese gehören also zu den Gläubigen. Und Allah wird den Gläubigen einen gewaltigen Lohn geben.\qt@no{(146)}}
\qt@newcmd\qurantrans@de@dcxl{Was wird Allah aus eurer Bestrafung machen, wenn ihr dankbar seid und glaubt? Und Allah ist Dankend, Allwissend.\qt@no{(147)}}
\qt@newcmd\qurantrans@de@dcxli{Allah liebt nicht, daß böse Worte laut vernehmbar gebraucht werden, außer wenn einem Unrecht geschieht; wahrlich, Allah ist Allhörend, Allwissend.\qt@no{(148)}}
\qt@newcmd\qurantrans@de@dcxlii{Ob ihr etwas Gutes kundtut oder es geheimhaltet oder etwas Böses verzeiht, so ist Allah wahrlich Allvergebend, Allmächtig.\qt@no{(149)}}
\qt@newcmd\qurantrans@de@dcxliii{Wahrlich, diejenigen, die nicht an Allah und Seine Gesandten glauben und eine Trennung zwischen Allah und Seinen Gesandten machen und sagen: ``Wir glauben an die einen und verwerfen die anderen" und einen Zwischenweg einschlagen möchten\qt@no{(150)}}
\qt@newcmd\qurantrans@de@dcxliv{diese sind die Ungläubigen im wahren Sinne, und bereitet haben Wir den Ungläubigen eine schmähliche Strafe.\qt@no{(151)}}
\qt@newcmd\qurantrans@de@dcxlv{Diejenigen aber, die an Allah und an Seine Gesandten glauben und zwischen ihnen keinen Unterschied machen, sind es, denen Er ihren Lohn geben wird; und Allah ist Allvergebend, Barmherzig.\qt@no{(152)}}
\qt@newcmd\qurantrans@de@dcxlvi{Die Leute der Schrift verlangen von dir, daß du ein Buch vom Himmel zu ihnen herabgelangen läßt. Von Moses aber verlangten sie etwas Größeres als dies, da sie sagten: ``Zeig uns Allah offensichtlich!" Da traf sie der Blitzschlag wegen ihres Frevels. Danach nahmen sie sich das Kalb, nachdem ihnen doch deutliche Zeichen zuteil geworden waren: aber Wir vergaben das. Und Wir verliehen Moses offensichtliche Beweismacht.\qt@no{(153)}}
\qt@newcmd\qurantrans@de@dcxlvii{Und Wir erhoben anläßlich des Bundes mit ihnen den Berg über sie empor und sprachen zu ihnen: ``Tretet durch das Tor in Unterwürfigkeit ein"; und Wir sprachen zu ihnen: ``Übertretet nicht das Sabbatgebot." Und Wir schlossen einen starken Bund mit ihnen.\qt@no{(154)}}
\qt@newcmd\qurantrans@de@dcxlviii{Als sie dann ihren Bund brachen und die Zeichen Allahs verleugneten und die Propheten widerrechtlich töteten und sagten: ``Unsere Herzen sind hinter einem Schleier", aber nein, Allah hat diese wegen ihres Unglaubens verschlossen, so daß sie nur wenig glauben.\qt@no{(155)}}
\qt@newcmd\qurantrans@de@dcxlix{Und wegen ihres Unglaubens und wegen ihrer Behauptung, die sie gegen Maria mit einer enormen Lüge vorbrachten\qt@no{(156)}}
\qt@newcmd\qurantrans@de@dcl{und wegen ihrer Rede: ``Wir haben den Messias, Jesus, den Sohn der Maria, den Gesandten Allahs, getötet", während sie ihn doch weder erschlagen noch gekreuzigt hatten, sondern dies wurde ihnen nur vorgetäuscht; und jene, die in dieser Sache uneins sind, sind wahrlich im Zweifel darüber; sie haben keine Kenntnis davon, sondern folgen nur einer Vermutung; und sie haben ihn nicht mit Gewißheit getötet.\qt@no{(157)}}
\qt@newcmd\qurantrans@de@dcli{Vielmehr hat Allah ihn zu Sich emporgehoben, und Allah ist Allmächtig, Allweise.\qt@no{(158)}}
\qt@newcmd\qurantrans@de@dclii{Und es gibt keinen unter den Leuten der Schrift, der nicht vor seinem Tod daran glauben wird; und am Tage der Auferstehung wird er ein Zeuge gegen sie sein.\qt@no{(159)}}
\qt@newcmd\qurantrans@de@dcliii{Und der Sünde der Juden wegen haben Wir ihnen gute Dinge verboten, die ihnen erlaubt waren, wie auch, weil sie viele Hindernisse in Allahs Weg legten\qt@no{(160)}}
\qt@newcmd\qurantrans@de@dcliv{und weil sie Zins nahmen, obgleich es ihnen untersagt war, und weil sie das Gut der Leute widerrechtlich aufzehrten. Und Wir haben den Ungläubigen unter ihnen eine schmerzliche Strafe bereitet.\qt@no{(161)}}
\qt@newcmd\qurantrans@de@dclv{Aber denen von ihnen, die ein gründliches Wissen haben, und den Gläubigen, die da an das glauben, was zu dir hinabgesandt wurde und was vor dir hinabgesandt wurde, und denjenigen, die das Gebet verrichten und die Zakah entrichten, und denen, die an Allah und an den Jüngsten Tag glauben ihnen werden Wir einen großen Lohn gewähren.\qt@no{(162)}}
\qt@newcmd\qurantrans@de@dclvi{Wahrlich, Wir haben dir offenbart, wie Wir Noah und den Propheten nach ihm offenbart haben. Und Wir offenbarten Abraham, Ismael, Isaak, Jakob, den Stämmen (Israels), Jesus, Hiob, Jonas, Aaron und Salomo; und Wir haben David einen Zabur gegeben.\qt@no{(163)}}
\qt@newcmd\qurantrans@de@dclvii{Es sind Gesandte, von denen Wir dir bereits berichtet haben, und Gesandte, von denen Wir dir nicht berichtet haben und Allah hat mit Moses wirklich gesprochen.\qt@no{(164)}}
\qt@newcmd\qurantrans@de@dclviii{(Es sind) Gesandte, Überbringer froher Botschaften und Warner, so daß die Menschen nach den Gesandten keinen Beweisgrund gegen Allah haben. Und Allah ist Allmächtig, Allweise.\qt@no{(165)}}
\qt@newcmd\qurantrans@de@dclix{Doch Allah bezeugt durch das, was Er zu dir hinabgesandt hat, daß Er es mit Seinem Wissen sandte; und die Engel bezeugen es; und Allah genügt als Zeuge.\qt@no{(166)}}
\qt@newcmd\qurantrans@de@dclx{Diejenigen aber, die ungläubig sind und sich von Allahs Weg abwenden, sie sind wahrlich weit in die Irre gegangen.\qt@no{(167)}}
\qt@newcmd\qurantrans@de@dclxi{Diejenigen, die ungläubig sind und Unrecht verübt haben ihnen wird Allah weder vergeben noch sie zu einem Weg leiten\qt@no{(168)}}
\qt@newcmd\qurantrans@de@dclxii{es sei denn den Weg zu Gahannam, in dem sie in aller Ewigkeit bleiben werden. Und dies ist für Allah ein leichtes.\qt@no{(169)}}
\qt@newcmd\qurantrans@de@dclxiii{O ihr Menschen, der Gesandte ist nunmehr zu euch mit der Wahrheit von eurem Herrn gekommen; glaubt darum, das gereicht euch zum Guten. Seid ihr aber ungläubig, dann ist Allahs, was in den Himmeln und was auf Erden ist; und Allah ist Allwissend, Allweise.\qt@no{(170)}}
\qt@newcmd\qurantrans@de@dclxiv{O Leute der Schrift, übertreibt nicht in eurem Glauben und sagt von Allah nichts als die Wahrheit. Wahrlich, der Messias, Jesus, Sohn der Maria, ist nur der Gesandte Allahs und Sein Wort, das Er Maria entboten hat, und von Seinem Geist. Darum glaubt an Allah und Seine Gesandten, und sagt nicht: ``Drei." Lasset (davon) ab (das) ist besser für euch. Allah ist nur ein einziger Gott. Es liegt Seiner Herrlichkeit fern, Ihm ein Kind zuzuschreiben. Sein ist, was in den Himmeln und was auf Erden ist; und Allah genügt als Anwalt.\qt@no{(171)}}
\qt@newcmd\qurantrans@de@dclxv{Der Messias wird es niemals verschmähen, Diener Allahs zu sein; ebenso nicht die (Allah) nahestehenden Engel; und wer es verschmäht, Ihn anzubeten, und sich dazu zu erhaben fühlt so wird Er sie alle zu Sich versammeln.\qt@no{(172)}}
\qt@newcmd\qurantrans@de@dclxvi{Denen aber, die glauben und gute Werke tun, wird Er den vollen Lohn und noch mehr von Seiner Huld geben; die aber, die verschmähen und stolz sind, die wird Er schmerzlich bestrafen. Und außer Allah finden sie weder Freund noch Helfer.\qt@no{(173)}}
\qt@newcmd\qurantrans@de@dclxvii{O ihr Menschen, zu euch ist in Wahrheit ein deutlicher Beweis von eurem Herrn gekommen; und Wir sandten zu euch ein klares Licht hinab.\qt@no{(174)}}
\qt@newcmd\qurantrans@de@dclxviii{Was aber diejenigen angeht, die an Allah glauben und an Ihm festhalten diese wird Er in Seine Barmherzigkeit und Huld aufnehmen und sie auf dem geraden Weg zu Sich führen.\qt@no{(175)}}
\qt@newcmd\qurantrans@de@dclxix{Sie fragen dich um Belehrung. Sprich: ``Allah belehrt euch über die seitliche Verwandtschaft: Wenn ein Mann stirbt und keine Kinder hinterläßt, aber eine Schwester hat, dann erhält sie die Hälfte seiner Erbschaft; und er beerbt sie, wenn sie keine Kinder hat. Sind es aber zwei (Schwestern), dann erhalten sie zwei Drittel von seiner Erbschaft. Und wenn sie Geschwister sind, Männer und Frauen, kommt auf eines männlichen Geschlechts gleichviel wie auf zwei weiblichen Geschlechts." Allah macht euch das klar damit ihr nicht irrt; und Allah weiß über alle Dinge Bescheid.\qt@no{(176)}}
\qt@newcmd\qurantrans@de@dclxx{\basmalahde O ihr, die ihr glaubt, erfüllt die Verträge. Erlaubt ist euch jede Art des Viehs, mit Ausnahme dessen, was euch (in der Schrift) bekanntgegeben wird; nicht, daß ihr die Jagd als erlaubt ansehen dürft, während ihr pilgert; wahrlich, Allah richtet, wie Er will.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@dclxxi{O ihr, die ihr glaubt! Entweihet weder die Glaubensausübung zur Verherrlichung Allahs, noch den heiligen Monat, noch die Opfertiere, noch die geweihten Opfertiere, noch die nach dem heiligen Hause Ziehenden, die da Gunst und Wohlgefallen von ihrem Herrn suchen. Wenn ihr den Weihezustand beendet habt, dürft ihr jagen; ihr dürft dazu nicht bewegt werden durch den Haß, den ihr gegen Leute hegt, weil sie euch von der heiligen Moschee abgehalten haben, so daß ihr eine Übertretung begeht. Und helft einander in Rechtschaffenheit und Frömmigkeit; doch helft einander nicht in Sünde und Übertretung. Und fürchtet Allah; denn Allah ist streng im Strafen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@dclxxii{Verboten ist euch das Verendete sowie Blut und Schweinefleisch und das, worüber ein anderer als Allahs Name angerufen wurde; das Erdrosselte, das zu Tode Geschlagene, das zu Tode Gestürzte oder Gestoßene und das, was Raubtiere angefressen haben, außer dem, was ihr geschlachtet habt, ferner das, was auf einem heidnischen Opferstein geschlachtet worden ist, und ferner (ist euch verboten), daß ihr durch Lospfeile das Schicksal zu erkunden sucht. Das ist eine Freveltat. Heute haben die Ungläubigen vor eurem Glauben resigniert; also fürchtet nicht sie, sondern fürchtet Mich. Heute habe Ich euch eure Religion vervollkommnet und Meine Gnade an euch vollendet und euch den Islam zum Glauben erwählt. Wer aber durch Hungersnot gezwungen wird, ohne sündhafte Neigung so ist Allah Allverzeihend, Barmherzig.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@dclxxiii{Sie fragen dich, was ihnen erlaubt sei. Sprich: ``Alle guten Dinge sind euch erlaubt: und was ihr die Jagdtiere gelehrt habt, indem ihr sie zur Jagd abrichtet und sie lehrt, was Allah euch gelehrt hat." Also esset von dem, was sie für euch fangen, und sprecht Allahs Namen darüber aus. Und fürchtet Allah; denn Allah ist schnell im Abrechnen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@dclxxiv{Heute sind euch alle guten Dinge erlaubt. Und die Speise derer, denen die Schrift gegeben wurde, ist euch erlaubt, wie auch eure Speise ihnen erlaubt ist. Und ehrbare gläubige Frauen und ehrbare Frauen unter den Leuten, denen vor euch die Schrift gegeben wurde, wenn ihr ihnen die Brautgabe gebt, und nur für eine Ehe und nicht für Unzucht und heimliche Liebschaften. Und wer den Glauben verleugnet, dessen Tat ist ohne Zweifel zunichte geworden; und im Jenseits wird er unter den Verlierern sein.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@dclxxv{O ihr, die ihr glaubt! Wenn ihr euch zum Gebet begebt, so wascht euer Gesicht und eure Hände bis zu den Ellenbogen und streicht über euren Kopf und wascht eure Füße bis zu den Knöcheln. Und wenn ihr im Zustande der Unreinheit seid, so reinigt euch. Und wenn ihr krank seid oder euch auf einer Reise befindet oder einer von euch von der Notdurft zurückkommt, oder wenn ihr Frauen berührt habt und kein Wasser findet, so sucht reinen Sand und reibt euch damit Gesicht und Hände ab. Allah will euch nicht mit Schwierigkeiten bedrängen, sondern Er will euch nur reinigen und Seine Gnade an euch erfüllen, auf daß ihr dankbar sein möget\qt@no{(6)}}
\qt@newcmd\qurantrans@de@dclxxvi{und gedenkt der Gnade Allahs gegen euch und des Bundes, den Er mit euch schloß, als ihr spracht: ``Wir hören und gehorchen." Und fürchtet Allah; wahrlich, Allah weiß, was die Herzen verbergen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@dclxxvii{O ihr, die ihr glaubt! Setzt euch für Allah ein und seid Zeugen der Gerechtigkeit. Und der Haß gegen eine Gruppe soll euch nicht (dazu) verleiten, anders als gerecht zu handeln. Seid gerecht, das ist der Gottesfurcht näher. Und fürchtet Allah; wahrlich, Allah ist eures Tuns kundig.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@dclxxviii{Allah hat denen, die glauben und gute Werke tun, verheißen, daß sie Vergebung und großen Lohn erlangen werden.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@dclxxix{Die aber ungläubig sind und Unsere Zeichen verleugnen, werden Insassen der Gahim sein.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@dclxxx{O ihr, die ihr glaubt! Gedenkt der Gnade Allahs über euch, als eine Gruppe die Hände nach euch auszustrecken trachtete. Er aber hielt ihre Hände von euch zurück. Und fürchtet Allah; auf Allah sollen die Gläubigen vertrauen.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@dclxxxi{Wahrlich, Allah hatte einen Bund mit den Kindern Israels geschlossen; und Wir erweckten aus ihnen zwölf Führer. Und Allah sprach: ``Seht, Ich bin mit euch, wenn ihr das Gebet verrichtet und die Zakah entrichtet und an Meine Gesandten glaubt und sie unterstützt und Allah ein gutes Darlehen gebt, dann werde Ich eure Missetaten tilgen und euch in Gärten führen, in denen Bäche fließen. Wer von euch aber hierauf in den Unglauben zurückfällt, der ist vom rechten Weg abgeirrt.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@dclxxxii{Deshalb, weil sie ihren Bund brachen, haben Wir sie verflucht und haben ihre Herzen verhärtet. Sie entstellten die Schrift an ihren richtigen Stellen und sie haben einen Teil von dem vergessen, woran sie gemahnt wurden. Und du wirst nicht aufhören, auf ihrer Seite bis auf einige von ihnen Verrat zu entdecken. Also vergib ihnen und wende dich (von ihnen) ab. Wahrlich, Allah liebt jene, die Gutes tun.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@dclxxxiii{Und auch mit denen, die sagen: ``Wir sind Christen", schlossen Wir einen Bund; auch diese haben dann einen Teil von dem vergessen, woran sie gemahnt wurden. Darum erregten Wir Feindschaft und Haß unter ihnen bis zum Tage der Auferstehung. Und Allah wird sie wissen lassen, was sie getan haben.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@dclxxxiv{O Leute der Schrift, Unser Gesandter ist nunmehr zu euch gekommen, um euch vieles zu enthüllen, was ihr von der Schrift geheim gehalten habt, und (er ist zu euch gekommen,) um gegen vieles Nachsicht zu üben. Wahrlich, zu euch sind ein Licht von Allah und ein klares Buch gekommen.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@dclxxxv{Damit leitet Allah jene, die Sein Wohlgefallen suchen, auf die Wege des Friedens, und Er führt sie mit Seiner Erlaubnis aus den Finsternissen zum Licht und führt sie auf einen geraden Weg.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@dclxxxvi{Wahrlich, ungläubig sind diejenigen, die sagen: ``Allah ist der Messias, der Sohn der Maria." Sprich: ``Wer vermöchte wohl etwas gegen Allah, wenn Er den Messias, den Sohn der Maria, seine Mutter und jene, die allesamt auf der Erde sind, vernichten will?" Allahs ist das Königreich der Himmel und der Erde und dessen, was zwischen beiden ist. Er erschafft, was Er will; und Allah hat Macht über alle Dinge.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@dclxxxvii{Und es sagten die Juden und die Christen: ``Wir sind die Söhne Allahs und seine Lieblinge." Sprich: ``Warum bestraft Er euch dann für eure Sünden? Nein, ihr seid Menschen von denen, die Er schuf." Er vergibt, wem Er will, und Er bestraft, wen Er will. Und Allahs ist das Königreich der Himmel und der Erde und dessen, was zwischen beiden ist, und zu Ihm ist die Heimkehr.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@dclxxxviii{O Leute der Schrift, zu euch ist nunmehr Unser Gesandter nach einer Zeitspanne zwischen den Gesandten gekommen, um euch aufzuklären, damit ihr nicht sagen könnt: ``Kein Bringer froher Botschaft und kein Warner ist zu uns gekommen." So ist nun in Wahrheit ein Bringer froher Botschaft und ein Warner zu euch gekommen. Und Allah hat Macht über alle Dinge.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@dclxxxix{Und (damals) als Moses zu seinem Volke sagte: ``O mein Volk, besinnt euch auf Allahs Huld gegen euch, als Er aus eurer Mitte Propheten erweckte und euch zu Königen machte und euch gab, was Er keinem anderen auf der Welt gegeben hat.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@dcxc{O mein Volk, betretet das heilige Land, das Allah für euch bestimmt hat, und kehret (ihm) nicht den Rücken; denn dann werdet ihr als Verlorene umkehren."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@dcxci{Sie sagten: ``O Moses, siehe, dort lebt ein tyrannisches Volk, und wir werden es (das Land) nicht betreten, ehe jene es nicht verlassen haben. Doch wenn sie es verlassen, dann wollen wir dort einziehen."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@dcxcii{Es sagten zwei Männer von denen, die gottesfürchtig waren, und denen Allah Seine Gnade erwiesen hatte: ``Zieht durch das Tor ein und wendet euch gegen sie; seid ihr eingezogen, dann werdet ihr siegreich sein. Und vertraut auf Allah, wenn ihr Gläubige seid."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@dcxciii{Sie sagten: ``O Moses, nimmermehr werden wir es betreten, solange jene dort sind. Gehe denn du mit deinem Herrn und kämpft; wir bleiben hier sitzen."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@dcxciv{Er sagte: ``Ich habe nur Macht über mich selbst und meinen Bruder; darum scheide Du uns von dem aufrührerischen Volk."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@dcxcv{Er sprach: ``Wahrlich, es (das Land) soll ihnen vierzig Jahre lang verwehrt sein; sie sollen auf der Erde umherirren. Und betrübe dich nicht wegen des aufrührerischen Volkes."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@dcxcvi{Und verlies ihnen in Wahrheit die Geschichte von den zwei Söhnen Adams, als sie beide ein Opfer darbrachten, und es von dem einen angenommen und von dem anderen nicht angenommen wurde. Da sagte dieser: ``Wahrhaftig, ich schlage dich tot." Jener erwiderte: ``Allah nimmt nur von den Gottesfürchtigen (Opfer) an.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@dcxcvii{Wenn du auch deine Hand nach mir ausstreckst, um mich zu erschlagen, so werde ich doch nicht meine Hand nach dir ausstrecken, um dich zu erschlagen. Ich fürchte Allah, den Herrn der Welten.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@dcxcviii{Ich will, daß du die Last meiner Sünde und deiner Sünde trägst und so unter den Bewohnern des Feuers bist, und dies ist der Lohn der Frevler."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@dcxcix{Doch er erlag dem Trieb, seinen Bruder zu töten; also erschlug er ihn und wurde einer von den Verlierern.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@dcc{Da sandte Allah einen Raben, der auf dem Boden scharrte, um ihm zu zeigen, wie er den Leichnam seines Bruders verbergen könne. Er sagte: ``Wehe mir! Bin ich nicht einmal imstande, wie dieser Rabe zu sein und den Leichnam meines Bruders zu verbergen?" Und da wurde er reumütig.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@dcci{Deshalb haben Wir den Kindern Israels verordnet, daß, wenn jemand einen Menschen tötet, ohne daß dieser einen Mord begangen hätte, oder ohne daß ein Unheil im Lande geschehen wäre, es so sein soll, als hätte er die ganze Menschheit getötet; und wenn jemand einem Menschen das Leben erhält, es so sein soll, als hätte er der ganzen Menschheit das Leben erhalten. Und Unsere Gesandten kamen mit deutlichen Zeichen zu ihnen; dennoch, selbst danach begingen viele von ihnen Ausschreitungen im Land.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@dccii{Der Lohn derer, die gegen Allah und Seinen Gesandten Krieg führen und Verderben im Lande zu erregen trachten, soll sein, daß sie getötet oder gekreuzigt werden oder daß ihnen Hände und Füße wechselweise abgeschlagen werden oder daß sie aus dem Lande vertrieben werden. Das wird für sie eine Schmach in dieser Welt sein, und im Jenseits wird ihnen eine schwere Strafe zuteil.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@dcciii{Ausgenommen davon sind jene, die bereuen, noch ehe ihr sie in eurer Gewalt habt. So wisset, daß Allah Allvergebend, Barmherzig ist.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@dcciv{O ihr, die ihr glaubt, fürchtet Allah und trachtet danach, Ihm nahezukommen und kämpft auf Seinem Wege, auf daß ihr Erfolg haben möget.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@dccv{Wahrlich, die Ungläubigen hätten sie auch alles, was auf der Erde ist, und dann nochmal so viel, um sich damit am Tage der Auferstehung von der Strafe loszukaufen es würde doch nicht von ihnen angenommen werden; und ihnen wird eine schmerzliche Strafe zuteil sein.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@dccvi{Sie wollen dem Feuer entrinnen, doch sie werden nicht daraus entrinnen können, und ihre Pein wird immerwährend sein.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@dccvii{Dem Dieb und der Diebin schneidet ihr die Hände ab, als Vergeltung für das, was sie begangen haben, und als abschreckende Strafe von Allah. Und Allah ist Allmächtig, Allweise.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@dccviii{Aber wer es bereut nach seiner Freveltat und sich bessert, von dem wird Allah die Reue annehmen; denn Allah ist Allvergebend, Barmherzig.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@dccix{Hast du nicht gewußt, daß Allah es ist, Dem das Königreich der Himmel und der Erde gehört? Er bestraft, wen Er will, und Er vergibt, wem Er will; und Allah hat Macht über alle Dinge.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@dccx{O du Gesandter, es sollen dich nicht jene betrüben, die hastig dem Unglauben verfallen, die mit dem Munde sagen: ``Wir glauben", jedoch im Herzen nicht glauben. Und unter den Juden sind solche, die auf jede Lüge hören; sie hören auf andere, die noch nicht zu dir gekommen sind. Sie rücken die Worte von ihren richtigen Stellen ab und sagen: ``Wenn euch dies (, was wir gutheißen wollen,) vorgebracht wird, so nehmt es an, doch wenn es euch nicht vorgebracht wird, dann seid auf der Hut!" Und wen Allah in Versuchung führen will dem wirst du mit keiner Macht gegen Allah helfen können. Das sind die, deren Herzen Allah nicht reinigen wollte; für sie ist in dieser Welt Schande, und im Jenseits wird ihnen eine große Strafe zuteil sein.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@dccxi{Sie sind notorische Lauscher hinsichtlich der Falschheit, Verschlinger von Unerlaubtem. Wenn sie nun zu dir kommen, so richte zwischen ihnen oder wende dich von ihnen ab. Und wenn du dich von ihnen abwendest, so können sie dir keinerlei Schaden zufügen; richtest du aber, so richte zwischen ihnen in Gerechtigkeit. Wahrlich, Allah liebt die Gerechten.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@dccxii{Wie aber wollen sie dich zum Richter berufen, während sie doch die Thora in ihrem Besitz haben, worin Allahs Richtspruch ist? Hierauf und trotz alledem, kehren sie (Ihm) den Rücken; und sie sind nicht als Gläubige zu bezeichnen.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@dccxiii{Wahrlich, Wir hatten die Thora, in der Führung und Licht war, hinabgesandt. Damit haben die Propheten, die sich (Allah) hingaben, den Juden Recht gesprochen, und so auch die Rabbiner und die Gelehrten; denn ihnen wurde aufgetragen, das Buch Allahs zu bewahren, und sie waren seine Hüter. Darum fürchtet nicht die Menschen, sondern fürchtet Mich; und gebt nicht Meine Zeichen um einen geringen Preis hin. Und wer nicht nach dem richtet, was Allah hinabgesandt hat das sind die Ungläubigen.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@dccxiv{Wir hatten ihnen darin vorgeschrieben: Leben um Leben, Auge um Auge, Nase um Nase, Ohr um Ohr und Zahn um Zahn; und für Verwundungen gerechte Vergeltung. Wer aber darauf verzichtet, dem soll das eine Sühne sein; und wer nicht nach dem richtet, was Allah hinabgesandt hat das sind die Ungerechten.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@dccxv{Wir ließen ihnen Jesus, den Sohn der Maria, folgen; zur Bestätigung dessen, was vor ihm in der Thora war; und Wir gaben ihm das Evangelium, worin Rechtleitung und Licht war, zur Bestätigung dessen, was vor ihm in der Thora war und als Rechtleitung und Ermahnung für die Gottesfürchtigen.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@dccxvi{Und die Leute des Evangeliums sollen sich nach dem richten, was Allah darin offenbart hat; und die sich nicht nach dem richten, was Allah herabgesandt hat das sind die (wahren) Frevler.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@dccxvii{Und Wir haben das Buch mit der Wahrheit zu dir herabgesandt, das bestätigt, was von der Schrift vor ihm da war und darüber Gewißheit gibt; richte also zwischen ihnen nach dem, was Allah herabgesandt hat und folge nicht ihren Neigungen, von der Wahrheit abzuweichen, die zu dir gekommen ist. Für jeden von euch haben Wir Richtlinien und eine Laufbahn bestimmt. Und wenn Allah gewollt hätte, hätte Er euch zu einer einzigen Gemeinde gemacht. Er wollte euch aber in alledem, was Er euch gegeben hat, auf die Probe stellen. Darum sollt ihr um die guten Dinge wetteifern. Zu Allah werdet ihr allesamt zurückkehren; und dann wird Er euch das kundtun, worüber ihr uneins waret.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@dccxviii{Und du sollst zwischen ihnen nach dem richten, was von Allah herabgesandt wurde; und folge nicht ihren Neigungen, und sei vor ihnen auf der Hut, damit sie dich nicht bedrängen und von einem Teil dessen, was Allah zu dir herabgesandt hat, wegtreiben. Wenden sie sich jedoch (von dir) ab, so wisse, daß Allah sie für etliche ihrer Sünden zu treffen gedenkt. Wahrlich, viele der Menschen sind Frevler.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@dccxix{Wünschen sie etwa die Richtlinien der Gahiliya? Und wer ist ein besserer Richter als Allah für ein Volk, das fest im Glauben ist?\qt@no{(50)}}
\qt@newcmd\qurantrans@de@dccxx{O ihr, die ihr glaubt! Nehmt nicht die Juden und die Christen zu Beschützern. Sie sind einander Beschützer. Und wer sie von euch zu Beschützern nimmt, der gehört wahrlich zu ihnen. Wahrlich, Allah weist nicht dem Volk der Ungerechten den Weg.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@dccxxi{Und du wirst jene sehen, deren Herzen von Krankheit befallen sind, (und) zu ihnen hineilen; sie sagen: ``Wir fürchten, es könnte uns ein Unglück befallen." Möge Allah den Sieg oder sonst ein Ereignis herbeiführen. Dann werden sie bereuen, was sie in ihren Herzen verbargen.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@dccxxii{Und die Gläubigen werden sagen: ``Sind das etwa jene, die mit ihren feierlichsten Eiden bei Allah schworen, daß sie unverbrüchlich zu euch stünden?" Eitel sind ihre Werke, und sie sind zu Verlierern geworden.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@dccxxiii{O ihr, die ihr glaubt, wer sich von euch von seinem Glauben abkehrt, wisset, Allah wird bald ein anderes Volk bringen, das Er liebt und das Ihn liebt, (das) demütig gegen die Gläubigen und hart gegen die Ungläubigen (ist); sie werden auf Allahs Weg kämpfen und werden den Vorwurf des Tadelnden nicht fürchten. Das ist Allahs Huld; Er gewährt sie, wem Er will; denn Allah ist Allumfassend, Allwissend.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@dccxxiv{Eure Beschützer sind wahrlich Allah und Sein Gesandter und die Gläubigen, die das Gebet verrichten, die Zakah entrichten und sich (vor Allah) verneigen.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@dccxxv{Und wer Allah und Seinen Gesandten und die Gläubigen zu Beschützern nimmt, der wisse, daß Allahs Schar ist es, die siegreich sein wird.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@dccxxvi{O ihr, die ihr glaubt, nehmt euch nicht die zu Beschützern von jenen, denen vor euch die Schrift gegeben wurde, und von den Ungläubigen, die mit eurem Glauben Spott und Scherz treiben und fürchtet Allah, wenn ihr Gläubige seid.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@dccxxvii{Und wenn ihr zum Gebet ruft, treiben sie damit ihren Spott und Scherz. Dies (ist so), weil sie Leute sind, die es nicht begreifen.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@dccxxviii{Sprich: ``O Leute der Schrift, ihr grollt uns nur deswegen, weil wir an Allah und an das glauben, was zu uns herabgesandt und was schon vorher herabgesandt wurde, und weil die meisten von euch Frevler sind."\qt@no{(59)}}
\qt@newcmd\qurantrans@de@dccxxix{Sprich: ``Soll ich euch über die belehren, deren Lohn bei Allah noch schlimmer ist als das? Es sind, die Allah verflucht hat und denen Er zürnt und aus denen Er Affen, Schweine und Götzendiener gemacht hat. Diese befinden sich in einer noch schlimmeren Lage und sind noch weiter vom rechten Weg abgeirrt."\qt@no{(60)}}
\qt@newcmd\qurantrans@de@dccxxx{Und wenn sie zu euch kommen, sagen sie: ``Wir glauben", während sie doch mit Unglauben eintreten und in diesem fortgehen; und Allah weiß am besten, was sie verborgen halten.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@dccxxxi{Und du siehst, wie viele von ihnen in Sünde und Übertretung und im Verzehr verbotener Dinge wetteifern. Übel ist wahrlich, was sie getan haben.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@dccxxxii{Warum untersagen ihnen die Rabbiner und die Schriftgelehrten nicht ihre sündige Rede und ihren Verzehr von Verbotenem? Übel ist wahrlich, was sie getrieben haben.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@dccxxxiii{Und die Juden sagen: ``Die Hand Allahs ist gefesselt." Ihre Hände sollen gefesselt sein, und sie sollen verflucht sein um dessentwillen, was sie da sprechen. Nein, Seine Hände sind weit offen; Er spendet, wie Er will. Und was auf dich von Deinem Herrn herabgesandt wurde, wird gewiß viele von ihnen in ihrem Aufruhr und Unglauben noch bestärken. Und Wir haben unter ihnen Haß und Zwietracht bis zum Tage der Auferstehung gesät. Sooft sie ein Feuer für den Krieg anzündeten, löschte Allah es aus, und sie trachteten nur nach Unheil auf Erden; und Allah liebt nicht die Unheilstifter.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@dccxxxiv{Wenn die Leute der Schrift geglaubt hätten und gottesfürchtig gewesen wären, hätten Wir gewiß ihre Übel von ihnen hinweggenommen und Wir hätten sie gewiß in die Gärten der Wonne geführt.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@dccxxxv{Und hätten sie die Thora befolgt und das Evangelium und das, was zu ihnen von ihrem Herrn hinabgesandt wurde, würden sie sicherlich über sich und zu ihren Füßen Nahrung finden. Es gibt unter ihnen Leute, die Mäßigung üben; doch viele von ihnen verrichten üble Dinge.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@dccxxxvi{O du Gesandter! Verkünde, was zu dir von deinem Herrn hinabgesandt wurde; und wenn du es nicht tust, so hast du Seine Botschaft nicht verkündigt. Und Allah wird dich vor den Menschen schützen. Wahrlich, Allah weist den ungläubigen Leuten nicht den Weg.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@dccxxxvii{Sprich: ``O Leute der Schrift, ihr fußt auf nichts, ehe ihr nicht die Thora und das Evangelium und das in die Tat umsetzt, was von eurem Herrn zu euch herabgesandt wurde." Aber gewiß, das, was von deinem Herrn zu dir hinabgesandt wurde, wird viele von ihnen in ihrem Aufruhr und Unglauben bestärken. Darum betrübe dich nicht über die ungläubigen Leute.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@dccxxxviii{Jene, die geglaubt haben, und die Juden und die Sabäer und die Christen wer an Allah glaubt und gute Werke tut, keine Furcht soll über sie kommen, noch sollen sie traurig sein.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@dccxxxix{Wahrlich, Wir hatten einen Bund mit den Kindern Israels geschlossen und Gesandte zu ihnen geschickt. Sooft aber Gesandte zu ihnen mit etwas kamen, was ihre Herzen nicht begehrten, erklärten sie einige von ihnen für Lügner und brachten andere um.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@dccxl{Und sie dachten, dies würde keine Verwirrung zur Folge haben; so wurden sie blind und taub. Dann wandte Sich Allah ihnen gnädig wieder zu; trotzdem wurden viele von ihnen abermals blind und taub; und Allah sieht wohl, was sie tun.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@dccxli{Wahrlich, ungläubig sind diejenigen, die sagen: ``Allah ist der Messias, der Sohn der Maria", während der Messias doch selbst gesagt hat: ``O ihr Kinder Israels, betet zu Allah, meinem Herrn und eurem Herrn." Wer Allah Götter zur Seite stellt, dem hat Allah das Paradies verwehrt, und das Feuer wird seine Herberge sein. Und die Frevler sollen keine Helfer finden.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@dccxlii{Wahrlich, ungläubig sind diejenigen, die sagen: ``Allah ist der Dritte von dreien"; und es ist kein Gott da außer einem Einzigen Gott. Und wenn sie nicht von dem, was sie sagen, Abstand nehmen, wahrlich, so wird diejenigen unter ihnen, die ungläubig bleiben, eine schmerzliche Strafe ereilen.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@dccxliii{Wollen sie sich denn nicht reumütig Allah wieder zuwenden und Ihn um Verzeihung bitten? Und Allah ist Allverzeihend, Barmherzig.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@dccxliv{Der Messias, der Sohn der Maria, war nur ein Gesandter; gewiß, andere Gesandte sind vor ihm dahingegangen. Und seine Mutter war eine Wahrhaftige; beide pflegten, Speise zu sich zu nehmen. Siehe, wie Wir die Zeichen für sie erklären, und siehe, wie sie sich abwenden.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@dccxlv{Sprich: ``Wollt ihr statt Allah das anbeten, was nicht die Macht hat, euch zu schaden oder zu nützen?" Und Allah allein ist der Allhörende, der Allwissende.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@dccxlvi{Sprich: ``O Leute der Schrift, übertreibt nicht zu Unrecht in eurem Glauben und folgt nicht den bösen Neigungen von Leuten, die schon vordem irregingen und viele irregeführt haben und weit vom rechten Weg abgeirrt sind."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@dccxlvii{Verflucht wurden diejenigen Ungläubigen von den Kindern Israels durch die Zunge Davids und Jesus', des Sohnes der Maria. Dies, weil sie ungehorsam waren und (gegen die Gebote) verstießen.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@dccxlviii{Sie hinderten einander nicht an den Missetaten, die sie begingen. Übel wahrlich war das, was sie zu tun pflegten.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@dccxlix{Du siehst, wie sich viele von ihnen die Ungläubigen zu Beschützern nehmen. Wahrlich, übel ist das, was sie selbst für sich vorausgeschickt haben, so daß Allah ihnen zürnt; und in der Strafe werden sie auf ewig bleiben.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@dccl{Und hätten sie an Allah geglaubt und an den Propheten und an das, was zu ihm herabgesandt wurde, hätten sie sich jene nicht zu Beschützern genommen; aber viele von ihnen sind Frevler.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@dccli{Sicherlich findest du, daß unter allen Menschen die Juden und die Götzendiener die erbittertsten Gegner der Gläubigen sind. Und du wirst zweifellos finden, daß die, welche sagen: ``Wir sind Christen" den Gläubigen am freundlichsten gegenüberstehen. Dies (ist so), weil es unter ihnen Priester und Mönche gibt und weil sie nicht hochmütig sind.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@dcclii{Und wenn sie hören, was zu dem Gesandten herabgesandt worden ist, siehst du ihre Augen von Tränen überfließen ob der Wahrheit, die sie erkannt haben. Sie sagen: ``Unser Herr, wir glauben, so schreibe uns unter die Bezeugenden.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@dccliii{Und weshalb sollten wir nicht an Allah glauben und an die Wahrheit, die zu uns gekommen ist, wo wir innig wünschen, daß unser Herr uns zu den Rechtschaffenen zählen möge?"\qt@no{(84)}}
\qt@newcmd\qurantrans@de@dccliv{Und um dessentwillen, was sie da gesagt haben, wird Allah sie mit Gärten belohnen, durch die Bäche fließen. Darin sollen sie ewig verweilen; und das ist der Lohn derer, die Gutes tun.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@dcclv{Die aber, die nicht glauben und Unsere Zeichen verwerfen, das sind die Insassen der Gahim.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@dcclvi{O ihr, die ihr glaubt, erklärt die guten Dinge, die Allah euch erlaubt hat, nicht für verboten; doch übertretet auch nicht. Denn Allah liebt die Übertreter nicht.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@dcclvii{Und esset von dem, was Allah euch gegeben hat: Erlaubtes, Gutes. Und fürchtet Allah, an Den ihr glaubt.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@dcclviii{Allah wird euch für ein unbedachtes Wort in euren Eiden nicht zur Rechenschaft ziehen, doch Er wird von euch für das Rechenschaft fordern, was ihr mit Bedacht geschworen habt. Die Sühne dafür sei dann die Speisung von zehn Armen in jenem Maß, wie ihr die Eurigen im Durchschnitt speist, oder ihre Bekleidung oder die Befreiung eines Sklaven. Wer es aber nicht kann, dann (soll er) drei Tage fasten. Das ist die Sühne für eure Eide, wenn ihr sie geleistet habt. Und hütet ja eure Eide. So macht euch Allah Seine Zeichen klar, auf daß ihr dankbar sein möget.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@dcclix{O ihr, die ihr glaubt! Berauschendes, Glückspiel, Opfersteine und Lospfeile sind ein Greuel, das Werk des Satans. So meidet sie, auf daß ihr erfolgreich seid\qt@no{(90)}}
\qt@newcmd\qurantrans@de@dcclx{Satan will durch das Berauschende und das Losspiel nur Feindschaft und Haß zwischen euch auslösen, um euch vom Gedenken an Allah und vom Gebet abzuhalten. Werdet ihr euch denn abhalten lassen?\qt@no{(91)}}
\qt@newcmd\qurantrans@de@dcclxi{Und gehorcht Allah und gehorcht dem Gesandten und seid auf der Hut. Kehrt ihr euch jedoch von ihm ab, dann wisset, daß Unserem Gesandten nur die deutliche Verkündigung obliegt.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@dcclxii{Denen, die glauben und gute Werke tun, soll als Sünde nicht angerechnet werden, was sie essen, wenn sie gottesfürchtig sind und glauben und gute Werke tun, und abermals fürchten und glauben, dann nochmals fürchten und Gutes tun. Und Allah liebt jene, die Gutes tun.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@dcclxiii{O ihr, die ihr glaubt! Allah will euch gewiß Prüfungen aussetzen mit dem Wild, das eure Hände und eure Speere erreichen können, so daß Allah die auszeichnen möge, die Ihn im geheimen fürchten. Wer sich darum noch nach diesem vergeht, dem wird eine schmerzliche Strafe zuteil sein.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@dcclxiv{O ihr, die ihr glaubt! Tötet kein Wild, während ihr pilgert. Und (wenn) einer von euch ein Tier vorsätzlich tötet, so ist die Ersatzleistung (dafür) ein gleiches Maß vom Vieh, wie das, was er getötet (hat), nach dem Spruch von zwei Redlichen unter euch, und das soll dann als Opfertier zu der Ka`ba gebracht werden; oder die Sühne sei die Speisung von Armen oder dementsprechendes Fasten, damit er die bösen Folgen seiner Tat koste. Allah vergibt das Vergangene; den aber, der es wieder tut, wird Allah der Vergeltung aussetzen. Und Allah ist Allmächtig und Herr der Vergeltung.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@dcclxv{Der Fang aus dem Meer und sein Genuß sind euch als Versorgung für euch und für die Reisenden erlaubt, doch verwehrt ist (euch) das Wild des Landes, solange ihr pilgert. Und fürchtet Allah, vor Dem ihr versammelt werdet.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@dcclxvi{Allah hat die Kaba, das unverletzliche Haus, zu einer Gebetsstätte für die Menschen gemacht, ebenso den heiligen Monat und die Opfertiere und die Tiere mit dem Halsschmuck. Dies, geschah damit ihr wisset, daß Allah weiß, was in den Himmeln und was auf Erden ist, und daß Allah alle Dinge weiß.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@dcclxvii{Wisset, daß Allah streng im Strafen ist und daß Allah Allverzeihend, Barmherzig ist.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@dcclxviii{Dem Gesandten obliegt nur die Verkündigung. Und Allah weiß, was ihr kundtut und was ihr verborgen haltet.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@dcclxix{Sprich: ``Das Schlechte und das Gute sind nicht gleich" obgleich dich auch die Menge des Schlechten in Erstaunen versetzen mag. Darum fürchtet Allah, ihr Verständigen, auf daß ihr erfolgreich sein möget.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@dcclxx{O ihr, die ihr glaubt! Fragt nicht nach Dingen, die, wenn sie euch enthüllt würden, euch unangenehm wären; und wenn ihr danach zur Zeit fragt, da der Quran niedergesandt wird, werden sie euch doch klar. Allah hat euch davon entbunden; und Allah ist Allverzeihend, Nachsichtig.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@dcclxxi{Es haben schon vor euch Leute nach solchem gefragt, doch dann versagten sie ihm den Glauben.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@dcclxxii{Allah hat keinerlei ``Bahira `` oder ``Saiba `` oder ``Wasila `` oder ``Ham `` geboten: vielmehr ersinnen die Ungläubigen eine Lüge gegen Allah, und die meisten von ihnen begreifen es nicht.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@dcclxxiii{Und wenn ihnen gesagt wird: ``Kommt her zu dem, was von Allah herabgesandt wurde, und kommt zu dem Gesandten", sagen sie: ``Uns genügt das, wobei wir unsere Väter vorfanden." Und selbst (dann,) wenn ihre Väter kein Wissen hatten und nicht auf dem rechten Wege waren!\qt@no{(104)}}
\qt@newcmd\qurantrans@de@dcclxxiv{O ihr, die ihr glaubt! Wacht über euch selbst. Wer irregeht, kann euch nicht schaden, wenn ihr nur selbst auf dem rechten Wege seid. Zu Allah ist euer aller Heimkehr; dann wird Er euch enthüllen, was ihr zu tun pflegtet.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@dcclxxv{O ihr, die ihr glaubt! Wenn der Tod an einen von euch herantritt, liegt die Zeugenschaft zum Zeitpunkt der Testamentseröffnung bei euch: (bei) zwei Redlichen unter euch, oder zwei anderen, die nicht zu euch gehören, wenn ihr gerade im Land herumreist und euch das Unglück des Todes trifft. Ihr sollt sie beide nach dem Gebet zurückhalten; und wenn ihr zweifelt, so sollen sie beide bei Allah schwören: ``Wir erstehen damit keinen Gewinn, handelte es sich auch um einen nahen Verwandten, und wir verhehlen das Zeugnis Allahs nicht; wahrlich, wir wären sonst Sünder."\qt@no{(106)}}
\qt@newcmd\qurantrans@de@dcclxxvi{Wenn es aber bekannt wird, daß die beiden (Zeugen) sich der Sünde schuldig gemacht haben, dann sollen an ihre Stelle zwei andere aus der Zahl derer treten, gegen welche die beiden ausgesagt haben, und die beiden (späteren Zeugen) sollen bei Allah schwören: ``Wahrlich, unser Zeugnis ist wahrhaftiger als das Zeugnis der beiden (früheren), wahrlich, wir gehörten sonst zu den Ungerechten."\qt@no{(107)}}
\qt@newcmd\qurantrans@de@dcclxxvii{So geschieht es eher, daß sie ein wahres Zeugnis ablegen oder daß sie fürchten, es könnten andere Eide nach ihrem Eide gefordert werden. Und fürchtet Allah und hört! Denn Allah weist nicht den ungehorsamen Leuten den Weg.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@dcclxxviii{Am Tage, an dem Allah die Gesandten versammelt und spricht: ``Welche Antwort empfingt ihr?" sagen sie: ``Wir haben kein Wissen, Du allein bist der Allwissende des Verborgenen."\qt@no{(109)}}
\qt@newcmd\qurantrans@de@dcclxxix{Wenn Allah sagen wird: ``O Jesus, Sohn der Maria, gedenke Meiner Gnade gegen dich und gegen deine Mutter; wie Ich dich stärkte mit der heiligen Eingebung du sprachst zu den Menschen sowohl in der Wiege als auch im Mannesalter; und wie Ich dich die Schrift und die Weisheit lehrte und die Thora und das Evangelium; und wie du mit Meiner Erlaubnis aus Ton bildetest, was wie Vögel aussah, du hauchtest ihm dann (Atem) ein, und es wurde mit Meiner Erlaubnis zu (wirklichen) Vögeln; und wie du mit Meiner Erlaubnis die Blinden und die Aussätzigen heiltest; und wie du mit Meiner Erlaubnis die Toten erwecktest; und wie Ich die Kinder Israels von dir abhielt als du zu ihnen mit deutlichen Zeichen kamst und die Ungläubigen unter ihnen aber sagten: ``Das ist nichts als offenkundige Zauberei.""\qt@no{(110)}}
\qt@newcmd\qurantrans@de@dcclxxx{Und als Ich den Jüngern eingab, an Mich und an Meinen Gesandten zu glauben, da sagten sie: ``Wir glauben, und sei Zeuge, daß wir (Dir) ergeben sind."\qt@no{(111)}}
\qt@newcmd\qurantrans@de@dcclxxxi{Als die Jünger sagten: ``O Jesus Sohn der Maria, ist dein Herr imstande, uns einen Tisch (mit Speisen) vom Himmel herabzusenden?" sagte er: ``Fürchtet Allah, wenn ihr Gläubige seid."\qt@no{(112)}}
\qt@newcmd\qurantrans@de@dcclxxxii{Sie sagten: ``Wir wollen davon essen, und unsere Herzen sollen beruhigt sein, und wir wollen wissen, daß du in Wahrheit zu uns gesprochen hast, und wollen selbst dafür Zeugnis ablegen."\qt@no{(113)}}
\qt@newcmd\qurantrans@de@dcclxxxiii{Da sagte Jesus, der Sohn der Maria: ``O Allah, unser Herr, sende uns einen Tisch (mit Speise) vom Himmel herab, daß er ein Fest für uns sei, für den Ersten von uns und für den Letzten von uns, und ein Zeichen von Dir; und versorge uns; denn Du bist der beste Versorger."\qt@no{(114)}}
\qt@newcmd\qurantrans@de@dcclxxxiv{Allah sprach: ``Siehe, Ich will ihn (den Tisch) zu euch niedersenden; wer von euch aber danach ungläubig wird, über den werde Ich eine Strafe verhängen, mit welcher Ich keinen anderen auf der Welt bestrafen werde."\qt@no{(115)}}
\qt@newcmd\qurantrans@de@dcclxxxv{Und wenn Allah sprechen wird: ``O Jesus, Sohn der Maria, hast du zu den Menschen gesagt: ``Nehmt mich und meine Mutter als zwei Götter neben Allah?" wird er antworten: ``Gepriesen seist Du. Nie könnte ich das sagen, wozu ich kein Recht hatte. Hätte ich es gesagt, würdest Du es sicherlich wissen. Du weißt, was in meiner Seele ist, aber ich weiß nicht, was Du in Dir hegst. Du allein bist der Allwissende des Verborgenen.\qt@no{(116)}}
\qt@newcmd\qurantrans@de@dcclxxxvi{Nichts anderes sagte ich zu ihnen, als das, was Du mich geheißen hattest: ``Betet Allah an, meinen Herrn und euren Herrn." Und ich war ihr Zeuge, solange ich unter ihnen weilte, doch nachdem Du mich abberufen hattest, bist Du ihr Wächter gewesen; und Du bist der Zeuge aller Dinge.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@dcclxxxvii{Wenn Du sie bestrafst, sind sie Deine Diener, und wenn Du ihnen verzeihst, bist Du wahrlich der Allmächtige, der Allweise."\qt@no{(118)}}
\qt@newcmd\qurantrans@de@dcclxxxviii{Allah wird sprechen: ``Das ist ein Tag, an dem den Wahrhaftigen ihre Wahrhaftigkeit nützen soll. Für sie gibt es Gärten, durch welche Bäche fließen; darin sollen sie verweilen auf ewig und immerdar. Allah hat an ihnen Wohlgefallen, und sie haben Wohlgefallen an Ihm; das ist die große Glückseligkeit."\qt@no{(119)}}
\qt@newcmd\qurantrans@de@dcclxxxix{Allahs ist das Königreich der Himmel und der Erde und dessen, was zwischen ihnen ist; und Er hat Macht über alle Dinge.\qt@no{(120)}}
\qt@newcmd\qurantrans@de@dccxc{\basmalahde Alles Lob gebührt Allah, Der Himmel und Erde erschaffen und die Finsternisse und das Licht gemacht hat; doch setzen jene, die da ungläubig sind, ihrem Herrn anderes gleich.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@dccxci{Er ist es, Der euch aus Lehm erschaffen hat, und dann bestimmte Er (euch) eine (Lebens-) Frist. Und eine weitere Frist ist Ihm bekannt. Ihr aber zweifelt noch!\qt@no{(2)}}
\qt@newcmd\qurantrans@de@dccxcii{Und Er ist Allah, (der Gott) in den Himmeln wie auch auf der Erde. Er kennt euer Verborgenes und euer Verlautbartes, und Er weiß, was ihr begeht.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@dccxciii{Es kommt zu ihnen auch nicht ein Zeichen von den Zeichen ihres Herrn, ohne daß sie sich davon abwenden.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@dccxciv{So haben sie die Wahrheit für Lüge erklärt, als sie zu ihnen kam; bald aber soll ihnen von dem Kunde gegeben werden, was sie verspotteten.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@dccxcv{Sehen sie denn nicht, wie so manches Geschlecht Wir schon vor ihnen vernichtet haben? Diesen hatten Wir auf der Erde Macht gegeben, wie Wir sie euch nicht gegeben haben; und ihnen sandten Wir vom Himmel reichlich Regen; und unter ihnen ließen wir Bäche fließen; dann aber tilgten Wir sie um ihrer Sünden willen aus und erweckten nach ihnen ein anderes Geschlecht.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@dccxcvi{Wenn Wir dir auch eine Schrift auf einem Blatt Papier hinabgesandt hätten, welche sie mit Händen angefaßt hätten, die Ungläubigen hätten selbst dann gesagt: ``Das ist nichts als offenkundige Zauberei."\qt@no{(7)}}
\qt@newcmd\qurantrans@de@dccxcvii{Und sie sagen: ``Wäre ein Engel zu ihm herabgesandt worden!" Hätten Wir aber einen Engel herabgesandt, wäre die Sache entschieden gewesen; dann hätten sie keinen Aufschub erlangt.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@dccxcviii{Und wenn Wir ihn zu einem Engel gemacht hätten, hätten Wir ihn doch als Menschen erscheinen lassen, und so hätten Wir ihnen das noch mehr verwirrt, was sie selbst schon verwirrt.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@dccxcix{Schon vor dir wurden Gesandte verspottet, doch das, worüber sie spotteten, erfaßte die Spötter unter ihnen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@dccc{Sprich: ``Wandert im Lande umher und seht, wie das Ende der Verleugner war."\qt@no{(11)}}
\qt@newcmd\qurantrans@de@dccci{Sprich: ``Wem gehört das, was in den Himmeln und was auf Erden ist?" Sprich: ``Allah." Er hat Sich Selbst Barmherzigkeit vorgeschrieben. Er wird euch gewiß weiter versammeln bis zum Tage der Auferstehung. Darüber besteht kein Zweifel. Jene aber, die ihrer selbst verlustig gegangen sind, glauben es nicht.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@dcccii{Ihm gehört das, was in der Nacht und am Tage ruht. Und Er ist der Allhörende, Allwissende.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@dccciii{Sprich: ``Sollte ich einen anderen zum Beschützer nehmen als Allah, den Schöpfer der Himmel und der Erde, Der Nahrung gibt und Selbst keine Nahrung nimmt?" Sprich: ``Mir wurde geboten, daß ich der Erste sei, der sich ergebe." Und sei nicht einer der Götzendiener.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@dccciv{Sprich: ``Ich fürchte die Strafe eines gewaltigen Tages, sollte ich meinem Herrn ungehorsam sein."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@dcccv{Wer an jenem Tage davor bewahrt bleibt, dem hat Er Barmherzigkeit erwiesen. Das ist ein offenbarer Erfolg.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@dcccvi{Und wenn Allah dir Schaden zufügt, so kann ihn keiner als Er hinwegnehmen; und wenn Er dir Gutes beschert, so hat er die Macht, alles zu tun, was Er will.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@dcccvii{Er ist Der, Der über Seine Diener Macht ausübt, und Er ist Allweise, Der wohl unterrichtet ist.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@dcccviii{Sprich: ``Was für ein Zeugnis wiegt schwerer?" Sprich: ``Allah ist mein und euer Zeuge. Und dieser Quran ist mir offenbart worden, auf daß ich euch damit warne und jeden, den er erreicht. Wolltet ihr wirklich bezeugen, daß es neben Allah andere Götter gebe?" Sprich: ``Ich bezeuge es nicht." Sprich: ``Er ist der Einzige Gott, und ich bin wahrlich fern von dem, was ihr anbetet."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@dcccix{Sie, denen wir das Buch gaben, erkennen es, wie sie ihre Söhne erkennen. Jene aber, die ihrer selbst verlustig gegangen sind, glauben es nicht.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@dcccx{Und wer ist ungerechter als der, der eine Lüge gegen Allah ersinnt oder Seine Verse für Lüge erklärt? Wahrlich, die Ungerechten erlangen keinen Erfolg.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@dcccxi{Und am Tage, an dem Wir sie alle versammeln werden, werden Wir zu denen, die Götzen anbeten, sprechen: ``Wo sind nun eure Götter, die ihr wähntet?"\qt@no{(22)}}
\qt@newcmd\qurantrans@de@dcccxii{Dann werden sie keine andere Ausrede haben als zu sagen: ``Bei Allah unserem Herrn, wir waren keine Götzendiener."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@dcccxiii{Schau wie sie sich selbst belügen und das, was sie sich ausdachten, sie im Stich läßt.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@dcccxiv{Und unter ihnen sind manche, die dir Gehör schenken, doch Wir haben auf ihre Herzen Hüllen und in ihre Ohren Taubheit gelegt, damit sie nicht begreifen. Selbst wenn sie jedes Zeichen sähen, würden sie nicht daran glauben, so daß sie mit dir stritten, wenn sie zu dir kämen. Die Ungläubigen sagen: ``Das sind bloß Fabeln der Früheren."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@dcccxv{Und sie hindern sich daran und halten sich selbst davon fern. Aber sie stürzen sich selbst ins Verderben; allein, sie begreifen es nicht.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@dcccxvi{Und wenn du nur sehen könntest, wie sie vor das Feuer gestellt werden! Dann werden sie sagen: ``Ach, würden wir doch zurückgebracht! Wir würden dann die Zeichen unseres Herrn nicht für Lüge erklären, und wir würden zu den Gläubigen zählen."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@dcccxvii{Nein, das, was sie ehemals zu verhehlen pflegten, ist ihnen nun klar geworden. Doch wenn sie auch zurückgebracht würden, kehrten sie ganz gewiß bald zu dem ihnen Verbotenen zurück. Und sie sind gewiß Lügner.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@dcccxviii{Und sie sagen: ``Es gibt kein anderes als unser irdisches Leben, und wir werden nicht wiedererweckt werden."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@dcccxix{Aber wenn du nur sehen könntest, wie sie vor ihren Herrn gestellt werden! Er wird sprechen: ``Ist dies nicht die Wahrheit?" Sie werden antworten: ``Ja, bei unserem Herrn." Er wird sprechen: ``Dann kostet die Strafe dafür, daß ihr ungläubig waret."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@dcccxx{Wahrlich, die Verlierer sind diejenigen, die die Begegnung mit Allah leugnen. Wenn aber unversehens die Stunde über sie kommt, werden sie sagen: ``O wehe uns, daß wir sie vernachlässigt haben!" Und sie werden ihre Last auf dem Rücken tragen. Wahrlich, schlimm ist das, was sie tragen werden.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@dcccxxi{Das Leben in dieser Welt ist wahrlich nichts als ein Spiel und Vergnügen. Und wahrlich, die Wohnstätte des Jenseits ist für jene besser, die gottesfürchtig sind. Wollt ihr (das) denn nicht begreifen?\qt@no{(32)}}
\qt@newcmd\qurantrans@de@dcccxxii{Wir wissen wohl, daß dich das betrübt, was sie sagen; denn wahrlich, nicht dich bezichtigen sie der Lüge, sondern es sind die Zeichen Allahs, welche die Ungerechten verwerfen.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@dcccxxiii{Es sind wohl vor dir Gesandte als lügenhaft gescholten worden; doch obgleich sie verleugnet und verfolgt wurden, blieben sie geduldig, bis Unsere Hilfe zu ihnen kam. Es gibt keinen, der die Worte Allahs zu ändern vermag. Wahrlich, von den Gesandten ist die Kunde zu dir gekommen.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@dcccxxiv{Und wenn dir ihr Widerwille schmerzlich ist, nun wohl, falls du imstande bist, einen Schacht in die Erde oder eine Leiter in den Himmel zu finden, um ihnen ein Zeichen zu bringen (dann magst du es tun) Wäre es Allahs Wille, Er hätte sie gewiß auf dem rechten Weg zusammengeführt. So sei nicht einer der Unwissenden.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@dcccxxv{Nur die können (etwas) aufnehmen, die zuhören. Diejenigen aber, die tot sind, wird Allah erwecken; dann sollen sie zu Ihm zurückgebracht werden.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@dcccxxvi{Sie sagen: ``Wäre ihm von seinem Herrn ein Zeichen niedergesandt worden!" Sprich: ``Allah hat die Macht, ein Zeichen herabzusenden, doch die meisten von ihnen wissen es nicht!"\qt@no{(37)}}
\qt@newcmd\qurantrans@de@dcccxxvii{Es gibt kein Getier auf Erden und keinen Vogel, der auf seinen zwei Schwingen dahinfliegt, die nicht Gemeinschaften wären so wie ihr. Nichts haben Wir in dem Buch ausgelassen. Vor ihrem Herrn sollen sie dann versammelt werden.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@dcccxxviii{Die aber Unsere Zeichen leugnen, sind taub und stumm in Finsternissen. Allah führt, wen Er will, in die Irre, und wen Er will, den führt Er auf einen geraden Weg.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@dcccxxix{Sprich: ``Was denkt ihr? Wenn die Strafe Allahs über euch kommt oder die Stunde euch ereilt, werdet ihr dann zu einem anderen rufen als zu Allah, wenn ihr wahrhaftig seid?"\qt@no{(40)}}
\qt@newcmd\qurantrans@de@dcccxxx{Nein, zu Ihm allein werdet ihr rufen; dann wird Er das hinwegnehmen, weshalb ihr (Ihn) anruft, wenn Er will, und ihr werdet vergessen, was ihr (Ihm) zur Seite stelltet.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@dcccxxxi{Wir schickten schon vor dir (Gesandte) zu den Völkern, dann suchten Wir sie mit Not und Drangsal heim, auf daß sie (Mich) anflehen möchten.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@dcccxxxii{Warum demütigten sie sich dann nicht, als Unsere Strafe über sie kam? Jedoch ihre Herzen waren verhärtet, und Satan ließ ihnen alles, was sie taten, als wohlgetan erscheinen.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@dcccxxxiii{Als sie das vergaßen, woran sie erinnert worden waren, da öffneten Wir ihnen die Tore aller Dinge. Als sie sich dann schließlich über das freuten, was sie erhalten hatten, verhängten Wir plötzlich eine Strafe über sie, und siehe, sie wurden in Verzweiflung gestürzt!\qt@no{(44)}}
\qt@newcmd\qurantrans@de@dcccxxxiv{So wurden die Leute ausgerottet, die Frevler waren; und alles Lob gebührt Allah, dem Herrn der Welten.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@dcccxxxv{Sprich: ``Was wähnt ihr? Wenn Allah euer Gehör und euer Gesicht wegnahme und eure Herzen versiegelte, welcher Gott außer Allah könnte euch das wiedergeben?" Schau, wie mannigfach Wir die Zeichen dartun, und dennoch wenden sie sich (davon) ab.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@dcccxxxvi{Sprich: ``Was wähnt ihr? Wenn Allahs Strafe unversehens oder offenkundig über euch kommt, wer anders wird vernichtet werden als die Ungerechten?"\qt@no{(47)}}
\qt@newcmd\qurantrans@de@dcccxxxvii{Wir schicken die Gesandten nur als Bringer froher Botschaft und als Warner. Über die also, die da glauben und sich bessern, soll keine Furcht kommen, noch sollen sie traurig sein.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@dcccxxxviii{Diejenigen aber, die Unsere Zeichen leugnen, wird die Strafe erfassen, weil sie ungehorsam sind.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@dcccxxxix{Sprich: ``Ich sage nicht zu euch: ``Bei mir sind Allahs Schätze", noch kenne ich das Verborgene; auch sage ich nicht zu euch: ``Ich bin ein Engel"; ich folge nur dem, was mir offenbart wurde." Sprich: ``Können wohl ein Blinder und ein Sehender einander gleichen? Wollt ihr denn nicht nachdenken?"\qt@no{(50)}}
\qt@newcmd\qurantrans@de@dcccxl{Und warne hiermit diejenigen, die da fürchten, daß sie vor ihrem Herrn versammelt werden wo sie außer Ihm keinen Beschützer noch Fürsprecher haben werden, auf daß sie doch gottesfürchtig werden mögen.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@dcccxli{Und treibe nicht jene fort, die ihren Herrn am Morgen und am Abend im Trachten nach Seinem Angesicht anrufen. Du bist nicht verantwortlich für sie, und sie sind nicht verantwortlich für dich. Treibst du sie fort, so wirst du einer der Ungerechten.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@dcccxlii{Und so haben Wir einige von ihnen durch andere auf die Probe gestellt, so daß sie sagen mögen: ``Sind es diese, denen Allah aus unserer Mitte huldreich gewesen ist?" Kennt Allah denn die Dankbaren nicht am besten?\qt@no{(53)}}
\qt@newcmd\qurantrans@de@dcccxliii{Und wenn jene, die an Unsere Zeichen glauben, zu dir kommen, so sprich: ``Friede sei auf euch! Euer Herr hat Sich Selbst Barmherzigkeit vorgeschrieben; wenn einer von euch unwissentlich etwas Böses tut und es danach bereut und sich bessert, so ist Er Allvergebend, Barmherzig."\qt@no{(54)}}
\qt@newcmd\qurantrans@de@dcccxliv{So machen Wir die Zeichen klar, auf daß der Weg der Sünder erkannt werde.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@dcccxlv{Sprich: ``Mir ist es verboten worden, daß ich diejenigen anbete, die ihr anruft außer Allah." Sprich: ``Ich folge euren bösen Gelüsten nicht: ich würde sonst wahrlich irregehen und wäre nicht unter den Rechtgeleiteten."\qt@no{(56)}}
\qt@newcmd\qurantrans@de@dcccxlvi{Sprich: ``Ich folge einem klaren Beweis von meinem Herrn, den ihr als Lüge erklärt. Es liegt nicht in meiner Macht (, herbeizuführen), was ihr zu beschleunigen wünscht. Die Entscheidung liegt nur bei Allah. Er legt die Wahrheit dar, und Er ist der beste Richter."\qt@no{(57)}}
\qt@newcmd\qurantrans@de@dcccxlvii{Sprich: ``Läge das in meiner Macht, was ihr zu beschleunigen wünscht, wahrlich, die Sache zwischen mir und euch wäre entschieden." Und Allah kennt die Ungerechten am besten.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@dcccxlviii{Bei Ihm befinden sich die Schlüssel zum Verborgenen; nur Er kennt sie. Und Er weiß, was auf dem Lande ist und was im Meer. Und nicht ein Blatt fällt nieder, ohne daß Er es weiß; und kein Körnchen ist in der Finsternis der Erde und nichts Feuchtes und nichts Trockenes, das nicht in einem deutlichen Buch (verzeichnet) wäre.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@dcccxlix{Und Er ist es, Der eure Seelen in der Nacht abruft und weiß, was ihr am Tage begeht, an dem Er euch dann wieder erweckt, auf daß die vorbestimmte Frist vollendet werde. Zu Ihm werdet ihr dann heimkehren; dann wird Er euch verkünden, was ihr getan habt.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@dcccl{Und Er ist es, der alle Macht über seine Diener hat, und Er sendet über euch Wächter, bis endlich, wenn der Tod an einen von euch herantritt, Unsere Boten seine Seele dahinnehmen; und sie vernachläßigen nichts.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@dcccli{Dann werden sie zu Allah, ihrem Herrn, zurückgebracht. Wahrlich, Sein ist das Urteil, und Er ist der Schnellste im Rechnen.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@dccclii{Sprich: ``Wer errettet euch aus den Fährnissen zu Lande und Meer, wenn ihr Ihn in Demut anruft und insgeheim (denkt): ``Wenn Er uns hieraus errettet, werden wir wahrlich dankbar sein.""\qt@no{(63)}}
\qt@newcmd\qurantrans@de@dcccliii{Sprich: ``Allah errettet euch daraus und aus aller Drangsal, dennoch stellt ihr Ihm Götter zur Seite."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@dcccliv{Sprich: ``Er hat die Macht euch ein Strafgericht zu senden aus der Höhe oder (aus der Tiefe) unter euren Füßen, oder euch als Gruppen zusammenzuführen und die einen der anderen Gewalttat kosten zu lassen." Schau, wie mannigfach Wir die Zeichen dartun, auf daß sie (sie) verstehen mögen.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@dccclv{Und deine Leute haben es für eine Lüge gehalten, obwohl es die Wahrheit ist. Sprich: ``Ich bin nicht euer Wächter."\qt@no{(66)}}
\qt@newcmd\qurantrans@de@dccclvi{Für jede Weissagung ist eine Zeit festgesetzt, und bald werdet ihr es erfahren.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@dccclvii{Wenn du jene siehst, die über Unsere Zeichen töricht reden, dann wende dich ab von ihnen, bis sie zu einem anderen Gespräch übergehen. Und sollte dich Satan (dies) vergessen lassen, dann sitze nach dem Wiedererinnern nicht mit den Ungerechten (beisammen)\qt@no{(68)}}
\qt@newcmd\qurantrans@de@dccclviii{Den Gottesfürchtigen obliegt nicht die Verantwortung für jene, sondern nur das Ermahnen, auf daß jene gottesfürchtig werden mögen.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@dccclix{Und verlaßt jene, die mit ihrem Glauben ein Spiel treiben und ihn als Zerstreuung betrachten, und die vom irdischen Leben betört sind. Und ermahne sie hierdurch, auf daß nicht eine Seele der Verdammnis für das anheimfalle, was sie begangen hat. Keinen Helfer noch Fürsprecher soll sie haben außer Allah; auch wenn sie jegliches Lösegeld bietet, wird es von ihr nicht angenommen. Das sind diejenigen, die für ihre eigenen Taten dem Verderben preisgegeben werden. Ein Trunk siedenden Wassers wird ihr Anteil sein sowie eine schmerzliche Strafe, weil sie ungläubig waren.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@dccclx{Sprich: ``Sollen wir statt Allah das anrufen, was uns weder nützt noch schadet, und sollen wir auf unseren Fersen umkehren, nachdem Allah uns den Weg gewiesen hat, gleich einem, den die Satane verwirrt im Land herumgängeln? (Jedoch) er hat Gefährten, die ihn zum rechten Weg rufen: ``Komm zu uns!"" Sprich: ``Allahs Führung ist die eigentliche Führung, und uns ist befohlen worden, daß wir uns dem Herrn der Welten ergeben sollen."\qt@no{(71)}}
\qt@newcmd\qurantrans@de@dccclxi{Und (uns ist befohlen worden): ``Verrichtet das Gebet und fürchtet Ihn, und Er ist es, vor Dem ihr versammelt werdet."\qt@no{(72)}}
\qt@newcmd\qurantrans@de@dccclxii{Er ist es, Der in Wahrheit die Himmel und die Erde erschuf; und am Tage, da Er spricht: ``Sei!" wird es so sein. Sein Wort ist die Wahrheit, und Sein ist das Reich an dem Tage, da in den Sur gestoßen wird. Kenner des Verborgenen und des Offenkundigen Er ist der Allweise, Der am besten unterrichtet ist.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@dccclxiii{Und als Abraham zu seinem Vater Azar sagte: ``Nimmst du Götzen zu Göttern? Ich sehe dich und dein Volk in einem offenbaren Irrtum"\qt@no{(74)}}
\qt@newcmd\qurantrans@de@dccclxiv{da zeigten Wir Abraham das Reich der Himmel und der Erde, auf daß er zu den Festen im Glauben zählen möge.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@dccclxv{Als ihn nun die Nacht überschattete, da erblickte er einen Stern. Er sagte: ``Das ist mein Herr." Doch da er unterging, sagte er: ``Ich liebe nicht die Untergehenden."\qt@no{(76)}}
\qt@newcmd\qurantrans@de@dccclxvi{Als er den Mond sah, wie er sein Licht ausbreitete, da sagte er: ``Das ist mein Herr." Doch da er unterging, sagte er: ``Wenn mein Herr mich nicht rechtleitet, werde ich gewiß unter den Verirrten sein."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@dccclxvii{Als er die Sonne sah, wie sie ihr Licht ausbreitete, da sagte er: ``Das ist mein Herr, das ist noch größer." Da sie aber unterging, sagte er: ``O mein Volk, ich habe nichts mit dem zu tun, was ihr (Allah) zur Seite stellt.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@dccclxviii{Seht, ich habe mein Angesicht in Aufrichtigkeit zu Dem gewandt, Der die Himmel und die Erde schuf, und ich gehöre nicht zu den Götzendienern."\qt@no{(79)}}
\qt@newcmd\qurantrans@de@dccclxix{Und sein Volk stritt mit ihm. Da sagte er: ``Streitet ihr mit mir über Allah, da Er mich schon recht geleitet hat? Und ich fürchte nicht das, was ihr Ihm zur Seite stellt, sondern nur das, was mein Herr will. Mein Herr umfaßt alle Dinge mit Wissen. Wollt ihr euch denn nicht ermahnen lassen?\qt@no{(80)}}
\qt@newcmd\qurantrans@de@dccclxx{Und wie sollte ich das fürchten, was ihr (Allah) zur Seite stellt, wenn ihr nicht fürchtet, Allah etwas zur Seite zu stellen, wozu Er euch keine Vollmacht niedersandte?" Welche der beiden Parteien hat also ein größeres Anrecht auf Sicherheit, wenn ihr es wissen würdet?\qt@no{(81)}}
\qt@newcmd\qurantrans@de@dccclxxi{Die da glauben und ihren Glauben nicht mit Ungerechtigkeiten vermengen sie sind es, die Sicherheit haben und die rechtgeleitet werden.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@dccclxxii{Das ist Unser Beweis, den Wir Abraham seinem Volk gegenüber gaben. Wir erheben im Rang, wen Wir wollen. Wahrlich, dein Herr ist Allweise, Allwissend.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@dccclxxiii{Und Wir schenkten ihm Isaak und Jakob; jeden leiteten Wir recht, wie Wir vordem Noah rechtgeleitet hatten und von seinen Nachkommen David, Salomo, Hiob, Joseph, Moses und Aaron. So belohnen Wir diejenigen, die Gutes tun.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@dccclxxiv{Und (Wir leiteten) Zacharias, Johannes, Jesus und Elias; sie alle gehörten zu den Rechtschaffenen.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@dccclxxv{Und (Wir leiteten) Ismael, Elisa, Jonas und Lot; und jeden (von ihnen) zeichneten Wir unter den Völkern aus\qt@no{(86)}}
\qt@newcmd\qurantrans@de@dccclxxvi{ebenso manche von ihren Vätern und ihren Nachkommen und ihren Brüdern: Wir erwählten sie und leiteten sie auf den geraden Weg.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@dccclxxvii{Das ist die Rechtleitung Allahs; damit leitet Er von Seinen Dienern, wen Er will. Hätten sie aber (etwas) anderes angebetet, wahrlich, all ihr Tun wäre für sie fruchtlos geblieben.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@dccclxxviii{Diese sind es, denen Wir die Schrift gaben und die Weisheit und das Prophetentum. Wenn diese das aber leugnen, so vertrauen Wir es einem Volke an, das es nicht leugnet.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@dccclxxix{Das sind jene, die Allah rechtgeleitet hat: so folge ihrer Rechtleitung. Sprich: ``Ich verlange von euch dafür keinen Lohn. Es ist ja nichts anderes als eine Ermahnung für die Welten."\qt@no{(90)}}
\qt@newcmd\qurantrans@de@dccclxxx{Sie haben Allah nicht richtig nach Seinem Wert eingeschätzt, wenn sie sagen: ``Allah hat keinem Menschen irgend etwas herabgesandt." Sprich: ``Wer sandte das Buch nieder, das Moses als ein Licht und eine Führung für die Menschen brachte obgleich ihr es zu Papyrusblättern macht, die ihr kundtut, während ihr viel verbergt, und wo euch das gelehrt worden ist, was weder ihr noch eure Väter wußten?" Sprich: ``Allah! `` Dann laß sie sich weiter vergnügen an ihrem eitlen Geschwätz.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@dccclxxxi{Und dies ist ein Buch, das Wir segensreich hinabsandten als Bestätigung dessen, was vor ihm war, auf daß du die Mutter der Städte (Makka) und die rings um sie (Wohnenden) warnen mögest. Diejenigen, die an das Jenseits glauben, glauben daran, und sie halten ihre Gebete regelmäßig ein.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@dccclxxxii{Wer ist ungerechter als derjenige, der eine Lüge gegen Allah erdichtet oder sagt: ``Mir wurde offenbart", während ihm doch nichts offenbart worden war, und der da sagt: ``Ich werde dergleichen hinabsenden, was Allah hinabgesandt hat?" Aber könntest du die Frevler nur in des Todes Schlünden sehen, wenn die Engel ihre Hände ausstrecken: ``Liefert eure Seelen aus! Heute sei euer Lohn die Strafe der Schande als Vergeltung für das, was ihr an Falschem gegen Allah gesprochen habt, und weil ihr euch hochmütig von Seinen Zeichen abgewendet habt."\qt@no{(93)}}
\qt@newcmd\qurantrans@de@dccclxxxiii{Und nun kommt ihr einzeln zu Uns, wie Wir euch zuerst erschufen, und habt, was Wir euch bescherten, hinter euch gelassen, und Wir sehen bei euch nicht eure Fürsprecher, von denen ihr wähntet, sie seien Teilhaber an euren Sachen. Nun seid ihr voneinander abgeschnitten und das, was ihr wähntet, ist euch dahingeschwunden.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@dccclxxxiv{Wahrlich, Allah ist es, Der das Korn und die Kerne keimen läßt. Er bringt das Lebendige aus dem Toten hervor, und Er ist der Hervorbringer des Toten aus dem Lebendigen. Das ist Allah; warum lasset ihr euch dann (von Ihm) abwenden?\qt@no{(95)}}
\qt@newcmd\qurantrans@de@dccclxxxv{Er läßt den Tag anbrechen; und Er macht die Nacht zur Ruhe und Sonne und Mond zur Berechnung (von Tag und Nacht) Das ist die Anordnung des Allmächtigen, des Allwissenden.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@dccclxxxvi{Und Er ist es, Der die Sterne für euch geschaffen hat, auf daß ihr durch sie den Weg in den Finsternissen zu Land und Meer finden möget. Und so haben Wir bis ins einzelne die Zeichen für die Menschen, die Wissen haben, dargelegt.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@dccclxxxvii{Er ist es, Der euch aus einem einzigen Wesen hervorbrachte, alsdann für euch eine Bleibe (im Mutterleib) und einen Aufbewahrungsort (im Grab bestimmte) Wir haben die Zeichen für Leute dargelegt, die es begreifen.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@dccclxxxviii{Und Er ist es, Der aus dem Himmel Wasser niedersendet; damit bringen Wir alle Arten von Pflanzen hervor; mit diesen bringen Wir dann Grünes hervor, woraus Wir Korn in Reihen sprießen lassen; und aus der Dattelpalme, aus ihren Blütendolden, (sprießen) niederhängende Datteltrauben, und Gärten mit Beeren, und Olivenund Granatapfel-(Bäume) einander ähnlich und nicht ähnlich. Betrachtet ihre Frucht, wenn sie Früchte tragen, und ihr Reifen. Wahrlich, hierin sind Zeichen für Leute, die glauben.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@dccclxxxix{Und doch haben sie die Ginn zu Allahs Teilhabern gemacht, obwohl Er sie geschaffen hat; und sie dichten Ihm ohne alles Wissen fälschlicherweise Söhne und Töchter an. Gepriesen sei Er und Erhaben über das, was sie (Ihm) zuschreiben.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@dcccxc{Schöpfer der Himmel und der Erde! Wie sollte Er einen Sohn haben, wo Er keine Gefährtin hat und wo Er alles erschuf und alle Dinge kennt?\qt@no{(101)}}
\qt@newcmd\qurantrans@de@dcccxci{Er ist Allah, euer Herr. Es ist kein Gott außer Ihm, dem Schöpfer aller Dinge; so betet Ihn an. Und Er ist der Hüter aller Dinge.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@dcccxcii{Blicke können Ihn nicht erreichen, Er aber erreicht die Blicke. Und Er ist der Allgütige, der Allkundige.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@dcccxciii{Wahrlich, sichtbare Beweise sind zu euch nunmehr von eurem Herrn gekommen; wenn einer also sieht, so ist es zu seinem eigenen Besten; und wenn einer blind wird, so ist es zu seinem eigenen Schaden. Und ich bin nicht euer Wächter.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@dcccxciv{So legen Wir die Verse dar, damit sie sagen können: ``Du hast geforscht", und damit Wir sie für die Leute, die Wissen haben, klar machen.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@dcccxcv{Folge dem, was dir von deinem Herrn offenbart wurde es ist kein Gott außer Ihm und wende dich von den Götzendienern ab.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@dcccxcvi{Und hätte Allah es gewollt, hätten sie (Ihm) keine Götter zur Seite gesetzt. Wir haben dich weder zu ihrem Hüter gemacht, noch bist du ihr Wächter.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@dcccxcvii{Und schmäht die nicht, welche sie statt Allah anrufen, sonst würden sie aus Groll ohne Wissen Allah schmähen. Also lassen Wir jedem Volke sein Tun als wohlgefällig erscheinen. Dann aber werden sie zu ihrem Herrn heimkehren; und Er wird ihnen verkünden, was sie getan haben.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@dcccxcviii{Und sie haben bei Allah hoch und heilig geschworen, wenn zu ihnen nur ein Zeichen käme, würden sie sicherlich daran glauben. Sprich: ``Über die Zeichen verfügt Allah. Und was gibt euch die Sicherheit, daß sie glauben, wenn sie kommen?"\qt@no{(109)}}
\qt@newcmd\qurantrans@de@dcccxcix{Und Wir werden ihre Herzen und ihre Augen verwirren, weil sie ja auch das erste Mal nicht daran glaubten, und Wir lassen sie sodann in ihrer Widerspenstigkeit verblendet irregehen.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@cm{Und sendeten Wir auch Engel zu ihnen herab, und sprächen die Toten zu ihnen, und versammelten Wir alle Dinge ihnen gegenüber, sie würden doch nicht glauben, es sei denn, Allah wollte es. Jedoch die meisten von ihnen sind unwissend.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@cmi{Und so hatten Wir für jeden Propheten Feinde bestimmt: die Satane der Menschen und der Ginn. Sie geben einander zum Trug prunkende Rede ein und hätte es dein Herr gewollt, hätten sie es nicht getan; so überlaß sie sich selbst mit dem, was sie erdichten.\qt@no{(112)}}
\qt@newcmd\qurantrans@de@cmii{Und damit die Herzen derer, die nicht an das Jenseits glauben, sich demselben zuneigen und an diesem Gefallen finden und (fortfahren) mögen zu verdienen, was sie sich nun erwerben.\qt@no{(113)}}
\qt@newcmd\qurantrans@de@cmiii{Soll ich denn einen anderen Richter suchen als Allah und Er ist es, Der euch das Buch klar gemacht und herabgesandt hat? Und jene, denen Wir das Buch gegeben haben, wissen, daß es von deinem Herrn mit der Wahrheit herabgesandt wurde, deshalb solltest du nicht unter den Bestreitern sein.\qt@no{(114)}}
\qt@newcmd\qurantrans@de@cmiv{Und das Wort deines Herrn ist in Wahrheit und Gerechtigkeit vollendet worden. Keiner vermag Seine Worte zu ändern, und Er ist der Allhörende, der Allwissende.\qt@no{(115)}}
\qt@newcmd\qurantrans@de@cmv{Und wenn du den meisten derer auf der Erde gehorchst, werden sie dich von Allahs Weg irreführen. Sie folgen nur Vermutungen, und sie raten nur\qt@no{(116)}}
\qt@newcmd\qurantrans@de@cmvi{Wahrlich, dein Herr kennt die am besten, die von Seinem Wege abirren; und Er kennt die Rechtgeleiteten am besten.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@cmvii{So esset das, worüber Allahs Name ausgesprochen wurde, wenn ihr an Seine Zeichen glaubt.\qt@no{(118)}}
\qt@newcmd\qurantrans@de@cmviii{Warum solltet ihr denn von dem nicht essen, worüber Allahs Name ausgesprochen wurde, wo Er euch bereits erklärt hat, was Er euch verboten hat das ausgenommen, wozu ihr gezwungen werdet? Und gewiß, viele führen mit ihren Gelüsten durch Mangel an Wissen zum Irrweg. Wahrlich, dein Herr kennt die Übertreter am besten.\qt@no{(119)}}
\qt@newcmd\qurantrans@de@cmix{Und meidet die offenkundige und die geheime Sünde. Jene, die Sünde erwerben, werden den Lohn für ihren Erwerb empfangen.\qt@no{(120)}}
\qt@newcmd\qurantrans@de@cmx{Und esset nicht von dem, worüber Allahs Name nicht ausgesprochen wurde; denn wahrlich, das ist Frevel. Und gewiß werden die Satane ihren Freunden eingeben, mit euch zu streiten. Und wenn ihr ihnen gehorcht, so werdet ihr Götzendiener sein.\qt@no{(121)}}
\qt@newcmd\qurantrans@de@cmxi{Kann wohl einer, der tot war und dem Wir Leben gaben und für den Wir ein Licht machten, um damit unter den Menschen zu wandeln, dem gleich sein, der in Finsternissen ist und nicht daraus hervorzugehen vermag? Und so wurde den Ungläubigen schön gemacht, was sie zu tun pflegten.\qt@no{(122)}}
\qt@newcmd\qurantrans@de@cmxii{Und so haben Wir es in jeder Stadt mit den Großen ihrer Sünder gemacht: damit sie darin Ränke schmieden. Und sie schmieden nur Ränke gegen sich selbst, ohne daß sie es merken.\qt@no{(123)}}
\qt@newcmd\qurantrans@de@cmxiii{Und wenn ein Zeichen zu ihnen kommt, sagen sie: ``Wir werden nicht eher glauben, als bis wir dasselbe erhalten, was die Gesandten Allahs erhalten haben." Allah weiß am besten, wem Er Seine Botschaft anvertraut. Wahrlich, Erniedrigung vor Allah und eine strenge Strafe wird die Sünder für ihre Ränke treffen.\qt@no{(124)}}
\qt@newcmd\qurantrans@de@cmxiv{Wen Allah aber leiten will, dem weitet Er die Brust für den Islam; und wen Er in die Irre gehen lassen will, dem macht Er die Brust eng und bedrückt, wie wenn er in den Himmel emporsteigen würde. So verhängt Allah die Strafe über jene, die nicht glauben.\qt@no{(125)}}
\qt@newcmd\qurantrans@de@cmxv{Und dies ist der Weg deines Herrn, ein gerader (Weg) Wahrlich, Wir haben die Zeichen für die Leute dargelegt, die sich ermahnen lassen.\qt@no{(126)}}
\qt@newcmd\qurantrans@de@cmxvi{Ihnen wird ein Haus des Friedens bei ihrem Herrn zuteil sein, und Er ist ihr Beschützer um ihrer Werke willen.\qt@no{(127)}}
\qt@newcmd\qurantrans@de@cmxvii{Und an dem Tage, da Er sie allesamt versammelt, dann (spricht Er): ``O ihr Ginn, ihr habt euch viele Menschen verschafft." Und ihre Freunde unter den Menschen sagen: ``Unser Herr, einige von uns haben von anderen Vorteile genossen, nun aber stehen wir am Ende unserer Frist, die Du uns bestimmtest." Er spricht: ``Das Feuer sei eure Herberge, darin sollt ihr auf ewig bleiben, es sei denn, daß Allah es anders will." Wahrlich, dein Herr ist Allweise, Allwissend.\qt@no{(128)}}
\qt@newcmd\qurantrans@de@cmxviii{Und so setzen Wir einige der Frevler über die anderen um dessentwillen, was sie sich erwarben.\qt@no{(129)}}
\qt@newcmd\qurantrans@de@cmxix{``O ihr Ginn und Menschen! Sind nicht aus eurer Mitte Gesandte zu euch gekommen, die euch Meine Zeichen berichteten und euch vor dem Eintreffen dieses eures Tages warnten?" Sie sagen: ``Wir zeugen gegen uns selbst." Das irdische Leben hat sie betört, und sie werden gegen sich selbst das Zeugnis ablegen, daß sie Ungläubige waren.\qt@no{(130)}}
\qt@newcmd\qurantrans@de@cmxx{Dies, weil dein Herr nicht ungerechterweise die Städte zerstören wollte, während ihre Bewohner ungewarnt waren.\qt@no{(131)}}
\qt@newcmd\qurantrans@de@cmxxi{Jeder hat Rangstellungen für das, was er geleistet hat; und dein Herr übersieht nicht, was sie tun.\qt@no{(132)}}
\qt@newcmd\qurantrans@de@cmxxii{Und dein Herr ist Der, Der auf keinen angewiesen ist, und Dem die Barmherzigkeit zu eigen ist. Wenn Er will, wird Er euch hinwegnehmen und an eurer Stelle folgen lassen, was Ihm beliebt, wie Er euch auch aus der Nachkommenschaft anderer entstehen ließ.\qt@no{(133)}}
\qt@newcmd\qurantrans@de@cmxxiii{Wahrlich, was euch versprochen wird, das wird geschehen, und ihr könnt es nicht vereiteln.\qt@no{(134)}}
\qt@newcmd\qurantrans@de@cmxxiv{Sprich: ``O Leute, handelt eurem Standpunkt gemäß, und ich werde (so) handeln. Bald werdet ihr erfahren, wer den endgültigen Lohn der Wohnstatt erhalten wird." Siehe, die Ungerechten sind nie erfolgreich.\qt@no{(135)}}
\qt@newcmd\qurantrans@de@cmxxv{Und sie haben für Allah einen Anteil an den Feldfrüchten und dem Vieh, das Er wachsen ließ, ausgesetzt, und sie sagen: ``Das ist für Allah" wie sie meinen, ``und das ist für unsere Teilhaber (Götzen)". Aber was für ihre Teilhaber ist, das erreicht Allah nicht, während das, was für Allah ist, ihre Teilhaber erreicht. Übel ist das, was sie beurteilen.\qt@no{(136)}}
\qt@newcmd\qurantrans@de@cmxxvi{Und ebenso haben ihre Teilhaber vielen der Götzenanbeter das Töten ihrer Kinder als wohlgefällig erscheinen lassen, damit sie sie verderben und ihren Glauben verwirren können. Und hätte Allah Seinen Willen erzwungen, hätten sie das nicht getan; so überlasse sie sich selbst mit dem, was sie erdichten.\qt@no{(137)}}
\qt@newcmd\qurantrans@de@cmxxvii{Und sie sagten: ``Dieses Vieh und diese Feldfrüchte sind unantastbar; niemand soll davon essen, außer dem, dem wir es erlauben, wie sie meinten, und es gibt Tiere, deren Rücken (zum Reiten) verboten ist, und Tiere, über die sie nicht den Namen Allahs aussprechen und so eine Lüge gegen Allah erfinden. Bald wird Er ihnen vergelten, was sie erdichteten.\qt@no{(138)}}
\qt@newcmd\qurantrans@de@cmxxviii{Und sie sagen: ``Was im Schoße von diesen Tieren ist, das ist ausschließlich unseren Männern vorbehalten und unseren Frauen verboten": wird es aber tot (geboren), dann haben sie (alle) Anteil daran. Er wird ihnen den Lohn für ihre Behauptung geben. Wahrlich, Er ist Allweise, Allwissend.\qt@no{(139)}}
\qt@newcmd\qurantrans@de@cmxxix{Den Schaden tragen wahrlich jene, die ihre Kinder aus törichter Unwissenheit töten und das für verboten erklären, was Allah ihnen gegeben hat und so eine Lüge gegen Allah erfinden. Sie sind wahrlich in die Irre gegangen, und sie sind nicht rechtgeleitet.\qt@no{(140)}}
\qt@newcmd\qurantrans@de@cmxxx{Und Er ist es, Der Gärten wachsen läßt, mit und ohne Pfahlwerk, und die Dattelpalme und die Getreidefelder, deren Früchte von verschiedener Art sind, und Oliven und Granatapfel(Bäume), einander ähnlich und unähnlich. Esset von ihren Früchten, wenn sie Früchte tragen, doch gebet davon am Tage der Ernte (dem Armen) seinen Anteil, seid (dabei aber) nicht verschwenderisch! Wahrlich, Er liebt diejenigen nicht, die nicht maßhalten.\qt@no{(141)}}
\qt@newcmd\qurantrans@de@cmxxxi{Unter dem Vieh sind Lasttiere und Schlachttiere. Esset von dem, was Allah euch gegeben hat und folgt nicht die Fußstapfen des Satans. Wahrlich, er ist euch ein offenkundiger Feind.\qt@no{(142)}}
\qt@newcmd\qurantrans@de@cmxxxii{Acht Paare: zwei von den Schafen und zwei von den Ziegen. Sprich: ``Sind es die beiden Männchen, die Er (euch) verboten hat, oder die beiden Weibchen oder das, was der Mutterschoß der beiden Weibchen umschließt? Verkündet es mir mit Wissen, wenn ihr wahrhaftig seid."\qt@no{(143)}}
\qt@newcmd\qurantrans@de@cmxxxiii{Und von den Kamelen zwei und von den Rindern zwei (Paare) Sprich: ``Sind es die beiden Männchen, die Er (euch) verboten hat, oder die beiden Weibchen oder das, was der Mutterschoß der beiden Weibchen umschließt? Waret ihr dabei, als Allah euch dies gebot?" Wer ist also ungerechter als der, welcher eine Lüge gegen Allah ersinnt, um die Leute ohne Wissen irrezuführen? Wahrlich, Allah leitet das ungerechte Volk nicht.\qt@no{(144)}}
\qt@newcmd\qurantrans@de@cmxxxiv{Sprich: ``Ich finde in dem, was mir offenbart worden ist, nichts, was einem Essenden, der es essen möchte, verboten wäre, es sei denn von selbst Verendetes oder ausgeflossenes Blut oder Schweinefleisch denn das ist eine Unreinheit oder ein Greuel, worüber ein anderer Name als der Allahs angerufen worden ist." Wenn aber jemand durch Not (dazu) getrieben wird und dabei keine Ungehorsamkeit oder Übertretung begeht, dann ist dein Herr Allverzeihend, Allbarmherzig.\qt@no{(145)}}
\qt@newcmd\qurantrans@de@cmxxxv{Und den Juden haben Wir alles Getier untersagt, das Krallen hat; und von den Rindern und vom Kleinvieh haben Wir ihnen das Fett verboten, ausgenommen das, was an ihrem Rücken sitzt oder in den Eingeweiden oder mit den Knochen verwachsen ist. Damit haben Wir ihnen ihre Auflehnung vergolten. Und siehe, Wir sind Wahrhaftig.\qt@no{(146)}}
\qt@newcmd\qurantrans@de@cmxxxvi{Wenn sie dich aber der Lüge bezichtigen, so sprich: ``Euer Herr ist von allumfassender Barmherzigkeit, doch Seine Strenge soll nicht vom verbrecherischen Volk abgewendet werden.\qt@no{(147)}}
\qt@newcmd\qurantrans@de@cmxxxvii{Die Götzendiener werden sagen: ``Hätte Allah es gewollt, so hätten weder wir noch unsere Väter (Allah etwas) beigesellt; auch hätten wir nichts ohne Erlaubnis gemacht." Genauso leugneten schon jene, die vor ihnen waren, bis sie Unsere Strenge zu kosten bekamen. Sprich: ``Habt ihr irgendein Wissen? Dann bringt es für uns zum Vorschein. Doch ihr geht nur Vermutungen nach; und ihr rätselt nur."\qt@no{(148)}}
\qt@newcmd\qurantrans@de@cmxxxviii{Sprich: ``Allah hat den überzeugenden Beweis. Hätte Er es gewollt, so hätte Er euch alle rechtgeleitet."\qt@no{(149)}}
\qt@newcmd\qurantrans@de@cmxxxix{Sprich: ``Her mit euren Zeugen, die bezeugen, Allah habe dies verboten!" Wenn sie (dies) bezeugen, so lege du nicht mit ihnen Zeugnis ab und folge nicht den Neigungen derer, die Unsere Zeichen für Lüge erklärt haben, und (den Neigungen) derer, die nicht an das Jenseits glauben und die andere Wesen ihrem Herrn gleichsetzen.\qt@no{(150)}}
\qt@newcmd\qurantrans@de@cmxl{Sprich: ``Kommt her, ich will verlesen, was euer Herr euch verboten hat: Ihr sollt Ihm nichts zur Seite stellen und den Eltern Güte erweisen; und ihr sollt eure Kinder nicht aus Armut töten, Wir sorgen ja für euch und für sie. Ihr sollt euch nicht den Schändlichkeiten nähern, seien sie offenkundig oder verborgen; und ihr sollt niemanden töten, dessen Leben Allah unverletzlich gemacht hat, außer wenn dies gemäß dem Recht geschieht. Das ist es, was Er euch geboten hat, auf daß ihr es begreifen möget.\qt@no{(151)}}
\qt@newcmd\qurantrans@de@cmxli{Und kommt dem Besitz der Waise nicht nahe, es sei denn zu ihrem Besten, bis sie ihre Volljährigkeit erreicht hat. Und gebt volles Maß und Gewicht in Billigkeit. Wir fordern von keiner Seele etwas über das hinaus, was sie zu leisten vermag. Und wenn ihr eine Aussage macht, so übt Gerechtigkeit, auch wenn es einen nahen Verwandten (betrifft); und haltet den Bund Allahs ein. Das ist es, was Er euch gebietet, auf daß ihr ermahnt sein möget."\qt@no{(152)}}
\qt@newcmd\qurantrans@de@cmxlii{Und dies ist Mein gerader Weg. So folgt ihm; und folgt nicht den (verschiedenen) Wegen, damit sie euch nicht weitab von Seinem Weg führen. Das ist es, was Er euch gebietet, auf daß ihr gottesfürchtig sein möget.\qt@no{(153)}}
\qt@newcmd\qurantrans@de@cmxliii{Hierauf gaben Wir Moses das Buch (die Gnade) erfüllend für den, der das Gute tat, und als Klarlegung aller Dinge und als Führung und als Barmherzigkeit auf daß sie an die Begegnung mit ihrem Herrn glauben mögen.\qt@no{(154)}}
\qt@newcmd\qurantrans@de@cmxliv{Und das ist (auch) ein Buch, das Wir niedersandten voll des Segens. So folgt ihm und hütet euch vor Sünde, auf daß ihr Barmherzigkeit finden möget\qt@no{(155)}}
\qt@newcmd\qurantrans@de@cmxlv{damit ihr nicht sprechet: ``Nur zu zwei Völkern vor uns wurde die Schrift niedergesandt, und wir hatten in der Tat keine Kunde von ihrem Inhalt"\qt@no{(156)}}
\qt@newcmd\qurantrans@de@cmxlvi{oder damit ihr nicht sprechet: ``Wäre das Buch zu uns niedergesandt worden, hätten wir uns wahrlich besser leiten lassen als sie." Nun ist zu euch ein deutlicher Beweis von eurem Herrn gekommen und eine Führung und eine Barmherzigkeit. Wer ist also ungerechter als der, der Allahs Zeichen leugnet und sich von ihnen abkehrt? Wir werden über die, die sich von Unseren Zeichen abkehren, eine schlimme Strafe verhängen, da sie sich abgewandt haben.\qt@no{(157)}}
\qt@newcmd\qurantrans@de@cmxlvii{Warten sie etwa darauf, daß Engel zu ihnen kommen oder daß dein Herr kommt oder daß einige Zeichen deines Herrn kommen? Am Tag, an dem einige Zeichen deines Herrn eintreffen, soll der Glaube an sie niemandem nützen, der nicht vorher geglaubt oder in seinem Glauben Gutes gewirkt hat. Sprich: ``Wartet nur; auch wir warten."\qt@no{(158)}}
\qt@newcmd\qurantrans@de@cmxlviii{Mit jenen aber, die zur Spaltung ihrer Religion beitrugen und zu Parteien geworden sind, hast du nichts Gemeinsames. Ihre Angelegenheit wird sicherlich von Allah beurteilt werden; dann wird Er ihnen verkünden, was sie getan haben.\qt@no{(159)}}
\qt@newcmd\qurantrans@de@cmxlix{Dem, der eine gute Tat vollbringt, soll (sie) zehnfach vergolten werden; derjenige aber, der eine böse Tat verübt, soll nur das Gleiche als Lohn empfangen; und sie sollen kein Unrecht erleiden.\qt@no{(160)}}
\qt@newcmd\qurantrans@de@cml{Sprich: ``Wahrlich, mich hat mein Herr auf einen geraden Weg geleitet zu dem rechten Glauben, dem Glauben Abrahams, des Aufrechten. Und er war keiner der Götzendiener."\qt@no{(161)}}
\qt@newcmd\qurantrans@de@cmli{Sprich: ``Mein Gebet und meine Opferung und mein Leben und mein Tod gehören Allah, dem Herrn der Welten.\qt@no{(162)}}
\qt@newcmd\qurantrans@de@cmlii{Er hat niemanden neben Sich. Und so ist es mir geboten worden, und ich bin der Erste der Gottergebenen."\qt@no{(163)}}
\qt@newcmd\qurantrans@de@cmliii{Sprich: ``Sollte ich einen anderen Herrn als Allah suchen, wo Er doch der Herr aller Dinge ist?" Und keine Seele wirkt, es sei denn gegen sich selbst, und keine lasttragende (Seele) soll die Last einer anderen tragen. Zu eurem Herrn werdet ihr dann heimkehren, und Er wird euch über all das belehren, worüber ihr uneins waret.\qt@no{(164)}}
\qt@newcmd\qurantrans@de@cmliv{Und Er ist es, Der euch zu Nachfolgern auf der Erde machte und die einen von euch über die anderen um Rangstufen erhöhte, um euch durch das zu prüfen, was Er euch gegeben hat. Wahrlich, dein Herr ist schnell im Strafen; und wahrlich, Er ist Allvergebend, Barmherzig.\qt@no{(165)}}
\qt@newcmd\qurantrans@de@cmlv{\basmalahde Alif Lam Mim Sad.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@cmlvi{(Dies ist) ein zu dir hinabgesandtes Buch; du sollst seinetwegen nicht bedrückt sein; und du sollst damit warnen; und es soll eine Ermahnung für die Gläubigen (sein)\qt@no{(2)}}
\qt@newcmd\qurantrans@de@cmlvii{Folgt dem, was zu euch von eurem Herrn herabgesandt wurde, und folgt keinen anderen Beschützern außer Ihm. Wie wenig seid ihr (dessen) eingedenk!\qt@no{(3)}}
\qt@newcmd\qurantrans@de@cmlviii{Und wieviele Städte haben Wir zerstört! Unsere Strafe kam über sie bei Nacht oder während sie (sich) am Mittag ausruhten.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@cmlix{Ihr Ausruf war nichts anderes, als Unsere Strafe über sie kam, als daß sie sagten: `` Wir waren wahrlich Frevler!"\qt@no{(5)}}
\qt@newcmd\qurantrans@de@cmlx{Wahrlich, Wir werden jene fragen, zu denen (die Gesandten) geschickt wurden, und Wir werden die Gesandten fragen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@cmlxi{Dann werden Wir ihnen mit Wissen berichten (was geschehen ist); denn Wir waren (ja) niemals abwesend.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@cmlxii{Und das Wägen an jenem Tage wird wahrhaftig sein. Diejenigen, deren Waagschale dann schwer ist, werden erfolgreich sein.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@cmlxiii{Diejenigen, deren Waagschale aber leicht ist, sind jene, die ihrer selbst verlustig gegangen, weil sie sich gegen Unsere Zeichen vergingen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@cmlxiv{Wahrlich, Wir haben euch auf der Erde Macht verliehen und euch darin die Mittel zum Unterhalt bereitet. Wie wenig seid ihr dankbar!\qt@no{(10)}}
\qt@newcmd\qurantrans@de@cmlxv{Und Wir hatten euch erschaffen, dann gaben Wir euch die Gestalt; dann sprachen Wir zu den Engeln: ``Werft euch vor Adam nieder" und sie alle warfen sich nieder. Nur Iblis nicht; er gehörte nicht zu denen, die sich unterwarfen.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@cmlxvi{Er sprach: ``Was hinderte dich daran, dich niederzuwerfen, nachdem Ich es dir befohlen habe?" Er sagte: `` Ich bin besser als er. Du hast mich aus Feuer erschaffen, ihn aber erschufst Du aus Lehm!"\qt@no{(12)}}
\qt@newcmd\qurantrans@de@cmlxvii{Er sprach: ``Hinab mit dir von hier; es ziemt sich nicht für dich, hier hochmütig zu sein. Hinaus denn; du bist wahrlich einer der Erniedrigten."\qt@no{(13)}}
\qt@newcmd\qurantrans@de@cmlxviii{Er sagte: ``Gewähre mir Aufschub bis zu dem Tage, da sie auferweckt werden."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@cmlxix{Er sprach: ``Dir sei Aufschub gewährt."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@cmlxx{Er sagte: ``Darum, daß Du mich hast abirren lassen, will ich ihnen gewiß auf Deinem geraden Weg auflauern.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@cmlxxi{Dann will ich über sie von vorne und von hinten kommen, von rechts und von links, und Du wirst die Mehrzahl von ihnen nicht dankbar finden."\qt@no{(17)}}
\qt@newcmd\qurantrans@de@cmlxxii{Er sprach: ``Hinweg mit dir, (sei) verachtet und verstoßen! Wahrlich, wer von ihnen dir folgt - Ich werde mit euch allesamt Gahannam füllen."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@cmlxxiii{``O Adam, weile du mit deiner Gattin in dem Garten und esset, wovon immer ihr wollt, nur nähert euch nicht diesem Baum, sonst werdet ihr Ungerechte sein."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@cmlxxiv{doch Satan flüsterte ihnen Böses ein, um ihnen das kundzutun, was ihnen von ihrer Scham verborgen war. Er sagte: ``Euer Herr hat euch diesen Baum nur deshalb verboten, damit ihr nicht Engel oder Ewiglebende werdet."\qt@no{(20)}}
\qt@newcmd\qurantrans@de@cmlxxv{Und er schwor ihnen: ``Gewiß, ich bin euch ein aufrichtiger Ratgeber."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@cmlxxvi{So verführte er sie durch Trug. Und als sie von dem Baum kosteten, wurde ihnen ihre Scham offenbar und sie begannen, sich mit den Blättern des Gartens zu bekleiden; und ihr Herr rief sie: ``Habe Ich euch nicht diesen Baum verwehrt und euch gesagt: ``Wahrlich, Satan ist euer offenkundiger Feind?""\qt@no{(22)}}
\qt@newcmd\qurantrans@de@cmlxxvii{Sie sagten: ``Unser Herr, wir haben gegen uns selbst gesündigt; und wenn Du uns nicht verzeihst und Dich unser erbarmst, dann werden wir gewiß unter den Verlierern sein."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@cmlxxviii{Er sprach: ``Hinab mit euch; die einen von euch seien der anderen Feinde. Und es sei euch auf der Erde (nur) ein Aufenthaltsort und eine Versorgung auf Zeit bestimmt."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@cmlxxix{Er sprach: ``Auf ihr sollt ihr leben, und auf ihr sollt ihr sterben, und aus ihr werdet ihr (wieder) hervorgebracht werden."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@cmlxxx{O Kinder Adams, Wir gaben euch Kleidung, um eure Scham zu bedecken und zum Schmuck; doch das Kleid der Frömmigkeit - das ist das beste. Dies ist eins der Zeichen Allahs, auf daß sie (dessen) eingedenk sein mögen.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@cmlxxxi{O Kinder Adams, lasset Satan euch nicht verführen, (so) wie er eure Eltern aus dem Garten vertrieb und ihnen ihre Kleidung entriß, um ihnen ihre Scham zu zeigen. Wahrlich, er sieht euch, er und seine Schar, von wo ihr sie nicht seht. Denn seht, Wir haben die Satane zu Freunden derer gemacht, die nicht glauben.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@cmlxxxii{Und wenn sie eine Schandtat begehen, sagen sie: ``Wir fanden unsere Väter dabei, und Allah hat sie uns befohlen." Sprich: ``Wahrlich, Allah befiehlt keine Schandtaten. Wollt ihr denn von Allah reden, was ihr nicht wisset?"\qt@no{(28)}}
\qt@newcmd\qurantrans@de@cmlxxxiii{Sprich: ``Mein Herr hat Gerechtigkeit befohlen. Und ihr sollt euer Antlitz bei jeder Gebetsstätte (zu Ihm) richten, und ihr sollt Ihn in lauterem Gehorsam anrufen. Wie Er euch ins Dasein gebracht hat, so werdet ihr (zu Ihm) zurückkehren."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@cmlxxxiv{Eine Schar hat Er geleitet, einer anderen aber wurde nach Gebühr Irrtum zuteil, da sie sich die Satane zu Beschützern außer Allah genommen hatten; und (sie) meinen, sie seien rechtgeleitet.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@cmlxxxv{O Kinder Adams, habt eine gepflegte Erscheinung an jeder Gebetsstätte, und esset und trinkt, doch überschreitet (dabei) das Maß nicht; wahrlich, Er liebt nicht diejenigen, die nicht maßhalten.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@cmlxxxvi{Sprich: ``Wer hat die schönen Dinge Allahs verboten, die Er für Seine Diener hervorgebracht hat und die guten Dinge der Versorgung?" Sprich: ``Sie sind für die Gläubigen in diesem Leben (und) ausschließlich (für sie) am Tage der Auferstehung." So machen Wir die Zeichen klar für Leute, die Wissen haben.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@cmlxxxvii{Sprich: ``Mein Herr hat nur Schändlichkeiten verboten, seien sie offenkundig oder verborgen, dazu Sünde und ungerechte Gewalttat. Und (Er hat verboten,) daß ihr Allah das zur Seite setzt, wozu Er keine Befugnis herabsandte, und (Er hat verboten,) daß ihr (etwas) von Allah aussagt, was ihr nicht wisset."\qt@no{(33)}}
\qt@newcmd\qurantrans@de@cmlxxxviii{Jedem Volk ist eine Frist gesetzt; und wenn ihre Zeit gekommen ist, dann können sie (sie) auch nicht um eine Stunde hinausschieben, noch können sie (sie) vorverlegen.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@cmlxxxix{O Kinder Adams, wenn zu euch aus eurer Mitte Gesandte kommen, die euch Meine Zeichen verkünden über diejenigen, die dann gottesfürchtig sind und gute Werke tun, soll keine Furcht kommen, noch sollen sie traurig sein.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@cmxc{Diejenigen aber, die Unsere Zeichen verleugnen und sich hochmütig von ihnen abwenden, sollen die Bewohner des Feuers sein; darin werden sie auf ewig verweilen.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@cmxci{Wer ist wohl frevelhafter als der, der eine Lüge gegen Allah erdichtet oder Seine Zeichen der Lüge bezichtigt? Diesen soll das bestimmte Los (zuteil) werden, bis Unsere Boten zu ihnen kommen, um ihnen den Tod zu bringen; sie werden sprechen: ``Wo ist nun das, was ihr statt Allah anzurufen pflegtet?" Jene werden antworten: ``Wir können sie nicht finden"; und sie werden gegen sich selbst Zeugnis ablegen, daß sie Ungläubige waren.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@cmxcii{Er wird sprechen: ``Tretet ein in das Feuer zu den Scharen der Ginn und der Menschen, die vor euch dahingingen." Sooft eine Schar eintritt, wird sie ihre Schwesterschar verfluchen, bis endlich, wenn sie alle nacheinander darin angekommen sind, die letzten zu den ersten sagen werden: ``Unser Herr, diese da haben uns irregeführt, so gib ihnen die Pein des Feuers mehrfach." Er wird sprechen: ``Jeder hat (sie) mehrfach, allein ihr wisset es nicht."\qt@no{(38)}}
\qt@newcmd\qurantrans@de@cmxciii{Und die ersten werden zu den letzten sagen: ``So hattet ihr denn keinen Vorteil vor uns; kostet also die Strafe für das, was ihr begangen habt."\qt@no{(39)}}
\qt@newcmd\qurantrans@de@cmxciv{Wahrlich, denjenigen, die Unsere Zeichen für Lüge erklären und sich mit Hochmut von ihnen abwenden, werden die Pforten des Himmels nicht geöffnet werden, noch werden sie in das Paradies eingehen, ehe denn ein Kamel durch ein Nadelöhr geht. Und so belohnen Wir die Verbrecher.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@cmxcv{Sie sollen Gahannam zum Lager und als Decke über sich haben. Und so belohnen Wir die Ungerechten.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@cmxcvi{Diejenigen aber, die glauben und gute Werke tun - Wir belasten keine Seele über ihr Vermögen hinaus -, sie sind die Bewohner des Paradieses; darin sollen sie auf ewig verweilen.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@cmxcvii{Und Wir wollen alles hinwegräumen, was an Groll in ihren Herzen sein mag. Unter ihnen sollen Bäche fließen. Und sie werden sagen: ``Alles Lob gebührt Allah, Der uns zu diesem (Paradies) geleitet hat! Wir hätten den Weg nicht zu finden vermocht, wenn Allah uns nicht geleitet hätte. Die Gesandten unseres Herrn haben in der Tat die Wahrheit gebracht." Und es soll ihnen zugerufen werden: ``Das ist das Paradies, das euch zum Erbe gegeben wird für das, was ihr getan habt."\qt@no{(43)}}
\qt@newcmd\qurantrans@de@cmxcviii{Und die Bewohner des Paradieses rufen den Bewohnern der Hölle zu: ``Seht, wir haben als Wahrheit vorgefunden, was unser Herr uns verhieß. Habt ihr auch als Wahrheit vorgefunden, was euer Herr (euch) verhieß?" Jene sagen: ``Ja." Dann kündigt ein Ausrufer unter ihnen an: `` Der Fluch Allahs sei über den Missetätern\qt@no{(44)}}
\qt@newcmd\qurantrans@de@cmxcix{die von Allahs Weg abhalten und ihn zu krümmen suchen und nicht an das Jenseits glauben!"\qt@no{(45)}}
\qt@newcmd\qurantrans@de@m{Und zwischen den zweien soll eine Scheidewand sein; und in den Höhen sind Leute, die die beiden (Scharen) an ihren Merkmalen erkennen. Sie rufen der Schar des Paradieses zu: ``Friede sei auf euch!" Diese sind (noch) nicht in (das Paradies) eingegangen, obwohl sie es erhoffen.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mi{Und wenn ihre Blicke sich in Richtung der Bewohner des Feuers wenden, sagen sie: ``Unser Herr, mache uns nicht zum Volk der Frevler."\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mii{Und die (Leute) in den Höhen rufen den Leuten, die sie an ihren Merkmalen erkennen, zu (und) sagen: ``Nichts hat euch das gefruchtet, was ihr zusammengebracht habt, und auch euer Hochmut (hat euch nichts gefruchtet)\qt@no{(48)}}
\qt@newcmd\qurantrans@de@miii{Sind das jene, von denen ihr (einst) geschworen habt, Allah würde ihnen keine Barrnherzigkeit erweisen?" Geht ein in das Paradies; keine Furcht soll über euch kommen, noch sollt ihr traurig sein.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@miv{Und die Bewohner des Feuers rufen den Bewohnern des Paradieses zu: ``Gießt etwas Wasser über uns aus oder etwas von dem, was Allah euch gegeben hat." Sie sagen: ``Wahrlich, Allah hat beides den Ungläubigen verwehrt\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mv{die ihre Religion als Zerstreung betrachteten und ihr Spiel mit ihr trieben und vom irdischen Leben betört waren." An diesem Tage nun vergessen Wir sie, wie sie die Begegnung an diesem ihrem Tage vergaßen und wie sie Unsere Zeichen zu leugnen pflegten.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mvi{Und wahrlich, Wir hatten ihnen ein Buch gebracht, das Wir mit Wissen darlegten als Richtschnur und Barmherzigkeit für die Leute, die gläubig sind.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mvii{Warten sie auf etwas (anderes) als auf seine Auslegung? An dem Tage, da seine Auslegung Wirklichkeit wird, werden jene sagen, die es vordem vergessen hatten: ``Die Gesandten unseres Herrn haben in der Tat die Wahrheit gebracht. Haben wir wohl Fürsprecher, die für uns Fürsprache einlegen? Oder könnten wir zurückgeschickt werden, auf daß wir anderes tun mögen, als wir zu tun pflegten?" Sie haben ihre Seelen zugrunde gerichtet, und das, was sie zu erdichten gewohnt waren, hat sie im Stich gelassen.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mviii{Seht, euer Herr ist Allah, Der die Himmel und die Erde in sechs Tagen erschuf, (und) Sich alsdann (Seinem) Reich majestätisch zuwandte: Er läßt die Nacht den Tag verhüllen, der ihr eilends folgt. Und (Er erschuf) die Sonne und den Mond und die Sterne, Seinem Befehl dienstbar. Wahrlich, Sein ist die Schöpfung und der Befehl! Segensreich ist Allah, der Herr der Welten.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mix{Ruft euren Herrn in Demut und im verborgenen an. Wahrlich, Er liebt die Übertreter nicht.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mx{Und stiftet keinen Verderb auf Erden, nachdem dort Ordnung herrscht, und ruft Ihn in Furcht und Hoffnung an. Wahrlich, Allahs Barmherzigkeit ist denen nahe, die gute Werke tun.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mxi{Er ist es, Der in Seiner Barmherzigkeit die Winde als frohe Botschaft schickt, bis daß Wir sie, wenn sie eine schwere Wolke tragen, zu einem toten Ort treiben; dann lassen Wir Wasser aus ihr herab, mit dem Wir Früchte von jeglicher Art hervorbringen. So bringen Wir auch die Toten hervor, auf daß ihr dessen eingedenk sein möget.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mxii{Und der gute Ort - seine Pflanzen sprießen nach der Erlaubnis seines Herrn hervor; der (Ort, der) aber schlecht ist - (seine Pflanzen) sprießen nur kümmerlich. Und so wenden Wir die Zeichen für Leute, die dankbar sind.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mxiii{Wir entsandten Noah zu seinem Volk, und er sagte: ``O mein Volk, dient Allah; ihr habt keinen anderen Gott außer Ihm. Wahrlich, ich fürchte für euch die Strafe eines großen Tages."\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mxiv{Es sagten die Vornehmen seines Volkes: ``Wahrlich, wir sehen dich in einem offenkundigen Irrtum."\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mxv{Er sagte: ``O meine Leute, es ist kein Irrtum in mir, sondern ich bin ein Gesandter vom Herrn der Welten.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mxvi{Ich überbringe euch die Botschaften meines Herrn und gebe euch aufrichtigen Rat, und ich weiß durch Allah, was ihr nicht wisset.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mxvii{Wundert ihr euch, daß eine Ermahnung von eurem Herrn durch einen Mann aus eurer Mitte zu euch gekommen ist, auf daß er euch warne, und auf daß ihr (Allah) fürchten möget und vielleicht Erbarmen findet?"\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mxviii{Doch ziehen sie ihn der Lüge; dann erretteten Wir ihn und die, die mit ihm im Schiff waren, und ließen jene ertrinken, die Unsere Zeichen verwarfen. Sie waren wahrlich eine blinde Schar.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mxix{Und zu den Ad (entsandten Wir) ihren Bruder Hud. Er sagte: ``O mein Volk, dient Allah; ihr habt keinen anderen Gott außer Ihm. Wollt ihr nicht gottesfürchtig sein?"\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mxx{Die ungläubigen Vornehmen seines Volkes sagten: ``Wahrlich wir sehen dich in Torheit, und wahrlich, wir erachten dich für einen Lügner."\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mxxi{Er sagte: ``O mein Volk, es ist keine Torheit in mir, sondern ich bin ein Gesandter vom Herrn der Welten.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mxxii{Ich überbringe euch die Botschaften meines Herrn, und ich bin euch ein aufrichtiger und getreuer Ratgeber.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mxxiii{Wundert ihr euch etwa, daß eine Ermahnung von eurem Herrn durch einen Mann aus eurer Mitte zu euch gekommen ist, auf daß er euch warne? Und gedenkt (der Zeit), da Er euch zu Erben der Leute Noahs einsetzte und euch ein Übermaß an Körperwuchs verlieh. Gedenkt denn der Gnaden Allahs, auf daß ihr erfolgreich sein möget."\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mxxiv{Sie sagten: ``Bist du zu uns gekommen, damit wir Allah allein verehren und das verlassen (sollen), was unsere Väter anbeteten? Bring uns denn her, was du uns (an Drohung) versprichst, wenn du wahrhaftig bist!"\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mxxv{Er sagte: ``Wahrlich, fällig geworden ist nunmehr für euch Strafe und Zorn von eurem Herrn. Wollt ihr mit mir über die Namen streiten, die ihr nanntet - ihr und eure Väter -, wozu Allah keine Befugnis hinabsandte? Wartet denn, ich bin mit euch unter den Wartenden."\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mxxvi{Sodann erretteten Wir ihn und diejenigen, die bei ihm waren, durch Unsere Barmherzigkeit; und Wir schnitten den letzten Zweig derer ab, die Unsere Zeichen leugneten und nicht gläubig waren.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mxxvii{Und zu den Tamud (entsandten Wir) ihren Bruder Salih. Er sagte: `` O mein Volk, dient Allah; ihr habt keinen anderen Gott außer Ihm. Wahrlich, nunmehr ist zu euch ein deutlicher Beweis von eurem Herrn gekommen - diese Kamelstute Allahs als Zeichen für euch. So lasset sie auf Allahs Erde weiden und tut ihr nichts zuleide; (denn) sonst würde euch eine schmerzliche Strafe treffen.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mxxviii{Und gedenkt (der Zeit), da Er euch zu Erben der `Ad einsetzte und euch eine Stätte im Land anwies; ihr erbaut Paläste in seinen Ebenen und grabt Wohnungen in die Berge. Seid also der Gnaden Allahs eingedenk und treibt im Land nicht (euer) Unwesen, indem ihr Unheil anrichtet.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mxxix{Die Vornehmen seines Volkes, die hochmütig waren, sagten zu denen, die unterdrückt wurden - das waren die Gläubigen unter ihnen: ``Seid ihr sicher, daß Salih von seinem Herrn gesandt worden ist?" Sie sagten: ``Wahrlich, wir glauben an das, womit er gesandt worden ist."\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mxxx{Da sagten die Hochmütigen: ``Wahrlich, wir verleugnen das, an das ihr glaubt."\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mxxxi{Dann schnitten sie der Kamelstute die Sehnen durch und trotzten dem Befehl ihres Herrn und sagten: ``O Salih, bring uns das her, was du uns (an Drohung) versprichst, wenn du einer der Gesandten bist."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mxxxii{Da erfaßte sie das Beben; und am Morgen lagen sie in ihren Wohnungen auf dem Boden hingestreckt.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mxxxiii{Da wandte er sich von ihnen ab und sagte: ``O mein Volk, ich überbrachte euch die Botschaft meines Herrn und bot euch aufrichtigen Rat an; ihr aber liebt die Ratgeber nicht."\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mxxxiv{Und (Wir entsandten) Lot, da er zu seinem Volke sagte: ``Wollt ihr eine Schandtat begehen, wie sie keiner in der Welt vor euch je begangen hat?\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mxxxv{Ihr gebt euch in (eurer) Sinnenlust wahrhaftig mit Männern statt mit Frauen ab. Nein, ihr seid ein ausschweifendes Volk."\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mxxxvi{Da war die Antwort seines Volkes keine andere als die: ``Treibt sie aus eurer Stadt hinaus; denn sie sind Leute, die sich reinsprechen wollen."\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mxxxvii{Sodann erretteten Wir ihn und die Seinen, mit Ausnahme seiner Frau; denn sie gehörte zu denen, die zurückblieben.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mxxxviii{Und Wir ließen einen gewaltigen Regen auf sie niedergehen. Nun siehe, wie das Ende der Verbrecher war!\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mxxxix{Und zu den Madyan (entsandten Wir) ihren Bruder Suaib. Er sagte: ``O mein Volk, dient Allah; ihr habt keinen anderen Gott außer Ihm. Ein deutliches Zeichen ist nunmehr von eurem Herrn zu euch gekommen. Darum gebt volles Maß und Gewicht und schmälert den Menschen ihre Dinge nicht und stiftet nicht nach ihrer Ordnung Unheil auf Erden. Das ist besser für euch, wenn ihr gläubig seid.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mxl{Und lauert nicht drohend auf jedem Weg, indem ihr die von Allahs Weg abtrünnig machen möget, die an Ihn glauben, und indem ihr ihn (den Weg) zu krümmen sucht. Und denkt daran, wie wenige ihr waret und (wie) Er euch mehrte. Und schaut, wie das Ende derer war, die Unheil stifteten!\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mxli{Und wenn unter euch solche sind, die an das glauben, womit ich gesandt worden bin, und andere, die nicht (daran) glauben, so habt die Geduld, bis Allah zwischen uns richtet; denn Er ist der beste Richter."\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mxlii{Da sagten die Vornehmen seines Volkes, die hochmütig waren: ``O Suaib, wir wollen dich und mit dir die Gläubigen aus unserer Stadt hinaustreiben, wenn ihr nicht zu unserer Religion zurückkehrt." Er sagte: ``Auch wenn wir (dazu) nicht willens sind?\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mxliii{Wir würden ja eine Lüge gegen Allah erdichten, wenn wir zu eurer Religion zurückkehrten, nachdem Allah uns daraus gerettet hat. Es ziemt sich für uns nicht, dazu zurückzukehren, es sei denn, daß Allah, unser Herr, es will. Unser Herr umfaßt alle Dinge mit Wissen. Auf Allah vertrauen wir. O unser Herr, entscheide denn Du zwischen uns und unseren Leuten nach der Wahrheit; denn Du bist es, Der am besten entscheidet."\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mxliv{Und die Vornehmen seines Volkes, die ungläubig waren, sagten: ``Wenn ihr Suaib folgt, seid ihr wahrlich verloren."\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mxlv{Dann erfaßte sie das Beben; und am Morgen lagen sie in ihren Wohnungen auf dem Boden hingestreckt.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mxlvi{Diejenigen, die Suaib der Lüge beschuldigt hatten, wurden (so zugerichtet), als hätten sie nie darin gewohnt. Diejenigen, die Suaib der Lüge beschuldigt hatten, waren selbst die Verlierer.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mxlvii{Dann wandte er sich von ihnen ab und sagte: ``O mein Volk, wahrlich, ich überbrachte euch die Botschaften meines Herrn und gab euch aufrichtigen Rat. Wie sollte ich mich nun über ungläubige Leute betrüben?"\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mxlviii{Nie sandten Wir einen Propheten in eine Stadt, ohne daß Wir ihre Bewohner mit Not und Drangsal heimsuchten, auf daß sie (Mich) demütig anflehen sollten.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mxlix{Darauf tauschten Wir das Übel gegen etwas Gutes ein, bis sie anwuchsen und sagten: ``Auch unsere Väter erfuhren Leid und Freude." Dann erfaßten Wir sie unversehens, ohne daß sie es merkten.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@ml{Hätten aber die Bewohner (jener) Städte geglaubt und wären sie gottesfürchtig gewesen, so hätten Wir ihnen ganz gewiß die Segnungen von Himmel und Erde eröffnet. Doch sie leugneten; also erfaßten Wir sie um dessentwillen, was sie begangen hatten.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mli{Sind denn die Bewohner der Städte sicher, daß Unsere Strafe nicht zur Nachtzeit über sie kommt, während sie noch schlafen?\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mlii{Oder sind die Bewohner der Städte sicher, daß Unsere Strafe nicht vormittags über sie kommt, während sie beim Spiel sind?\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mliii{Sind sie denn sicher vor dem Plan Allahs? Aber niemand kann sich vor dem Plan Allahs sicher fühlen, außer dem Volk der Verlierenden.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mliv{Leuchtet das jenen nicht ein, die die Erde von ihren (früheren) Bewohnern ererbt haben, daß Wir, wenn Wir wollen, sie für ihre Sünden treffen können und ihre Herzen versiegeln, so daß sie nicht hören können?\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mlv{Dies sind die Städte, deren Geschichte Wir dir erzählt haben. Wahrlich, ihre Gesandten waren zu ihnen mit deutlichen Beweisen gekommen. Aber sie möchten nicht an das glauben, was sie zuvor geleugnet hatten. So versiegelt Allah die Herzen der Ungläubigen.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mlvi{Und bei den meisten von ihnen fanden Wir keine Vertragstreue, sondern Wir fanden die meisten von ihnen als Frevler vor.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mlvii{Hierauf, nach ihnen, entsandten Wir Moses mit Unseren Zeichen zu Pharao und seinen Vornehmen, doch sie frevelten an ihnen. Nun schau, wie das Ende derer war, die Unheil stifteten!\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mlviii{Und Moses sagte: ``O Pharao, ich bin ein Gesandter vom Herrn der Welten.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mlix{Es ziemt sich, daß ich von Allah nichts anderes als die Wahrheit rede. Ich bin zu euch mit einem deutlichen Beweis von eurem Herrn gekommen; so laß denn die Kinder Israels mit mir ziehen."\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mlx{Er sagte: ``Wenn du wirklich mit einem Zeichen gekommen bist, so weise es vor, wenn du zu den Wahrhaftigen gehörst."\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mlxi{Da warf er seinen Stock nieder, und da war dieser (auf einmal) eine leibhaftige Schlange.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mlxii{Dann zog er seine Hand heraus und da sah sie (auf einmal) für die Zuschauer weiß aus.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mlxiii{Die Vornehmen von Pharaos Volk sagten: ``Wahrlich, das ist ein wissensreicher Zauberer.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mlxiv{Er will euch aus eurem Land vertreiben. Was veranlaßt ihr nun?"\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mlxv{Sie sagten: ``Warte mit ihm und seinem Bruder noch eine Weile und sende Ausrufer zu einer Versammlung in die Städte aus\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mlxvi{auf daß sie jeden kundigen Zauberer zu dir bringen sollen."\qt@no{(112)}}
\qt@newcmd\qurantrans@de@mlxvii{Und die Zauberer kamen zu Pharao (und) sagten: ``Uns wird doch gewiß eine Belohnung zuteil wenn wir siegen?"\qt@no{(113)}}
\qt@newcmd\qurantrans@de@mlxviii{Er sagte: ``Ja, und ihr sollt zu den Nächsten (von uns) gehören."\qt@no{(114)}}
\qt@newcmd\qurantrans@de@mlxix{Sie sagten: ``O Moses, entweder wirfst du (den Stock) oder wir werfen (zuerst)"\qt@no{(115)}}
\qt@newcmd\qurantrans@de@mlxx{Er sagte: ``Ihr sollt werfen!" Und als sie geworfen hatten, bezauberten sie die Augen der Leute und versetzten sie in Furcht und brachten einen gewaltigen Zauber hervor.\qt@no{(116)}}
\qt@newcmd\qurantrans@de@mlxxi{Und Wir offenbarten Moses: ``Wirf deinen Stock!" Und siehe, er verschlang alles, was sie an Trug vorgebracht hatten.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@mlxxii{So wurde die Wahrheit vollzogen, und ihre Werke erwiesen sich als nichtig.\qt@no{(118)}}
\qt@newcmd\qurantrans@de@mlxxiii{Dort wurden sie damals besiegt, und beschämt kehrten sie um.\qt@no{(119)}}
\qt@newcmd\qurantrans@de@mlxxiv{Und die Zauberer trieb es, in Anbetung niederzufallen.\qt@no{(120)}}
\qt@newcmd\qurantrans@de@mlxxv{Sie sagten: ``Wir glauben an den Herrn der Welten\qt@no{(121)}}
\qt@newcmd\qurantrans@de@mlxxvi{den Herrn von Moses und Aaron."\qt@no{(122)}}
\qt@newcmd\qurantrans@de@mlxxvii{Da sagte Pharao: ``Ihr habt an ihn geglaubt, ehe ich es euch erlaubte. Gewiß, das ist eine List, die ihr in der Stadt ersonnen habt, um ihre Bewohner daraus zu vertreiben; doch ihr sollt es bald erfahren.\qt@no{(123)}}
\qt@newcmd\qurantrans@de@mlxxviii{Wahrlich, ich werde wechselweise eure Hände und Füße abhauen. Dann werde ich euch alle kreuzigen."\qt@no{(124)}}
\qt@newcmd\qurantrans@de@mlxxix{Sie sagten: ``Dann kehren wir zu unserem Herrn zurück.\qt@no{(125)}}
\qt@newcmd\qurantrans@de@mlxxx{Du nimmst nur darum Rache an uns, weil wir an die Zeichen unseres Herrn glaubten, als sie zu uns kamen. Unser Herr, gib uns reichlich Geduld und laß uns als Muslime sterben."\qt@no{(126)}}
\qt@newcmd\qurantrans@de@mlxxxi{Die Vornehmen von Pharaos Volk sagten: ``Willst du zulassen, daß Moses und sein Volk Unheil im Land stiften und dich und deine Götter verlassen?"; er sagte: ``Wir wollen ihre Söhne umbringen und ihre Frauen am Leben lassen; denn wir haben Gewalt über sie."\qt@no{(127)}}
\qt@newcmd\qurantrans@de@mlxxxii{Da sagte Moses zu seinem Volk: ``Fleht Allah um Hilfe an und seid geduldig. Wahrlich, die Erde ist Allahs; Er vererbt sie unter Seinen Dienern, wem Er will, und der Ausgang (aller Dinge) ist für die Gottesfürchtigen."\qt@no{(128)}}
\qt@newcmd\qurantrans@de@mlxxxiii{Sie sagten: ``Wir litten, ehe du zu uns kamst und nachdem du zu uns gekommen bist." Er sagte: ``Euer Herr möge bald eure Feinde zugrunde gehen lassen und euch die Folgeherrschaft im Land geben; und Er wird sehen, was ihr dann tut."\qt@no{(129)}}
\qt@newcmd\qurantrans@de@mlxxxiv{Und Wir bestraften Pharaos Volk mit Dürre und Mangel an Früchten, auf daß sie sich ermahnen ließen.\qt@no{(130)}}
\qt@newcmd\qurantrans@de@mlxxxv{Doch als dann Gutes zu ihnen kam, sagten sie: ``Das gebührt uns." Und wenn sie ein Übel traf, so schrieben sie das Unheil Moses und den Seinigen zu. Nun liegt doch gewiß ihr Unheil bei Allah allein, jedoch die meisten von ihnen wissen es nicht.\qt@no{(131)}}
\qt@newcmd\qurantrans@de@mlxxxvi{Und sie sagten: ``Was du uns auch immer für ein Zeichen bringen magst, um uns damit zu bezaubern, wir werden dir doch nicht glauben."\qt@no{(132)}}
\qt@newcmd\qurantrans@de@mlxxxvii{Da sandten Wir die Flut über sie, die Heuschrecken, die Läuse, die Frösche und das Blut - deutliche Zeichen -, doch sie betrugen sich hochmütig und wurden ein sündiges Volk.\qt@no{(133)}}
\qt@newcmd\qurantrans@de@mlxxxviii{Wann immer aber das Strafgericht über sie kam, sagten sie: ``O Moses, bete für uns zu deinem Herrn und berufe dich auf das, was Er dir verhieß! Wenn du die Strafe von uns wegnehmen läßt, so werden wir dir ganz gewiß glauben und die Kinder Israels ganz gewiß mit dir ziehen lassen."\qt@no{(134)}}
\qt@newcmd\qurantrans@de@mlxxxix{Doch als Wir ihnen die Strafe wegnahmen - für eine Frist, die sie vollenden sollten -, siehe, da brachen sie ihr Wort.\qt@no{(135)}}
\qt@newcmd\qurantrans@de@mxc{Darauf bestraften Wir sie und ließen sie im Meer ertrinken, weil sie Unsere Zeichen für Lüge erklärten und nicht auf sie achteten.\qt@no{(136)}}
\qt@newcmd\qurantrans@de@mxci{Und Wir gaben dem Volk, das als schwach galt, die östlichen Teile des Landes zum Erbe und dazu die westlichen Teile, die Wir gesegnet hatten. Und das gnadenvolle Wort deines Herrn wurde damit an den Kindern Israels erfüllt, weil sie geduldig waren; und Wir zerstörten alles, was Pharao und sein Volk geschaffen und was sie an hohen Bauten erbaut hatten.\qt@no{(137)}}
\qt@newcmd\qurantrans@de@mxcii{Und Wir brachten die Kinder Israels durch das Meer; und sie kamen zu einem Volk, das seinen Götzen ergeben war. Sie sagten: ``O Moses, mache uns (so) einen Gott, wie diese hier Götter haben." Er sagte: ``Ihr seid ein unbelehrbares Volk.\qt@no{(138)}}
\qt@newcmd\qurantrans@de@mxciii{Diesen geht wahrlich (all) das zugrunde, was sie betreiben, und eitel wird all das sein, was sie tun."\qt@no{(139)}}
\qt@newcmd\qurantrans@de@mxciv{Er sagte: ``Soll ich für euch einen anderen Gott fordern als Allah, obwohl Er euch vor allen Völkern ausgezeichnet hat?"\qt@no{(140)}}
\qt@newcmd\qurantrans@de@mxcv{Und gedenkt der Zeit,) da Wir euch vor den Leuten Pharaos erretteten, die euch mit bitterer Pein bedrückten, eure Söhne hinmordeten und eure Frauen am Leben ließen. Und hierin lag für euch eine schwere Prüfung von eurem Herrn.\qt@no{(141)}}
\qt@newcmd\qurantrans@de@mxcvi{Und Wir verabredeten Uns mit Moses für dreißig Nächte und ergänzten sie mit zehn. So war die festgesetzte Zeit seines Herrn vollendet - vierzig Nächte. Und Moses sagte zu seinem Bruder Aaron: ``Vertritt mich bei meinem Volk und führe (es) richtig und folge nicht dem Weg derer, die Unheil stiften."\qt@no{(142)}}
\qt@newcmd\qurantrans@de@mxcvii{Und als Moses zu Unserem Termin gekommen war und sein Herr zu ihm gesprochen hatte, sagte er: ``Mein Herr, zeige (Dich) mir, auf daß ich Dich schauen mag." Er sprach: ``Du wirst Mich nicht sehen, doch blicke auf den Berg; wenn er unverrückt an seinem Ort bleibt, dann wirst du Mich sehen." Als nun sein Herr dem Berg erschien, da ließ Er ihn zu Schutt zerfallen, und Moses stürzte ohnmächtig nieder. Und als er zu sich kam, sagte er: ``Gepriesen seist Du, ich bekehre mich zu Dir, und ich bin der Erste der Gläubigen."\qt@no{(143)}}
\qt@newcmd\qurantrans@de@mxcviii{Er sprach: ``O Moses, Ich habe dich vor den Menschen durch Meine Botschaft und durch Mein Wort zu dir auserwählt. So nimm denn hin, was Ich dir gegeben habe, und sei einer der Dankbaren."\qt@no{(144)}}
\qt@newcmd\qurantrans@de@mxcix{Und Wir schrieben ihm auf den Tafeln allerlei auf zur Ermahnung und Erklärung von allen Dingen: ``So halte sie fest und befiehl deinem Volk, das Beste davon zu befolgen". Bald werde Ich euch die Stätte der Frevler sehen lassen.\qt@no{(145)}}
\qt@newcmd\qurantrans@de@mc{Abwenden aber will Ich von Meinen Zeichen diejenigen, die sich im Lande hochmütig gegen alles Recht gebärden; und wenn sie auch alle Zeichen sehen, so wollen sie nicht daran glauben; und wenn sie den Weg der Rechtschaffenheit sehen, so wollen sie ihn nicht als Weg annehmen; sehen sie aber den Weg des Irrtums, so nehmen sie ihn als Weg an. Dies (ist so), weil sie Unsere Zeichen für Lügen erklärten und sie nicht achteten.\qt@no{(146)}}
\qt@newcmd\qurantrans@de@mci{Diejenigen, die Unsere Zeichen und ihre Begegnung im Jenseits leugnen - deren Werke sind hinfällig. Können sie für etwas anderes als das, was sie getan haben, belohnt werden?\qt@no{(147)}}
\qt@newcmd\qurantrans@de@mcii{Und die Leute Moses' nahmen sich, nachdem er weggegangen war, aus ihren Schmucksachen ein leibhaftiges Kalb, das muhte. Sahen sie denn nicht, daß es nicht zu ihnen sprechen und sie nicht auf den rechten Weg führen könnte? Sie nahmen es sich, und sie wurden Frevler.\qt@no{(148)}}
\qt@newcmd\qurantrans@de@mciii{Als sie dann von Reue erfaßt wurden und einsahen, daß sie wirklich irregegangen waren, da sagten sie: ``Wenn Sich unser Herr nicht unser erbarmt und uns verzeiht, so werden wir ganz gewiß unter den Verlierenden sein."\qt@no{(149)}}
\qt@newcmd\qurantrans@de@mciv{Und als Moses zu seinen Leuten zurückkehrte, zornig und voller Gram, da sagte er: ``Es ist schlimm, was ihr in meiner Abwesenheit an meiner Stelle verübt habt. Wolltet ihr den Befehl eures Herrn beschleunigen?" Und er warf die Tafeln hin und packte seinen Bruder beim Kopf und zerrte ihn zu sich. Er (Aaron) sagte: ``Sohn meiner Mutter, siehe, das Volk hielt mich für schwach, und fast hätten sie mich getötet. Darum laß die Feinde nicht über mich frohlocken und weise mich nicht dem Volk der Ungerechten zu."\qt@no{(150)}}
\qt@newcmd\qurantrans@de@mcv{Er (Moses) sagte: ``Mein Herr, vergib mir und meinem Bruder und gewähre uns Zutritt zu Deiner Barmherzig keit; denn Du bist der Barmherzigste Erbarmer."\qt@no{(151)}}
\qt@newcmd\qurantrans@de@mcvi{Wahrlich, diejenigen, die sich nun das Kalb nahmen, wird der Zorn ihres Herrn sowie Schmach im diesseitigen Leben treffen. Und so belohnen Wir diejenigen, die Lügen erdichten.\qt@no{(152)}}
\qt@newcmd\qurantrans@de@mcvii{Diejenigen aber, die Böses taten und es dann bereuten und glaubten - wahrlich, dein Herr ist hernach Allverzeihend, Barmherzig.\qt@no{(153)}}
\qt@newcmd\qurantrans@de@mcviii{Und als der Zorn von Moses abließ, nahm er die Tafeln, und in ihrer Niederschrift war Rechtleitung und Barmherzigkeit für jene, die ihren Herrn fürchten.\qt@no{(154)}}
\qt@newcmd\qurantrans@de@mcix{Und Moses erwählte aus seinem Volk siebzig Männer für Unsere Verabredung. Doch als das Beben sie ereilte, sagte er: ``Mein Herr, hättest Du es gewollt, hättest Du sie zuvor vernichten können und mich ebenfalls. Willst Du uns denn vernichten um dessentwillen, was die Toren unter uns getan haben? Dies ist nur eine Prüfung von Dir. Damit führst Du irre, wen Du willst, und weist den Weg, wem Du willst. Du bist unser Beschützer; so vergib uns denn und erbarme Dich unser; denn Du bist der Beste der Vergebenden.\qt@no{(155)}}
\qt@newcmd\qurantrans@de@mcx{Und bestimme für uns Gutes, sowohl im Diesseits als auch im Jenseits; denn zu Dir sind wir reuevoll zurückgekehrt." Er sprach: ``Ich treffe mit Meiner Strafe, wen Ich will; doch Meine Barmherzigkeit umfaßt alle Dinge; so werde Ich sie bestimmen - sowohl für jene, die (Mich) fürchten und die Zakah entrichten als auch für jene, die an Unsere Zeichen glauben."\qt@no{(156)}}
\qt@newcmd\qurantrans@de@mcxi{Dies sind jene, die dem Gesandten, dem Propheten folgen, der des Lesens und Schreibens unkundig ist; dort in der Thora und im Evangelium werden sie über ihn (geschrieben) finden: er gebietet ihnen das Gute und verbietet ihnen das Böse, und er erlaubt ihnen die guten Dinge und verwehrt ihnen die schlechten, und er nimmt ihnen ihre Last hinweg und die Fesseln, die auf ihnen lagen -; die also an ihn glauben und ihn stärken und ihm helfen und dem Licht folgen, das mit ihm hinabgesandt wurde, die sollen erfolgreich sein.\qt@no{(157)}}
\qt@newcmd\qurantrans@de@mcxii{Sprich: ``O ihr Menschen, ich bin für euch alle ein Gesandter Allahs, Dessen das Königreich der Himmel und der Erde ist. Es ist kein Gott außer Ihm. Er macht lebendig und läßt sterben. Darum glaubt an Allah und an Seinen Gesandten, den Propheten, der des Lesens und Schreibens unkundig ist, der an Allah und an Seine Worte glaubt; und folgt ihm, auf daß ihr rechtgeleitet werden möget."\qt@no{(158)}}
\qt@newcmd\qurantrans@de@mcxiii{Und unter dem Volke Moses' gibt es eine Gemeinde, die in Wahrheit den Weg weist und danach Gerechtigkeit übt.\qt@no{(159)}}
\qt@newcmd\qurantrans@de@mcxiv{Und Wir teilten sie in zwölf Stämme zu Gemeinschaften auf, und Wir offenbarten Moses, als sein Volk von ihm etwas zu trinken forderte: ``Schlage mit `` deinem Stock an den Felsen." Da entsprangen ihm zwölf Quellen: so kannte jeder Stamm seinen Trinkplatz. Und Wir ließen sie von Wolken überschatten und sandten ihnen Manna und Salwa hinab: ``Esset von den guten Dingen, die Wir euch beschert haben." Und sie schädigten nicht Uns, sondern sich selbst haben sie Schaden zugefügt.\qt@no{(160)}}
\qt@newcmd\qurantrans@de@mcxv{Und wenn ihnen gesagt wird: ``Wohnt in dieser Stadt und nehmet von ihr eure Speise, wo immer ihr wollt, und sprecht: ``Vergebung!" und geht durch das Tor ein, indem ihr euch niederwerft! Dann werden Wir euch eure Sünden vergeben; wahrlich, Wir werden jenen, die Gutes tun, noch mehr (an Gnade) erweisen."\qt@no{(161)}}
\qt@newcmd\qurantrans@de@mcxvi{Da vertauschten die Ungerechten unter ihnen den Ausspruch mit einem anderen als dem, der zu ihnen gesprochen worden war. Darum sandten Wir wegen ihres frevelhaften Tuns ein Strafgericht vom Himmel über sie hernieder.\qt@no{(162)}}
\qt@newcmd\qurantrans@de@mcxvii{Und frage sie nach der Stadt, die am Meer lag, und (danach,) wie sie den Sabbat entweihten, wie ihre Fische scharenweise an ihrem Sabbattage zu ihnen kamen. Doch an dem Tage, da sie den Sabbat nicht feierten, da kamen sie nicht zu ihnen. So prüften Wir sie, weil sie gefrevelt hatten.\qt@no{(163)}}
\qt@newcmd\qurantrans@de@mcxviii{Und als eine Gemeinschaft unter ihnen sagte: ``Warum ermahnt ihr Leute, die Allah vernichten oder mit einer strengen Strafe bestrafen will?" - da sagten sie (die Ermahner): ``Zur Entschuldigung vor eurem Herrn, und damit sie gottesfürchtig werden mögen."\qt@no{(164)}}
\qt@newcmd\qurantrans@de@mcxix{Und als sie das vergaßen, womit sie ermahnt worden waren, da retteten Wir jene, die das Böse verhindert hatten, und erfaßten die Ungerechten mit peinlicher Strafe, weil sie gefrevelt hatten.\qt@no{(165)}}
\qt@newcmd\qurantrans@de@mcxx{Und als sie trotzig bei dem verharrten, was ihnen verboten worden war, da sprachen Wir zu ihnen: ``Werdet denn verächtliche Affen! ``\qt@no{(166)}}
\qt@newcmd\qurantrans@de@mcxxi{Und (gedenke der Zeit,) da dein Herr verkündete, Er wolle gewiß gegen sie bis zum Tage der Auferstehung solche entsenden, die sie mit grimmiger Pein bedrängen würden. Wahrlich, dein Herr ist schnell im Strafen. Und wahrlich, Er ist Allvergebend, Barmherzig.\qt@no{(167)}}
\qt@newcmd\qurantrans@de@mcxxii{Und Wir haben sie auf Erden in Gemeinschaften zerteilt. Unter ihnen sind Rechtschaffene, und unter ihnen gibt es welche, die nicht so sind. Und Wir prüften sie durch Gutes und durch Böses, auf daß sie sich bekehren mögen.\qt@no{(168)}}
\qt@newcmd\qurantrans@de@mcxxiii{Es folgten ihnen dann Nachkommen, die die Schrift erbten; sie greifen aber nach den armseligen Gütern dieser niedrigen (Welt) und sagen: ``Es wird uns verziehen werden." Doch wenn (abermals) derartige Güter zu ihnen kämen, griffen sie wiederum danach. Wurde denn der Bund der Schrift nicht mit ihnen geschlossen, damit sie von Allah nichts als die Wahrheit aussagen sollten? Und sie haben gelesen, was darin steht. Aber die Wohnstätte im Jenseits ist besser für die Gottesfürchtigen. Wollt ihr es denn nicht begreifen?\qt@no{(169)}}
\qt@newcmd\qurantrans@de@mcxxiv{Und diejenigen, die an der Schrift festhalten und das Gebet verrichten Wir lassen den Rechtschaffenen den Lohn nicht verlorengehen.\qt@no{(170)}}
\qt@newcmd\qurantrans@de@mcxxv{Und da Wir den Berg über ihnen schüttelten, als wäre er ein Schattenspender, und sie dachten, er würde auf sie stürzen (, da sprachen Wir): `` Haltet fest, was Wir euch gegeben haben, und denkt daran, was darin steht, auf daß ihr gottesfürchtig werden möget."\qt@no{(171)}}
\qt@newcmd\qurantrans@de@mcxxvi{Und als dein Herr aus den Kindern Adams - aus ihren Lenden ihre Nachkommenschaft hervorbrachte und sie zu Zeugen gegen Sich Selbst machte (, indem Er sprach): ``Bin Ich nicht euer Herr?", sagten sie: ``Doch, wir bezeugen es." (Dies ist so,) damit ihr nicht am Tage der Auferstehung sprecht: ``Siehe, wir wußten nichts davon."\qt@no{(172)}}
\qt@newcmd\qurantrans@de@mcxxvii{Oder (damit ihr nicht) sprecht: ``Es waren bloß unsere Väter, die vordem Götzendiener waren; wir aber waren ein Geschlecht nach ihnen. Willst Du uns denn vernichten um dessentwillen, was die Verlogenen taten?"\qt@no{(173)}}
\qt@newcmd\qurantrans@de@mcxxviii{Und so machen Wir die Zeichen klar, auf daß sie sich bekehren mögen.\qt@no{(174)}}
\qt@newcmd\qurantrans@de@mcxxix{Und erzähle ihnen die Geschichte dessen, dem Wir Unsere Zeichen gaben, der aber an ihnen vorbeiglitt; so folgte Satan ihm nach, und er wurde einer der Irregegangenen.\qt@no{(175)}}
\qt@newcmd\qurantrans@de@mcxxx{Und hätten Wir es gewollt, hätten Wir ihn dadurch erhöhen können; doch er neigte der Erde zu und folgte seiner eigenen Neigung. Er gleicht daher einem Hunde: treibst du ihn fort, so hängt er seine Zunge heraus; läßt du aber von ihm ab, so hängt er auch seine Zunge heraus. Gerade so ergeht es Leuten, die Unsere Zeichen leugnen. Darum erzähle (ihnen) die Geschichten, auf daß sie sich besinnen mögen.\qt@no{(176)}}
\qt@newcmd\qurantrans@de@mcxxxi{Schlimm ist das Beispiel der Leute, die Unsere Zeichen leugnen und gegen sich selbst gesündigt haben.\qt@no{(177)}}
\qt@newcmd\qurantrans@de@mcxxxii{Derjenige, den Allah rechtleitet, ist auf dem rechten Weg. Diejenigen aber, die Er irreführt, sind wahrlich jene, die verloren haben.\qt@no{(178)}}
\qt@newcmd\qurantrans@de@mcxxxiii{Wir haben viele Ginn und Menschen erschaffen, deren Ende Gahannam sein wird! Sie haben Herzen, mit denen sie nicht begreifen, und sie haben Augen, mit denen sie nicht sehen, und sie haben Ohren, mit denen sie nicht hören; sie sind wie das Vieh; nein, sie irren noch eher (vom Weg) ab. Sie sind wahrlich unbedacht.\qt@no{(179)}}
\qt@newcmd\qurantrans@de@mcxxxiv{Und Allahs sind die Schönsten Namen; so ruft Ihn mit ihnen an. Und lasset jene sein, die hinsichtlich Seiner Namen eine abwegige Haltung einnehmen. Ihnen wird das vergolten werden, was sie getan haben.\qt@no{(180)}}
\qt@newcmd\qurantrans@de@mcxxxv{Und unter denen, die Wir erschufen, gibt es eine Gemeinschaft, die mit der Wahrheit leitet und danach Gerechtigkeit übt.\qt@no{(181)}}
\qt@newcmd\qurantrans@de@mcxxxvi{Diejenigen aber, die Unsere Zeichen leugnen, werden Wir Schritt für Schritt erniedrigen, ohne daß sie begreifen, wie dies geschah.\qt@no{(182)}}
\qt@newcmd\qurantrans@de@mcxxxvii{Und Ich werde ihnen Aufschub gewähren; denn wahrlich, Meine Pläne sind stark angelegt.\qt@no{(183)}}
\qt@newcmd\qurantrans@de@mcxxxviii{Haben sie denn nicht darüber nachgedacht, daß ihr Gefährte nicht besessen ist? Er ist nichts anderes als ein deutlicher Warner.\qt@no{(184)}}
\qt@newcmd\qurantrans@de@mcxxxix{Haben sie denn nicht das Reich der Himmel und der Erde betrachtet und alle Dinge, die Allah geschaffen hat, und (haben sie nicht bedacht,) daß sich ihre Lebensfrist vielleicht schon dem Ende nähert? Woran sonst wollen sie wohl nach dieser Verkündigung glauben?\qt@no{(185)}}
\qt@newcmd\qurantrans@de@mcxl{Für den, den Allah irreführt, kann es keinen geben, der ihn rechtleitet; und Er läßt sie in ihrer Widerspenstigkeit blindlings umherirren.\qt@no{(186)}}
\qt@newcmd\qurantrans@de@mcxli{Sie befragen dich nach der Stunde, wann sie wohl eintreten werde. Sprich: ``Das Wissen darum ist bei meinem Herrn. Keiner als Er kann sie (die Stunde) zu ihrer Zeit bekannt geben. Schwer lastet sie in den Himmeln und auf der Erde. Sie soll über euch nur plötzlich hereinbrechen." Sie befragen dich, als ob du von ihr genaue Kenntnis besäßest. Sprich: ``Das Wissen darum ist bei meinem Herrn; doch die meisten Menschen wissen es nicht."\qt@no{(187)}}
\qt@newcmd\qurantrans@de@mcxlii{Sprich: ``Ich habe nicht die Macht, mir selbst zu nützen oder zu schaden, es sei denn, Allah will es. Und hätte ich Kenntnis von dem Verborgenen, wahrlich, ich hätte mir die Fülle des Guten zu sichern vermocht, und Übeles hätte mich nicht berührt. Ich bin ja nur ein Warner und ein Bringer froher Botschaft für die Leute, die gläubig sind."\qt@no{(188)}}
\qt@newcmd\qurantrans@de@mcxliii{Er ist es, Der euch aus einer einzigen Seele erschuf; und aus ihm machte Er seine Gattin, damit er bei ihr ruhe. Als er ihr dann beigewohnt hatte, war sie mit einer leichten Last schwanger und ging mit ihr umher. Und wenn sie schwer wird, dann beten beide zu Allah, ihrem Herrn: ``Wenn Du uns ein gutes (Kind) gibst, so werden wir wahrlich unter den Dankbaren sein."\qt@no{(189)}}
\qt@newcmd\qurantrans@de@mcxliv{Doch wenn Er ihnen dann ein gutes (Kind) gibt, so schreiben sie Seine ihnen gewahrte Gabe Göttern zu. Aber Allah ist über alles Erhaben, was sie (Ihm) zur Seite stellen.\qt@no{(190)}}
\qt@newcmd\qurantrans@de@mcxlv{Wollen sie denn jene Teilhaber (anbeten), die nichts erschaffen können und selbst (nur) Erschaffene sind?\qt@no{(191)}}
\qt@newcmd\qurantrans@de@mcxlvi{Und sie vermögen ihnen keine Hilfe zu gewähren, noch können sie sich selber helfen.\qt@no{(192)}}
\qt@newcmd\qurantrans@de@mcxlvii{Und wenn ihr sie zum rechten Weg ruft, dann folgen sie euch nicht. Es ist ganz gleich für euch, ob ihr sie ruft oder ob ihr schweigt.\qt@no{(193)}}
\qt@newcmd\qurantrans@de@mcxlviii{Jene, die ihr statt Allah ruft, sind selbst erschaffene (Wesen) wie ihr. Ruft sie denn an und lasset sie euch Antwort geben, wenn ihr wahrhaftig seid.\qt@no{(194)}}
\qt@newcmd\qurantrans@de@mcxlix{Haben sie etwa Füße, um zu gehen, oder haben sie Hände, um zu greifen, oder haben sie Augen, um zu sehen, oder haben sie Ohren, um zu hören? Sprich: ``Ruft eure Götter an; dann schmiedet Listen gegen mich und lasset mich nicht lange warten.\qt@no{(195)}}
\qt@newcmd\qurantrans@de@mcl{Wahrlich, mein Beschützer ist Allah, Der das Buch herabgesandt hat. Und Er beschützt die Rechtschaffenen.\qt@no{(196)}}
\qt@newcmd\qurantrans@de@mcli{Die aber, die ihr statt Ihm anruft, vermögen euch nicht zu helfen, noch können sie sich selber helfen."\qt@no{(197)}}
\qt@newcmd\qurantrans@de@mclii{Und wenn ihr sie zum rechten Weg ruft, so hören sie (euch) nicht. Und du siehst sie nach dir schauen, doch sie sehen nicht.\qt@no{(198)}}
\qt@newcmd\qurantrans@de@mcliii{sbe Nachsicht, gebiete das Rechte und wende dich von den Unwissenden ab.\qt@no{(199)}}
\qt@newcmd\qurantrans@de@mcliv{Und wenn du zu einer bösen Tat vom Satan aufgestachelt worden bist, dann nimm deine Zuflucht bei Allah; wahrlich, Er ist Allhörend, Allwissend.\qt@no{(200)}}
\qt@newcmd\qurantrans@de@mclv{Wahrlich, diejenigen, die dann gottesfürchtig sind, wenn sie eine Heimsuchung durch Satan trifft, und sich dann ermahnen lassen: siehe, gleich sehen sie (ihren klaren Weg) wieder.\qt@no{(201)}}
\qt@newcmd\qurantrans@de@mclvi{Aber ihre (heidnischen) Brüder treiben sie dazu, im Irrtum fortzufahren, und dann lassen sie (darin) nicht nach.\qt@no{(202)}}
\qt@newcmd\qurantrans@de@mclvii{Wenn du ihnen kein Zeichen bringst, sagen sie: ``Warum erfindest du es nicht?" Sprich: ``Ich folge nur dem, was mir von meinem Herrn offenbart wurde. Dies sind sichtbare Beweise von eurem Herrn und eine Führung und Barmherzigkeit für gläubige Leute."\qt@no{(203)}}
\qt@newcmd\qurantrans@de@mclviii{Und wenn der Quran verlesen wird, so hört zu und schweigt in Aufmerksamkeit, auf daß ihr Erbarmen finden möget.\qt@no{(204)}}
\qt@newcmd\qurantrans@de@mclix{Und gedenke deines Herrn in deinem Herzen in Demut und Furcht, ohne laut vernehmbare Worte am Morgen und am Abend; und sei nicht einer der Unachtsamen.\qt@no{(205)}}
\qt@newcmd\qurantrans@de@mclx{Wahrlich, diejenigen, die bei deinem Herrn sind, sind nicht zu hochmütig dazu, Ihm zu dienen; sie lobpreisen Ihn und werfen sich vor Ihm nieder.\qt@no{(206)}}
\qt@newcmd\qurantrans@de@mclxi{\basmalahde Sie fragen dich nach der Beute. Sprich: ``Die Beute gehört Allah und dem Gesandten. Darum fürchtet Allah und ordnet die Dinge in Eintracht unter euch und gehorcht Allah und Seinem Gesandten, wenn ihr Gläubige seid."\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mclxii{Gläubig sind wahrlich diejenigen, deren Herzen erbeben, wenn Allah genannt wird, und die in ihrem Glauben gestärkt sind, wenn ihnen Seine Verse verlesen werden, und die auf ihren Herrn vertrauen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mclxiii{Das sind jene, die das Gebet verrichten und von dem spenden, was Wir ihnen gegeben haben.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mclxiv{Diese sind die wahren Gläubigen. Sie genießen (die hohe) Wertschätzung ihres Herrn sowie Vergebung und eine ehrenvolle Versorgung.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mclxv{Dies (genauso), wie dein Herr dich in gerechter Weise aus deinem Hause führte, während ein Teil der Gläubigen abgeneigt war.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mclxvi{Sie streiten mit dir über die Wahrheit, nachdem sie (ihnen) doch deutlich kund geworden ist, als ob sie in den Tod getrieben würden und (ihn) vor Augen hätten.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mclxvii{Und damals verhieß Allah euch von einer der beiden Scharen, sie solle euch zufallen, und ihr wünschtet, daß diejenige ohne Kampfkraft für euch bestimmt sei; Allah aber will, daß die Wahrheit durch Seine Worte vollbracht werde und daß die Wurzel der Ungläubigen ausgerottet werde\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mclxviii{damit Er die Wahrheit an den Tag bringe und den Trug zunichte mache, mag es den Sündern auch zuwider sein.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mclxix{Da ihr zu eurem Herrn um Hilfe schriet, und Er euch erhörte und versprach: ``Ich will euch mit eintausend Engeln nacheinander beistehen."\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mclxx{Allah sagte dies nur als frohe Botschaft, damit eure Herzen sich beruhigten. Jedoch die Hilfe kommt von Allah allein; wahrlich, Allah ist Erhaben, Allweise\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mclxxi{denn Er ließ den Schlaf als eine Sicherheit von Ihm auf euch niedersinken; und Er sandte Wasser auf euch aus den Wolken nieder, um euch damit zu reinigen und Satans Befleckung von euch hinwegzunehmen, auf daß Er eure Herzen stärkte und (eure) Schritte festigte.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mclxxii{Da gab dein Herr den Engeln ein: ``Ich bin mit euch; so festigt denn die Gläubigen. In die Herzen der Ungläubigen werde Ich Schrecken werfen. Trefft (sie) oberhalb des Nackens und schlagt ihnen jeden Finger ab!"\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mclxxiii{Dies (war so), weil sie Allah und Seinem Gesandten trotzten. Wer aber Allah und Seinem Gesandten trotzt wahrlich, Allah ist streng im Strafen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mclxxiv{Dies sollt ihr kosten; und (wisset), daß für die Ungläubigen die Feuerspein bestimmt ist.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mclxxv{O ihr, die ihr glaubt, wenn ihr auf die Ungläubigen stoßt, die im Heerzug vorrücken, so kehrt ihnen nicht den Rücken.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mclxxvi{Und derjenige, der ihnen an solch einem Tage den Rücken kehrt, es sei denn, er schwenke zur Schlacht oder zum Anschluß an einen Trupp ab, der lädt wahrlich Allahs Zorn auf sich, und seine Herberge soll Gahannam sein; und schlimm ist das Ende!\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mclxxvii{Nicht ihr habt sie erschlagen, sondern Allah erschlug sie. Und nicht du hast geschossen, sondern Allah gab den Schuß ab; und prüfen wollte Er die Gläubigen mit einer schönen Prüfung von Ihm. Wahrlich, Allah ist Allhörend, Allwissend.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mclxxviii{Dies und (wisset), daß Allah die List der Ungläubigen kraftlos machen will.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mclxxix{Verlangt ihr eine Entscheidung, dann ist die Entscheidung schon zu euch gekommen. Und wenn ihr absteht, so ist es besser für euch; kehrt ihr jedoch (zur Feindseligkeit) zurück, werden auch Wir (zu ihr) zurückkehren, und eure Menge soll euch nichts nützen, so zahlreich sie auch sein mag; denn (wisset), daß Allah mit den Gläubigen ist.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mclxxx{O ihr, die ihr glaubt, gehorcht Allah und Seinem Gesandten, und wendet euch nicht von ihm ab wahrend ihr zuhört.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mclxxxi{Und seid nicht wie jene, die sagen: ``Wir hören", und doch nicht hören.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mclxxxii{Wahrlich, die schlimmsten Tiere vor Allah sind die tauben und stummen, die nicht begreifen.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mclxxxiii{Und hätte Allah etwas Gutes in ihnen erkannt, hätte Er sie gewiß hörend gemacht. Und wenn Er sie hörend macht, so werden sie sich in Widerwillen wegwenden.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mclxxxiv{O ihr, die ihr glaubt, hört auf Allah und den Gesandten, wenn er euch zu etwas aufruft, das euch Leben verleiht, und wisset, daß Allah zwischen den Menschen und sein Herz tritt, und daß ihr vor Ihm versammelt werdet.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mclxxxv{Und hütet euch vor einer Drangsal, die gewiß nicht bloß die unter euch treffen wird, die Unrecht getan haben. Und wisset, daß Allah streng im Strafen ist.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mclxxxvi{Und denkt daran, wie wenige ihr waret, im Land als schwach galtet, in Furcht schwebtet, die Leute könnten euch hinwegraffen: Er aber beschirmte euch und stärkte euch durch Seine Hilfe und versorgte euch mit guten Dingen, auf daß ihr dankbar sein möget.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mclxxxvii{O ihr, die ihr glaubt, handelt nicht untreu gegenüber Allah und dem Gesandten, noch seid wissentlich untreu in eurer Treuhandschaft.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mclxxxviii{Und wisset, daß euer Gut und eure Kinder nur eine Versuchung sind und daß bei Allah großer Lohn ist.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mclxxxix{O ihr, die ihr glaubt, wenn ihr Allah fürchtet, wird Er euch Entscheidungskraft gewähren und eure Übel von euch nehmen und euch vergeben; und Allah ist voll großer Huld.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mcxc{Und damals schmiedeten die Ungläubigen gegen dich Pläne, dich gefangen zu nehmen oder dich zu ermorden oder dich zu vertreiben. Sie schmiedeten Pläne, (aber) auch Allah schmiedete Pläne, und Allah ist der beste Planschmied.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mcxci{Und wenn ihnen Unsere Verse verlesen werden, sagen sie: ``Wir haben es gehört. Wollten wir es, könnten wir gewiß Derartiges äußern; denn das sind ja Fabeln der Früheren."\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mcxcii{Und da sagten sie: ``O Allah, wenn dies wirklich die Wahrheit von Dir ist, dann laß Steine vom Himmel auf uns niederregnen oder bringe eine schmerzliche Strafe auf uns herab."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mcxciii{Allah aber wollte sie nicht bestrafen, solange du unter ihnen weiltest, noch wollte Allah sie bestrafen, während sie um Vergebung baten.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mcxciv{Aber, warum sollte Allah sie nicht bestrafen, wenn sie (die Gläubigen) von (dem Besuch) der heiligen Moschee abhalten, wo sie doch nicht deren Beschützer sind? Ihre Beschützer sind nur die Gottesfürchtigen, jedoch die meisten von ihnen wissen es nicht.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mcxcv{Und ihr Gebet vor dem Haus (Ka`ba) ist nichts anderes als Pfeifen und Händeklatschen. ``Kostet denn die Strafe dafür, daß ihr ungläubig waret."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mcxcvi{Die Ungläubigen geben wahrlich ihr Vermögen (dafür) aus, um von Allahs Weg abzuhalten. Sie werden es ausgeben; dann aber werden sie darüber jammern, und dann werden sie besiegt werden. Und die Ungläubigen werden in Gahannam versammelt werden\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mcxcvii{auf daß Allah die Bösen von den Guten scheide, und die Bösen einen zum anderen und sie alle zusammen auf einen Haufen versammele (und) sie dann in Gahannam werfe. Diese sind wahrlich die Verlierer.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mcxcviii{Sprich zu denen, die ungläubig sind, daß ihnen das Vergangene verziehen wird, wenn sie (von ihrem Unglauben) absehen; kehren sie aber (zum Unglauben) zurück, dann wahrlich, ist das Beispiel der Früheren schon dagewesen.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mcxcix{Und kämpft gegen sie, damit keine Verführung mehr stattfinden kann und (kämpft,) bis sämtliche Verehrung auf Allah allein gerichtet ist. Stehen sie jedoch (vom Unglauben) ab, dann, wahrlich, sieht Allah sehr wohl, was sie tun.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mcc{Und wenn sie (euch) den Rücken kehren, dann wisset, daß Allah euer Beschützer ist; welch bester Beschützer und welch bester Helfer ist Er!\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mcci{Und wisset, was immer ihr erbeuten mögt, ein Fünftel davon gehört Allah und dem Gesandten und der Verwandtschaft und den Waisen und den Bedürftigen und den Sohn des Weges, wenn ihr an Allah glaubt und an das, was Wir zu Unserem Diener niedersandten am Tage der Unterscheidung - dem Tage, an dem die beiden Heere zusammentrafen -; und Allah hat Macht über alle Dinge.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mccii{(Damals,) als ihr auf dieser Seite (des Tales) waret und sie auf jener Seite und die Karawane tiefer war als ihr. Und hättet ihr etwas verabreden wollen, wäret ihr uneins über den Zeitpunkt gewesen. Doch (das Treffen wurde herbeigeführt), damit Allah die Sache herbeiführte, die geschehen sollte; und damit diejenigen, die (dabei) umkamen, auf Grund eines klaren Beweises umkämen, und diejenigen, die am Leben blieben, auf Grund eines klaren Beweises am Leben bleiben würden. Wahrlich, Allah ist Allhörend, Allwissend.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mcciii{(Damals als Allah sie dir in deinem Traum in geringer Anzahl zeigte; und hätte Er sie dir in großer Anzahl gezeigt, wäret ihr sicherlich Versager und über die Sache uneins gewesen; Allah aber bewahrte (euch davor); wahrlich, Er kennt wohl, was in den Herzen ist.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mcciv{Zur Zeit eures Treffens geschah es, daß Er sie in euren Augen als zahlenmäßig gering erscheinen ließ und euch in ihren Augen als zahlenmäßig gering erscheinen ließ, auf daß Allah die Sache herbeiführte, die geschehen sollte. Und zu Allah werden alle Angelegenheiten zurückgebracht.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mccv{O ihr, die ihr glaubt, wenn ihr auf eine Schar stoßt, so bleibt fest und denkt eifrig an Allah, auf daß ihr erfolgreich sein möget.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mccvi{Und gehorcht Allah und Seinem Gesandten und hadert nicht miteinander, damit ihr nicht versaget und euch die Kampfkraft nicht verläßt. Seid geduldig; wahrlich, Allah ist mit den Geduldigen.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mccvii{Und seid nicht wie jene, die prahlerisch und, um von den Leuten gesehen zu werden, aus ihren Wohnstätten auszogen, und die von Allahs Weg abhalten. Und Allah umfaßt das, was sie tun.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mccviii{Und da ließ Satan ihnen ihre Werke als wohlgefällig erscheinen und sagte: ``Keiner unter den Menschen soll heute etwas gegen euch ausrichten können, und ich bin eure Stütze." Als jedoch die beiden Heerscharen einander ansichtig wurden, da wandte er sich auf seinen Fersen um und sagte: ``Ich habe nichts mit euch zu schaffen; ich sehe, was ihr nicht seht. Ich fürchte Allah; und Allah ist streng im Strafen."\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mccix{Da sagten die Heuchler und diejenigen, in deren Herzen Krankheit war: ``Ihr Glaube hat diese da hochmütig gemacht." Wer aber auf Allah vertraut - siehe, Allah ist Erhaben, Allweise.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mccx{Könntest du nur sehen, wie die Engel die Seelen der Ungläubigen hinwegnehmen, während sie ihnen Gesicht und Rücken schlagen und (sprechen): ``Kostet die Strafe des Verbrennens!\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mccxi{Dies (geschieht) um dessentwillen, was eure Hände (euch) vorausgeschickt haben; und (wisset), daß Allah niemals ungerecht gegen die Diener ist."\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mccxii{(Es wird ihnen) wie den Leuten Pharaos und denen (ergehen), die vor ihnen waren: Sie glaubten nicht an die Zeichen Allahs; darum bestrafte Allah sie für ihre Sünden. Wahrlich, Allah ist Allmächtig und streng im Strafen.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mccxiii{Dies (ist so), weil Allah niemals eine Gnade ändern würde, die Er einem Volk gewährt hat, es sei denn, daß es seine eigene Einstellung änderte, und weil Allah Allhörend, Allwissend ist.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mccxiv{(Es wird ihnen) wie den Leuten Pharaos und denen (ergehen), die vor ihnen waren: Sie hielten die Zeichen ihres Herrn für eine Lüge, darum ließen Wir sie zugrunde gehen um ihrer Sünden willen, und Wir ertränkten die Leute Pharaos; sie alle waren Frevler.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mccxv{Wahrlich, schlimmer als das Vieh sind bei Allah jene, die ungläubig sind und nicht glauben werden\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mccxvi{es sind jene, mit denen du einen Bund geschlossen hast; dann brechen sie jedesmal ihren Bund, und sie fürchten (Allah) nicht.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mccxvii{Darum, wenn du sie im Kriege anpackst, verscheuche mit ihnen diejenigen, die hinter ihnen sind, auf daß sie ermahnt seien.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mccxviii{Und wenn du von einem Volk Verrat fürchtest, so verwirf (den) gegenseitigen (Vertrag) Wahrlich, Allah liebt nicht die Verräter.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mccxix{Laß die Ungläubigen nicht meinen, sie hätten (Uns) übertroffen. Wahrlich, sie können nicht siegen.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mccxx{Und rüstet gegen sie auf, soviel ihr an Streitmacht und Schlachtrossen aufbieten könnt, damit ihr Allahs Feind und euren Feind - und andere außer ihnen, die ihr nicht kennt abschreckt; Allah kennt sie (alle) Und was ihr auch für Allahs Sache aufwendet, es wird euch voll zurückgezahlt werden, und es soll euch kein Unrecht geschehen.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mccxxi{Und wenn sie jedoch zum Frieden geneigt sind, so sei auch du ihm geneigt und vertraue auf Allah. Wahrlich, Er ist der Allhörende, der Allwissende.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mccxxii{Wenn sie dich aber hintergehen wollen, dann laß es dir an Allah genügen. Er hat dich mit Seiner Hilfe und mit den Gläubigen gestärkt.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mccxxiii{Und Er hat zwischen ihren Herzen Freundschaft gestiftet. Hättest du auch alles aufgewandt, was auf Erden ist, du hättest doch nicht Freundschaft in ihre Herzen zu legen vermocht, Allah aber hat Freundschaft in sie gelegt. Wahrlich, Er ist Erhaben, Allweise.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mccxxiv{O Prophet, Allah soll dir vollauf genügen und denen, die dir folgen unter den Gläubigen.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mccxxv{O Prophet, feuere die Gläubigen zum Kampf an. Sind auch nur zwanzig unter euch, die Geduld haben, so sollen sie zweihundert überwältigen; und sind einhundert unter euch, so werden sie eintausend von denen überwältigen, die ungläubig sind, weil das ein Volk ist, das nicht begreift.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mccxxvi{Jetzt aber hat Allah euch eure Bürde erleichtert; denn Er weiß, daß ihr schwach seid. Wenn also unter euch einhundert sind, die Geduld haben, so sollen sie zweihundert überwältigen; und wenn eintausend unter euch sind, so sollen sie zweitausend mit der Erlaubnis Allahs überwältigen. Und Allah ist mit den Geduldigen.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mccxxvii{Einem Propheten geziemt es nicht, Gefangene zu (be-)halten, sofern er nicht heftig auf dieser Erde gekämpft hat. Ihr wollt die Güter dieser Welt, Allah aber will (für euch) das Jenseits. Und Allah ist Erhaben, Allweise.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mccxxviii{Wäre nicht schon eine Bestimmung von Allah dagewesen, so hätte euch gewiß eine schwere Strafe getroffen um dessentwillen, was ihr (euch) genommen hattet.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mccxxix{So esset von dem, was ihr erbeutet habt, soweit es erlaubt und gut ist, und fürchtet Allah. Wahrlich, Allah ist Allvergebend, Barmherzig.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mccxxx{O Prophet, sprich zu den (Kriegs-) Gefangenen, die in euren Händen sind: ``Erkennt Allah Gutes in euren Herzen, dann wird Er euch (etwas) Besseres geben als das, was euch genommen wurde, und wird euch vergeben. Denn Allah ist Allvergebend, Barmherzig."\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mccxxxi{Wenn sie aber Verrat an dir üben wollen, so haben sie schon zuvor an Allah Verrat geübt. Er aber gab (dir) Macht über sie; und Allah ist Allwissend, Allweise.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mccxxxii{Wahrlich, diejenigen, die geglaubt haben und ausgewandert sind und mit ihrem Gut und ihrem Blut für Allahs Sache gekämpft haben, und jene, die (ihnen) Herberge und Hilfe gaben - diese sind einander Freund. Für den Schutz derjenigen aber, die glaubten, jedoch nicht ausgewandert sind, seid ihr keineswegs verantwortlich, sofern sie (nicht doch noch) auswandern. Suchen sie aber eure Hilfe für den Glauben, dann ist das Helfen eure Pflicht, (es sei denn, sie bitten euch) gegen ein Volk (um Hilfe), zwischen dem und euch ein Bündnis besteht. Und Allah sieht euer Tun.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mccxxxiii{Und die Ungläubigen - (auch) sie sind einander Beschützer. Wenn ihr das nicht tut, wird Verwirrung im Lande und gewaltiges Unheil entstehen.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mccxxxiv{Und diejenigen, die geglaubt haben und ausgewandert sind und für Allahs Sache gekämpft haben, und jene, die (ihnen) Herberge und Hilfe gaben - diese sind in der Tat wahre Gläubige. Ihnen wird Vergebung und eine ehrenvolle Versorgung zuteil sein.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mccxxxv{Und die, welche hernach glauben und auswandern und (für Allahs Sache) an eurer Seite kämpfen werden - sie gehören zu euch; und (unter) Blutsverwandten stehen sich im Buche Allahs die einen näher als die anderen. Wahrlich, Allah weiß wohl alle Dinge.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mccxxxvi{\basmalahde (Dies ist) eine Lossprechung (von jeglicher Verpflichtung) seitens Allahs und Seines Gesandten; (sie ist) an diejenigen Götzendiener (gerichtet), mit denen ihr ein Bündnis abgeschlossen habt.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mccxxxvii{So zieht denn vier Monate lang im Lande umher und wisset, daß ihr Allahs (Plan) nicht zuschanden machen könnt und daß Allah die Ungläubigen demütigen wird.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mccxxxviii{Und (dies ist) eine Ankündigung von Allah und Seinem Gesandten an die Menschen am Tage der großen Pilgerfahrt, daß Allah der Götzendiener ledig ist und ebenso Sein Gesandter. Bereut ihr also, so wird das besser für euch sein; kehrt ihr euch jedoch ab, so wisset, daß ihr Allahs (Plan) nicht zuschanden machen könnt. Und verheiße denen schmerzliche Strafe, die ungläubig sind.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mccxxxix{Davon sind diejenigen Götzendiener ausgenommen, mit denen ihr einen Vertrag eingegangen seid und die es euch an nichts haben fehlen lassen und die keine anderen gegen euch unterstützt haben. Diesen gegenüber haltet den Vertrag bis zum Ablauf der Frist ein. Wahrlich, Allah liebt diejenigen, die (Ihn) fürchten.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mccxl{Und wenn die heiligen Monate abgelaufen sind, dann tötet die Götzendiener, wo immer ihr sie findet, und ergreift sie und belagert sie und lauert ihnen aus jedem Hinterhalt auf. Wenn sie aber bereuen und das Gebet verrichten und die Zakah entrichten, dann gebt ihnen den Weg frei. Wahrlich, Allah ist Allvergebend, Barmherzig\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mccxli{und wenn einer der Götzendiener bei dir Schutz sucht, dann gewähre ihm Schutz, bis er Allahs Worte vernehmen kann; hierauf lasse ihn den Ort seiner Sicherheit erreichen. Dies (soll so sein), weil sie ein unwissendes Volk sind.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mccxlii{Wie kann es einen Vertrag geben zwischen den Götzendienern und Allah und Seinem Gesandten - allein die ausgenommen, mit denen ihr bei der heiligen Moschee ein Bündnis eingingt -? Solange diese euch die Treue halten, haltet ihnen die Treue. Wahrlich, Allah liebt diejenigen, die (Ihn) fürchten.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mccxliii{Wie? Würden sie doch, wenn sie euch besiegten, weder Bindungen noch Verpflichtungen euch gegenüber einhalten! Sie würden euch mit dem Munde gefällig sein, indes ihre Herzen sich weigerten; und die meisten von ihnen sind Frevler.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mccxliv{Sie verkaufen Allahs Zeichen für einen geringen Preis und halten von Seinem Weg ab. Übel ist wahrlich, was sie tun.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mccxlv{Sie achten keine Bindung und keine Verpflichtung gegenüber einem Gläubigen; und sie sind die Übertreter.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mccxlvi{Bereuen sie aber und verrichten sie das Gebet und entrichten sie die Zakah, so sind sie eure Brüder im Glauben. Und Wir machen die Zeichen klar für die wissenden Leute.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mccxlvii{Wenn sie aber nach ihrem Vertrag ihre Eide brechen und euren Glauben angreifen, dann bekämpft die Anführer des Unglaubens - sie halten ja keine Eide -, so daß sie (davon) ablassen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mccxlviii{Wollt ihr nicht gegen Leute kämpfen, die ihre Eide gebrochen haben und die den Gesandten zu vertreiben planten - sie waren es ja, die euch zuerst angegriffen haben -? Fürchtet ihr sie etwa? Allahs Würde geziemt es eher, daß ihr Ihn fürchtet, wenn ihr Gläubige seid.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mccxlix{Bekämpft sie; so wird Allah sie durch eure Hand bestrafen und demütigen und euch gegen sie helfen und den Herzen eines gläubigen Volkes Heilung bringen\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mccl{und Er wird die Wut aus ihren Herzen bannen. Und Allah kehrt Sich gnädig dem zu, dem Er will. Und Allah ist Allwissend, Allweise.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mccli{Meint ihr etwa, ihr würdet verlassen sein, wo Allah doch noch nicht jene von euch gezeichnet hat, die (in Seiner Sache) kämpfen und sich keinen zum Vertrauten nehmen außer Allah und Seinen Gesandten und die Gläubigen? Und Allah weiß recht wohl, was ihr tut.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mcclii{Die Götzendiener dürfen keine Erhaltung der Moscheen Allahs vornehmen, solange sie gegen sich selbst den Unglauben bezeugen. Sie sind es, deren Werke nichtig sein sollen, und sie müssen auf ewig im Feuer bleiben.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mccliii{Wahrlich, der allein vermag die Erhaltung der Moscheen Allahs vorzunehmen, der an Allah und an den Jüngsten Tag glaubt und das Gebet verrichtet und die Zakah entrichtet und keinen außer Allah fürchtet: diese also mögen unter denen sein, welche den rechten Weg finden.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mccliv{Wollt ihr etwa die Tränkung der Pilger und die Erhaltung der heiligen Moschee (den Werken) dessen gleichsetzen, der an Allah und an den Jüngsten Tag glaubt und auf Allahs Weg kämpft? Vor Allah sind sie nicht gleich. Und Allah weist nicht den ungerechten Leuten den Weg.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mcclv{Diejenigen, die glauben und auswandern und mit ihrem Gut und ihrem Blut für Allahs Sache kämpfen, nehmen den höchsten Rang bei Allah ein; und sie sind es, die gewinnen werden.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mcclvi{Ihr Herr verheißt ihnen Seine Barmherzigkeit und Sein Wohlgefallen und Gärten, in deren ewiger Wonne sie sein werden.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mcclvii{Dort werden sie auf ewig und immerdar verweilen. Wahrlich, bei Allah ist ein riesiger Lohn.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mcclviii{O ihr, die ihr glaubt, nehmt nicht eure Väter und eure Brüder zu Beschützern, wenn sie den Unglauben dem Glauben vorziehen. Und diejenigen von euch, die sie zu Beschützern nehmen das sind die Ungerechten.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mcclix{Sprich: ``Wenn eure Väter und eure Söhne und eure Brüder und eure Frauen und eure Verwandten und das Vermögen, das ihr euch erworben habt, und der Handel, dessen Niedergang ihr fürchtet, und die Wohnstätten, die ihr liebt, euch lieber sind als Allah und Sein Gesandter und das Kämpfen für Seine Sache, dann wartet, bis Allah mit Seiner Entscheidung kommt; und Allah weist den Ungehorsamen nicht den Weg."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mcclx{Wahrlich, Allah half euch schon an vielen Orten zum Sieg, und am Tage von Hunain, als eure große Zahl euch stolz machte - doch sie nutzte euch nichts, und die Erde wurde euch in ihrer Weite eng - da wandtet ihr euch zur Flucht.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mcclxi{Dann sandte Allah Seinen Frieden auf Seinen Gesandten und auf die Gläubigen herab und sandte Heerscharen hernieder, die ihr nicht saht, und strafte jene, die ungläubig waren. Das ist der Lohn der Ungläubigen.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mcclxii{Doch hernach kehrt Sich Allah gnädig dem zu, dem Er will; und Allah ist Allvergebend, Barmherzig.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mcclxiii{O ihr, die ihr glaubt! Wahrlich, die Götzendiener sind unrein. Darum dürfen sie sich nach diesem ihrem Jahr der heiligen Moschee nicht nähern. Und falls ihr Armut befürchtet, so wird euch Allah gewiß aus Seiner Fülle reich machen, wenn Er will. Wahrlich, Allah ist Allwissend, Allweise.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mcclxiv{Kämpft gegen diejenigen, die nicht an Allah und an den Jüngsten Tag glauben, und die das nicht für verboten erklären, was Allah und Sein Gesandter für verboten erklärt haben, und die nicht dem wahren Glauben folgen von denen, die die Schrift erhalten haben, bis sie eigenhändig den Tribut in voller Unterwerfung entrichten.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mcclxv{Und die Juden sagen, Esra sei Allahs Sohn, und die Christen sagen, der Messias sei Allahs Sohn. Das ist das Wort aus ihrem Mund. Sie ahmen die Rede derer nach, die vordem ungläubig waren. Allahs Fluch über sie! Wie sind sie (doch) irregeleitet!\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mcclxvi{Sie haben sich ihre Schriftgelehrten und Mönche zu Herren genommen außer Allah; und den Messias, den Sohn der Maria. Und doch war ihnen geboten worden, allein den Einzigen Gott anzubeten. Es ist kein Gott außer Ihm. Gepriesen sei Er über das, was sie (Ihm) zur Seite stellen!\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mcclxvii{Sie wollten Allahs Licht mit ihrem Munde auslöschen; jedoch Allah will nichts anderes, als Sein Licht zu vollenden; mag es den Ungläubigen auch zuwider sein.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mcclxviii{Er ist es, Der Seinen Gesandten mit der Führung und der wahren Religion geschickt hat, auf daß Er sie über alle (anderen) Religionen siegen lasse; mag es den Götzendienern auch zuwider sein.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mcclxix{O ihr, die ihr glaubt, wahrlich, viele der Schriftgelehrten und Mönche verzehren das Gut der Menschen zu Unrecht und wenden sie von Allahs Weg ab. Und jenen, die Gold und Silber horten und es nicht für Allahs Weg verwenden ihnen verheiße schmerzliche Strafe.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mcclxx{An dem Tage, wo es (Gold und Silber) im Feuer der Gahannam glühend gemacht wird und ihre Stirnen und ihre Seiten und ihre Rücken damit gebrandmarkt werden (, wird ihnen gesagt): ``Dies ist, was ihr für euch selbst gehortet habt; kostet nun, was ihr zu horten pflegtet."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mcclxxi{Wahrlich, die Zahl der Monate bei Allah beträgt zwölf Monate; (so sind sie) im Buche Allahs (festgelegt worden) seit dem Tage, da Er die Himmel und die Erde erschuf. Von diesen (Monaten) sind vier heilig. Das ist der beständige Glaube. Darum versündigt euch nicht in diesen (Monaten) Und bekämpft die Götzendiener allesamt, wie sie euch allesamt bekämpfen; und wisset, daß Allah mit denjenigen ist, die Ihn fürchten.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mcclxxii{Das Verschieben (eines heiligen Monats) ist nur eine Steigerung des Unglaubens. Die Ungläubigen werden dadurch irregeführt. Sie erlauben es in einem Jahr und verbieten es in einem anderen Jahr, damit sie eine Übereinstimmung in der Anzahl (der Monate) erreichen, die Allah heilig gemacht hat, und so erlauben sie das, was Allah verwehrt hat. Das Böse ihrer Taten wird ihnen schön vor Augen geführt. Doch Allah weist dem ungläubigen Volk nicht den Weg.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mcclxxiii{O ihr, die ihr glaubt, was ist mit euch, daß ihr euch schwer zur Erde sinken lasset, wenn euch gesagt wird: ``Zieht aus auf Allahs Weg"? Würdet ihr euch denn mit dem diesseitigen Leben statt mit jenem im Jenseits zufrieden geben? Doch der Genuß des irdischen Lebens ist gar gering, verglichen mit dem des Jenseits.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mcclxxiv{Wenn ihr nicht auszieht, wird Er euch mit schmerzlicher Strafe bestrafen und wird an eurer Stelle ein anderes Volk erwählen, und ihr werdet Ihm gewiß keinen Schaden zufügen. Und Allah hat Macht über alle Dinge.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mcclxxv{Wenn ihr ihm nicht helft, so (wisset, daß) Allah ihm damals half, als die Ungläubigen ihn vertrieben haben -, wie sie da beide in der Höhle waren und er zu seinem Begleiter sagte: ``Sei nicht traurig; denn Allah ist mit uns." Da ließ Allah Seinen Frieden auf ihn herab und stärkte ihn mit Heerscharen, die ihr nicht saht, und erniedrigte das Wort der Ungläubigen; und Allahs Wort allein ist das höchste. Und Allah ist Erhaben, Allweise.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mcclxxvi{Zieht aus, leicht und schwer, und kämpft mit eurem Gut und mit eurem Blut für Allahs Sache! Das ist besser für euch, wenn ihr es nur wüßtet!\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mcclxxvii{Hätte es sich um einen nahen Gewinn und um eine kurze Reise gehandelt, wären sie dir gewiß gefolgt, doch die schwere Reise schien ihnen zu lang. Und doch werden sie bei Allah schwören: ``Hätten wir es vermocht, wären wir sicherlich mit euch ausgezogen." Sie fügen sich selbst Schaden zu; und Allah weiß, daß sie Lügner sind.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mcclxxviii{Allah verzeihet dir! Warum erlaubtest du ihnen (zurückzubleiben), bis die, welche die Wahrheit sagten, dir bekannt wurden und du die Lügner erkanntest?\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mcclxxix{Diejenigen, die an Allah und an den Jüngsten Tag glauben, bitten dich nicht um Erlaubnis, nicht mit ihrem Gut und ihrem Blut kämpfen zu müssen, und Allah kennt diejenigen recht wohl, die (Ihn) fürchten.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mcclxxx{Nur die werden dich um Erlaubnis bitten, (dem Kampf fernzubleiben,) die nicht an Allah und an den Jüngsten Tag glauben und deren Herzen voller Zweifel sind; und in ihrem Zweifel schwanken sie.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mcclxxxi{Wären sie aber zum Ausmarsch entschlossen gewesen, hätten sie sich doch gewiß für ihn gerüstet; doch Allah wollte ihren Abmarsch nicht. So hielt Er sie zurück, und es wurde gesagt: ``Sitzet (daheim) bei den Sitzenden."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mcclxxxii{Wären sie mit euch ausgezogen, hätten sie nur eure Sorgen vermehrt und wären in eurer Mitte hin- und hergelaufen und hätten Zwietracht unter euch erregt. Und unter euch sind manche, die auf sie gehört hätten, aber Allah kennt die Frevler wohl.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mcclxxxiii{Schon vorher trachteten sie nach Verwirrung und schmiedeten Pläne gegen dich, bis die Wahrheit kam und Allahs Wille durchgesetzt wurde, obgleich es ihnen zuwider war.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mcclxxxiv{Und unter ihnen ist so mancher, der sagt: ``Erlaube mir (zurückzubleiben), und stelle mich nicht auf die Probe." Hört! Ihre Probe hat sie ja schon ereilt. Und wahrlich, Gahannam wird die Ungläubigen einschließen.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mcclxxxv{Geschieht dir etwas Gutes, so betrübt es sie; doch wenn dich ein Unheil trifft, sagen sie: ``Wir hatten uns ja schon vorher abgesichert." Und sie wenden sich voller Freude ab.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mcclxxxvi{Sprich: ``Nichts kann uns treffen außer dem, was Allah uns bestimmt hat. Er ist unser Beschützer. Und auf Allah sollen die Gläubigen vertrauen."\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mcclxxxvii{Sprich: ``Ihr wartet darauf, daß uns nur eines der beiden guten Dinge ereilt, während wir, was euch betrifft, darauf warten, daß Allah euch mit einer Strafe treffen wird, die entweder von Ihm Selbst oder durch unsere Hände (über euch kommen wird) Wartet denn ab, und wir werden mit euch abwarten."\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mcclxxxviii{Sprich: ``Spendet willig oder unwillig, es wird doch nicht von euch angenommen. Denn wahrlich, ihr seid frevelhafte Leute."\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mcclxxxix{Ihre Spenden werden nur deshalb nicht angenommen, weil sie nicht an Allah und an Seinen Gesandten glauben und nur träge zum Gebet kommen und ihre Spenden nur widerwillig geben.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mccxc{Wundere dich weder über ihr Gut noch über ihre Kinder. Allah will sie damit nur im irdischen Leben bestrafen, und ihre Seelen sollen verscheiden, während sie (noch) ungläubig sind.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mccxci{Und sie schwören bei Allah, daß sie wahrhaftig zu euch gehören; doch sie gehören nicht zu euch, sondern sie sind ängstliche Leute.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mccxcii{Könnten sie nur einen Zufluchtsort finden oder Höhlen oder ein Schlupfloch, würden sie gewiß in wilder Hast dorthin eilen.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mccxciii{Unter ihnen sind jene, die dir wegen der Almosen Vorwürfe machen. Erhalten sie welche, so sind sie zufrieden; erhalten sie aber keine, siehe, dann sind sie verdrossen.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mccxciv{Wären sie mit dem zufrieden gewesen, was Allah und Sein Gesandter ihnen gegeben hatten, und hätten sie nur gesagt: ``Wir lassen uns an Allah genügen: Allah wird uns aus Seiner Fülle geben und ebenso Sein Gesandter. Zu Allah wollen wir uns als Bittende begeben!"\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mccxcv{Wahrlich, die Almosen sind nur für die Armen und Bedürftigen und für die mit der Verwaltung (der Almosen) Beauftragten und für die, deren Herzen gewonnen werden sollen, für die (Befreiung von) Sklaven und für die Schuldner, für die Sache Allahs und für den Sohn des Weges; (dies ist) eine Vorschrift von Allah. Und Allah ist Allwissend, Allweise.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mccxcvi{Und unter ihnen sind jene, die den Propheten kränken und sagen: ``Er hört (auf alles)" Sprich: ``Er hört für euch nur auf das Gute: Er glaubt an Allah und vertraut den Gläubigen und erweist denen unter euch Barmherzigkeit, die gläubig sind." Und denen, die den Gesandten Allahs kränken, wird eine schmerzliche Strafe zuteil sein.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mccxcvii{Sie schwören euch bei Allah, um euch zufriedenzustellen; jedoch Allahs und Seines Gesandten Würde geziemt es mehr, Ihm zu gefallen, wenn sie gläubig sind.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mccxcviii{Wissen sie denn nicht, daß für den, der Allah und Seinem Gesandten zuwiderhandelt, das Feuer der Gahannam bestimmt ist? Darin wird er auf ewig bleiben; das ist die große Demütigung.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mccxcix{Die Heuchler fürchten, es könnte gegen sie eine Sura herabgesandt werden, die ihnen ankündet, was in ihren Herzen ist. Sprich: ``Spottet nur! Allah wird alles ans Licht bringen, wovor ihr euch fürchtet."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mccc{Und wenn du sie fragst, so werden sie gewiß sagen: ``Wir plauderten nur und scherzten." Sprich: ``Galt euer Spott etwa Allah und Seinen Zeichen und Seinem Gesandten?\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mccci{Versucht euch nicht zu entschuldigen. Ihr seid ungläubig geworden, nachdem ihr geglaubt habt. Wenn Wir einem Teil von euch vergeben, so bestrafen (Wir) den anderen Teil deshalb, weil sie Sünder waren."\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mcccii{Die Heuchler und Heuchlerinnen gehören zueinander. Sie gebieten das Böse und verbieten das Gute; und ihre Hände bleiben geschlossen. Sie haben Allah vergessen, und so hat Er sie vergessen. Wahrlich, die Heuchler sind wahre Frevler.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mccciii{Allah hat den Heuchlern und Heuchlerinnen und den Ungläubigen das Feuer der Gahannam versprochen; darin werden sie auf ewig bleiben. Das wird genug für sie sein. Und Allah hat sie verflucht, und ihnen wird eine dauernde Strafe zuteil sein\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mccciv{wie jenen, die vor euch waren. Sie waren mächtiger als ihr an Kraft und reicher an Gut und Kindern. Sie erfreuten sich ihres Loses; auch ihr habt euch eures Loses erfreut, gerade so wie jene vor euch sich ihres Loses erfreuten. Und ihr ergötztet euch an müßiger Rede, wie jene sich an müßiger Rede ergötzten. Ihre Werke sollen ihnen nichts fruchten, weder in dieser Welt noch im Jenseits. Und sie sind die Verlierer.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mcccv{Hat sie nicht die Kunde von denen erreicht, die vor ihnen waren vom Volke Noahs, von `Ad und Tamud und vom Volke Abrahams und den Bewohnern Madyans und der zusammengestürzten Städte? Ihre Gesandten kamen mit deutlichen Zeichen zu ihnen. Allah also wollte ihnen kein Unrecht tun, doch sie taten sich selber Unrecht.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mcccvi{Und die gläubigen Männer und die gläubigen Frauen sind einer des anderen Freund: Sie gebieten das Gute und verbieten das Böse und verrichten das Gebet und entrichten die Zakah und gehorchen Allah und Seinem Gesandten. Sie sind es, derer Allah Sich erbarmen wird. Wahrlich, Allah ist Erhaben, Allweise.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mcccvii{Allah hat den gläubigen Männern und den gläubigen Frauen verheißen, immerdar in Gärten zu verweilen, die von Bächen durchflossen werden, und (hat ihnen) herrliche Wohnstätten in den Gärten von Eden (verheißen) Allahs Wohlgefallen aber ist noch größer. Das ist der gewaltige Gewinn.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mcccviii{O Prophet, kämpfe gegen die Ungläubigen und die Heuchler. Und sei streng mit ihnen. Ihre Herberge ist Gahannam, und schlimm ist das Ende.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mcccix{Sie schwören bei Allah, daß sie nichts gesagt hätten, doch sie führten unzweifelhaft lästerliche Rede, und sie fielen in den Unglauben zurück, nachdem sie den Islam angenommen hatten. Sie begehrten das, was sie nicht erreichen könnten. Und sie nährten nur darum Haß, weil Allah und Sein Gesandter - sie in Seiner Huld reich gemacht hatten. Wenn sie nun bereuen, so wird es besser für sie sein; wenden sie sich jedoch (vom Glauben) ab, so wird Allah sie in dieser Welt und im Jenseits mit schmerzlicher Strafe bestrafen, und sie haben auf Erden weder Freund noch Helfer.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mcccx{Und unter ihnen sind so manche, die Allah versprachen: ``Wenn Er uns aus Seiner Fülle gibt, dann wollen wir bestimmt Almosen geben und rechtschaffen sein."\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mcccxi{Doch als Er ihnen dann aus Seiner Fülle gab, geizten sie damit und wandten sich in Abneigung ab.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mcccxii{Zur Vergeltung pflanzte Er Heuchelei in ihre Herzen. (Sie währt) bis zu dem Tage, an dem sie Ihm begegnen werden, weil sie Allah nicht gehalten haben, was sie Ihm versprochen hatten, und weil sie gelogen hatten.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mcccxiii{Wußten sie denn nicht, daß Allah ihre Geheimnisse und ihre vertraulichen Beratungen kennt, und daß Allah der Kenner des Verborgenen ist?\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mcccxiv{Diejenigen, die da jene Gläubigen schelten, die freiwillig Almosen geben, wie auch jene, die nichts (zu geben) finden als ihre eigene Leistung, und sie deswegen verhöhnen, denen wird Allah ihren Hohn vergelten, und ihnen wird eine schmerzliche Strafe zuteil sein.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mcccxv{Ob du für sie um Verzeihung bittest oder nicht um Verzeihung für sie bittest, oder ob du siebzigmal für sie um Verzeihung bittest, Allah wird ihnen niemals verzeihen. Deshalb, weil sie nicht an Allah und Seinen Gesandten glaubten. Und Allah weist den frevelhaften Leuten nicht den Weg.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mcccxvi{Jene, die zurückgelassen worden waren, freuten sich ihres Daheimbleibens hinter dem (Rücken des) Gesandten Allahs und waren nicht geneigt, mit ihrem Gut und mit ihrem Blut für Allahs Sache zu kämpfen. Sie sagten: ``Zieht doch nicht in der Hitze aus." Sprich: ``Das Feuer der Gahannam ist von stärkerer Hitze." Wenn sie doch nur begreifen könnten!\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mcccxvii{Sie sollten wenig lachen und viel weinen über das, was sie sich erworben haben.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mcccxviii{Und wenn Allah dich zu einer Gruppe von ihnen heimkehren läßt und sie dich um Erlaubnis bitten, auszuziehen, dann sprich: ``Nie sollt ihr mit mir ausziehen und nie einen Feind an meiner Seite bekämpfen. Es gefiel euch, das erste Mal daheim sitzen zu bleiben, so sitzet nun (wieder) bei denen, die zurückbleiben."\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mcccxix{Und bete nie für einen von ihnen, der stirbt, noch stehe an seinem Grabe; (denn) sie glaubten nicht an Allah und an Seinen Gesandten, und sie starben als Frevler.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mcccxx{Wundere dich weder über ihr Gut noch über ihre Kinder. Allah will sie damit nur in dieser Welt bestrafen, und ihre Seelen sollen verscheiden, während sie noch ungläubig sind.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mcccxxi{Und wenn eine Sura hinabgesandt wird (des Inhalts): ``Glaubt an Allah und kämpft an der Seite Seines Gesandten", dann bitten dich die Reichen unter ihnen um Erlaubnis und sagen: ``Laß uns bei denen sein, die daheim bleiben."\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mcccxxii{Sie sind damit zufrieden, bei den Zurückbleibenden zu sein, und ihre Herzen sind versiegelt, so daß sie nichts begreifen.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mcccxxiii{Jedoch der Gesandte und die Gläubigen mit ihm, die mit ihrem Gut und mit ihrem Blut kämpfen, sind es, denen Gutes zuteil werden soll; und sie sind es, die Erfolg haben werden.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mcccxxiv{Allah hat Gärten für sie bereitet, durch welche Bäche fließen; darin sollen sie auf ewig verweilen. Das ist die große Glückseligkeit.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mcccxxv{Und es kamen solche Wüstenaraber, die Ausreden gebrauchten, um (vom Kampf) ausgenommen zu werden; und jene blieben (daheim), die falsch gegen Allah und Seinen Gesandten waren. Wahrlich, getroffen von einer schmerzlichen Strafe werden jene unter ihnen sein, die ungläubig sind.\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mcccxxvi{Kein Tadel trifft die Schwachen und die Kranken und diejenigen, die nichts zum Ausgeben finden, wenn sie nur gegen Allah und Seinen Gesandten aufrichtig sind. Kein Vorwurf trifft jene, die Gutes tun und Allah ist Allverzeihend, Barmherzig.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mcccxxvii{Noch (trifft) jene (ein Tadel), die zu dir kamen, damit du ihnen die Möglichkeit zu reiten verschafftest, und (zu denen) du sagtest: ``Ich kann nichts finden, womit ich euch beritten machen könnte." Da kehrten sie um, während ihre Augen von Tränen überflossen aus Kummer darüber, daß sie nichts fanden, was sie hätten ausgeben können.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mcccxxviii{Ein Vorwurf trifft nur jene, die dich um Erlaubnis bitten, obwohl sie reich sind. Sie sind damit zufrieden, bei den Zurückbleibenden zu sein. Allah hat ein Siegel auf ihre Herzen gelegt, so daß sie kein Wissen haben.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mcccxxix{Sie werden euch Entschuldigungen vorbringen, wenn ihr zu ihnen zurückkehrt. Sprich: ``Bringt keine Entschuldigungen vor; wir glauben euch doch nicht. Allah hat uns schon über eure Angelegenheit belehrt. Allah und Sein Gesandter werden auf euer Tun schauen; dann werdet ihr zu dem Kenner des Verborgenen und des Offenbaren zurückgebracht werden, und Er wird euch alles verkünden, was ihr zu tun pflegtet."\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mcccxxx{Sie werden vor euch bei Allah schwören, wenn ihr zu ihnen zurückkehrt, daß ihr sie sich selbst überlassen sollt. Überlaßt sie also sich selbst. Sie sind eine Plage, und ihre Herberge ist Gahannam, als Entgelt für das, was sie sich selbst erwarben.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mcccxxxi{Sie werden euch schwören, daß ihr mit ihnen wohl zufrieden sein könntet. Doch wäret ihr auch mit ihnen zufrieden, Allah würde doch nicht mit einer Schar von Frevlern zufrieden sein.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mcccxxxii{Die Wüstenaraber sind am härtesten in Unglauben und Heuchelei und sind eher dazu geneigt, die Schranken nicht anzuerkennen, die Allah Seinem Gesandten offenbart hat. Und Allah ist Allwissend, Allweise.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mcccxxxiii{Und unter den Wüstenarabern sind so manche, die das, was sie spenden, als eine erzwungene Buße ansehen; und sie warten nur auf euer Mißgeschick. Allein sie selbst wird ein unheilvolles Mißgeschick treffen. Und Allah ist Allhörend, Allwissend.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mcccxxxiv{Doch unter den Wüstenarabern sind auch solche, die an Allah und an den Jüngsten Tag glauben und die das, was sie spenden, als ein Mittel betrachten, sich Allah zu nähern und die Segnungen des Propheten (zu empfangen) Wahrlich, für sie ist es ein Mittel der Annäherung. Allah wird sie bald in Seine Barmherzigkeit einführen. Wahrlich, Allah ist Allvergebend, Barmherzig.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mcccxxxv{Die Allerersten, die ersten der Auswanderer und der Helfer und jene, die ihnen auf die beste Art gefolgt sind - mit ihnen ist Allah wohl zufrieden und sie sind wohl zufrieden mit Ihm; und Er hat ihnen Gärten vorbereitet, durch welche Bäche fließen. Darin sollen sie verweilen auf ewig und immerdar. Das ist der gewaltige Gewinn.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mcccxxxvi{Und unter den Wüstenarabern, die in eurer Gegend wohnen, gibt es auch Heuchler, wie im Volk von Madina. Sie sind verstockt in ihrer Heuchelei. Du kennst sie nicht; Wir aber kennen sie. Wir werden sie zweimal bestrafen. Hierauf werden sie einer gewaltigen Strafe zugewiesen werden.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mcccxxxvii{Und es gibt andere, die ihre Schuld bekennen. Sie vermischten eine gute Tat mit einer anderen, schlechten. Bald wird Allah Sich mit Erbarmen zu ihnen wenden. Wahrlich, Allah ist Allvergebend, Barmherzig.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mcccxxxviii{Nimm Almosen von ihrem Besitz, auf daß du sie dadurch reinigen und läutern mögest. Und bete für sie; denn dein Gebet verschafft ihnen Beruhigung. Und Allah ist Allhörend, Allwissend.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mcccxxxix{Wissen sie denn nicht, daß es Allah allein ist, Der von Seinen Dienern Reue annimmt und Almosen entgegennimmt, und daß Allah der Allvergebende, der Barmherzige ist?\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mcccxl{Und sprich: ``Wirkt! Allah wird euer Wirken sehen, und so (auch) Sein Gesandter und die Gläubigen. Und ihr sollt zu dem Kenner des Verborgenen und des Offenbaren zurückgebracht werden; dann wird Er euch verkünden, was ihr zu tun pflegtet."\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mcccxli{Und es gibt andere, die auf Allahs Entscheidung warten müssen. Er mag sie bestrafen, oder Er mag Sich mit Erbarmen zu ihnen wenden; und Allah ist Allwissend, Allweise.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mcccxlii{Und (es gibt) jene, die eine Moschee erbaut haben, um Unheil, Unglauben und Spaltung unter den Gläubigen zu stiften, und um einen Hinterhalt für den (zu schaffen), der zuvor gegen Allah und Seinen Gesandten Krieg führte. Und sie werden sicherlich schwören: ``Wir bezwecken nur Gutes"; doch Allah ist Zeuge, daß sie bloß Lügner sind.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mcccxliii{Stehe nie (zum Gebet) darin (in dieser Moschee) Eine Moschee, die vom allerersten Tag an auf Frömmigkeit gegründet wurde, ist wahrlich würdiger, um darin zu stehen. In ihr sind Männer, die sich gerne reinigen; und Allah liebt diejenigen, die sich reinigen.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mcccxliv{Ist nun dieser besser, der sein Gebäude aus Furcht vor Allah und (um Sein) Wohlgefallen gegründet hat, oder jener, der sein Gebäude auf den Rand einer wankenden, unterspülten Sandbank gründete, die mit ihm in das Feuer der Gahannam gestürzt ist? Und Allah weist nicht den frevelhaften Leuten den Weg.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mcccxlv{Das Gebäude, das sie errichtet haben, wird nicht aufhören, Zweifel in ihren Herzen zu errregen, bis ihre Herzen in Stücke gerissen sind. Und Allah ist Allwissend, Allweise.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mcccxlvi{Allah hat von den Gläubigen ihr Leben und ihr Gut für das Paradies erkauft: Sie kämpfen für Allahs Sache, sie töten und werden getötet; eine Verheißung - bindend für Ihn - in der Thora und im Evangelium und im Quran. Und wer hält seine Verheißung getreuer als Allah? So freut euch eures Handels, den ihr mit Ihm abgeschlossen habt; denn dies ist wahrlich die große Glückseligkeit.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mcccxlvii{Denjenigen, die sich in Reue (zu Allah) wenden, (Ihn) anbeten, (Ihn) lobpreisen, die (in Seiner Sache) umherziehen, die sich beugen und niederwerfen, die das Gute gebieten und das Böse verbieten und die Schranken Allahs achten verkünde (diesen) Gläubigen die frohe Botschaft.\qt@no{(112)}}
\qt@newcmd\qurantrans@de@mcccxlviii{Es kommt dem Propheten und den Gläubigen nicht zu, für die Götzendiener um Verzeihung zu flehen, und wären es selbst ihre nächsten Verwandten, nachdem ihnen deutlich geworden ist, daß jene Bewohner der Gahim sind.\qt@no{(113)}}
\qt@newcmd\qurantrans@de@mcccxlix{Daß Abraham um Verzeihung bat für seinen Vater, war nur wegen eines Versprechens, das er ihm gegeben hatte; doch als ihm klar wurde, daß jener ein Feind Allahs war, sagte er sich von ihm los. Abraham war doch gewiß zärtlichen Herzens und sanftmütig.\qt@no{(114)}}
\qt@newcmd\qurantrans@de@mcccl{Es ist nicht Allah, Der ein Volk irregehen läßt, nachdem Er ihm den Weg gewiesen und ihm klar gemacht hat, wovor es sich zu hüten habe. Wahrlich, Allah weiß über alle Dinge Bescheid.\qt@no{(115)}}
\qt@newcmd\qurantrans@de@mcccli{Allah ist es, Dem das Königreich der Himmel und der Erde gehört. Er macht lebendig und läßt sterben. Und ihr habt keinen Beschützer noch Helfer außer Allah.\qt@no{(116)}}
\qt@newcmd\qurantrans@de@mccclii{Allah hat Sich wahrlich gnadenvoll dem Propheten zugewandt und den Auswanderern und den Helfern, die ihm in der Stunde der Not gefolgt sind, nachdem die Herzen einiger von ihnen fast gewankt hätten. Er aber wandte Sich ihnen abermals mit Erbarmen zu. Wahrlich, Er ist gegen sie Gütig, Barmherzig.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@mcccliii{Und auch den Dreien (wandte Er Sich wieder gnädig zu), die zurückgeblieben waren, bis die Erde ihnen in ihrer Weite zu eng wurde und ihre Seelen ihnen zugeschnürt wurden, und sie wußten, daß es keine Rettung vor Allah gibt, es sei denn die Zuflucht bei Ihm. Da kehrte Er Sich ihnen mit Erbarmen zu, auf daß sie sich bekehren möchten. Wahrlich, Allah ist der Gnädige, der Barmherzige.\qt@no{(118)}}
\qt@newcmd\qurantrans@de@mcccliv{O ihr, die ihr glaubt, fürchtet Allah und seid mit den Wahrhaftigen.\qt@no{(119)}}
\qt@newcmd\qurantrans@de@mccclv{Es ziemt sich nicht für die Bewohner von Madina, noch für die sie umgebenden Wüstenaraber, hinter dem Gesandten Allahs zurückzubleiben und ihr Leben dem seinigen vorzuziehen. Dies (ist so), weil weder Durst noch Mühsal noch Hunger sie auf Allahs Weg erleiden, auch betreten sie keinen Weg, der die Ungläubigen erzürnt, noch fügen sie einem Feind Leid zu, ohne daß ihnen ein verdienstliches Werk angeschrieben würde. Wahrlich, Allah läßt den Lohn derer, die Gutes tun, nicht verloren gehen.\qt@no{(120)}}
\qt@newcmd\qurantrans@de@mccclvi{Und sie spenden keine Summe, sei sie groß oder klein, und sie durchziehen kein Tal, ohne daß es ihnen angeschrieben würde, auf daß Allah ihnen den besten Lohn gebe für das, was sie getan haben.\qt@no{(121)}}
\qt@newcmd\qurantrans@de@mccclvii{Die Gläubigen dürfen nicht alle auf einmal ausziehen. Warum rückt dann nicht aus jeder Gruppe nur eine Abteilung aus, auf daß sie (die Zurückbleibenden) in Glaubensfragen wohl bewandert würden? Und nach ihrer Rückkehr könnten sie (die Zurückbleibenden) ihre (ausgezogenen) Leute belehren, damit sie sich in acht nähmen.\qt@no{(122)}}
\qt@newcmd\qurantrans@de@mccclviii{O ihr, die ihr glaubt, kämpft gegen jene, die euch nahe sind unter den Ungläubigen, und lasset sie euch hart vorfinden; und wisset, daß Allah mit den Gottesfürchtigen ist.\qt@no{(123)}}
\qt@newcmd\qurantrans@de@mccclix{Sooft eine Sura herabgesandt wird, gibt es welche unter ihnen, die sagen: ``Wen von euch hat sie im Glauben bestärkt?" Die aber gläubig sind, stärkt sie in ihrem Glauben, und sie freuen sich darüber.\qt@no{(124)}}
\qt@newcmd\qurantrans@de@mccclx{Jenen aber, in deren Herzen Krankheit ist, fügt sie zu ihrem Übel noch Übel hinzu, und sie sterben als Ungläubige.\qt@no{(125)}}
\qt@newcmd\qurantrans@de@mccclxi{Sehen sie denn nicht, daß sie in jedem Jahr einmal oder zweimal geprüft werden? Dennoch bereuen sie nicht und lassen sich nicht ermahnen.\qt@no{(126)}}
\qt@newcmd\qurantrans@de@mccclxii{Und sooft eine Sura herabgesandt wird, schauen sie einander an (und sagen): ``Sieht euch jemand?" Dann wenden sie sich ab. Allah hat ihre Herzen abgewendet, weil sie Leute sind, die es nicht begreifen.\qt@no{(127)}}
\qt@newcmd\qurantrans@de@mccclxiii{Wahrlich, ein Gesandter aus eurer Mitte ist zu euch gekommen; es schmerzt ihn sehr, wenn ihr unter etwas leidet; er setzt sich eifrig für euer Wohl ein; gegen die Gläubigen ist er mitleidig und barmherzig.\qt@no{(128)}}
\qt@newcmd\qurantrans@de@mccclxiv{Doch wenn sie sich abwenden, so sprich: ``Allah allein soll mir genügen. Es ist kein Gott außer Ihm. Auf Ihn vertraue ich, und Er ist der Herr des gewaltigen Throns."\qt@no{(129)}}
\qt@newcmd\qurantrans@de@mccclxv{\basmalahde Alif Lam Ra ' Dies sind die Verse des vollkommenen Buches\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mccclxvi{Scheint es den Menschen so verwunderlich, daß Wir einem Manne aus ihrer Mitte eingegeben haben: ``Warne die Menschen und verkünde die frohe Botschaft denjenigen, die da glauben, einen wirklichen Rang bei ihrem Herrn innezuhaben?" Die Ungläubigen sagen: ``Wahrlich, das ist ein offenkundiger Zauberer."\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mccclxvii{Wahrlich, euer Herr ist Allah, Der die Himmel und die Erde in sechs Tagen erschuf, (und) Sich alsdann (Seinem) Reich majestätisch zuwandte: Er sorgt für alles. Es gibt keinen Fürsprecher, es sei denn mit Seiner Erlaubnis. Dies ist Allah, euer Herr, so betet Ihn an. Wollt ihr euch denn nicht ermahnen lassen?\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mccclxviii{Zu Ihm werdet ihr alle heimkehren; (dies ist) die Verheißung Allahs in Wahrheit. Er bringt die Schöpfung hervor; dann läßt Er sie wiederholen, auf daß Er jene, die glauben und gute Werke tun, nach Billigkeit belohne; denen aber, die ungläubig sind, wird ein Trunk siedenden Wassers zuteil werden und schmerzliche Strafe, weil sie ungläubig waren.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mccclxix{Er ist es, Der die Sonne zur Helligkeit und den Mond zu einem Licht machte und ihm Stationen zuwies, damit ihr die Anzahl der Jahre und die Berechnung (der Zeit) beherrschen könnt. Allah hat dies nicht anders als in Gerechtigkeit erschaffen. Er legt die Zeichen für die Leute dar, die Wissen besitzen.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mccclxx{Wahrlich, in dem Wechsel von Nacht und Tag und in allem, was Allah in den Himmeln und auf der Erde erschaffen hat, sind Zeichen für gottesfürchtige Leute.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mccclxxi{Die aber, die nicht mit der Begegnung mit Uns rechnen und mit dem diesseitigen Leben zufrieden sind und sich darauf verlassen und Unsere Zeichen nicht beachten\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mccclxxii{diese sind es, deren Herberge das Feuer ist, um dessentwillen, was sie sich erworben haben.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mccclxxiii{Jene jedoch, die da glauben und gute Werke tun, wird ihr Herr um ihres Glaubens willen leiten. Bäche werden unter ihnen in den Gärten der Wonne fließen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mccclxxiv{Ihr Ruf dort wird sein: ``Preis Dir, o Allah!" Und ihr Gruß dort wird ``Frieden!" sein. Und zuletzt werden sie rufen: `` Alles Lob gebührt Allah, dem Herrn der Welten."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mccclxxv{Und wenn Allah den Menschen das Unheil so eilig zukommen ließe, wie sie es mit dem Guten eilig haben, so wäre ihre Lebensfrist schon zu Ende. Und so lassen Wir die, welche nicht mit der Begegnung mit Uns rechnen, in ihrer Widersetzlichkeit verblenden.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mccclxxvi{Und wenn den Menschen ein Schaden trifft, ruft er Uns an, ob er nun auf der Seite liegt oder sitzt oder steht; haben Wir aber den Schaden von ihm fortgenommen, dann geht er seines Weges, als hätte er Uns nie um (die Befreiung) vom Schaden, der ihn getroffen hat, angerufen. Also zeigt sich den Maßlosen das in schönem Licht, was sie begangen haben.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mccclxxvii{Und Wir vernichteten die Geschlechter vor euch, als sie frevelten; denn zu ihnen kamen ihre Gesandten mit deutlichen Zeichen, sie aber wollten nicht glauben. Also vergelten Wir (dies) der verbrecherischen Schar.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mccclxxviii{Danach machten Wir euch zu ihren Nachfolgern auf der Erde, auf daß Wir schauten, wie ihr handeln würdet.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mccclxxix{Und wenn ihnen Unsere deutlichen Verse verlesen werden, sagen jene, die nicht mit der Begegnung mit Uns rechnen: ``Bring einen Quran, der anders ist als dieser oder ändere ihn." Sprich: ``Es steht mir nicht zu, ihn aus eigenem Antrieb zu ändern. Ich folge nur dem, was mir offenbart wurde. Ich fürchte, falls ich meinem Herrn ungehorsam bin, die Strafe eines gewaltigen Tages."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mccclxxx{Sprich: ``Hätte Allah es gewollt so hätte ich ihn euch nicht verlesen, noch hätte Er ihn euch kundgetan. Ich habe doch wahrlich ein Menschenalter unter euch gelebt, bevor (der Quran da war) Wollt ihr denn nicht begreifen?"\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mccclxxxi{Wer ist wohl ungerechter als jener, der eine Lüge gegen Allah erdichtet oder Seine Zeichen für Lügen erklärt? Wahrlich, die Verbrecher haben keinen Erfolg.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mccclxxxii{Sie verehren statt Allah das, was ihnen weder schaden noch nützen kann; und sie sagen: ``Das sind unsere Fürsprecher bei Allah." Sprich: ``Wollt ihr Allah von etwas Nachricht geben, was Ihm in den Himmeln oder auf der Erde unbekannt ist?" Gepriesen sei Er, und hoch Erhaben ist Er über das, was sie (Ihm) zur Seite stellen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mccclxxxiii{Die Menschen waren einst nur eine einzige Gemeinde, dann aber wurden sie uneins; und wäre nicht ein Wort von deinem Herrn vorausgegangen, wäre zwischen ihnen bereits über das, worüber sie uneins waren, entschieden worden.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mccclxxxiv{Und sie sagen: ``Warum ist nicht ein Zeichen zu ihm von seinem Herrn herabgesandt worden?" Sprich: ``Das Verborgene gehört Allah allein. Darum wartet ab; seht, ich warte auch mit euch ab."\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mccclxxxv{Und wenn Wir die Menschen Barmherzigkeit erleben lassen, nachdem Unheil sie getroffen hat, siehe, dann beginnen sie wieder, gegen Unsere Zeichen Pläne zu schmieden. Sprich: ``Allah schmiedet die Pläne schneller." Unsere Boten schreiben wahrlich alles nieder, was ihr an Plänen schmiedet.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mccclxxxvi{Er ist es, Der euch zu Lande und zur See Wege bereitet. Und da sie an (Bord) der Schiffe sind und mit ihnen (den Passagieren) bei gutem Wind dahinsegeln und sich darüber freuen, werden sie plötzlich von einem Sturm erfaßt, und die Wogen schlagen von allen Seiten über sie zusammen. Und sie meinen schon, sie seien rings umschlossen - da rufen sie Allah in vollem, aufrichtigen Glauben an: ``Wenn Du uns aus diesem (Sturm) errettest, so werden wir sicherlich unter den Dankbaren sein."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mccclxxxvii{Doch wenn Er sie dann errettet hat, siehe, schon beginnen sie wieder, ohne Berechtigung auf Erden Gewalt zu verüben. O ihr Menschen, eure Gewalttat richtet sich nur gegen euch selbst. (Genießt) die Gaben des diesseitigen Lebens. Zu Uns sollt ihr dann heimkehren; dann werden Wir euch verkünden, was ihr getan habt.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mccclxxxviii{Das Gleichnis des irdischen Lebens ist nur wie das Wasser, das Wir aus den Wolken herabsenden; damit vermischen sich dann die Gewächse der Erde, wovon Mensch und Vieh sich nähren, bis zu ihr wenn die Erde ihren Prunk angelegt und sich schön geschmückt hat und ihre Bewohner glauben, sie hätten Macht über sie - Unser Befehl in der Nacht oder am Tage kommt und Wir sie zu einem niedergemähten Acker machen, als wäre sie nicht am Tage zuvor gediehen. Also machen Wir die Zeichen für die Leute klar, die nachdenken.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mccclxxxix{Und Allah lädt ein zum Haus des Friedens und leitet, wen Er will, zum geraden Weg.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mcccxc{Denen, die Gutes tun, soll das Beste zuteil sein und noch mehr. Weder Betrübnis noch Schmach soll ihre Gesichter bedecken. Sie sind die Bewohner des Paradieses; darin werden sie auf ewig verweilen.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mcccxci{Für diejenigen aber, die böse Taten begangen haben, ist eine Strafe in gleichem Ausmaße (wie dem der bösen Taten) bereitet. Schmach wird sie bedecken; keinen Schutz werden sie vor Allah haben, (und es soll so sein,) als ob ihre Gesichter mit Fetzen einer finsteren Nacht bedeckt wären. Sie sind die Bewohner des Feuers; darin werden sie auf ewig bleiben.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mcccxcii{Und (gedenke) des Tages, da Wir sie versammeln werden allzumal; dann werden Wir zu denen, die Götzen anbeteten, sprechen: ``An euren Platz, ihr und eure Teilhaber! ``Dann scheiden Wir sie voneinander, und ihre Teilhaber werden sagen: ``Nicht uns habt ihr angebetet.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mcccxciii{Allah genügt als Zeuge gegen uns und euch. Wir haben wahrhaftig nichts von eurer Anbetung gewußt."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mcccxciv{Dort erfahrt jede Seele, was sie (an Taten) vorausgeschickt hat. Und sie werden zu Allah, ihrem wahren Herrn, zurückgebracht, und das, was sie zu erdichten pflegten, wird ihnen entschwunden sein.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mcccxcv{Sprich: ``Wer versorgt euch vom Himmel her und aus der Erde? Oder wer ist es, der Gewalt über die Ohren und die Augen hat? Und wer bringt das Lebendige aus dem Toten hervor und das Tote aus dem Lebendigen? Und wer sorgt für alle Dinge?" Sie werden sagen: ``Allah". So sprich: ``Wollt ihr Ihn denn nicht fürchten?"\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mcccxcvi{Das ist Allah, euer wahrer Herr. Was sollte also nach der Wahrheit (übrig) bleiben als der Irrtum? Wie lasset ihr euch abwenden?\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mcccxcvii{Und so hat sich das Wort deines Herrn gegen die Empörer bewahrheitet, (nämlich,) daß sie nicht glauben.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mcccxcviii{Sprich: ``Ist unter euren Teilhabern etwa einer der eine Schöpfung hervorbringt und sie dann wiederholen läßt?" Sprich: ``Allah ist es, Der die Schöpfung hervorbringt und sie wiederholen läßt. Wohin also lasset ihr euch abwenden?"\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mcccxcix{Sprich: ``Ist unter euren Teilhabern etwa einer, der zur Wahrheit leitet?" Sprich: ``Allah ist es, Der zur Wahrheit leitet. Ist nun Der, Der zur Wahrheit leitet, nicht der Gefolgschaft würdiger als der, der den Weg nicht zu finden vermag, es sei denn, er wird selbst geleitet? Was fehlt euch also? Wie urteilt ihr nur?"\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mcd{Und die meisten von ihnen folgen bloß einer Vermutung; doch eine Vermutung nützt nichts gegenüber der Wahrheit. Siehe, Allah weiß recht wohl, was sie tun.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mcdi{Und dieser Quran hätte nicht ersonnen werden können, außer durch Allah. Vielmehr ist er eine Bestätigung dessen, was ihm vorausging, und eine Darlegung des Buches - darüber herrscht kein Zweifel vom Herrn der Welten.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mcdii{Oder wollen sie etwa sagen: ``Er hat ihn erdichtet?" Sprich: ``Bringt denn eine Sura gleicher Art hervor und ruft, wen ihr nur könnt, außer Allah, wenn ihr wahrhaftig seid."\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mcdiii{Nein; aber sie haben das geleugnet, was sie an Wissen nicht umfassen ten, und ebensowenig zugänglich war ihnen seine Deutung. Ebenso leugneten auch jene, die vor ihnen waren. Doch siehe, wie das Ende der Ungerechten war!\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mcdiv{Unter ihnen sind solche, die daran glauben, und andere, die nicht daran glauben, und dein Herr kennt jene wohl, die Verderben stiften.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mcdv{Und wenn sie dich der Lüge bezichtigen, so sprich: ``Für mich ist mein Werk und für euch ist euer Werk. Ihr seid nicht verantwortlich für das, was ich tue, und ich bin nicht verantwortlich für das, was ihr tut."\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mcdvi{Und unter ihnen sind solche, die dir zuhören. Aber kannst du die Tauben hörend machen, obwohl sie nicht begreifen?\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mcdvii{Und unter ihnen sind solche, die auf dich schauen. Aber kannst du den Blinden den Weg weisen, obwohl sie nicht sehen?\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mcdviii{Wahrlich, Allah fügt den Menschen kein Unrecht zu; die Menschen aber begehen Unrecht gegen sich selbst.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mcdix{Und an dem Tage, an dem Er sie (vor Sich) versammelt, (kommt es ihnen so vor,) als hätten sie (seit ihrem Tod) nur eine Stunde an einem Tage (im Grabe) verweilt. Sie werden einander erkennen. Verloren wahrlich haben jene, die die Begegnung mit Allah leugneten und nicht rechtgeleitet waren.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mcdx{Und ob Wir dir einige Dinge zeigen, die Wir ihnen angedroht haben, oder (ob Wir) dich sterben lassen: zu Uns werden sie dann heimkehren; hernach ist Allah Zeuge all dessen, was sie tun.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mcdxi{Und für jede Nation ist ein Gesandter (bestimmt) Wenn also ihr Gesandter kommt, so wird zwischen ihnen in Gerechtigkeit entschieden, und kein Unrecht widerfährt ihnen.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mcdxii{Und sie sagen: ``Wann wird dieses Versprechen (verwirklicht werden), wenn ihr wahrhaftig seid?"\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mcdxiii{Sprich: ``Ich vermag mir selbst weder zu schaden noch zu nutzen, es sei denn, Allah will es. Jeder Gemeinschaft ist eine Frist bestimmt; und wenn ihre Frist um ist, so können sie nicht (hinter ihr) eine Stunde zurückbleiben, noch können sie ihr vorausgehen."\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mcdxiv{Sprich: ``Was meint ihr? Wenn Seine Strafe über euch kommt, bei Nacht oder bei Tage, wie werden die Verbrecher sich ihr entziehen?\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mcdxv{Wollt ihr erst dann an sie glauben, wenn sie eintrifft? Wie? Jetzt? Und doch wolltet ihr sie beschleunigen!"\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mcdxvi{Dann wird zu den Ungerechten gesagt werden: ``Kostet nun die Strafe der Ewigkeit. Erhaltet ihr denn etwas anderes als das, wofür ihr vorgesorgt habt?"\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mcdxvii{Und sie fragen dich: ``Ist das die Wahrheit?" Sprich: ``Ja, bei meinem Herrn! Es ist ganz gewiß die Wahrheit; und ihr könnt es nicht verhindern."\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mcdxviii{Und wenn eine jede Seele, die Unrecht begangen hat, alles besäße, was auf Erden ist, würde sie versuchen, sich damit (von der Strafe) loszukaufen. Und sie werden Reue empfinden, wenn sie sehen, wie die Strafe (über sie) kommt. Und es wird zwischen ihnen in Gerechtigkeit entschieden werden, und sie sollen kein Unrecht erleiden.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mcdxix{Wisset, Allahs ist, was in den Himmeln und was auf Erden ist. Wisset, Allah s Verheißung ist wahr! Doch die meisten von ihnen wissen es nicht.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mcdxx{Er macht lebendig und läßt sterben, und zu Ihm kehrt ihr zurück.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mcdxxi{O ihr Menschen! Nunmehr ist von eurem Herrn eine Ermahnung zu euch gekommen und eine Heilung für das, was euch in eurer Brust bewegt, und eine Führung und Barmherzigkeit für die Gläubigen.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mcdxxii{Sprich: ``Durch die Gnade Allahs und durch Seine Barmherzigkeit; darüber sollen sie sich nun freuen. Das ist besser als das, was sie anhäufen."\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mcdxxiii{Sprich: ``Habt ihr das betrachtet, was Allah euch an Nahrung hinabgesandt hat, woraus ihr aber (etwas) Verbotenes und Erlaubtes gemacht habt?" Sprich: ``Hat Allah euch (das) gestattet oder erdichtet ihr Lügen gegen Allah?"\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mcdxxiv{Was meinen wohl jene, die Lügen gegen Allah erdichten, vom Tage der Auferstehung? Wahrlich Allah ist Gnadenvoll gegen die Menschen, jedoch die meisten von ihnen sind nicht dankbar.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mcdxxv{Du unternimmst nichts, und du verliest von diesem (Buch) keinen Teil des Quran, und ihr begeht keine Tat, ohne daß Wir eure Zeugen sind, wenn ihr damit vollauf beschäftigt seid. Und auch nicht das Gewicht eines Stäubchens auf Erden oder im Himmel ist vor deinem Herrn verborgen. Und es gibt nichts, weder etwas Kleineres als dies noch etwas Größeres, das nicht in einem Buche voller Klarheit stünde.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mcdxxvi{Wisset, daß über Allahs Schützlinge keine Furcht kommen wird, noch sollen sie traurig sein.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mcdxxvii{Diejenigen, die da glauben und rechtschaffen sind\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mcdxxviii{Für sie ist die frohe Botschaft im diesseitigen Leben sowie im Jenseits (bestimmt) Unabänderlich sind Allahs Worte - das ist wahrlich der gewaltige Gewinn.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mcdxxix{Und sei nicht betrübt über ihre Rede. Alle Erhabenheit gebührt Allah allein. Er ist der Allhörende, der Allwissende.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mcdxxx{Wisset, daß Allahs ist, wer immer in den Himmeln und wer immer auf der Erde ist. Und diejenigen, die da andere außer Allah anrufen, folgen nicht (diesen) Teilhabern; sie folgen nur einem Wahn, und sie vermuten nur.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mcdxxxi{Er ist es, Der die Nacht für euch gemacht hat, auf daß ihr in ihr ruhet, und den Tag voll von Licht. Wahrlich, hierin liegen Zeichen für die Leute, die hören können.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mcdxxxii{Sie sagen: ``Allah hat Sich einen Sohn genommen." Gepriesen sei Er! Er ist der Sich-Selbst-Genügende. Sein ist, was in den Himmeln und was auf der Erde ist. Ihr habt keinen Beweis hierfür. Wollt ihr von Allah etwas behaupten, was ihr nicht wisset?\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mcdxxxiii{Sprich: ``Jene, die eine Lüge gegen Allah erdichten, werden keinen Erfolg haben."\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mcdxxxiv{Eine Weile Genuß in dieser Welt - dann werden sie zu Uns heimkehren. Dann werden Wir sie die strenge Strafe dafür kosten lassen, daß sie ungläubig waren.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mcdxxxv{Und verlies ihnen die Geschichte von Noah, als er zu seinem Volke sprach: ``O mein Volk, wenn mein Rang und meine Ermahnung durch die Zeichen Allahs für euch unerträglich sind, so setze ich mein Vertrauen in Allah; so beschließt nur eure Angelegenheiten und versammelt eure Teilhaber, und belaßt euer Planen nicht im Verborgenen, sondern handelt gegen mich, und gebt mir keine Wartezeit.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mcdxxxvi{Kehrt ihr (mir) aber den Rücken, so habe ich von euch keinen Lohn verlangt. Mein Lohn ist allein bei Allah, und mir wurde befohlen, zu den Gottergebenen zu gehören."\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mcdxxxvii{Doch sie bezichtigten ihn der Lüge; darum retteten Wir ihn und die, die bei ihm im Schiff waren. Und Wir machten sie zu den Nachfolgern (der Menschen), während Wir jene ertrinken ließen, die Unsere Zeichen für Lügen hielten. Schau also, wie das Ende derer war, die gewarnt worden waren!\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mcdxxxviii{Dann schickten Wir nach ihm Gesandte zu ihrem Volk, und sie brachten ihnen klare Beweise. Allein sie wollten unmöglich an das glauben, was sie zuvor verleugnet hatten. So versiegeln Wir die Herzen der Übertreter.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mcdxxxix{Dann schickten Wir nach ihnen Moses und Aaron mit Unseren Zeichen zu Pharao und seinen Vornehmen; sie aber waren hochmütig. Und sie waren ein verbrecherisches Volk.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mcdxl{Als nun die Wahrheit von Uns zu ihnen kam, da sagten sie: ``Das ist gewiß ein offenkundiger Zauber."\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mcdxli{Moses sprach: ``Sagt ihr (solches) von der Wahrheit, nachdem sie zu euch gekommen ist? Ist das Zauberei? Und die Zauberer haben niemals Erfolg."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mcdxlii{Sie sagten: ``Bist du zu uns gekommen, um uns von dem abzulenken, was wir bei unseren Vätern vorfanden, und wollt ihr beide die Oberhand im Lande haben? Wir aber wollen euch nicht glauben."\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mcdxliii{Da sprach Pharao: ``Bringt mir einen jeden kundigen Zauberer herbei."\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mcdxliv{Als nun die Zauberer kamen, sprach Moses zu ihnen: ``Werft, was ihr zu werfen habt."\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mcdxlv{Als sie dann geworfen hatten sprach Moses: ``Was ihr gebracht habt, ist Zauberei. Allah wird es sicher zunichte machen. Denn wahrlich, Allah läßt das Werk der Verderbensstifter nicht gedeihen.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mcdxlvi{Und Allah stärkt die Wahrheit durch Seine Worte, auch wenn es die Verbrecher verwünschen."\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mcdxlvii{Und niemand bekannte sich zu Moses, bis auf einige junge Menschen aus seinem Volk - voller Furcht vor Pharao und seinen Vornehmen, er (Pharao) würde sie verfolgen. Und in der Tat war Pharao ein Tyrann im Land, und wahrlich, er war einer der Maßlosen.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mcdxlviii{Und Moses sprach: ``O mein Volk, habt ihr an Allah geglaubt, so vertraut nun auf Ihn, wenn ihr euch (Ihm) wirklich ergeben habt."\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mcdxlix{Sie sagten: ``Auf Allah vertrauen wir. Unser Herr, mache uns nicht zu einer Versuchung für das Volk der Ungerechten.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mcdl{Und errette uns durch Deine Barmherzigkeit von dem Volk der Ungläubigen."\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mcdli{Und Wir gaben Moses und seinem Bruder ein: ``Nehmt in Ägypten einige Häuser für euer Volk und macht sie zur Begegnungsstätte und verrichtet das Gebet." Und (weiter): ``Verkünde den Gläubigen die frohe Botschaft!"\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mcdlii{Und Moses sprach: ``Unser Herr, Du gabst die Pracht sowie die Reichtümer im diesseitigen Leben dem Pharao und seinen Vornehmen, unser Herr, damit sie von Deinem Weg abhalten. Unser Herr, zerstöre ihre Reichtümer und triff ihre Herzen, so daß sie nicht glauben, ehe sie die schmerzliche Strafe erleben."\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mcdliii{Er sprach: ``Euer Gebet ist erhört. Seid ihr beide denn aufrichtig und folgt nicht dem Weg derer, die unwissend sind."\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mcdliv{Und Wir führten die Kinder Israels durch das Meer; und Pharao mit seinen Heerscharen verfolgte sie widerrechtlich und feindlich, bis er nahe daran war, zu ertrinken, (und) sprach: ``Ich glaube, daß kein Gott ist als Der, an Den die Kinder Israels glauben, und ich gehöre nun zu den Gottergebenen."\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mcdlv{Wie? Jetzt? Wo du bisher ungehorsam und einer derer warst, die Unheil stifteten?\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mcdlvi{Nun wollen Wir dich heute dem Leibe nach erretten, auf daß du ein Beweis für diejenigen seiest, die nach dir kommen. Und es gibt sicher viele Menschen, die Unseren Zeichen keine Beachtung schenken.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mcdlvii{Wahrlich, Wir bereiteten den Kindern Israels ein wahrhaftig sicheres Dasein und versorgten sie mit guten Dingen; und sie waren nicht eher uneins, als bis das Wissen zu ihnen kam. Wahrlich, am Tage der Auferstehung wird dein Herr zwischen ihnen darüber entscheiden, worüber sie uneins waren.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mcdlviii{Und falls du im Zweifel über das bist, was Wir zu dir niedersandten, so frage diejenigen, die vor dir die Schrift gelesen haben. Wahrlich, die Wahrheit ist von deinem Herrn zu dir gekommen; sei also nicht einer der Zweifler.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mcdlix{Und gehöre auch nicht zu jenen, die Allahs Zeichen für Lügen halten, da du sonst einer der Verlierenden sein wirst.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mcdlx{Wahrlich, diejenigen, gegen die das Wort deines Herrn ergangen ist, werden nicht gläubig sein\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mcdlxi{auch wenn zu ihnen irgendein Zeichen käme, bis sie die schmerzliche Strafe sehen.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mcdlxii{Gab es denn kein Volk außer dem Volke Jonas, das so glauben könnte daß ihnen ihr Glaube (etwas) genutzt hätte? Als sie glaubten, da nahmen Wir die Strafe der Schande in diesem Leben von ihnen fort und versorgten sie auf eine (beschränkte) Zeit.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mcdlxiii{Und hätte dein Herr es gewollt, so hätten alle, die insgesamt auf der Erde sind, geglaubt. Willst du also die Menschen dazu zwingen, Gläubige zu werden?\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mcdlxiv{Niemandem steht es zu zu glauben, es sei denn mit Allahs Erlaubnis. Und Er läßt (Seinen) Zorn auf jene herab, die ihre Vernunft (dazu) nicht gebrauchen wollen.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mcdlxv{Sprich: ``Schaut doch, was in den Himmeln und auf der Erde ist." Aber den Leuten, die nicht glauben, helfen die Zeichen und die Warnungen nichts.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mcdlxvi{Was erwarten sie denn anderes als die Tage jener, die vor ihnen dahingegangen sind? Sprich: ``Wartet denn, (und) ich warte mit euch."\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mcdlxvii{Dann werden Wir Unsere Gesandten und jene, die da glauben, erretten. Also obliegt es Uns, die Gläubigen zu retten.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mcdlxviii{Sprich: ``O ihr Menschen, wenn ihr über meine Religion im Zweifel seid, dann (wisset), ich verehre nicht die, welche ihr statt Allah verehrt, sondern ich verehre Allah allein, Der euch abberufen wird; und mir wurde befohlen, einer der Gläubigen zu sein."\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mcdlxix{Und (mir wurde befohlen): ``Richte dein Antlitz auf die einzig wahre Religion, und sei nicht einer der Götzendiener.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mcdlxx{Und rufe nicht statt Allah (etwas) anderes an, das dir weder nützt noch schadet. Tätest du es, dann wärest du gewiß unter den Ungerechten."\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mcdlxxi{Und wenn dich Allah mit einem Übel treffen will, so gibt es keinen, der es hinwegnehmen kann, außer Ihm; und wenn Er dir etwas Gutes erweisen will, so gibt es keinen, der Seine Gnade verhindern kann. Er läßt sie unter Seinen Dienern zukommen, wem Er will, und Er ist der Allverzeihende, der Barmherzige.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mcdlxxii{Sprich: ``O ihr Menschen, nun ist die Wahrheit von eurem Herrn zu euch gekommen. Wer nun dem rechten Weg folgt, der folge ihm allein zum Heil seiner eigenen Seele; und wer in die Irre geht, der geht nur zu seinem eigenen Schaden irre. Und ich bin nicht euer Hüter."\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mcdlxxiii{Und folge dem, was dir offenbart wurde, und sei geduldig, bis Allah richtet; denn Er ist der beste Richter.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mcdlxxiv{\basmalahde Alif Lam Ra'(Dies ist) ein Buch, dessen Verse vervollkommnet und dann im einzelnen erklärt worden sind - von einem Allweisen, Allkundigen.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mcdlxxv{(Es lehrt euch,) daß ihr keinen außer Allah anbeten sollt. Ich bin euch von Ihm (als) ein Warner und ein Bringer froher Botschaft (gesandt worden)\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mcdlxxvi{(Und ich bin zu euch gesandt worden, auf) daß ihr Vergebung von eurem Herrn erflehet und euch dann reumütig zu Ihm bekehret. Er wird euch dann bis zum Ende einer festgesetzten Frist reich versorgen. Und Seine Huld wird Er einem jeden gewähren, der sie verdient. Kehrt ihr euch jedoch (von Ihm) ab; wahrlich, dann fürchte ich für euch die Strafe eines großen Tages.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mcdlxxvii{Zu Allah werdet ihr heimkehren; und Er hat Macht über alle Dinge.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mcdlxxviii{Gewiß nun, sie verschließen ihre Brust, um sich vor Ihm zu verstecken. Doch siehe, wenn sie sich auch mit ihren Gewändern bedecken, weiß Er, was sie verbergen und was sie offenbaren. Wahrlich, Er weiß wohl, was in den Herzen gehegt wird.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mcdlxxix{Und es gibt kein Geschöpf auf der Erde, dessen Versorgung nicht Allah obläge. Und Er kennt seinen Aufenthaltsort und seine Heimstatt. Alles ist in einer deutlichen Schrift (verzeichnet)\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mcdlxxx{Und Er ist es, Der die Himmel und die Erde in sechs Tagen erschuf - und Sein Reich war auf dem Wasser -, damit Er prüfe, wer von euch die beste Tat begehe. Und wenn du sprichst: ``Ihr werdet wahrlich nach dem Tode auferweckt werden" dann werden die Ungläubigen gewiß sagen: ``Das ist nichts als offenkundige Zauberei."\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mcdlxxxi{Und wenn Wir aber ihre Bestrafung bis zu einem be rechneten Zeitpunkt aufschöben, würden sie sicherlich sagen: ``Was hält sie zurück?" Nun wahrlich, an dem Tage, an dem sie zu ihnen kommen wird, da wird keiner (sie) von ihnen abwenden können; und das, was sie zu verspotten pflegten, wird sie rings umschließen.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mcdlxxxii{Und wenn Wir dem Menschen Unsere Gnade zu kosten geben und sie ihm daraufhin fortnehmen, ist er verzweifelt und undankbar.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mcdlxxxiii{Und wenn Wir ihm nach einer Drangsal, die ihn getroffen hat, eine Gabe bescheren, sagt er sicherlich: ``Das Übel ist von mir gewichen." Siehe, er ist frohlockend und prahlend.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mcdlxxxiv{Ausgenommen (von der Strafe) sind diejenigen, die geduldig sind und gute Werke tun. Ihnen wird Vergebung und ein großer Lohn zuteil sein.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mcdlxxxv{Vielleicht wirst du nun einen Teil von dem aufgeben, was dir offenbart wurde; und deine Brust wird davon so bedrückt sein, daß sie sagen: ``Warum ist nicht ein Schatz zu ihm niedergesandt worden oder ein Engel mit ihm gekommen?" Du aber bist nur ein Warner, und Allah ist der Hüter aller Dinge.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mcdlxxxvi{Oder werden sie sagen: ``Er hat es erdichtet?" Sprich: ``So bringt doch zehn ebenbürtig erdichtete Suren hervor und ruft an, wen ihr vermögt, außer Allah, wenn ihr wahrhaftig seid!"\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mcdlxxxvii{Und wenn sie darauf nicht reagieren, dann wisset, es ist mit Allahs Wissen offenbart worden; und es gibt keinen Gott außer Ihm. Wollt ihr euch nun ergeben?\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mcdlxxxviii{Diejenigen, die das irdische Leben und seine Pracht begehren, wollen Wir für ihre irdischen Werke voll belohnen, und sie sollen (auf Erden) kein Unrecht erleiden.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mcdlxxxix{Diese sind es, die im Jenseits nichts als das Feuer erhalten sollen, und das, was sie hienieden gewirkt haben, wird nichtig sein, und eitel (wird) all das (sein), was sie zu tun pflegten.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mcdxc{Kann denn der, der einen deutlichen Beweis von seinem Herrn besitzt und dem Sein Zeuge folgen soll und dem das Buch Moses' als Führung und Barmherzigkeit vorausging(, ein Betrüger sein)? Diese werden an ihn glauben, und wer von den Gruppen nicht an ihn glaubt das Feuer soll sein verheißener Ort sein. Sei daher darüber nicht im Zweifel. Dies ist die Wahrheit von deinem Herrn; jedoch die meisten Menschen glauben es nicht.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mcdxci{Und wer ist ungerechter als der, der eine Lüge gegen Allah erdichtet? Diese werden ihrem Herrn vorgeführt werden, und die Zeugen werden sagen: ``Das sind die, die gegen ihren Herrn logen." Hört! Wahrlich, der Fluch Allahs lastet auf den Ungerechten\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mcdxcii{die vom Wege Allahs abhalten und ihn zu krümmen suchen. Und diese sind es, die nicht an das Jenseits glauben\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mcdxciii{sie vermögen nimmermehr im Lande zu siegen, noch haben sie irgendeinen Beschützer vor Allah. Verdoppelt soll ihnen die Strafe werden! Sie konnten weder hören noch konnten sie sehen.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mcdxciv{Diese sind es, die ihrer selbst verlustig gegangen sind, und was sie ersonnen haben, soll ihnen nichts nützen.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mcdxcv{(Es besteht) kein Zweifel (darüber), daß sie im Jenseits die größten Verlierer sein werden.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mcdxcvi{Diejenigen aber, die glauben und gute Werke tun und sich vor ihrem Herrn demütigen, sind die Bewohner des Paradieses; darin sollen sie auf ewig verweilen.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mcdxcvii{Der Fall der beiden Parteien ist wie der (Fall) des Blinden und des Tauben und des Sehenden und des Hörenden. Sind nun beide wohl in der gleichen Lage? Wollt ihr denn nicht daran denken?\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mcdxcviii{Wir entsandten ja Noah zu seinem Volke (und er sagte): ``Wahrlich, ich bin für euch ein deutlicher Warner\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mcdxcix{daß ihr keinen anderen außer Allah dient. Ich fürchte für euch die Strafe eines schmerzlichen Tages."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@md{Die Vornehmen seines Volkes, die nicht glaubten, sagten: ``Wir sehen in dir nur einen Menschen unseresgleichen und wir sehen, daß dir keine als jene gefolgt sind, die aller äußeren Erscheinung nach die Niedrigsten unter uns sind, noch sehen wir in euch irgendeinen Vorzug vor uns; nein, wir erachten euch für Lügner."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mdi{Er sprach: ``O mein Volk, (ihr) seht nicht ein, daß ich einen klaren Beweis von meinem Herrn habe; und Er hat mir Seine Barmherzigkeit gewährt, die euch aber verborgen geblieben ist. Sollen wir sie euch da aufzwingen, wo sie euch zuwider ist?\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mdii{O mein Volk, ich verlange von euch kein Entgelt dafür. Mein Lohn ist allein bei Allah. Und ich werde gewiß nicht jene, die glauben, verstoßen. Sie werden ihrem Herrn begegnen. Allein, ich erachte euch für ein Volk, das unwissend ist.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mdiii{O mein Volk, wer würde mir gegen Allah helfen, wenn ich sie verstieße? Wollt ihr (das) denn nicht einsehen?\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mdiv{Und ich sage nicht zu euch: ``Ich besitze die Schätze Allahs", noch kenne ich das Verborgene, noch erkläre ich: ``Ich bin ein Engel." Noch sage ich von denen, die eure Augen verachten: ``Allah wird ihnen niemals (etwas) Gutes gewähren." Allah kennt am besten, was in ihrem Inneren vorgeht; wahrlich, ich gehörte sonst zu denen, die ungerecht sind."\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mdv{Sie sagten: ``O Noah, du hast schon (genug) mit uns gehadert und gar lange mit uns gehadert; so bring uns denn her, was du uns androhst, wenn du zu den Wahrhaftigen gehörst."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mdvi{Er sprach: ``Allah allein wird es euch bringen, wenn Er will, und ihr vermögt es nicht zu verhindern.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mdvii{Und mein Rat, den ich euch geben will, wird euch nichts nützen, wenn Allah euch abirren lassen will. Er ist euer Herr; und zu Ihm werdet ihr zurückgebracht werden."\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mdviii{Ob sie sagen werden: ``Er hat es ersonnen?" Sprich: ``Wenn ich es ersonnen habe, so sei dies meine Sünde; und ich bin nicht verantwortlich für das, was ihr an Sünden begeht."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mdix{Und es wurde Noah offenbart: ``Keiner von deinem Volk wird (dir) glauben, außer jenen, die (dir) bereits geglaubt haben: sei darum nicht traurig über ihr Tun.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mdx{Und baue das Schiff unter Unserer Aufsicht und nach Unserer Anweisung, und lege bei Mir keine Fürsprache für diejenigen ein, die gefrevelt haben; denn diese werden ertrinken."\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mdxi{Und er baute also das Schiff; sooft die Vornehmen seines Volkes an ihm vorübergingen, verspotteten sie ihn. Er sprach: ``Verspottet ihr uns, so werden auch wir euch verspotten, gerade so, wie ihr spottet.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mdxii{Ihr werdet dann erfahren, wer es ist, über den eine Strafe kommen wird, die ihn mit Schande bedeckt, und wen eine immerwährende Strafe treffen wird."\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mdxiii{Alsdann erging Unser Befehl und die Fluten (der Erde) brachen hervor. Da sprachen Wir: ``Bringe in das Schiff je zwei von allen (Arten) hinein, Pärchen, und deine Familie mit Ausnahme derer, gegen die das Wort bereits ergangen ist, und die Gläubigen." Und keiner glaubte ihm, außer einer kleinen Schar.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mdxiv{Und er sprach: ``Steigt hinein! Im Namen Allahs erfolgt die Ausfahrt und die Landung. Mein Herr ist wahrlich Allverzeihend, Barmherzig."\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mdxv{Und es (das Schiff) fuhr mit ihnen über Wogen gleich Bergen einher, und Noah rief zu seinem Sohn, der sich abseits hielt: ``O mein Sohn, steig mit uns ein und bleibe nicht bei den Ungläubigen!"\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mdxvi{Er sagte: ``Ich will mich sogleich auf einen Berg begeben, der mich vor dem Wasser retten wird." Er sagte: ``Es gibt heute keinen Retter vor Allahs Befehl - (Rettung) gibt es nur für jene, derer Er Sich erbarmt." Und die Woge brach zwischen den beiden herein, (und) so war er unter denen, die ertranken.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mdxvii{Und es wurde befohlen: ``O Erde, verschlinge dein Wasser, o Himmel, höre auf (zu regnen)!" Und das Wasser begann zu sinken, und die Angelegenheit war entschieden. Und das Schiff kam auf dem Güdyy zur Rast. Und es wurde befohlen: ``Fort mit dem Volk der Frevler!"\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mdxviii{Und Noah rief zu seinem Herrn und sagte: ``Mein Herr, mein Sohn gehört doch zu meiner Familie, und Dein Versprechen ist doch wahr, und Du bist der beste Richter."\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mdxix{Er sprach: ``O Noah, er gehört nicht zu deiner Familie; siehe, dies ist kein rechtschaffenes Benehmen. So frage Mich nicht nach dem, von dem du keine Kenntnis hast. Ich ermahne dich, damit du nicht einer der Toren wirst."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mdxx{Er sagte: ``Mein Herr, ich nehme meine Zuflucht bei Dir davor daß ich Dich nach dem frage, wovon ich keine Kenntnis habe. Und wenn Du mir nicht verzeihst und Dich meiner nicht erbarmst, so werde ich unter den Verlierenden sein."\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mdxxi{Es wurde befohlen: ``O Noah, geh an Land, (und sei) mit Unserem Frieden begleitet! Und Segnungen (seien) über dir und über den Geschlechtern, die bei dir sind! Und es werden andere Geschlechter kommen, denen Wir Versorgung gewähren; dann aber wird Unsere schmerzliche Strafe sie treffen."\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mdxxii{Das ist einer der Berichte von den verborgenen Dingen, die Wir dir offenbaren. Zuvor kanntest du sie nicht, weder du noch dein Volk. So harre denn aus; denn der Ausgang entscheidet zugunsten der Gottesfürchtigen.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mdxxiii{Und zu den `Ad (entsandten Wir) ihren Bruder Hud. Er sagte: ``O mein Volk, dient Allah. Ihr habt keinen anderen Gott außer Ihm. Ihr seid nichts anderes als Lügner.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mdxxiv{O mein Volk, ich verlange von euch keinen Lohn dafür; seht, mein Lohn ist einzig bei Dem, Der mich erschuf. Wollt ihr es denn nicht begreifen?\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mdxxv{O mein Volk, erfleht Vergebung von eurem Herrn, dann bekehrt euch reumütig zu Ihm; Er wird (den Segen) in reichlicher Weise vom Himmel über euch schicken und wird euch Kraft zu eurer Kraft hinzugeben. So wendet euch nicht als Schuldige ab."\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mdxxvi{Sie sagten: ``O Hud, du hast uns kein deutliches Zeichen gebracht, und wir wollen unsere Götter nicht auf dein Wort hin verlassen, noch wollen wir dir glauben.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mdxxvii{Wir können nur sagen, daß einige unserer Götter dich mit einem Übel heimgesucht haben." Er sagte: ``Ich rufe Allah zum Zeugen an, und bezeugt auch ihr, daß ich nicht an dem teilhabe, was ihr (Ihm) zur Seite stellt\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mdxxviii{außer Ihm; so schmiedet denn Pläne gegen mich, ihr alle, und gewährt mir keine Frist.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mdxxix{Ich aber vertraue auf Allah, meinen Herrn und euren Herrn. Kein Geschöpfbewegt sich (auf Erden), das Er nicht in Seine Richtung steuert. Seht, mein Herr ist auf dem geraden Weg.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mdxxx{Wenn ihr euch nun (von Ihm) abkehrt, so habe ich euch schon überbracht, womit ich zu euch entsandt wurde; und mein Herr wird ein anderes Volk an eure Stelle setzen. Und ihr könnt Ihm keineswegs schaden. Wahrlich, mein Herr ist Hüter über alle Dinge."\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mdxxxi{Und als Unser Befehl kam, da erretteten Wir Hud und diejenigen, die mit ihm gläubig waren, durch Unsere Barmherzigkeit. Und Wir erretteten sie vor schwerer Strafe.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mdxxxii{Und diese waren die `Ad, die die Zeichen ihres Herrn leugneten und Seinen Gesandten nicht gehorchten und der Aufforderung eines jeden abschweifenden Tyrannen folgten.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mdxxxiii{Ein Fluch verfolgte sie auf dieser Welt und (wird sie) am Tag der Auferstehung (verfolgen) Siehe, die `Ad haben sich gegen ihren Herrn undankbar erwiesen. Siehe, verstoßen sind die `Ad, das Volk Huds.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mdxxxiv{Und zu den Tamud (entsandten Wir) ihren Bruder Sälih; er sagte: ``O mein Volk, dient Allah; ihr habt keinen anderen Gott außer Ihm. Er hat euch aus der Erde hervorgebracht und ließ euch darauf ansiedeln. So erfleht Seine Vergebung, dann bekehrt euch zu Ihm. Wahrlich, mein Herr ist nahe (und) erhört die Gebete."\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mdxxxv{Sie sagten: ``O Salih, du warst zuvor unter uns der Mittelpunkt der Hoffnung. Willst du uns verwehren, das anzubeten, was unsere Väter anbeteten? Und wir befinden uns wahrhaftig in beunruhigendem Zweifel über das, wozu du uns aufforderst."\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mdxxxvi{Er sagte: ``O mein Volk, was meint ihr, wenn ich einen klaren Beweis von meinem Herrn habe und Er hat mir Seine Barmherzigkeit erwiesen -, wer wird mir dann gegen Allah helfen, wenn ich Ihm ungehorsam bin? So würdet ihr mein Verderben nur fördern.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mdxxxvii{O mein Volk, dies ist die Kamelstute Allahs als ein Zeichen für euch; so lasset sie auf Allahs Erde weiden und fügt ihr kein Leid zu, damit euch nicht baldige Strafe erfasse."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mdxxxviii{Doch sie zerschnitten ihr die Sehnen; da sagte er: ``Ergötzt euch in euren Häusern (noch) drei Tage. Das ist ein Urteil, das nicht zu verleugnen ist."\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mdxxxix{Als Unser Befehl eintraf, da erretteten Wir Sälih und diejenigen, die mit ihm gläubig waren, durch Unsere Barmherzigkeit, (Wir erretteten sie) vor der Schmach jenes Tages. Wahrlich, dein Herr ist der Allmächtige, der Erhabene.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mdxl{Da kam über diejenigen, die frevelten, der Schrei; und da lagen sie in ihren Häusern leblos hingestreckt\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mdxli{als hätten sie nie darin gewohnt. Siehe, die Tamud zeigten sich undankbar gegen ihren Herrn; siehe, verstoßen sind die Tamud.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mdxlii{Und es kamen Unsere Gesandten mit froher Botschaft zu Abraham. Sie sprachen: ``Friede!" Er sagte: ``Friede!" und es dauerte nicht lange, bis er ein gebratenes Kalb herbeibrachte.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mdxliii{Als er aber sah, daß ihre Hände sich nicht danach ausstreckten, fand er sie befremdend und empfand Furcht vor ihnen. Sie sprachen: ``Fürchte dich nicht; denn wir sind zum Volke Lots entsandt."\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mdxliv{Und seine Frau stand dabei und lachte, worauf Wir ihr die frohe Botschaft von (ihrem künftigen Sohn) Isaak und von (dessen künftigem Sohn) Jakob nach Isaak verkündeten.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mdxlv{Sie sagte: ``Ach, wehe mir! Soll ich ein Kind gebären, wo ich doch eine alte Frau bin und dieser mein Ehemann ein Greis ist? Das wäre wahrlich eine wunderbare Sache."\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mdxlvi{Da sprachen jene: ``Wunderst du dich über den Beschluß Allahs? Allahs Gnade und Seine Segnungen sind über euch, o Leute des Hauses. Wahrlich, Er ist Preiswürdig, Ruhmvoll."\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mdxlvii{Als die Furcht von Abraham abließ und die frohe Botschaft zu ihm kam, da begann er, mit Uns über das Volk Lots zu streiten.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mdxlviii{ahrlich, Abraham war milde, mitleidend und bußfertig.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mdxlix{``O Abraham, laß von diesem (Streit) ab. Siehe, schon ist der Befehl deines Herrn ergangen, und über sie bricht ganz gewiß die unabwendbare Strafe herein."\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mdl{Und als Unsere Gesandten zu Lot kamen geriet er ihretwegen in Bedrängnis, wurde ratlos und entsetzt und sagte: ``Das ist ein schwerer Tag."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mdli{Und sein Volk kam eilends zu ihm gelaufen; und schon zuvor hatten sie Schlechtigkeiten verübt. Er sagte: ``O mein Volk, dies hier sind meine Töchter; sie sind reiner für euch (als meine Gäste) So fürchtet Allah und bringt keine Schande hinsichtlich meiner Gäste über mich. Ist denn kein redlicher Mann unter euch?"\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mdlii{Sie sagten: ``Du weißt recht wohl, daß wir keine Absicht hinsichtlich deiner Töchter hegen, und du weißt wohl, was wir wollen."\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mdliii{Er sagte: ``Hätte ich doch Macht über euch, oder könnte ich mich an eine starke Stütze lehnen!"\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mdliv{Sie sprachen: ``O Lot, wir sind Gesandte deines Herrn. Sie sollen dich nimmermehr erreichen. So mache dich mit den Deinen in einer Phase der Nacht auf; und niemand von euch wende sich um, außer deiner Frau. Gewiß, was jene dort treffen wird, das wird auch sie treffen. Siehe, am Morgen ist ihr Termin. Ist nicht der Morgen nahe?"\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mdlv{Als nun Unser Befehl eintraf, da kehrten Wir in dieser (Stadt) das Oberste zuunterst und ließen auch brennende Steine niedergehen, die wie Regentropfen aufeinander folgten.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mdlvi{Und (dies war für sie) bei deinem Herrn aufgezeichnet. Und das gleiche liegt auch den Ungerechten nicht fern.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mdlvii{Und zu den Madyan (entsandten Wir) ihren Bruder Suaib. Er sagte: ``O mein Volk, dient Allah. Ihr habt keinen anderen Gott außer Ihm. Und verkürzt nicht Maß und Gewicht. Ich sehe euch im Wohlsein, aber ich fürchte für euch die Strafe eines völlig vernichtenden Tages.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mdlviii{O mein Volk, gebt volles Maß und Gewicht nach Richtigkeit und betrügt die Menschen nicht um ihr Eigentum und treibt im Land nicht euer Unwesen, indem ihr Unheil anrichtet.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mdlix{Das, was Allah (bei euch) ließ, ist besser für euch, wenn ihr Gläubige seid. Und ich bin nicht euer Wächter."\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mdlx{Sie sagten: ``O Suaib, heißt dein Gebet, daß wir das verlassen sollen, was unsere Väter anbeteten, oder daß wir aufhören sollen, mit unserem Besitz zu tun, was uns gefällt? Du bist doch wahrlich der Milde und der Mündige!"\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mdlxi{Er sagte: ``O mein Volk, seht ihr nicht ein, daß ich einen deutlichen Beweis von meinem Herrn habe und (daß) Er mir Seine Sorge angedeihen ließ? Und ich will gegen euch nicht so handeln, wie ich es euch zu unterlassen bitte. Ich will nur Besse rung, soweit ich (es erreichen) kann. Es ist keine Macht in mir als durch Allah. Auf Ihn vertraue ich und an Ihn wende ich mich.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mdlxii{O mein Volk, möge die Feindseligkeit gegen mich euch nicht dazu führen, daß euch das gleiche wie das trifft, was das Volk Noahs oder das Volk Huds oder das Volk Salihs getroffen hat; und das (Schicksal) des Volkes Lots ist euch nicht fern.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mdlxiii{Und bittet euren Herrn um Vergebung, (und) dann bekehrt euch zu Ihm. Wahrlich, mein Herr ist Barmherzig, Liebevoll."\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mdlxiv{Sie sagten: ``O Suaib, wir verstehen nicht viel von dem, was du sprichst, und wir sehen nur, daß du unter uns schwach bist. Und wäre nicht dein Stamm, würden wir dich steinigen. Und du wirst kein Mitleid in uns wecken."\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mdlxv{Er sagte: ``O mein Volk, ist mein Stamm bei euch geehrter als Allah? Und ihr nehmt Ihn nicht ernst. Doch wahrlich, mein Herr umfaßt alles, was ihr tut.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mdlxvi{O mein Volk, handelt eurem Standpunkt gemäß, auch ich handle (meinem Standpunkt gemäß) Bald werdet ihr erfahren, auf wen eine Strafe niederfallen wird, die ihn schändet, und wer ein Lügner ist. Und paßt nur auf; seht, ich passe mit euch auf."\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mdlxvii{Und als Unser Befehl eintraf, da erretteten Wir Suaib und diejenigen, die mit ihm gläubig waren, durch Unsere Barmherzigkeit; und der Schrei erfaßte die, welche gefrevelt hatten, so daß sie leblos in ihren Häusern lagen\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mdlxviii{so als hätten sie nie darin gewohnt. Wahrlich, Madyan wurde gerade so verstoßen wie (das Volk) Tamud verstoßen worden war.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mdlxix{Wahrlich, Wir entsandten Moses mit Unseren Zeichen und offenbarem Beweis\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mdlxx{zu Pharao und seinen Vornehmen; jedoch sie folgten Pharaos Befehl, und Pharaos Befehl war keineswegs klug.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mdlxxi{Am Tage der Auferstehung soll er seinem Volk vorangehen und sie in das Feuer hinabführen. Und schlimm ist das Ziel, wohin sie gelangen.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mdlxxii{Und ein Fluch verfolgt sie hienieden und (wird sie) am Tage der Auferstehung (verfolgen) Schlimm ist die Gabe, die (ihnen) gegeben wird.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mdlxxiii{Das ist die Kunde von den Städten, die Wir dir erzählen. Manche von ihnen stehen noch aufrecht da, und (manche) sind zerstört worden.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mdlxxiv{Nicht Wir taten ihnen Unrecht, sondern sie taten sich selber Unrecht an; und ihre Götter, die sie statt Allah anriefen, nützten ihnen überhaupt nichts, als der Befehl deines Herrn eintraf; sie stürzten sie nur noch mehr ins Verderben.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mdlxxv{Und so ist der Griff deines Herrn, wenn Er die Städte erfaßt, weil sie freveln. Wahrlich, Sein Griff ist schmerzhaft, streng.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mdlxxvi{Darin liegt gewiß ein Zeichen für den, der die Strafe des Jenseits fürchtet. Das ist ein Tag, an dem die Menschen versammelt werden, und das ist ein Tag, den jeder erleben wird.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mdlxxvii{Und Wir verschieben ihn nur bis zu einem berechneten Termin.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mdlxxviii{Wenn jener (Tag) kommt, dann wird keine Seele sprechen, es sei denn mit Seiner Erlaubnis; unter ihnen gibt es dann welche, die unselig und welche, die selig sind.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mdlxxix{Was nun diejenigen angeht, die unselig sind, so werden sie ins Feuer gelangen, worin sie seufzen und schluchzen werden.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mdlxxx{Darin werden sie auf ewig bleiben, solange die Himmel und die Erde dauern, es sei denn, dein Herr will es anders. Wahrlich, dein Herr tut, was Er will.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mdlxxxi{Was aber diejenigen angeht, die glücklich sind, so werden sie im Paradies sein, und sie werden darin auf ewig verweilen, solange die Himmel und die Erde dauern, es sei denn, dein Herr will es anders eine Gabe, die nicht unterbrochen wird.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mdlxxxii{Sei darum nicht im Zweifel darüber, was diese Leute verehren; sie verehren nur, was ihre Väter zuvor verehrten, und Wir wollen ihnen wahrlich ihren vollen Anteil unverkürzt gewähren.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mdlxxxiii{Und wahrlich, Wir haben Moses die Schrift gegeben, doch dann entstand Uneinigkeit über sie; und wäre nicht schon zuvor ein Wort von deinem Herrn ergangen, wäre es zwischen ihnen entschieden worden; und sie befinden sich darüber immer noch in bedenklichem Zweifel.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mdlxxxiv{Und allen wird dein Herrsicher ihre Taten vergelten. Er ist gut über das unterrichtet, was sie tun.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mdlxxxv{andle du darum aufrichtig, wie dir befohlen worden ist - und die (sollen aufrichtig handeln,) die sich mit dir bekehrt haben. Und seid nicht aufsässig; wahrlich, Er ist dessen ansichtig, was ihr tut.\qt@no{(112)}}
\qt@newcmd\qurantrans@de@mdlxxxvi{Und neigt euch nicht zu den Ungerech ten, damit euch das Feuer nicht erfasse. Und ihr werdet keine Beschützer außer Allah haben, noch wird euch geholfen werden.\qt@no{(113)}}
\qt@newcmd\qurantrans@de@mdlxxxvii{Und verrichte das Gebet an den beiden Tagesenden und in den Stunden der Nacht, die dem Tage näher sind. Wahrlich, die guten Taten tilgen die bösen. Das ist eine Ermahnung für die Nachdenkli chen.\qt@no{(114)}}
\qt@newcmd\qurantrans@de@mdlxxxviii{Und sei geduldig; denn wahrlich, Allah läßt den Lohn der Rechtschaffenen nicht verlorengehen.\qt@no{(115)}}
\qt@newcmd\qurantrans@de@mdlxxxix{Wären nur unter den Geschlechtern vor euch Leute von Verstand gewesen, die der Verderbtheit auf Erden hätten entgegensteuern können - ausgenommen die wenigen, die Wir aus ihrer Zahl erretteten! Doch die Frevler folgten dem, was ihnen Genuß und Behagen versprach, und sie übertraten (die Gebote)\qt@no{(116)}}
\qt@newcmd\qurantrans@de@mdxc{Und dein Herr ist nicht Der, Der die Städte zu Unrecht zerstören würde, wenn ihre Bewohner rechtschaffen wären.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@mdxci{Und hätte dein Herr es gewollt, so hätte Er die Menschen alle zu einer einzigen Gemeinde gemacht; doch sie wollten nicht davon ablassen, uneins zu sein.\qt@no{(118)}}
\qt@newcmd\qurantrans@de@mdxcii{Ausgenommen davon sind jene, derer dein Herr Sich erbarmt hat, und dazu hat Er sie erschaffen. Und das Wort deines Herrn ist in Erfüllung gegangen: ``Wahrlich, Ich werde Gahannam mit den Ginn und den Menschen insgesamt füllen."\qt@no{(119)}}
\qt@newcmd\qurantrans@de@mdxciii{Und Wir berichten dir von den Geschichten der Gesandten, um dein Herz zu festigen. Und hierin ist die Wahrheit zu dir gekommen und eine Ermahnung und eine Erinnerung für die Gläubigen.\qt@no{(120)}}
\qt@newcmd\qurantrans@de@mdxciv{Und sprich zu denen, die nicht glauben: ``Handelt eurem Standpunkt gemäß, auch wir handeln (unserem Standpunkt gemäß)\qt@no{(121)}}
\qt@newcmd\qurantrans@de@mdxcv{Und wartet nur, auch wir warten."\qt@no{(122)}}
\qt@newcmd\qurantrans@de@mdxcvi{Und Allahs ist das Verborgene in den Himmeln und auf der Erde, zu Ihm werden alle Angelegenheiten zurückgebracht werden. So bete Ihn an und vertraue auf Ihn; und dein Herr ist nicht achtlos eures Tuns.\qt@no{(123)}}
\qt@newcmd\qurantrans@de@mdxcvii{\basmalahde Alif Lam Ra ' Das sind die Verse der deutlichen Schrift.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mdxcviii{Wir haben sie als Quran auf Arabisch offenbart, auf daß ihr (sie) begreifen möget.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mdxcix{Wir erzählen dir die schönste der Geschichten, indem Wir dir diesen Quran offenbaren, obwohl du zuvor unter denen warst die keine Kenntnis besaßen.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mdc{Damals sagte Yusuf zu seinem Vater: ``O mein Vater, ich sah elf Sterne und die Sonne und den Mond, (und) ich sah sie vor mir niederfallen."\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mdci{Er sagte: ``Du, mein Söhnchen, erzähle deinen Traum nicht deinen Brüdern, sie werden sonst eine List gegen dich ersinnen; denn Satan ist dem Menschen ein offenkundiger Feind.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mdcii{Und so wird dein Herr dich erwählen und dich die Deutung der Träume lehren und Seine Huld an dir und an dem Geschlecht Jakobs vollenden, so wie Er sie zuvor an zweien deiner Vorväter vollendete, an Abraham und Isaak. Wahrlich, dein Herr ist Allwissend, Allweise."\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mdciii{Gewiß, in (der Geschichte von) Yusuf und seinen Brüdern liegen Zeichen für die Ratsuchenden.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mdciv{Damals sagten sie: ``Wahrlich, Yusuf und sein Bruder sind unserem Vater lieber als wir, obwohl wir mehrere sind. Unser Vater befindet sich gewiß in einem offenkundigen Irrtum.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mdcv{Tötet Yusuf oder vertreibt ihn in ein fernes Land; frei (für euch) wird damit das Antlitz eures Vaters, und ihr werdet danach gute Leute sein."\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mdcvi{Es sagte einer von ihnen: ``Tötet Yusuf nicht; wenn ihr aber vorhabt, etwas zu unternehmen, dann werft ihn in die Tiefe eines Brunnens: möge jemand von den Reisenden ihn herausziehen."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mdcvii{Sie sagten: ``O unser Vater, warum vertraust du uns Yusuf nicht an, obwohl wir es wahrhaftig gut mit ihm meinen?\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mdcviii{Schicke ihn morgen mit uns, damit er sich vergnüge und spiele, und wir wollen gut auf ihn aufpassen."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mdcix{Er sagte: ``Es macht mich traurig, wenn ihr ihn mit fortnehmt, und ich fürchte, der Wolf könnte ihn fressen, wenn ihr nicht auf ihn achtgebt."\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mdcx{Sie sagten: ``Wenn ihn der Wolf frißt, obgleich wir zu mehre ren sind, dann werden wir wahrlich die Verlierenden sein."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mdcxi{Und als sie ihn also mit sich fortnahmen und beschlossen, ihn in die Tiefe des Brunnens zu werfen gaben Wir ihm ein: ``Du wirst ihnen diese ihre Tat dereinst sicherlich verkünden, ohne daß sie es merken."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mdcxii{Und am Abend kamen sie weinend zu ihrem Va ter.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mdcxiii{Sie sagten: ``O unser Vater, wir liefen miteinander um die Wette und ließen Yusuf bei unseren Sachen zurück, und da hat ihn der Wolf gefressen; du wirst uns doch nicht glauben, auch wenn wir die Wahrheit; aussprechen."\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mdcxiv{Und sie hatten falsches Blut auf sein Hemd gebracht. Er sagte: ``Nein, ihr habt das geplant. Doch schön geduldig sein. Und Allah sei um Hilfe wider das gebeten, was ihr beschreibt."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mdcxv{Und dann kam eine Karawane, und sie schickte ihren Wasserschöpfer voraus. Er ließ seinen Eimer herab; und er sagte: ``O Glücksbotschaft! Hier ist ein Jüngling!" Und sie verbargen ihn wie eine Ware, und Allah wußte wohl, was sie taten.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mdcxvi{Und sie verkauften ihn zu einem schäbigen Preis für einige Dirhams; denn (an ihm) hatten sie kein Interesse.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mdcxvii{Und derjenige (Mann) aus Ägypten, der ihn gekauft hatte, sagte zu seiner Frau: ``Nimm ihn freundlich auf. Vielleicht kann er uns einmal nützlich werden, oder wir nehmen ihn als Sohn an." Und so gaben Wir Yusuf Macht im Land, und Wir lehrten ihn (auch) die Deutung der Träume. Und Allah setzt das durch, was Er beschließt. Die meisten Menschen aber wissen es nicht.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mdcxviii{Und als er zum Mann heranwuchs, verliehen Wir ihm Weisheit und Wissen. Und so belohnen Wir diejenigen, die Gutes tun.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mdcxix{Und sie (die Frau), in deren Haus er war, versuchte ihn zu verführen gegen seinen Willen; und sie verriegelte die Türen und sagte: ``Nun komm zu mir!" Er sagte: ``Ich suche Zuflucht bei Allah. Er ist mein Herr. Er hat meinen Aufenthalt ehrenvoll gemacht. Wahrlich, die Frevler erlangen keinen Erfolg."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mdcxx{Und sie begehrte ihn (und) auch er hätte sie begehrt, wenn er nicht ein deutliches Zeichen von seinem Herrn gesehen hätte. Das geschah, um Schlechtigkeit und Unsittlichkeit von ihm abzuwenden. Wahrlich, er war einer Unserer auserwählten Diener.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mdcxxi{Und sie eilten beide zur Tür, und sie zerriß sein Hemd von hinten, und sie trafen an der Tür auf ihren Mann. Sie sagte: ``Was soll der Lohn desjenigen sein, der gegen deine Familie etwas Böses plante, wenn nicht das Gefängnis oder sonst irgendeine schmerzliche Strafe?"\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mdcxxii{Er sagte: ``Sie war es, die mich gegen meinen Willen zu verführen suchte." Und ein Zeuge aus ihrer Familie bezeugte es: ``Wenn sein Hemd vorne zerrissen ist, dann hat sie die Wahrheit gesprochen und er ist ein Lügner.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mdcxxiii{Wenn sein Hemd jedoch hinten zerrissen ist, so hat sie gelogen, und er ist der, der die Wahrheit sagte."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mdcxxiv{Als er nun sah, daß sein Hemd hinten zerrissen war, da sagte er: ``Wahrlich, das ist eine List von euch (Weibern); eure List ist wahrlich groß.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mdcxxv{O Yusuf, wende dich ab von dieser Sache, und du (, o Frau), bitte um Vergebung für deine Sünde. Denn gewiß, du gehörst zu den Schuldigen."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mdcxxvi{Und einige Frauen in der Stadt sagten: ``Die Frau des `Aziz verlangt von ihrem Burschen die Hingabe gegen seinen Willen; sie ist ganz verliebt in ihn. Wahrlich, wir sehen sie in einem offenbaren Irrtum."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mdcxxvii{Als sie von ihren Ränken höne, da sandte sie ihnen (Einladungen) und bereitete ein Gastmahl für sie und gab einer jeden von ihnen ein Messer und sagte (zu Yusuf): ``Komm heraus zu ihnen!" Als sie ihn sahen, bestaunten sie ihn und schnitten sich (dabei) in die Hände und sagten: ``Allah bewahre! Das ist kein Mensch, das ist nichts als ein edler Engel."\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mdcxxviii{Sie sagte: ``Und dieser ist es, um dessentwillen ihr mich getadelt habt. Ich habe allerdings versucht, ihn gegen seinen Willen zu verführen, doch er bewährte sich. Wenn er nun nicht tut, was ich ihm befehle, so soll er unweigerlich ins Gefängnis geworfen werden und einer der Gedemütigten sein."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mdcxxix{Er sagte: ``O mein Herr, mir ist das Gefängnis lieber als das, wozu sie mich auffordern; und wenn Du ihre List nicht von mir abwendest, so könnte ich mich ihnen zuneigen und einer der Unwissenden sein."\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mdcxxx{Da erhörte ihn sein Herr und wendete ihre List von ihm ab. Wahrlich, Er ist der Allhörende, der Allwissende.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mdcxxxi{Hierauf, nachdem sie die Zeichen (seiner Unschuld) gesehen hatten, schien es ihnen angebracht (zu sein), ihn eine Zeitlang einzukerkern.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mdcxxxii{Und mit ihm kamen zwei junge Männer ins Gefängnis. Der eine von ihnen sagte: ``Ich sah mich Wein auspressen." Und der andere sagte: ``Ich sah mich auf meinem Kopf Brot tragen, von dem die Vögel fraßen. Verkünde uns die Deutung hiervon; denn wir sehen, daß du einer der Rechtschaffenen bist."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mdcxxxiii{Er sprach: ``Jedes Essen, mit dem ihr versorgt werdet, wird euch nicht eher gebracht werden, bevor ich euch hiervon berichtet habe, und zwar noch, ehe es zu euch kommt. Dies (geschieht) auf Grund dessen, was mich mein Herr gelehrt hat. Ich habe die Religion jener Leute verlassen, die nicht an Allah glauben und Leugner des Jenseits sind.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mdcxxxiv{Und ich folge der Religion meiner Väter Abraham und Isaak und Jakob. Uns geziemt es nicht, Allah irgend etwas zur Seite zu stellen. Dies ist etwas von Allahs Huld gegen uns und gegen die Menschheit, jedoch die meisten Menschen sind undankbar.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mdcxxxv{O meine beiden Kerkergenossen, sind Herren in größerer Anzahl besser oder (ist) Allah (besser), der Eine, der Allmächtige?\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mdcxxxvi{Statt Ihm verehrt ihr nichts anderes als Namen, die ihr selbst genannt habt, ihr und eure Väter; Allah hat dazu keine Ermächtigung herabgesandt. Die Entscheidung liegt einzig bei Allah. Er hat geboten, Ihn allein zu verehren. Das ist der richtige Glaube, jedoch die meisten Menschen wissen es nicht.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mdcxxxvii{O meine beiden Kerkergenossen, was den einen von euch anbelangt, so wird er seinem Herrn Wein ausschenken; und was den anderen anbelangt, so wird er gekreuzigt werden, so daß die Vögel von seinem Kopfe fressen. Die Sache, worüber ihr Auskunft verlangtet, ist beschlossen."\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mdcxxxviii{Und er sagte zu dem von den beiden, von dem er glaubte, er würde entkommen: ``Erwähne mich bei deinem Herrn." Doch Satan ließ ihn vergessen es bei seinem Herrn zu erwähnen, (und) so blieb er noch einige Jahre im Gefängnis.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mdcxxxix{Und der König sprach: ``Ich sehe sieben fette Kühe, und sie werden von sieben mageren gefressen; und ich sehe sieben grüne Ähren und(sieben) andere dürre. O ihr Vornehmen, erklärt mir die Bedeutung meines Traums, wenn ihr einen Traum auszulegen versteht."\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mdcxl{Sie sagten: ``Ein Wirrnis von Träumen! Und nicht wir sind jene, die das Deuten der Träume beherrschen."\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mdcxli{Und derjenige von den beiden, der (dem Kerker) entkommen war und sich nach geraumer Zeit (wieder an Yusuf) erinnerte, sprach: ``Ich will euch die Deutung davon wissen lassen, darum schickt mich (zu Yusuf)"\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mdcxlii{``Yusuf, o du Wahrhaftiger, erkläre uns die Bedeutung von sieben fetten Kühen, die von sieben mageren gefressen werden, und (die Bedeutung) von sieben grünen Ähren und (sieben) anderen dürren, auf daß ich zurückkehre zu den Leuten, damit sie es erfahren."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mdcxliii{Er sprach: ``lhr werdet ununterbrochen sieben Jahre lang säen und hart arbeiten; und was ihr erntet, belaßt auf den Ähren, bis auf das wenige, was ihr esset.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mdcxliv{Danach werden dann sieben schwere Jahre kommen, die alles aufzehren, was ihr an Vorrat für sie aufgespeichert habt, bis auf das wenige, was ihr bewahren möget.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mdcxlv{Danach wird ein Jahr kommen, in welchem die Menschen Erleichterung finden und in welchem sie (Früchte) pressen."\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mdcxlvi{Und der König sprach: ``Bringt ihn zu mir!" Doch als der Bote zu ihm kam, sprach er: ``Kehre zurück zu deinem Herrn und frage ihn, wie es den Frauen ergeht, die sich in die Hände schnitten; denn mein Herr kennt ihre List recht wohl."\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mdcxlvii{Er sprach (zu den Frauen): ``Wie stand es um euch, als ihr eure Verführungskünste an Yusuf gegen seinen Willen ausprobiertet?" Sie sagten: ``Allah bewahre! Wir haben nichts Böses über ihn erfahren!" Da sprach die Frau des `Aziz: ``Nun ist die Wahrheit ans Licht gekommen. Ich versuchte, ihn gegen seinen Willen zu verführen, und er gehört sicherlich zu den Wahrhaftigen."\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mdcxlviii{(Yusuf sprach): ``Dies (kommt ans Licht), damit er (`Aziz) erfährt, daß ich in (seiner) Abwesenheit gegen ihn nicht treulos war, und damit Allah die List der Treulosen nicht gelingen läßt.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mdcxlix{Und ich behaupte nicht, daß ich unschuldig bin; denn das (Menschen-)Wesen gebietet oft Böses; davon sind jene ausgenommen, derer mein Herr Sich erbarmt. Wahrlich, mein Herr ist Allverzeihend, Barmherzig."\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mdcl{Und der König sprach: ``Bringt ihn zu mir, ich will ihn für mich vorbehalten." Als er mit ihm geredet hatte, sprach er: ``Du bist von heute an bei uns in Sicherheit und genießt unser Vertrauen."\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mdcli{Er sprach: ``Setze mich über die Schatzkammern des Landes ein; denn ich bin ein wohlerfahrener Hüter."\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mdclii{Und so verliehen Wir Yusuf Macht im Lande; er weilte darin, wo immer es ihm gefiel. Wir gewähren Unsere Gnade, wem Wir wollen, und Wir lassen den Lohn der Rechtschaffenen nicht verlorengehen.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mdcliii{Der Lohn des Jenseits aber ist besser für jene, die glauben und (Allah) fürchten.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mdcliv{Und es kamen die Brüder Yusufs und traten zu ihm ein; er erkannte sie, sie aber erkannten ihn nicht.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mdclv{Und als er sie mit ihrem Bedarf ausgerüstet hatte, da sprach er: ``Bringt mir euren Bruder von eures Vaters Seite. Seht ihr nicht, daß ich volles Maß gebe und daß ich der beste Gastgeber bin?\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mdclvi{Doch wenn ihr ihn mir nicht bringt, dann sollt ihr kein Maß von mir erhalten, noch sollt ihr mir nahe kommen."\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mdclvii{Sie sagten: ``Wir wollen versuchen, ihn von seinem Vater zu trennen; und das tun wir bestimmt."\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mdclviii{Und er sprach zu seinen Dienern: ``Steckt ihre Ware in ihre Satteltaschen, so daß sie sie erkennen können, wenn sie zu ihren Angehörigen zurückgekehrt sind; vielleicht kommen sie wieder."\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mdclix{Als sie zu ihrem Vater zurückgekehrt waren, sagten sie: ``O unser Vater, das Maß ist uns verweigert worden; so schicke unseren Bruder mit uns, so daß wir das Maß erhalten; und wir wollen ihn hüten."\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mdclx{Er sprach: ``Ich kann ihn euch nicht anders anvertrauen, als ich euch zuvor seinen Bruder anvertraut habe. Doch Allah ist der beste Beschützer, und Er ist der Barmherzigste Erbarmer."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mdclxi{Und als sie ihr Gepäck öffneten, da fanden sie, daß ihnen ihre Ware wiedergegeben worden war. Sie sagten: ``O unser Vater, was können wir (uns) mehr wünschen? Diese unsere Ware ist uns zurückgegeben worden. Wir werden den Vorrat für unsere Familie heimbringen und unseren Bruder behüten, und überdies werden wir das Maß einer Kamellast haben. Das ist ein leicht erhältliches Maß."\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mdclxii{Er sprach: ``Ich werde ihn nicht mit euch schicken, ehe ihr mir nicht ein festes Versprechen im Namen Allahs gebt, daß ihr ihn mir sicher wiederbringt, es sei denn, daß euch selbst die Rückkehr abgeschnitten wird." Als sie ihm ihr festes Versprechen gegeben hatten, sprach er: ``Allah wacht über das, was wir sagen."\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mdclxiii{Und er sprach: ``O meine Söhne, zieht nicht durch ein einziges Tor ein, sondern zieht durch verschiedene Tore ein; ich kann euch nichts gegen Allah nützen. Die Entscheidung ruht bei Allah allein. Auf Ihn vertraue ich, und auf Ihn sollen die Vertrauenden vertrauen."\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mdclxiv{Daß sie auf die Art eingezogen waren wie ihr Vater es ihnen geboten hatte, konnte nichts gegen Allah nützen; nur wurde auf diese Weise das Verlangen in Jakobs Seele befriedigt; und er besaß gewiß großes Wissen, weil Wir ihn gelehrt hatten, allein die meisten Menschen wissen es nicht.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mdclxv{Und als sie vor Yusuf traten, nahm er seinen Bruder zu sich. Er sprach: ``Ich bin dein Bruder; so sei nicht traurig über das, was sie getan haben."\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mdclxvi{Als er sie dann mit ihrem Bedarf ausgerüstet hatte, steckte er den Trinkbecher (des Königs) in die Satteltaschen seines Bruders. Dann gab ein Ausrufer bekannt: ``O ihr Kamelführer, ihr seid wahrhaftig Diebe."\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mdclxvii{Sie sagten, indem sie sich zu ihnen wandten: ``Was vermißt ihr?"\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mdclxviii{Jene sagten: ``Wir vermissen den Maßbecher des Königs, und wer ihn wiederbringt, soll eine Kamellast erhalten, ich bürge dafür."\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mdclxix{Sie sagten: ``Bei Allah, ihr wisset doch, daß wir nicht gekommen sind, um Unheil im Land zu stiften, und wir sind keine Diebe."\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mdclxx{Sie sagten: ``Was soll dann die Strafe dafür sein, wenn ihr Lügner seid?"\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mdclxxi{Sie sagten: ``Die Strafe dafür sei: Der, in dessen Satteltaschen er (der Becher) gefunden wird, soll selbst das Entgelt dafür sein. So belohnen wir die Übeltäter."\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mdclxxii{Da begann er ihre Säcke vor dem Sack seines Bruders (zu durchsuchen); dann zog er ihn aus dem Sack seines Bruders hervor. So richteten Wir es für Yusuf ein; er hätte seinen Bruder nach dem Gesetz des Königs nicht aufhalten können; es sei denn, Allah hätte es so gewollt. Wir erhöhen um Rangstufen wen Wir wollen; und über jedem, der Wissen hat, ist der Eine, Der noch mehr weiß.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mdclxxiii{Sie sagten: ``Hat er gestohlen, so hat zuvor schon sein Bruder Diebstahl begangen." Jedoch Yusuf hielt es in seinem Herzen geheim und offenbarte es ihnen nicht. Er sprach: ``lhr (scheint) in der Tat übler (als das) zu sein; und Allah weiß am besten, was ihr behauptet."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mdclxxiv{Sie sagten: ``O `Aziz, er hat einen greisen Vater, so nimm einen von uns statt seiner an; denn wir sehen, du gehörst zu denen, die Gutes tun."\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mdclxxv{Er sprach: ``Allah behüte, daß wir einen anderen nehmen sollten als den, bei dem wir unsere Sachen gefunden haben; wir wären sonst wahrlich ungerecht."\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mdclxxvi{Als sie die Hoffnung, ihn umzustimmen, aufgegeben hatten, gingen sie zu vertraulicher Beratung abseits. Es sprach ihr Ältester: ``Wisset ihr nicht, daß euer Vater von euch ein festes Versprechen im Namen Allahs entgegengenommen hat und daß ihr zuvor in eurer Pflicht gegen Yusuf gefehlt habt? Ich will darum das Land nicht eher verlassen, bis mein Vater es mir erlaubt oder Allah für mich entscheidet; und Er ist der beste Richter.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mdclxxvii{Kehrt ihr zu eurem Vater zurück und sprecht: ``O unser Vater, dein Sohn hat gestohlen; und wir haben nur ausgesagt, was wir wußten, und wir konnten keine Wächter des Verborgenen sein.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mdclxxviii{Frage nur in der Stadt nach, in der wir waren, und in der Karawane, mit der wir kamen; gewiß, wir sagen die Wahrheit.""\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mdclxxix{Er sprach: ``Nein, ihr habt euch etwas vorgemacht. Doch schön geduldig sein. Vielleicht wird Allah sie mir alle wiederbringen; denn Er ist der Allwissende, der Allweise."\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mdclxxx{Und er wandte sich von ihnen ab und sprach: ``O mein Kummer um Yusuf!" Und seine Augen wurden vor Traurigkeit trüb, (doch) dann beherrschte er sich.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mdclxxxi{Sie sagten: ``Bei Allah, du hörst nicht auf, von Yusuf zu sprechen, bis du dich ganz verzehrt hast oder zu denen gehörst, die zugrunde gehen."\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mdclxxxii{Er sprach: ``Ich beklage nur meinen Kummer und meinen Gram vor Allah, und ich weiß von Allah, was ihr nicht wisset.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mdclxxxiii{O meine Söhne, zieht aus und forscht nach Yusuf und seinem Bruder und zweifelt nicht an Allahs Erbarmen; denn an Allahs Erbarmen zweifelt nur das ungläubige Volk."\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mdclxxxiv{Als sie dann vor ihn (Yusuf) traten, da sagten sie: ``O `Aziz, die Not hat uns und unsere Familie geschlagen, und wir haben Ware von geringem Wert mitgebracht; so gib uns das volle Maß und sei wohltätig gegen uns. Wahrlich, Allah belohnt die Wohltätigen."\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mdclxxxv{Er sprach: ``Wisset ihr, was ihr Yusuf und seinem Bruder antatet, weil ihr töricht waret?"\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mdclxxxvi{Sie sagten: ``Bist du etwa gar Yusuf?" Er sprach: ``Ich bin Yusuf, und dies ist mein Bruder. Allah ist wahrlich gnädig gegen uns gewesen. Wahrlich, wer rechtschaffen und geduldig ist nimmermehr läßt Allah den Lohn derer, die Gutes tun, verlorengehen."\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mdclxxxvii{Sie sagten: ``Bei Allah, Allah hat dich wahrhaftig vor uns bevorzugt, und wir sind wahrlich schuldig gewesen."\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mdclxxxviii{Er sprach: ``Kein Tadel treffe euch heute. Möge Allah euch vergeben! Denn Er ist der Barmherzigste Erbarmer.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mdclxxxix{Nehmt dies mein Hemd und legt es auf das Gesicht meines Vaters; dann kann er (wieder) sehen. Und bringt eure Familien allesamt zu mir."\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mdcxc{Als die Karawane aufgebrochen war, sprach ihr Vater: ``Wahrlich, ich spüre den Geruch Yusufs, auch wenn ihr mich für schwachsinnig haltet."\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mdcxci{Sie sagten: ``Bei Allah, du befindest dich gewiß in deinem alten Irrtum."\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mdcxcii{Als dann der Freudenbote kam, da legte er es (das Hemd) auf sein Gesicht, und da wurde er wieder sehend. Er sprach: ``Habe ich euch nicht gesagt: Ich weiß von Allah was ihr nicht wisset?"\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mdcxciii{Sie sagten: ``O unser Vater bitte für uns um Vergebung unserer Sünden; denn wir sind wahrhaftig schuldig gewesen."\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mdcxciv{Er sprach: ``Ich will Vergebung für euch von meinem Herrn erbitten. Wahrlich, Er ist der Allvergebende, der Barmherzige."\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mdcxcv{Als sie dann vor Yusuf traten, nahm er seine Eltern bei sich auf und sprach: ``Zieht in Ägypten in Sicherheit ein, wie Allah es will."\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mdcxcvi{Und er hob seine Eltern auf den Thron, und sie warfen sich vor ihm nieder. Und er sprach: ``O mein Vater, dies ist die Deutung meines Traumes von damals. Mein Herr hat ihn wahrgemacht. Und Er hat mich gütig behandelt, als Er mich aus dem Kerker führte und euch aus der Wüste herbrachte, nachdem Satan zwischen mir und meinen Brüdern Zwietracht gestiftet hatte. Wahrlich, mein Herr ist Gütig, zu wem Er will; denn Er ist der Allwissende, der Allweise.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mdcxcvii{O mein Herr, Du hast mir nun die Herrschaft verliehen und mich die Deutung der Träume gelehrt. O Schöpfer der Himmel und der Erde, Du bist mein Beschützer in dieser Welt und im Jenseits. Laß mich als (Dir) ergeben sterben und vereine mich mit den Rechtschaffenen."\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mdcxcviii{Dies ist die Kunde von dem Verborgenen, das Wir dir offenbaren. Du warst nicht bei ihnen, als sie sich über ihren Plan einigten, indem sie Ränke schmiedeten.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mdcxcix{Und die meisten Menschen werden nicht glauben, magst du es auch noch so eifrig wünschen.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mdcc{Und du verlangst von ihnen keinen Lohn dafür. Vielmehr ist es eine Ermahnung für alle Welten.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mdcci{Und wie viele Zeichen sind in den Himmeln und auf Erden, an denen sie vorbeigehen, indem sie sich von ihnen abwenden!\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mdccii{Und die meisten von ihnen glauben nicht an Allah, ohne (Ihm) Götter zur Seite zu stellen.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mdcciii{Sind sie denn sicher davor, daß nicht eine überwältigende Strafe von Allah über sie kommt, oder daß nicht plötzlich die Stunde über sie kommt, während sie nichtsahnend sind?\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mdcciv{Sprich: ``Das ist mein Weg: Ich rufe zu Allah; ich und diejenigen, die mir folgen, sind uns darüber im klaren. Und gepriesen sei Allah; und ich gehöre nicht zu den Götzendienern."\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mdccv{Auch vor dir entsandten Wir nur Männer, denen Wir die Offenbarung gaben, aus dem Volk der Städte. Sind sie denn nicht im Lande umhergezogen, so daß sie schauen konnten, wie das Ende derer war, die vor ihnen lebten? Und gewiß, die Wohnstatt des Jenseits ist besser für die Gottesfürchtigen. Wollt ihr es denn nicht begreifen?\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mdccvi{Als nun die Gesandten die Hoffnung aufgaben und dachten, sie würden belogen, kam Unsere Hilfe zu ihnen; da wurden jene errettet, die Wir wollten. Und Unsere Strafe kann nicht von dem sündigen Volk abgewendet werden.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mdccvii{Wahrlich, in ihren Geschichten ist eine Lehre für die Verständigen. Es ist keine erdichtete Rede, sondern eine Bestätigung dessen, was ihm vorausging, und eine deutliche Darlegung aller Dinge und eine Führung und eine Barmherzigkeit für ein gläubiges Volk.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mdccviii{\basmalahde Alif Lam Mim Ra'. Das sind die Verse des Buches. Und was dir von deinem Herrn hinabgesandt wurde, ist die Wahrheit. Jedoch die meisten Menschen glauben nicht.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mdccix{Allah ist es, Der die Himmel, die ihr sehen könnt, ohne Stützpfeiler emporgehoben hat. Dann herrschte Er über Sein Reich. Und Er machte (Sich) Sonne und Mond dienstbar; jedes (Gestirn) läuft seine Bahn in einer vorgezeichneten Frist. Er bestimmt alle Dinge. Er macht die Zeichen deutlich, auf daß ihr an die Begegnung mit eurem Herrn fest glauben möget.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mdccx{Und Er ist es, Der die Erde ausdehnte und feststehende Berge und Flüsse in ihr gründete. Und Er schuf auf ihr Früchte aller Art, ein Paar von jeder (Art) Er läßt die Nacht den Tag bedecken. Wahrlich, hierin liegen Zeichen für ein nachdenkendes Volk.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mdccxi{Und auf der Erde liegen dicht beieinander Landstriche und Gärten von Weinstöcken, Kornfeldern und Dattelpalmen, die auf Doppel- und auf Einzelstämmen aus einer Wurzel zusammenwachsen; sie werden mit demselben Wasser getränkt, dennoch lassen Wir die einen von ihnen die anderen an Frucht übertreffen. Hierin liegen wahrlich Zeichen für ein verständiges Volk.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mdccxii{Wenn du dich wunderst, so ist ihre Rede wunderlich: ``Wie? Wenn wir zu Staub geworden sind, dann sollen wir in einer Neuschöpfung sein?" Diese sind es, die ihrem Herrn den Glauben versagen, und diese sind es, die Fesseln um ihren Hals haben werden; und sie werden die Bewohner des Feuers sein, darin werden sie auf ewig bleiben.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mdccxiii{Sie werden dich eher die Strafe als die Wohltat beschleunigen heißen, obwohl vor ihnen beispielgebende Bestrafungen erfolgt sind. Wahrlich, dein Herr ist immer bereit, den Menschen zu vergeben, trotz ihrer Missetaten, und siehe, dein Herr ist streng im Strafen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mdccxiv{Und diejenigen, die nicht glauben, sagen: ``Warum wurde kein Zeichen von seinem Herrn zu ihm herabgesandt?" Du bist nur ein Warner. Und für jedes Volk wird ein Führer (eingesetzt)\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mdccxv{Allah weiß, was jedes weibliche Wesen trägt, und wann der Mutterschoß abnimmt und wann er zunimmt. Und bei Ihm geschehen alle Dinge nach Maß.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mdccxvi{(Er ist) der Kenner des Verborgenen und des Sichtbaren, der Große, der Erhabenste!\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mdccxvii{Diejenigen, die unter euch das Wort verhehlen und die es offen aussprechen, sind (vor Ihm) gleich; so wie die, die sich in der Nacht verbergen und die am Tag offen hervortreten.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mdccxviii{Er (der Gesandte) hat Beschützer vor und hinter sich; sie behüten ihn auf Allahs Geheiß. Gewiß, Allah ändert die Lage eines Volkes nicht, ehe sie (die Leute) nicht selbst das ändern, was in ihren Herzen ist. Und wenn Allah einem Volk etwas Übeles zufügen will, so gibt es dagegen keine Abwehr, und sie haben keinen Helfer außer Ihm.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mdccxix{Er ist es, Der euch den Blitz in Furcht und Hoffnung sehen läßt; und Er läßt die schweren Wolken aufsteigen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mdccxx{Und der Donner lobpreist Seine Herrlichkeit; und (genauso lobpreisen) Ihn die Engel in Ehrfurcht. Und Er sendet die Blitzschläge und trifft damit, wen Er will; doch streiten sie über Allah, während Er streng in der Vergeltung ist.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mdccxxi{Ihm gebührt der aufrichtige Anruf; und jene, die sie statt Ihm anrufen, kommen ihnen mit nichts entgegen; (sie sind) wie jener, der seine beiden Hände nach Wasser ausstreckt, damit es seinen Mund erreiche und ihn doch nicht erreicht. Und das Bitten der Ungläubigen ist völlig verfehlt.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mdccxxii{Wer immer in den Himmeln und auf der Erde ist, wirft sich vor Allah in Anbetung nieder, willig oder widerwillig, und (ebenfalls tun dies) ihre Schatten am Morgen und am Abend.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mdccxxiii{Sprich: ``Wer ist der Herr der Himmel und der Erde?" Sprich: ``Allah." Sprich: ``Habt ihr euch Helfer außer Ihm genommen, die sich selbst weder nützen noch schaden können?" Sprich: ``Können der Blinde und der Sehende gleich sein? Oder kann die Finsternis dem Licht gleich sein? Oder stellen sie Allah Teilhaber zur Seite die eine Schöpfung wie die Seine erschaffen haben, So das (beide) Schöpfungen ihnen gleichartig erscheinen?" Sprich: ``Allah ist der Schöpfer aller Dinge, und Er ist der Einzige, der Allmächtige."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mdccxxiv{Er sendet Wasser vom Himmel herab, so daß die Täler nach ihrem Maß durchströmt werden, und die Flut trägt Schaum auf der Oberfläche. Und ein ähnlicher Schaum ist in dem, was sie im Feuer aus Verlangen nach Schmuck und Gerät erhitzen. So verdeutlicht Allah Wahrheit und Falschheit. Der Schaum aber, der vergeht wie die Blasen; das aber, was den Menschen nützt, bleibt auf der Erde zurück. Und so prägt Allah die Gleichnisse.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mdccxxv{Für diejenigen, die auf ihren Herrn hören, ist das Gute vorgesehen; diejenigen aber, die nicht auf Ihn hören - hätten sie auch alles, was auf Erden ist, und noch einmal soviel dazu -, würden sich gerne damit loskaufen. Diese sind es, die eine schlimme Abrechnung haben werden, und ihre Herberge ist Gahannam. Welch ein elender Ruheplatz!\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mdccxxvi{Ist denn der, der weiß, daß das die Wahrheit ist, was zu dir von deinem Herrn hinabgesandt wurde, einem Blinden gleich? Nur diejenigen, die Verstand haben, lassen sich mahnen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mdccxxvii{Es sind jene, die ihr Versprechen Allah gegenüber einhalten und den Bund (mit Ihm) nicht brechen\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mdccxxviii{und es sind jene, welche verbinden, was Allah zu verbinden geboten hat, und die ihren Herrn fürchten und sich auf einen schlechten Ausgang der Abrechnung gefaßt machen\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mdccxxix{und es sind jene, die im Verlangen nach dem Wohlgefallen ihres Herrn geduldig bleiben und das Gebet verrichten und von dem, was Wir ihnen gegeben haben, im Verborgenen und öffentlich spenden und das Böse durch das Gute abwehren - diese sind es, denen der Lohn der Wohnstatt zuteil wird\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mdccxxx{die Gärten von Eden. Dort werden sie eingehen und die von ihren Eltern und ihren Frauen und ihren Nachkommen, die rechtschaffen sind. Und die Engel werden zu ihnen durch jegliches Tor treten.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mdccxxxi{``Friede sei mit euch, da ihr geduldig waret; seht, wie herrlich der Lohn der Wohnstatt ist!"\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mdccxxxii{Diejenigen aber, die den Bund Allahs brechen, nachdem (sie) ihn geschlossen haben, und zerreißen, was Allah zu verbinden geboten hat, und Unheil auf Erden stiften auf ihnen lastet der Fluch, und sie haben eine schlimme Wohnstatt.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mdccxxxiii{Allah erweitert und beschränkt die Mittel zum Unterhalt, wem Er will. Sie freuen sich des irdischen Lebens, doch das diesseitige Leben ist im Vergleich mit dem jenseitigen nur ein vergängliches Gut.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mdccxxxiv{Und jene, die ungläubig sind, sagen: ``Warum ist ihm von seinem Herrn kein Zeichen herabgesandt worden?" Sprich: ``Allah läßt zugrunde gehen, wen Er will, und leitet die zu Sich, welche sich bekehren.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mdccxxxv{Es sind jene, die glauben und deren Herzen Trost finden im Gedenken an Allah. Wahrlich, im Gedenken Allahs werden die Herzen ruhig.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mdccxxxvi{Denen, die da glauben und gute Werke tun, wird Glück und eine treffliche Heimstatt zuteil sein."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mdccxxxvii{Und so haben Wir dich zu einem Volk gesandt, vor dem bereits andere Völker dahingegangen sind, auf daß du ihnen verkünden mögest, was Wir dir offenbarten; und doch glauben sie nicht an den Allerbarmer. Sprich: ``Er ist mein Herr; kein Gott ist da außer Ihm. In Ihn setze ich mein Vertrauen und zu Ihm werde ich heimkehren."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mdccxxxviii{Und gäbe es auch einen Quran, durch den Berge versetzt oder die Erde gespalten oder durch den zu den Toten gesprochen werden könnte (, würden sie doch nicht an ihn glauben) Nein! Die Sache ruht völlig bei Allah. Haben denn die Gläubigen nicht den Versuch (, daran zu zweifeln,) aufgegeben, daß, wenn Allah gewollt hätte, Er sicher der ganzen Menschheit hätte den Weg weisen können? Und die Katastrophe wird nicht aufhören, die Ungläubigen um dessentwillen zu treffen, was sie gewirkt haben, oder sich nahe bei ihren Wohnstätten niederzulassen, bis Allahs Verheißung sich erfüllt hat. Wahrlich, Allah verfehlt den Termin nicht.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mdccxxxix{Und gewiß sind schon vor dir Gesandte verspottet worden, doch Ich gewährte denen eine Frist, die ungläubig waren. Dann erfaßte Ich sie, und wie war Meine Strafe!\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mdccxl{Ist denn Der, Der über alles, was sie begehen, wacht (, den angeblichen Göttern gleich)? Dennoch stellen sie Allah Götter zur Seite. Sprich: ``Nennt sie!" Wollt ihr Ihm etwas verkünden, was Er auf Erden nicht kennt? Oder ist es nur leere Rede? Nein, aber der böse Plan der Ungläubigen ist ihnen schön vorgegaukelt worden, und sie sind vom (rechten) Weg abgehalten worden. Und derjenige, den Allah zum Irrenden erklärt, soll keinen finden, der ihn rechtleitet.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mdccxli{Für sie ist eine Strafe im Diesseits bestimmt; und die Strafe des Jenseits ist gewiß (noch) härter, und sie werden keinen Beschützer vor Allah haben.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mdccxlii{(Dies ist) die Beschreibung des Paradieses, das den Gottesfürchtigen versprochen worden ist: Bäche durchfließen es; seine Früchte wie sein Schatten sind immerwährend. Das ist der Lohn derer, die gottesfürchtig sind; und der Lohn der Ungläubigen ist das Feuer.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mdccxliii{Und die, denen Wir die Schrift gegeben haben, freuen sich über das, was zu dir hinabgesandt wurde. Und unter den Gruppen sind einige, die einen Teil davon leugnen. Sprich: ``Mir wurde befohlen, Allah zu dienen, und nicht, Ihm Götter zur Seite zu stellen. Zu Ihm rufe ich und zu Ihm werde ich heimkehren."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mdccxliv{Und so haben Wir ihn (den Quran) hinabgesandt als eine Entscheidung in arabischer Sprache. Und wenn du ihren persönlichen Neigungen folgst, obwohl zu dir das Wissen gekommen war, so sollst du keinen Beschützer oder Retter vor Allah haben.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mdccxlv{Wahrlich, schon vor dir entsandten Wir Gesandte und gaben ihnen Frauen und Kinder. Und es ist für einen Gesandten nicht möglich, ein Zeichen zu bringen, es sei denn auf Allahs Geheiß. Alles geschieht zu einem vorbestimmten Termin.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mdccxlvi{Allah löscht aus und läßt bestehen, was Er will, und bei Ihm ist die Urschrift des Buches.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mdccxlvii{Und ob Wir dich einen Teil von dem sehen lassen, was Wir ihnen androhen, oder ob Wir dich sterben lassen - dir obliegt nur die Verkündigung und Uns die Abrechnung.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mdccxlviii{Sehen sie denn nicht, daß Wir vom Land Besitz ergreifen und es von allen Seiten in seiner Größe schmälern? Und Allah richtet; da ist keiner, der Seine Entscheidung widerrufen kann. Und Er ist schnell im Abrechnen.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mdccxlix{Diejenigen, die vor ihnen waren, haben auch Pläne geschmiedet, doch alles Planen ist Allahs Sache. Er weiß, was ein jeder begeht; und die Ungläubigen werden erfahren, wem die endgültige Wohnstatt zuteil wird.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mdccl{Und die Ungläubigen sagen: ``Du bist nicht entsandt worden." Sprich: ``Allah genügt als Zeuge gegen mich und euch und auch gegen diejenigen, die die Kenntnis der Schrift haben."\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mdccli{\basmalahde Alif Lam Ra (Dies ist) ein Buch, das Wir zu dir hinabgesandt haben, auf daß du die Menschen mit der Erlaubnis ihres Herrn aus den Finsternissen zum Licht führen mögest, auf den Weg des Erhabenen, des Preiswürdigen.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mdcclii{Allahs ist, was in den Himmeln und was auf der Erde ist. Und wehe den Ungläubigen wegen der schrecklichen Strafe!\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mdccliii{Es sind jene, die das Leben des Diesseits dem des Jenseits vorziehen und von Allahs Weg abhalten und ihn zu krümmen trachten. Sie sind es, die im großen Irrtum weit gegangen sind.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mdccliv{Und Wir schickten keinen Gesandten, es sei denn mit der Sprache seines Volkes, auf daß er sie aufkläre. Dann erklärt Allah zum Irrenden, wen Er will, und leitet recht, wen Er will. Und Er ist der Erhabene, der Allweise.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mdcclv{Und wahrlich, Wir entsandten Moses mit Unseren Zeichen (und sprachen): ``Führe dein Volk aus den Finsternissen zum Licht und erinnere es an die Tage Allahs! `` Wahrlich, darin liegen Zeichen für jeden Geduldigen, Dankbaren.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mdcclvi{Und damals sprach Moses zu seinem Volk: ``Denkt an die Gnade Allahs an euch, als Er euch vor den Leuten Pharaos errettete, die euch mit schlimmer Qual bedrückten, eure Söhne abschlachteten und eure Frauen am Leben ließen; und darin lag eine gewaltige Prüfung von eurem Herrn für euch."\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mdcclvii{Und da kündigte euer Herr an: ``Wenn ihr dankbar seid, so will Ich euch wahrlich mehr geben; seid ihr aber undankbar, dann ist Meine Strafe wahrlich streng."\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mdcclviii{Und Moses sprach: ``Wenn ihr ungläubig seid, ihr und wer sonst noch alles auf Erden ist - wahrlich, Allah ist auf keinen angewiesen, Preiswürdig."\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mdcclix{Kam zu euch (denn) nicht die Kunde von jenen, die vor euch waren - von dem Volk Noahs, den Ads und Tamuds - und von denen, die nach ihnen (kamen)? Niemand kennt sie außer Allah. Ihre Gesandten kamen mit deutlichen Zeichen zu ihnen, jedoch sie hielten ihnen die Hände vor den Mund und sagten: ``Wir glauben nicht an das, womit ihr gesandt worden seid, und wir befinden uns wahrlich in bedenklichem Zweifel über das, wozu ihr uns auffordert."\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mdcclx{Ihre Gesandten sagten: ``Existiert etwa ein Zweifel über Allah, den Schöpfer der Himmel und der Erde? Er ruft euch, damit Er euch eure Sünden vergebe und euch Aufschub bis zu einer bestimmten Frist gewähre." Sie sagten: ``lhr seid nur Menschen wie wir; ihr wollt uns von dem abhalten, was unsere Väter zu verehren pflegten. So bringt uns einen deutlichen Beweis."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mdcclxi{Ihre Gesandten sagten zu ihnen: ``Wir sind nur Menschen wie ihr, jedoch Allah erweist Gnade wem von Seinen Dienern Er will. Und wir besitzen keine Macht dazu, euch einen Beweis zu bringen, es sei denn mit Allahs Erlaubnis. Und auf Allah sollen die Gläubigen vertrauen.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mdcclxii{Und warum sollten wir nicht auf Allah vertrauen, wo Er uns doch unsere Wege gewiesen hat? Und wir wollen gewiß mit Geduld alles ertragen, was ihr uns an Leid zufügt; auf Allah mögen denn diejenigen vertrauen, die sich auf (Allah) verlassen wollen."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mdcclxiii{Und jene, die ungläubig waren, sagten zu ihren Gesandten: ``Wahrlich, wir werden euch sicherlich aus unserem Land vertreiben, wenn ihr nicht zu unserer Religion zurückkehrt." Da gab ihr Herr ihnen ein: ``Wir werden gewiß jene zugrunde gehen lassen, die Frevler sind\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mdcclxiv{und Wir werden euch wahrlich nach ihnen das Land bewohnen lassen. Das gilt für den, der das Auftreten vor Mir fürchtet, und auch das fürchtet, was Meine Drohung angeht."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mdcclxv{Und sie erflehten den Sieg, und jeder hartnäckige Tyrann schlug fehl\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mdcclxvi{und hinter ihm rückt Gahannam her, und er wird von Eiter getränkt werden\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mdcclxvii{er wird ihn hinunterschlucken und kaum daran Genuß finden. Und der Tod wird von allen Seiten zu ihm kommen, doch er wird nicht sterben. Und (zusätzlich) kommt hinterher noch eine strenge Strafe.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mdcclxviii{Die Lage derer, die nicht an ihren Herrn glauben, ist die: Ihre Werke sind gleich Asche, auf die der Wind an einem stürmischen Tag heftig bläst. Sie sollen keine Macht haben über das, was sie verdienen. Das ist wahrlich die weitgegangene Irreführung.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mdcclxix{Siehst du denn nicht, daß Allah die Himmel und die Erde in Wirklichkeit geschaffen hat? Wenn Er will, so kann Er euch hinwegnehmen und eine neue Schöpfung hervorbringen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mdcclxx{Und das ist für Allah keineswegs schwer.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mdcclxxi{Und sie werden allesamt vor Allah hintreten; dann werden die Schwachen zu den Hochmütigen sagen: ``Gewiß, wir waren eure Gefolgs leute; könnt ihr uns also nicht etwas von der Strafe Allahs abnehmen?" Sie werden sagen: ``Hätte Allah uns den Weg gewiesen, wir hätten euch sicherlich den Weg gewiesen. Es ist gleich für uns, ob wir Ungeduld zeigen oder geduldig bleiben: es gibt für uns kein Entrinnen."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mdcclxxii{Und wenn die Sache entschieden worden ist, dann wird Satan sagen: ``Allah hat euch ein wahres Versprechen gegeben, ich aber versprach euch etwas und hielt es nicht. Und ich hatte keine Macht über euch, außer euch zu rufen; und ihr gehorchtet mir. So tadelt nicht mich, sondern tadelt euch selber. Ich kann euch nicht retten, noch könnt ihr mich retten. Ich habe es schon von mir gewiesen, daß ihr mich (Allah) zur Seite stelltet." Den Missetätern wird wahrlich eine schmerzliche Strafe zuteil sein.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mdcclxxiii{Und diejenigen, die da glauben und gute Werke tun, werden in Gärten eingeführt werden, durch die Bäche fließen, um mit der Erlaubnis ihres Herrn ewig darin zu wohnen. Ihr Gruß dort wird lauten: ``Friede!"\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mdcclxxiv{Siehst du nicht, wie Allah das Gleichnis eines guten Wortes prägt? (Es ist) wie ein guter Baum, dessen Wurzeln fest sind und dessen Zweige bis zum Himmel (ragen).\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mdcclxxv{Er bringt seine Frucht zu jeder Zeit mit der Erlaubnis seines Herrn hervor. Und Allah prägt Gleichnisse für die Menschen, auf daß sie nachdenken mögen.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mdcclxxvi{Und das Gleichnis eines schlechten Wortes aber ist wie ein schlechter Baum, der aus der Erde entwurzelt ist und keinen Halt im Boden hat.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mdcclxxvii{Allah stärkt die Gläubigen mit dem fest gegründeten Wort, in diesem Leben wie im künftigen; und Allah läßt die Frevler irregehen; und Allah tut, was Er will.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mdcclxxviii{Siehst du nicht jene, die Allahs Gnade mit der Undankbarkeit vertauschten und ihr Volk in die Stätte des Verderbens brachten?\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mdcclxxix{Es ist Gahannam. Darin werden sie brennen, und das ist eine schlimme Unterkunft.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mdcclxxx{Und sie haben Allah Nebenbuhler zur Seite gesetzt, damit (die Menschen) von Seinem Weg abirren. Sprich: ``Vergnügt euch eine Weile, dann aber endet eure Reise im Feuer."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mdcclxxxi{Sprich zu Meinen Dienern, die gläubig sind, auf daß sie das Gebet verrichten und von dem, was Wir ihnen gegeben haben, im Verborgenen und öffentlich spenden mögen, bevor ein Tag kommt, an dem es weder Handel noch Freundschaft geben wird.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mdcclxxxii{Allah ist es, der die Himmel und die Erde erschuf und Wasser aus den Wolken niederregnen ließ und damit Früchte zu eurem Unterhalt hervorbrachte; und Er hat euch die Schiffe dienstbar gemacht, damit sie auf dem Meer auf Seinen Befehl fahren, und Er hat euch die Flüsse dienstbar gemacht.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mdcclxxxiii{Und Er machte euch die Sonne und den Mond dienstbar, die voller Eifer sind. Und dienstbar machte Er euch die Nacht und den Tag.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mdcclxxxiv{Und Er gab euch alles, was ihr von Ihm begehrtet; und wenn ihr Allahs Wohltaten aufzählen wolltet, würdet ihr sie nicht vollständig erfassen können. Siehe, der Mensch ist wahrlich frevelhaft, undankbar.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mdcclxxxv{Und damals sprach Abraham: ``Mein Herr, mache diese Stadt zu einer Stätte des Friedens und bewahre mich und meine Kinder davor, die Götzen anzubeten\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mdcclxxxvi{mein Herr, sie haben viele Menschen irregeleitet. Wer mir nun folgt, der gehört sicher zu mir; und wer mir nicht gehorcht siehe, Du bist Allverzeihend, Barmherzig.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mdcclxxxvii{Unser Herr, ich habe einen Teil meiner Nachkommenschaft in einem unfruchtbaren Tal nahe bei Deinem heiligen Haus angesiedelt, o unser Herr, auf daß sie das Gebet verrichten mögen. So mache ihnen die Herzen der Menschen zugeneigt und versorge sie mit Früchten, damit sie dankbar sein mögen.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mdcclxxxviii{Unser Herr, Du weißt, was wir verbergen und was wir kundtun. Und vor Allah ist nichts verborgen, ob auf Erden oder im Himmel.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mdcclxxxix{Alles Lob gebührt Allah, Der mir, ungeachtet des Alters, Ismael und Isaak geschenkt hat. Wahrlich, mein Herr ist der Erhörer des Gebets.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mdccxc{Mein Herr, hilf mir, daß ich und meine Kinder das Ge bet verrichten. Unser Herr! Und nimm mein Gebet an.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mdccxci{Unser Herr, vergib mir und meinen Eltern und den Gläubigen an dem Tage, an dem die Abrechnung stattfinden wird."\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mdccxcii{Und denke nicht, daß Allah nicht beachtet, was die Frevler tun. Er gewährt ihnen nur einen Aufschub bis zu dem Tage, an dem die Augen starr blicken werden.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mdccxciii{Angstvoll eilen sie vorwärts, mit hochgereckten Köpfen, (und) ihr Blick kehrt nicht zu ihnen zurück, und ihre Herzen sind leer.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mdccxciv{Und warne die Menschen vor dem Tag, an dem die Strafe über sie kommen wird. Dann werden die Frevler sagen: ``Unser Herr, gib uns für eine kurze Frist Aufschub. Wir wollen Deinem Ruf Gehör schenken und den Gesandten Folge leisten." - ``Habt ihr nicht zuvor geschworen, der Untergang werde euch nicht treffen?\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mdccxcv{Und ihr wohnt in den Wohnungen derer, die gegen sich selbst frevelten, und es ist euch deutlich gemacht worden, wie Wir mit ihnen verfuhren; und Wir haben euch klare Beweise geliefert."\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mdccxcvi{Und sie haben bereits ihre Ränke geschmiedet, aber ihre Ränke sind bei Allah, und wären ihre Ränke derart, daß sie Berge versetzen sollten.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mdccxcvii{Denke nicht, daß Allah Sein Versprechen Seinen Gesandten gegenüber nicht halten werde; gewiß, Allah ist Erhaben, (ist Der,) Der Seine Vergeltung fühlen läßt\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mdccxcviii{an dem Tage, da die Erde in eine andere Erde verwandelt werden wird, und auch die Himmel (verwandelt werden); und sie werden (alle) vor Allah treten, den Einzigen, den Allgewaltigen.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mdccxcix{Und an jenem Tage wirst du die Sünder in Ketten gefesselt sehen.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mdccc{Ihre Hemden werden aus Teer sein, und das Feuer wird ihre Gesichter bedecken\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mdccci{auf daß Allah jedem vergelte, was er begangen hat. Wahrlich, Allah ist schnell im Abrechnen.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mdcccii{Dies ist eine Kundgebung an die Menschen, auf daß sie sich dadurch warnen lassen und auf daß sie wissen mögen, daß nur Er der Einzige Gott ist, und auf daß diejenigen, die Verstand haben, sich mahnen lassen.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mdccciii{\basmalahde Alif Lam Ra Dies sind die Verse des Buches und des deutlichen Quran.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mdccciv{Es mag wohl sein, daß die Ungläubigen wünschen, sie wären Muslime geworden.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mdcccv{Lasse sie essen und genießen und von Hoffnung abgelenkt werden; bald werden sie es erfahren.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mdcccvi{Und Wir haben nie eine Stadt zerstört, ohne daß ihr eine wohlbekannte Frist bemessen gewesen wäre.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mdcccvii{Kein Volk kann seine Frist überschreiten; noch können sie dahinter zurückbleiben.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mdcccviii{Und sie sagten: `` O du, zu dem die Ermahnung herabgesandt wurde, du bist wahrlich ein Verrückter.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mdcccix{Warum bringst du nicht Engel zu uns, wenn du einer der Wahrhaftigen bist?"\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mdcccx{Wahrlich, Wir senden keine Engel hinab, außer aus triftigem Grunde, und dann wird ihnen kein Aufschub gewährt.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mdcccxi{Wahrlich, Wir Selbst haben diese Ermah nung hinabgesandt, und sicherlich werden Wir ihr Hüter sein.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mdcccxii{Und wahrlich, Wir entsandten schon vor dir (Gesandte) zu den Parteien der Früheren.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mdcccxiii{Und nie kam ein Gesandter zu ihnen, über den sie nicht gespottet hätten.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mdcccxiv{So lassen Wir diese (Spottlust) in die Herzen der Sünder einziehen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mdcccxv{Sie glauben nicht daran, obwohl sich das Beispiel der Früheren ereignet hat.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mdcccxvi{Und selbst wenn Wir ihnen ein Tor des Himmels öffneten und sie begännen dadurch hinaufzusteigen\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mdcccxvii{sie würden gewiß sagen: ``Nur unsere Blicke sind benommen; wahrlich, man hat uns nur etwas vorgegaukelt."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mdcccxviii{Wahrlich, Wir haben Türme in den Himmel gesetzt und ihn für diejenigen, die ihn anschauen, ausge schmückt.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mdcccxix{Und Wir haben ihn vor jedem verfluchten Satan bewahrt\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mdcccxx{außer vor jenem, der heimlich lauscht, (und den) dann eine wirkungsvolle Flamme verfolgt.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mdcccxxi{Und die Erde haben Wir ausgedehnt und darauf feste Berge gesetzt, und Wir ließen alles auf ihr wachsen, was ausgewogen ist.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mdcccxxii{Und Wir schufen dar auf Mittel zu eurem Unterhalt und dem derer, die ihr nicht versorgt.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mdcccxxiii{Und es gibt nichts, von dem Wir keine Schätze hätten; aber Wir senden es nur in bestimmtem Maß hinab.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mdcccxxiv{Und Wir senden die fruchtbar machenden Winde (hinab) Dann senden Wir Wasser aus den Wolken nieder, dann geben Wir es euch zu trinken; und ihr hättet es nicht aufspeichern können.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mdcccxxv{Und wahrlich, Wir Selbst machen lebendig und lassen sterben; und Wir allein sind die Erben.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mdcccxxvi{Und Wir kennen wohl jene unter euch, die voranschreiten, und Wir kennen wohl jene, die zurückbleiben.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mdcccxxvii{Und wahrlich, es ist dein Herr, Der sie versammeln wird. Siehe, Er ist Allweise, Allwissend.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mdcccxxviii{Und wahrlich, Wir haben den Menschen erschaffen aus trockenem, tönendem Lehm, aus schwarzem, zu Gestalt gebildetem Schlamm.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mdcccxxix{Und die Ginn erschufen Wir zuvor aus dem Feuer der sengenden Glut.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mdcccxxx{Und damals sprach dein Herr zu den Engeln: ``lch bin im Begriff, den Menschen aus trockenem, tönendem Lehm zu erschaffen, aus schwarzem, zu Gestalt gebildetem Schlamm.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mdcccxxxi{Wenn Ich ihn nun vollkommen geformt und ihm Meinen Geist eingehaucht habe, dann werft euch vor ihm nieder."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mdcccxxxii{Da warfen sich die Engel allesamt nieder\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mdcccxxxiii{außer Iblis; er weigerte sich, unter den Sich-Niederwerfenden zu sein.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mdcccxxxiv{Er sprach: ``O Iblis, was ist mit dir, daß du nicht unter den SichNiederwerfenden sein wolltest?"\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mdcccxxxv{Er sprach: ``Nimmermehr werde ich mich vor einem Menschen niederwerfen, den Du aus trockenem, tönendem Lehm geschaffen hast, aus schwarzem, zu Gestalt gebildetem Schlamm."\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mdcccxxxvi{Er sprach: ``Hinaus denn von hier; denn wahrlich, du bist verflucht.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mdcccxxxvii{Der Fluch soll auf dir lasten bis zum Tage des Gerichts."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mdcccxxxviii{Er sprach: ``Mein Herr, so gewähre mir einen Aufschub bis zu dem Tage, an dem sie auferweckt werden."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mdcccxxxix{Er sprach: ``Du bist unter denen, die Aufschub erlangen\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mdcccxl{bis zur vorbestimmten Zeit."\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mdcccxli{Er sprach: ``Mein Herr, da Du mich hast abirren lassen, so will ich ihnen wahrlich (das Böse) auf Erden ausschmücken, und wahrlich, ich will sie allesamt irreführen\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mdcccxlii{außer Deinen erwählten Dienern unter ihnen."\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mdcccxliii{Er sprach: ``Dies ist ein gerader Weg, den Ich (dir) gewähre.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mdcccxliv{Wahrlich, du sollst keine Macht über Meine Diener haben, bis auf jene der Verführten, die dir folgen."\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mdcccxlv{Und wahrlich, Gahannam ist ihnen allen der verheißene Ort.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mdcccxlvi{Sieben Tore hat sie, und jedem Tor ist ein Teil von ihnen zugewiesen.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mdcccxlvii{Wahrlich, die Gottesfürchtigen werden sich in Gärten und an Quellen befinden.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mdcccxlviii{``Tretet hinein in Frieden und Sicherheit!"\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mdcccxlix{Und Wir wollen hinwegnehmen, was an Groll in ihren Herzen sein mag; brüderlich (sollen sie) auf Ruhesitzen einander gegenüber sitzen.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mdcccl{Müdigkeit wird sie darin nicht berühren, noch sollen sie jemals von dort vertrieben werden.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mdcccli{Verkünde Meinen Dienern, daß Ich wahrlich der Allverzeihende, der Barmherzige bin\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mdccclii{und daß Meine Strafe die schmerzliche Strafe ist.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mdcccliii{Und verkünde ihnen von den Gästen Abrahams\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mdcccliv{als sie bei ihm eintraten und sprachen: ``Friede!" und er sprach: ``Wir haben Angst vor euch."\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mdccclv{Sie sprachen: ``Fürchte dich nicht, wir bringen dir frohe Kunde von einem hochbegabten Knaben."\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mdccclvi{Er sagte: ``Bringt ihr mir die frohe Kunde ungeachtet dessen, daß ich vom Alter getroffen bin? Welche frohe Kunde bringt ihr denn?"\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mdccclvii{Sie sprachen: ``Wir haben dir die frohe Kunde wahrheitsgemäß überbracht; sei darum nicht einer derjenigen, die die Hoffnung aufgeben."\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mdccclviii{Er sprach: ``Und wer außer den Verirrten zweifelt an der Barmherzigkeit seines Herrn?"\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mdccclix{Er sprach: ``Was ist euer Auftrag, ihr Boten?"\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mdccclx{Sie sprachen: ``Wir sind zu einem schuldigen Volk entsandt worden\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mdccclxi{ausgenommen die Anhänger Lots, die wir alle erretten sollen\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mdccclxii{bis auf seine Frau. Wir bestimmten, daß sie unter denen sein wird, die zurückbleiben."\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mdccclxiii{Als die Boten zu den Anhängern Lots kamen\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mdccclxiv{da sprach er: ``Wahrlich, ihr seid (uns) unbekannte Leute."\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mdccclxv{Sie sprachen: ``Nein, aber wir sind mit dem zu dir gekommen, woran sie zweifelten.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mdccclxvi{Und wir sind mit der Gerechtigkeit zu dir gekommen, und gewiß, wir sind wahrhaftig.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mdccclxvii{So mache dich mit den Deinen in einer nächtlichen Stunde fort und ziehe hinter ihnen her. Und keiner von euch soll sich umwenden, sondern geht, wohin euch befohlen werden wird."\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mdccclxviii{Und Wir verkündeten ihm in dieser Angelegenheit, daß die Wurzel jener (Leute) am Morgen ausgerottet werden sollte.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mdccclxix{Und das Volk der Stadt kam voller Freude.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mdccclxx{Er sprach: ``Das sind meine Gäste, so tut mir keine Schande an.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mdccclxxi{Und fürchtet Allah und stürzt mich nicht in Schmach."\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mdccclxxii{Sie sagten: ``Haben wir dir nicht verboten, Leute (aufzunehmen)?"\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mdccclxxiii{Er sagte: ``Hier sind meine Töchter, wenn ihr etwas zu unternehmen beabsichtigt."\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mdccclxxiv{Wahrhaftig! Sie waren in ihrem Rausch verblendet, so daß sie umherirrten.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mdccclxxv{Da erfaßte der Schrei sie bei Sonnenaufgang.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mdccclxxvi{Und Wir kehrten das Oberste zuunterst, und Wir ließen auf sie brennende Steine nieder-regnen.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mdccclxxvii{Wahrlich, hierin liegen Zeichen für die Einsichtigen.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mdccclxxviii{Und wahrlich, es stellt eine bleibende Lehre dar.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mdccclxxix{Wahrlich, hierin ist ein Zeichen für die Gläubigen.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mdccclxxx{Und wahrlich, die Leute des Waldes waren gewiß Frevler.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mdccclxxxi{Und Wir rächten Uns an ihnen. Und beide liegen als eine erkennbare Mahnung da.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mdccclxxxii{Auch das Volk von Al- Higr hielt die Gesandten für Lügner.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mdccclxxxiii{Und Wir gaben (ihnen) Unsere Zeichen, sie aber wandten sich von ihnen ab.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mdccclxxxiv{Und sie pflegten sich Wohnungen zur Sicherheit in die Berge einzu hauen.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mdccclxxxv{Jedoch die Strafe erfaßte sie am Morgen.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mdccclxxxvi{Und alles, was sie sich erworben hatten, nützte ihnen nichts.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mdccclxxxvii{Wir erschufen die Himmel und die Erde und das, was zwischen beiden ist, nicht anders als in gerechter Weise; und die Stunde kommt gewiß. Darum übe Vergebung in schöner Weise.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mdccclxxxviii{Wahrlich, dein Herr - Er ist der Schöpfer, der Allwissende.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mdccclxxxix{Und Wir gaben dir wahrlich die sieben Doppelverse und den großartigen Quran.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mdcccxc{Und laß deine Augen nicht auf das abschweifen, was Wir manchen von ihnen zu kurzer Nutznießung verliehen haben, und sei auch nicht traurig ihretwegen; und senke deinen Flügel auf die Gläubigen.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mdcccxci{Und sprich: ``lch bin gewiß der deutliche Warner. ``\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mdcccxcii{Wie Wir (die Strafe) auf jene herabsandten, die sich abgespalten haben\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mdcccxciii{und den Quran für lauter Lügen erklärten.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mdcccxciv{Darum, bei deinem Herrn, werden Wir sie sicherlich alle zur Rechenschaft ziehen\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mdcccxcv{um dessentwillen, was sie zu tun pflegten.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mdcccxcvi{So tue kund, was dir befohlen wurde, und wende dich von den Götzendienern ab.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mdcccxcvii{Wir werden dir sicherlich gegen die Spötter genügen\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mdcccxcviii{die einen anderen Gott neben Allah setzen, doch bald werden sie es wissen.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mdcccxcix{Und wahrlich, Wir wissen, daß deine Brust beklommen wird wegen dem, was sie reden.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mcm{Aber lobpreise deinen Herrn und sei unter den SichNiederwerfenden.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mcmi{Und diene deinem Herrn, bis die Gewißheit zu dir kommt.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mcmii{\basmalahde Der Befehl Allahs kommt, so sucht ihn nicht zu beschleunigen. Gepriesen ist Er und Erhaben über all das, was sie anbeten.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mcmiii{Er sendet die Engel auf Seinen Befehl mit der Offenbarung zu dem von Seinen Dienern hernieder, zu dem Er will: ``Warnt (die Menschen,) daß kein Gott da ist außer Mir. Mich allein sollt ihr fürchten."\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mcmiv{Er hat die Himmel und die Erde in gerechter Weise erschaffen. Erhaben ist Er über all das, was sie anbeten.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mcmv{Er hat den Menschen aus einem Tropfen erschaffen, doch seht, nun ist er ein offenkundiger Gegner.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mcmvi{Und das Vieh hat Er erschaffen, ihr habt an ihm Wärme und Nutzen; und davon esset ihr.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mcmvii{Und es ist schön für euch, wenn ihr (es) abends eintreibt und morgens austreibt\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mcmviii{und sie tragen eure Lasten in ein Land, das ihr nicht erreichen könntet, es sei denn mit großer Mühsal. Wahrlich, euer Herr ist Gütig, Barmherzig.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mcmix{Und (erschaffen hat Er) Pferde, Maultiere und Esel zum Reiten und zum Schmuck. Und Er wird erschaffen, was ihr (noch) nicht kennt.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mcmx{Allah weist den Weg. Es gibt solche, die (vom Weg) abweichen. Und hätte Er es gewollt, hätte Er euch allesamt den Weg gewiesen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mcmxi{Er ist es, Der Wasser aus den Wolken herniedersendet; davon habt ihr zu trinken, und davon wachsen die Gebüsche, an denen ihr (euer Vieh) weiden lasset.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mcmxii{Damit läßt Er für euch Korn sprießen und den Ölbaum und die Dattelpalme und die Trauben und Früchte aller Art. Wahrlich, darin liegt ein Zeichen für nachdenkende Leute.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mcmxiii{Und Er hat für euch die Nacht und den Tag dienstbar gemacht und die Sonne und den Mond; und die Sterne sind auf Seinen Befehl hin dienstbar. Wahrlich, darin liegen Zeichen für die Leute, die Verstand haben.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mcmxiv{Und was Er auf der Erde für euch erschaffen hat, ist mannigfach an Farben. Wahrlich, darin liegt ein Zeichen für Leute, die sich mahnen lassen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mcmxv{Und Er ist es, Der (euch) das Meer dienstbar gemacht hat, auf daß ihr zartes Fleisch daraus esset und Schmuck daraus gewinnt, um ihn euch anzulegen. Und du siehst, wie die Schiffe es durchfahren, auf daß ihr Seine Huld suchet und auf daß ihr dankbar sein möget.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mcmxvi{Und Er hat feste Berge auf der Erde gegründet, damit sie nicht mit euch wanke, und Flüsse und Wege, damit ihr recht gehen möget\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mcmxvii{und (Er hat) Wegzeichen (geschaffen); und durch die Gestirne finden sie die Richtung.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mcmxviii{Ist nun wohl Der, Der erschafft, dem gleich, der nicht erschafft? Wollt ihr euch nicht ermahnen lassen?\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mcmxix{Und wenn ihr Allahs Wohltaten aufzählen wolltet, würdet ihr sie nicht restlos erfassen können. Wahrlich, Allah ist Allverzeihend, Barmherzig.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mcmxx{Und Allah weiß, was ihr verbergt und was ihr kundtut.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mcmxxi{Und jene, die sie statt Allah anrufen, schaffen nichts - sind sie doch selbst erschaffen.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mcmxxii{Tot sind sie, nicht lebendig; und sie wissen nicht, wann sie erweckt werden.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mcmxxiii{Euer Gott ist der Einzige Gott. Und die, die nicht ans Jenseits glauben - ihre Herzen sind (der Wahrheit) fremd, und sie sind hochmütig.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mcmxxiv{Unzweifelhaft kennt Allah, was sie verbergen und was sie kundtun. Wahrlich, Er liebt die Hochmütigen nicht.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mcmxxv{Und wenn sie gefragt werden: ``Was (haltet ihr) von dem, was euer Herr niedergesandt hat?" sagen sie: ``(Das sind) Fabeln der Früheren."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mcmxxvi{(Dies ist so), damit sie am Tage der Auferstehung ihre Lasten vollständig tragen und einen Teil der Lasten derer, die sie ohne Wissen irreführen. Wahrlich, schlimm ist das, was sie tragen.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mcmxxvii{Diejenigen, die vor ihnen waren, planten auch Ränke, doch Allah rüttelte ihren Bau an den Grundmauern, so daß das Dach von oben her auf sie stürzte; und die Strafe kam über sie, ohne daß sie ahnten, woher.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mcmxxviii{Dann wird Er sie am Tage der Auferstehung zuschanden machen und sprechen: ``Wo sind nun Meine ``Teilhaber", um deretwillen ihr strittet?" Die mit Erkenntnis Begabten werden sagen: ``An diesem Tage wird Schande und Unheil den Ungläubigen (zuteil sein)."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mcmxxix{Diejenigen, die von den Engeln abberufen werden - da sie gegen sich selber gefrevelt haben und nun unterwürfig geworden sind (sagen): ``Wir pflegten ja, nichts Böses zu tun." Nein, wahrlich, Allah weiß wohl, was ihr zu tun pflegtet.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mcmxxx{So tretet durch die Tore der Gahannam ein, um darin zu wohnen. Schlimm ist wahrlich die Wohnstatt der Hochmütigen.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mcmxxxi{Und (wenn) zu den Gottesfürchtigen gesprochen wird: ``Was (haltet ihr) von dem, was euer Herr herabgesandt hat?" sagen sie: ``Etwas Gutes!" Für die, welche Gutes tun, ist Gutes in dieser Welt, und die Wohnstatt des Jenseits ist noch besser. Herrlich wahrlich ist die Wohnstatt der Gottesfürchtigen.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mcmxxxii{Die Gärten von Eden, die sie betreten werden: Bäche durchfließen sie. Darin werden sie haben, was sie begehren. Und so belohnt Allah die Gottesfürchtigen.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mcmxxxiii{(Zu ihnen), die von den Engeln friedlich abberufen werden, sprechen die Engel: ``Friede sei auf euch! Tretet ein in das Paradies für das, was ihr zu tun pflegtet."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mcmxxxiv{Worauf warten sie denn, wenn nicht darauf, daß die Engel zu ihnen kommen oder daß der Befehl deines Herrn eintrifft? So taten schon jene, die vor ihnen waren. Allah war nicht ungerecht gegen sie, jedoch sie waren ungerecht gegen sich selber.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mcmxxxv{So ereilten sie die bösen Folgen ihres Tuns, und das, was sie zu verhöhnen pflegten, umschloß sie von allen Seiten.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mcmxxxvi{Und die Götzendiener sagen: ``Hätte Allah es so gewollt, so hätten wir nichts außer Ihm angebetet, weder wir noch unsere Väter, noch hätten wir etwas ohne Seinen (Befehl) verboten." Genauso taten schon jene vor ihnen. Jedoch sind die Gesandten für irgend etwas außer für die deutliche Verkündigung verantwortlich?\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mcmxxxvii{Und in jedem Volk erweckten Wir einen Gesandten (, der da predigte): ``Dient Allah und meidet die Götzen." Dann waren unter ihnen einige, die Allah leitete, und es waren unter ihnen einige, die das Schicksal des Irrtums erlitten. So reist auf der Erde umher und seht, wie das Ende der Leugner war\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mcmxxxviii{Wenn du für sie den rechten Weg begehrst, dann (wisse, daß) Allah nicht jenen den Weg weist, die (andere) irreführen; noch gibt es für sie Helfer.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mcmxxxix{Und sie schwören bei Allah ihre festen Eide, Allah werde jene nicht auferwecken, die sterben. Aber nein! Ihn bindet ein Versprechen, das Ihm obliegt jedoch die meisten Menschen wissen es nicht.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mcmxl{Er wird ihnen das klar machen, worüber sie uneins waren, damit jene, die ungläubig sind, wissen, daß sie Lügner sind.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mcmxli{Unser Wort, das Wir für eine Sache sprechen, wenn Wir sie wollen, ist nur: ``Sei!" und sie ist.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mcmxlii{Und denjenigen, die um Allahs willen ausgewandert sind, nachdem sie unterdrückt worden waren, werden Wir sicherlich eine schöne Wohnstatt in der Welt geben; und wahrlich, der Lohn des Jenseits ist (noch) größer, wenn sie es nur wüßten\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mcmxliii{(es sind) diejenigen, die geduldig geblieben sind und auf ihren Herrn vertrauen.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mcmxliv{Und vor dir entsandten Wir (auch) nur Männer, denen Wir die Offenbarung gegeben haben; so fragt die, welche die Ermahnung besitzen, wenn ihr (etwas) nicht wisset.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mcmxlv{(Wir entsandten sie) mit den deutlichen Zeichen und mit den Büchern; und zu dir haben Wir die Ermahnung hinabgesandt, auf daß du den Menschen erklärest, was ihnen hinabgesandt wurde, und auf daß sie nachdenken mögen.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mcmxlvi{Sind denn jene, die Böses planen, sicher da vor, daß Allah sie nicht in die Erde versinken läßt, oder daß die Strafe nicht über sie kommen wird, wenn sie es nicht ahnen?\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mcmxlvii{Oder (sind jene sicher davor,) daß Er sie nicht in ihrem Hin und Her ergreift, so daß sie nicht imstande sein werden, dies zu vereiteln?\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mcmxlviii{Oder (sind jene sicher davor,) daß Er sie nicht durch vorgewarnte Vernichtung erfaßt? Euer Herr ist wahrlich Gütig Barmherzig.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mcmxlix{Haben sie denn nicht gesehen, wie die Schatten eines jeden Dings, das Allah erschuf, sich nach rechts und nach links wenden und sich vor Allah niederwerfen, während sie gedemütigt werden?\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mcml{Und was an Geschöpfen in den Himmeln und auf Erden ist, wirft sich vor Allah in Anbetung nieder; genauso die Engel, und sie betragen sich nicht hochmütig.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mcmli{Sie fürchten ihren Herrn über sich und tun, was ihnen befohlen wird.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mcmlii{Und Allah hat gesprochen: ``Nehmet euch nicht zwei Götter. Er ist der Einzige Gott. So fürchtet Mich allein."\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mcmliii{Und Sein ist, was in den Himmeln und auf Erden ist, und Ihm gebührt die immerwährende Furcht. Wollt ihr also einen anderen fürchten außer Allah?\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mcmliv{Was ihr Gutes habt - es ist von Allah; und wenn euch ein Schaden trifft, dann fleht ihr Ihn um Hilfe an.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mcmlv{Doch wenn Er dann den Schaden von euch hinwegnimmt, seht, da (beginnt) ein Teil von euch, ihrem Herrn Götter zur Seite zu stellen\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mcmlvi{und das zu verleugnen, was Wir ihnen beschert haben. Wohlan, vergnügt euch nur eine Weile; bald aber werdet ihr es wissen.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mcmlvii{Und für die, von denen sie nichts wissen, setzen sie einen Teil von dem beiseite, was Wir ihnen beschert haben. Bei Allah, ihr werdet sicherlich zur Rechenschaft gezogen werden für all das, was ihr erdichtet.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mcmlviii{Und sie dichten Allah Töchter an. Gepriesen sei Er! Und sich selbst behalten sie vor, was sie begehren.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mcmlix{Und wenn einem von ihnen die Nachricht von (der Geburt) einer Tochter überbracht wird, so verfinstert sich sein Gesicht, und er unterdrückt den inneren Schmerz.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mcmlx{Er verbirgt sich vor den Leuten aufgrund der schlimmen Nachricht, die er erhalten hat: Soll er sie behalten trotz der Schande, oder (soll er sie) in der Erde verscharren? Wahrlich, übel ist, wie sie urteilen!\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mcmlxi{Diejenigen, die nicht an das Jenseits glauben, sind mit dem Schlechten zu vergleichen; Allah aber mit dem Höchsten, und Er ist der Erhabene, der Allweise.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mcmlxii{Und wenn Allah die Menschen für ihr Freveln bestrafen wollte, würde Er nicht ein einziges Lebewesen darauf (auf der Erde) bestehen lassen; doch Er gewährt ihnen Aufschub bis zu einer bestimmten Frist; und wenn ihre Frist um ist, dann können sie auch nicht eine Stunde dahinter zurückbleiben, noch können sie (ihr) vorauseilen.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mcmlxiii{Und sie schreiben Allah zu, was ihnen (selbst) mißliebig ist, und ihre Zungen äußern die Lüge, daß sie das Beste erhalten würden. Zweifellos wird ihnen das Feuer zuteil werden, und (darin) sollen sie unbeachtet bleiben.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mcmlxiv{Bei Allah, Wir schickten wahrlich schon Gesandte zu den Völkern vor dir, doch Satan ließ ihnen ihre Werke wohlgefällig erscheinen. So ist er heute ihr Schutzherr, und ihnen wird eine schmerzliche Strafe zuteil sein.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mcmlxv{Und Wir haben dir das Buch nur deshalb hinabgesandt, auf daß du ihnen das erklärest, worüber sie uneinig sind, und (Wir haben es) als Führung und Barmherzigkeit für die Leute, die glauben (, hinabgesandt)\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mcmlxvi{Und Allah hat Wasser vom Himmel herniedergesandt und damit die Erde nach ihrem Tod belebt. Wahrlich, darin liegt ein Zeichen für Leute, die hören können.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mcmlxvii{Wahrlich, auch am Vieh habt ihr eine Lehre. Wir geben euch von dem zu trinken, was in ihren Leibern (ist): Zwischen Kot und Blut (ist) in der Mitte Milch, die denen lauter (und) angenehm ist, die sie trinken.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mcmlxviii{Und von den Früchten der Dattelpalmen und den Beeren macht ihr euch Rauschtrank und gute Speise. Wahrlich, darin liegt ein Zeichen für die Leute, die Verstand haben.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mcmlxix{Und dein Herr hat der Biene eingegeben: ``Baue dir Häuser in den Bergen und in den Bäumen und in dem, was sie errichten.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mcmlxx{Dann iß von allen Früchten und folge den Wegen deines Herrn, (die Er dir) leicht gemacht hat." Aus ihren Leibern kommt ein Trank, mannigfach an Farbe. Darin liegt ein Heilmittel für die Menschen. Wahrlich, hierin ist ein Zeichen für Leute, die nachdenken.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mcmlxxi{Und Allah hat euch erschaffen, dann läßt Er euch sterben; und es gibt manche unter euch, die ins hinfällige Greisenalter getrieben werden, so daß sie nichts wissen, nachdem (sie) doch Wissen (besessen haben) Wahrlich, Allah ist Allwissend, Allmächtig.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mcmlxxii{Und Allah hat einige von euch vor den anderen mit Gaben begünstigt. Und doch wollen die Begünstigten nichts von ihren Gaben denen zurückgeben, die sie von Rechts wegen besitzen, so daß sie gleich (beteiligt) wären. Wollen sie denn Allahs Huld verleugnen?\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mcmlxxiii{Und Allah gab euch Gattinnen aus euch selbst, und aus euren Gattinnen machte Er euch Söhne und Enkelkinder, und Er hat euch mit Gutem versorgt. Wollen sie da an Nichtiges glauben und Allahs Huld verleugnen?\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mcmlxxiv{Dennoch verehren sie statt Allah solche, die nicht die Macht haben, ihnen irgendwelche Gaben von den Himmeln oder der Erde zu gewähren, noch können sie je solche Macht erlangen.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mcmlxxv{So sollt ihr Allah keine Gleichnisse prägen. Gewiß, Allah weiß, und ihr wisset nicht.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mcmlxxvi{Allah gibt (euch) das Gleichnis (von zwei Männern) an die Hand: von einem Sklaven, einem Leibeigenen, der über nichts Gewalt hat, und von einem (Freien), den Wir Selbst reichlich versorgt haben, und der davon im Verborgenen und offenkundig spendet. Sind diese gleich? Preis sei Allah! Doch die meisten von ihnen wissen es nicht.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mcmlxxvii{Und Allah gibt (euch) ein (anderes) Gleichnis von zwei Männern an die Hand: der eine von ihnen ist stumm, er hat über nichts Gewalt und ist für seinen Dienstherrn eine Last; wo er ihn auch hinschicken mag - er bringt nichts Gutes (zurück) Kann er dem gleich sein, der Gerechtigkeit gebietet und der selbst auf dem geraden Weg ist?\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mcmlxxviii{Und Allah gehört das Ungesehene der Himmel und der Erde; und was die Stunde anbelangt, so ist sie nur einen Augenblick (entfernt), nein, sie ist noch näher. Gewiß, Allah hat Macht über alle Dinge.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mcmlxxix{Und Allah hat euch aus dem Schoß eurer Mütter hervorgebracht, ohne daß ihr etwas wußtet, und Er gab euch Ohren und Augen und Herzen, auf daß ihr danken möget.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mcmlxxx{Sehen sie nicht die Vögel, die im Luftraum des Himmels in Dienstbarkeit gehalten sind? Keiner hält sie aufrecht außer Allah. Wahrlich, darin liegen Zeichen für die Leute, die glauben.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mcmlxxxi{Und Allah hat euch eure Häuser zu einem Ruheplatz gemacht, und Er hat euch aus den Häuten der Tiere Zelte gemacht, die ihr leicht zur Zeit eurer Reise und zur Zeit eures Aufenthalts handhaben könnt; und ihre Wolle und ihr Pelz und ihr Haar (gab Er euch) zu Gebrauchsgegenständen und zur Nutznießung für eine (bestimmte) Zeit.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mcmlxxxii{Und Allah hat euch aus dem, was Er geschaffen hat, schattenspendende Dinge gemacht, und in den Bergen hat Er euch Schutzwinkel gemacht, und Er hat euch Gewänder gemacht, die euch vor Hitze schützen, und Panzerhemden, die euch im Kampf schützen. So vollendet Er Seine Gnade an euch, auf daß ihr (Ihm) ergeben sein möget.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mcmlxxxiii{Doch wenn sie sich abkehren, dann bist du für nichts verantwortlich außer für die klare Verkündigung.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mcmlxxxiv{Sie kennen Allahs Gnade, und sie leugnen sie doch; und die meisten von ihnen sind ungläubig.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mcmlxxxv{Und am Tage, da Wir aus jeglichem Volk einen Zeugen erwecken werden, wird denen, die nicht glauben, nichts gestattet werden, noch wird ihre Entschuldigung angenommen werden.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mcmlxxxvi{Und wenn jene, die Unrecht begangen haben, die Strafe erst erleben, dann wird sie ihnen nicht leicht gemacht, noch werden sie Aufschub erlangen.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mcmlxxxvii{Und wenn die, welche Götter anbeten, ihre Götter sehen werden, so werden sie sagen: ``Unser Herr, das sind unsere Götter, die wir statt Deiner anriefen." Darauf werden sie ihnen die Beschuldigung zurückgeben: ``Wahrlich, ihr seid Lügner."\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mcmlxxxviii{Und an jenem Tage werden sie Allah (ihre) Unterwerfung anbieten, und alles, was sie zu erdichten pflegten, wird sie im Stich lassen.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mcmlxxxix{Die ungläubig sind und von Allahs Weg abhalten - zu (deren) Strafe werden Wir noch eine Strafe hinzufügen, weil sie Unheil anrichteten.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mcmxc{Und am Tage, da Wir in jeglichem Volk einen Zeugen aus ihren eigenen Reihen gegen sie selbst erwecken werden, wollen Wir dich als Zeugen bringen gegen diese. Und Wir haben dir das Buch zur Erklärung aller Dinge herniedergesandt, und als Führung und Barmherzigkeit und frohe Botschaft für die Gottergebenen.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mcmxci{Wahrlich, Allah gebietet, gerecht (zu handeln), uneigennützig Gutes zu tun und freigebig gegenüber den Verwandten zu sein; und Er verbietet, was schändlich und abscheulich und gewalttätig ist. Er ermahnt euch; vielleicht werdet ihr die Ermahnung annehmen.\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mcmxcii{Haltet den Bund mit Allah ein, wenn ihr einen Bund geschlossen habt; und brecht die Eide nicht nach ihrer Bekräftigung, wo ihr doch Allah zum Bürgen für euch gemacht habt. Wahrlich, Allah weiß, was ihr tut.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mcmxciii{Und seid nicht wie jene (Frau), die ihre Strickarbeiten auflöste, nachdem sie diese angefertigt hatte. Ihr macht eure Eide zu einem Mittel, euch gegenseitig zu betrügen, (aus Furcht,) ein Volk könnte sonst mächtiger werden als ein anderes. Allah stellt euch damit nur auf die Probe, und am Tage der Auferstehung wird Er euch das klar machen, worüber ihr uneinig waret.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mcmxciv{Und hätte Allah es gewollt, hätte Er euch sicherlich zu einer einzigen Gemeinde gemacht; jedoch Er läßt irregehen, wen Er will, und führt richtig, wen Er will, und ihr werdet gewiß zur Rechenschaft gezogen werden für das, was ihr getan habt.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mcmxcv{Und macht eure Eide nicht zu einem Mittel, euch gegenseitig zu betrügen; sonst wird euer Fuß ausgleiten, nachdem er fest aufgetreten ist, und ihr werdet dafür vom Übel kosten, daß ihr von Allahs Weg abgehalten habt, und euch wird eine strenge Strafe zuteil sein.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mcmxcvi{Und verschachert Allahs Bund nicht zu einem armseligen Preis. Wahrlich, was bei Allah ist, ist besser für euch, wenn ihr es nur wüßtet.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mcmxcvii{Was bei euch ist, vergeht, und was bei Allah ist, bleibt. Und Wir werden gewiß denen, die standhaft sind, ihren Lohn nach der besten ihrer Taten bemessen.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mcmxcviii{Dem, der recht handelt - ob Mann oder Frau - und gläubig ist, werden Wir gewiß ein gutes Leben gewähren; und Wir werden gewiß solchen (Leuten) ihren Lohn nach der besten ihrer Taten bemessen.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mcmxcix{Und wenn du den Quran liest, so suche bei Allah Zuflucht vor dem Satan, dem Verfluchten.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mm{Wahrlich, er hat keine Macht über die, welche da glauben und auf ihren Herrn vertrauen.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mmi{Siehe, seine Macht erstreckt sich nur auf jene, die bei ihm Beistand suchen und die (Allah) Götter zur Seite stellen.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mmii{Und wenn Wir einen Vers an Stelle eines anderen bringen - und Allah weiß am besten, was Er offenbart -, sagen sie: ``Du bist nur ein Erdichter." Nein, aber die meisten von ihnen wissen es nicht.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mmiii{Sprich: ``Der Geist der Heiligkeit hat ihn (den Quran) von deinem Herrn in Wahrheit herabgebracht, auf daß Er die festige, die da glauben, und (er hat den Quran) zu einer Führung und einer frohen Botschaft für die Gottergebenen (herabgebracht)"\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mmiv{Und Wir wissen wahrlich, daß sie sagen, wer ihn lehrt, sei nur ein Mensch. Die Sprache dessen jedoch, auf den sie hinweisen, ist eine fremde, während dies hier eine deutliche arabische Sprache ist.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mmv{Denen, die nun nicht an die Zeichen Allahs glauben, wird Allah nicht den Weg weisen, und ihnen wird eine schmerzliche Strafe zuteil sein.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mmvi{Wahrlich, es sind ja nur jene, die nicht an die Zeichen Allahs glauben, die da Falsches erdichten; und sie allein sind die Lügner.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mmvii{Wer Allah verleugnet, nachdem er geglaubt hat - den allein ausgenommen, der (dazu) gezwungen wird, während sein Herz im Glauben Frieden findet -, auf jenen aber, die ihre Brust dem Unglauben öffnen, lastet Allahs Zorn; und ihnen wird eine strenge Strafe zuteil sein.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mmviii{Dies (ist so), weil sie das Leben des Diesseits dem des Jenseits vorgezogen haben, und weil Allah das Volk der Ungläubigen nicht leitet.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mmix{Sie sind es, auf deren Herzen und Ohren und Augen Allah ein Siegel gesetzt hat. Und sie sind die Achtlosen.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mmx{Zweifellos sind sie es, die im Jenseits die Verlierenden sein werden.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mmxi{Alsdann wird dein Herr denen gegenüber, die auswanderten, nachdem sie verfolgt worden waren, und dann kämpften und geduldig blieben - siehe, (ihnen gegenüber) wird dein Herr hernach gewiß Allverzeihend, Barmherzig sein.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mmxii{An dem Tage, da jede Seele kommen wird, um sich selbst zu rechtfertigen, und da jeder Seele voll vergolten wird, was sie getan hat, sollen sie kein Unrecht erleiden.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mmxiii{Und Allah gibt das Gleichnis von einer Stadt: Sie genoß Sicherheit und Frieden und wurde reichlich aus allen Orten versorgt; doch sie leugnete die Wohltaten Allahs. Darum ließ Allah sie eine umfassende Not des Hungers und der Furcht kosten für das, was sie (ihre Bewohner) zu tun pflegten.\qt@no{(112)}}
\qt@newcmd\qurantrans@de@mmxiv{Und wahrlich, zu ihnen war ein Gesandter aus ihrer Mitte gekommen, sie aber verleugneten ihn; da ereilte sie die Strafe, weil sie Frevler waren.\qt@no{(113)}}
\qt@newcmd\qurantrans@de@mmxv{Darum esset nun von den erlaubten guten Dingen, womit Allah euch versorgt hat; und seid dankbar für Allahs Huld, wenn Er es ist, Dem ihr dient.\qt@no{(114)}}
\qt@newcmd\qurantrans@de@mmxvi{Verwehrt hat Er euch nur das von selbst Verendete und Blut und Schweinefleisch und das, worüber ein anderer Name als Allahs angerufen worden ist. Wer aber genötigt wird, (davon zu essen,) ohne die Gebote übertreten zu wollen und ohne das Maß zu überschreiten -, wahrlich, Allah ist dann Allverzeihend, Barm herzig.\qt@no{(115)}}
\qt@newcmd\qurantrans@de@mmxvii{Und sagt nicht aufgrund der Falschheit eurer Zungen: ``Das ist erlaubt, und das ist verboten", so daß ihr eine Lüge gegen Allah erdichtet. Wahrlich, diejenigen, die eine Lüge gegen Allah erdichten, haben keinen Erfolg.\qt@no{(116)}}
\qt@newcmd\qurantrans@de@mmxviii{Wenig Genuß (haben sie), (dann) aber wird ihnen eine schmerzliche Strafe zuteil sein.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@mmxix{Und denen, die Juden sind, haben Wir zuvor schon all das verboten, was Wir dir mitteilen. Und nicht Wir taten ihnen Unrecht, sondern sie taten sich selber Unrecht.\qt@no{(118)}}
\qt@newcmd\qurantrans@de@mmxx{Alsdann wird dein Herr gegen die, die in Unwissenheit Böses tun und es danach bereuen und sich bessern -, wahrlich, (ihnen gegenüber) wird dein Herr hernach Allverzeihend, Barmherzig sein.\qt@no{(119)}}
\qt@newcmd\qurantrans@de@mmxxi{Wahrlich, Abraham war ein Vorbild: (er war) gehorsam gegen Allah, lauter im Glauben, und er gehörte nicht zu den Götzendienern\qt@no{(120)}}
\qt@newcmd\qurantrans@de@mmxxii{er war dankbar für Seine Wohltaten; Er erwählte ihn und leitete ihn auf den geraden Weg.\qt@no{(121)}}
\qt@newcmd\qurantrans@de@mmxxiii{Und Wir gewährten ihm Gutes in dieser Welt, und im Jenseits wird er sicherlich unter den Rechtschaffenen sein.\qt@no{(122)}}
\qt@newcmd\qurantrans@de@mmxxiv{Alsdann haben Wir dir offenbart: ``Folge dem Weg Abrahams, des Lauteren im Glauben, der nicht zu den Götzendienern gehörte."\qt@no{(123)}}
\qt@newcmd\qurantrans@de@mmxxv{Der Sabbat wurde denen auferlegt, die über ihn uneins waren; und dein Herr wird gewiß am Tage der Auferstehung zwischen ihnen über das richten, worüber sie uneins waren.\qt@no{(124)}}
\qt@newcmd\qurantrans@de@mmxxvi{Rufe zum Weg deines Herrn mit Weisheit und schöner Ermahnung auf, und streite mit ihnen auf die beste Art. Wahrlich, dein Herr weiß am besten, wer von Seinem Wege abgeirrt ist; und Er kennt jene am besten, die rechtgeleitet sind.\qt@no{(125)}}
\qt@newcmd\qurantrans@de@mmxxvii{Und wenn ihr bestraft, dann bestraft in dem Maße, wie euch Unrecht zugefügt wurde; wollt ihr es aber geduldig ertragen, dann ist das wahrlich das Beste für die Geduldigen\qt@no{(126)}}
\qt@newcmd\qurantrans@de@mmxxviii{und harre in Geduld aus; deine Geduld aber kommt nur von Allah. Und sei weder traurig über sie, noch beunruhigt wegen ihrer Ränke.\qt@no{(127)}}
\qt@newcmd\qurantrans@de@mmxxix{Wahrlich, Allah ist mit denen, die gottesfürchtig sind und Gutes tun.\qt@no{(128)}}
\qt@newcmd\qurantrans@de@mmxxx{\basmalahde Gepriesen sei Der, Der bei Nacht Seinen Diener von der heiligen Moschee zu der fernen Moschee, deren Umgebung Wir gesegnet haben, hinführte, auf daß Wir ihm einige Unserer Zeichen zeigten. Wahrlich, Er ist der Allhörende, der Allsehende.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmxxxi{Und Wir gaben Moses die Schrift und machten sie zu einer Führung für die Kinder Israels (und sprachen): ``Nehmt keinen zum Beschützer außer Mir\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmxxxii{o ihr Nachkommen derer, die Wir mit Noah trugen! Er war wahrlich ein dankbarer Diener."\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmxxxiii{Und Wir hatten den Kindern Israels in der Schrift dargelegt: ``Seht, ihr werdet gewiß zweimal im Land Unheil anrichten, und ihr werdet gewiß sehr überheblich sein."\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmxxxiv{Wenn nun die Zeit für die erste der beiden Verheißungen in Erfüllung kam, da sandten Wir gegen euch Diener von Uns, die mit gewaltiger Kriegsmacht begabt waren; und sie drangen in das Wohngebiet ein, und so wurde die Verheißung erfüllt.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmxxxv{Dann gaben Wir euch wiederum die Macht über sie und stärkten euch mit Reichtum und Kindern und vermehrten eure Zahl.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmxxxvi{Wenn ihr Gutes tut, so tut ihr Gutes für eure eigenen Seelen; und wenn ihr Böses tut, so ist es gegen sie. Als nun die Zeit für die zweite Verheißung in Erfüllung kam (, entsandten Wir Diener), damit sie eure Gesichter demütigten und die Moschee betreten, wie sie sie das erste Mal betreten hatten, und alles, was sie erobert hatten, bis auf den Grund zerstörten.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmxxxvii{Es ist möglich, daß euer Herr Sich eurer erbarmt; doch wenn ihr zurückkehrt, so wollen (auch) Wir zurückkehren; und Wir haben Gahannam zu einem Gefängnis für die Ungläubigen gemacht.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmxxxviii{Wahrlich, dieser Quran leitet zum wirklich Richtigen und bringt den Gläubigen, die gute Taten verrichten, die frohe Botschaft, auf daß ihnen großer Lohn zuteil werde.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmxxxix{Und Wir haben denen, die nicht an das Jenseits glauben, eine schmerzliche Strafe bereitet.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmxl{Und der Mensch bittet um das Schlimme, wie er um das Gute bittet; und der Mensch ist voreilig.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmxli{Und Wir machten die Nacht und den Tag zu zwei Zeichen, indem Wir das Zeichen der Nacht gelöscht haben, und das Zeichen des Tages haben Wir sichtbar gemacht, damit ihr nach der Fülle eures Herrn trachtet und die Zählung der Jahre und die Rechenkunst kennt. Und jegliches Ding haben Wir durch eine deutliche Erklärung klar gemacht.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmxlii{Und einem jeden Menschen haben Wir seine Taten an den Nacken geheftet; und am Tage der Auferstehung werden Wir ihm ein Buch herausbringen, das ihm geöffnet vorgelegt wird.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmxliii{``lies dein Buch. Heute genügt deine eigene Seele, um die Abrechnung gegen dich vorzunehmen."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmxliv{Wer den rechten Weg befolgt, der befolgt ihn nur zu seinem eigenen Heil; und wer irregeht, der geht allein zu seinem eignen Schaden irre. Und keine lasttragende Seele soll die Last einer anderen tragen. Und Wir bestrafen nie, ohne zuvor einen Gesandten geschickt zu haben.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmxlv{Und wenn Wir eine Stadt zu zerstören beabsichtigen, lassen Wir Unseren Befehl an ihre Wohlhabenden ergehen; wenn sie in ihr freveln, so wird der Richtspruch gegen sie fällig, und Wir zerstören sie bis auf den Grund.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmxlvi{Und wie viele Geschlechter haben Wir nach Noah vernichtet! Und dein Herr kennt und sieht die Sünden Seiner Diener zur Genüge.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmxlvii{Wenn einer das Irdische begehrt, bereiten Wir ihm schnell das, was Wir wollen - dem, der Uns beliebt; danach haben Wir Gahannam für ihn bestimmt, in der er brennt, verdammt und verstoßen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmxlviii{Und wenn aber einer das Jenseits begehrt und es beharrlich erstrebt und gläubig ist - dessen Eifer wird mit Dank belohnt.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmxlix{Ihnen allen, diesen und jenen, gewähren Wir die Gabe deines Herrn. Und die Gabe deines Herrn ist keinesfalls beschränkt.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mml{Schau, wie Wir die einen von ihnen über die anderen erhöht haben; und wahrhaftig, das Jenseits soll noch mehr Ränge und Auszeichnungen enthalten.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmli{Setze neben Allah keinen anderen Gott, auf daß du nicht mit Schimpf bedeckt und verlassen dasitzt.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmlii{Und dein Herr hat befohlen: ``Verehrt keinen außer Ihm und (erweist) den Eltern Güte. Wenn ein Elternteil oder beide bei dir ein hohes Alter erreichen, so sage dann nicht ``Pfui!" zu ihnen und fahre sie nicht an, sondern sprich zu ihnen in ehrerbietiger Weise.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmliii{Und senke für sie in Barmherzigkeit den Flügel der Demut und sprich: ``Mein Herr, erbarme Dich ihrer (ebenso mitleidig), wie sie mich als Kleines aufgezogen haben.""\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmliv{Euer Herr weiß am besten, was in euren Seelen ist: Wenn ihr rechtgesinnt seid, dann ist Er gewiß Verzeihend gegenüber den SichBekehrenden.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmlv{Und gib dem Verwandten, was ihm gebührt, und ebenso dem Armen und dem Sohn des Weges, aber sei (dabei) nicht ausgesprochen verschwenderisch.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmlvi{Denn die Verschwender sind Brüder der Satane, und Satan war undankbar gegen seinen Herrn.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmlvii{Und wenn du dich von ihnen abwendest - im Trachten nach der Barmherzigkeit deines Herrn, auf die du hoffst -, so sprich zu ihnen angenehme Worte.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmlviii{Und laß deine Hand nicht an deinen Hals gefesselt sein, aber strecke sie auch nicht zu weit geöffnet aus, damit du nicht getadelt (und) zerschlagen niedersitzen mußt.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmlix{Wahrlich, dein Herr erweitert und beschränkt (dem), dem Er will, die Mittel zum Unterhalt; denn Er kennt und sieht Seine Diener wohl.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmlx{Und tötet eure Kinder nicht aus Furcht vor Armut; Wir sorgen für sie und für euch. Wahrlich, sie zu töten ist ein großer Fehler.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmlxi{Und kommt der Unzucht nicht nahe; seht, das ist eine Schändlichkeit und ein übler Weg.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmlxii{Und tötet nicht das Leben, das Allah unverletzlich gemacht hat, es sei denn zu Recht. Und wer da ungerechterweise getötet wird - dessen Erben haben Wir gewiß Ermächtigung (zur Vergeltung) gegeben; doch soll er im Töten nicht maßlos sein; denn er findet (Unsere) Hilfe.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmlxiii{Und tastet nicht das Gut der Waise an, es sei denn zu (ihrem) Besten, bis sie die Reife erreicht hat. Und haltet die Verpflichtung ein; denn über die Verpflichtung muß Rechenschaft abgelegt werden.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmlxiv{Und gebt volles Maß, wenn ihr meßt, und wägt mit richtiger Waage; das ist durchaus vorteilhaft und letzten Endes das Beste.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmlxv{Und verfolge nicht das, wovon du keine Kenntnis hast. Wahrlich, das Ohr und das Auge und das Herz sie alle sollen zur Rechenschaft gezogen werden.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmlxvi{Und wandle nicht überheblich auf der Erde; denn du kannst weder die Erde durchbrechen, noch kannst du die Berge an Höhe erreichen.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmlxvii{Dasselbe all dessen ist hassenswert vor deinem Herrn.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmlxviii{Dies ist ein Teil von der Weisheit, die dir dein Herr offenbart hat. Und setze neben Allah keinen anderen Gott, auf daß du nicht in Gahannam geworfen werdest, verdammt und verstoßen.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmlxix{Hat euer Herr euch denn mit Söhnen bevorzugt und für Sich Selbst Töchter von den Engeln genommen? Wahrlich, ihr sprecht da ein großes Wort.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmlxx{Und wahrlich, Wir haben in diesem Quran (manches) auf verschiedene Art dargelegt, damit sie ermahnt seien, doch es mehrt nur ihren Widerwillen.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmlxxi{Sprich: ``Gäbe es neben Ihm noch andere Götter, wie sie behaupten, dann hätten sie gewiß versucht, einen Weg zum Herrn des Throns einzuschlagen."\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmlxxii{Gepriesen sei Er und in großer Weise Erhaben über all das, was sie behaupten.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmlxxiii{Die sieben Himmel und die Erde und alle darin lobpreisen Ihn; und es gibt nichts, was Seine Herrlichkeit nicht preist; ihr aber versteht deren Lobpreisung nicht. Wahrlich, Er ist Nachsichtig, Allverzeihend.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmlxxiv{Und wenn du den Quran verliest, legen Wir zwischen dir und jenen, die nicht an das Jenseits glauben, eine unsichtbare Scheidewand.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmlxxv{Und Wir legen Hüllen auf ihre Herzen, so daß sie ihn nicht verstehen, und in ihre Ohren Taubheit. Und wenn du im Quran deinen Herrn nennst, Ihn allein, so wenden sie ihren Rücken in Widerwillen ab.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmlxxvi{Wir wissen am besten, worauf sie horchen, wenn sie dir zuhören, und wenn sie sich insgeheim bereden, während die Frevler sagen: ``lhr folgt nur einem Manne, der einem Zauber zum Opfer gefallen ist."\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmlxxvii{Schau, wie sie von dir Gleichnisse prägen und damit so sehr in die Irre gegangen sind, daß sie nicht in der Lage sind, den Weg zu finden.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmlxxviii{Und sie sagen: ``Wenn wir zu Gebeinen und Staub geworden sind, sollen wir dann wirklich zu einer neuen Schöpfung auferweckt werden?"\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmlxxix{Sprich: ``Ob ihr Steine oder Eisen\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmlxxx{oder sonst eine Schöpfung von der Art seid, die nach eurem Sinn am schwersten wiegt." Dann werden sie sagen: ``Wer soll uns ins Leben zurückrufen?" Sprich: ``Er, Der euch das erste Mal erschuf." Dann werden sie ihre Köpfe vor dir schütteln und sagen: ``Wann geschieht es?" Sprich: ``Vielleicht geschieht es gar bald.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmlxxxi{An dem Tage, an dem Er euch ruft, da werdet ihr Ihm lobpreisend entgegenkommen und meinen, ihr hättet nur kurz verweilt."\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmlxxxii{Und sprich zu Meinen Dienern, sie möchten nur das Beste reden; denn Satan stiftet zwischen ihnen Zwietracht. Wahrlich, Satan ist dem Menschen ein offenkundiger Feind.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmlxxxiii{Euer Herr kennt euch am besten. Wenn Er will, so wird Er Sich eurer erbarmen, oder wenn Er will, so wird Er euch bestrafen. Und Wir haben dich nicht als ihren Wächter entsandt.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmlxxxiv{Und dein Herr kennt jene am besten, die in den Himmeln und auf der Erde sind. Und wahrlich, Wir erhöhten einige der Propheten über die anderen, und David gaben Wir ein Buch.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmlxxxv{Sprich: ``Ruft doch die an, die ihr neben Ihm wähnt; sie haben keine Macht, weder das Unheil von euch zu nehmen noch es abzuwenden."\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmlxxxvi{Jene, die sie anrufen, suchen selbst die Nähe ihres Herrn (und wetteifern untereinander,) wer von ihnen (Ihm) am nächsten sei - und hoffen auf Sein Erbarmen und fürchten Seine Strafe. Wahrlich, die Strafe deines Herrn ist zu fürchten.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmlxxxvii{Es gibt keine Stadt, die Wir nicht vor dem Tage der Auferstehung vernichten oder der (Wir) keine strenge Strafe auferlegen werden. Das ist in dem Buche niedergeschrieben.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmlxxxviii{Und nichts könnte Uns hindern, Zeichen zu senden, obwohl die Früheren sie verworfen hatten. Und Wir gaben den Tamud die Kamelstute als ein sichtbares Zeichen, doch sie frevelten an ihr. Und Wir senden Zeichen, nur um abzuschrecken.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmlxxxix{Und Wir sprachen da zu dir: ``Dein Herr umfaßt die Menschen." Und Wir haben das Traumgesicht, das Wir dich sehen ließen, nur als eine Prüfung für die Menschen gemacht und ebenso den verfluchten Baum im Quran. Und Wir warnen sie, jedoch es bestärkt sie nur noch in ihrer großen Ruchlosigkeit.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmxc{Und als Wir zu den Engeln sprachen: ``Werft euch vor Adam nieder!" da warfen sie sich nieder, außer Iblis. Er sagte: ``Soll ich mich vor einem niederwerfen, den Du aus Ton erschaffen hast?"\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmxci{Er sagte (weiter): ``Was denkst Du? Dieser ist es, den Du höher geehrt hast als mich! Willst Du mir eine Frist bis zum Tage der Auferstehung geben, so will ich gewiß Gewalt über seine Nachkommen - bis auf einige wenige - erlangen."\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmxcii{Er sprach: ``Fort mit dir! Und wer von ihnen dir folgt wahrlich, Gahannam soll deren aller Lohn sein, ein ausgiebiger Lohn.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmxciii{Und betöre nun mit deiner Stimme von ihnen, wen du vermagst, und treibe dein Roß und dein Fußvolk gegen sie und habe an ihren Vermögen und Kindern teil und mache ihnen Versprechungen." - Und Satan verspricht ihnen nur Trug. -\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmxciv{``Über Meine Diener aber wirst du gewiß keine Macht haben." Und dein Herr genügt als Beschützer.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmxcv{Euer Herr ist es, Der die Schiffe auf dem Meer für euch treibt, auf daß ihr nach Seiner Gnade trachten möget. Wahrlich, Er ist gegen euch Barmherzig.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmxcvi{Und wenn euch auf dem Meer ein Unheil trifft: verloren sind jene die ihr an Seiner Statt anruft. Hat Er euch aber ans Land gerettet, dann kehrt ihr euch (von Ihm) ab; denn der Mensch ist undankbar.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmxcvii{Fühlt ihr euch denn sicher davor, daß Er euch nicht auf dem Festland versinken läßt, oder daß Er einen heftigen Sandsturm gegen euch schickt, (so daß) ihr dann keinen Beschützer für euch findet?\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmxcviii{Oder fühlt ihr euch sicher davor, daß Er euch nicht noch ein zweites Mal dorthin zurückschickt und einen Sturmwind gegen euch entsendet und euch für euren Unglauben ertrinken läßt? Dafür werdet ihr dann Uns gegenüber keinen Rächer für euch finden.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmxcix{Und wahrlich, Wir haben die Kinder Adams geehrt und sie über Land und Meer getragen und sie mit guten Dingen versorgt und sie ausgezeichnet eine Auszeichnung vor jenen vielen, die Wir erschaffen haben.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmc{An jenem Tage, da werden Wir ein jedes Volk mit seinem Führer vorladen. Diejenigen, die dann ihr Buch in ihrer Rechten empfangen werden, werden ihr Buch verlesen und nicht das geringste Unrecht erleiden.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmci{Wer aber blind ist in dieser (Welt), der wird auch im Jenseits blind sein und noch weiter vom Weg abirren.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmcii{Und sie hätten dich beinahe in schwere Bedrängnis um dessentwillen gebracht, was Wir dir offenbarten, damit du etwas anderes über Uns erdichten mögest; und dann hätten sie dich gewiß zu ihrem Freund erklärt.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmciii{Hätten Wir dich aber nicht gefestigt, hättest du dich ihnen nur wenig zugeneigt.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmciv{Dann hätten Wir dich das Doppelte im Leben kosten lassen und das Doppelte im Tode; und du hättest keinen Helfer Uns gegenüber gefunden.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmcv{Und in der Tat hätten sie dich fast aus dem Lande verscheucht, indem sie dich daraus vertreiben wollten; dann aber wären sie nach dir nur eine kurze Zeitspanne (dort) geblieben.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmcvi{In dieser Weise verfuhren (Wir) mit Unseren Gesandten, die Wir vor dir schickten; und du wirst keine Änderung in Unserem Verfahren finden.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmcvii{Verrichte dein Gebet vom Neigen der Sonne an bis zum Dunkel der Nacht, und (lies) den Quran bei Tagesanbruch. Wahrlich (besonders bei der Lesung) des Quran bei Tagesanbruch (sind die Engel) zugegen.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmcviii{Und unterbrich deswegen (für die Lesung) in der Nacht deinen Schlaf (vollbringe) diese (Leistung) freiwillig. Es mag sein, daß dich dein Herr (dafür) zu einem löblichen Rang erweckt.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmcix{Und sprich: ``O mein Herr, laß meinen Eingang einen guten Eingang sein und laß meinen Ausgang einen guten Ausgang sein. Und gewähre mir Deine hilfreiche Kraft."\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmcx{Und sprich: ``Gekommen ist die Wahrheit und dahingeschwunden ist die Falschheit; wahrlich, das Falsche verschwindet bestimmt."\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmcxi{Und Wir senden vom Quran das hinab, was eine Heilung und Barmherzigkeit für die Gläubigen ist; den Ungerechten aber mehrt es nur den Schaden.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmcxii{Und wenn Wir dem Menschen Gnade erweisen, wendet er sich ab und geht beiseite; wenn ihn aber ein Übel trifft, gibt er sich der Verzweiflung hin.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmcxiii{Sprich: ``Ein jeder handelt gemäß seiner eigenen Art, und euer Herr weiß am besten, wer den rechten Weg geht."\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmcxiv{Und sie befragen dich über die Seele. Sprich: ``Die Seele ist eine Angelegenheit meines Herrn; und euch ist vom Wissen nur wenig gegeben."\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmcxv{Und wenn Wir es wollten, könnten Wir gewiß das wieder fortnehmen, was Wir dir offenbart haben; du fändest dann für dich in dieser Sache keinen Beschützer Uns gegenüber\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmcxvi{außer der Barmherzigkeit deines Herrn. Wahrlich, Seine Gnade gegen dich ist groß.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmcxvii{Sprich: ``Wenn sich auch die Menschen und die Ginn vereinigten, um diesem Quran etwas Gleiches hervorzubringen, brächten sie doch nichts Gleiches hervor, selbst wenn sie einander beistünden."\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmcxviii{Und wahrlich, Wir haben für die Menschen in diesem Quran allerlei abgewandelte Beispiele angeführt; aber die meisten Menschen wollen nichts anderes als ungläubig zu sein.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmcxix{Und sie sagen: ``Wir werden dir nimmermehr glauben, bis du uns einen Quell aus der Erde hervorsprudeln läßt\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmcxx{oder (bis) du einen Garten mit Dattelpalmen und Trauben hast und mittendrin Bäche in reichlicher Weise hervorsprudeln läßt\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmcxxi{oder (bis) du den Himmel über uns in Stücken einstürzen läßt, wie du es behauptest, oder (bis du) Allah und die Engel vor unser Angesicht bringst\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmcxxii{oder (bis) du ein prunkvolles Haus besitzt oder zum Himmel aufsteigst; und wir werden nicht eher an deinen Aufstieg glauben, bis du uns ein Buch hinabsendest, das wir lesen können." Sprich: ``Preis sei meinem Herrn! Bin ich denn etwas anderes als ein Mensch, ein Gesandter?"\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmcxxiii{Und nichts hat die Menschen abgehalten zu glauben, als die Führung zu ihnen kam; doch sie sagten nur: ``Hat Allah einen Menschen als Gesandten geschickt?"\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mmcxxiv{Sprich: ``Wären auf Erden friedlich und in Ruhe wandelnde Engel gewesen, hätten Wir ihnen gewiß einen Engel vom Himmel als Gesandten geschickt."\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mmcxxv{Sprich: ``Allah genügt als Zeuge gegen mich und euch; wahrlich, Er weiß und sieht alles von Seinen Dienern."\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mmcxxvi{Und der, den Allah leitet, ist der Rechtgeleitete; die aber, die Er zu Irrenden erklärt - für die wirst du keine Helfer finden, außer Ihm. Und Wir werden sie am Tage der Auferstehung versammeln, (und sie werden) auf ihren Angesichtern (liegen), blind, stumm und taub. Ihre Herberge wird Gahannam sein; sooft (ihr Feuer) nachläßt, um so stärker fachen Wir die Flamme an.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mmcxxvii{Das ist ihr Lohn, weil sie Unsere Zeichen verwarfen und sagten: ``Wie? Wenn wir zu Gebein und Staub geworden sind, sollen wir wirklich zu einer neuen Schöpfung auferweckt werden?"\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mmcxxviii{Haben sie nicht gesehen, daß Allah, Der die Himmel und die Erde erschuf, imstande ist, ihresgleichen zu schaffen? Und Er hat eine Frist für sie bestimmt, über die kein Zweifel herrscht. Allein die Frevler verwerfen alles, nur nicht den Unglauben.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mmcxxix{Sprich: ``Besäßet ihr die Schätze der Barmherzigkeit meines Herrn, wahrlich, ihr würdet (sie) aus Furcht vor dem Ausgeben (für) euch zurückbehalten; denn der Mensch ist geizig."\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mmcxxx{Und wahrlich, Wir hatten Moses neun offenbare Zeichen gegeben. Frage nur die Kinder Israels. Als er zu ihnen kam, sprach Pharao zu ihm: ``lch halte dich, o Moses, zweifellos für ein Opfer des Zaubers."\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mmcxxxi{Er sprach: ``Du weißt recht wohl, daß kein anderer als der Herr der Himmel und der Erde diese (Zeichen) als Zeugnisse herabgesandt hat; und ich halte dich, o Pharao, zweifellos für ein Opfer des Unheils."\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mmcxxxii{Da beschloß er, sie aus dem Lande zu vertreiben; doch Wir ertränkten ihn und diejenigen, die mit ihm waren, allesamt.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mmcxxxiii{Und Wir sprachen nach ihm zu den Kindern Israels: ``Wohnt in dem Lande; und wenn die Zeit der zweiten Verheißung kommt, dann werden Wir euch als eine gesammelte Schar herbeibringen."\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mmcxxxiv{Und mit der Wahrheit haben Wir (den Quran) hinabgesandt, und mit der Wahrheit kam er hernieder. Und dich entsandten Wir nur als Bringer froher Botschaft und Warner.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mmcxxxv{Und Wir haben den Quran in Abschnitten offenbart, damit du ihn den Menschen in Ruhe verlesen mögest, und Wir sandten ihn nach und nach hinab.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mmcxxxvi{Sprich: ``Ob ihr an ihn glaubt oder nicht glaubt, wahrlich, jene, denen zuvor das Wissen gegeben wurde, fallen, wenn er ihnen verlesen wird, anbetend auf ihr Angesicht nieder\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mmcxxxvii{und sagen: ``Preis sei unserem Herrn! Siehe, die Verheißung unseres Herrn wird sich wahrlich erfüllen."\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mmcxxxviii{Und weinend fallen sie anbetend auf ihr Angesicht nieder, und ihre Demut nimmt zu.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mmcxxxix{Sprich: ``Ruft Allah an oder ruft den Barmherzigen an - bei welchem (Namen) ihr (Ihn) immer anruft, Ihm stehen die Schönsten Namen zu." Und sprich dein Gebet nicht zu laut, und flüstere es auch nicht zu leise, sondern suche einen Mittelweg.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mmcxl{Und sprich: `` Alles Lob gebührt Allah, Der Sich keinen Sohn genommen hat und niemanden in der Herrschaft neben Sich noch sonst einen Gehilfen aus Ohnmacht hat." Und rühme Seine Größe in gebührender Weise.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mmcxli{\basmalahde Alles Lob gebührt Allah, Der zu Seinem Diener das Buch herabsandte und nichts Krummes darein legte.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmcxlii{(Es ist) frei von Widersprüchen, damit es Seine strenge Strafe androhe und den Gläubigen, die gute Werke tun, die frohe Botschaft bringe, auf daß ihnen ein schöner Lohn zuteil werde\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmcxliii{worin (im Paradies) sie auf ewig weilen werden\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmcxliv{(und) damit es jene warne, die da sa gen: ``Allah hat Sich einen Sohn genommen."\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmcxlv{Sie haben keinerlei Kenntnis davon, noch hatten sie ihre Väter. Ungeheuerlich ist das Wort, das aus ihrem Munde kommt. Sie sprechen nichts als Lüge.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmcxlvi{So wirst du dich vielleicht noch aus Kummer über sie zu Tode grämen, wenn sie dieser Rede keinen Glauben schenken.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmcxlvii{Wahrlich, Wir machten alles, was auf der Erde ist, zu einem Schmuck für sie, auf daß Wir sie prüften, wer unter ihnen der Beste im Wirken sei.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmcxlviii{Und gewiß, Wir werden alles, was auf ihr ist, in dürren Wüstenstaub verwandeln.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmcxlix{Meinst du wohl, die Gefährten in der Höhle und Ar-Raqim seien ein Wunder unter Unseren Zeichen?\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmcl{Da nahmen die jungen Männer in der Höhle Zuflucht und sagten: ``Unser Herr, gewähre uns Deine Barmherzigkeit und bereite uns einen Weg für unsere Sache."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmcli{Sodann versiegelten Wir in der Höhle ihre Ohren für eine Anzahl von Jahren.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmclii{Dann erweckten Wir sie, damit Wir erführen, welche von den beiden Scharen die Zeit ihres Verweilens am besten berechnet habe.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmcliii{Wir wollen dir ihre Geschichte wahrheitsgemäß berichten: Sie waren junge Männer, die an ihren Herrn glaubten, und Wir ließen ihnen zunehmend Rechtleitung zukommen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmcliv{Und Wir stärkten ihre Herzen, als sie aufstanden und sagten: ``Unser Herr ist der Herr der Himmel und der Erde. Nie werden wir einen (anderen) Gott außer Ihm anrufen; sonst würden wir ja etwas Unsinniges aussprechen.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmclv{Dieses unser Volk hat Götter statt Seiner angenommen. Warum bringen sie dann keinen klaren Beweis dafür? Und wer verübt einen größeren Frevel, als der, der eine Lüge gegen Allah erdichtet?\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmclvi{Und wenn ihr euch von ihnen und von dem, was sie statt Allah anbeten, zurückzieht, so sucht Zuflucht in der Höhle; euer Herr wird Seine Barmherzigkeit über euch breiten und euch einen tröstlichen Ausweg aus eurer Lage weisen."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmclvii{Und hättest du sehen können, wie die Sonne, als sie aufging, sich von ihrer Höhle nach rechts wegneigte, und als sie unterging, sich von ihnen nach links abwandte; und (wie) sie in einem Hohlraum mitten dazwischen waren. Das gehört zu den Zeichen Allahs. Wen Allah leitet, der ist rechtgeleitet; doch wen Er irregehen läßt, für den wirst du keinen Helfer finden, der ihn führt.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmclviii{Du könntest sie für wach halten, aber sie schlafen; und Wir ließen sie sich auf die rechte Seite und auf die linke Seite drehen, während ihr Hund seine Vor derpfoten auf der Schwelle ausstreckte. Hättest du sie so erblickt, hättest du gewiß vor ihnen die Flucht ergriffen, und es hätte dir vor ihnen gegraut.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmclix{Und so erweckten Wir sie, damit sie einander befragen konnten. Ein Sprecher von ihnen sprach: ``Wie lange habt ihr verweilt?" Sie sagten: ``Wir verweilten einen Tag oder den Teil eines Tages." (Andere) sagten: ``Euer Herr kennt die (Zeit), die ihr verbracht habt, am besten. Nun entsendet einen von euch mit dieser eurer Silbermünze zur Stadt; und er soll sehen, wer von ihren (Bewohnern) die reinste Speise hat, und soll euch davon einen Vorrat bringen. Er muß aber freundlich sein und soll ja nichts über euch verlauten lassen\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmclx{denn wenn sie (etwas) von euch erfahren würden, würden sie euch steinigen oder euch zu ihrem Glauben zurückbringen, und ihr würdet dann nimmermehr erfolgreich sein."\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmclxi{Und so ließen Wir sie (die Leute) sie finden, damit sie erkennen mögen, daß Allahs Verheißung wahr ist und daß über die Stunde kein Zweifel herrscht. Und da stritten sie (die Leute) untereinander über sie und sagten: ``Errichtet über ihnen einen Bau." Ihr Herr kennt sie am besten. Jene, deren Ansicht siegte, sagten: ``Wir wollen unbedingt eine Moschee über ihnen errichten."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmclxii{(Manche) werden sagen: ``(Sie waren) drei; ihr vierter war ihr Hund", und (andere) werden sagen: ``(Sie waren) zu fünft, ihr sechster war ihr Hund", indem sie in Unkenntnis herumraten, und (andere) sagen: ``(Es waren) sieben; ihr achter war ihr Hund." Sprich: ``Mein Herr kennt ihre Zahl am besten. Niemand weiß sie, bis auf einige wenige." So streite nicht über sie, es sei denn, (du hättest) einen klaren Beweis, und suche keine Kunde über sie bei irgendeinem von ihnen (zu erlangen)\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmclxiii{Und sprich nie von einer Sache: ``lch werde es morgen tun"\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmclxiv{es sei denn (du fügst hinzu): ``So Allah will". Und gedenke deines Herrn, wenn du dies vergessen hast, und sprich: ``lch hoffe, mein Herr wird mich noch näher als diesmal zum rechten Wege führen."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmclxv{Und sie blieben dreihundert Jahre lang in ihrer Höhle, und neun wurden hinzugefügt.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmclxvi{Sprich: ``Allah weiß am besten wie lange sie verweilten." Ihm gehören das Verborgene der Himmel und der Erde. Wie sehend ist Er! Und wie hörend! Sie haben keinen Helfer außer Ihm, und Er teilt Seine Befehlsgewalt mit keinem.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmclxvii{Und verlies, was dir von dem Buche deines Herrn offenbart wurde. Da ist keiner, der Seine Worte verändern könnte, und du wirst außer bei Ihm keine Zuflucht finden.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmclxviii{Und geduldige dich zusammen mit denjenigen, die ihren Herrn morgens und abends anrufen im Trachten nach Seinem Wohlgefallen; und laß deine Blicke nicht über sie hinauswandern, indem du nach dem Schmuck des irdischen Lebens trachtest; und gehorche nicht dem, dessen Herz Wir achtlos für die Erinnerung an Uns machten, (und gehorche nicht dem,) der seinen Gelüsten folgt und kein Maß und Ziel kennt.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmclxix{Und sprich: ``Es ist die Wahrheit von eurem Herrn: darum laß den gläubig sein, der will, und den ungläubig sein, der will. Siehe, Wir haben für die Frevler ein Feuer bereitet, dessen Zeltdecke sie umschließen wird. Und wenn sie um Hilfe schreien, so wird ihnen mit Wasser gleich geschmolzenem Metall, das die Gesichter verbrennt, geholfen werden. Wie schrecklich ist der Trank, und wie schlimm ist die Raststätte!\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmclxx{Wahrlich, die da glauben und gute Werke tun wahrlich, Wir lassen den Lohn derjenigen, die gute Werke tun, nicht verloren gehen.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmclxxi{Sie sind es, denen die Gärten von Eden, durch welche Bäche fließen, zuteil werden. Darin werden sie mit Armspangen aus Gold geschmückt und in grüne Gewänder aus feiner Seide und Brokat gekleidet sein, und darin lehnen (sie) auf erhöhten Sitzen. Wie herrlich ist der Lohn und wie schön ist die Raststätte!\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmclxxii{Und stelle ihnen das Gleichnis von zwei Männern vor: für den einen von ihnen schufen Wir zwei Rebgärten und umgaben sie mit Dattelpalmen, und dazwischen legten Wir Kornfelder an.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmclxxiii{Beide brachten ihre Früchte hervor und versagten in nichts. Und in ihrer Mitte ließen Wir einen Bach hervorsprudeln.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmclxxiv{Und (der Garten) trug für ihn Früchte. Er sprach in herausforderndem Ton zu seinem Gefährten: ``lch bin reicher als du an Besitz und mächtiger an Gefolgschaft."\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmclxxv{Und er betrat seinen Garten, während er sündig gegen sich selbst war. Er sagte: ``lch kann mir nicht vorstellen, daß dieser je zugrunde gehen wird\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmclxxvi{noch glaube ich, daß die Stunde heraufkommen wird. Selbst wenn ich zu meinem Herrn zurückgebracht werde, so werde ich ganz gewiß einen besseren Aufenthalt als diesen finden."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmclxxvii{Sein Gefährte sagte zu ihm, indem er sich mit ihm auseinandersetzte: ``Glaubst du denn nicht an Ihn, Der dich aus Erde erschaffen hat, dann aus einem Samentropfen, (und) dich dann zu einem vollkommenen Mann bildete?\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmclxxviii{Was jedoch mich betrifft Allah ist mein Herr, und nie will ich meinem Herrn etwas anders zur Seite stellen.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmclxxix{Warum hast du nicht damals, als du deinen Garten betratest, gesagt: ``Wie Allah es will (, so geschehe es); es gibt keine Macht, außer bei Allah"; wenn du mich auch geringer als dich selbst an Besitz und Nachkommenschaft siehst?\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmclxxx{So wird mein Herr mir vielleicht (etwas) Besseres als deinen Garten geben und wird auf ihn ein Strafgericht vom Himmel niedersenden, so daß er zu ödem Boden wird.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmclxxxi{Oder sein Wasser versiegt so tief im Boden, daß du nimmer imstande sein wirst, es herauszuholen."\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmclxxxii{Da wurde seine Frucht verwüstet, und er begann die Hände zu ringen wegen alldem, was er für den (Garten), dessen Bau zerfallen dalag, ausgegeben hatte. Er sprach: ``Hätte ich doch meinem Herrn niemanden zur Seite gestellt!"\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmclxxxiii{Und er hatte keine Schar, die ihm gegen Allah zu helfen vermöchte, und er konnte sich selbst nicht wehren.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmclxxxiv{Insofern gibt es Schutz nur bei Allah, dem Wahren. Er ist der Beste im Belohnen und der Beste, was den Ausgang (der Dinge) anbelangt.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmclxxxv{Und präge ihnen das Gleichnis vom irdischen Leben: Es ist wie das Wasser, das Wir vom Himmel herniedersenden, mit dem die Pflanzen der Erde sich sättigen, und welche dann dürre Spreu werden, die der Wind verweht. Und Allah hat Macht über alle Dinge.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmclxxxvi{Besitztum und Kinder sind Schmuck des irdischen Lebens. Die bleibenden guten Werke aber sind lohnender bei deinem Herrn und hoffnungsvoller.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmclxxxvii{Und am Tage, da Wir die Berge vergehen lassen werden, wirst du die Erde kahl sehen, und Wir werden sie (die Völker der Erde) versammeln und werden keinen von ihnen zurücklassen.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmclxxxviii{Und sie werden in Reihen vor deinen Herrn geführt: ``Nun seid ihr zu Uns gekommen, so wie Wir euch erstmals erschufen. Ihr aber dachtet, Wir würden euch nie einen Termin der Erfüllung setzen."\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmclxxxix{Und das Buch wird (ihnen) vorgelegt, und du wirst die Schuldigen in Ängsten wegen dem sehen, was darin ist; und sie werden sagen: ``O wehe uns! Was für ein Buch ist das! Es läßt nichts aus, ob klein oder groß, sondern hält alles aufgezeichnet." Und sie werden all das, was sie getan haben, gegenwärtig finden; und dein Herr tut keinem Unrecht.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmcxc{Und da sprachen Wir zu den Engeln: ``Werft euch vor Adam nieder" und sie warfen sich nieder, außer Iblis. Er war einer der Ginn, so war er ungehorsam gegen den Befehl seines Herrn. Wollt ihr nun ihn und seine Nachkommenschaft statt Meiner zu Beschützern nehmen, wo sie doch eure Feinde sind? Schlimm ist dieser Tausch für die Frevler.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmcxci{Ich nahm sie nicht zu Zeugen, weder bei der Schöpfung der Himmel und der Erde noch bei ihrer eigenen ja, Ich nehme die Verführer nie zum Beistand.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmcxcii{Und am Tage, da wird Er sprechen: ``Ruft die herbei, von denen ihr vorgabt, sie seien Meine Teilhaber." Dann werden sie sie rufen, doch sie werden ihnen nicht antworten; und Wir werden einen Abgrund zwischen ihnen auftun.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmcxciii{Und die Schuldigen werden das Feuer sehen und ahnen, daß sie hineinstürzen werden; und sie werden kein Entrinnen daraus finden.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmcxciv{Wahrlich, Wir haben in diesem Quran den Menschen allerlei Gleichnisse erläutert, doch von allen Geschöpfen ist der Mensch am streitsüchtigsten.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmcxcv{Und nichts hinderte die Menschen daran zu glauben, als die Rechtleitung zu ihnen kam, und ihren Herrn um Verzeihung zu bitten, (es sei) denn, (sie warteten) bis das Beispiel(hafte Schicksal) der Früheren über sie käme oder (ihnen) die Strafe offen vor Augen gehalten würde.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmcxcvi{Und Wir schickten die Gesandten ja nur als Bringer froher Botschaft und als Warner. Die aber, die ungläubig sind, streiten in Falschheit, um dadurch die Wahrheit zu widerlegen. Und sie verspotten Meine Zeichen und das, womit sie gewarnt werden.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmcxcvii{Und wer ist ungerechter als der, der an die Zeichen seines Herrn gemahnt wurde, sich aber von ihnen abwandte und vergaß, was seine Hände vorausgeschickt hatten? Wahrlich, Wir haben Schleier über ihre Herzen gelegt, so daß sie es nicht begreifen, und Taubheit in ihre Ohren. Und selbst wenn du sie zum rechten Weg rufst, werden sie nie den rechten Weg einschlagen.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmcxcviii{Und dein Herr ist der Vergebungsreiche, voll der Barmherzigkeit. Wollte Er sie zur Rechenschaft ziehen für das, was sie begehen, dann würde Er gewiß ihre Bestrafung beschleunigen. Allein sie haben eine festgesetzte Frist, vor der sie keine Zuflucht finden werden.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmcxcix{Und diese Städte! Wir zerstörten sie, als sie Frevel begingen. Und Wir setzten eine Frist für ihre Zerstörung.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmcc{Und Moses sagte zu sei nem jungen Diener: ``lch will nicht eher rasten, als bis ich den Zusammenfluß der beiden Meere erreicht habe, und sollte ich jahrhundertelang wandern."\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmcci{Doch als sie den Zusammenfluß der beiden (Meere) erreicht hatten, da vergaßen sie ihren Fisch; und dieser nahm seinen Weg und schwamm ins Meer hinaus.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmccii{Und als sie weitergegangen waren, sagte er zu seinem jungen Diener: ``Bring uns unsere Speise. Wir haben wahrlich auf dieser unserer Reise große Anstrengungen auf uns genommen."\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmcciii{Er sagte: ``Hast du nicht gesehen, daß sich der Fisch da auf wundersame Weise ins Meer begab, als wir auf dem Felsen rasteten und ich ihn vergaß und kein (anderer) als Satan ließ mich vergessen, ihn zu erwähnen?"\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmcciv{Er sagte: ``Das ist es was wir wollten." Da kehrten sie beide um und schritten auf ihren Spuren zurück.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmccv{Dann fanden sie einen Unserer Diener, dem Wir Unsere Barmherzigkeit verliehen und den Wir Unser Wissen gelehrt hatten.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmccvi{Moses sagte zu ihm: ``Darf ich dir folgen, auf daß du mich über das rechte Handeln belehrest, wie du gelehrt worden bist?"\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmccvii{Er sagte: ``Du vermagst nimmer bei mir in Geduld auszuharren.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmccviii{Und wie könntest du bei Dingen geduldig sein, von denen dir keine Kunde gegeben worden ist?"\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmccix{Er sagte: ``Du wirst mich, so Allah will, geduldig finden, und ich werde gegen keinen deiner Befehle ungehorsam sein."\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmccx{Er sagte: ``Nun gut. Wenn du mir folgen willst, so frage mich nach nichts, bis ich es dir von selbst erkläre."\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmccxi{So machten sich beide auf den Weg, bis sie in ein Schiff stiegen, in das er ein Loch schlug. Er (Moses) sagte: ``Schlugst du ein Loch hinein, um seine Mannschaft zu ertränken? Wahrlich, du hast etwas Schreckliches be gangen!"\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmccxii{Er sagte: ``Habe ich nicht gesagt, du würdest es nimmer fertigbringen, bei mir in Geduld auszuharren?"\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmccxiii{Er (Moses) sagte: ``Stelle mich nicht meines Vergessens wegen zur Rede, und sei deswegen nicht streng mit mir."\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmccxiv{So zogen sie weiter, bis sie einen Jüngling trafen, den er erschlug. Er (Moses) sagte: ``Hast du einen unschuldigen Menschen erschlagen, ohne daß (er) einen anderen (erschlagen hätte)? Wahrlich, du hast etwas Verabscheuliches getan!"\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmccxv{Er sagte: ``Habe ich dir nicht gesagt, du würdest es nimmer fertigbringen, bei mir in Geduld auszuharren?"\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmccxvi{Er (Moses) sagte: ``Wenn ich dich nochmal nach etwas frage, so begleite mich nicht weiter; von mir aus wärst du dann entschuldigt."\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmccxvii{So zogen sie weiter, bis sie bei den Bewohnern einer Stadt ankamen und von ihnen Gastfreundschaft erbaten; diese aber weigerten sich, sie zu bewirten. Nun fanden sie dort eine Mauer, die einzustürzen drohte, und er richtete sie auf. Er (Moses) sagte: ``Wenn du es gewollt hättest, hättest du einen Arbeitslohn dafür erhalten können."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmccxviii{Er sagte: ``Dies führt zur Trennung zwischen mir und dir. Doch will ich dir die Bedeutung von dem sagen, was du nicht in Geduld zu ertragen vermöchtest.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmccxix{Was das Schiff anbelangt, so gehörte es armen Leuten, die auf dem Meer arbeiteten, und ich wollte es beschädigen; denn hinter ihnen war ein König, der jedes Schiff beschlagnahmte.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmccxx{Und was den Jüngling anbelangt, so waren seine Eltern Gläubige, und wir fürchteten, er könnte Schmach durch Widersetzlichkeit und Unglauben über sie bringen.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmccxxi{So wollten wir, daß ihr Herr ihnen zum Tausch (ein Kind) gebe, das redlicher als dieses und anhänglicher wäre.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmccxxii{Und was nun die Mauer anbelangt, so gehörte sie zwei Waisenknaben in der Stadt, und darunter lag ein Schatz für sie (verborgen), und ihr Vater war ein rechtschaffener Mann gewesen; so wünschte dein Herr, daß sie ihre Volljährigkeit erreichen und ihren Schatz heben mögen als eine Barmherzigkeit deines Herrn; und ich tat es nicht aus eigenem Ermessen. Das ist die Bedeutung dessen, was du nicht in Geduld zu ertragen vermöchtest."\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmccxxiii{Und sie fragen dich nach Du-l-Qarnain. Sprich: ``lch will euch etwas darüber berichten."\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmccxxiv{Wir haben ihm Macht auf Erden und die Mittel zu allem gegeben.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmccxxv{So folgte er dem gegebenen Weg\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmccxxvi{bis er den Ort, an dem die Sonne untergeht, erreichte; er fand sie in einem Quell von schlammigem Wasser untergehen, und dort fand er ein Volk. Wir sprachen: ``O Du- l-Qarnain, entweder strafe sie oder behandle sie mit Güte."\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmccxxvii{Er sagte: ``Den, der da frevelt, werden wir sicherlich bestrafen; dann soll er zu seinem Herrn zurückgebracht werden, und Er wird ihn in gräßlicher Weise bestrafen.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmccxxviii{Dem aber, der gläubig ist und Gutes tut, wird herrlicher Lohn zuteil werden; und wir werden zu ihm in angenehmer Weise über unsere Angelegenheiten sprechen."\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmccxxix{Darauf folgte er dem gegebenen Weg\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmccxxx{bis er den Ort, an dem die Sonne aufgeht, erreichte; er fand sie über einem Volk aufgehen, dem Wir keinen Schutz gegen sie gegeben, hatten.\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmccxxxi{Und so war es; und Wir umfaßten mit Wissen, wie es um ihn bestellt war.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmccxxxii{Hierauf folgte er dem gegebenen Weg\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmccxxxiii{bis er zwischen die beiden Wälle gelangte; er fand hinter diesen ein Volk, das kaum eine Sprache verstehen konnte.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmccxxxiv{Sie sagten: ``O Du-I- Qarnain, Gog und Magog stiften Unheil im Lande; sollen wir dir nun Tribut zahlen unter der Bedingung, daß du zwischen uns und ihnen einen Wall errichtest?"\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mmccxxxv{Er sagte: ``Die Macht, die mein Herr mir gegeben hat, ist besser. So helft mir denn mit all eurer Kraft, damit ich zwischen euch und ihnen einen Damm errichten kann.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mmccxxxvi{Bringt mir Eisenstücke." Als er die Kluft zwischen den beiden Bollwerken ausgefüllt hatte, sagte er: ``Blast!" Als er es (das Eisen) feurig gemacht hatte, sagte er: ``Bringt mir geschmolzenes Kupfer, ich will es darüber gießen!"\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mmccxxxvii{So vermöchten sie es nicht sie (die Dämme) zu erklimmen, noch konnten sie sie durchbrechen.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mmccxxxviii{Er sagte: ``Das ist die Gnade meines Herrn; doch wenn die Verheißung meines Herrn in Erfüllung geht, wird Er sie zu Schutt zerfallen lassen; und die Verheißung meines Herrn ist wahr."\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mmccxxxix{An jenem Tage werden Wir die einen von ihnen wie Wogen gegen die anderen anstürmen lassen, und es wird in den Sur gestoßen. Dann werden Wir sie allzumal (vor Uns) versammeln.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mmccxl{Und den Ungläubigen stellen Wir an jenem Tage Gahannam in deutlicher Weise vor Augen\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mmccxli{ihnen, deren Augen vor Meiner Mahnung verhüllt waren und die nicht einmal hören konnten.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mmccxlii{Meinen die Ungläubigen etwa, sie könnten meine Diener an Meiner Statt zu Beschützern nehmen? Wahrlich, Wir haben den Ungläubigen Gahannam als Hort bereitet.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mmccxliii{Sprich: ``Sollen Wir euch die nennen, die bezüglich ihrer Werke die größten Verlierer sind?\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mmccxliv{Das sind die, deren Eifer im irdischen Leben in die Irre ging, während sie meinen, sie täten gar etwas Gutes."\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mmccxlv{Das sind jene, die die Zeichen ihres Herrn und die Begegnung mit Ihm leugnen. Darum sind ihre Werke nichtig, und am Tage der Auferstehung werden Wir ihnen kein Gewicht beimessen.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mmccxlvi{Dies ist ihr Lohn Gahannam, weil sie ungläubig waren und mit Meinen Zeichen und mit Meinen Gesandten Spott trieben.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mmccxlvii{Wahrlich, jene, die da glauben und gute Werke tun ihnen wird das Paradies von Al-Firdaus ein Hort sein\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mmccxlviii{in dem sie auf ewig verweilen werden; von dort werden sie nicht weggehen wollen.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mmccxlix{Sprich: ``Wäre das Meer Tinte für die Worte meines Herrn, wahrlich, das Meer würde versiegen, ehe die Worte meines Herrn zu Ende gingen, auch wenn wir noch ein gleiches als Nachschub brächten."\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mmccl{Sprich: ``lch bin nur ein Mensch wie ihr, doch mir ist offenbart worden, daß euer Gott ein Einziger Gott ist. Möge denn derjenige, der auf die Begegnung mit seinem Herrn hofft, gute Werke tun und keinen anderen einbeziehen in den Dienst an seinem Herrn."\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mmccli{\basmalahde Kaf Ha Ya Ain, Sad.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmcclii{Erwähnt wird (hier) die Barmherzigkeit deines Herrn gegen Seinen Diener Zacharias.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmccliii{Als er seinen Herrn mit leisem Ruf anrief\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmccliv{sagte er: ``Mein Herr, mein Gebein ist nun schwach geworden, und die Haare meines Hauptes schimmern grau, doch niemals, mein Herr, bin ich mit meiner Bitte an Dich unglücklich gewesen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmcclv{Nun aber fürchte ich meine Verwandten, die mich überleben werden, und meine Frau ist unfruchtbar geworden. Gewähre Du mir darum einen Nachfolger\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmcclvi{auf daß er mein Erbe sei und der Erbe des Hauses Jakobs. Und mache ihn, mein Herr, (Dir) wohlgefällig."\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmcclvii{``O Zacharias, Wir geben dir die frohe Botschaft von einem Sohn, dessen Name Yahya sein soll. Wir haben noch keinen dieses Namens geschaffen."\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmcclviii{Er sagte: ``Mein Herr, wie soll mir ein Sohn (geboren) werden, wo doch meine Frau unfruchtbar ist und ich schon das fortgeschrittene Alter erreicht habe?"\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmcclix{Er sprach: ``So ist es; dein Herr aber spricht: ``Es ist Mir ein leichtes, und Ich habe dich zuvor geschaffen, als du ein Nichts warst.""\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmcclx{Er sagte: ``Mein Herr, gib mir ein Zeichen." Er sprach: ``Dein Zeichen sei, daß du wiewohl gesund drei (Tage und) Nächte lang nicht zu den Menschen reden sollst."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmcclxi{So trat er aus dem Tempel heraus vor sein Volk und gab ihm zu verstehen, daß es (Allah) am Morgen und am Abend zu preisen habe.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmcclxii{``O Yahya, halte das Buch kraftvoll fest." Und wir verliehen ihm Weisheit im Knabenalter\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmcclxiii{und ein liebevolles Gemüt von Uns und Reinheit. Und er war fromm\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmcclxiv{und ehrerbietig gegen seine Eltern. Und er war nicht hochfahrend, trotzig.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmcclxv{Und Friede war auf ihm an dem Tage, als er geboren wurde, und an dem Tage, als er starb, und (Friede wird auf ihm sein) an dem Tage, wenn er wieder zum Leben erweckt wird.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmcclxvi{Und ermahne im Buch Maria. Als sie sich von ihrer Familie nach einem östlichen Ort zurückzog\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmcclxvii{und sich vor ihr abschirmte, da sandten Wir Unseren Engel Gabriel zu ihr, und er erschien ihr in der Gestalt eines vollkommenen Menschen\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmcclxviii{und sie sagte: ``lch nehme meine Zuflucht vor dir bei dem Allerbarmer, (laß ab von mir,) wenn du Gottesfurcht hast."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmcclxix{Er sprach: ``lch bin der Bote deines Herrn. (Er hat mich zu dir geschickt,) auf daß ich dir einen reinen Sohn beschere."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmcclxx{Sie sagte: ``Wie soll mir ein Sohn (geschenkt) werden, wo mich doch kein Mann (je) berührt hat und ich auch keine Hure bin?"\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmcclxxi{Er sprach: ``So ist es; dein Herr aber spricht: ``Es ist Mir ein leichtes, und Wir machen ihn zu einem Zeichen für die Menschen und zu Unserer Barmherzigkeit, und dies ist eine beschlossene Sache.""\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmcclxxii{Und so empfing sie ihn und zog sich mit ihm an einen entlegenen Ort zurück.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmcclxxiii{Und die Wehen der Geburt trieben sie zum Stamm einer Dattelpalme. Sie sagte: ``O wäre ich doch zuvor gestorben und wäre ganz und gar vergessen!"\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmcclxxiv{Da rief er ihr von unten her zu: ``Sei nicht traurig. Dein Herr hat dir ein Bächlein fließen lassen\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmcclxxv{und schüttele den Stamm der Palme in deine Richtung, und sie wird frische reife Datteln auf dich fallen lassen.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmcclxxvi{So iß und trink und sei frohen Mutes. Und wenn du einen Menschen siehst, dann sprich: ``lch habe dem Allerbarmer zu fasten gelobt, darum will ich heute mit keinem Menschen reden.""\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmcclxxvii{Dann brachte sie ihn auf dem Arm zu den Ihren. Sie sagten: ``O Maria, du hast etwas Unerhörtes getan.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmcclxxviii{O Schwester Aarons, dein Vater war kein Bösewicht, und deine Mutter war keine Hure."\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmcclxxix{Da zeigte sie auf ihn. Sie sagten: ``Wie sollen wir zu einem reden, der noch ein Kind in der Wiege ist?"\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmcclxxx{Er (Jesus) sprach: ``lch bin ein Diener Allahs: Er hat mir das Buch gegeben und mich zu einem Propheten gemacht.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmcclxxxi{Und Er gab mir Seinen Segen, wo ich auch sein möge, und Er befahl mir Gebet und Zakah, solange ich lebe\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmcclxxxii{und ehrerbietig gegen meine Mutter (zu sein); Er hat mich nicht gewalttätig und unselig gemacht.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmcclxxxiii{Und Friede war über mir an dem Tage, als ich geboren wurde, und (Friede wird über mir sein) an dem Tage, wenn ich sterben werde, und an dem Tage, wenn ich wieder zum Leben erweckt werde."\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmcclxxxiv{Dies ist Jesus, Sohn der Maria (dies ist) eine Aussage der Wahrheit, über die sie uneins sind.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmcclxxxv{Es geziemt Allah nicht, Sich einen Sohn zu nehmen. Gepriesen sei Er! Wenn Er etwas beschließt, so spricht Er nur: ``Sei!" und es ist.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmcclxxxvi{``Wahrlich, Allah ist mein Herr und euer Herr. So dient Ihm! Das ist ein gerader Weg."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmcclxxxvii{Doch die Parteien wurden uneinig untereinander; wehe darum denen, die ungläubig sind; sie werden einen großen Tag erleben.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmcclxxxviii{Wie gut wird ihr Hören und Sehen an dem Tage sein, wo sie zu Uns kommen werden! Heute aber befinden sich die Frevler in offenbarem Irrtum.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmcclxxxix{Und warne sie vor dem Tag der Verbitterung, wenn alles entschieden werden wird, während sie (jetzt) noch in Sorglosigkeit leben und immer noch nicht glauben.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmccxc{Wir sind es, Die die Erde, und alle, die auf ihr sind, erben werden, und zu Uns werden sie zurückgebracht.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmccxci{Und erwähne in diesem Buch Abraham. Er war ein Wahrhaftiger, ein Prophet\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmccxcii{als er zu seinem Vater sagte: ``O mein Vater, warum verehrst du das, was nicht hört und sieht und dir nichts nützen kann?\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmccxciii{O mein Vater, zu mir ist ein Wissen gekommen, das nicht zu dir kam; so folge mir, ich will dich auf den ebenen Weg leiten.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmccxciv{O mein Vater, diene nicht dem Satan; denn Satan empört sich gegen den Allerbarmer.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmccxcv{O mein Vater, siehe, ich fürchte, es könnte dich die Strafe des Allerbarmers treffen, und dann wirst du ein Freund des Satans werden."\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmccxcvi{Er sagte: ``Wendest du dich von meinen Göttern ab, o Abraham? Wenn du (damit) nicht aufhörst, so werde ich dich wahrlich steinigen. Verlaß mich für lange Zeit."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmccxcvii{Er (Abraham) sagte: ``Friede sei auf dir! Ich will bei meinem Herrn um Vergebung für dich bitten; denn Er ist gnädig gegen mich.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmccxcviii{Und ich werde mich von euch und von dem, was ihr statt Allah anruft, fernhalten; und ich will zu meinem Herrn beten; ich werde durch das Gebet zu meinem Herrn bestimmt nicht unglücklich sein."\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmccxcix{Als er sich nun von ihnen und von dem, was sie statt Allah verehrten, getrennt hatte, da bescherten Wir ihm Isaak und Jakob und machten beide zu Propheten.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmccc{Und Wir verliehen ihnen Unsere Barmherzigkeit; und Wir gaben ihnen einen guten Ruf und hohes Ansehen.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmccci{Und erwähne in diesem Buch Moses. Er war wahrlich ein Erwählter; und er war ein Gesandter, ein Prophet.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmcccii{Wir riefen ihn von der rechten Seite des Berges und ließen ihn zu einer vertraulichen Unterredung näher treten.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmccciii{Und Wir machten ihm in Unserer Barmherzigkeit seinen Bruder Aaron zum Propheten.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmccciv{Und erwähne in diesem Buch Ismael. Er blieb wahrlich seinem Versprechen treu und war ein Gesandter, ein Prophet\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmcccv{und er pflegte seinen Angehörigen Gebet und Zakah ans Herz zu legen und war seinem Herrn wohlgefällig.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmcccvi{Und ermahne in diesem Buch Idris. Er war ein Wahrhaftiger, ein Prophet.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmcccvii{Wir erhoben ihn zu hohem Rang\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmcccviii{sie waren jene, denen Allah Gnade erwiesen hat. (Sie entstammten) der Nachkommenschaft Adams und derer, die Wir mit Nah trugen, und der Nachkommenschaft Abrahams und Israels und derer, die Wir rechtgeleitet und erwählt hatten. Wenn ihnen die Verse des Allerbarmers verlesen wurden, fielen sie betend und weinend nieder.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmcccix{Dann aber kamen nach ihnen Nachfahren, die das Gebet vernachlässigten und ihren Leidenschaften folgten. So gehen sie nun sicher dem Untergang entgegen\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmcccx{außer denen, die bereuen und glauben und rechtschaffen handeln. Diese werden ins Paradies eingehen, und sie werden kein Unrecht erleiden\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmcccxi{(in den) Gärten von Eden, die der Allerbarmer Seinen Dienern im Verborgenen verhieß. Wahrlich, Seine Verheißung wird in Erfüllung gehen.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmcccxii{Sie hören dort kein leeres Gerede, sondern (genießen) nur Frieden; und sie werden dort ihren Unterhalt morgens und abends empfangen.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmcccxiii{Dies ist das Paradies, das Wir jenen Unserer Diener zum Erbe geben, die gottesfürchtig sind.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmcccxiv{``Wir (Engel) kommen nur auf den Befehl deines Herrn hernieder. Sein ist alles, was vor uns und was hinter uns und was dazwischen ist; und dein Herr ist nicht vergeßlich."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmcccxv{(Er ist der) Herr der Himmel und der Erde und all dessen, was zwischen beiden liegt. So diene Ihm, und sei beharrlich in Seinem Dienst. Kennst du etwa einen, der Ihm gleich wäre?\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmcccxvi{Und der Mensch sagt: ``Wie? Wenn ich tot bin, soll ich dann wirklich (wieder) zum Leben auferstehen?"\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmcccxvii{Bedenkt der Mensch denn nicht, daß Wir ihn zuvor erschufen, als er ein Nichts war?\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmcccxviii{Und, bei deinem Herrn, Wir werden sie ganz gewiß versammeln und auch die Satane; dann werden Wir sie auf den Knien rund um Gahannam bringen.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmcccxix{Alsdann werden Wir aus jeder Partei diejenigen herausgreifen, die am trotzigsten in der Empörung gegen den Allerbarmer waren.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmcccxx{Und Wir kennen die am besten, die es am meisten verdienen, darein zu gehen.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmcccxxi{Und keiner ist unter euch, der nicht daran vorbeikommen wird das ist eine von deinem Herrn beschlossene Fügung.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmcccxxii{Dann werden Wir die Gottesfürchtigen erretten, die Frevler aber werden Wir darin auf den Knien belassen.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmcccxxiii{Und wenn ihnen Unsere deutlichen Zeichen verlesen werden, sagen die Ungläubigen zu den Gläubigen: ``Welche der beiden Gruppen ist besser gestellt und gibt eine eindrucksvollere Versammlung ab?"\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmcccxxiv{Und wieviele Geschlechter vor ihnen haben Wir schon vernichtet, (die) ansehnlicher an Besitz und äußerer Erscheinung (waren)!\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmcccxxv{Sprich: ``Diejenigen, die sich im Irrtum befinden, erhalten langes Gewähren vom Allerbarmer, bis sie das sehen, was ihnen angedroht wurde ob es nun die Strafe ist oder die Stunde, und dann erkennen, wer in der schlechteren Lage und schwächer an Streitmacht ist.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmcccxxvi{Und Allah bestärkt die, die rechtgeleitet sind, in Seiner Führung. Die bleibenden guten Werke aber sind lohnender bei deinem Herrn und fruchtbarer."\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmcccxxvii{Hast du wohl den gesehen, der Unsere Zeichen leugnet und sagt: ``Ganz gewiß werde ich Vermögen und Kinder erhalten?"\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmcccxxviii{Hatte er denn Zugang zum Verborgenen oder hat er vom Allerbarmer ein Versprechen entgegengenommen?\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmcccxxix{Nein; Wir werden aufschreiben, was er sagt, und Wir werden für ihn die Strafe verlängern.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmcccxxx{Und Wir werden all das von ihm erben, wovon er redet, und er wird allein zu Uns kommen.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmcccxxxi{Und sie haben sich Götter statt Allah genommen, auf daß sie ihnen zur Ehre gereichen.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmcccxxxii{Nein; sie werden einst ihre Verehrung leugnen und derer Widersacher sein.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmcccxxxiii{Siehst du nicht, daß Wir die Satane auf die Ungläubigen losgelassen haben, um sie aufzureizen?\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmcccxxxiv{Darum geh nicht eilig gegen sie vor; Wir zählen ihre (Taten) genau ab.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmcccxxxv{Am Tage, da Wir die Gottesfürchtigen als eine Abordnung vor dem Allerbarmer versammeln\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmcccxxxvi{werden Wir die Schuldigen wie eine Herde zu Gahannam treiben.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmcccxxxvii{Sie werden kein Anrecht auf Fürsprache haben mit Ausnahme dessen, der vom Allerbarmer ein Versprechen empfangen hat.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmcccxxxviii{Und sie sagen: ``Der Allerbarmer hat Sich einen Sohn genommen."\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmcccxxxix{Wahrhaftig, ihr habt da etwas Ungeheuerliches begangen!\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmcccxl{Beinahe werden die Himmel zerreißen und die Erde auseinanderbersten und beinahe werden die Berge in Trümmern zusammenstürzen\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmcccxli{weil sie dem Allerbarmer einen Sohn zugeschrieben haben.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmcccxlii{Und es geziemt dem Allerbarmer nicht, Sich einen Sohn zu nehmen.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmcccxliii{Da ist keiner in den Himmeln noch auf der Erde, der dem Allerbarmer anders denn als Diener sich nahen dürfte.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmcccxliv{Wahrlich, Er hat sie gründlich erfaßt und Er hat alle genau gezählt.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mmcccxlv{Und jeder von ihnen wird am Tage der Auferstehung allein zu Ihm kommen.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mmcccxlvi{Diejenigen, die da glauben und gute Werke tun ihnen wird der Allerbarmer Liebe zukommen lassen.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mmcccxlvii{Darum haben Wir ihn (den Quran) (dir) in deiner Sprache leicht (verständlich) gemacht, damit du durch ihn den Gottesfürchtigen die frohe Botschaft verkünden und die Streitsüchtigen warnen mögest.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mmcccxlviii{Und wieviele Geschlechter haben Wir vor ihnen vernichtet! Kannst du auch nur einen von ihnen spüren oder auch nur einen Laut von ihnen hören?\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mmcccxlix{\basmalahde Ta Ha.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmcccl{Wir haben den Quran nicht auf dich herabgesandt, um dich unglücklich zu machen\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmcccli{sondern als eine Ermahnung für den, der (Allah) fürchtet.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmccclii{(Dies ist) eine Offenbarung von Ihm, Der die Erde und die hohen Himmel erschuf.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmcccliii{(Er ist) der Allerbarmer, Der über Sein Reich majestätisch herrscht.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmcccliv{Sein ist, was in den Himmeln und was auf Erden ist und was zwischen beiden und was unter dem Erdreich liegt.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmccclv{Und wenn du das Wort laut aussprichst, dann wahrlich, kennt Er das Geheime und das, was noch verborgener ist.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmccclvi{Allah - es ist kein Gott außer Ihm. Ihm kommen die Schönsten Namen zu.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmccclvii{Ist dir Moses' Geschichte nicht zu Ohren gekommen?\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmccclviii{Als er ein Feuer sah, sagte er zu seinen Angehörigen: ``Bleibt (hier), ich habe ein Feuer wahrgenommen; vielleicht kann ich euch ein Stück Glut davon bringen oder den rechten Weg am Feuer finden.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmccclix{Und wie er näher herankam, wurde er angerufen: ``O Moses!\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmccclx{Ich bin es, dein Herr. So zieh deine Schuhe aus; denn du bist im heiligen Wadi Tuwa.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmccclxi{Und Ich habe dich erwählt; so höre denn auf das, was offenbart wird.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmccclxii{Wahrlich, Ich bin Allah. Es ist kein Gott außer Mir; darum diene Mir und verrichte das Gebet zu Meinem Gedenken.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmccclxiii{Wahrlich, die Stunde kommt bestimmt. Ich halte sie fest verborgen, auf daß jede Seele nach ihrem Bemühen belohnt werde.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmccclxiv{Darum laß dich nicht von dem, der hieran nicht glaubt und seinen Gelüsten folgt, davon abhalten, damit du nicht untergehest.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmccclxv{Und was ist das in deiner Rechten, o Moses?"\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmccclxvi{Er sagte: ``Das ist mein Stock; ich stütze mich darauf und schlage damit Laub für meine Schafe ab, und ich habe für ihn noch andere Verwendungen."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmccclxvii{Er sprach: ``Wirf ihn hin, o Moses!"\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmccclxviii{Da warf er ihn hin, und siehe, er wurde zu einer Schlange, die umhereilte.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmccclxix{Er sprach: ``Ergreife ihn und fürchte dich nicht. Wir werden ihn in seinen früheren Zustand zurückbringen.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmccclxx{Und stecke deine Hand dicht unter deinen Arm: sie wird weiß hervorkommen, ohne ein Übel - (dies ist) noch ein weiteres Zeichen\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmccclxxi{auf daß Wir dir etwas von Unseren größten Zeichen zeigen.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmccclxxii{Gehe zu Pharao; denn er ist aufsässig geworden."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmccclxxiii{Er sagte: ``Mein Herr, gib mir die Bereitschaft (dazu)\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmccclxxiv{und erleichtere mir meine Aufgabe\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmccclxxv{und löse den Knoten meiner Zunge\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmccclxxvi{damit sie meine Rede verstehen mögen.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmccclxxvii{Und gib mir einen Beistand aus meiner Familie mit\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmccclxxviii{Aaron, meinen Bruder\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmccclxxix{mit dem ich meine Kraft steigere\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmccclxxx{und laß ihn an meiner Aufgabe teilhaben\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmccclxxxi{auf daß wir Dich oft preisen mögen\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmccclxxxii{und Deiner oft gedenken\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmccclxxxiii{denn Du kennst uns am besten."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmccclxxxiv{Er sprach: ``Dein Wunsch ist dir gewährt, o Moses!\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmccclxxxv{Und sicher haben Wir dir (auch schon) ein andermal Gnade erwiesen\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmccclxxxvi{als Wir deiner Mutter jene Weisung eingaben\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmccclxxxvii{>Lege ihn in einen Kasten und wirf ihn in den Fluß, dann wird der Fluß ihn ans Ufer spülen, so daß ein Feind von Mir und ihm ihn aufnehmen wird." Und Ich habe auf dich Liebe von Mir gelegt; damit du unter Meinem Auge aufgezogen wurdest.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmccclxxxviii{Damals ging deine Schwester hin und sagte: ``Soll ich euch jemanden empfehlen, der ihn betreuen könnte?" So gaben Wir dich deiner Mutter wieder, auf daß ihr Auge von Freude erfüllt würde und sie sich nicht grämte. Und du erschlugst einen Menschen, Wir aber erretteten dich aus der Trübsal. Dann prüften Wir dich auf mannigfache Art. Und du verweiltest jahrelang unter dem Volk von Madyan. Hierauf kamst du hierher, o Moses, gemäß einer bestimmten Fügung.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmccclxxxix{Und Ich habe dich für Mich ausgewählt.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmcccxc{Geht denn mit Meinen Zeichen hin, du und dein Bruder, und lasset nicht (darin) nach, Meiner zu gedenken.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmcccxci{Geht beide zu Pharao; denn er ist aufsässig geworden.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmcccxcii{Jedoch sprechet zu ihm in sanfter Sprache; vielleicht läßt er sich mahnen oder fürchtet sich."\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmcccxciii{Beide sagten: ``Unser Herr, wir fürchten, er könnte sich an uns vergreifen oder das Ausmaß seiner Gewalt übersteigen."\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmcccxciv{Er sprach: ``Fürchtet euch nicht; denn Ich bin mit euch beiden. Ich höre und Ich sehe.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmcccxcv{So geht denn beide zu ihm hin und sprecht: ``Wir sind zwei Gesandte deines Herrn; so laß die Kinder Israels mit uns ziehen; und bestrafe sie nicht. Wir haben dir in Wahrheit ein Zeichen von deinem Herrn gebracht und Friede sei auf dem, der der Rechtleitung folgt!\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmcccxcvi{Es ist uns offenbart worden, daß die Strafe über den kommen wird, der (den Glauben) verwirft und sich (von ihm) abwendet.""\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmcccxcvii{(Pharao) sagte: ``Wer ist euer beider Herr, o Moses?"\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmcccxcviii{Er sagte: ``Unser Herr ist Der, Der jedem Ding seine Schöpfungsart gab, alsdann es zu seiner Bestimmung führte."\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmcccxcix{Er (Pharao) sagte: ``Und wie steht es dann um die früheren Geschlechter?"\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmcd{Er sagte: ``Das Wissen um sie steht bei meinem Herrn in einem Buch. Weder irrt mein Herr, noch vergißt Er."\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmcdi{(Er ist es,) Der die Erde für euch zu einem Lager gemacht hat und Wege über sie für euch hinlaufen läßt und Regen vom Himmel hernieder sendet. Und damit bringen Wir Paare von Pflanzenarten hervor.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmcdii{``Esset denn und weidet euer Vieh." Wahrlich, hierin liegen Zeichen für Leute von Verstand.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmcdiii{Aus ihr (der Erde) haben Wir euch erschaffen, und in sie werden Wir euch zurückkehren lassen, und aus ihr bringen Wir euch abermals hervor.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmcdiv{Und wir ließen ihn (Pharao) Unsere Zeichen allesamt schauen; doch er verwarf (sie) und weigerte sich (zu glauben)\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmcdv{Er sagte: ``Bist du zu uns gekommen, o Moses, um uns durch deinen Zauber aus unserem Lande zu treiben\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmcdvi{Aber wir werden dir sicher einen diesem Zauber gleichen bringen; so setze einen Termin an einem neutralen Ort für uns fest, den wir nicht verfehlen werden - weder wir noch du."\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmcdvii{Er (Moses) sagte: ``Euer Termin sei auf den Tag des Festes (gelegt), und veranlasse, daß sich die Leute bereits am Vormittag versammeln."\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmcdviii{Da wandte sich Pharao ab und plante eine List, und dann kam er.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmcdix{Moses sagte zu ihnen: ``Wehe euch, ersinnt keine Lüge gegen Allah, damit Er euch nicht durch eine Strafe vernichte. Wer eine Lüge ersinnt, der wird eine Enttäu schung erleben."\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmcdx{Dann stritten sie sich über ihre Sache und berieten (sich) insgeheim.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmcdxi{Sie sagten: ``Diese beiden sind sicher Zauberer, die euch durch ihren Zauber aus eurem Land treiben und eure vortreffliche Lebensweise beseitigen wollen.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmcdxii{So zeigt, was ihr an Macht habt und kommt dann wohlgereiht nach vorn. Und wer heute die Oberhand gewinnt, der wird Erfolg haben."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmcdxiii{Sie sagten: ``O Moses, entweder wirfst du (den Stock zuerst), oder wir werden die Ersten (beim Werfen) sein."\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmcdxiv{Er sagte: ``Nein; werft ihr nur!" Da siehe, ihre Stricke und ihre Stöcke erschienen ihm durch ihre Zauberei; als ob sie umhereilten.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmcdxv{Und Moses verspürte Furcht in seiner Seele.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmcdxvi{Wir sprachen: ``Fürchte dich nicht; denn du wirst die Oberhand gewinnen.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmcdxvii{Und wirf nur, was in deiner Rechten ist; es wird das verschlingen, was sie gemacht haben; denn das, was sie gemacht haben, ist nur die List eines Zauberers. Und ein Zauberer soll keinen Erfolg haben, woher er auch kommen mag."\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmcdxviii{Da warfen die Zauberer sich nieder. Sie sagten: ``Wir glauben an den Herrn Aarons und Moses'."\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmcdxix{Er (Pharao) sagte: ``Glaubt ihr an ihn bevor ich es euch erlaube? Er muß wohl euer Meister sein, der euch die Zauberei lehrte. Wahrhaftig, ich will euch darum die Hände und Füße wechselweise abhauen (lassen), und wahrhaftig, ich will euch an den Stämmen der Palmen kreuzigen (lassen); dann werdet ihr bestimmt erfahren, wer von uns strenger und nachhaltiger im Strafen ist."\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmcdxx{Sie sagten: ``Wir wollen dir in keiner Weise den Vorzug geben vor den deutlichen Zeichen, die zu uns gekommen sind, noch (vor Dem,) Der uns erschaffen hat. Gebiete, was du gebieten magst: du kannst ja doch nur über dieses irdische Leben gebieten.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmcdxxi{Wir glauben an unseren Herrn, auf daß Er uns unsere Sünden und die Zauberei, zu der du uns genötigt hast, vergebe. Allah ist der Beste und der Beständigste."\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmcdxxii{Wahrlich, für den, der im Zustand der Sündhaftigkeit zu seinem Herrn kommt, ist Gahannam (bestimmt); darin soll er weder sterben noch leben.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmcdxxiii{Denen aber, die als Gläubige zu Ihm kommen (und) gute Taten vollbracht haben, sollen die höchsten Rangstufen zuteil werden\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmcdxxiv{die Gärten von Eden, durch die Bäche fließen; darin werden sie auf ewig verweilen. Und das ist der Lohn derer, die sich rein halten.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmcdxxv{Und wahrlich, Wir offenbarten Moses: ``Führe Meine Diener bei Nacht hinweg und schlage ihnen eine trockene Straße durch das Meer. Du brauchst nicht zu fürchten, eingeholt zu werden, noch brauchst du dir sonst (irgendwelche) Sorgen zu machen."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmcdxxvi{Darauf verfolgte sie Pharao mit seinen Heerscharen, und es kam (etwas) aus dem Meer über sie, was sie überwältigte.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmcdxxvii{Und Pharao führte sein Volk in die Irre und führte (es) nicht den rechten Weg.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmcdxxviii{``O ihr Kinder Israels, Wir erretteten euch von eurem Feinde, und Wir schlossen einen Bund an der rechten Seite des Berges mit euch und sandten Manna und Wachteln auf euch herab.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmcdxxix{Esset nun von den guten Dingen, die Wir euch gegeben haben, doch überschreitet dabei nicht das Maß, damit Mein Zorn nicht auf euch niederfahre; denn der, auf den Mein Zorn niederfährt, geht unter.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmcdxxx{Und doch gewähre Ich dem Verzeihung, der bereut und glaubt und das Gute tut und dann der Führung folgt.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmcdxxxi{Und was hat dich so eilig von deinem Volke weggetrieben, o Moses?"\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmcdxxxii{Er sagte: ``Sie folgen meiner Spur, und ich bin zu Dir geeilt, mein Herr, damit Du wohl zufrieden bist."\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmcdxxxiii{Er sprach: ``Siehe, Wir haben dein Volk in deiner Abwesenheit geprüft, und der Samiryy hat sie verführt."\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmcdxxxiv{Da kehrte Moses zornig und voller Bedauern zu seinem Volk zurück. Er sagte: ``O mein Volk, hat euer Herr euch nicht eine schöne Verheißung gegeben? Erschien euch etwa die anberaumte Zeit zu lang, oder wolltet ihr, daß der Zorn eures Herrn auf euch niederfahre, als ihr euer Versprechen mir gegenüber bracht?"\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmcdxxxv{Sie sagten: ``Nicht aus freien Stücken haben wir das Versprechen dir gegenüber gebrochen: allein, wir waren beladen mit der Last der Schmucksachen des Volkes; wir warfen sie fort, und das gleiche tat auch der Samiryy."\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmcdxxxvi{Dann brachte er ihnen ein leibhaftiges Kalb, das blökte, hervor. Und sie sagten: ``Das ist euer Gott und der Gott Moses'; er hat (ihn) vergessen."\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmcdxxxvii{Konnten sie denn nicht sehen, daß es ihnen keine Antwort gab und keine Macht hatte, ihnen weder zu schaden noch zu nützen?\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmcdxxxviii{Und doch hatte Aaron zuvor zu ihnen gesagt: ``O mein Volk, dadurch seid ihr nur geprüft worden. Wahrlich, euer Herr ist der Allerbarmer; darum folgt mir und gehorcht meinem Befehl."\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmcdxxxix{Sie sagten: ``Wir werden keineswegs aufhören, es anzubeten, bis Moses zu uns zurückkehrt."\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmcdxl{Er (Moses) sagte: ``O Aaron, was hinderte dich, als du sie irregehen sahst\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmcdxli{mir zu folgen? Bist du denn meinem Befehl ungehorsam gewesen?"\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmcdxlii{Er sagte: ``O Sohn meiner Mutter, greife nicht nach meinem Bart, noch nach meinem Kopf. Ich fürchtete, du könntest sagen: ``Du hast die Kinder Israels gespalten und mein Wort nicht beachtet.""\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mmcdxliii{Er sagte: ``Und was hast du zu sagen, o Samiryy?"\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mmcdxliv{Er sagte: ``lch bemerkte, was sie nicht wahrnehmen konnten. Da faßte ich eine Handvoll Erde von der Spur des Gesandten und warf sie hin. So habe ich es mir selber eingeredet."\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mmcdxlv{Er (Moses) sagte: ``Geh denn hin! Du sollst dein ganzes Leben lang sagen müssen: ``Berührt (mich) nicht"; und dann ist da ein Zeitpunkt für dich, dem du nicht entgehen wirst. So schaue nun auf deinen ``Gott", dessen ergebener Anbeter du geworden bist. Wir werden ihn ganz gewiß verbrennen und ihn darauf ins Meer streuen."\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mmcdxlvi{Wahrlich, euer Gott ist Allah, außer Dem kein Gott da ist. Er umfaßt alle Dinge mit Wissen.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mmcdxlvii{Damit also erzählen Wir dir so manche Geschichte von dem, was zuvor geschah. Und Wir haben dir Unsere Ermahnung erteilt.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mmcdxlviii{Wer sich abkehrt, der wird wahrlich am Tage der Auferstehung eine Last tragen.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mmcdxlix{(In der Hölle) werden sie auf ewig verweilen; und schwer wird ihnen die Bürde am Tage der Auferstehung sein\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mmcdl{an dem Tage, da in den Sur gestoßen wird. Und an jenem Tage werden Wir die Schuldigen als Blauäugige versammeln\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mmcdli{sie werden einander heimlich zuflüstern: ``lhr weiltet nur zehn (Tage im Grab)"\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mmcdlii{Wir wissen am besten, was sie sagen. Dann wird der Vernünftigste von ihnen sagen: ``Nur einen Tag verweiltet ihr."\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mmcdliii{Und sie werden dich nach den Bergen fragen. Sprich: ``Mein Herr wird sie vollständig sprengen.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mmcdliv{Und Er wird sie als kahle Ebene zurück lassen\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mmcdlv{worin du weder Krümmungen noch Unebenheiten sehen wirst."\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mmcdlvi{An jenem Tage werden sie dem Rufe folgen, der keine Abweichung kennt; alle Stimmen werden vor dem Allerbarmer gesenkt sein, und du wirst nichts als Flüstern hören.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mmcdlvii{An jenem Tage wird keinem Fürsprache etwas nützen - außer jenem, dem der Allerbarmer (dazu) die Erlaubnis gibt und dessen Wort Ihm wohlgefällig ist.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mmcdlviii{Er kennt alles, was vor ihnen ist und was hinter ihnen ist; sie aber können es nicht mit Wissen umfassen.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mmcdlix{Und die Gesichter werden sich demütig vor dem Lebendigen, dem Ewig-Beständigen, neigen. Und hoffnungslos wahrlich ist jener, der (die Last des) Frevels trägt.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mmcdlx{Und der aber, der gute Werke tut und dabei gläubig ist, wird weder Ungerechtigkeit noch Unterdrückung (zu) fürchten (haben)\qt@no{(112)}}
\qt@newcmd\qurantrans@de@mmcdlxi{Und somit haben Wir (die Schrift) als arabischen Quran niedergesandt, und Wir haben darin gewisse Warnungen klar gemacht, auf daß sie (Ihn) fürchten mögen oder (wünschen mögen,) daß er ihnen eine Ermahnung bringe.\qt@no{(113)}}
\qt@newcmd\qurantrans@de@mmcdlxii{Hoch Erhaben ist Allah, der wahre König! Und überhaste dich nicht mit dem Quran, ehe seine Offenbarung dir nicht vollständig zuteil geworden ist, sondern sprich: ``O mein Herr, mehre mein Wissen."\qt@no{(114)}}
\qt@newcmd\qurantrans@de@mmcdlxiii{Und wahrlich, Wir schlossen zuvor einen Bund mit Adam, aber er vergaß (ihn); Wir fanden in ihm kein Ausharrungsvermögen.\qt@no{(115)}}
\qt@newcmd\qurantrans@de@mmcdlxiv{Und als Wir da zu den Engeln sprachen: ``Werft euch vor Adam nieder", da warfen sie sich nieder, außer Iblis. Er weigerte sich.\qt@no{(116)}}
\qt@newcmd\qurantrans@de@mmcdlxv{Sodann sprachen Wir: ``O Adam, dieser ist dir und deiner Frau ein Feind; (achtet darauf,) daß er euch nicht beide aus dem Garten treibt! Sonst würdest du unglücklich sein.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@mmcdlxvi{Es ist für dich gesorgt, daß du darin weder Hunger fühlen noch nackt sein sollst.\qt@no{(118)}}
\qt@newcmd\qurantrans@de@mmcdlxvii{Und du sollst darin nicht dürsten noch der Sonnenhitze ausgesetzt sein."\qt@no{(119)}}
\qt@newcmd\qurantrans@de@mmcdlxviii{Jedoch Satan flüsterte ihm Böses ein; er sagte: ``O Adam, soll ich dich zum Baume der Ewigkeit führen und zu einem Königreich, das nimmer vergeht?"\qt@no{(120)}}
\qt@newcmd\qurantrans@de@mmcdlxix{Da aßen sie beide davon, so daß ihnen ihre Blöße ersichtlich wurde, und sie begannen, die Blätter des Gartens über sich zusammenzustecken. Und Adam befolgte das Gebot seines Herrn nicht und ging irre.\qt@no{(121)}}
\qt@newcmd\qurantrans@de@mmcdlxx{Hierauf erwählte ihn sein Herr und wandte Sich ihm mit Erbarmen und Rechtleitung zu.\qt@no{(122)}}
\qt@newcmd\qurantrans@de@mmcdlxxi{Er sprach: ``Geht von hier allesamt hinunter, der eine von euch soll des anderen Feind sein! Und wenn Meine Führung zu euch kommt, dann wird der, der Meiner Führung folgt, nicht zugrunde gehen, noch wird er Unglück erleiden.\qt@no{(123)}}
\qt@newcmd\qurantrans@de@mmcdlxxii{Und dem, der sich jedoch von Meiner Ermahnung abkehrt, wird ein Leben in Drangsal beschieden sein, und am Tage der Auferstehung werden Wir ihn blind vor Uns führen."\qt@no{(124)}}
\qt@newcmd\qurantrans@de@mmcdlxxiii{Er wird sagen: ``Mein Herr, warum hast Du mich blind (vor Dich) geführt, obwohl ich (zuvor) sehen konnte?"\qt@no{(125)}}
\qt@newcmd\qurantrans@de@mmcdlxxiv{Er wird sprechen: ``Es sind ja Unsere Zeichen zu dir gekommen, und du hast sie mißachtet: also wirst heute nun du mißachtet sein!"\qt@no{(126)}}
\qt@newcmd\qurantrans@de@mmcdlxxv{Und ebenso belohnen Wir auch den, der maßlos ist und nicht an die Zeichen seines Herrn glaubt; und die Strafe des Jenseits ist wahrlich strenger und nachhaltiger.\qt@no{(127)}}
\qt@newcmd\qurantrans@de@mmcdlxxvi{Leuchtet es ihnen (denn) nicht ein, wie viele Geschlechter vor ihnen Wir schon vernichteten, in deren Wohnstätten sie umherwandern? Darin liegen Zeichen für die Leute, die Verstand haben.\qt@no{(128)}}
\qt@newcmd\qurantrans@de@mmcdlxxvii{Und wäre nicht zuvor ein Wort von deinem Herrn ergangen, so wäre die (Strafe) fällig; (genauso ist es) mit der Frist, die vorbestimmt ist.\qt@no{(129)}}
\qt@newcmd\qurantrans@de@mmcdlxxviii{Ertrage denn geduldig, was sie sagen, und lobpreise deinen Herrn vor dem Aufgang und vor dem Untergang der Sonne, und verherrliche (ihn) in den Nachtstunden und an den Tagesenden, auf daß du wahre Glückseligkeit finden mögest.\qt@no{(130)}}
\qt@newcmd\qurantrans@de@mmcdlxxix{Und richte deinen Blick nicht auf das, was Wir einigen von ihnen zu (kurzem) Genuß gewährten den Glanz des irdischen Lebens -, um sie dadurch zu prüfen. Denn die Versorgung deines Herrn ist besser und bleibender.\qt@no{(131)}}
\qt@newcmd\qurantrans@de@mmcdlxxx{Und fordere die Deinen zum Gebet auf und sei (selbst) darin ausdauernd. Wir verlangen keinen Unterhalt von dir; Wir Selbst sorgen für dich. Und der Ausgang ist durch Gottesfurcht vorgegeben.\qt@no{(132)}}
\qt@newcmd\qurantrans@de@mmcdlxxxi{Und sie sagen: ``Warum bringt er uns kein Zeichen von seinem Herrn?" Ist zu ihnen denn nicht der klarste Beweis für das gekommen, was in den früheren Schriften steht?\qt@no{(133)}}
\qt@newcmd\qurantrans@de@mmcdlxxxii{Und hätten Wir sie vordem durch eine Strafe vernichtet, dann hätten sie gewiß gesagt: ``Unser Herr, warum schicktest Du uns keinen Gesandten, (der uns hätte helfen können,) Deine Gebote zu befolgen, ehe wir gedemütigt und beschämt wurden?"\qt@no{(134)}}
\qt@newcmd\qurantrans@de@mmcdlxxxiii{Sprich: ``Ein jeder wartet; so wartet auch ihr, und ihr werdet erfahren, wer die Befolger des ebenen Weges sind und wer rechtgeleitet ist."\qt@no{(135)}}
\qt@newcmd\qurantrans@de@mmcdlxxxiv{\basmalahde Den Menschen ist die Zeit ihrer Abrechnung nahe gerückt; und doch wenden sie sich in Achtlosigkeit ab.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmcdlxxxv{Keine neue Ermahnung von ihrem Herrn kommt zu ihnen, die sie nicht leichtfertig anhörten.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmcdlxxxvi{Ihre Herzen belustigen sich anderweitig. Und sie besprechen sich insgeheim - sie, die da freveln - (, dann sagen sie): ``Ist dieser etwa ein anderer Mensch als wir? Wollt ihr euch denn gegen (bessere) Einsicht auf Zauberei einlassen?"\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmcdlxxxvii{Er sagte: ``Mein Herr weiß, was im Himmel und auf Erden gesprochen wird, und Er ist der Allhörende, der Allwissende."\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmcdlxxxviii{``Nein", sagen sie, ``(das) aber (sind) wirre Träume; nein, er hat ihn erdichtet; nein, er ist (nur) ein Dichter. Möge er uns doch ein Zeichen in der Art bringen, wie die früheren entsandt wurden."\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmcdlxxxix{Nie hatte vor ihnen irgendeine Stadt je geglaubt, die Wir vernichteten. Würden sie denn glauben?\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmcdxc{Und Wir entsandten vor dir lediglich Männer, denen Wir die Offenbarung zuteil werden ließen - fragt nur diejenigen, die von der Ermahnung wissen, wenn ihr (davon) nichts wisset.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmcdxci{Und Wir machten ihnen keinen Leib, daß sie keiner Speise bedürft hätten, noch daß sie ewig lebten.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmcdxcii{Dann erfüllten Wir ihnen das Versprechen; und Wir erretteten sie und die, die Wir wollten; die Übertreter aber vertilgten Wir.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmcdxciii{Wahrlich, Wir haben euch ein Buch hinabgesandt, worin eure Ehre liegt; wollt ihr es denn nicht begreifen?\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmcdxciv{Wie so manche Stadt, voll der Ungerechtigkeit, haben Wir schon niedergebrochen und nach ihr ein anderes Volk erweckt!\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmcdxcv{Und da sie Unsere Strafe spürten, siehe, da begannen sie davor zu fliehen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmcdxcvi{``Flieht nicht, sondern kehrt zu dem Behagen, das ihr genießen dürftet, und zu euren Wohnstätten zurück, damit ihr befragt werden könnt."\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmcdxcvii{Sie sagten: `` O wehe uns, wir waren wahrlich Frevler!"\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmcdxcviii{Und dieser ihr Ruf hörte nicht eher auf, als bis Wir sie niedermähten und in Asche verwandelten.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmcdxcix{Und Wir erschufen Himmel und Erde und das, was zwischen beiden ist, nicht zum Spiel.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmd{Hätten Wir Uns einen Zeitvertreib schaffen wollen, so hätten Wir dies von Uns aus vorgenommen, wenn Wir das überhaupt hätten tun wollen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmdi{Vielmehr werfen Wir die Wahrheit gegen die Lüge, und diese wird dadurch lebensunfähig gemacht. Und wehe euch im Hinblick darauf, was ihr aussagt!\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmdii{Und Sein ist, wer in den Himmeln und auf der Erde ist. Und die bei Ihm sind, sind nicht zu stolz, Ihm zu dienen, noch werden sie lustlos sein.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmdiii{Sie verherrlichen (ihn) bei Nacht und Tag; (und) sie lassen (darin) nicht nach.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmdiv{Oder haben sie sich Götter von der Erde genommen, die lebendig machen?\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmdv{Gäbe es in (Himmel und Erde) Götter außer Allah, dann wären wahrlich beide dem Unheil verfallen. Gepriesen sei denn Allah, der Herr des Thrones, Hoch Erhaben über das, was sie beschreiben.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmdvi{Er wird nicht befragt nach dem, was Er tut; sie aber werden befragt (nach dem, was sie tun)\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmdvii{Haben sie sich Götter außer Ihm genommen? Sprich: ``Bringt euren Beweis herbei. Dieser (Quran) ist eine Ermahnung für jene, die mit mir sind, und eine Ermahnung für die, die vor mir waren." Doch die meisten von ihnen kennen die Wahrheit nicht, und so wenden sie sich (von ihr) ab.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmdviii{Und Wir schickten keinen Gesandten vor dir, dem Wir nicht offenbart haben: ``Es ist kein Gott außer Mir, darum dient nur Mir."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmdix{Und sie sagen: ``Der Allerbarmer hat Sich einen Sohn genommen." Gepriesen sei Er! Nein, aber sie sind (nur) geehrte Diener\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmdx{sie kommen Ihm beim Sprechen nicht zuvor, und sie handeln nur nach Seinem Befehl.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmdxi{Er weiß, was vor ihnen und was hinter ihnen ist, und sie legen keine Fürsprache ein; außer für den, an dem Er Wohlgefallen hat, und sie zagen aus Furcht vor Ihm.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmdxii{Und dem, der von ihnen sagen wollte: ``lch bin ein Gott neben Ihm", würden Wir es mit Gahannam vergelten. Und ebenso vergelten Wir es den Ungerechten.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmdxiii{Haben die Ungläubigen nicht gesehen, daß die Himmel und die Erde eine Einheit waren, die Wir dann zerteilten? Und Wir machten aus dem Wasser alles Lebendige. Wollen sie denn nicht glauben?\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmdxiv{Und feste Berge haben Wir in der Erde gegründet, auf daß sie nicht mit ihnen wanke; und Wir haben auf ihr gangbare Pässe angelegt, damit sie sich zurecht finden.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmdxv{Und Wir machten den Himmel zu einem wohlgeschützten Dach; dennoch kehren sie sich von seinem Zeichen ab.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmdxvi{Und Er ist es, Der die Nacht und den Tag erschuf und die Sonne und den Mond. Sie schweben, ein jedes (Gestirn) auf seiner Laufbahn.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmdxvii{Wir gewährten keinem Menschenwesen vor dir das ewige Leben. Als ob sie es wären, die ewig leben könnten, wenn du gestorben wärst!\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmdxviii{Jede Seele wird den Tod kosten; und Wir stellen euch mit Bösem und mit Gutem auf die Probe; und zu Uns werdet ihr zu rückgebracht.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmdxix{Und wenn die Ungläubigen dich sehen, so treiben sie nur Spott mit dir: ``Ist das der, der eure Götter (in abfälliger Weise) erwähnt?" während sie es doch selbst sind, die die Erwähnung des Allerbarmers verleugnen.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmdxx{Der Mensch ist ein Geschöpf der Eilfertigkeit. Ich werde euch Meine Zeichen zeigen, aber fordert nicht von Mir, daß Ich Mich übereile.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmdxxi{Und sie sagen: ``Wann wird diese Verheißung (in Erfüllung gehen), wenn ihr wahrhaftig seid?"\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmdxxii{Wenn die Ungläubigen nur die Zeit wüßten, wo sie nicht imstande sein werden, das Feuer von ihren Gesichtern oder ihren Rücken fernzuhalten! Und keine Hilfe wird ihnen zuteil sein.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmdxxiii{Nein, es wird unversehens über sie kommen, so daß sie in Verwirrung gestürzt werden; und sie werden es nicht abwehren können, noch werden sie Aufschub erlangen.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmdxxiv{Und es sind wahrlich schon vor dir Gesandte verspottet worden, dann aber traf jene, die Spott trieben, das, worüber sie spotteten.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmdxxv{Sprich: ``Wer beschützt euch bei Nacht und bei Tag vor dem Allerbarmer?" Und doch kehren sie sich von der Ermahnung ihres Herrn ab.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmdxxvi{Oder haben sie etwa Götter, die sie vor Uns beschützen können? Sie vermögen sich nicht selbst zu helfen, noch kann ihnen gegen Uns geholfen werden.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmdxxvii{Nein, Wir ließen diese und ihre Väter leben, bis das Leben ihnen lang wurde. Sehen sie denn nicht, daß Wir über das Land kommen und es an seinen Enden schmälern? Können sie denn siegen?\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmdxxviii{Sprich: ``lch warne euch nur mit der Offenbarung." Jedoch die Tauben hören den Ruf nicht, wenn sie gewarnt werden.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmdxxix{Und wenn sie ein Hauch von der Strafe deines Herrn berührt, dann werden sie sicher sagen: ``O wehe uns, wir waren wahrlich Frevler!"\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmdxxx{Und Wir werden Waagen der Gerechtigkeit für den Tag der Auferstehung aufstellen, so daß keine Seele in irgendeiner Weise Unrecht erleiden wird. Und wäre es das Gewicht eines Senfkorns, würden Wir es hervorbringen. Und Wir genügen als Rechner.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmdxxxi{Und wahrlich, Wir gaben Moses und Aaron die Unterscheidung als Licht und Ermahnung für die Gottesfürchtigen\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmdxxxii{die ihren Herrn im verborgenen fürchten und sich vor der Stunde Sorge tragen.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmdxxxiii{Und dieser (Quran) ist eine segensreiche Ermahnung, die Wir hinabgesandt haben. Wollt ihr sie nun verwerfen?\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmdxxxiv{Und vordem gaben Wir Abraham seine Recht schaffenheit; denn Wir kannten ihn.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmdxxxv{Als er zu seinem Vater und seinem Volke sagte: ``Was sind das für Bildwerke, denen ihr so ergeben seid?"\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmdxxxvi{sagten sie: ``Wir fanden, daß unsere Väter stets diese verehrten."\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmdxxxvii{Er sagte: ``Wahrlich, ihr selbst wie auch eure Väter seid im deutlichen Irrtum gewesen."\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmdxxxviii{Sie sagten: ``Bringst du uns die Wahrheit, oder gehörst du zu denen, die einen Scherz (mit uns) treiben?"\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmdxxxix{Er sagte: ``Nein, euer Herr ist der Herr der Himmel und der Erde, Der sie erschuf; und ich bin einer, der dies bezeugt.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmdxl{Und, bei Allah, ich will gewiß gegen eure Götzen verfahren, nachdem ihr kehrt gemacht habt und weggegangen seid."\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmdxli{Alsdann schlug er sie in Stücke - mit Ausnahme des größten von ihnen -, damit sie sich an ihn wenden könnten.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmdxlii{Sie sagten: ``Wer hat unseren Göttern dies angetan? Er muß wahrlich ein Frevler sein."\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmdxliii{Sie sagten: ``Wir hörten einen jungen Mann von ihnen reden; Abraham heißt er."\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmdxliv{Sie sagten: ``So bringt ihn vor die Augen der Menschen damit sie das bezeugen."\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmdxlv{Sie sagten: ``Bist du es gewesen, der unseren Göttern dies angetan hat, O Abraham?"\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmdxlvi{Er sagte: ``Nein, dieser da, der größte von ihnen, hat es getan. Fragt sie doch, wenn sie reden können."\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmdxlvii{Da wandten sie sich einander zu und sagten: ``Wir selber sind wahrhaftig im Unrecht."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmdxlviii{Dann wurden sie rückfällig: ``Du weißt recht wohl, daß diese nicht reden können."\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmdxlix{Er sagte: ``Verehrt ihr denn statt Allah das, was euch weder den geringsten Nutzen bringen noch euch schaden kann?\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmdl{Pfui über euch und über das, was ihr statt Allah anbetet! Wollt ihr es denn nicht begreifen?"\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmdli{Sie sagten: ``Verbrennt ihn und helft euren Göttern, wenn ihr etwas tun wollt."\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmdlii{Wir sprachen: ``O Feuer, sei kühl und ein Frieden für Abraham!"\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmdliii{Und sie strebten, ihm Böses zu tun, allein Wir machten sie zu den größten Verlierern.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmdliv{Und Wir retteten ihn und Lot in das Land, das Wir für die Welten gesegnet hatten.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmdlv{Und Wir schenkten ihm Isaak und dazu Jakob, und Wir machten jeden von ihnen rechtschaffen.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmdlvi{Und Wir machten sie zu Vorbildern, die auf unser Geheiß (die Menschen) rechtleiteten, und Wir gaben ihnen ein, Gutes zu tun, das Gebet zu verrichten und die Zakah zu entrichten. Und sie verehrten Uns allein.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmdlvii{Und Lot gaben Wir Weisheit und Wissen. Und Wir retteten ihn aus der Stadt, die Schändlichkeiten beging. Sie waren wahrlich ein ruchloses Volk und Empörer.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmdlviii{Und Wir ließen ihn in Unsere Barmherzigkeit eingehen; denn er war einer der Rechtschaffenen\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmdlix{wie auch Noah, als er vordem (zu Uns) rief; Wir erhörten ihn und retteten ihn und seine Angehörigen aus großer Drangsal.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmdlx{Und Wir halfen ihm gegen das Volk, das Unsere Zeichen verwarf. Sie waren wahrlich ein ruchloses Volk; so ertränkten Wir sie alle.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmdlxi{Und David und Salomo richteten über den Acker, worin sich die Schafe eines Volkes zur Nachtzeit verliefen und weideten; und Wir waren Zeugen ihres Urteilspruches.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmdlxii{Wir gaben Salomo volle Einsicht in die Sache, und jedem (von ihnen) gaben Wir Weisheit und Wissen. Und Wir machten die Berge und die Vögel dienstbar, mit David zusammen (Allahs) Preis zu verkünden, und Wir konnten das tun.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmdlxiii{Und Wir lehrten ihn das Verfertigen eurer Panzerhemden, auf daß sie euch in eurem Kampf schützen mögen. Wollt ihr denn nicht dankbar sein?\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmdlxiv{Und Salomo (machten Wir) den Wind (dienstbar), der in seinem Auftrage in das Land blies, das Wir gesegnet hatten. Und Wir besitzen Kenntnis von allen Dingen\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmdlxv{und von den Satanen, die für ihn tauchten und dazu noch andere Werke verrichteten; und Wir Selbst beaufsichtigten sie.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmdlxvi{Und Hiob rief zu seinem Herrn: ``Unheil hat mich geschlagen, und Du bist der Barmherzigste aller Barmherzigen."\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmdlxvii{Da erhörten Wir ihn und nahmen sein Unheil hinweg, und Wir gaben ihm seine Familie (wieder) und noch einmal so viele dazu - aus Unserer Barmherzigkeit und als Ermahnung für die (Uns) Verehrenden.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmdlxviii{Und Ismael und Idris und Du-l-Kifl; sie alle zählten zu den Standhaften.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmdlxix{Und Wir ließen sie in Unsere Barmherzigkeit eingehen; denn sie gehörten zu den Rechtschaffenen.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmdlxx{Und Du-n-Nun ging im Zorn hinweg und war überzeugt, daß Wir ihn nie in Betrübnis bringen würden; und da rief er in der dichten Finsternis: ``Es ist kein Gott außer Dir. Gepriesen seist Du Ich bin wahrlich einer der Frevler gewesen."\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmdlxxi{Da erhörten Wir ihn und retteten ihn aus seiner Bedrängnis; und genauso retten Wir die Gläubigen.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmdlxxii{Und Zacharias rief zu seinem Herrn: ``Mein Herr, laß mich nicht einsam bleiben; denn Du bist der Beste der Erben."\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmdlxxiii{Da erhörten Wir ihn und schenkten ihm Jahya und heilten seine Frau. Sie pflegten miteinander in guten Taten zu wetteifern, und sie riefen Uns in Hoffnung und in Furcht an und waren demütig vor Uns.\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmdlxxiv{Und der die ihre Keuschheit wahrte, hauchten Wir von Unserem Geist ein und machten sie und ihren Sohn zu einem Zeichen für die Welten.\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmdlxxv{Diese eure Gemeinschaft ist eine einheitliche Gemeinschaft; und Ich bin euer Herr, darum dient Mir.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmdlxxvi{Sie aber sind untereinander zerstritten; alle werden sie zu Uns zurückkehren.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmdlxxvii{Das Bemühen dessen, der also gute Werke tut und gläubig ist, wird nicht unbelohnt bleiben. Wir werden es gewiß verzeichnen.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mmdlxxviii{Und für eine Stadt, die Wir zerstört haben, ist es unwiderruflich festgelegt, nicht zurückzukehren\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mmdlxxix{bis dann, wenn Gog und Magog freigelassen werden, und sie von allen Höhen herbeieilen.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mmdlxxx{Und die wahre Verheißung naht; siehe dann werden die Augen derer, die ungläubig waren, starr blicken: ``O wehe uns, wir haben in der Tat nicht daran gedacht; ja, wir waren Frevler!"\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mmdlxxxi{Wahrlich, ihr und das, was ihr statt Allah anbetet, seid Brennstoff der Gahannam. Dahin werdet ihr kommen müssen.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mmdlxxxii{Wären diese Götter gewesen, wären sie nicht dahin gekommen; doch sie müssen alle auf ewig darin bleiben.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mmdlxxxiii{Darin werden sie stöhnen; doch darin werden sie nicht hören können.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mmdlxxxiv{Diejenigen aber, an welche (Unsere Verheißung) eines herrlichen Lohns schon vordem ergangen ist, werden von ihr (der Hölle) weit entfernt sein\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mmdlxxxv{sie werden nicht den leisesten Laut von ihr hören, während sie auf ewig in dem verweilen, was ihre Seelen begehren.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mmdlxxxvi{Der größte Schrecken wird sie nicht betrüben, und die Engel werden ihnen entgegenkommen: ``Das ist euer Tag, der euch verheißen wurde."\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mmdlxxxvii{An dem Tage, da werden Wir den Himmel zusammenrollen, wie die Schriftrollen zusammengerollt werden. (So) wie Wir die erste Schöpfung begonnen haben, werden Wir sie wiederholen - bindend für Uns ist die Verheißung; wahrlich, Wir werden (sie) erfüllen.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mmdlxxxviii{Und Wir haben bereits nach der Ermahnung in dem Zabur geschrieben, daß das Land von Meinen rechtschaffenen Dienern beerbt wird.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mmdlxxxix{Hierin liegt wahrlich eine Botschaft für ein Volk, das (Allah) dient.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mmdxc{Und Wir entsandten dich nur aus Barmherzigkeit für alle Welten.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mmdxci{Sprich: `` Mir wird lediglich offenbart, daß euer Gott nur ein Einziger Gott ist! Wollt ihr euch denn nicht ergeben?"\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mmdxcii{Doch wenn sie (dir) den Rücken kehren, so sprich: ``lch habe euch die Kunde in gerechter Weise entboten und ich weiß nicht, ob nah oder ferne ist, was euch verheißen wird.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mmdxciii{Wahrlich, Er kennt, was in eurer Rede offenkundig ist, und Er weiß, was ihr verheimlicht.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mmdxciv{Und ich weiß nicht, ob es vielleicht nur eine Prüfung für euch oder ein Nießbrauch auf bestimmte Zeit ist."\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mmdxcv{Er sagte: ``Mein Herr, richte in Wahr heit. Und unser Herr ist der Allerbarmer, Dessen Hilfe gegen das, was ihr behauptet, anzuflehen ist."\qt@no{(112)}}
\qt@newcmd\qurantrans@de@mmdxcvi{\basmalahde O Ihr Menschen, fürchtet euren Herrn; denn das Beben der Stunde ist wahrlich etwas Gewaltiges.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmdxcvii{An dem Tage, da ihr es seht, wird jede Stillende ihren Säugling vergessen und jede Schwangere ihre Bürde abwerfen; und du wirst die Menschen trunken sehen, obwohl sie nicht trunken sind; aber die Strafe Allahs ist gewaltig.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmdxcviii{Und unter den Menschen ist manch einer, der ohne Wissen über Allah streitet und jedem in der Empörung hartnäckigen Satan folgt\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmdxcix{und über den beschlossen ist, daß, wer ihn zum Beschützer nimmt, von ihm irregeführt und zur Strafe des Höllenbrands geführt wird.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmdc{O ihr Menschen, wenn ihr über die Auferstehung im Zweifel seid, so (bedenkt,) daß Wir euch aus Erde erschaffen haben, dann aus einem Samentropfen, dann aus einem Blutklumpen, dann aus einem Klumpen Fleisch, teils geformt und teils ungeformt, auf daß Wir es euch deutlich machen. Und Wir lassen bis zu einem bestimmten Zeitpunkt in den Mutterschößen ruhen, was Wir wollen; dann bringen Wir euch als Kinder hervor; dann (lassen Wir euch groß werden,) auf daß ihr eure Vollkraft erreicht. Und mancher von euch wird abberufen, und mancher von euch wird zu einem hinfälligen Greisenalter geführt, so daß er, nachdem er gewußt hatte, nichts mehr weiß. Und du siehst die Erde leblos, doch wenn Wir Wasser über sie niedersenden, dann regt sie sich und schwillt und läßt alle Arten von entzückenden Paaren hervorsprießen.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmdci{Dies (ist so), weil Allah die Wahrheit ist und weil Er es ist, Der die Toten lebendig macht, und weil Er die Macht über alles hat\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmdcii{und weil die Stunde kommt - darüber herrscht kein Zweifel - und weil Allah alle erwecken wird, die in den Gräbern ruhen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmdciii{Und unter den Menschen ist manch einer, der ohne Wissen oder Führung oder ein erleuchtendes Buch über Allah streitet.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmdciv{Dem, der sich hochmütig von Allahs Weg abwendet, ist Schande im Diesseits bestimmt; und am Tage der Auferstehung werden Wir ihn die Strafe des Verbrennens kosten lassen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmdcv{``Dies ist für das, was deine Hände vorausgeschickt haben: denn Allah ist nicht ungerecht gegen Seine Diener."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmdcvi{Und unter den Menschen ist manch einer, der Allah nur am Rande dient. Wenn ihn Gutes trifft, so ist er damit zufrieden; trifft ihn aber eine Prüfung, dann kehrt er zu seinem (früheren) Weg zurück. Er verliert diese Welt so gut wie die künftige. Das ist der deutliche Verlust.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmdcvii{Er ruft statt Allah das an, was ihm weder zu schaden noch zu nutzen vermag. Dies ist der weitbegangene Irrtum.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmdcviii{Er ruft den an, dessen Schaden näher ist als sein Nutzen. Übel ist wahrlich der Beschützer und übel ist wahrlich der Gefährte.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmdcix{Wahrlich, Allah wird jene, die glauben und gute Werke tun, in Gärten führen, durch die Bäche fließen; siehe, Allah tut, was Er will.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmdcx{Wer da meint, daß Allah ihm niemals im Diesseits und im Jenseits helfen werde, der soll doch mit Hilfe eines Seils zum Himmel emporsteigen und es abschneiden. Dann soll er sehen, ob seine List das hinweg nehmen wird, was (ihn) erzürnt.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmdcxi{Und so haben Wir ihn (den Quran) als deutliches Zeichen hinabgesandt, und gewiß, Allah weist dem den Weg, dem Er will.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmdcxii{Siehe, zwischen denen, die gläubig sind, und den Juden und den Sabäern und den Christen und den Magiern und den Götzendienern wird Allah wahrlich am Tage der Auferstehung richten; denn Allah ist der Zeuge aller Dinge.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmdcxiii{Hast du nicht gesehen, daß sich vor Allah anbetend niederwirft, wer in den Himmeln und auf Erden ist - ebenso die Sonne und der Mond und die Sterne und die Berge und die Bäume und die Tiere und viele Menschen? Vielen aber ist die Strafe fällig geworden. Und wer von Allah erniedrigt wird, dem kann keiner Ehre geben. Wahrlich, Allah tut, was Er will.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmdcxiv{Diese beiden sind zwei Streitende, die über ihren Herrn hadern. Für die, die nun ungläubig sind, werden Kleider aus Feuer zurechtgeschnitten werden; siedendes Wasser wird über ihre Köpfe gegossen werden\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmdcxv{wodurch das, was in ihren Bäuchen ist, und ihre Haut schmelzen wird.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmdcxvi{Und ihnen sind eiserne Keulen bestimmt.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmdcxvii{Sooft sie aus Bedrängnis daraus zu entrinnen streben, sollen sie wieder dahin zurückgetrieben werden; und (es heißt): ``Kostet die Strafe des Verbrennens."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmdcxviii{Doch Allah wird jene, die gläubig sind und gute Werke tun, in Gärten führen, durch welche Bäche fließen. Sie sollen darin mit Annspangen von Gold und Perlen geschmückt sein, und ihre Gewänder darin sollen aus Seide sein.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmdcxix{Und sie werden zu lauterster Rede rechtgeleitet werden, und sie werden zu dem Weg des Preiswürdigen rechtgeführt werden.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmdcxx{Diejenigen aber, die ungläubig sind und vom Weg Allahs abhalten und von der heiligen Moschee - die Wir zum Wohl aller Menschen bestimmt haben, gleichviel ob sie dort angesiedelt oder Wüstenbewohner sind -, und diejenigen, die hier durch Ruchlosigkeit irgendeinen krummen Weg suchen: Wir werden sie schmerzliche Strafe kosten lassen.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmdcxxi{Und als Wir für Abraham die Stätte des Hauses bestimmten (, sprachen Wir): ``Setze Mir nichts zur Seite und halte Mein Haus rein für die (es) Umkreisenden, Betenden und Sich-Niederwerfenden.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmdcxxii{Und rufe die Menschen zur Pilgerfahrt auf. Sie werden zu Fuß und auf jedem mageren Kamel aus allen entfernsten Gegenden zu dir kommen\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmdcxxiii{auf daß sie allerlei Vorteile wahrnehmen und während einer bestimmten Anzahl von Tagen des Namens Allahs für das gedenken mögen, was Er ihnen an Vieh gegeben hat. Darum esset davon und speist den Notleidenden, den Bedürftigen.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmdcxxiv{Dann sollen sie ihre persönliche Reinigung vollziehen und ihre Gelübde erfüllen und um das Altehrwürdige Haus wandeln."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmdcxxv{Somit wird es für den, der die Gebote Allahs ehrt, gut vor seinem Herrn sein. Erlaubt ist euch alles Vieh mit Ausnahme dessen, was euch angesagt worden ist. Meidet darum den Greuel der Götzen und meidet das Wort der Lüge.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmdcxxvi{Seid lauter gegen Allah, ohne daß ihr Ihm etwas zur Seite stellt. Und wer Allah etwas zur Seite stellt, ist (so), als fiele er vom Himmel und die Vögel erhaschten ihn oder der Wind verwehte ihn an einen fernen Ort.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmdcxxvii{Somit rührt das wahrlich von der Gottesfürchtigkeit der Herzen her, wenn einer die Gebote Allahs ehrt.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmdcxxviii{Die (Opfertiere) bringen euch Nutzen für eine bestimmte Frist, dann aber ist ihr (Opfer-)Platz bei dem Altehrwürdigen Haus.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmdcxxix{Und jedem Volk gaben Wir eine Anleitung zur Opferung, auf daß sie des Namens Allahs für das gedenken mögen, was Er ihnen an Vieh gegeben hat. So ist euer Gott ein Einziger Gott; darum ergebt euch Ihm. Und die frohe Botschaft gib den Demütigen\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmdcxxx{; deren Herzen mit Furcht erfüllt sind, wenn Allah erwähnt wird, und die geduldig ertragen, was sie trifft, und die das Gebet verrichten und von dem spenden, was Wir ihnen gegeben haben.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmdcxxxi{Und für den Opferbrauch Allahs haben Wir für euch die großen Kamele bestimmt. An ihnen habt ihr viel Gutes. So sprecht den Namen Allahs über sie aus, wenn sie gereiht dastehen. Und wenn ihre Seiten (auf dem Boden) liegen, so esset davon und speist den Genügsamen und den Bittenden. So haben Wir sie euch dienstbar gemacht, auf daß ihr dankbar sein möget.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmdcxxxii{Ihr Fleisch erreicht Allah nicht, noch tut es ihr Blut, sondern eure Ehrfurcht ist es, die Ihn erreicht. In der Weise hat Er sie euch dienstbar gemacht, auf daß ihr Allah für Seine Rechtleitung preiset. Und gib denen frohe Botschaft, die Gutes tun.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmdcxxxiii{Wahrlich, Allah verteidigt jene, die gläubig sind. Gewiß, Allah liebt keinen Treulosen, Undankbaren.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmdcxxxiv{Die Erlaubnis (, sich zu verteidigen,) ist denen gegeben, die bekämpft werden, weil ihnen Unrecht geschah - und Allah hat wahrlich die Macht, ihnen zu helfen -\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmdcxxxv{jenen, die schuldlos aus ihren Häusern vertrieben wurden, nur weil sie sagten: ``Unser Herr ist Allah." Und wenn Allah nicht die einen Menschen durch die anderen zurückgehalten hätte, so wären gewiß Klausen, Kirchen, Synagogen und Moscheen, in denen der Name Allahs oft genannt wird, niedergerissen worden. Und Allah wird sicher dem beistehen, der Ihm beisteht. Allah ist wahrlich Allmächtig, Erhaben.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmdcxxxvi{Jenen, die, wenn Wir ihnen auf Erden die Oberhand gegeben haben, das Gebet verrichten und die Zakah entrichten und Gutes gebieten und Böses verbieten (, steht Allah bei) Und Allah bestimmt den Ausgang aller Dinge.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmdcxxxvii{Wenn sie dich der Lüge bezichtigen, so waren schon vor ihnen das Volk Noahs und die `Ad und die Tamud Verleugner\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmdcxxxviii{sowie auch das Volk Abrahams und das Volk Lots\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmdcxxxix{und die Bewohner von Madyan. Auch Moses wurde der Lüge bezichtigt. Ich gewährte alsdann den Ungläubigen Aufschub; dann erfaßte Ich sie, und wie war es mit der Verleugnung!\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmdcxl{Wie so manche Stadt haben Wir zerstört, weil sie voll des Frevels war, daß sie nunmehr in Trümmern steht, und (wie so) manch verlassenen Brunnen und manch hochragendes Schloß (haben Wir zerstört)!\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmdcxli{Sind sie denn nicht im Lande umhergereist, so daß sie Herzen haben könnten, um zu begreifen, oder Ohren, um zu hören? Denn wahrlich, es sind ja nicht die Augen, die blind sind, sondern blind sind die Herzen in der Brust.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmdcxlii{Und sie fordern dich auf, die Strafe zu beschleunigen, doch Allah wird nie Sein Versprechen brechen. Wahrlich, ein Tag bei deinem Herrn ist gleich tausend Jahre nach eurer Zeitrechnung.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmdcxliii{Und manch einer Stadt gewährte Ich Aufschub, obgleich sie voll des Frevels war. Zuletzt aber erfaßte Ich sie, und zu Mir ist die Heimkehr.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmdcxliv{Sprich: ``O ihr Menschen, ich bin euch nur ein deutlicher Warner."\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmdcxlv{Für diejenigen die glauben und gute Werke tun, ist Vergebung und eine ehrenvolle Versorgung bereit.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmdcxlvi{Diejenigen aber, die gegen Unsere Zeichen eifern und (sie) zu besiegen versuchen - diese sind die Bewohner der Gahim.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmdcxlvii{Und Wir schickten vor dir keinen Gesandten oder Propheten, dem, wenn er etwas wünschte, Satan seinen Wunsch nicht (zu) beeinflussen (trachtete) Doch Allah macht zunichte, was Satan einstreut. Dann setzt Allah Seine Zeichen fest. Und Allah ist Allwissend, Allweise.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmdcxlviii{(Er läßt dies zu,) damit Er das, was Satan einstreut, zur Prüfung für die machen kann, in deren Herzen Krankheit ist und deren Herzen verhärtet sind; wahrlich, die Frevler befinden sich in äußerster Auflehnung.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmdcxlix{Und (Er läßt dies zu,) damit diejenigen, denen das Wissen gegeben wurde, erkennen, daß es die Wahrheit von deinem Herrn ist, auf daß sie daran glauben und ihre Herzen sich Ihm friedvoll unterwerfen mögen. Und siehe, Allah leitet jene, die gläubig sind, auf den geraden Weg.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmdcl{Und die Ungläubigen werden nicht (eher) aufhören, daran Zweifel zu hegen, bis die Stunde unerwartet über sie hereinbricht oder die Strafe eines unheilvollen Tages über sie kommt.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmdcli{Das Königreich wird an jenem Tage Allah gehören. Er wird zwischen ihnen richten. Also werden jene, die gläubig sind und gute Werke tun, in den Gärten der Wonne sein.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmdclii{Für diejenigen aber, die ungläubig sind und Unsere Zeichen verwerfen, ist eine Strafe (vorgesehen), die schmachvoll ist.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmdcliii{Und denjenigen, die um Allahs willen auswandern und dann erschlagen werden oder sterben, wird Allah eine stattliche Versorgung bereiten. Wahrlich, Allah - Er ist der beste Versorger.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmdcliv{Er wird sie gewiß in einen Ort eingehen lassen, mit dem sie wohl zufrieden sind. Und Allah ist wahrlich Allwissend, Nachsichtig.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmdclv{Das (soll so sein) Und dem, der Vergeltung in dem Maße übt, in dem ihm Unrecht zugefügt worden ist, und dann (wiederum) Unrecht erleidet -, dem wird Allah sicherlich zum Sieg verhelfen. Wahrlich, Allah ist Allvergebend, Allverzeihend.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmdclvi{Dies (geschieht) deshalb, weil Allah die Nacht in den Tag und den Tag in die Nacht übergehen läßt und weil Allah Allhörend, Allsehend ist.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmdclvii{Dies ist (so), weil Allah die Wahrheit ist, und (weil) das, was sie an Seiner Statt anrufen, die Lüge ist und weil Allah der Erhabene ist, der Große.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmdclviii{Hast du denn nicht gesehen, daß Allah Wasser vom Himmel herabsendet und (daß) die Erde grün wird? Allah ist wahrlich Gütig, Allkundig.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmdclix{Sein ist, was in den Himmeln und was auf der Erde ist, und Allah ist es, Der wahrlich auf keinen angewiesen ist, der Preiswürdige.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmdclx{Hast du denn nicht gesehen, daß Allah euch dienstbar gemacht hat, was auf Erden ist, und (daß) die Schiffe durcheilen das Meer auf Sein Geheiß? Und Er hält den Himmel zurück, damit er nicht auf die Erde fällt, es sei denn, mit Seiner Erlaubnis. Wahrlich, Allah ist Gütig und Barmherzig gegen die Menschen.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmdclxi{Und Er ist es, Der euch das Leben gab, und dann wird Er euch sterben lassen, und dann wird Er euch (wieder) lebendig machen. Wahrlich, der Mensch ist höchst undankbar.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmdclxii{Einem jeden Volke haben Wir Andachtsriten gegeben, die sie befolgen; sie sollen daher nicht mit dir über diese Sache streiten; sondern rufe (du sie) zu deinem Herrn. Wahrlich, du folgst der rechten Führung.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmdclxiii{Wenn sie jedoch mit dir hierüber streiten, so sprich: ``Allah weiß am besten, was ihr tut.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmdclxiv{Allah wird zwischen euch am Tage der Auferstehung über das richten, worüber ihr uneinig waret."\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmdclxv{Weißt du nicht, daß Allah das kennt, was im Himmel und was auf der Erde ist? Wahrlich, das steht in einem Buch, das ist für Allah ein Leichtes.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmdclxvi{Und sie verehren an Allahs Statt das, wofür Er keine Ermächtigung herabgesandt hat und wovon sie keine Kenntnis haben. Und für die Ungerechten gibt es keinen Helfer.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmdclxvii{Und wenn Unsere Verse ihnen verlesen werden, dann kannst du auf dem Antlitz derer, die ungläubig sind, Ablehnung wahrnehmen. Sie möchten am liebsten über die herfallen, die ihnen Unsere Verse verlesen. Sprich: ``Soll ich euch von etwas Schlimmerem als diesem Kunde geben? Dem Feuer! Allah hat es denen verheißen, die ungläubig sind. Und das ist eine üble Bestimmung!"\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmdclxviii{O ihr Menschen, ein Gleichnis ist geprägt, so hört darauf: Gewiß, jene, die ihr an Allahs Statt anruft, werden in keiner Weise vermögen, eine Fliege zu erschaffen, auch dann nicht, wenn sie sich dazu zusammentäten. Und wenn die Fliege ihnen etwas raubte, könnten sie es ihr nicht entreißen. Schwach ist der Suchende wie der Gesuchte.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmdclxix{Sie bewerten Allah nicht nach Seinem wahren Wert. Gewiß, Allah ist Stark, Erhaben.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmdclxx{Allah erwählt aus den Engeln Boten und (ebenfalls) aus den Menschen. Siehe, Allah ist Allhörend, Allsehend.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmdclxxi{Er weiß, was vor ihnen ist und was hinter ihnen ist; und zu Allah sollen alle Angelegenheiten zurückgebracht werden.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmdclxxii{O ihr, die ihr glaubt, verneigt euch und werft euch in Anbetung nieder und verehrt euren Herrn und tut das Gute, auf daß ihr Erfolg haben möget.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmdclxxiii{Und eifert in Allahs Sache, wie dafür geeifert werden soll. Er hat euch erwählt und hat euch nichts auferlegt, was euch in der Religion bedrücken könnte, der Religion eures Vaters Abraham. Er (Allah) ist es, Der euch vordem schon Muslime nannte und (nun) in diesem (Buche), damit der Gesandte Zeuge über euch sei und damit ihr Zeugen über die Menschen sein möget. Also verrichtet das Gebet und entrichtet die Zakah und haltet an Allah fest. Er ist euer Beschützer, ein vortrefflicher Beschützer und ein vortrefflicher Helfer!\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmdclxxiv{\basmalahde Wahrlich, erfolgreich sind die Gläubigen\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmdclxxv{die in ihren Gebeten voller Demut sind\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmdclxxvi{und die sich von allem leeren Gerede fernhalten\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmdclxxvii{und die die Zakah entrichten\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmdclxxviii{und ihre Schamteile bewahren\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmdclxxix{außer gegenüber ihren Gattinnen oder denen, die sie von Rechts wegen besitzen; denn dann sind sie nicht zu tadeln.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmdclxxx{Diejenigen aber, die darüber hinaus etwas begehren, sind Übertreter.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmdclxxxi{Und diejenigen, die das ihnen anvertraute Gut und ihre Verpflichtung hüten\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmdclxxxii{und die ihre Gebete einhalten\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmdclxxxiii{- dies sind die Erben\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmdclxxxiv{die Al-Firdaus erben werden. Auf ewig werden sie darin verweilen.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmdclxxxv{Und wahrlich, Wir erschufen den Menschen aus einer Substanz aus Lehm.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmdclxxxvi{Alsdann setzten Wir ihn als Samentropfen an eine sichere Ruhestätte.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmdclxxxvii{Dann bildeten Wir den Tropfen zu einem Blutklumpen; dann bildeten Wir den Blutklumpen zu einem Fleischklumpen; dann bildeten Wir aus dem Fleischklumpen Knochen; dann bekleideten Wir die Knochen mit Fleisch; dann entwickelten Wir es zu einer anderen Schöpfung. So sei denn Allah gepriesen, der beste Schöpfer.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmdclxxxviii{Dann, danach, werdet ihr mit Gewißheit sterben.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmdclxxxix{Dann werdet ihr am Tage der Auferstehung erweckt werden.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmdcxc{Und Wir haben wahrlich über euch sieben Himmelssphären geschaffen, und nie sind Wir gegen die Schöpfung unachtsam gewesen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmdcxci{Und Wir sandten Wasser vom Himmel in bestimmtem Maß nieder, und Wir ließen es in der Erde ruhen; und Wir vermögen es wieder hinwegzunehmen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmdcxcii{Dann haben Wir damit für euch Gärten mit Dattelpalmen und Beeren hervorgebracht; an ihnen habt ihr reichlich Früchte, und von ihnen esset ihr.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmdcxciii{Und (Wir haben) einen Baum (hervorgebracht), der aus dem Berge Sinai emporwächst; er gibt Öl und Würze für die Essenden.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmdcxciv{Und betrachtet das Vieh als Lehre für euch. Wir geben euch von dem zu trinken, was in ihren Leibern ist, und ihr habt von ihnen vielerlei Nutzen, und von ihnen esset ihr.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmdcxcv{Und auf ihnen wie auch in Schiffen werdet ihr getragen.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmdcxcvi{Und Wir sandten wahrlich Noah zu seinem Volk, und er sagte: ``O mein Volk, dient Allah. Ihr habt keinen anderen Gott außer Ihm. Wollt ihr also nicht gottesfürchtig sein?"\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmdcxcvii{Aber die Vornehmen seines Volks, die ungläubig waren, sagten: ``Er ist nur ein Mensch wie ihr; er möchte sich bloß über euch erheben. Hätte Allah gewollt, hätte Er doch gewiß Engel hinabsenden können. Wir haben nie von solchem unter unseren Vorvätern gehört.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmdcxcviii{Er ist nichts anderes als ein Mann, der unter Besessenheit leidet; wartet darum eine Weile mit ihm."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmdcxcix{Er sagte: ``Mein Herr, hilf mir wider ihre Beschuldigung der Lüge."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmdcc{So offenbarten Wir ihm: ``Baue das Schiff unter Unserer Aufsicht und gemäß Unserer Eingebung. Und wenn Unser Befehl ergeht und die Oberfläche der Erde (Wasser) hervorwallen läßt, dann nimm ein Paar von jeglicher Gattung an Bord sowie deine Angehörigen mit Ausnahme derer, gegen die das Wort bereits ergangen ist. Und sprich Mich nicht deretwegen an, die gefrevelt haben; denn sie werden ertränkt.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmdcci{Und wenn du dich auf dem Schiff eingerichtet hast - du und die, die bei dir sind -, dann sprich: ``Alles Lob gebührt Allah, Der uns vor dem ruchlosen Volk errettet hat!".\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmdccii{Und sprich: ``Mein Herr, gewähre mir eine gesegnete Unterkunft; denn Du bist der Beste, Der für die Unterkunft sorgt.""\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmdcciii{Wahrlich, hierin liegen Zeichen, und Wir stellen (euch) nur auf die Probe.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmdcciv{Dann ließen Wir nach ihnen andere Geschlechter entstehen.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmdccv{Alsdann sandten Wir ihnen einen Gesandten aus ihrer Mitte (, der sagte): ``Dient Allah. Ihr habt doch keinen anderen Gott als Ihn. Wollt ihr also nicht gottesfürchtig sein?"\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmdccvi{Und die Vornehmen seines Volks, die ungläubig waren und die Begegnung im Jenseits leugneten und denen Wir das Wohlleben des irdischen Lebens beschert hatten, sagten: ``Das ist nur ein Mensch wie ihr. Er ißt von dem, was ihr esset, und trinkt von dem, was ihr trinkt.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmdccvii{Und wenn ihr einem Menschen euresgleichen gehorcht, dann werdet ihr gewiß Verlierende sein.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmdccviii{Verheißt er euch etwa, daß ihr, wenn ihr tot seid und Staub und Gebeine geworden seid, wieder auferstehen werdet?\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmdccix{Weit, weit hergeholt ist das, was euch da verheißen wird!\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmdccx{Es gibt kein anderes Leben als unser Leben auf der Erde; wir sterben und wir leben, doch wir werden nicht wieder erweckt werden.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmdccxi{Er ist nur ein Mensch, der eine Lüge gegen Allah erdichtet hat; und wir wollen ihm nicht glauben."\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmdccxii{Er sagte: ``Mein Herr, hilf mir wider ihre Beschuldigung der Lüge."\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmdccxiii{Er sprach: ``In kurzer Zeit werden sie sicher reumütig werden."\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmdccxiv{Da erfaßte sie der Schrei nach Gerechtigkeit, und Wir machten sie zu Spreu. Verflucht sei denn das Volk, das Frevel begeht!\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmdccxv{Dann ließen Wir nach ihnen andere Geschlechter entstehen.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmdccxvi{Kein Volk kann seine festgesetzte Frist beschleunigen, noch kann es sie hinauszögern.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmdccxvii{Dann entsandten Wir Unsere Gesandten, einen nach dem anderen. Sooft ein Gesandter zu seinem Volke kam, ziehen sie ihn der Lüge. So ließen Wir sie einander folgen und machten ihr (Schicksal) zu (viel erzählten) Geschichten. Verflucht sei denn das Volk, das nicht glaubt!\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmdccxviii{Alsdann sandten Wir Moses und seinen Bruder Aaron mit Unseren Zeichen und einer klaren Vollmacht\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmdccxix{zu Pharao und seinen Vornehmen; doch sie wandten sich verächtlich ab; denn sie waren ein hochmütiges Volk.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmdccxx{Sie sagten: ``Sollen wir an zwei uns gleichen Menschen glauben, wo ihr Volk uns doch dienstbar ist?"\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmdccxxi{So ziehen sie beide der Lüge, und sie gehörten zu denen, die venichtet wurden.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmdccxxii{Und wahrlich, Wir gaben Moses das Buch, auf daß sie dem rechten Weg folgen mögen.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmdccxxiii{Und Wir machten den Sohn der Maria und seine Mutter zu einem Zeichen und gewährten ihnen Zuflucht zu einem Hügel mit einer grünen Fläche und einem fließenden Quell.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmdccxxiv{O ihr Gesandten, esset von den reinen Dingen und tut Gutes. Wahrlich, Ich weiß recht wohl, was ihr tut.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmdccxxv{Und diese eure Gemeinschaft ist eine einheitliche Gemeinschaft, und Ich bin euer Herr. So fürchtet Mich.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmdccxxvi{Aber sie wurden untereinander uneinig und spalteten sich in Parteien, und jede Partei freute sich über das, was sie selbst hatte.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmdccxxvii{Darum überlaß sie eine Zeitlang ihrer Unwissenheit.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmdccxxviii{Meinen sie denn, wenn Wir sie reichlich mit Glücksgütern und Söhnen versorgen\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmdccxxix{würden Wir Uns beeilen, ihnen Gutes zu tun? Nein, sie nehmen es nicht wahr.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmdccxxx{Wahrlich, jene, die sich aus Furcht vor ihrem Herrn Sorge tragen\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmdccxxxi{und jene, die an die Zeichen ihres Herrn glauben\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmdccxxxii{und jene, die ihrem Herrn nichts zur Seite stellen\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmdccxxxiii{und jene, die da spenden, was zu spenden ist, und jene, deren Herzen beben, weil sie zu ihrem Herrn zurückkehren werden\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmdccxxxiv{sie sind es, die sich bei guten Werken beeilen und ihnen darin voraus sind.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmdccxxxv{Und Wir fordern von keiner Seele etwas über das hinaus, was sie zu leisten vermag. Und Wir haben ein Buch, das die Wahrheit spricht; und es soll ihnen kein Unrecht geschehen.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmdccxxxvi{Nein, ihre Herzen beachten dieses (Buch) ganz und gar nicht, und außerdem gibt es da Tätigkeiten von ihnen, die sie fortführen\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmdccxxxvii{siehe, bis daß sie, wenn Wir die Wohlhabenden unter ihnen mit Strafe erfassen, um Hilfe rufen.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmdccxxxviii{``Schreit heute nicht um Hilfe; denn ihr werdet bei Uns keine Hilfe finden.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmdccxxxix{Meine Verse wurden euch doch verlesen, ihr aber pflegtet euch auf euren Fersen umzukehren\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmdccxl{hochmütig erwähntet ihr ihn (den Quran) und nachts meidet ihr ihn."\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmdccxli{Haben sie denn das Wort nicht bedacht, oder ist zu ihnen das gekommen, was nicht zu ihren Vorvätern kam?\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmdccxlii{Oder kennen sie ihren Gesandten nicht, so daß sie ihn verleugnen?\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmdccxliii{Oder sagen sie: ``Er ist ein Besessener?" Nein, er hat ihnen die Wahrheit gebracht, und die meisten von ihnen hassen die Wahrheit.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmdccxliv{Und wenn die Wahrheit sich nach ihren Begierden gerichtet hätte; wahrlich, die Himmel und die Erde und wer darin ist, wären in Unordnung gestürzt worden. Nein, Wir haben ihnen ihre Mahnung gebracht, doch von ihrer eigenen Mahnung kehren sie sich ab.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmdccxlv{Oder forderst du etwa von ihnen einen Lohn? Doch der Lohn deines Herrn ist besser; und Er ist der beste Versorger.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmdccxlvi{Und gewiß, du rufst sie zu einem geraden Weg auf.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmdccxlvii{Und jene, die nicht an das Jenseits glauben, weichen wahrlich von dem Weg ab.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmdccxlviii{Und hätten Wir Uns ihrer erbarmt und sie von ihrer Drangsal befreit, würden sie dennoch in ihrer Widerspenstigkeit verharren und verblendet in die Irre gehen.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmdccxlix{Und wahrlich, Wir haben sie mit Strafe erfaßt, doch sie haben sich ihrem Herrn weder unterworfen, noch haben sie sich gedemütigt\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmdccl{- bis daß Wir ihnen ein Tor zu strenger Strafe öffnen. Siehe, da werden sie hierüber in Verzweiflung stürzen.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmdccli{Und Er ist es, Der euch Ohren, Augen und Herzen geschaffen hat. Wie wenig dankbar seid ihr!\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmdcclii{Und Er ist es, Der euch auf der Erde vermehrt hat, und vor Ihm werdet ihr versammelt werden.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmdccliii{Und Er ist es, Der leben und sterben läßt, und in Seinen Händen ruht der Wechsel von Nacht und Tag. Wollt ihr es denn nicht begreifen?\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmdccliv{Nein, sie sagten aber, wie schon die Früheren sagten.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmdcclv{Sie sagten: ``Wie? Wenn wir gestorben und zu Staub und Gebein geworden sind, sollen wir dann wirklich aufer weckt werden?\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmdcclvi{Dies ist uns verheißen worden, uns und zuvor unseren Vätern. Das sind ja nichts als Fabeln der Früheren."\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmdcclvii{Sprich: ``Wessen ist die Erde, und (wessen,) wer auf ihr ist, wenn ihr es wisset?"\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmdcclviii{Sie werden sagen: ``Allah." Sprich: ``Wollt ihr denn nicht nachdenken?"\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmdcclix{Sprich: ``Wer ist der Herr der sieben Himmel und der Herr des Gewaltigen Throns?"\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmdcclx{Sie werden sagen: ``(Sie sind) Allahs." Sprich: ``Wollt ihr denn nicht gottesfürchtig sein?"\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmdcclxi{Sprich: ``Wer ist es in Dessen Hand die Herrschaft über alle Dinge ist, und Der Schutz gewährt, aber vor Dem es keinen Schutz gibt, wenn ihr es wisset?"\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmdcclxii{Sie werden sagen: ``(All dies ist) Allahs." Sprich: ``Wieso also seid ihr verblendet?"\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmdcclxiii{Doch Wir haben ihnen die Wahrheit gebracht, und wahrlich, sie leugnen (sie).\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmdcclxiv{Allah hat Sich keinen Sohn genommen, noch ist irgendein Gott neben Ihm: sonst würde jeder Gott mit sich fortgenommen haben, was er erschaffen hätte, und die einen von ihnen hätten sich sicher gegen die anderen erhoben. Gepriesen sei Allah (und Erhaben) über all das, was sie beschreiben!\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmdcclxv{(Er ist) der Kenner des Verborgenen und des Offenbaren! Erhaben ist Er darum über das, was sie Ihm beigesellen.\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmdcclxvi{Sprich: ``Mein Herr, wenn Du mich schauen lassen willst, was ihnen angedroht wird\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmdcclxvii{dann, mein Herr, setze mich nicht zu dem Volk der Frevler."\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mmdcclxviii{Und Wir haben wahrlich die Macht, dich schauen zu lassen, was Wir ihnen androhen.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mmdcclxix{Wehre das Böse mit dem ab, was das Beste ist. Wir wissen recht wohl, was für Dinge sie behaupten.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mmdcclxx{Und sprich: ``Mein Herr, ich nehme meine Zuflucht bei Dir vor den Einflüsterungen der Satane.\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mmdcclxxi{Und ich nehme meine Zuflucht bei Dir, mein Herr, damit sie sich mir nicht nähern."\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mmdcclxxii{Wenn dann der Tod an einen von ihnen herantritt, sagt er: ``Mein Herr, bringe mich zurück\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mmdcclxxiii{auf daß ich Gutes tue von dem, was ich unterlassen habe." Keineswegs, es ist nur ein Wort, das er ausspricht. Und hinter ihnen liegt eine Trennstrecke zurück bis zu dem Tage, an dem sie auferweckt werden.\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mmdcclxxiv{Wenn dann der Stoß in den Sur erfolgt ist, gibt es zwischen ihnen an jenem Tage keine Verwandtschaftsbande (mehr), und sie werden einander nicht befragen.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mmdcclxxv{Dann werden die, deren Waagschalen schwer sind, die Erfolgreichen sein.\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mmdcclxxvi{Jene aber, deren Waagschalen leicht sind, werden die sein, die ihrer selbst verlustig gegangen sind; in Gahannam werden sie auf ewig bleiben.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mmdcclxxvii{Das Feuer wird ihre Gesichter verbrennen, und sie werden darin mißgebildet sein.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mmdcclxxviii{``Wurden euch Meine Verse nicht verlesen, ohne daß ihr diese für Lüge erklärt habt?"\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mmdcclxxix{Sie werden sagen: ``Unser Herr, unsere Unseligkeit überkam uns, und wir waren ein irrendes Volk.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mmdcclxxx{Unser Herr, führe uns aus ihr (der Hölle) heraus. Wenn wir (zum Ungehorsam) zurückkehren, dann werden wir wahrlich Frevler sein."\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mmdcclxxxi{Er wird sprechen: ``Hinab mit euch darein, und redet nicht mit Mir.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mmdcclxxxii{Wahrlich, es gab eine Anzahl unter Meinen Dienern, die zu sagen pflegten: ``Unser Herr, wir glauben; vergib uns darum und erbarme Dich unser; denn Du bist der beste Erbarmer."\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mmdcclxxxiii{Ihr aber habt sie mit Spott behandelt, so sehr, daß sie euch Meine Ermahnung vergessen ließen, während ihr sie auslachtet.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mmdcclxxxiv{Ich habe sie heute belohnt; denn sie waren geduldig. Wahrlich, sie sind es, die den Sieg erreicht haben."\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mmdcclxxxv{Er wird sprechen: ``Wie viele Jahre verweiltet ihr auf Erden?"\qt@no{(112)}}
\qt@newcmd\qurantrans@de@mmdcclxxxvi{Sie sagen: ``Wir verweilten einen Tag oder den Teil eines Tages; doch frage diejenigen, die rechnen können."\qt@no{(113)}}
\qt@newcmd\qurantrans@de@mmdcclxxxvii{Er spricht: ``lhr verweiltet nur kurze Zeit, wenn ihr es nur wüßtet!\qt@no{(114)}}
\qt@newcmd\qurantrans@de@mmdcclxxxviii{Glaubtet ihr denn, Wir hätten euch in Sinnlosigkeit erschaffen, und ihr würdet nicht zu Uns zurückgebracht?"\qt@no{(115)}}
\qt@newcmd\qurantrans@de@mmdcclxxxix{Darum ist Allah, der Wahre König, Hoch Erhaben. Es ist kein Gott außer Ihm, dem Herrn des Würdigen Throns.\qt@no{(116)}}
\qt@newcmd\qurantrans@de@mmdccxc{Und wer neben Allah einen anderen Gott anruft, für den er keinen Beweis hat, der wird seinem Herrn Rechenschaft abzulegen haben. Wahrlich, die Ungläubigen haben kei nen Erfolg.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@mmdccxci{Und sprich: ``Mein Herr, vergib (uns) und habe Erbarmen (mit uns); denn Du bist der beste Erbarmer."\qt@no{(118)}}
\qt@newcmd\qurantrans@de@mmdccxcii{\basmalahde (Dies ist) eine Sura, die Wir hinabsandten und die Wir zum Gesetz erhoben, und worin Wir deutliche Zeichen offenbarten, auf das ihr ermahnt sein möget.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmdccxciii{Peitscht die Unzüchtige und den Unzüchtigen gegebenenfalls jeweils mit hundert Peitschenhieben aus; und lasset euch angesichts dieser Vorschrift Allahs nicht von Mitleid mit den beiden ergreifen, wenn ihr an Allah und an den Jüngsten Tag glaubt. Und eine Anzahl der Gläubigen soll ihrer Pein beiwohnen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmdccxciv{Ein Unzüchtiger darf nur eine Unzüchtige oder eine Götzendienerin heiraten, und eine Unzüchtige darf nur einen Unzüchtigen oder einen Götzendiener heiraten; den Gläubigen aber ist das verwehrt.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmdccxcv{Und denjenigen, die ehrbaren Frauen (Unkeuschheit) vorwerfen, jedoch nicht vier Zeugen (dafür) beibringen, verabreicht achtzig Peitschenhiebe. Und lasset ihre Zeugenaussage niemals gelten; denn sie sind es, die Frevler sind\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmdccxcvi{außer jenen, die es hernach bereuen und sich bessern; denn wahrlich, Allah ist Allvergebend, Barmherzig.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmdccxcvii{Und (was) jene (betrifft), die ihren Gattinnen (Ehebruch) vorwerfen und keine Zeugen (dafür) außer sich selber haben - von solchen Leuten soll die Aussage des Mannes allein (genügen), wenn er viermal bei Allah schwört, daß er die Wahrheit rede\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmdccxcviii{und (sein) fünfter (Eid) soll sein, daß der Fluch Allahs auf ihm lasten möge, falls er ein Lügner sei.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmdccxcix{Von ihr aber soll die Strafe abgewendet werden, wenn sie viermal den Schwur bei Allah leistet, daß er ein Lügner sei.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmdccc{Und (ihr) fünfter (Eid) soll sein, daß Allahs Zorn auf ihr lasten möge, falls er die Wahrheit rede.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmdccci{Wäre nicht Allahs Huld und Seine Barmherzigkeit über euch und wäre Allah nicht Viel vergebend, Allweise (, wäret ihr verloren gewesen)\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmdcccii{Diejenigen, welche die große Lüge vorbrachten, bilden eine Gruppe von euch. Glaubt nicht, dies sei übel für euch; im Gegenteil, es gereicht euch zum Guten. Jedem von ihnen soll die Sünde, die er begangen hat (, vergolten werden); und der von ihnen, der den Hauptanteil daran verschuldete, soll eine schwere Strafe erlei den.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmdccciii{Warum dachten die gläubigen Männer und die gläubigen Frauen, als ihr es hörtet, nichts Gutes von ihren eigenen Leuten und sagten: ``Das ist eine offenkundige Lüge?"\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmdccciv{Warum brachten sie dafür nicht vier Zeugen bei? Da sie keine Zeugen beigebracht haben sind sie es also, die vor Allah die Lügner sind.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmdcccv{Wäre nicht Allahs Huld und Seine Barmherzigkeit im Diesseits und im Jenseits über euch, hätte euch für das, worauf ihr euch einließt eine schwere Strafe getroffen.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmdcccvi{Als ihr es mit euren Zungen übernahmt und ihr mit eurem Mund das ausspracht, wovon ihr keine Kenntnis hattet, da hieltet ihr es für eine geringe Sache, während es vor Allah eine große war.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmdcccvii{Und warum sagtet ihr nicht, als ihr es hörtet: ``Es kommt uns nicht zu, darüber zu reden. Gepriesen seist Du! Dies ist eine arge Verleumdung?"\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmdcccviii{Allah ermahnt euch, nie wieder dergleichen zu begehen, wenn ihr Gläubige seid.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmdcccix{Und Allah erklärt euch die Gebote; denn Allah ist Allwissend, Allweise.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmdcccx{Wahrlich, jenen, die wünschen, daß sich Unzucht unter den Gläubigen verbreite, wird im Diesseits und im Jenseits eine schmerzliche Strafe zuteil sein. Und Allah weiß, und ihr wisset nicht.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmdcccxi{Und wäre nicht Allahs Huld und Seine Barmherzigkeit über euch, und wäre Allah nicht Gütig, Erbarmend (, wäret ihr zugrunde gegangen).\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmdcccxii{O ihr, die ihr glaubt, folgt nicht den Schritten des Satans. Und wer den Schritten des Satans folgt, der gebietet gewiß Schändliches und Unrechtes. Und wäre nicht über euch Allahs Huld und Seine Barmherzigkeit, nicht einer von euch wäre rein geworden; doch Allah macht rein, wen Er will. Und Allah ist Allhörend, Allwissend.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmdcccxiii{Und die unter euch, die Reichtum im Überfluß besitzen, sollen nicht schwören, den Anverwandten und den Bedürftigen und den auf Allahs Weg Ausgewanderten nichts zu geben. Sie sollen (vielmehr) vergeben und verzeihen. Wünscht ihr nicht, daß Allah euch vergebe? Und Allah ist Allvergebend, Barmherzig.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmdcccxiv{Diejenigen, welche den ehrbaren, unbedachten, gläubigen Frauen (Unkeuschheit) vorwerfen, sind im Diesseits und im Jenseits verflucht. Ihnen wird eine schwere Strafe zuteil sein\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmdcccxv{an dem Tage, wo ihre Zungen und ihre Hände und ihre Füße gegen sie das bezeugen werden, was sie getan haben.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmdcccxvi{An dem Tage wird Allah ihnen (alles) nach Gebühr heimzahlen, und sie werden erfahren, daß Allah allein die lautere Wahrheit ist.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmdcccxvii{Schlechte Frauen sind für schlechte Männer, und schlechte Männer sind für schlechte Frauen. Und gute Frauen sind für gute Männer, und gute Männer sind für gute Frauen; sie sind frei von all dem, was sie (die Verleumder) sagen. Auf sie wartet Vergebung und eine ehrenvolle Versorgung.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmdcccxviii{O ihr, die ihr glaubt, betretet keine anderen Wohnungen als die euren, bevor ihr nicht um Erlaubnis gebeten und ihre Bewohner gegrüßt habt. Das ist besser für euch, wenn ihr euch ermahnen lasset.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmdcccxix{Und wenn ihr niemanden darin findet, so tretet nicht eher ein, als bis euch die Erlaubnis (dazu) gegeben wird. Und wenn zu euch gesprochen wird: ``Kehrt um", dann kehrt um; das ist reiner für euch. Und Allah weiß wohl, was ihr tut.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmdcccxx{Es ist für euch keine Sünde, wenn ihr in unbewohnte Häuser eintretet, die euch von Nutzen sind. Und Allah weiß, was ihr kundtut und was ihr verbergt.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmdcccxxi{Sprich zu den gläubigen Männern, daß sie ihre Blicke zu Boden schlagen und ihre Keuschheit wahren sollen. Das ist reiner für sie. Wahrlich, Allah ist dessen, was sie tun, recht wohl kundig.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmdcccxxii{Und sprich zu den gläubigen Frauen, daß sie ihre Blicke zu Boden schlagen und ihre Keuschheit wahren und ihren Schmuck nicht zur Schau tragen sollen - bis auf das, was davon sichtbar sein darf, und daß sie ihren Schal um ihre Kleidungsausschnitte schlagen und ihren Schmuck vor niemand (anderem) enthüllen sollen als vor ihren Gatten oder Vätern oder den Vätern ihrer Gatten oder ihren Söhnen oder den Söhnen ihrer Gatten oder ihren Brüdern oder den Söhnen ihrer Brüder oder Söhnen ihrer Schwestern oder ihren Frauen oder denen, die sie von Rechts wegen besitzen, oder solchen von ihren männlichen Dienern, die keinen Geschlechtstrieb mehr haben, und den Kindern, die der Blöße der Frauen keine Beachtung schenken. Und sie sollen ihre Füße nicht so (auf den Boden) stampfen, daß bekannt wird, was sie von ihrem Schmuck verbergen. Und wendet euch allesamt reumütig Allah zu, o ihr Gläubigen, auf daß ihr erfolgreich sein möget.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmdcccxxiii{Und verheiratet diejenigen von euch, die ledig sind, und die guten unter euren Sklaven, männliche wie weibliche. Wenn sie arm sind, so wird Allah sie aus Seiner Fülle reich machen; denn Allah ist Allumfassend, Allwissend.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmdcccxxiv{Und diejenigen, die keine (Gelegenheit) zur Ehe finden, sollen sich keusch halten, bis Allah sie aus Seiner Fülle reich macht. Und jene, die ihr von Rechts wegen besitzt - wenn welche von ihnen eine Freilassungsurkunde begehren, (so) stellt sie ihnen aus, falls ihr von ihnen Gutes wisset; und gebt ihnen von Allahs Reichtum, den Er euch gegeben hat. Und zwingt eure Sklavinnen nicht zur Prostitution, wenn sie ein ehrbares Leben führen wollen, nur um die Güter des irdischen Lebens zu erlangen. Werden sie aber (zur Prostitution) gezwungen, dann wird Allah gewiß nach ihrem erzwungenen Tun Allvergebend und Barmherzig (zu ihnen) sein.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmdcccxxv{Und wahrlich, Wir haben euch deutliche Zeichen niedergesandt und das Beispiel derer, die vor euch dahingingen, und eine Ermahnung für die Gottesfürchtigen.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmdcccxxvi{Allah ist das Licht der Himmel und der Erde. Sein Licht ist gleich einer Nische, in der sich eine Lampe befindet: Die Lampe ist in einem Glas; das Glas gleich einem funkelnden Stern. Angezündet (wird die Lampe) von einem gesegneten Ölbaum, der weder östlich noch westlich ist, dessen Öl beinahe leuchten würde, auch wenn das Feuer es nicht berührte. Licht über Licht. Allah leitet zu Seinem Licht, wen Er will. Und Allah prägt Gleichnisse für die Menschen, und Allah kennt alle Dinge.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmdcccxxvii{(Es ist) in Häusern, für die Allah die Erlaubnis erteilte, sie sollen errichtet werden und Sein Name soll darin verkündet werden. Darin preisen (sie) Ihn am Morgen und am Abend\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmdcccxxviii{- Männer, die weder Ware noch Handel vom Gedenken an Allah abhält und der Verrichtung des Gebets und dem Entrichten der Zakah; sie fürchten einen Tag, an dem sich Herzen und Augen verdrehen werden.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmdcccxxix{Damit Allah sie belohne für die besten ihrer Taten und ihnen reichlich gebe aus Seiner Fülle. Und Allah versorgt ja, wen Er will, ohne zu rechnen.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmdcccxxx{Die aber ungläubig sind - ihre Taten sind wie eine Luftspiegelung in einer Ebene: Der Dürstende hält sie für Wasser, bis er, wenn er hinzutritt, sie als Nichts vorfindet. Doch nahebei findet er Allah, Der ihm seine Abrechnung vollzieht; und Allah ist schnell im Abrechnen.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmdcccxxxi{Oder (die Ungläubigen sind) wie Finsternisse in einem tiefen Meer: Eine Woge bedeckt es, über ihr ist (noch) eine Woge, darüber ist eine Wolke; Finsternisse, eine über der anderen. Wenn er seine Hand ausstreckt, kann er sie kaum sehen; und wem Allah kein Licht gibt - für den ist kein Licht.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmdcccxxxii{Hast du nicht gesehen, daß Allah es ist, Den alle lobpreisen, die in den Himmeln und auf Erden sind, und sogar die Vögel im Schwebeflug? Jedes (Geschöpf) kennt seine eigene (Weise von) Gebet und Lobpreisung. Und Allah weiß wohl, was sie tun.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmdcccxxxiii{Und Allahs ist das Königreich der Himmel und der Erde, und zu Allah ist die Heimkehr.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmdcccxxxiv{Hast du nicht gesehen, daß Allah die Wolken einhertreibt, sie dann zusammenfügt, sie dann aufeinander schichtet, so daß du Regen aus ihrer Mitte hervorströmen siehst? Und Er sendet vom Himmel Berge (von Wolken) nieder, in denen Hagel ist, und Er trifft damit, wen Er will, und wendet ihn ab, von wem Er will. Der Glanz Seines Blitzes nimmt fast das Augenlicht.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmdcccxxxv{Allah läßt die Nacht und den Tag wechseln. Hierin liegt wahrlich eine Lehre für solche, die sehen können.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmdcccxxxvi{Und Allah hat jedes Lebewesen aus Wasser erschaffen. Unter ihnen sind manche, die auf ihren Bäuchen kriechen, und unter ihnen sind manche, die auf zwei Beinen gehen, und unter ihnen sind manche, die sich auf vieren fortbewegen. Allah schafft, was Er will. Wahrlich, Allah hat Macht über alle Dinge.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmdcccxxxvii{Wahrlich, Wir haben deutliche Zeichen herabgesandt. Und Allah leitet, wen Er will, auf den geraden Weg.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmdcccxxxviii{Und sie sagen: ``Wir glauben an Allah und an den Gesandten, und wir gehorchen." Hierauf aber wenden sich einige von ihnen ab. Und dies sind keine Gläubigen.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmdcccxxxix{Und wenn sie zu Allah und Seinem Gesandten gerufen werden, damit er zwischen ihnen richte, siehe, dann wendet sich eine Gruppe von ihnen ab.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmdcccxl{Doch wenn das Recht auf ihrer Seite ist, dann kommen sie zu ihm in aller Unterwürfigkeit gelaufen.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmdcccxli{Ist Krankheit in ihren Herzen? Oder zweifeln sie, oder fürchten sie, daß Allah und Sein Gesandter ungerecht gegen sie sein würden? Nein, sie sind es selbst, die Unrecht begehen.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmdcccxlii{Doch die Rede der Gläubigen, wenn sie zu Allah und Seinem Gesandten gerufen werden, damit Er zwischen ihnen richten möge, ist nichts anderes als: ``Wir hören und wir gehorchen." Und sie sind es, die Erfolg haben werden.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmdcccxliii{Und wer Allah und Seinem Gesandten gehorcht und Allah fürchtet und sich vor Ihm in acht nimmt: solche sind es, die glückselig sind.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmdcccxliv{Und sie schwören bei Allah ihre festen Eide, sie würden, wenn du es ihnen beföhlest, gewiß ausziehen. Sprich: ``Schwört nicht! Euer Gehorsam ist (uns) bekannt!" Wahrlich, Allah ist dessen wohl kundig, was ihr tut.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmdcccxlv{Sprich: ``Gehorcht Allah und gehorcht dem Gesandten." Doch wenn ihr euch (von ihm) abkehrt, dann ist er nur für das verantwortlich, was ihm auferlegt wurde, und ihr seid nur für das verantwortlich, was euch auferlegt wurde. Und wenn ihr ihm gehorcht, so werdet ihr dem rechten Weg folgen. Und dem Gesandten obliegt nur die deutliche Verkündigung.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmdcccxlvi{Verheißen hat Allah denen, die von euch glauben und gute Werke tun, daß Er sie gewiß zu Nachfolgern auf der Erde machen wird, wie Er jene, die vor ihnen waren, zu Nachfolgern machte; und daß Er gewiß für sie ihre Religion befestigen wird, die Er für sie auserwählt hat; und daß Er gewiß ihren (Stand) nach ihrer Furcht in Frieden und Sicherheit verwandeln wird, auf daß sie Mich verehren (und) Mir nichts zur Seite stellen. Wer aber hernach undankbar ist, wird ein Frevler sein.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmdcccxlvii{Und verrichtet das Gebet und entrichtet die Zakah und gehorcht dem Gesandten, auf daß ihr Barmherzigkeit empfangen möget.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmdcccxlviii{Denke nicht, die, die da ungläubig sind, könnten (ihm) auf Erden entrinnen; ihre Herberge ist das Feuer; und das ist wahrlich ein schlimmes Ende!\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmdcccxlix{O ihr, die ihr glaubt, es sollen (sogar) die, die ihr von Rechts wegen besitzt, und die unter euch, die noch nicht die Reife erlangt haben, euch zu drei Zeiten um Erlaubnis bitten: vor dem Morgengebet, und dann, wenn ihr eure Kleider wegen der Mittagshitze ablegt, und nach dem Abendgebet - (denn dies sind) für euch drei Zeiten der Zurückgezogenheit. Danach ist es für euch und für sie keine Sünde, wenn die einen von euch sich um die anderen kümmern. So macht euch Allah die Zeichen klar, und Allah ist Allwissend, Allweise.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmdcccl{Und wenn die Kinder unter euch ihre Reife erlangen, dann sollen (auch) sie um Erlaubnis bitten, gerade so wie die, die vor ihnen um Erlaubnis gebeten haben. So macht euch Allah Seine Zeichen klar; denn Allah ist Allwissend, Allweise.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmdcccli{(Was nun) die älteren Frauen (betrifft), die nicht mehr auf Heirat hoffen können, so trifft sie kein Vorwurf, wenn sie ihre Tücher ablegen, ohne ihre Zierde zur Schau zu stellen. Aber wenn sie sich dessen enthalten, ist das besser für sie. Und Allah ist Allhörend, Allwissend.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmdccclii{Kein Vorwurf trifft den Blinden, noch trifft ein Vorwurf den Gehbehinderten, kein Vorwurf trifft den Kranken oder euch selbst, wenn ihr in euren eigenen Häusern esset oder den Häusern eurer Väter oder den Häusern eurer Mütter oder den Häusern eurer Brüder oder den Häusern eurer Schwestern oder den Häusern eurer Vatersbrüder oder den Häusern eurer Vatersschwestern oder den Häusern eurer Mutterbrüder oder den Häusern eurer Mutterschwestern oder in einem (Haus), dessen Schlüssel in eurer Obhut sind, oder (in dem Haus) eures Freundes. Es ist keine Sünde für euch, ob ihr nur zusammen oder getrennt esset. Doch wenn ihr in Häuser eintretet, so begrüßt einander mit einem gesegneten, lauteren Gruß von Allah. So macht euch Allah die Gebote klar, auf daß ihr (sie) begreifen möget.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmdcccliii{Nur diejenigen sind Gläubige, die an Allah und an Seinen Gesandten glauben, und diejenigen, die, wenn sie in einer für alle wichtigen Angelegenheit bei ihm sind, nicht eher fortgehen, als sie ihn um Erlaubnis (dazu) gebeten haben. Die, die dich um Erlaubnis bitten, sind diejenigen, die (wirklich) an Allah und Seinen Gesandten glauben. Wenn sie dich also um Erlaubnis für irgendeine eigene Angelegenheit bitten, so erteile dem von ihnen die Erlaubnis, dem du willst, und bitte Allah für sie um Verzeihung. Wahrlich, Allah ist Allverzeihend, Barmherzig.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmdcccliv{Erachtet nicht den Ruf des Gesandten unter euch als dem Ruf des einen oder anderen von euch gleichrangig. Allah kennt diejenigen unter euch, die sich hinwegstehlen, indem sie sich verstecken. So mögen sich die, die sich seinem Befehl widersetzen, (davor) hüten, daß sie nicht Drangsal befalle oder eine schmerzliche Strafe treffe.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmdccclv{Ist es nicht so, daß Allahs ist, was in den Himmeln und auf der Erde ist? Er kennt euren Zustand wohl. Und an dem Tage, wo sie zu Ihm zurückgebracht werden, da wird Er ihnen verkünden, was sie getan haben! Und Allah weiß alle Dinge wohl.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmdccclvi{\basmalahde Voller Segen ist Er, Der die Unterscheidung zu Seinem Diener hinabgesandt hat, auf daß er ein Warner für die Welten sei.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmdccclvii{Er (ist es), Dessen das Königreich der Himmel und der Erde ist, Der Sich keinen Sohn genommen hat und Der keinen Partner im Königreich hat und Der jegliches Ding erschaffen und ihm das rechte Maß gegeben hat.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmdccclviii{Und doch haben sie sich Götter außer Ihm genommen, die nichts erschaffen haben, sondern selbst erschaffen worden sind, die weder für sich selber Macht über Schaden und Nutzen noch Macht über Leben und Tod und Auferweckung haben.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmdccclix{Und jene, die ungläubig sind, sagen: ``Dies ist ja nichts als eine Lüge, die er erdichtet hat; und andere Leute haben ihm dabei geholfen." Wahrlich, sie haben da Ungerechtigkeiten und Lügen vorgebracht.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmdccclx{Und sie sagen: ``(Das sind) Fabeln der Früheren: er hat sie aufschreiben lassen, und sie werden ihm am Morgen und am Abend diktiert."\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmdccclxi{Sprich: ``Er, Der das Verborgene von Himmel und Erde kennt, hat ihn herabgesandt. Er ist wahrlich Allverzeihend, Barmherzig."\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmdccclxii{Und sie sagen: ``Was ist mit diesem Gesandten, daß er Speise ißt und auf den Märkten umhergeht? Warum ist kein Engel zu ihm herabgesandt worden, um als Warner bei ihm zu sein?\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmdccclxiii{Oder (warum ist) ihm kein Schatz herabgeworfen oder kein Garten gegeben worden, wovon er essen könnte?" Und die Ungerechten sagen: ``lhr folgt nur einem Mann, der einem Zauber zum Opfer gefallen ist."\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmdccclxiv{Schau, wie sie dir Gleichnisse prägen! Sie sind irregegangen und vermögen keinen (Ausweg) zu finden.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmdccclxv{Voller Segen ist Er, Der, wenn Er will, dir Besseres als all dies gewähren wird - Gärten, durch die Bäche fließen - und dir (auch) Paläste geben wird.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmdccclxvi{Nein, sie leugnen die Stunde; und denen, welche die Stunde leugnen, haben Wir einen Höllenbrand bereitet.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmdccclxvii{Wenn er sie aus der Ferne wahrnimmt, werden sie hören, wie er grollt und laut aufheult.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmdccclxviii{Und wenn sie zusammengekettet in den engen Raum (des Feuers) geworfen werden, dann werden sie dort die Vernichtung wünschen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmdccclxix{``Wünscht heute nicht nur einmal die Vernichtung, sondern wünscht die Vernichtung mehrere Male!"\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmdccclxx{Sprich: ``Ist dies nun besser oder das Paradies der Ewigkeit, das den Gerechten verheißen wurde? Es wird ihre Belohnung und Bestimmung sein."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmdccclxxi{Darin werden sie haben, was immer sie begehren, (und sie werden) auf ewig (darin) verweilen. Dies ist eine Verheißung, die bindend für deinen Herrn ist.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmdccclxxii{Und an dem Tage, da Er sie und jene, die sie an Allahs Statt verehren, versammeln wird, da wird Er fragen: ``Waret ihr es, die Meine Diener irregeführt habt, oder sind sie (von) selbst von dem Weg abgeirrt?"\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmdccclxxiii{Sie werden sagen: ``Preis Dir! Es geziemte uns nicht, andere Beschützer als Dich anzunehmen; Du aber beschertest ihnen und ihren Vätern die guten Dinge (dieses Lebens), bis sie die Ermahnung vergaßen und ein verlorenes Volk wurden."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmdccclxxiv{``Nun haben sie euch für das, was ihr sagtet, der Lüge bezichtigt, und ihr könnt weder (die Strafe) abwenden noch (euch) helfen." Und den, der von euch Unrecht tut, werden Wir eine große Strafe kosten lassen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmdccclxxv{Auch vor dir schickten Wir keine Gesandten, die keine Speise aßen oder nicht auf den Märkten umhergingen. Allein, Wir machen die einen unter euch zur Prüfung für die anderen. Wollt ihr denn geduldig sein? Und dein Herr ist Allsehend.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmdccclxxvi{Und diejenigen, die nicht mit Unserer Begegnung rechnen, sagen: ``Warum werden keine Engel zu uns herniedergesandt? Oder (warum) sollten wir (nicht) unseren Herrn schauen?" Wahrlich, sie denken zu hoch von sich und haben die Schranken arg überschritten.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmdccclxxvii{Am Tage, wenn sie die Engel sehen: Keine frohe Botschaft (sei) für die Schuldigen an diesem Tage! Und sie werden sagen: ``Das sei verwehrt, verboten!"\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmdccclxxviii{Und Wir werden Uns den Werken zuwenden, die sie gewirkt haben, und werden sie wie verwehte Stäubchen zunichte machen.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmdccclxxix{Die Bewohner des Paradieses werden an jenem Tage die bessere Wohnstatt und den würdigeren Ruheplatz haben.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmdccclxxx{Und an dem Tage wird sich der Himmel mitsamt den Wolken spalten und die Engel werden ununterbrochen herabgesandt.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmdccclxxxi{Das Königreich, das wahrhaftige - an jenem Tage wird es des Allerbarmers sein; und ein Tag soll es sein, (der) schwer für die Ungläubigen (ist)\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmdccclxxxii{Am Tage, da der Ungerechte sich in die Hände beißen wird, da wird er sagen: `` O wäre ich doch den Weg mit dem Gesandten gegangen!\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmdccclxxxiii{O wehe mir! Hätte ich doch nimmermehr den Soundso zum Freund genommen!\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmdccclxxxiv{Wahrlich, er führte mich irre, hinweg von der Ermahnung, nachdem sie zu mir gekommen war." Und Satan läßt den Menschen im Stich.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmdccclxxxv{Und der Gesandte sagte: ``O mein Herr, mein Volk hat wirklich diesen Quran von sich gewiesen."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmdccclxxxvi{Und so gaben Wir jedem Propheten einen Feind aus den Reihen der Sünder; doch dein Herr genügt als Führer und als Helfer.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmdccclxxxvii{Und jene, die ungläubig sind, sagen: ``Warum ist ihm der Quran nicht in einem Zuge herabgesandt worden?" Dies (geschieht), weil Wir dein Herz dadurch stärken wollen, und Wir haben seine Anordnung recht gut gemacht.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmdccclxxxviii{Und sie legen dir keinen Einwand vor, ohne daß Wir die Wahrheit und die schönste Erklärung brächten.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmdccclxxxix{Diejenigen, die auf ihren Gesichtern in Gahannam versammelt werden - sie werden in der schlimmsten Lage und vom Wege am weitesten abgeirrt sein.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmdcccxc{Und wahrlich, Wir gaben Moses die Schrift, und zugleich haben Wir (ihm) seinen Bruder Aaron als Helfer zur Seite gestellt.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmdcccxci{Dann sprachen Wir: ``Geht beide zum Volk, das Unsere Zeichen verworfen hat": dann zerstörten Wir sie alle vollständig.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmdcccxcii{Und das Volk Noahs: Als sie die Gesandten verleugneten, ertränkten Wir sie und machten sie zu einem Zeichen für die Menschen. Und Wir haben für die Ungerechten eine schmerzliche Strafe bereitet.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmdcccxciii{Und so auch (für) die `Ad, die Tamud und die Leute vom Brunnen und so viele der Geschlechter zwischen ihnen.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmdcccxciv{Ihnen allen prägten Wir Gleichnisse; und sie alle zerstörten Wir vollständig.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmdcccxcv{Und wahrlich, sie kamen vorüber an der Stadt, auf die ein Unheilsregen niederging. Haben sie sie denn nicht gesehen? Nein, sie haben nicht mit der Auferstehung gerechnet.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmdcccxcvi{Und wenn sie dich sehen, treiben sie nur Spott mit dir: ``Ist das der, den Allah als Gesandten erweckt hat?\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmdcccxcvii{Wahrlich, er hätte uns beinahe irregeführt, hinweg von unseren Göttern, hätten wir nicht geduldig an ihnen festgehalten." Und sie werden erfahren, wenn sie die Strafe sehen, wer weiter vom Weg abgeirrt ist.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmdcccxcviii{Hast du den gesehen, der seine persönliche Neigung zu seinem Gott erhebt? Könntest du wohl sein Wächter sein?\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmdcccxcix{Meinst du etwa, daß die meisten von ihnen hörten oder verständen? Sie sind nur wie das Vieh - nein, sie sind noch weiter vom Weg abgeirrt.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmcm{Hast du nicht gesehen, wie dein Herr den Schatten verlängert? Und hätte Er gewollt hätte Er ihn stillstehen lassen. Dann haben Wir die Sonne zu seinem Wegweiser gemacht.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmcmi{Dann ziehen Wir ihn sachte zu Uns.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmcmii{Und Er ist es, Der euch die Nacht zu einer Verhüllung und den Schlaf zur Ruhe und den Tag zur Regsamkeit gemacht.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmcmiii{Und Er ist es, Der die Winde als Freudenboten Seiner Barmherzigkeit herabsendet; und Wir senden reines Wasser aus den Wolken nieder\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmcmiv{auf daß Wir damit ein totes Land lebendig machen und es Unserer Schöpfung zu trinken geben - dem Vieh und den Menschen in großer Zahl.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmcmv{Und Wir haben es (das Wasser) unter ihnen verteilt, um sie zu ermahnen. Die meisten Menschen jedoch lehnen alles ab, nur nicht den Unglauben.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmcmvi{Hätten Wir es gewollt, hätten Wir gewiß in jeder Stadt einen Warner erwecken können.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmcmvii{So gehorche nicht den Ungläubigen, sondern eifere mit ihm (dem Quran) in großem Eifer gegen sie.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmcmviii{Und Er ist es, Der den beiden Gewässern freien Lauf gelassen hat zu fließen das eine (ist) wohlschmeckend, süß, und das andere salzig, bitter; und zwischen ihnen hat Er eine Scheidewand und eine sichere Schranke gemacht\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmcmix{und Er ist es, Der den Menschen aus Wasser erschaffen hat und ihm Blutsverwandtschaft und Schwägerschaft gab; und All mächtig ist dein Herr.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmcmx{Dennoch verehren sie statt Allah das, was ihnen weder nützen noch schaden kann. Der Ungläubige ist ein Helfer gegen seinen Herrn.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmcmxi{Und Wir haben dich nur als Bringer froher Botschaft und als Warner gesandt.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmcmxii{Sprich: ``lch verlange von euch keinen Lohn dafür, nur (das eine:) daß jeder, der will, den Weg zu seinem Herrn einschlagen mag."\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmcmxiii{Und vertraue auf den Lebendigen, Der nicht stirbt, und preise Seine Lobenswürdigkeit. Es genügt, daß Er gegenüber den Sünden Seiner Diener ein Kenner ist.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmcmxiv{Er, Der die Himmel und die Erde und das, was zwischen beiden ist, in sechs Tagen erschuf, wandte Sich alsdann Seinem Reich zu. Der Allerbarmer: Befrage über Ihn einen, der Kenntnis (von Ihm) hat.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmcmxv{Und wenn zu ihnen gesprochen wird: ``Fallt vor dem Allerbarmer in Anbetung nieder!" sagen sie: ``Und was ist der Allerbarmer? Sollen wir vor irgend etwas in Anbetung niederfallen, nur weil du es uns befiehlst?" Und es verstärkt nur ihren Widerwillen.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmcmxvi{Voller Segen ist Er, Der Burgen im Himmel gemacht und eine Leuchte und einen scheinenden Mond darein gestellt hat.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmcmxvii{Und Er ist es, Der die Nacht und den Tag, die einander folgen, gemacht hat für einen, der (daran) denken oder (dafür) dankbar sein möge.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmcmxviii{Und die Diener des Allerbarmers sind diejenigen, die sanftmütig auf der Erde schreiten; und wenn die Unwissenden sie anreden, sprechen sie friedlich (zu ihnen)\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmcmxix{sie sind jene, die die Nacht dazu verbringen, um sich niederzuwerfen und zu beten.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmcmxx{Und sie sind es, die sagen: ``Unser Herr, wende von uns die Strafe der Gahannam ab; denn wahr lich, ihre Pein ist eine bedrückende Qual.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmcmxxi{Sie ist wahrlich schlimm als Ruhestatt und als Aufenthalt."\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmcmxxii{Und die, die, wenn sie spenden, weder verschwenderisch noch geizig sind; dazwischen gibt es einen Mittelweg.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmcmxxiii{Und die, welche keinen anderen Gott außer Allah anrufen und niemanden töten, dessen Leben Allah unverletzlich gemacht hat - es sei denn, (sie töten) dem Recht nach -, und keine Unzucht begehen: und wer das aber tut, der soll dafür zu büßen haben.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmcmxxiv{Verdoppelt soll ihm die Strafe am Tage der Auferstehung werden, und er soll darin auf ewig in Schmach bleiben\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmcmxxv{außer denen, die bereuen und glauben und gute Werke tun; denn deren böse Taten wird Allah in gute umwandeln; und Allah ist ja Allverzeihend, Barmherzig.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmcmxxvi{Und der, der bereut und Gutes tut, der wendet sich in wahrhafter Reue Allah zu.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmcmxxvii{Und diejenigen, die nichts Falsches bezeugen, und die, wenn sie un terwegs leeres Gerede hören, mit Würde (daran) vorbeigehen.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmcmxxviii{Und diejenigen, die, wenn sie mit den Zeichen ihres Herrn ermahnt werden, deswegen nicht wie taub und blind daraufstürzen.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmcmxxix{Und diejenigen, welche sagen: ``Unser Herr, gewähre uns an unseren Frauen und Kindern Augentrost und mache uns zu einem Vorbild für die Gottesfürchtigen."\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmcmxxx{Diese werden mit der höchsten Stätte (im Paradies) belohnt, weil sie geduldig waren; und Gruß und Frieden werden sie dort empfangen.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmcmxxxi{Ewig darin verweilend: herrlich ist es als Ruhestatt und als Aufenthalt.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmcmxxxii{Sprich: ``Was kümmert Sich mein Herr um euch, wenn ihr nicht (zu Ihm) betet? Ihr habt (Ihn) ja geleugnet, und das wird (euch) nun anhaften."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmcmxxxiii{\basmalahde Ta' Sin Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmcmxxxiv{Das sind die Verse des deutlichen Buches.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmcmxxxv{Vielleicht grämst du dich noch zu Tode darüber, daß sie nicht glauben.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmcmxxxvi{Wenn Wir wollen können Wir ihnen ein Zeichen vom Himmel niedersenden, so daß ihre Nacken sich demütig davor beugen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmcmxxxvii{Aber nie kommt zu ihnen eine neue Ermahnung vom Aller barmer, ohne daß sie sich davon abkehren.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmcmxxxviii{Sie haben tatsächlich (die Ermahnung) verworfen; bald aber wird von dem Kunde zu ihnen kommen, was sie verspotteten.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmcmxxxix{Haben sie nicht die Erde betrachtet wieviel Wir auf ihr von jeglicher herrlichen Gattung wachsen ließen?\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmcmxl{Darin liegt wahrlich ein Zeichen; jedoch die meisten von ihnen glauben es nicht.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmcmxli{Und dein Herr: Er ist wahrlich der Allmächtige, der Barmherzige.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmcmxlii{Und da rief dein Herr Moses an: ``Geh zu dem Volk der Ungerechten\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmcmxliii{dem Volke Pharaos. Wollen sie denn nicht gottesfürchtig sein?"\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmcmxliv{Er sagte: ``Mein Herr, ich fürchte, sie werden mich für einen Lügner halten\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmcmxlv{und meine Brust wird beklemmt, und meine Zunge den Redefluß versagt. Schicke darum zu Aaron.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmcmxlvi{Auch haben sie eine Schuldklage gegen mich erhoben, deshalb fürchte ich, daß sie mich umbringen."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmcmxlvii{Er sprach: ``Keineswegs! Geht nur beide mit Unseren Zeichen hin. Wir sind mit euch; Wir werden mit euch zuhören.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmcmxlviii{Geht denn zu Pharao und sagt: ``Wir beide sind die Boten des Herrn der Welten.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmcmxlix{Laß die Kinder Israels mit uns zie hen.""\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmcml{Er (Pharao) sagte: ``Haben wir dich nicht als Kind bei uns aufgezogen? Und du hast viele Jahre deines Lebens bei uns verbracht.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmcmli{Und du begingst jene deine Tat, die du begangen hast, und du warst undankbar."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmcmlii{Er (Moses) sagte: ``lch tat es damals, als ich auf dem Irrweg war.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmcmliii{Dann floh ich von euch, weil ich euch fürchtete; doch (nun) hat mir mein Herr Weisheit geschenkt und mich zu einem Gesandten gemacht.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmcmliv{Und die Gnade, die du mir vorhältst, ist die, daß du die Kinder Israels geknechtet hast."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmcmlv{Pharao sagte: ``Und was ist der Herr der Welten?"\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmcmlvi{Er (Moses) sagte: ``Er ist der Herr der Himmel und der Erde und dessen, was zwischen den beiden ist, wenn ihr nur Gewißheit wolltet."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmcmlvii{Er (Pharao) sagte zu denen, die um ihn waren: ``Hört ihr nicht?"\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmcmlviii{Er (Moses) sagte: `` Er ist euer Herr und der Herr eurer Vorväter."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmcmlix{Er (Pharao) sagte: ``Dieser euer Gesandter, der zu euch entsandt wurde, ist wahrlich ein Besessener."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmcmlx{Er (Moses) sagte: ``Er ist der Herr des Ostens und des Westens und dessen, was zwischen den beiden ist, wenn ihr es nur begreifen würdet."\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmcmlxi{Er (Pharao) sagte: ``Wenn du einen anderen Gott als mich annimmst, so werde ich dich ganz gewiß zum Gefängnisinsassen machen."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmcmlxii{Er (Moses) sagte: ``Wie? Selbst wenn ich dir etwas bringe, das offenkundig ist?"\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmcmlxiii{Er (Pharao) sagte: ``So bringe es, wenn du die Wahrheit redest!"\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmcmlxiv{Da warf (Moses) seinen Stock hin, und siehe, er wurde eine Schlange, ganz deutlich.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmcmlxv{Und er zog seine Hand hervor, und siehe, sie erschien den Zuschauern weiß.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmcmlxvi{Er (Pharao) sagte zu den Vornehmen um ihn: ``Das ist wahrlich ein erfahrener Zauberer.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmcmlxvii{Er will euch durch seine Zauberei aus eurem Lande vertreiben. Was ratet ihr nun?"\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmcmlxviii{Sie sagten: ``Halte ihn und seinen Bruder hin und sende Ausrufer in die Städte\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmcmlxix{die dir alle erfahrenen Zauberer bringen sollen."\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmcmlxx{So wurden die Zauberer zur anberaumten Zeit an einem bestimmten Tage versammelt.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmcmlxxi{Und es wurde zu den Menschen gesprochen: ``Seid ihr alle da\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmcmlxxii{so daß wir den Zauberern folgen können, wenn sie die Sieger sind?"\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmcmlxxiii{Als die Zauberer kamen, da sagten sie zu Pharao: ``Wird es auch eine Belohnung für uns geben, wenn wir die Sieger sind?"\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmcmlxxiv{Er sagte: ``Ja, und dann werdet ihr zu unseren Nächsten gehören."\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmcmlxxv{Moses sagte zu ihnen: ``Werft hin, was ihr zu werfen habt."\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmcmlxxvi{Da warfen sie ihre Stricke und ihre Stöcke hin und sagten: ``Bei Pharaos Macht, wir sind es, die sicher siegen werden."\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmcmlxxvii{Dann warf Moses seinen Stock hin, und siehe, er verschlang (all) das, was sie vorgetäuscht hatten.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmcmlxxviii{Da warfen sich die Zauberer anbetend nieder.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmcmlxxix{Sie sagten: ``Wir glauben an den Herrn der Welten\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmcmlxxx{den Herrn Moses' und Aarons."\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmcmlxxxi{Er (Pharao) sagte: ``Glaubt ihr an ihn, bevor ich es euch erlaube? Er ist sicher euer Meister, der euch die Zauberei gelehrt hat. Aber bald sollt ihr es erfahren. Wahrhaftig, ich werde euch die Hände und Füße wech selweise abhauen (lassen), und wahrhaftig, ich will euch alle kreuzigen (lassen)"\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmcmlxxxii{Sie sagten: ``Darin liegt kein Schaden; denn wir werden zu unserem Herrn zurückkehren.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmcmlxxxiii{Wir hoffen ernsthaft, unser Herr werde uns unsere Sünden vergeben, da wir die ersten der Gläubigen sind."\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmcmlxxxiv{Und Wir offenbarten Moses: ``Führe Meine Diener nachts hinweg; denn ihr werdet verfolgt werden ``\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmcmlxxxv{Und Pharao sandte (Boten) in die Städte, um zu einer Versammlung aufzurufen\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmcmlxxxvi{``Diese sind nur ein kleiner Haufen\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmcmlxxxvii{dennoch haben sie uns erzürnt\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmcmlxxxviii{und wir sind eine wachsame Menge."\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmcmlxxxix{So vertrieben Wir sie aus Gärten und von Quellen\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmcmxc{und aus Schätzen und ehrenvollen Wohnsitzen.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmcmxci{So (geschah es); und Wir gaben sie den Kindern Israels zum Erbe.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmcmxcii{Und sie verfolgten sie bei Sonnenaufgang.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmcmxciii{Als die beiden Scharen einander ansichtig wurden, sagten die Gefährten Moses': ``Wir werden sicher eingeholt."\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmcmxciv{Er sagte: ``Keineswegs! Mein Herr ist mit mir. Er wird mich richtig führen."\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmcmxcv{Darauf offenbarten Wir Moses: ``Schlage das Meer mit deinem Stock." Und es teilte sich, und jeder Teil erhob sich wie ein gewaltiger Berg.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmcmxcvi{Und Wir ließen alsdann die anderen nahe herankommen.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmcmxcvii{Und Wir erretteten Moses und alle, die mit ihm waren.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmcmxcviii{Dann ertränkten Wir die anderen.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmcmxcix{Hierin ist wahrlich ein Zeichen; doch die meisten von ihnen glauben es nicht.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmm{Und wahrlich, dein Herr ist der Allmächtige, der Barmherzige.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmi{Und verlies ihnen die Geschichte Abrahams\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmii{als er zu seinem Vater und seinem Volke sagte: ``Was betet ihr an?"\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmiii{Sie sagten: ``Wir beten Götzen an, und wir sind ihnen anhaltend zugetan."\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmiv{Er sagte: ``Hören sie euch, wenn ihr (sie) anruft?\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmv{Oder nützen sie oder schaden sie euch?"\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmvi{Sie sagten: ``Nein, aber wir fanden unsere Väter das gleiche tun."\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmvii{Er sagte: ``Seht ihr denn nicht, was ihr da angebetet habt\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmviii{ihr und eure Vorväter?\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmix{Sie sind mir feindlich (gesonnen); nicht aber der Herr der Welten\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmx{Der mich erschaffen hat; und Er ist es, Der mich richtig führt\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmxi{und Der mir Speise und Trank gibt.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmmxii{Und wenn ich krank bin, ist Er es, Der mich heilt\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmmxiii{und (Er ist es,) Der mich sterben lassen wird und mich dann wieder zum Leben zurückbringt\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmmxiv{und von Dem ich hoffe, daß Er mir meine Fehler am Tage des Gerichts vergeben werde.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmmxv{Mein Herr, schenke mir Weisheit und füge mich zu den Rechtschaffenen\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmmxvi{und verleih mir einen guten Ruf bei den künftigen Geschlechtern.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmmxvii{Und mache mich zu einem der Erben des Paradieses der Wonne\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmmxviii{und vergib meinem Vater; denn er war einer der Irrenden\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmmxix{und tue mir an dem Tage, da (die Menschen) auferweckt werden, keine Schande an\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmmxx{an dem Tage, da weder Besitz noch Söhne (etwas) nützen\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmmxxi{sondern nur der (gerettet werden wird), der mit reinem Herzen zu Allah kommt."\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmmxxii{Und das Paradies wird den Gottesfürchtigen nahegebracht werden.\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmmxxiii{Und die Gahim wird denen vor Augen gehalten, die abgeirrt sind\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmmxxiv{und es wird zu ihnen gesprochen: ``Wo ist nun das, was ihr anzubeten pflegtet\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmmxxv{statt Allah? Können sie euch helfen oder sich selber helfen?"\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmmxxvi{Dann werden sie kopfüber (in die Hölle) hineingestürzt werden, sie und diejenigen, die abgeirrt sind\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mmmxxvii{und Iblis' Scharen allesamt.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mmmxxviii{Sie sagen, indem sie miteinander darüber streiten:\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mmmxxix{``Bei Allah, wir waren in einem offenkundigen Irrtum\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mmmxxx{als wir euch dem Herrn der Welten gleichsetzten.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mmmxxxi{Und es waren nur die Schuldigen, die uns irre führten\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mmmxxxii{und nun haben wir weder Fürsprecher\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mmmxxxiii{noch einen treuen Freund.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mmmxxxiv{Wenn es doch für uns eine Rückkehr gäbe, (dann) wären wir unter den Gläubigen!"\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mmmxxxv{Hierin ist wahrlich ein Zeichen, jedoch die meisten von ihnen glauben es nicht.\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mmmxxxvi{Und wahrlich, dein Herr - Er ist der Allmächtige, der Barmherzige.\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mmmxxxvii{Das Volk Noahs bezichtigte den Gesandten der Lüge\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mmmxxxviii{als ihr Bruder Noah zu ihnen sagte: ``Wollt ihr nicht gottesfürchtig sein?\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mmmxxxix{In Wahrheit, ich bin euch ein vertrauenswürdiger Gesandter.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mmmxl{So fürchtet Allah und gehorcht mir.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mmmxli{Und ich verlange von euch keinen Lohn dafür; mein Lohn ist allein beim Herrn der Welten.\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mmmxlii{So fürchtet Allah und gehorcht mir."\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mmmxliii{Sie sagten: ``Sollen wir dir glauben, wo es (doch nur) die Niedrigsten sind, die dir folgen?"\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mmmxliv{Er sagte: ``Und welche Kenntnis habe ich von dem, was sie getan haben?\qt@no{(112)}}
\qt@newcmd\qurantrans@de@mmmxlv{Ihre Rechenschaft ist einzig die Sache meines Herrn, wenn ihr euch dessen nur bewußt wäret!\qt@no{(113)}}
\qt@newcmd\qurantrans@de@mmmxlvi{Und ich werde die Gläubigen gewiß nicht hinauswerfen.\qt@no{(114)}}
\qt@newcmd\qurantrans@de@mmmxlvii{Ich bin nichts (anderes) als ein aufklärender Warner."\qt@no{(115)}}
\qt@newcmd\qurantrans@de@mmmxlviii{Sie sagten: ``Wenn du (davon) nicht abläßt, o Noah, so wirst du sicherlich gesteinigt werden."\qt@no{(116)}}
\qt@newcmd\qurantrans@de@mmmxlix{Er sagte: ``Mein Herr, mein Volk hat mich für einen Lügner gehalten.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@mmml{Darum richte entscheidend zwischen mir und ihnen; und rette mich und die Gläubigen, die mit mir sind."\qt@no{(118)}}
\qt@newcmd\qurantrans@de@mmmli{So erretteten Wir ihn und jene, die mit ihm in dem beladenen Schiff waren.\qt@no{(119)}}
\qt@newcmd\qurantrans@de@mmmlii{Dann ertränkten Wir hernach jene, die zurückblieben.\qt@no{(120)}}
\qt@newcmd\qurantrans@de@mmmliii{Wahrlich, hierin ist ein Zeichen, jedoch die meisten von ihnen glauben es nicht.\qt@no{(121)}}
\qt@newcmd\qurantrans@de@mmmliv{Und wahrlich, dein Herr - Er ist der Erhabene, der Barmherzige.\qt@no{(122)}}
\qt@newcmd\qurantrans@de@mmmlv{Die `Ad bezichtigten den Gesandten der Lüge\qt@no{(123)}}
\qt@newcmd\qurantrans@de@mmmlvi{als ihr Bruder Hud zu ihnen sagte: ``Wollt ihr nicht gottesfürchtig sein?\qt@no{(124)}}
\qt@newcmd\qurantrans@de@mmmlvii{In Wahrheit, ich bin euch ein vertrauenswürdiger Gesandter\qt@no{(125)}}
\qt@newcmd\qurantrans@de@mmmlviii{darum fürchtet Allah und gehorcht mir.\qt@no{(126)}}
\qt@newcmd\qurantrans@de@mmmlix{Und ich verlange von euch keinen Lohn dafür; mein Lohn ist allein beim Herrn der Welten.\qt@no{(127)}}
\qt@newcmd\qurantrans@de@mmmlx{Baut ihr Mahnmale auf jeder Anhöhe, um euch zu vergnügen?\qt@no{(128)}}
\qt@newcmd\qurantrans@de@mmmlxi{Und errichtet ihr Burgen, als solltet ihr lange leben?\qt@no{(129)}}
\qt@newcmd\qurantrans@de@mmmlxii{Und wenn ihr zupackt, so benehmt ihr euch gewalttätig.\qt@no{(130)}}
\qt@newcmd\qurantrans@de@mmmlxiii{So fürchtet Allah und gehorcht mir.\qt@no{(131)}}
\qt@newcmd\qurantrans@de@mmmlxiv{Ja, fürchtet Den, Der euch mit dem versorgt hat, was ihr kennt.\qt@no{(132)}}
\qt@newcmd\qurantrans@de@mmmlxv{Er hat euch mit Vieh und Söhnen versorgt\qt@no{(133)}}
\qt@newcmd\qurantrans@de@mmmlxvi{und Gärten und Quellen.\qt@no{(134)}}
\qt@newcmd\qurantrans@de@mmmlxvii{Wahrlich, ich fürchte für euch die Strafe eines gewaltigen Tages."\qt@no{(135)}}
\qt@newcmd\qurantrans@de@mmmlxviii{Sie sagten: ``Es ist uns gleich ob du (uns) predigst oder ob du (uns) nicht pre digst.\qt@no{(136)}}
\qt@newcmd\qurantrans@de@mmmlxix{Dies ist nichts als ein Brauch der Früheren\qt@no{(137)}}
\qt@newcmd\qurantrans@de@mmmlxx{und wir werden nicht bestraft werden."\qt@no{(138)}}
\qt@newcmd\qurantrans@de@mmmlxxi{So hielten sie ihn für einen Lügner, und Wir vernichteten sie. Hierin ist wahrlich ein Zeichen, jedoch die meisten von ihnen glauben es nicht.\qt@no{(139)}}
\qt@newcmd\qurantrans@de@mmmlxxii{Und wahrlich, dein Herr - Er ist der Erhabene, der Barmherzige.\qt@no{(140)}}
\qt@newcmd\qurantrans@de@mmmlxxiii{Die Tamud bezichtigten den Gesandten der Lüge\qt@no{(141)}}
\qt@newcmd\qurantrans@de@mmmlxxiv{als ihr Bruder, Sahih zu ihnen sagte: ``Wollt ihr nicht gottesfürchtig sein?\qt@no{(142)}}
\qt@newcmd\qurantrans@de@mmmlxxv{In Wahrheit, ich bin euch ein vertrauenswürdiger Gesandter.\qt@no{(143)}}
\qt@newcmd\qurantrans@de@mmmlxxvi{So fürchtet Allah und gehorcht mir.\qt@no{(144)}}
\qt@newcmd\qurantrans@de@mmmlxxvii{Und ich verlange von euch keinen Lohn dafür; mein Lohn ist allein beim Herrn der Welten.\qt@no{(145)}}
\qt@newcmd\qurantrans@de@mmmlxxviii{Werdet ihr etwa sicher zurückbleiben unter den Dingen, die hier sind\qt@no{(146)}}
\qt@newcmd\qurantrans@de@mmmlxxix{unter Gärten und Quellen\qt@no{(147)}}
\qt@newcmd\qurantrans@de@mmmlxxx{und Kornfeldern und Dattelpalmen mit Blütendolden, die fast brechen?\qt@no{(148)}}
\qt@newcmd\qurantrans@de@mmmlxxxi{Und aus den Bergen hauet ihr euch Wohnungen geschickt aus.\qt@no{(149)}}
\qt@newcmd\qurantrans@de@mmmlxxxii{So fürchtet Allah und gehorcht mir.\qt@no{(150)}}
\qt@newcmd\qurantrans@de@mmmlxxxiii{Und gehorcht nicht dem Befehl derer, die nicht maßhalten\qt@no{(151)}}
\qt@newcmd\qurantrans@de@mmmlxxxiv{die Verderben auf Erden stiften und keine guten Werke verrichten."\qt@no{(152)}}
\qt@newcmd\qurantrans@de@mmmlxxxv{Sie sagten: ``Du bist nur einer, der dem Zauber zum Opfer gefallen ist.\qt@no{(153)}}
\qt@newcmd\qurantrans@de@mmmlxxxvi{Du bist nichts (anderes) als ein Mensch wie wir. So bringe ein Zeichen, wenn du zu den Wahrhaftigen gehörst."\qt@no{(154)}}
\qt@newcmd\qurantrans@de@mmmlxxxvii{Er sagte: ``Hier ist eine Kamelstute; sie hat (ihre) Trinkzeit, und ihr habt (eure) Trinkzeit an einem bestimmten Tag.\qt@no{(155)}}
\qt@newcmd\qurantrans@de@mmmlxxxviii{Berührt sie nicht mit Bösem, damit euch nicht die Strafe eines gewaltigen Tages ereile."\qt@no{(156)}}
\qt@newcmd\qurantrans@de@mmmlxxxix{Sie aber schnitten ihr die Sehnen durch; und danach wurden sie reumütig.\qt@no{(157)}}
\qt@newcmd\qurantrans@de@mmmxc{Allein die Strafe ereilte sie. Hierin ist wahrlich ein Zeichen, jedoch die meisten von ihnen glauben es nicht.\qt@no{(158)}}
\qt@newcmd\qurantrans@de@mmmxci{Und wahrlich, dein Herr - Er ist der Erhabene, der Barmherzige.\qt@no{(159)}}
\qt@newcmd\qurantrans@de@mmmxcii{Das Volk Lots bezichtigte den Gesandten der Lüge\qt@no{(160)}}
\qt@newcmd\qurantrans@de@mmmxciii{als ihr Bruder Lot zu ihnen sagte: ``Wollt ihr nicht gottesfürchtig sein?\qt@no{(161)}}
\qt@newcmd\qurantrans@de@mmmxciv{In Wahrheit, ich bin euch ein vertrauenswürdiger Gesandter.\qt@no{(162)}}
\qt@newcmd\qurantrans@de@mmmxcv{So fürchtet Allah und gehorcht mir.\qt@no{(163)}}
\qt@newcmd\qurantrans@de@mmmxcvi{Und ich verlange von euch keinen Lohn dafür; mein Lohn ist allein beim Herrn der Welten.\qt@no{(164)}}
\qt@newcmd\qurantrans@de@mmmxcvii{Vergeht ihr euch unter allen Geschöpfen an Männern\qt@no{(165)}}
\qt@newcmd\qurantrans@de@mmmxcviii{und lasset eure Frauen (beiseite), die euer Herr für euch geschaffen hat? Nein, ihr seid ein Volk, das die Schranken überschreitet."\qt@no{(166)}}
\qt@newcmd\qurantrans@de@mmmxcix{Sie sagten: ``Wenn du (davon) nicht abläßt, o Lot, so wirst du gewiß einer der Verbannten sein."\qt@no{(167)}}
\qt@newcmd\qurantrans@de@mmmc{Er sagte: ``lch verabscheue euer Treiben.\qt@no{(168)}}
\qt@newcmd\qurantrans@de@mmmci{Mein Herr, rette mich und die Meinen vor dem, was sie tun."\qt@no{(169)}}
\qt@newcmd\qurantrans@de@mmmcii{So erretteten Wir ihn und die Seinen allesamt\qt@no{(170)}}
\qt@newcmd\qurantrans@de@mmmciii{bis auf eine alte Frau, die unter denen war, die zurückblieben.\qt@no{(171)}}
\qt@newcmd\qurantrans@de@mmmciv{Dann vernichteten Wir die an deren.\qt@no{(172)}}
\qt@newcmd\qurantrans@de@mmmcv{Und Wir ließen einen Regen auf sie niederregnen; und schlimm war der Regen für die Gewarnten.\qt@no{(173)}}
\qt@newcmd\qurantrans@de@mmmcvi{Hierin liegt wahrlich ein Zeichen, jedoch die meisten von ihnen glauben es nicht.\qt@no{(174)}}
\qt@newcmd\qurantrans@de@mmmcvii{Wahrlich, dein Herr - Er ist der Erhabene, der Barmherzige.\qt@no{(175)}}
\qt@newcmd\qurantrans@de@mmmcviii{Das Volk vom Walde bezichtigte den Gesandten der Lüge\qt@no{(176)}}
\qt@newcmd\qurantrans@de@mmmcix{als Suaib zu ihnen sagte: ``Wollt ihr nicht gottes fürchtig sein?\qt@no{(177)}}
\qt@newcmd\qurantrans@de@mmmcx{In Wahrheit, ich bin euch ein ver trauenswürdiger Gesandter.\qt@no{(178)}}
\qt@newcmd\qurantrans@de@mmmcxi{So fürchtet Allah und gehorcht mir.\qt@no{(179)}}
\qt@newcmd\qurantrans@de@mmmcxii{Und ich verlange von euch keinen Lohn dafür; mein Lohn ist allein beim Herrn der Welten.\qt@no{(180)}}
\qt@newcmd\qurantrans@de@mmmcxiii{Gebt volles Maß und gehört nicht zu denen, die weniger geben\qt@no{(181)}}
\qt@newcmd\qurantrans@de@mmmcxiv{und wiegt mit richtiger Waage.\qt@no{(182)}}
\qt@newcmd\qurantrans@de@mmmcxv{Und vermindert den Menschen nicht ihr Gut und handelt nicht verderbend im Lande, indem ihr Unheil anrichtet.\qt@no{(183)}}
\qt@newcmd\qurantrans@de@mmmcxvi{Und fürchtet Den, Der euch und die früheren Geschlechter erschuf."\qt@no{(184)}}
\qt@newcmd\qurantrans@de@mmmcxvii{Sie sagten: ``Du bist nur einer, der dem Zauber zum Opfer gefallen ist.\qt@no{(185)}}
\qt@newcmd\qurantrans@de@mmmcxviii{Und du bist nichts (anderes) als ein Mensch wie wir, und wir halten dich für einen Lügner.\qt@no{(186)}}
\qt@newcmd\qurantrans@de@mmmcxix{So laß Brocken vom Himmel auf uns niederfallen, wenn du zu den Wahrhaftigen gehörst."\qt@no{(187)}}
\qt@newcmd\qurantrans@de@mmmcxx{Er sagte: ``Mein Herr weiß am besten, was ihr tut."\qt@no{(188)}}
\qt@newcmd\qurantrans@de@mmmcxxi{Und sie erklärten ihn für einen Lügner. So ereilte sie die Strafe am Tage der schattenspendenden Wolke. Das war wahrlich die Strafe eines gewaltigen Tages.\qt@no{(189)}}
\qt@newcmd\qurantrans@de@mmmcxxii{Hierin ist wahrlich ein Zeichen, jedoch die meisten von ihnen glauben es nicht.\qt@no{(190)}}
\qt@newcmd\qurantrans@de@mmmcxxiii{Wahrlich, dein Herr - Er ist der Erhabene, der Barmherzige.\qt@no{(191)}}
\qt@newcmd\qurantrans@de@mmmcxxiv{Und wahrlich, dies ist eine Offenbarung vom Herrn der Welten\qt@no{(192)}}
\qt@newcmd\qurantrans@de@mmmcxxv{die vom vertrauenswürdigen Gabriel, herabgebracht worden ist\qt@no{(193)}}
\qt@newcmd\qurantrans@de@mmmcxxvi{auf dein Herz, auf daß du einer der Warner sein mögest\qt@no{(194)}}
\qt@newcmd\qurantrans@de@mmmcxxvii{in arabischer Sprache, die deutlich ist.\qt@no{(195)}}
\qt@newcmd\qurantrans@de@mmmcxxviii{Und ganz gewiß steht dies in den Schriften der Früheren.\qt@no{(196)}}
\qt@newcmd\qurantrans@de@mmmcxxix{Gilt es ihnen denn nicht als Zeichen, daß die Kundigen unter den Kindern Israels ihn kennen?\qt@no{(197)}}
\qt@newcmd\qurantrans@de@mmmcxxx{Und hätten Wir ihn zu einem Nichtaraber hinabgesandt\qt@no{(198)}}
\qt@newcmd\qurantrans@de@mmmcxxxi{und hätte er ihn ihnen vorgelesen, würden sie (doch) nie an ihn geglaubt haben.\qt@no{(199)}}
\qt@newcmd\qurantrans@de@mmmcxxxii{So haben Wir ihn in die Herzen der Sünder einziehen lassen.\qt@no{(200)}}
\qt@newcmd\qurantrans@de@mmmcxxxiii{Sie werden nicht an ihn glauben, bis sie die schmerzliche Strafe erleben.\qt@no{(201)}}
\qt@newcmd\qurantrans@de@mmmcxxxiv{Doch sie wird unversehens über sie kommen, ohne daß sie es merken.\qt@no{(202)}}
\qt@newcmd\qurantrans@de@mmmcxxxv{Dann werden sie sagen: ``Wird uns eine Frist gewährt?"\qt@no{(203)}}
\qt@newcmd\qurantrans@de@mmmcxxxvi{Ist es denn Unsere Strafe, die sie beschleunigen wollen?\qt@no{(204)}}
\qt@newcmd\qurantrans@de@mmmcxxxvii{Siehst du es nicht, wenn Wir sie jahrelang genießen lassen?\qt@no{(205)}}
\qt@newcmd\qurantrans@de@mmmcxxxviii{Dann aber kommt das zu ihnen, was ihnen angedroht wurde.\qt@no{(206)}}
\qt@newcmd\qurantrans@de@mmmcxxxix{Nichts nützt ihnen dann all das, was sie genießen dürften.\qt@no{(207)}}
\qt@newcmd\qurantrans@de@mmmcxl{Und nie zerstörten Wir eine Stadt, ohne daß sie Warner gehabt hätte\qt@no{(208)}}
\qt@newcmd\qurantrans@de@mmmcxli{zur Ermahnung; und nie sind Wir ungerecht.\qt@no{(209)}}
\qt@newcmd\qurantrans@de@mmmcxlii{Und die Satane haben ihn (den Quran) nicht herabgebracht\qt@no{(210)}}
\qt@newcmd\qurantrans@de@mmmcxliii{noch schickt es sich für sie, noch vermögen sie es\qt@no{(211)}}
\qt@newcmd\qurantrans@de@mmmcxliv{denn sie sind vom Lauschen ferngehalten.\qt@no{(212)}}
\qt@newcmd\qurantrans@de@mmmcxlv{Rufe daher außer Allah keinen anderen Gott an, damit du nicht zu denen gehörst, die bestraft werden.\qt@no{(213)}}
\qt@newcmd\qurantrans@de@mmmcxlvi{Und warne deine nächsten Verwandten\qt@no{(214)}}
\qt@newcmd\qurantrans@de@mmmcxlvii{und senke deinen Flügel über die Gläubigen, die dir folgen.\qt@no{(215)}}
\qt@newcmd\qurantrans@de@mmmcxlviii{Sind sie dir dann aber ungehorsam, so sprich: ``lch bin schuldlos an dem, was ihr tut."\qt@no{(216)}}
\qt@newcmd\qurantrans@de@mmmcxlix{Und vertraue auf den Erhabenen, den Barmherzigen\qt@no{(217)}}
\qt@newcmd\qurantrans@de@mmmcl{Der dich sieht, wenn du (im Gebet) dastehst\qt@no{(218)}}
\qt@newcmd\qurantrans@de@mmmcli{und (Der) deine Bewegungen inmitten derer, die sich (vor Ihm) niederwerfen, (sieht)\qt@no{(219)}}
\qt@newcmd\qurantrans@de@mmmclii{denn Er ist der Allhörende, der Allwissende.\qt@no{(220)}}
\qt@newcmd\qurantrans@de@mmmcliii{Soll ich euch verkünden, auf wen die Satane herniederfahren?\qt@no{(221)}}
\qt@newcmd\qurantrans@de@mmmcliv{Sie fahren auf jeden gewohnheitsmäßigen Lügner und Sünder hernieder\qt@no{(222)}}
\qt@newcmd\qurantrans@de@mmmclv{sie horchen, und die meisten von ihnen sind Lügner.\qt@no{(223)}}
\qt@newcmd\qurantrans@de@mmmclvi{Und die Dichter - es sind die Irrenden, die ihnen folgen.\qt@no{(224)}}
\qt@newcmd\qurantrans@de@mmmclvii{Hast du nicht gesehen, wie sie verwirrt in jedem Tal umherwandeln\qt@no{(225)}}
\qt@newcmd\qurantrans@de@mmmclviii{und wie sie reden, was sie nicht tun?\qt@no{(226)}}
\qt@newcmd\qurantrans@de@mmmclix{Die (sind von der Strafe) ausgenommen, die glauben und gute Werke verrichten und Allahs des öfteren gedenken und die sich widersetzen, nachdem ihnen Unrecht widerfuhr. Und die Ungerechten werden bald erfahren, zu welchem Ort sie zurückkehren werden.\qt@no{(227)}}
\qt@newcmd\qurantrans@de@mmmclx{\basmalahde Ta Sin. Dies sind die Verse des Quran - eines deutlichen Buches.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmclxi{(Es ist) eine Führung und frohe Botschaft für die, die glauben\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmclxii{das Gebet verrichten und die Zakah entrichten und fest mit dem Jenseits rechnen.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmclxiii{Denjenigen aber, die nicht an das Jenseits glauben, haben Wir ihre Werke schön erscheinen lassen; so wandern sie nur in Verwirrung (umher)\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmclxiv{Das sind die, derer eine schlimme Strafe harrt, und sie allein sind es, die im Jenseits die größten Verlierer sind.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmclxv{Und wahrlich, du empfängst den Quran von einem Allweisen, Allwissenden.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmclxvi{Damals sagte Moses zu seinen Angehörigen: ``lch nahm ein Feuer wahr. Ich will euch von dort Kunde bringen, oder ich will zu euch eine brennende Glut herbeischaffen, auf daß ihr euch wärmen möget."\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmclxvii{Und als er zu ihm kam, wurde gerufen: ``Gesegnet soll der sein, der in dem Feuerbereich ist und der, der sich in ihrer Nähe befindet; und gepriesen sei Allah, der Herr der Welten!"\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmclxviii{``O Moses, Ich bin Allah, der Erhabene, der Allweise.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmclxix{Und wirf deinen Stock hin." Doch als er ihn sich regen sah als wäre er eine Riesenschlange, da wandte er sich zur Flucht und schaute nicht zurück. ``O Moses, fürchte dich nicht. Wahrlich, bei Mir fürchten sich nicht die Gesandten.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmclxx{Wer aber Unrecht tut und dann Gutes an Stelle des Bösen setzt, dann, wahrlich, bin Ich Allverzeihend, Barmherzig.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmclxxi{Und steck deine Hand unter deinen Arm; sie wird ohne ein Übel weiß hervorkommen - (dies ist eines) der neun Zeichen für Pharao und sein Volk; denn sie sind ein frevelhaftes Volk."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmclxxii{Doch als Unsere sichtbaren Zeichen zu ihnen kamen, sagten sie: ``Das ist offenkundige Zauberei."\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmclxxiii{Und sie verwarfen sie in Ungerechtigkeit und Hochmut, während ihre Seelen doch von ihnen überzeugt waren. Siehe nun, wie das Ende derer war, die Unheil anrichteten!\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmclxxiv{Und wahrlich, Wir gaben David und Salomo Wissen, und beide sagten: `` Alles Lob gebührt Allah, Der uns erhöht hat über viele Seiner gläubigen Diener."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmclxxv{Und Salomo wurde Davids Erbe, und er sagte: ``O ihr Menschen, die Sprache der Vögel ist uns gelehrt worden; und alles wurde uns beschert. Das ist wahrlich die offenbare Huld."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmclxxvi{Und dort vor Salomo wurden dessen Heerscharen der Ginn und Menschen und Vögel versammelt, und sie standen in Reih und Glied geordnet\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmclxxvii{bis dann, als sie zum Tale der Ameisen kamen, eine Ameise (darunter) sagte: ``O ihr Ameisen, geht in eure Wohnungen hinein, damit euch Salomo und seine Heerscharen nicht zertreten, ohne daß sie es merken."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmclxxviii{Da lächelte er heiter über ihre Worte und sagte: Mein Herr gib mir ein, dankbar für die Gnade zu sein, die Du mir und meinen Eltern gewährt hast, und (gib mir ein,) Gutes zu tun, das Dir wohlgefällig sei, und nimm mich in Deiner Barmherzigkeit unter Deine rechtschaffenen Diener auf."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmclxxix{Und er musterte die Vögel und sagte: ``Wie kommt es, daß ich den Wiedehopf nicht sehe? Ist er abwesend?\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmclxxx{Ich werde ihn gewiß mit strenger Strafe bestrafen, oder ich werde ihn töten, es sei denn, er bringt mir einen triftigen Grund vor."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmclxxxi{Und dieser blieb nicht lange fern, dann sprach er: ``lch habe eine Erfahrung gemacht, die du nicht gemacht hast; und ich bin aus Saba' mit sicherer Nachricht zu dir gekommen.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmclxxxii{Dort fand ich eine Frau, die über sie herrscht, und ihr ist alles beschert worden, und sie besitzt einen großartigen Thron.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmclxxxiii{Ich fand sie und ihr Volk die Sonne statt Allah anbeten; und Satan hat ihnen ihre Werke ausgeschmückt und hat sie vom Weg (Allahs) abgehalten, so daß sie dem Weg nicht folgen.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmclxxxiv{Wollen sie nicht Allah verehren, Der ans Licht bringt, was in den Himmeln und auf Erden verborgen ist, und Der weiß, was ihr verhehlt und was ihr offenbart!\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmclxxxv{Allah! Es ist kein Gott außer Ihm, dem Herrn des Gewaltigen Throns."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmclxxxvi{Er (Salomo) sagte: ``Wir werden sehen, ob du die Wahrheit gesprochen hast oder ob du zu den Lügnern gehörst.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmclxxxvii{Geh mit diesem Brief von mir und wirf ihn vor sie hin, sodann zieh dich von ihnen zurück und schau, was sie erwidern."\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmclxxxviii{Sie (die Königin) sagte: ``Ihr Vornehmen, ein ehrenvoller Brief ist mir überbracht worden.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmclxxxix{Er ist von Salomo, und er lautet: ``Im Namen Allahs, des Allerbarmers, des Barmherzigen!\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmcxc{Seid nicht überheblich gegen mich, sondern kommt zu mir in Ergebenheit.""\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmcxci{Sie sagte: ``O ihr Vornehmen, ratet mir in dieser Sache. Ich entscheide keine Angelegenheit, solange ihr nicht zugegen seid."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmcxcii{Sie sagten: ``Wir besitzen Kraft und eine starke Kriegsmacht, aber dir obliegt der Befehl; sieh nun zu, was du befehlen willst."\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmcxciii{Sie sagte: ``Wahrlich, wenn Könige in ein Land eindringen, verwüsten sie es und machen die höchsten seiner Bewohner zu den niedrigsten. So verfahren sie.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmcxciv{Ich aber will ihnen ein Geschenk schicken und will abwarten, was die Boten (für eine Antwort) zurückbringen."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmcxcv{Als (der Überbringer) zu Salomo kam, sagte (dieser): ``Schüttet ihr Reichtümer über mich aus? Jedoch was Allah mir gegeben hat, ist besser als das, was Er euch gegeben hat. Nein, ihr seid es, die sich an dieser Gabe erfreuen.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmcxcvi{Kehre zu ihnen zurück; denn wir werden ganz gewiß mit Heerscharen zu ihnen kommen, gegen die sie keine Macht haben werden, und wir werden sie von dort in Schmach forttreiben, und sie werden sich gedemütigt fühlen."\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmcxcvii{Er sagte: ``O ihr Vornehmen, wer von euch bringt mir ihren Thron, bevor sie in Ergebenheit zu mir kommen?"\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmcxcviii{Da sprach ein kraftvoller (Riese) von den Ginn: ``lch will ihn dir bringen, ehe du dich von deinem Feldlager erhebst; wahrlich, ich habe die Stärke dazu und bin vertrauenswürdig."\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmcxcix{Da sprach einer der Kenntnis von der Schrift besaß: ``lch bringe ihn dir innerhalb eines Augenzwinkerns von dir." Und da er ihn vor sich stehen sah, sagte er: ``Dies geschieht durch die Gnade meines Herrn, um mich zu prüfen, ob ich dankbar oder undankbar bin. Und wer dankbar ist, der ist dankbar zum Heil seiner eigenen Seele; wer aber undankbar ist - siehe, mein Herr ist auf keinen angewiesen, Großzügig."\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmcc{Er sagte: ``Macht ihr ihren Thron unkenntlich; wir wollen sehen, ob sie dem rechten Weg folgt oder ob sie zu denen gehört, die nicht dem rechten Weg folgen."\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmcci{Als sie kam, da wurde gesprochen: ``Ist dein Thron wie dieser?" Sie sagte: ``Es ist, als wäre er ein und derselbe." Und uns wurde (davon) Wissen, schon vor ihr, verliehen; und wir hatten uns bereits (Allah) ergeben.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmccii{Und es hielt sie von dem ab, was sie statt Allah zu verehren pflegte; denn sie gehörte zu einem ungläubigen Volk."\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmcciii{Es wurde zu ihr gesprochen: ``Tritt ein in den Palast." Und da sie ihn sah, hielt sie ihn für einen Wasserspiegel und entblößte ihre Beine. Er (Salomo) sagte: ``Es ist ein Palast, getäfelt und gepflastert mit geglättetem Glas." Sie sagte: ``Mein Herr, ich habe wahrlich gegen meine eigene Seele gesündigt; und ich ergebe mich mit Salomo Allah, dem Herrn der Welten."\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmcciv{Und wahrlich, Wir entsandten zu den Tamud ihren Bruder Salih (, der sagte): ``Verehrt Allah!" Doch siehe, sie spalteten sich in zwei Parteien, die miteinander stritten.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmccv{Er sagte: ``O mein Volk, weshalb wollt ihr lieber das Böse beschleunigt sehen als das Gute? Warum bittet ihr Allah nicht um Vergebung damit euch Barmherzigkeit zuteil werde?"\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmccvi{Sie sagten: ``Wir ahnen Böses von dir und von denen, die mit dir sind." Er sagte: ``Euer Unheil ist bereits bei Allah. Nein, ihr seid ein Volk, das geprüft wird."\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmccvii{Und es waren in der Stadt neun Führer, die Unheil im Lande stifteten, und sie wollten nicht für Ordnung sorgen.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmccviii{Sie sagten: ``Schwört einander bei Allah, daß wir ihn (Salih) und seine Angehörigen gewiß bei Nacht überfallen und dann zu seinen Hinterlassenen sagen wollen: ``Wir waren keine Zeugen vom Untergang seiner Familie, und wir reden bestimmt die Wahrheit.""\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmccix{Sie schmiedeten einen Plan, (und) auch Wir schmiedeten einen Plan, aber sie gewahrten es nicht.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmccx{Sieh nun wie der Ausgang ihres Planes war; denn Wir vernichteten sie und all ihr Volk ganz und gar.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmccxi{Und dort sind ihre Häuser, verfallen ihres Frevelns wegen. Hierin ist wahrlich ein Zeichen für Leute, die es wissen.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmccxii{Und Wir erretteten jene, die glaubten und gottesfürchtig waren.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmccxiii{Und (gedenke) Lots, als er zu seinem Volke sagte: ``Wollt ihr Schändlichkeiten begehen, wo ihr doch einsichtig seid?\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmccxiv{Wollt ihr euch wirklich in (eurer) Sinnenlust mit Männern statt mit Frauen abgeben? Nein, ihr seid ein unwissendes Volk."\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmccxv{Doch die Antwort seines Volkes war nichts anderes als: ``Treibt Lots Familie aus eurer Stadt hinaus: denn sie sind Leute, die rein sein möchten."\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmccxvi{Also erretteten Wir ihn und die Seinen bis auf seine Frau; sie ließen Wir bei jenen, die zurückblieben.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmccxvii{Und Wir ließen einen Regen auf sie niedergehen; und schlimm war der Regen für die Gewarnten.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmccxviii{Sprich: ``Aller Preis gebührt Allah, und Frieden sei über jenen von Seinen Dienern, die Er auserwählt hat. Ist Allah besser oder das, was sie anbeten?"\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmccxix{Wer hat denn Himmel und Erde geschaffen, und wer sendet Wasser vom Himmel für euch nieder, durch das Wir in Schönheit herrliche Gärten sprießen lassen? Ihr vermögt nicht ihre Bäume sprießen zu lassen. Existiert wohl ein Gott neben Allah? Nein, sie sind ein Volk, das Götter neben Gott stellt.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmccxx{Wer hat denn die Erde zu einer Ruhestatt gemacht und Flüsse durch ihre Mitte geführt und feste Berge auf ihr gegründet und eine Schranke zwischen die beiden Meere gesetzt? Existiert wohl ein Gott neben Allah? Nein, die meisten von ihnen wissen es nicht.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmccxxi{Wer antwortet denn dem Bedrängten, wenn er Ihn anruft, und nimmt das Übel hinweg und macht euch zu Nachfolgern auf Erden? Existiert wohl ein Gott neben Allah? Geringfügig ist das, was ihr (davon) bedenkt.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmccxxii{Wer leitet euch in den Finsternissen über Land und Meer, und wer sendet die Winde als Freudenboten Seiner Barmherzigkeit voraus? Existiert wohl ein Gott neben Allah? Hoch Erhaben ist Allah über das, was sie (ihm) beigesellen.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmccxxiii{Wer ruft denn zum Beginn die Schöpfung hervor und wiederholt sie hierauf, und wer versorgt euch vom Himmel und von der Erde? Existiert wohl ein Gott neben Allah? Sprich: ``Bringt euren Beweis herbei, wenn ihr wahrhaftig seid."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmccxxiv{Sprich: ``Niemand in den Himmeln und auf Erden kennt das Verborgene außer Allah; und sie wissen nicht, wann sie wiederauferweckt werden."\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmccxxv{Nein, ihr Wissen über das Jenseits hat gänzlich versagt; nein, sie befinden sich im Zweifel darüber; nein, sie sind ihm gegenüber blind.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmccxxvi{Und jene, die ungläubig sind, sagen: ``Wie? Wenn wir und unsere Väter zu Staub geworden sind, sollen wir dann wirklich wieder hervorgebracht werden?\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmccxxvii{Verheißen wurde uns dies zuvor - uns und unseren Vätern; dies sind ja nur Fabeln der Früheren."\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmccxxviii{Sprich: ``Reist auf der Erde umher und seht, wie der Ausgang der Sündigen war!"\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmccxxix{Sei ihretwegen nicht traurig, noch sei deswegen bedrängt, was sie an Ranken schmieden.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmccxxx{Und sie sagen: ``Wann wird diese Verheißung (erfüllt werden), wenn ihr die Wahrheit redet?"\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmccxxxi{Sprich: ``Vielleicht ist ein Teil von dem, was ihr zu beschleunigen trachtet, schon nahe herangekommen."\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmccxxxii{Und wahrlich, dein Herr ist Huldreich gegen die Menschen, doch die meisten von ihnen sind nicht dankbar.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmccxxxiii{Und dein Herr kennt wohl, was ihre Herzen verhehlen und was sie kundtun.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmccxxxiv{Und (es gibt) nichts Verborgenes im Himmel oder auf Erden, das nicht in einem deutlichen Buch stünde.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmccxxxv{Wahrlich, dieser Quran erklärt den Kindern Israels das meiste von dem, worüber sie uneins sind.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmccxxxvi{Und er ist wahrlich eine Führung und eine Barmherzigkeit für die Gläubigen.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmccxxxvii{Wahrlich, dein Herr wird zwischen ihnen durch Seinen Spruch entscheiden, und Er ist der Allmächtige, der Allwissende.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmccxxxviii{Vertraue also auf Allah; denn du verfährst nach der offenkundigen Wahrheit.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmmccxxxix{Du kannst die Toten weder hörend machen, noch kannst du bewirken, daß die Tauben den Anruf hören, wenn sie (dir) den Rücken kehren\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmmccxl{noch kannst du die Blinden aus ihrem Irrtum leiten. Du kannst nur diejenigen hörend machen, die an Unsere Zeichen glauben und die sich (Uns) ergeben.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmmccxli{Und wenn der Befehl gegen sie ergeht, dann werden Wir für sie ein Tier aus der Erde hervorbringen, das zu ihnen spricht, daß die Menschen nicht an Unsere Zeichen glaubten.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmmccxlii{Und (mahne sie an) den Tag, wo Wir aus jedem Volk eine Schar derer versammeln werden, die Unsere Zeichen für Lüge erklärten; und sie sollen in Reih und Glied gehalten werden\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmmccxliii{bis Er sprechen wird, wenn sie kommen: ``Habt ihr Meine Zeichen für Lüge erklärt, obwohl ihr sie nicht kanntet? Oder was war es, was ihr tatet?"\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmmccxliv{Und der Befehl wird ihres Frevels wegen gegen sie ergehen, und sie werden nicht reden.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmmccxlv{Haben sie denn nicht gesehen, daß Wir die Nacht geschaffen haben, damit sie darin ruhen mögen, und den Tag, (damit sie) sehen (mögen)? Hierin sind wahrlich Zeichen für Leute, die glauben.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmmccxlvi{Und an dem Tage, wenn in den Sur gestoßen wird, hat jeder mit dem Schrecken zu kämpfen, der in den Himmeln und der auf Erden ist, ausgenommen der, den Allah will. Und alle sollen demütig zu Ihm kommen.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmmccxlvii{Und die Berge, die du für fest hältst, wirst du wie Wolken dahingehen sehen: Das (ist das) Werk Allahs, Der alles vollendet hat. Wahrlich, Er weiß wohl, was ihr tut.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmmccxlviii{Dem, der Gutes vollbringt, wird Besseres als das zuteil sein, und sie werden vor dem Schrecken an jenem Tag sicher sein.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmmccxlix{Und die Gesichter derjenigen, die Schlechtes vollbringen, sollen ins Feuer gestürzt werden: ``Seid ihr für das belohnt worden, was ihr getan habt?"\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmmccl{``Wahrlich, mir ist nur befohlen worden, dem Herrn dieser Stadt zu dienen, die Er geheiligt hat, und Sein sind alle Dinge; und mir ist befohlen worden, einer der Gottergebenen zu sein\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmmccli{und den Quran zu verlesen." Wer also dem rechten Weg folgt, der folgt ihm nur zu seinem eigenen Besten; (wenn) einer irregeht, so sprich: ``lch bin nur einer der Warner."\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmmcclii{Und sprich: ``Aller Preis gebührt Allah; Er wird euch Seine Zeichen zeigen, und ihr werdet sie erkennen." Und dein Herr ist dessen nicht unachtsam, was ihr tut.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmmccliii{\basmalahde Ta Sin Mim\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmccliv{Das sind die Verse des deutlichen Buches.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmcclv{Wir verlesen dir wahrheitsgemäß einen Teil der Geschichte von Moses und Pharao, für Leute, die glauben.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmcclvi{Wahrlich, Pharao betrug sich hochmütig im Land und machte dessen Bewohner zu Parteien. Eine Gruppe davon pflegte er zu unterdrücken, indem er ihre Söhne erschlug und ihre Frauen leben ließ. Wahrlich, er war einer der Unheilstifter!\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmcclvii{Und Wir wollten denen, die im Lande als schwach erachtet worden waren, Huld erweisen und sie zu Führern machen und zu Erben einsetzen\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmcclviii{und ihnen die Oberhand im Lande geben und Pharao und Haman und ihren Heerscharen durch sie (die Schwachen) das zeigen, was sie befürchteten.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmcclix{Und Wir gaben der Mutter von Moses ein: ``Säuge ihn; und wenn du für ihn fürchtest, so wirf ihn in den Fluß und fürchte dich nicht und betrübe dich nicht; denn Wir werden ihn dir wiedergeben und ihn zu einem Gesandten machen."\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmcclx{Und die Angehörigen Pharaos lasen ihn auf, so daß er ihnen zum Feind wurde und Kummer verursachte; denn Pharao und Haman und ihre Heerscharen waren Missetäter.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmcclxi{Und die Frau des Pharao sagte: ("Er ist) mir und dir eine Augenweide! Tötet ihn nicht. Vielleicht erweist er sich als nützlich für uns, oder wir nehmen ihn als Sohn an." Aber sie waren ahnungslos.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmcclxii{Und das Herz von Moses' Mutter war (von jeder Hoffnung) entleert. Fast hätte sie ihr Geheimnis preisgegeben, wenn Wir nicht ihr Herz gestärkt hätten, damit sie am Glauben festhielte.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmcclxiii{Sie sagte zu seiner Schwester: ``Spüre ihm nach." So beobachtete sie ihn von weitem; und jene ahnten nichts.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmcclxiv{Und vordem hatten Wir ihm die Ammen verwehrt. Da sagte sie (seine Schwester): ``Soll ich euch eine Familie nennen, wo man ihn für euch aufziehen und ihm wohlgesinnt sein würde?"\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmcclxv{Dann gaben Wir ihn seiner Mutter zurück, damit ihr Auge mit Freude erfüllt würde und damit sie sich nicht grämte und damit sie wüßte, daß Allahs Verheißung wahr sei. Jedoch die meisten von ihnen wissen es nicht.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmcclxvi{Und als er seine Vollkraft erreicht hatte und reif geworden war, verliehen Wir ihm Weisheit und Wissen; so belohnen Wir jene, die Gutes tun.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmcclxvii{Und er betrat die Stadt um eine Zeit, da ihre Bewohner in einem Zustand der Unachtsamkeit waren; und er fand da zwei Männer, die miteinander kämpften. Der eine war von seiner eigenen Partei und der andere von seinen Feinden. Jener, der von seiner Partei war, rief ihn zu Hilfe gegen den, der von seinen Feinden war. So schlug Moses ihn zurück; doch es führte zu seinem Tod. Er sagte: ``Das ist ein Werk des Satans; er ist ein Feind, ein offenbarer Verführer."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmcclxviii{Er sagte: ``Mein Herr, ich habe mir selbst Unrecht getan, so vergib mir." So verzieh Er ihm; denn Er ist der Allverzeihende, der Barmherzige.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmcclxix{Er sagte: ``Mein Herr, da Du mir gnädig gewesen bist, will ich niemals ein Helfer der Sünder sein."\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmcclxx{Dann wurde er in der Stadt furchtsam (und war) auf der Hut; und siehe, jener, der ihn zuvor um Hilfe gerufen hatte, schrie nach ihm um Beistand. Da sagte Moses zu ihm: ``Du bist offensichtlich auf dem falschen Weg."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmcclxxi{Und als er sich entschloß, Hand an den Mann zu legen, der ihrer beider Feind war, sagte er: ``O Moses, willst du mich töten, so wie du gestern einen Menschen getötet hast? Du versuchst nur, ein Tyrann im Land zu werden, und du willst kein Friedensstifter sein."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmcclxxii{Da kam ein Mann vom äußersten Ende der Stadt angelaufen. Er sagte: ``O Moses, die Vornehmen beraten sich gegen dich, um dich zu töten. Darum mache dich fort; denn ich rate dir gut."\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmcclxxiii{Da zog er furchtsam aus ihr hinaus und spähte umher. Er sagte: ``Mein Herr rette mich vor dem ungerechten Volk."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmcclxxiv{Und als er sich in Richtung Madyan begab, sagte er: ``lch hoffe, mein Herr wird mich auf den rechten Weg leiten."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmcclxxv{Als er zum Wasser von Madyan kam, fand er dort eine Schar von Leuten, die (ihr Vieh) tränkten. Und neben ihnen fand er zwei Frauen, die (ihr Vieh) zurückhielten. Er sagte: `` Was ist mit euch?" Sie sagten: ``Wir können (unser Vieh) nicht eher tränken, als bis die Hirten (ihre Herden) fortgetrieben haben, und unser Vater ist ein hochbetagter Greis."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmcclxxvi{Da tränkte er (ihre Herde) für sie. Dann zog er sich in den Schatten zurück und sagte: ``Mein Herr, ich bedarf des Guten, was immer es (auch) sei, das Du auf mich herabsenden magst."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmcclxxvii{Und eine der beiden (Frauen) kam zu ihm gelaufen voller Scham. Sie sagte: ``Siehe, mein Vater ladet dich ein, damit er dich dafür belohnen kann, daß du unser Vieh getränkt hast." Als er nun zu ihm kam und ihm seine Geschichte erzählte, sagte er: ``Fürchte dich nicht; du bist dem ungerechten Volk entronnen."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmcclxxviii{Da sagte eine der beiden: ``O mein Vater, stell ihn in deinen Dienst ein; denn der beste Mann, den du einstellen kannst, ist wahrlich der, der stark und ehrlich ist."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmcclxxix{Er sagte: ``lch will dir eine von diesen meinen zwei Töchtern zur Frau geben unter der Bedingung, daß du dich mir auf acht Jahre zum Dienst verpflichtest. Willst du dann zehn (Jahre) vollmachen, so steht es bei dir. Ich möchte aber nicht hart zu dir sein; du wirst in mir, so Allah will, einen rechtschaffenen (Mann) finden.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmcclxxx{Er sagte: ``Das sei zwischen mir und dir (abgemacht) Welche der beiden Fristen ich auch erfülle - es soll mich kein Vorwurf treffen; und Allah ist Zeuge dessen, was wir sagen."\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmcclxxxi{Als Moses nun die Frist erfüllt hatte und mit seinen Angehörigen reiste, gewahrte er an der Seite des Berges ein Feuer. Er sagte zu seinen Angehörigen: ``Bleibt hier ich habe ein Feuer wahrgenommen; vielleicht kann ich euch eine Nachricht von dort bringen oder eine Feuersglut, so daß ihr euch wärmen könnt."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmcclxxxii{Und als er zu ihm kam, da wurde er von der rechten Seite des Tales am gesegneten Ort aus dem Baum angerufen: O Moses, wahrlich, Ich bin Allah, der Herr der Welten.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmcclxxxiii{Und wirf deinen Stock hin." Als er ihn sich regen sah, als wäre er eine Riesenschlange, da wandte er sich zur Flucht und schaute nicht zurück. ``O Moses, tritt vor und fürchte dich nicht; denn du gehörst zu jenen, die in Sicherheit sind.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmcclxxxiv{Steck deine Hand in deinen Hemdschlitz; sie wird ohne Übel weiß hervorkommen; und zieh deinen Arm an dich, um die Ängstlichkeit von dir zu jagen. Das sollen zwei Beweise von deinem Herrn für Pharao und seine Vornehmen sein; denn sie sind ein frevelndes Volk."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmcclxxxv{Er sagte: ``Mein Herr, ich habe einen von ihnen erschlagen, und ich fürchte, sie werden mich töten.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmcclxxxvi{Und mein Bruder Aaron - er ist beredter als ich mit seiner Zunge; sende ihn darum als Helfer mit mir, auf daß er mich bestätige; denn ich fürchte, sie werden mich der Falschheit bezichtigen."\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmcclxxxvii{Er sprach: ``Wir wollen dich mit deinem Bruder stärken, und Wir wollen euch beiden Macht geben, so daß sie euch nicht erreichen werden - durch Unsere Zeichen. Ihr beide und die, welche euch folgen, werden die Sieger sein."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmcclxxxviii{Als dann Moses zu ihnen mit Unseren deutlichen Zeichen kam, da sagten sie: ``Das ist nichts als ein Zaubertrug, und wir haben von unseren Vorvätern nie dergleichen gehört."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmcclxxxix{Und Moses sagte: ``Mein Herr weiß am besten, wer es ist, der Seine Führung gebracht hat, und wem der glückselige Lohn der Wohnstatt zuteil werden wird. Wahrlich, die Frevler haben nie Erfolg."\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmccxc{Und Pharao sagte: ``O ihr Vornehmen, ich kenne keinen anderen Gott für euch au ßer mir; so brenne mir, O Haman, (Ziegel aus) Ton und mache mir einen Turm, damit ich den Gott Moses' erblicken kann, obgleich ich ihn gewiß für einen Lügner erachte."\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmccxci{Und er und seine Heerscharen verhielten sich hochmütig im Lande, ohne die Rechtfertigung dazu. Und sie meinten, nie zu Uns zurückgebracht zu werden.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmccxcii{So erfaßten Wir ihn und seine Heerscharen und setzten sie mitten im Meer aus. Schau darum, wie der Ausgang der Missetäter war!\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmccxciii{Und Wir machten sie zu Führern, welche (Menschen) zum Feuer luden; und am Tage der Auferstehung werden sie keinen Beistand finden.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmccxciv{Und Wir ließen ihnen in dieser Welt einen Fluch folgen; und am Tage der Auferstehung werden sie unter den Verabscheuten sein.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmccxcv{Und wahrlich, Wir gaben Moses die Schrift, nachdem Wir die früheren Geschlechter vernichtet hatten, als ein Mittel zur Ermahnung für die Menschen und als Führung und Barmherzigkeit, auf daß sie (Meiner Macht) eingedenk sein mögen.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmccxcvi{Und du warst weder auf der westlichen Seite, als Wir Moses den Auftrag gaben, noch warst du unter den Augenzeugen.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmccxcvii{Jedoch Wir ließen (nach Moses) Generationen entstehen, und das Leben wurde ihnen lang! Und du verweiltest nicht unter dem Volk von Madyan, um ihnen Unsere Zeichen vorzutragen; Wir aber schickten (ihnen) Gesandte.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmccxcviii{Und du warst nicht auf der Seite des Berges als Wir (Moses) anriefen. Vielmehr (haben Wir dich) als eine Barmherzigkeit deines Herrn (entsandt), damit du ein Volk warnen mögest, zu dem vor dir kein Warner gekommen war, auf daß sie ermahnt seien.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmccxcix{Und wäre es nicht (nur deshalb), daß sie nicht sagen können, wenn ein Unglück sie um dessentwillen treffen sollte, was ihre Hände vorausgeschickt haben: ``Unser Herr, warum hast Du uns keine Gesandten geschickt, daß wir Deine Zeichen hätten befolgen können und dann unter den Gläubigen gewesen wären?"\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmccc{Doch als nun die Wahrheit von Uns zu ihnen kam, da sagten sie: ``Warum ist ihm nicht das gleiche gegeben worden wie das, was Moses gegeben wurde?" Haben sie denn nicht das geleugnet, was Moses zuvor gegeben wurde? Sie hatten gesagt: ``(Dies sind) zwei Zauberwerke, die einander stützen." Und sie sagten: ``Wir leugnen beide."\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmccci{Sprich: ``So bringt ein Buch von Allah herbei, das eine bessere Führung als diese beiden hat, damit ich ihm folge, wenn ihr wahrhaftig seid."\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmcccii{Doch wenn sie dir keine Folge leisten, dann wisse, daß sie nur ihren eigenen Neigungen folgen. Und wer ist irrender als der, der ohne Führung Allahs seinen eigenen Neigungen folgt? Wahrlich, Allah leitet das ungerechte Volk nicht.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmccciii{Und wahrlich, Wir haben ihnen das Wort immer wieder übermittelt, auf daß sie ermahnt seien.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmccciv{Diejenigen, denen Wir die Schrift zuvor gegeben haben, glauben an sie.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmcccv{Und wenn sie ihnen verlesen wird, dann sagen sie: ``Wir glauben daran. Wahrlich, es ist die Wahrheit von unserem Herrn; wir hatten uns (Ihm) schon vordem ergeben."\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmcccvi{Diese werden ihren Lohn zweimal erhalten, weil sie geduldig waren und das Böse durch das Gute abwehrten und von dem spendeten, was Wir ihnen gegeben hatten.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmcccvii{Und wenn sie leeres Gerede hören, so wenden sie sich davon ab und sagen: ``Für uns (seien) unsere Taten und für euch (seien) eure Taten. Friede sei mit euch! Wir suchen keine Unwissenden."\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmcccviii{Wahrlich, du kannst dem den Weg nicht weisen, den du liebst; Allah aber weist dem den Weg, dem Er will; und Er kennt jene am besten, die die Führung annehmen.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmcccix{Und sie sagen: ``Wenn wir deiner Führung folgten, so würden wir von unserem Land weggerissen werden." Haben Wir denn kein sicheres Schutzgebiet errichtet, zu dem die Früchte aller Art gebracht werden als Versorgung von Uns? Jedoch die meisten von ihnen wissen es nicht.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmcccx{Und wie so manche Stadt haben Wir vernichtet, die sich ihrer Fülle des Unterhalts rühmte! Und dort stehen ihre Wohnstät ten, die nach ihnen nicht bewohnt worden sind - mit Ausnahme einiger weniger. Und Wir wurden die Erben.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmcccxi{Und dein Herr würde nie die Städte zerstören, ohne zuvor in ihrer Mitte einen Gesandten erweckt zu haben, der ihnen Unsere Verse verliest; noch zerstörten Wir die Städte, ohne daß ihre Bewohner (zuvor) ge frevelt hätten.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmcccxii{Und was euch auch an Dingen gegeben wurde - es ist nur eine zeitweilige Nutznießung des irdischen Lebens und sein Schmuck; und das aber, was bei Allah ist, ist besser und bleibender. Wollt ihr denn nicht begreifen?\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmcccxiii{Ist denn der, dem Wir eine schöne Verheißung gaben, die er erfüllt sehen wird, gleich jenem, den Wir mit den guten Dingen des irdischen Lebens versorgt haben? Doch dann, am Tage der Auferstehung, wird er unter den Vorgeführten sein.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmcccxiv{An jenem Tage wird Er sie rufen und sprechen: ``Wo sind nun Meine Partner, die ihr wähntet?"\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmcccxv{Diejenigen, über die das Urteil gefällt wird, sagen: ``Unser Herr, dies sind jene, die wir irreführten. Wir führten sie irre, wie wir selbst irregingen. Wir sprechen uns vor Dir (von ihnen) los. Nicht wir waren es, die sie anbeteten."\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmcccxvi{Und es wird gesprochen: ``Ruft eure Götter an." Und sie werden sie anrufen, doch jene werden ihnen nicht antworten. Und sie werden die Strafe erleben. Wären sie doch dem rechten Weg gefolgt!\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmcccxvii{Und an jenem Tage wird Er sie rufen und sprechen: ``Welche Antwort gabt ihr den Gesandten?"\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmcccxviii{Dann werden ihnen an jenem Tage alle Ausreden dunkel werden, und sie werden einander nicht befragen können.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmcccxix{Der aber, der bereut und glaubt und das Rechte wirkt - (es ist) wohl, daß er unter den Erfolgreichen sein wird.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmcccxx{Und dein Herr erschafft, was Er will, und erwählt, was Ihm gefällt. Nicht ihnen steht die Wahl zu. Gepriesen sei Allah und Hoch Erhaben über das, was sie anbeten!\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmcccxxi{Und dein Herr weiß, was ihre Herzen verbergen und was sie offenbaren.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmcccxxii{Und Er ist Allah; es ist kein Gott außer Ihm. Ihm gebührt aller Preis am Anfang und am Ende. Sein ist die Herrschaft, und zu Ihm werdet ihr zurückgebracht.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmcccxxiii{Sprich: ``Was haltet ihr davon, wenn Allah die Nacht über euch bis zum Tage der Auferstehung dauern ließe? Welcher Gott außer Allah könnte euch ein Licht bringen? Wollt ihr denn nicht hören?"\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmcccxxiv{Sprich: ``Was haltet ihr davon, wenn Allah den Tag über euch bis zum Tage der Auferstehung dauern ließe? Welcher Gott außer Allah könnte euch eine Nacht zur Ruhe bringen? Wollt ihr es denn nicht einsehen?"\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmcccxxv{Und in Seiner Barmherzigkeit schuf Er für euch die Nacht und den Tag, auf daß ihr darin ruhen möget und auf daß ihr nach Seiner Huld trachtet und dankbar sein möget.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmcccxxvi{Und an jenem Tage wird Er sie rufen und sprechen: ``Wo sind nun Meine Partner, die ihr wähntet?"\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmcccxxvii{Und Wir werden aus jedem Volke einen Zeugen holen und sprechen: ``Bringt euren Beweis herbei." Dann werden sie erkennen, daß die Wahrheit Allahs ist. Und das, was sie zu erdichten pflegten, wird für sie verloren sein.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmcccxxviii{Wahrlich, Korah gehörte zum Volke Moses', und doch unterdrückte er es. Und wir gaben ihm so viel Schätze, daß ihre Schlüssel sicher eine Bürde für eine Schar von Starken gewesen wären. Da sagte sein Volk zu ihm: ``Freue dich nicht; denn Allah liebt diejenigen nicht, die frohlocken.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmcccxxix{Sondern suche in dem, was Allah dir gegeben hat, die Wohnstatt des Jenseits; und vergiß deinen Teil an der Welt nicht; und tue Gutes, wie Allah dir Gutes getan hat; und begehre kein Unheil auf Erden; denn Allah liebt die Unheilstifter nicht."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmcccxxx{Er sagte: ``Es (die Schätze) wurde mir nur um des Wissens willen, das ich besitze, gegeben." Wußte er denn nicht, daß Allah vor ihm schon Generationen vernichtet hatte, die noch gewaltigere Macht und größeren Reichtum als er besaßen? Und die Schuldigen werden nicht nach ihren Sünden befragt.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmcccxxxi{So ging er denn in seinem Schmuck hinaus zu seinem Volk. Jene nun, die nach dem Leben in dieser Welt begierig waren, sagten: ``O wenn wir doch das gleiche besäßen wie das, was Korah gegeben wurde! Er hat wahrlich großes Glück."\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmmcccxxxii{Die aber, denen Wissen zuteil geworden war, sagten: ``Wehe euch, Allahs Lohn ist besser für den, der glaubt und gute Werke tut; und keiner wird ihn erlangen außer den Geduldigen."\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmmcccxxxiii{Dann ließen Wir ihn von der Erde verschlingen und (auch) sein Haus; und er hatte keine Schar, die ihm gegen Allah helfen konnte, noch konnte er sich (selbst) retten.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmmcccxxxiv{Und jene, die sich noch tags zuvor an seine Stelle gewünscht hatten, sagten: ``Ah sieh! Es ist wahrlich Allah, Der denen von Seinen Dienern die Mittel zum Unterhalt erweitert und beschränkt, denen Er will. Wäre uns Allah nicht Gnädig gewesen, hätte Er uns (von der Erde) verschlingen lassen. Ah sieh! Die Ungläubigen haben nie Erfolg."\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmmcccxxxv{Jene Wohnstatt im Jenseits! Wir geben sie denen, die weder Selbsterhöhung auf Erden noch irgendein (anderes) Verderbnis begehren. Und der Ausgang ist für die Gottesfürchti gen.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmmcccxxxvi{Wer Gutes vollbringt, soll Besseres als das erhalten; wer jedoch eine böse Tat vollbringt - jene, die böse Werke tun, sollen nur gemäß dem belohnt werden, was sie getan haben.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmmcccxxxvii{Wahrlich, Er, Der den Quran bindend für dich gemacht hat - Er wird dich zur Stätte der Wiederkehr zurückbringen. Sprich: ``Mein Herr weiß am besten, wer es ist, der auf dem rechten Weg ist, und wer sich in einem offenbaren Irrtum befindet."\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmmcccxxxviii{Und du hattest selbst keine Hoffnung, daß dir das Buch offenbart würde; allein es ist eine Barmherzigkeit deines Herrn; darum sei nicht ein Beistand für die Ungläubigen.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmmcccxxxix{Und laß dich von niemandem von den Zeichen Allahs abwenden, nachdem sie zu dir niedergesandt worden sind; und rufe (die Menschen) zu deinem Herrn und sei nicht einer der Götzendiener.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmmcccxl{Und rufe neben Allah keinen anderen Gott an. Es ist kein Gott außer Ihm. Alle Dinge sind vergänglich, bis auf Sein Angesicht. Sein ist die Herrschaft und zu Ihm werdet ihr zurückgebracht werden.\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmmcccxli{\basmalahde Alif Lam Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmcccxlii{Meinen die Menschen, sie würden in Ruhe gelassen werden, wenn sie bloß sagten: ``Wir glauben", und meinen sie, sie würden nicht auf die Probe gestellt?\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmcccxliii{Und Wir stellten doch die auf die Probe, die vor ihnen waren. Also wird Allah gewiß die erkennen, die wahrhaftig sind, und gewiß wird Er die Lügner er kennen.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmcccxliv{Oder glauben diejenigen, die böse Taten begehen, daß sie Uns entrinnen könnten? Übel ist es, wie sie urteilen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmcccxlv{Wer mit Allahs Begegnung rechnet, (der soll wissen, daß) Allahs angesetzte Frist sicher abläuft. Und Er ist der Allhörende, der Allwissende.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmcccxlvi{Und wer da eifert, eifert nur für seine eigene Seele; denn Allah ist auf niemanden von allen Welten angewiesen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmcccxlvii{Und jene, die glauben und gute Werke tun - wahrlich, Wir werden ihre Übel von ihnen nehmen und ihnen den besten Lohn für ihre Taten geben.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmcccxlviii{Und Wir haben dem Menschen anbefohlen, seinen Eltern Gutes zu tun. Doch wenn sie dich zwingen wollen, Mir das zur Seite zu stellen, wovon du keine Kenntnis hast, so gehorche ihnen nicht. Zu Mir werdet ihr heimkehren, (und) dann will Ich euch verkünden, was ihr getan habt.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmcccxlix{Und jene, die glauben und gute Werke tun - wahrlich, Wir werden sie bei den Rechtschaffenen einführen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmcccl{Und unter den Menschen sind manche, die sagen: ``Wir glauben an Allah", doch wenn sie für Allahs Sache Ungemach erleiden, so betrachten sie die Anfeindung von Menschen als der Strafe Allahs gleich. Kommt aber Hilfe von deinem Herrn, dann sagen sie gewiß: ``Wahrlich, wir waren mit euch." Ist es nicht Allah, Der am besten weiß, was in den Herzen aller Geschöpfe ist?\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmcccli{Und Allah wird sicherlich die bezeichnen, die glauben, und Er wird sicherlich die Heuchler bezeichnen.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmccclii{Und die Ungläubigen sagen zu denen, die glauben: ``Wenn ihr unserem Weg folgt, so wollen wir eure Sünden tragen." Sie können doch nichts von ihren Sünden tragen. Sie sind gewiß Lügner.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmcccliii{Aber sie sollen wahrlich ihre eigenen Lasten tragen und (noch) Lasten zu ihren Lasten dazu. Und sie werden gewiß am Tage der Auferstehung über das befragt werden, was sie erdichtet haben.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmcccliv{Und wahrlich, Wir sandten Noah zu seinem Volke, und er weilte unter ihnen eintausend Jahre weniger fünfzig Jahre. Da ereilte sie die Sintflut, weil sie Missetäter waren.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmccclv{Aber Wir erretteten ihn und die Schiffsinsassen; und Wir machten sie zu einem Zeichen für alle Völker.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmccclvi{Und Abraham sagte zu seinem Volk: ``Dient Allah und fürchtet Ihn. Das ist besser für euch, wenn ihr es wüßtet.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmccclvii{Ihr dient nur Götzen statt Allah, und ihr ersinnt eine Lüge. Jene, die ihr statt Allah dient, vermögen euch nicht zu versorgen. Sucht darum bei Allah die Versorgung und dient Ihm und seid Ihm dankbar. Zu Ihm werdet ihr zurückgebracht werden.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmccclviii{Und wenn ihr es für Lüge erklärt, so haben Generationen vor euch es für Lüge gehalten. Und dem Gesandten obliegt nur die deutliche Verkündigung."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmccclix{Sehen sie denn nicht, wie Allah die Schöpfung hervorbringt und sie dann wiederholt? Das ist wahrlich ein leichtes für Allah.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmccclx{Sprich: ``Zieht auf Erden umher und schauet, wie Er ein erstes Mal die Schöpfung hervorbrachte. Sodann ruft Allah die zweite Schöpfung hervor." Wahrlich, Allah hat Macht über alle Dinge.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmccclxi{Er bestraft, wen Er will, und erweist Barmherzigkeit, wem Er will; und zu Ihm werdet ihr zurückkehren.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmccclxii{Und ihr könnt (Allahs Pläne) nicht vereiteln, weder auf Erden noch im Himmel, noch habt ihr einen Beschützer oder Helfer außer Allah.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmccclxiii{Und diejenigen, die nicht an die Zeichen Allahs und an die Begegnung mit Ihm glauben - sie sind es, die an Meiner Barmherzigkeit zweifeln. Und ihnen wird eine schmerzliche Strafe zuteil sein.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmccclxiv{Die Antwort seines Volkes waren nur die Worte: ``Erschlagt ihn (Abraham) oder verbrennt ihn." Doch Allah errettete ihn aus dem Feuer. Hierin liegen wahrlich Zeichen für Leute, die glauben.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmccclxv{Und er sagte: ``lhr habt euch nur Götzen statt Allah genommen um die Beziehung zueinander im irdischen Leben zu pflegen. Dann aber, am Tage der Auferstehung, werdet ihr einander verleugnen und verfluchen. Und eure Herberge wird das Feuer sein; und ihr werdet keine Helfer finden."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmccclxvi{Da glaubte Lot ihm; und (Abraham) sagte: ``lch werde zu meinem Herrn auswandern; Er ist der Allmächtige, der Allweise."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmccclxvii{Und Wir schenkten ihm Isaak und Jakob und gaben seinen Nachkommen das Prophetentum und die Schrift; und Wir gaben ihm seinen Lohn im Diesseits; und im Jenseits wird er gewiß unter den Rechtschaffenen sein.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmccclxviii{Und da sagte Lot zu seinem Volk: ``lhr begeht eine Schändlichkeit, die keiner von allen Menschen je vor euch begangen hat.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmccclxix{Vergeht ihr euch tatsächlich an Männern und macht die Wege unsicher? Und bei euren Versammlungen begeht ihr Abscheuliches!" Jedoch die Antwort seines Volkes waren nur die Worte: ``Bringe Allahs Strafe über uns, wenn du die Wahrheit redest."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmccclxx{Er sagte: ``Hilf mir mein Herr, gegen das Volk, das frevelt."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmccclxxi{Und als Unsere Boten Abraham die frohe Botschaft brachten, sprachen sie: ``Wir kommen, um die Bewohner dieser Stadt zu vernichten; denn ihre Bewohner sind Missetäter."\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmccclxxii{Er sagte: ``Doch Lot ist dort."Sie sprachen: ``Wir wissen recht wohl, wer dort ist. Gewiß, wir werden ihn und die Seinen erretten, bis auf seine Frau, die zu denen gehört, die zurückbleiben sollen."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmccclxxiii{Und als Unsere Boten zu Lot kamen, war er ihretwegen besorgt und fühlte sich außerstande, ihnen zu helfen. Sie sprachen: ``Fürchte dich nicht und sei nicht traurig, wir wollen dich und die Deinen sicher retten, bis auf deine Frau, die zu denen gehört, die zurückbleiben sollen.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmccclxxiv{Wir werden über die Bewohner dieser Stadt eine Strafe vom Himmel niedergehen lassen, weil sie gefrevelt haben."\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmccclxxv{Und Wir haben davon ein klares Zeichen für die Leute zurückgelassen, die Verstand haben.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmccclxxvi{Und zu Madyan (entsandten Wir) ihren Bruder Suaib, der sagte: ``O mein Volk, dient Allah und fürchtet den Jüngsten Tag und tobt nicht aus auf Erden, indem ihr Unheil stiftet."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmccclxxvii{Jedoch sie erklärten ihn für einen Lügner. Da erfaßte sie ein heftiges Beben, und sie lagen in ihren Wohnungen auf dem Boden.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmccclxxviii{Und (Wir vernichteten) die `Ad und die Tamud; und dies ist aus ihren Wohnstätten für euch klar ersichtlich. Und Satan ließ ihnen ihre Werke wohlgefällig erscheinen und hielt sie von dem Weg ab, obwohl sie einsichtig waren.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmccclxxix{Und (Wir vernichteten) Korah und Pharao und Haman. Und Moses kam wahrlich mit deutlichen Beweisen zu ihnen, doch sie betrugen sich hochmütig auf Erden; (Uns) aber konnten sie nicht entrinnen.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmccclxxx{So erfaßten Wir einen jeden in seiner Sünde; es waren unter ihnen welche, gegen die Wir einen Sandsturm schickten, und welche, die der Schrei ereilte, und welche, unter denen Wir die Erde versinken ließen, und welche, die Wir ertränkten. Und nicht Allah wollte ihnen Unrecht tun, sondern sie taten sich selbst Unrecht.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmccclxxxi{Das Gleichnis derer, die sich Helfer außer Allah nehmen, ist wie das Gleichnis von der Spinne, die sich ein Haus macht; und das gebrechlichste der Häuser ist gewiß das Haus der Spinne - wenn sie es nur begriffen!\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmccclxxxii{Wahrlich, Allah kennt all das, was sie an Seiner Statt anrufen; und Er ist der Allmächtige, der Allweise.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmccclxxxiii{Und dies sind Gleichnisse, die Wir den Menschen prägen; doch es verstehen sie nur jene, die Wissen haben.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmccclxxxiv{Allah erschuf die Himmel und die Erde in makelloser Weise. Hierin liegt wahrlich ein Zeichen für die Gläubigen.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmccclxxxv{Verlies, was dir von dem Buche offenbart wurde, und verrichte das Gebet. Wahrlich, das Gebet hält von schändlichen und abscheulichen Dingen ab; und Allahs zu gedenken, ist gewiß das Höchste. Und Allah weiß, was ihr begeht.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmccclxxxvi{Und streitet nicht mit dem Volk der Schrift; es sei denn auf die beste Art und Weise. Ausgenommen davon sind jene, die ungerecht sind. Und sprecht: ``Wir glauben an das, was zu uns herabgesandt wurde und was zu euch herabgesandt wurde; und unser Gott und euer Gott ist Einer; und Ihm sind wir ergeben."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmccclxxxvii{Und somit haben Wir dir das Buch herniedergesandt, und so glauben diejenigen daran, denen Wir das Buch gegeben haben; und unter diesen sind einige, die daran glauben. Es sind aber nur die Ungläubigen, die Unsere Zeichen leugnen.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmccclxxxviii{Und nie zuvor hast du in einem Buch gelesen, noch konntest du eines mit deiner Rechten schreiben; sonst hätten die Verleugner daran gezweifelt.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmccclxxxix{Nein, es sind klare Zeichen in den Herzen derer, denen das Wissen gegeben wurde. Es gibt keinen, der Unsere Zeichen leugnet außer den Ungerechten.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmcccxc{Und sie sagten: ``Warum wurden keine Zeichen zu ihm von seinem Herrn herabgesandt?" Sprich: ``Die Zeichen sind allein bei Allah, und ich bin nur ein deutlicher Warner."\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmcccxci{Genügt es ihnen denn nicht, daß Wir dir das Buch herniedergesandt haben, das ihnen verlesen wird? Wahrlich, hierin ist eine Barmherzigkeit und Ermahnung für ein Volk, das glaubt.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmcccxcii{Sprich: ``Allah genügt als Zeuge gegen mich und euch. Er weiß, was in den Himmeln und was auf Erden ist. Und diejenigen, die das Falsche annehmen und Allah ablehnen - das sind die Verlierenden."\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmcccxciii{Und sie verlangen von dir, daß du die Strafe beschleunigen sollst. Wäre nicht eine Frist festgesetzt worden, hätte die Strafe sie schon ereilt; und sie wird gewiß unerwartet über sie kommen, ohne daß sie es merken.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmcccxciv{Sie verlangen von dir, daß du die Strafe beschleunigen sollst; doch wahrlich, Gahannam wird die Ungläubigen einschließen.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmcccxcv{An dem Tage, da die Strafe sie von oben und von ihren Füßen her überwältigen wird, wird Er sprechen: ``Kostet nun die (Früchte) eurer Taten."\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmcccxcvi{O Meine Diener, die ihr glaubt, Meine Erde ist weit. Darum verehrt nur Mich.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmcccxcvii{Jede Seele wird den Tod kosten; zu Uns werdet ihr dann zurückgebracht.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmcccxcviii{Und jene, die glauben und gute Werke tun, beherbergen Wir in den oberen Gemächern des Paradieses, durch das Bäche fließen. Darin verweilen sie auf immerdar. Herrlich ist der Lohn derjenigen, die wohltätig sind\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmcccxcix{die da standhaft sind und auf ihren Herrn vertrauen.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmcd{Und wie viele Tiere gibt es, die nicht ihre eigene Versorgung tragen. Allah versorgt sie und euch. Und Er ist der Allhörende, der Allwissende.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmcdi{Und wenn du sie fragst: ``Wer hat die Himmel und die Erde geschaffen und euch die Sonne und den Mond dienstbar gemacht?" dann werden sie gewiß sagen: ``Allah." Wieso lassen sie sich dann (von Allah) abwenden?\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmcdii{Allah erweitert und beschränkt die Mittel zum Unterhalt dem von Seinen Dienern, den Er will. Wahrlich, Allah besitzt die volle Kenntnis von allen Dingen.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmcdiii{Und wenn du sie fragst: ``Wer sendet Wasser vom Himmel nieder und belebt damit die Erde nach ihrem Tod?" - dann werden sie gewiß sagen: ``Allah." Sprich: ``Aller Preis gebührt Allah." Jedoch die meisten von ihnen begreifen es nicht.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmcdiv{Dieses irdische Leben ist nichts als ein Zeitvertreib und ein Spiel; die Wohnstatt des Jenseits aber - das ist das eigentliche Leben, wenn sie es nur wüßten!\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmcdv{Und wenn sie ein Schiff besteigen, dann rufen sie Allah reinen Glaubens an. Bringt Er sie dann aber heil ans Land, siehe, dann stellen sie (ihm) Götter zur Seite\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmcdvi{und leugnen somit das, was Wir ihnen beschert haben, und ergötzen sich. Bald aber werden sie es erfahren!\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmcdvii{Haben sie denn nicht gesehen, daß Wir ein Schutzgebiet sicher gemacht haben, während die (anderen) Menschen in ihrer Umgebung hinweggerissen werden? Wollen sie da noch an (etwas) Falsches glauben und die Huld Allahs leugnen?\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmcdviii{Und wer ist ungerechter als jener, der eine Lüge gegen Allah erdichtet oder die Wahrheit verwirft, wenn sie zu ihm kommt? Existiert denn für die Ungläubigen keine Wohnstatt in Gahannam?\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmcdix{Und diejenigen, die in Unserer Sache wetteifern - Wir werden sie gewiß auf Unseren Wegen leiten. Wahrlich, Allah ist mit denen, die Gutes tun.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmcdx{\basmalahde Alif Lam Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmcdxi{Besiegt sind die Byzantiner\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmcdxii{in dem nahegelegenen Land, doch sie werden nach ihrer Niederlage siegen\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmcdxiii{in wenigen Jahren - Allahs ist die Herrschaft vorher und nachher -, und an jenem Tage werden sich die Gläubigen freuen\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmcdxiv{über Allahs Hilfe. Er hilft, wem Er will; und Er ist der Allmächtige, der Barmherzige.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmcdxv{(Das ist) die Verheißung Allahs - Allah bricht Seine Verheißung nicht -; allein die meisten Menschen wissen es nicht.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmcdxvi{Sie kennen nur die Außenseite des diesseitigen Lebens; das Jenseits aber beachten sie gar nicht.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmcdxvii{Haben sie sich denn über sich selbst keine Gedanken gemacht? Allah hat die Himmel und die Erde und das, was zwischen beiden ist, nur in gerechter Weise und für eine bestimmte Frist geschaffen. Doch wahrlich, viele der Menschen glauben nicht an die Begegnung mit ihrem Herrn.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmcdxviii{Sind sie denn nicht im Lande umhergezogen, so daß sie schauen konnten, wie das Ende derer war, die vor ihnen lebten? Jene waren noch mächtiger als sie, und sie bebauten das Land und bevölkerten es mehr, als diese es bevölkert haben. Und ihre Gesandten kamen mit den Beweisen zu ihnen. Und nicht Allah wollte ihnen Unrecht antun, sondern sie taten sich selbst Unrecht.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmcdxix{Und dann war das Ende derer, die selbes begingen, das schlimmste, daß sie die Zeichen Allahs verwarfen und über sie zu spotten pflegten.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmcdxx{Allah bringt die Schöpfung hervor; sodann läßt er sie wiederholen; dann werdet ihr zu Ihm zurückgebracht.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmcdxxi{Und an dem Tage, da die Stunde herankommt, werden die Schuldigen von Verzweiflung überwältigt sein.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmcdxxii{Denn keiner von ihren Partnern wird ihr Fürsprecher sein; und sie werden ihre Partner verleugnen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmcdxxiii{Und an dem Tage, da die Stunde herankommt, an jenem Tage werden sie voneinander getrennt sein.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmcdxxiv{Was nun die betrifft, die glaubten und gute Werke taten, so werden sie in einem Garten Glück finden.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmcdxxv{Jene aber, die ungläubig waren und Unsere Zeichen und die Begegnung (mit Uns) im Jenseits leugneten, werden zur Bestrafung vorgeführt.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmcdxxvi{Preis sei denn Allah, wenn ihr den Abend und wenn ihr den Morgen verbringt\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmcdxxvii{denn Ihm gebührt alles Lob in den Himmeln und auf Erden und am Abend und zu eurer Mittagsruhe.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmcdxxviii{Er läßt das Lebendige aus dem Toten und das Tote aus dem Lebendigen hervorgehen; und Er belebt die Erde nach ihrem Tod, und in gleicher Weise sollt ihr wieder hervorgebracht werden.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmcdxxix{Und unter Seinen Zeichen ist dies, daß Er euch aus Erde erschuf; alsdann, seht, seid ihr Menschen geworden, die sich vermehren.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmcdxxx{Und unter Seinen Zeichen ist dies, daß Er Gattinnen für euch aus euch selber schuf, auf daß ihr Frieden bei ihnen fändet; und Er hat Zuneigung und Barmherzigkeit zwischen euch gesetzt. Hierin liegen wahrlich Zeichen für ein Volk, das nachdenkt.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmcdxxxi{Und unter Seinen Zeichen sind die Schöpfung der Himmel und der Erde und die Verschiedenheit eurer Sprachen und Farben. Hierin sind wahrlich Zeichen für die Wissenden.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmcdxxxii{Und zu Seinen Zeichen zählt euer Schlafen bei Nacht und euer Trachten nach Seiner Gnadenfülle bei Tage. Hierin sind wahrlich Zeichen für ein Volk, das hört.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmcdxxxiii{Und zu Seinen Zeichen gehört dies, daß Er euch den Blitz zu Furcht und Hoffnung zeigt und Wasser vom Himmel herniedersendet und damit die Erde nach ihrem Tod belebt. Hierin sind wahrlich Zeichen für ein Volk, das begreift.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmcdxxxiv{Und unter Seinen Zeichen ist dies, daß Himmel und Erde auf Sein Geheiß hin fest stehen. Als dann, wenn Er euch mit einem Ruf aus der Erde ruft, seht, dann werdet ihr (daraus) hervorgehen.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmcdxxxv{Und Sein ist, wer in den Himmeln und auf der Erde ist. Alle sind Ihm gehorsam.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmcdxxxvi{Und Er ist es, Der die Schöpfung hervorbringt, dann wiederholt Er sie, und dies fällt Ihm noch leichter. Und Er Selbst stellt das schönste Gleichnis in den Himmeln und auf Erden dar; und Er ist der Allmächtige, der Allweise.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmcdxxxvii{Er prägt euch ein Gleichnis eurer eigenen Lage. Habt ihr unter denen, die ihr von Rechts wegen besitzt, Teilhaber an dem, was Wir euch beschert haben? Seid ihr darin also gleich (und) fürchtet sie, wie ihr einander fürchtet? So machen Wir die Zeichen klar für ein Volk, das begreift.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmcdxxxviii{Doch die Ungerechten folgen ohne Wissen ihren persönlichen Neigungen. Und wer kann den leiten, den Allah zum Irrenden erklärt? Für solche wird es keine Helfer geben.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmcdxxxix{So richte dein Antlitz in aufrichtiger Weise auf den Glauben; (dies entspricht) der natürlichen Veranlagung, mit der Allah die Menschen geschaffen hat. Es gibt keine Veränderung an Allahs Schöpfung. Das ist der beständige Glaube. Allein die meisten Menschen wissen es nicht.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmcdxl{Wendet euch zu Ihm und fürchtet Ihn und verrichtet das Gebet und seid nicht unter den Götzendienern.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmcdxli{Von denen, die ihren Glauben gespalten haben und zu Parteien geworden sind - jede Partei freut sich über das, was sie selbst hat.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmcdxlii{Und wenn die Menschen ein Schaden trifft, dann rufen sie ihren Herrn an und wenden sich reumütig zu Ihm; hernach aber, wenn Er sie dann von Seiner Barmherzigkeit kosten läßt, siehe, dann stellen einige von ihnen ihrem Herrn Götter zur Seite\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmcdxliii{und verleugnen somit das, was Wir ihnen gegeben haben. Ergötzt euch denn (eine Weile), bald jedoch werdet ihr es wissen.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmcdxliv{Haben Wir ihnen etwa eine Ermächtigung niedergesandt, die für das spräche, was sie Ihm zur Seite stellen?\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmcdxlv{Und wenn Wir die Menschen Barmherzigkeit kosten lassen, freuen sie sich darüber; doch wenn sie ein Übel um dessentwillen befällt, was ihre eigenen Hände vorausgeschickt haben, siehe, dann verzweifeln sie.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmcdxlvi{Haben sie denn nicht gesehen, daß Allah dem, dem Er will, die Mittel zum Unterhalt erweitert und beschränkt? Hierin sind wahrlich Zeichen für Leute, die glauben.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmcdxlvii{So gib dem Verwandten, was ihm zusteht, wie auch dem Bedürftigen und dem Sohn des Weges. Das ist das Beste für die, die nach Allahs Antlitz verlangen, und sie sind die Erfolgreichen.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmcdxlviii{Und was immer ihr auf Zinsen verleiht, damit es sich mit dem Gut der Menschen ver mehre; es vermehrt sich nicht vor Allah; doch was ihr an Zakah entrichtet, indem ihr nach Allahs Antlitz verlangt, sie sind es, die vielfache Mehrung empfangen werden.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmcdxlix{Allah ist es, Der euch erschaffen hat, und dann hat Er euch versorgt; dann wird Er euch sterben lassen, und dann wird Er euch wieder lebendig machen. Ist etwa unter euren Göttern einer, der davon etwas vollbringen könnte? Gepriesen sei Er und Hoch Erhaben über das, was sie anbeten!\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmcdl{Unheil ist auf dem Festland und auf dem Meer sichtbar geworden um dessentwillen, was die Hände der Menschen gewirkt haben, auf daß Er sie die (Früchte) so mancher ihrer Handlungen kosten lasse, damit sie sich besännen.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmcdli{Sprich: ``Wandert auf Erden umher und seht, wie das Ende derer zuvor war! Die meisten von ihnen waren Götzendiener."\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmcdlii{Richte also dein Antlitz auf den beständigen Glauben, bevor der Tag kommt, an dem es gegen Allah keine Wehr gibt. An jenem Tage werden sie auseinan derbrechen.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmcdliii{Wenn jemand ungläubig ist; so lastet auf ihm sein Unglaube! Und der, der Rechtes tut, bereitet es für sich selbst vor\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmcdliv{auf daß Er aus Seiner Gnadenfülle diejenigen belohnen möge, die glauben und das Rechte tun. Wahrlich, Er liebt die Ungläubigen nicht.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmcdlv{Und zu Seinen Zeichen gehört dies, daß Er die Winde mit frohen Botschaften entsendet, auf daß Er euch von Seiner Barmherzigkeit kosten lasse, und auf daß die Schiffe auf Sein Geheiß hin fahren mögen, und auf daß ihr nach Seiner Huld trachtet, und auf daß ihr dankbar sein möget.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmcdlvi{Und wahrlich, Wir schickten schon Gesandte vor dir zu ihren eigenen Leuten. Sie brachten ihnen klare Beweise. Dann bestraften Wir die Schuldigen; und es oblag Uns, den Gläubigen zu helfen.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmcdlvii{Allah ist es, Der die Winde entsendet, so daß sie Wolken zusammentreiben. Dann breitet Er sie am Himmel aus, wie Er will, und häuft sie Schicht auf Schicht auf; und du siehst den Regen aus ihrer Mitte hervorbrechen. Und wenn Er ihn auf die von Seinen Dienern, die Er will, fallen läßt, siehe, dann ahnen sie Gutes\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmcdlviii{obwohl sie zuvor, ehe er auf sie niedergesandt wurde, hoffnungslos waren.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmcdlix{Schau dann auf die Spuren von Allahs Barmherzigkeit, wie Er die Erde nach ihrem Tode belebt. Wahrlich, Derselbe wird auch die Toten erwecken; denn Er hat Macht über alle Dinge.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmcdlx{Und wenn Wir einen Wind entsendeten und sie sie (die Ernte) vergilbt (versengt) sähen, so würden sie gewiß danach undankbar sein.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmcdlxi{Weder kannst du die Toten hörend machen, noch kannst du die Tauben den Ruf hören lassen, wenn sie (Allah) den Rücken kehren\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmcdlxii{noch wirst du die Blinden aus ihrem Irrweg leiten können. Nur die wirst du hörend machen, die an Unsere Zeichen glauben und sich (Ihm) ergeben.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmcdlxiii{Allah ist es, Der euch in Schwäche erschaffen hat, und nach der Schwäche gab Er (euch) Stärke. Dann wiederum, nach der Stärke, gab Er (euch) Schwäche und graues Haar. Er schafft, was Er will. Und Er ist der Allwissende, der Allmächtige.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmcdlxiv{Und an dem Tage, wo die Stunde herankommt, werden die Schuldigen schwören, daß sie nicht länger als eine Stunde (auf Erden) weilten - so sehr sind sie an (Selbsttäuschung gewöhnt.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmcdlxv{Doch die, denen Kenntnis und Glauben verliehen wurden, sagen: ``lhr habt wahrlich gemäß dem Buche Allahs bis zum Tage der Auferstehung (im Grabe) geweilt. Und das ist der Tag der Auferstehung, allein ihr wolltet es nicht wissen."\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmcdlxvi{So werden denn an jenem Tage den Ungerechten ihre Ausreden nichts fruchten, noch werden sie Gunst finden.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmcdlxvii{Und wahrlich, Wir haben den Menschen in diesem Quran allerlei Gleichnisse geprägt; aber wenn du ihnen ein Zeichen bringst, dann werden jene, die ungläubig sind, sicher sagen: ``lhr bringt nur Unsinn vor."\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmcdlxviii{Und so versiegelt Allah die Herzen derer, die unwissend sind.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmcdlxix{So sei geduldig. Wahrlich, das Versprechen Allahs ist wahr. Und laß dich nicht von jenen ins Wanken bringen, die keine Gewißheit haben.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmcdlxx{\basmalahde Alif Lam Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmcdlxxi{Dies sind die Verse der vollkommenen Schrift\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmcdlxxii{eine Führung und eine Barmherzigkeit für jene, die Gutes tun\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmcdlxxiii{die das Gebet verrichten und die Zakah entrichten und fest ans Jenseits glauben.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmcdlxxiv{Sie sind es, die der Führung ihres Herrn folgen, und sie sind es, die erfolgreich sind.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmcdlxxv{Und unter den Menschen gibt es solche, die leeres Gerede vorziehen, um (Menschen) ohne Wissen von Allahs Weg hinweg in die Irre zu füh ren, und um damit Spott zu treiben. Solchen (Menschen) harrt eine schmähliche Strafe.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmcdlxxvi{Und wenn ihm Unsere Verse verlesen werden, so kehrt er sich überheblich (von ihnen) ab, als hätte er sie nicht gehört, als wären seine Ohren schwerhörig. So künde ihm eine schmerzliche Strafe an.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmcdlxxvii{Wahrlich, denen, die da glauben und gute Werke tun, werden Gärten der Wonne zuteil sein.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmcdlxxviii{Darin werden sie auf ewig weilen. (Dies ist) eine Verheißung Allahs in Wahrheit! Und Er ist der Allmächtige, der Allweise.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmcdlxxix{Er hat den Himmel ohne Stützen erschaffen, wie ihr seht, und Er hat in der Erde feste Berge gegründet, damit sie nicht ins Schwanken gerät, und hat allerlei Getier über sie verstreut. Und Wir senden Wasser aus dem Himmel nieder und lassen jede herrliche Gattung auf ihr sprießen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmcdlxxx{Dies ist Allahs Schöpfung. Zeigt mir nun, was andere außer Ihm geschaffen haben. Nein, die Ungerechten befinden sich in einem offenkundigen Irrtum.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmcdlxxxi{Und wahrlich, Wir verliehen Luqman Weisheit, auf daß er Allah dankbar sein möge: denn wer da dankbar ist, der ist dankbar zum Besten seiner eigenen Seele. Ist aber einer undankbar, dann ist Allah wahrlich auf keinen angewiesen, Preiswürdig.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmcdlxxxii{Und da sagte Luqman zu seinem Sohn, indem er ihn ermahnte: ``O mein Sohn, setze Allah keine Götter zur Seite; denn Götzendienst ist wahrlich ein gewaltiges Unrecht."\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmcdlxxxiii{Und Wir haben dem Menschen im Hinblick auf seine Eltern anbefohlen seine Mutter trug ihn in Schwäche über Schwäche, und seine Entwöhnung erfordert zwei Jahre -: ``Sei Mir und deinen Eltern dankbar. Zu Mir ist die Heimkehr.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmcdlxxxiv{Doch wenn sie dich auffordern, Mir das zur Seite zu setzen, wovon du keine Kenntnis hast, dann gehorche ihnen nicht. In weltlichen Dingen aber verkehre mit ihnen auf gütige Weise. Doch folge dem Weg dessen, der sich zu Mir wendet. Dann werdet ihr zu Mir zurückkehren, und Ich werde euch das verkünden, was ihr getan habt."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmcdlxxxv{``O mein Sohn, hätte es auch nur das Gewicht eines Senfkorns und wäre es in einem Felsen oder in den Himmeln oder in der Erde, Allah würde es gewiß hervorbringen. Wahrlich, Allah ist Gnädig, Kundig.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmcdlxxxvi{O mein Sohn, verrichte das Gebet und gebiete Gutes und verbiete Böses und ertrage geduldig, was dich auch treffen mag. Das ist wahrlich eine Stärke in allen Dingen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmcdlxxxvii{Und weise den Menschen nicht verächtlich deine Wange und schreite nicht mit Heiterkeit auf Erden; denn Allah liebt keine eingebildeten Prahler.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmcdlxxxviii{Und schreite gemessenen Schritts und dämpfe deine Stimme; denn wahrlich, die widerwärtigste der Stimmen ist die Stimme des Esels."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmcdlxxxix{Habt ihr denn nicht gesehen, daß Allah euch alles dienstbar gemacht hat, was in den Himmeln und was auf der Erde ist, und (daß Er) Seine Wohltaten reichlich über euch ergossen hat - in sichtbarer und unsichtbarer Weise? Und doch gibt es unter den Menschen so manchen, der ohne Kenntnis und ohne Führung und ohne ein erleuchtendes Buch (zu besitzen) über Allah streitet.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmcdxc{Und wenn zu ihnen gesagt wird: ``Folgt dem, was Allah herniedergesandt hat", dann sagen sie: ``Nein, wir wollen dem folgen wobei wir unsere Väter vorfanden." Wie? Selbst dann wenn Satan sie zu der Strafe des brennenden Feuers lädt?\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmcdxci{Und der aber, der sein Antlitz auf Allah richtet und Gutes tut, hat wahrlich die festeste Handhabe ergriffen. Und bei Allah ruht das Ende aller Dinge.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmcdxcii{Und wenn jemand ungläubig ist, so laß dich nicht durch seinen Unglauben bekümmern. Zu Uns werden sie heimkehren, dann werden Wir ihnen verkünden, was sie getan haben; denn Allah weiß recht wohl, was in den Herzen ist\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmcdxciii{Wir lassen sie sich eine kleine Weile ergötzen, dann aber werden Wir sie strenger Strafe zutreiben.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmcdxciv{Und wenn du sie fragst: ``Wer schuf die Himmel und die Erde?" dann werden sie gewiß sagen: ``Allah." Sprich: ``Alles Lob gebührt Allah." Jedoch die meisten von ihnen wissen es nicht.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmcdxcv{Allahs ist, was in den Himmeln und auf Erden ist. Wahrlich, Allah ist Der, Der auf keinen angewiesen ist, der Preiswürdige.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmcdxcvi{Und wenn alle Bäume, die auf der Erde sind, Schreibrohre wären und der Ozean (Tinte), und sieben Ozeane würden sie mit Nachschub versorgen, selbst dann könnten Allahs Worte nicht erschöpft werden. Wahrlich, Allah ist Allmächtig, Allweise.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmcdxcvii{Eure Erschaffung und eure Auferstehung sind (für Ihn so leicht wie die) eines einzigen Wesens. Wahrlich, Allah ist Allhörend, Allsehend.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmcdxcviii{Hast du denn nicht gesehen, daß Allah die Nacht in den Tag und den Tag in die Nacht übergehen läßt, und daß Er (euch) die Sonne und den Mond dienstbar gemacht hat, so daß jedes (Gestirn auf seiner Bahn) zu einem bestimmten Ziel läuft, und daß Allah wohl dessen kundig ist, was ihr tut?\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmcdxcix{Dies (ist so), weil Allah allein die Wahrheit ist und was sie sonst außer Ihm anrufen, ist das Falsche und weil Allah, Er, der Erhabene ist, der Große.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmd{Hast du denn nicht gesehen, daß die Schiffe durch Allahs Gnade auf dem Meer fahren, auf daß Er euch Seine Zeichen zeige? Hierin sind wahrlich Zeichen für jeden Standhaften, Dankbaren.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmdi{Und wenn Wogen sie gleich Hüllen bedecken, dann rufen sie Allah in lauterem Glauben an; doch rettet Er sie dann ans Land, so sind es (nur) einige von ihnen, die einen gemäßigten Standpunkt vertreten. Und niemand leugnet Unsere Zeichen, außer allen Treulosen, Undankbaren.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmdii{O ihr Menschen, fürchtet euren Herrn und fürchtet den Tag, da kein Vater für seinen Sohn etwas unternehmen kann und kein Sohn für seinen Vater im geringsten etwas unternehmen kann. Wahrlich, Allahs Verheißung ist wahr. Darum soll das Leben dieser Welt euch nicht verführen, noch sollt ihr euch über Allah mit (eurem) Denken selbst täuschen.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmdiii{Wahrlich, bei Allah allein ist die Kenntnis der Stunde. Er sendet den Regen nieder, und Er weiß, was in den Mutterschößen ist. Und niemand weiß, was er sich morgen zufügen wird, und niemand weiß, in welchem Lande er sterben wird. Wahrlich, Allah ist Allwissend, Allkundig.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmdiv{\basmalahde Alif Lam Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmdv{Die Offenbarung des Buches stammt ohne Zweifel vom Herrn der Welten.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmdvi{Oder sagen sie: ``Er hat es erdichtet?" Nein, es ist die Wahrheit von deinem Herrn, auf daß du ein Volk warnest, zu dem vor dir kein Warner gekommen ist, damit sie dem rechten Weg folgen mögen.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmdvii{Allah ist es, Der die Himmel und die Erde und alles, was zwischen beiden ist, in sechs Tagen erschuf; dann wandte Er Sich Seinem Reich majestätisch zu. Ihr habt außer Ihm weder einen wahren Freund noch einen Fürsprecher. Wollt ihr euch denn nicht ermahnen lassen?\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmdviii{Er verwaltet die An gelegenheiten von Himmel und Erde, (und) dann werden sie wieder zu Ihm emporsteigen in einem Tage, dessen Länge nach eurer Zeitrechnung tausend Jahre beträgt.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmdix{Er ist der Kenner des Verborgenen und des Sichtbaren, der Allmächtige, der Barmherzige\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmdx{Der alles gut gemacht hat, was Er erschuf. Und Er begann die Schöpfung des Menschen aus Ton.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmdxi{Hierauf machte Er seine Nachkommenschaft aus einer nichtbeachtenswerten Flüssigkeit.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmdxii{Dann formte Er ihn und hauchte ihm von Seinem Geist ein. Und Er hat euch Gehör und Augenlicht und Herzen gegeben. Doch euer Dank ist recht gering.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmdxiii{Und sie sagen: ``Wie? Wenn wir in der Erde verschwunden sind, dann sollen wir in einer neuen Schöpfung sein?" Nein, sie sind hinsichtlich der Begegnung mit ihrem Herrn ungläubig.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmdxiv{Sprich: ``Der Engel des Todes, der über euch eingesetzt wurde wird euch abberufen; dann werdet ihr zu eurem Herrn zurückgebracht."\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmdxv{Könntest du nur sehen, wie die Schuldigen ihre Köpfe vor ihrem Herrn hängen lassen werden: ``Unser Herr, nun haben wir gesehen und gehört, so sende uns zurück, auf daß wir Gutes tun mögen; denn nun haben wir Gewißheit."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmdxvi{Und hätten Wir gewollt, hätten Wir jedem seinen Weg gezeigt; jedoch Mein Wort soll geschehen: ``Füllen will Ich Gahannam mit den Ginn und mit den Menschen allzumal."\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmdxvii{So kostet (die Strafe); denn ihr vergaßt das Eintreffen dieses euren Tages. (Auch) Wir haben euch vergessen. Kostet denn die Strafe der Ewigkeit um dessentwillen, was ihr getan habt.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmdxviii{Nur jene glauben an Unsere Zeichen, die sich, wenn sie an sie gemahnt werden, niederwerfen und das Lob ihres Herrn preisen; und sie sind nicht hochmütig.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmdxix{Ihre Seiten halten sich fern von (ihren) Betten; sie rufen ihren Herrn in Furcht und Hoffnung an und spenden von dem, was Wir ihnen gegeben haben.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmdxx{Doch niemand weiß, welche Augenweide für sie als Lohn für ihre Taten verborgen ist.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmdxxi{Ist wohl jener, der gläubig ist, dem gleich, der frevelt? Sie sind nicht gleich.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmdxxii{Jene aber, die glauben und gute Werke tun, werden Gärten der Geborgenheit haben als einen Wohnsitz für das, was sie getan haben.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmdxxiii{Jene aber, die ungehorsam sind - ihre Herberge wird das Feuer sein. Sooft sie daraus entfliehen wollen, werden sie wieder dahin zurückgetrieben, und es wird zu ihnen gesprochen: ``Kostet nun die Strafe des Feuers, die ihr zu leugnen pflegtet!"\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmdxxiv{Und wahrlich, Wir werden sie vor der größeren Strafe von der diesseitigen Strafe kosten lassen, damit sie sich vielleicht doch noch bekehren.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmdxxv{Und wer ist ungerechter als jener, der an die Zeichen seines Herrn gemahnt wird und sich dann doch von ihnen abwendet? Wahrlich, Wir werden Uns an den Sündern rächen.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmdxxvi{Und wahrlich, Wir gaben Moses das Buch - zweifle deshalb nicht daran, daß auch du es bekommst -, und Wir machten es zu einer Führung für die Kinder Israels.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmdxxvii{Und Wir erweckten Führer aus ihrer Mitte, die (das Volk) nach Unserem Gebot leiteten, weil sie geduldig waren und fest an Unsere Zeichen glaubten.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmdxxviii{Wahrlich, dein Herr ist es, Der zwischen ihnen am Tage der Auferstehung über das richten wird, worüber sie uneinig waren.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmdxxix{Ist ihnen nicht klar, wie viele Geschlechter Wir schon vor ihnen vernichtet haben, in deren Wohnstätten sie nun wandeln? Hierin liegen wahrlich Zeichen. Wollen sie also nicht hören?\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmdxxx{Haben sie denn nicht gesehen, daß Wir das Wasser auf das dürre Land treiben und dadurch Gewächs hervorbringen, an dem ihr Vieh und auch sie selber sich laben? Wollen sie also nicht sehen?\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmdxxxi{Und sie sagen: ``Wann wird dieser Sieg kommen, wenn ihr die Wahrheit redet?"\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmdxxxii{Sprich: ``Am Tage des Sieges wird den Ungläubigen ihr Glaube nichts nutzen, noch werden sie Aufschub erlangen."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmdxxxiii{So wende dich denn von ihnen ab und warte; auch sie warten.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmdxxxiv{\basmalahde O Prophet, fürchte Allah und gehorche nicht den Ungläubigen und den Heuchlern. Wahrlich, Allah ist Allwissend, Allweise.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmdxxxv{Und folge dem, was dir von deinem Herrn offenbart wird. Wahrlich, Allah ist wohl all dessen kundig, was ihr tut.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmdxxxvi{Und vertraue auf Allah; denn Allah genügt als Beschützer.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmdxxxvii{Allah hat keinem Manne zwei Herzen in seinem Inneren gegeben, noch hat Er jene unter euren Frauen, von denen ihr euch scheidet mit der Formel, sie seien euch verwehrt wie der Rücken eurer Mütter, zu euren (wirklichen) Müttern gemacht, noch hat Er eure adoptierten Söhne zu euren (wirklichen) Söhnen gemacht. Das ist (nur) Gerede aus euren Mündern; Allah aber spricht die Wahrheit, und Er zeigt (euch) den Weg.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmdxxxviii{Nennt sie (eure Adoptivsöhne) nach ihren Vätern. Das ist gerechter vor Allah. Wenn ihr jedoch ihre Väter nicht kennt, so sind sie eure Brüder im Glauben und eure Schützlinge. Und wenn ihr versehentlich darin gefehlt habt, so ist das keine Sünde von euch, sondern (Sünde ist) nur das, was eure Herzen vorsätzlich tun. Und Allah ist wahrlich Allverzeihend, Barmherzig.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmdxxxix{Der Prophet steht den Gläubigen näher als sie sich selber, und seine Frauen sind ihre Mütter. Und Blutsverwandte sind einander näher als die (übrigen) Gläubigen und die Ausgewanderten - gemäß dem Buche Allahs -, es sei denn, daß ihr euren Schützlingen Güte erweist. Das ist in dem Buche niedergeschrieben.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmdxl{Und dann gingen Wir mit den Propheten den Bund ein und mit dir und mit Noah und Abraham und Moses und mit Jesus, dem Sohn der Maria. Und Wir gingen mit ihnen einen gewaltigen Bund ein\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmdxli{auf daß Er die Wahrhaftigen nach ihrer Wahrhaftigkeit befrage. Und für die Ungläubigen hat Er eine schmerzliche Strafe bereitet.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmdxlii{O ihr, die ihr glaubt! Gedenkt der Gnade Allahs gegen euch, als Heerscharen gegen euch heranrückten; und Wir sandten gegen sie einen Wind und Heerscharen, die ihr nicht gesehen hattet. Und Allah sieht, was ihr tut.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmdxliii{Als sie von oben und von unten her über euch kamen, und als die Augen rollten und die Herzen in die Kehle stiegen und ihr verschiedene Gedanken über Allah hegtet\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmdxliv{damals wurden die Gläubigen geprüft, und sie wurden in heftigem Maße erschüttert.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmdxlv{Und da sagten die Heuchler und die, in deren Herzen Krankheit war: ``Allah und Sein Gesandter haben uns nur Trug verheißen."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmdxlvi{Und alsdann sagte eine Gruppe von ihnen: ``O ihr Leute von Yatrib, ihr könnt (ihnen) nicht standhalten, darum kehrt zurück." Und ein Teil von ihnen bat den Propheten um Erlaubnis und sagte: ``Unsere Wohnungen sind schutzlos." Und sie waren nicht schutzlos. Sie wollten eben nur fliehen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmdxlvii{Und wenn der Zutritt gegen sie von allen Seiten her erzwungen würde, und wenn sie dann aufgefordert würden, (vom Islam) abzufallen, würden sie es sogleich tun; dann würden sie darin nicht lange weilen können.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmdxlviii{Und sie hatten doch in Wahrheit zuvor mit Allah den Bund geschlossen, daß sie nicht den Rücken zur Flucht wenden würden. Und über den Bund mit Allah muß Rechenschaft abgelegt werden.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmdxlix{Sprich: ``Die Flucht wird euch nimmermehr nützen, wenn ihr dem Tod oder der Niedermetzelung entflieht; dann werdet ihr nur wenig genießen."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmdl{Sprich: ``Wer ist es, der euch vor Allah schützen kann, wenn Er vorhat, über euch ein Übel zu verhängen, oder wenn Er vorhat, euch Barmherzigkeit zu erweisen? Und sie werden für sich außer Allah weder Beschützer noch Helfer finden.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmdli{Allah kennt doch diejenigen unter euch, die (die Menschen vom Weg) abhalten, und diejenigen, die zu ihren Brüdern sagen: ``Kommt her zu uns"; und sie lassen sich nur selten in Kriege ein\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmdlii{(und sind) euch gegenüber geizig. Naht aber Gefahr, dann siehst du sie nach dir ausschauen - mit rollenden Augen wie einer, der aus Todesfurcht in Ohnmacht fällt. Doch wenn dann die Angst vorbei ist, dann treffen sie euch mit scharfen Zungen in ihrer Gier nach Gut. Diese haben nicht geglaubt; darum hat Allah ihre Werke zunichte gemacht. Und das ist für Allah ein leichtes.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmdliii{Sie meinen, daß die Verbündeten noch nicht abgezogen seien; und wenn die Verbündeten kommen sollten, so würden sie lieber bei den nomadischen Arabern in der Wüste sein und dort Nachrichten über euch erfragen. Und wenn sie bei euch wären, so würden sie nur wenig kämpfen.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmdliv{Wahrlich, ihr habt an dem Gesandten Allahs ein schönes Vorbild für jeden, der auf Allah und den Letzten Tag hofft und Allahs häufig gedenkt.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmdlv{Und als die Gläubigen die Verbündeten sahen, da sagten sie: ``Das ist es, was Allah und Sein Gesandter uns verheißen haben; und Allah und Sein Gesandter sprachen die Wahrheit." Und es verstärkte nur ihren Glauben und ihre Ergebung.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmdlvi{Unter den Gläubigen sind Leute, die dem Bündnis, das sie mit Allah geschlossen hatten, die Treue hielten. Es sind welche unter ihnen, die ihr Gelübde erfüllt haben, und welche, die noch warten, und sie haben nichts verändert, nicht im geringsten.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmdlvii{Allah belohne die Wahrhaftigen für ihre Wahrhaftigkeit und bestrafe die Heuchler, wenn Er will, oder wende Sich ihnen in Barmherzigkeit zu. Wahrlich, Allah ist Allverzeihend, Barmherzig.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmdlviii{Und Allah schlug die Ungläubigen in ihrem Grimm zurück; sie erlangten keinen Vorteil. Und Allah ersparte den Gläubigen den Kampf. Und Allah ist Allmächtig, Erhaben.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmdlix{Und Er brachte die aus dem Volk der Schrift, die ihnen halfen, von ihren Burgen herunter und warf Schrecken in ihre Herzen. Einen Teil tötetet ihr, und einen Teil nahmt ihr gefangen.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmdlx{Und Er ließ euch ihr Land erben und ihre Häuser und ihren Besitz und ein Land, in das ihr nie den Fuß gesetzt hattet. Und Allah hat Macht über alle Dinge.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmdlxi{O Prophet! Sprich zu deinen Frauen: ``Wenn ihr das Leben in dieser Welt und seinen Schmuck begehrt, so kommt, ich will euch eine Gabe reichen und euch dann auf schöne Art entlassen.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmdlxii{Doch wenn ihr Allah und Seinen Gesandten und die Wohnstatt des Jenseits begehrt, dann wahrlich, hat Allah für die unter euch, die Gutes tun, einen herrlichen Lohn, bereitet."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmdlxiii{O Frauen des Propheten! Wenn eine von euch eine offenkundige Schändlichkeit begeht, so wird ihr die Strafe verdoppelt. Und das ist für Allah ein leichtes.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmdlxiv{Doch welche von euch Allah und Seinem Gesandten gehorsam ist und Gutes tut - ihr werden Wir ihren Lohn zweimal geben; und Wir haben für sie eine ehrenvolle Versorgung bereitet.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmdlxv{O Frauen des Propheten, ihr seid nicht wie andere Frauen! Wenn ihr gottesfürchtig sein wollt, dann seid nicht unterwürfig im Reden, damit nicht der, in dessen Herzen Krankheit ist, Erwartungen hege, sondern redet in geziemenden Worten.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmdlxvi{Und bleibt in euren Häusern und prunkt nicht wie in den Zeiten der Gahiliya und verrichtet das Gebet und entrichtet die Zakah und gehorcht Allah und Seinem Gesandten. Allah will nur jegliches Übel von euch verschwinden lassen, ihr Leute des Hauses, und euch stets in vollkommener Weise rein halten.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmdlxvii{Und gedenkt der Verse Allahs und der Weisheiten, die in euren Häusern verlesen werden; denn Allah ist Gütig, Allkundig.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmdlxviii{Wahrlich, die muslimischen Männer und die muslimischen Frauen, die gläubigen Männer und die gläubigen Frauen, die gehorsamen Männer und die gehorsamen Frauen, die wahrhaftigen Männer und die wahrhaftigen Frauen, die geduldigen Männer und die geduldigen Frauen, die demütigen Männer und die demütigen Frauen, die Männer, die Almosen geben, und die Frauen, die Almosen geben, die Männer, die fasten, und die Frauen, die fasten, die Männer, die ihre Keuschheit wahren, und die Frauen, die ihre Keuschheit wahren, die Männer, die Allahs häufig gedenken, und die Frauen, die (Allahs häufig) gedenken - Allah hat ihnen (allen) Vergebung und großen Lohn bereitet.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmdlxix{Und es ziemt sich nicht für einen gläubigen Mann oder eine gläubige Frau, daß sie - wenn Allah und Sein Gesandter eine Angelegenheit beschlossen haben - eine andere Wahl in ihrer Angelegenheit treffen. Und der, der Allah und Seinem Gesandten nicht gehorcht, geht wahrlich in of fenkundiger Weise irre.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmdlxx{Und da sagtest du zu dem, dem Allah Gnade erwiesen hatte und dem du Gnade erwiesen hattest: ``Behalte deine Frau für dich und fürchte Allah." Und du verbargst das, was du in dir hegtest, das, was Allah ans Licht bringen wollte, und du fürchtetest die Menschen, während Allah es ist, Den du in Wirklichkeit fürchten sollst. Dann aber, als Zaid seine eheliche Beziehung mit ihr beendet hatte, verbanden Wir sie ehelich mit dir, damit die Gläubigen in Bezug auf die Frauen ihrer angenommenen Söhne nicht in Verlegenheit gebracht würden, wenn sie ihre ehelichen Beziehungen mit ihnen beendet hätten. Und Allahs Be fehl muß vollzogen werden.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmdlxxi{Es bringt den Propheten in keine Verlegenheit, was Allah für ihn angeordnet hat. Das war Allahs Vorgehen gegen jene, die vordem dahingingen, und Allahs Befehl ist ein unabänderlicher Beschluß\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmdlxxii{- jene, die Allah s Botschaften ausrichteten und Ihn fürchteten und niemanden außer Allah fürchteten. Und Allah genügt als Rechner.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmdlxxiii{Muhammad ist nicht der Vater eines eurer Männer, sondern der Gesandte Allahs und der letzte aller Propheten, und Allah besitzt die volle Kenntnis aller Dinge.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmdlxxiv{O ihr, die ihr glaubt! Gedenkt Allahs in häufigem Gedenken\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmdlxxv{und lobpreist Ihn morgens und abends.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmdlxxvi{Er ist es, Der euch segnet, und Seine Engel bitten (darum) für euch, daß Er euch aus den Finsternissen zum Licht führe. Und Er ist Barmherzig gegen die Gläubigen.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmdlxxvii{Ihr Gruß an dem Tage, da sie Ihm begegnen, wird sein: ``Frieden!" Und Er hat für sie einen ehrenvollen Lohn bereitet.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmdlxxviii{O Prophet, Wir haben dich als einen Zeugen, als Bringer froher Botschaft und als Warner entsandt\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmdlxxix{und mit Seiner Erlaubnis als einen Ausrufer zu Allah und als eine lichtspendene Leuchte.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmdlxxx{Und verkünde den Gläubigen die frohe Botschaft, daß ihnen von Allah große Huld zuteil werde.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmdlxxxi{Und gehorche nicht den Ungläubigen und den Heuchlern und beachte ihre Belästigung nicht, und vertraue auf Allah; denn Allah genügt als Beschützer.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmdlxxxii{O ihr, die ihr glaubt! Wenn ihr gläubige Frauen heiratet und euch dann von ihnen scheiden lasset, ehe ihr sie berührt habt, so besteht für euch ihnen gegenüber keine Wartefrist, die sie einhalten müßten. Darum beschenkt sie und entlaßt sie auf geziemende Weise.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmdlxxxiii{O Prophet, Wir erlaubten dir deine Gattinnen, denen du ihre Brautgabe gegeben hast, und jene, die du von Rechts wegen aus (der Zahl) derer besitzt, die Allah dir als Kriegsbeute gegeben hat, und die Töchter deines Vaterbruders und die Töchter deiner Vaterschwestern und die Töchter deines Mutterbruders und die Töchter deiner Mutterschwestern, die mit dir ausgewandert sind, und jedwede gläubige Frau, die sich dem Propheten schenkt, vorausgesetzt, daß der Prophet sie zu heiraten wünscht; (dies gilt) nur für dich und nicht für die Gläubigen. Wir haben bereits bekanntgegeben, was Wir ihnen bezüglich ihrer Frauen und jener, die sie von Rechts wegen besitzen, verordnet haben, so daß sich (daraus) keine Verlegenheit für dich ergibt. Und Allah ist Allverzeihend, Barmherzig.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmdlxxxiv{Du darfst die von ihnen entlassen, die du (zu entlassen) wünschst, und du darfst die behalten, die du (zu behalten) wünschst; und wenn du eine, die du entlassen hast, wieder aufnehmen willst, dann trifft dich kein Vorwurf. Das ist dazu angetan, daß ihre Blicke Zufriedenheit ausstrahlen und sie sich nicht grämen und sie alle zufrieden sein mögen mit dem, was du ihnen zu geben hast. Und Allah weiß, was in euren Herzen ist; denn Allah ist Allwissend, Nachsichtig.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmdlxxxv{Es ist dir nicht erlaubt, künftig (andere) Frauen (zu heiraten), noch sie gegen (andere) Frauen einzutauschen, auch wenn ihre Schönheit dir gefällt; (davon sind) nur die ausgenommen, die du von Rechts wegen besitzt. Und Allah wacht über alle Dinge.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmdlxxxvi{O ihr, die ihr glaubt! Betretet nicht die Häuser des Propheten, es sei denn, daß euch zu einer Mahlzeit (dazu) Erlaubnis gegeben wurde. Und wartet nicht (erst) auf deren Zubereitung, sondern tretet (zur rechten Zeit) ein, wann immer ihr eingeladen seid. Und wenn ihr gespeist habt, dann geht auseinander und lasset euch nicht aus Geselligkeit in eine weitere Unterhaltung verwickeln. Das verursacht dem Propheten Ungelegenheit, und er ist scheu vor euch, jedoch Allah ist nicht scheu vor der Wahrheit. Und wenn ihr sie (seine Frauen) um irgend etwas zu bitten habt, so bittet sie hinter einem Vorhang. Das ist reiner für eure Herzen und ihre Herzen. Und es geziemt euch nicht, den Gesandten Allahs zu belästigen, noch (geziemt es euch,) seine Frauen jemals nach ihm zu heiraten. Wahrlich, das würde vor Allah eine Ungeheuerlichkeit sein.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmdlxxxvii{Ob ihr eine Sache offenkundig tut oder sie verbergt, wahrlich, Allah kennt alle Dinge.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmdlxxxviii{Es ist kein Vergehen von ihnen, (sich) ihren Vätern (zu zeigen) oder ihren Söhnen oder ihren Brüdern oder den Söhnen ihrer Brüder oder den Söhnen ihrer Schwestern oder ihren Frauen oder denen, die sie von Rechts wegen besitzen. Und fürchtet Allah; wahrlich, Allah ist Zeuge aller Dinge.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmdlxxxix{Wahrlich, Allah sendet Segnungen auf den Propheten, und Seine Engel bitten darum für ihn. O ihr, die ihr glaubt, bittet (auch) ihr für ihn und wünscht ihm Frieden in aller Ehrerbietung.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmdxc{Wahrlich, diejenigen, die Allah und Seinen Gesandten Ungemach zufügen - Allah hat sie in dieser Welt und im Jenseits verflucht und hat ihnen eine schmähliche Strafe berei tet.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmdxci{Und diejenigen, die gläubigen Männern und gläubigen Frauen ungerechterweise Ungemach zufügen, laden gewiß (die Schuld) der Verleumdung und eine offenkundige Sünde auf sich.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmdxcii{O Prophet! Sprich zu deinen Frauen und deinen Töchtern und zu den Frauen der Gläubigen, sie sollen ihre Übergewänder reichlich über sich ziehen. So ist es am ehesten gewährleistet, daß sie (dann) erkannt und nicht belästigt werden. Und Allah ist Allverzeihend, Barmherzig.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmdxciii{Wenn die Heuchler und diejenigen, in deren Herzen Krankheit ist, und die, welche Gerüchte in der Stadt verbreiten, nicht (von ihrem Tun) ablassen, dann werden Wir dich sicher gegen sie anspornen, dann werden sie nur noch für kurze Zeit in ihr deine Nachbarn sein.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmdxciv{Verflucht seien sie! Wo immer sie gefunden werden, sollen sie ergriffen und rücksichtslos hingerichtet werden.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmdxcv{So geschah der Wille Allahs im Falle derer, die vordem hingingen; und du wirst in Allahs Willen nie einen Wandel finden.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmdxcvi{Die Menschen befragen dich über die Stunde. Sprich: ``Das Wissen um sie ist allein bei Allah", und wie kannst du (das) wissen? Vielleicht ist die Stunde nahe.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmdxcvii{Wahrlich, Allah hat die Ungläubigen verflucht und hat für sie ein flammendes Feuer bereitet\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmdxcviii{worin sie auf ewig bleiben. Sie werden weder Beschützer noch Helfer finden.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmdxcix{An dem Tage, da ihre Gesichter im Feuer gewendet werden, da werden sie sagen: ``O wenn wir doch Allah gehorcht hätten; und hätten wir (doch auch) dem Gesandten gehorcht!"\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmdc{Und sie werden sagen: ``Unser Herr, wir gehorchten unseren Häuptern und unseren Großen, und sie führten uns irre (und) vom Weg ab.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmdci{Unser Herr, gib ihnen die zweifache Strafe und verfluche sie mit einem gewaltigen Fluch."\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmdcii{O ihr, die ihr glaubt! Seid nicht wie jene, die Moses kränkten; jedoch Allah bewies seine Unschuld in der Sache, die sie (gegen ihn) vorbrachten. Und er war ehrenwert vor Allah.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmdciii{O ihr, die ihr glaubt! Fürchtet Allah und sprecht aufrichtige Worte\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmdciv{auf daß Er eure Taten segensreich fördere und euch eure Sünden vergebe. Und wer Allah und Seinem Gesandten gehorcht, der hat gewiß einen gewaltigen Gewinn erlangt.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmdcv{Wahrlich, Wir boten das Treuhänderamt den Himmeln und der Erde und den Bergen an; doch sie weigerten sich, es zu tragen, und schreckten davor zurück. Aber der Mensch nahm es auf sich. Wahrlich, er ist sehr ungerecht, unwissend.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmdcvi{Allah wird Heuchler und Heuchlerinnen sowie Götzendiener und Götzendienerinnen bestrafen; und Allah kehrt Sich in Barmherzigkeit gläubigen Männern und gläubigen Frauen zu; denn Allah ist Allverzeihend, Barmherzig.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmdcvii{\basmalahde Alles Lob gebührt Allah, Dessen ist, was in den Himmeln und was auf Erden ist, und Sein ist alles Lob im Jenseits; und Er ist der Allweise, der Allkundige.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmdcviii{Er weiß, was in die Erde eingeht und was aus ihr hervorkommt, und was vom Himmel herniedersteigt und was zu ihm aufsteigt; und Er ist der Barmherzige, der All verzeihende.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmdcix{Und es sagen diejenigen, die ungläubig sind: ``Wir werden die Stunde nicht erleben." Sprich: ``Ja doch, bei meinem Herrn, dem Kenner des Verborgenen, sie wird gewiß über euch kommen! Nicht einmal das Gewicht eines Stäubchens in den Himmeln oder auf Erden ist vor Ihm verborgen; noch gibt es etwas Kleineres oder Größeres als dieses, das nicht in einem deutlichen Buch stünde.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmdcx{Er belohnt gewiß diejenigen, die glauben und gute Werke tun. Solche sind es, die Vergebung und eine ehrenvolle Versorgung erhalten werden."\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmdcxi{Und jene aber, die versuchen, Unsere Zeichen zu entkräften - sie sind es, denen eine Strafe schmerzlicher Pein zuteil wird.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmdcxii{Und die, denen das Wissen gegeben wurde, sehen, daß das, was dir von deinem Herrn offenbart worden ist, die Wahrheit selbst ist und zu dem Weg des Allmächtigen, des Preiswürdigen leitet.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmdcxiii{Und jene, die ungläubig sind, sagen: ``Sollen wir euch einen Mann zeigen, der euch berichtet, ihr würdet, wenn ihr ganz in Stücke zerfallen seid, auch dann noch als neue Schöpfung auferstehen?\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmdcxiv{Hat er eine Lüge gegen Allah ersonnen oder ist er ein vom Wahn Besessener?" Nein, (nicht er,) sondern jene, die nicht an das Jenseits glauben, befinden sich in der Pein und im weitgegangenen Irrtum.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmdcxv{Haben sie denn nicht gesehen, was vom Himmel und von der Erde vor ihnen und was hinter ihnen ist? Wenn Wir wollten, ließen Wir sie in der Erde versinken oder ließen Wir auf sie Brocken vom Himmel fallen. Hierin liegt wahrlich ein Zeichen für jeden Diener, der sich bekehrt.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmdcxvi{Und wahrlich, Wir verliehen David Unsere Huld: ``O ihr Berge lobpreiset mit ihm (Allah), und auch ihr Vögel, (lobpreiset Ihn)!" Und schmiegsam machten Wir ihm das Eisen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmdcxvii{(Und Wir sprachen:) ``Verfertige lange Panzerhemden und füge die Maschen des Kettenwerks fein ineinander. Und verrichtet gute Taten; denn Ich sehe alles, was ihr tut."\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmdcxviii{Und Salomo (machten Wir) den Wind (dienstbar); sein Herweg dauerte einen Monat, und sein Hinweg dauerte einen Monat. Und Wir verflüssigten ihm eine Metallquelle. Und von den Ginn gab es welche, die unter ihm auf Geheiß seines Herrn arbeiteten. Und sollte einer von ihnen sich von Unserem Befehl abwenden, so würden Wir ihn die Strafe des flammenden Feuers kosten lassen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmdcxix{Sie machten für ihn, was er begehrte: Paläste und Bildwerke, Becken wie Teiche und feststehende Kochbottiche: ``Wirkt ihr vom Hause Davids in Dankbarkeit." Und nur wenige von Meinen Dienern sind dankbar.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmdcxx{Und als Wir über ihn den Tod verhängt hatten, da zeigte ihnen nichts seinen Tod an außer einem Tier aus der Erde, das seinen Stock zerfraß; so gewahrten die Ginn deutlich, wie er fiel, so daß sie, hätten sie das Verborgene gekannt, nicht in schmählicher Pein hätten bleiben müssen.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmdcxxi{Es gab wahrlich ein Zeichen für Saba' in ihrem Heimatland: zwei Gärten zur Rechten und zur Linken: ``Esset von den Gaben eures Herrn und seid Ihm dankbar. (Euer ist) eine Stadt, die gut ist, und ein Herr, Der Allverzeihend ist!"\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmdcxxii{Jedoch sie kehrten sich ab; da sandten Wir eine reißende Flut gegen sie. Und Wir gaben ihnen an Stelle ihrer Gärten zwei Gärten mit bitterer Frucht und Tamarisken und wenigen Lotosbäumen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmdcxxiii{Solches gaben Wir ihnen zum Lohn für ihre Undankbarkeit; und so belohnen Wir keinen (anderen) als den Undankbaren.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmdcxxiv{Und Wir setzten zwischen sie und die Städte, die Wir gesegnet hatten, (andere) hochragende Städte, und Wir erleichterten das Reisen zwischen ihnen: ``Reist zwischen ihnen bei Tag und Nacht in Sicherheit umher."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmdcxxv{Jedoch sie sagten: ``Unser Herr, vergrößere die Entfernung zwischen unseren Reisezielen." Und sie sündigten gegen sich selber; so machten Wir sie zu (abschreckenden) Geschichten (für die Nachfahren), und Wir ließen sie in Stücke zerfallen. Hierin sind wahrlich Zeichen für jeden Geduldigen, Dankbaren.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmdcxxvi{Und Iblis bewies wahrlich die Richtigkeit seiner Meinung von ihnen; dann folgten sie ihm mit Ausnahme einer Schar von Gläubigen.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmdcxxvii{Und er hatte keine Macht über sie; allein Wir wollten denjenigen, der ans Jenseits glaubte, vor dem auszeichnen, der Zweifel darüber hegte. Und dein Herr wacht über alle Dinge.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmdcxxviii{Sprich: ``Ruft doch jene an, die ihr vermutet neben Allah. Sie haben nicht einmal über das Gewicht eines Stäubchens in den Himmeln oder auf Erden Macht, noch haben sie einen Anteil an beiden, noch hat Er einen Helfer unter ihnen."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmdcxxix{Auch nützt bei Ihm keine Fürsprache, außer für den, bei dem Er es erlaubt, so daß, wenn der Schrecken aus ihren Seelen gewichen ist und sie sagen: ``Was hat euer Herr gesprochen?" sie sagen werden: ``Die Wahrheit." Und Er ist der Erhabene, der Große.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmdcxxx{Sprich: ``Wer gibt euch Nahrung von den Himmeln und der Erde?" Sprich: ``Allah. Entweder wir sind oder ihr seid auf dem rechten Weg oder in offenkundigem Irrtum."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmdcxxxi{Sprich: ``lhr sollt nicht nach unseren Sünden befragt werden, noch werden wir nach dem, was ihr tut, befragt werden."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmdcxxxii{Sprich: ``Unser Herr wird uns alle zusammenbringen, dann wird Er zwischen uns in Gerechtigkeit richten; und Er ist der beste Richter, der Allwissende."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmdcxxxiii{Sprich: ``Zeigt mir jene, die ihr Ihm als Götter zur Seite gesetzt habt! Nichts! Er aber ist Allah, der Allmächtige, der Allweise."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmdcxxxiv{Und Wir haben dich nur als Bringer froher Botschaft und Warner für alle Menschen entsandt; jedoch die meisten Menschen wissen es nicht.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmdcxxxv{Und sie sagen: ``Wann wird dieses Versprechen erfüllt, wenn ihr wahrhaftig seid?"\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmdcxxxvi{Sprich: ``Euch ist die Frist eines Tages festgesetzt, hinter der ihr weder eine Stunde zurückbleiben noch ihr vorausgehen könnt."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmdcxxxvii{Und jene, die ungläubig sind sagen: ``Wir wollen keineswegs an diesen Quran glauben, noch an das, was vor ihm gewesen ist." Und könntest du nur sehen, wie sich die Ungerechten wechselseitig die Schuld zuweisen, wenn sie vor ihren Herrn gestellt werden! Diejenigen, die unterdrückt waren, werden dann zu denen, die hochmütig waren, sagen: ``Wäret ihr nicht gewesen, wären wir ganz gewiß Gläubige geworden."\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmdcxxxviii{Jene, die hochmütig waren werden zu denen, die unterdrückt waren, sagen: ``Waren wir es etwa, die euch vom rechten Weg abhielten, nachdem er (der Quran) zu euch gekommen war? Nein, ihr selbst waret die Schuldigen."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmdcxxxix{Und jene, die unterdrückt waren, werden zu denen, die hochmütig waren, sagen: ``Nein, aber es war (euer) Ränkeschmieden bei Nacht und Tag, als ihr uns befahlt, nicht an Allah zu glauben und Ihm Götter zur Seite zu setzen." Und in ihrem Innern werden sie von Reue erfüllt sein, wenn sie die Strafe sehen; und Wir werden Fesseln um die Nac ken derer legen, die ungläubig waren. Sie werden nur für das entlohnt werden, was sie getan haben.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmdcxl{Und Wir entsandten zu keiner Stadt einen Warner, ohne daß die, die darin ein Leben in Wohlstand führten, gesprochen hätten: ``Gewiß, wir leugnen das, womit ihr gesandt worden seid."\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmdcxli{Und sie sagten: ``Wir haben mehr Güter und Kinder (als ihr); und wir werden nicht bestraft werden!"\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmdcxlii{Sprich: ``Wahrlich, mein Herr erweitert und beschränkt dem die Mittel zum Unterhalt, dem Er will; jedoch die meisten Menschen wissen es nicht."\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmdcxliii{Und es ist weder euer Gut, noch sind es eure Kinder, die euch Uns nahe bringen werden; die aber, die glauben und gute Werke tun, die sollen den zweifachen Lohn für das, was sie getan haben, erhalten. Und in den Obergemächern (des Paradieses) werden sie sicher wohnen.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmdcxliv{Doch jene, die versuchen, Unsere Zeichen zu entkräften - sie sind es, die der Strafe zugeführt werden.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmdcxlv{Sprich: ``Wahrlich, mein Herr erweitert und beschränkt dem von Seinen Dienern die Mittel zum Unterhalt, dem Er will. Und was immer ihr spendet, Er wird es ersetzen; und Er ist der beste Versorger."\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmdcxlvi{Und am Tage, wo Er sie alle versammeln (und) dann zu den Engeln sprechen wird: ``Sind diese es, die euch dienten?"\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmdcxlvii{werden sie sagen: ``Preis (sei) Dir! Dich haben Wir zum Beschützer, nicht sie. Nein, sie dienten den Ginn; an sie haben die meisten von ihnen geglaubt."\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmdcxlviii{``So sollt ihr heute einander weder nützen noch schaden können." Und zu denen, die frevelten, werden Wir sprechen: ``Kostet die Strafe des Feuers, das ihr zu leugnen pflegtet."\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmdcxlix{Und wenn ihnen Unsere deutlichen Verse verlesen werden, sagen sie: ``Dieser ist nichts weiter als ein Mann, der euch von dem abwenden möchte, was eure Väter verehrten." Und sie sagen: ``Dieser (Quran) ist nichts (anderes) als eine erdichtete Lüge." Und diejenigen, die ungläubig sind, sagen von der Wahrheit, wenn sie zu ihnen kommt: ``Das ist nichts als eine offenkundige Zauberei."\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmdcl{Und Wir gaben ihnen keine Bücher, die sie (hätten) studieren (können), noch sandten Wir ihnen einen Warner vor dir.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmdcli{Jene, die vor ihnen waren, leugneten ebenfalls - und diese haben nicht den zehnten Teil von dem erreicht, was Wir jenen gegeben hatten -, und doch bezichtigten sie Meine Gesandten der Lüge. Doch wie war (die Folge davon,) daß sie Mich verleugneten!\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmdclii{Sprich: ``lch mahne euch nur an eines: daß ihr euch ernsthaft mit Allahs Sache - zu zweit oder einzeln - befaßt und dann nachdenken sollt. Es ist in eurem Gefährten (dem Propheten) keine Besessenheit; er ist für euch nur ein Warner vor einer bevorstehenden strengen Strafe."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmdcliii{Sprich: ``lch habe von euch keinen Lohn verlangt; denn dieser (Lohn) kommt euch zugute. Mein Lohn ist allein bei Allah; und Er ist der Zeuge aller Dinge.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmdcliv{Sprich: ``Wahrlich, mein Herr, der Kenner des Verborgenen schleudert (euch) die Wahrheit entgegen."\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmdclv{Sprich: ``Die Wahrheit ist gekommen, und das Falsche kann weder etwas erschaffen noch etwas zurückbringen."\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmdclvi{Sprich: ``Wenn ich irre, so irre nur ich selbst; und wenn ich rechtgeleitet bin, so geschieht es durch das, was mein Herr mir offenbart hat. Wahrlich, Er ist der Allhörende, der Nahe."\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmdclvii{Könntest du nur sehen wenn sie mit Furcht geschlagen sein werden! Dann wird es (für sie) kein Entrinnen geben; denn sie werden aus nächster Nähe erfaßt werden.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmdclviii{Und sie werden sagen: ``(Nun) glauben wir daran." Allein, wie kann das Erlangen (des Glaubens) ihnen an einem (so) fernen Orte möglich sein\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmdclix{wenn sie zuvor nicht daran geglaubt haben? Und sie äußern Mutmaßungen von einem fernen Ort aus.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmdclx{Und ein Abgrund ist zwischen ihnen und ihren Begierden aufgerissen worden, wie es ihresgleichen schon zuvor widerfuhr. Auch sie befanden sich in beunruhigendem Zweifel.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmdclxi{\basmalahde Alles Lob gebührt Allah, dem Schöpfer der Himmel und der Erde, Der die Engel, mit je zwei, drei und vier Flügeln, zu Boten gemacht hat. Er fügt der Schöpfung hinzu, was Ihm gefällt; Allah hat wahrlich Macht über alle Dinge.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmdclxii{Was Allah den Menschen an Barmherzigkeit gewährt, das kann keiner zurückhalten; und was Er zurückhält, das kann nach Ihm keiner freigeben; und Er ist der Allmächtige, der Allweise.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmdclxiii{O ihr Menschen, gedenkt der Gnade Allahs gegen euch. Gibt es einen Schöpfer außer Allah, der euch vom Himmel und von der Erde her versorgt? Es ist kein Gott außer Ihm. Wie könnt ihr euch da (von Ihm) abwenden?\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmdclxiv{Und wenn sie dich der Lüge bezichtigen: schon die Gesandten vor dir sind der Lüge bezichtigt worden; und zu Allah werden die Angelegenheiten zurückgebracht.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmdclxv{O ihr Menschen, wahrlich, die Verheißung Allahs ist wahr, darum lasset euch nicht vom diesseitigen Leben betören, und lasset euch nicht vom Betörer über Allah betören.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmdclxvi{Wahrlich, Satan ist euer Feind; so haltet ihn für einen Feind. Er ruft seine Anhänger nur herbei, damit sie zu Bewohnern des flammenden Feuers werden.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmdclxvii{Denjenigen, die ungläubig sind, wird eine strenge Strafe zuteil sein. Denen aber, die glauben und gute Werke tun, wird Vergebung und großer Lohn zuteil sein.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmdclxviii{Ist etwa der, dem das Böse seines Tuns verschönt wird, so daß er es als gut ansieht(, rechtgeleitet)? Gewiß, Allah läßt in die Irre gehen, wen Er. will, und leitet recht, wen Er will. Laß darum deine Seele nicht in Seufzern über sie hinschwinden. Wahrlich, Allah weiß, was sie tun.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmdclxix{Und Allah ist es, Der die Winde sendet, die das Gewölk hochtreiben. Dann treiben Wir es über eine tote Stadt und beleben damit die Erde nach ihrem Tode. Ebenso wird es bei der Auferstehung der (Toten) sein.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmdclxx{Wer da Erhabenheit begehrt (, der wisse), daß alle Erhabenheit Allah gehört. Zu Ihm steigt das gute Wort empor, und rechtschaffenes Werk wird es hochtreiben lassen. Und diejenigen, die Böses planen für sie ist eine strenge Strafe (bestimmt); und ihr Planen wird unwirksam sein.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmdclxxi{Und Allah hat euch aus Erde erschaffen, dann aus einem Samentropfen, dann machte Er euch zu Paaren. Und kein weibliches Wesen wird schwanger oder entbindet ohne Sein Wissen. Und keinem, der ein langes Leben hat, wird sein Leben verlängert, noch wird sein Leben irgendwie verringert, ohne daß es in einem Buch stünde. Das ist ein leichtes für Allah.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmdclxxii{Und die beiden Gewässer sind nicht gleich: dieses (ist) wohlschmeckend, süß und angenehm zu trinken, und das andere (ist) salzig, bitter. Und aus den beiden esset ihr zartes Fleisch und holt Schmucksachen, die ihr tragt. Und du siehst die Schiffe darauf fahren, auf daß ihr nach Seiner Huld trachten und vielleicht doch dankbar sein möget.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmdclxxiii{Er läßt die Nacht in den Tag und den Tag in die Nacht übergehen. Und Er hat (euch) die Sonne und den Mond dienstbar gemacht; ein jedes (Gestirn) umläuft seine Bahn auf eine bestimmte Zeit. Dies ist Allah, euer Herr; Sein ist das Reich, und jenen, die ihr statt Ihm anruft, gehört noch nicht einmal Macht über das Häutchen eines Dattelkerns.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmdclxxiv{Wenn ihr sie bittet, hören sie eure Bitte nicht; und wenn sie diese auch hören würden, so würden sie euch nichts in Erfüllung bringen. Und am Tage der Auferstehung werden sie leugnen, daß ihr (sie) zu Göttern nahmt. Und niemand kann dich so unterrichten wie der Eine, Der Kundig ist.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmdclxxv{O ihr Menschen, ihr seid arm und auf Allah angewiesen, Allah aber ist auf keinen angewiesen und ist des Lobes Würdig.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmdclxxvi{Wenn Er will, kann Er euch hinwegnehmen und eine neue Schöpfung hervorbringen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmdclxxvii{Und das ist für Allah nicht schwer.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmdclxxviii{Und keine lasttragende (Seele) soll die Last einer anderen tragen; und wenn eine schwerbeladene um ihrer Last willen ruft, soll nichts davon getragen werden, und handelte es sich auch um einen Verwandten. Du kannst die allein warnen, die ihren Herrn im geheimen fürchten und das Gebet verrichten. Und wer sich reinigt, der reinigt sich nur zu seinem eigenen Vorteil; und zu Allah ist die Heimkehr.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmdclxxix{Und wahrlich, der Blinde ist dem Sehenden nicht gleich\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmdclxxx{noch ist es die Finsternis dem Lichte\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmdclxxxi{noch ist es der Schatten der Sonnenhitze\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmdclxxxii{noch sind die Lebenden den Toten gleich. Wahrlich, Allah macht hörend, wen Er will; und du kannst diejenigen nicht hörend machen, die in den Gräbern sind.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmdclxxxiii{Wahrlich, du bist nur ein Warner.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmdclxxxiv{Wahrlich, Wir haben dich mit der Wahrheit als Bringer froher Botschaft und als Warner entsandt; und es gibt kein Volk, in dem es nicht einmal schon Warner gegeben hätte.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmdclxxxv{Und wenn sie dich der Lüge bezichtigen, so haben auch jene schon, die vor ihnen waren, (die Propheten) der Lüge bezichtigt. Ihre Gesandten kamen mit klaren Beweisen und mit den Büchern und mit der erleuchtenden Schrift zu ihnen.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmdclxxxvi{Dann erfaßte Ich jene, die ungläubig waren, und wie war es mit der Verleugnung!\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmdclxxxvii{Hast du nicht gesehen, daß Allah Wasser vom Himmel herniedersendet? Dann bringen Wir damit Früchte mit mannigfachen Farben hervor; und in den Bergen sind weiße und rote, verschiedenfarbige und rabenschwarze Schichten.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmdclxxxviii{Und bei Mensch und Tier und Vieh (gibt es) auch verschiedene Farben. Wahrlich, nur die Wissenden unter Seinen Dienern fürchten Allah. Wahrlich, Allah ist Erhaben, Allverzeihend.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmdclxxxix{Wahrlich, diejenigen, die Allahs Buch verlesen und das Gebet verrichten und von dem, was Wir ihnen gegeben haben, insgeheim und offenkundig spenden, rechnen mit einem Handel, der nie pleite sein wird.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmdcxc{Damit gibt Er ihnen ihren vollen Lohn und noch mehr aus Seiner Huld hinzu; Er ist wahrlich Allverzeihend, Dankbar.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmdcxci{Und das, was Wir dir in dem Buch offenbart haben, ist die Wahrheit, die das bestätigt, was ihm vorausging. Gewiß, Allah kennt und durchschaut Seine Diener recht wohl.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmdcxcii{Alsdann gaben Wir das Buch jenen von Unseren Dienern zum Erbe, die Wir erwählten. Und unter ihnen sind einige, die gegen sich selbst freveln, und unter ihnen sind einige, die den gemäßigten Standpunkt einnehmen, und unter ihnen sind einige, die nach den guten Dingen mit Allahs Erlaubnis wetteifern. Das ist die große Huld.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmdcxciii{Gärten von Eden! Sie werden sie betreten. Geschmückt werden sie darin sein mit Armspangen aus Gold und Perlen, und ihre Kleidung darin wird aus Seide sein.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmdcxciv{Und sie werden sagen: ``Alles Lob gebührt Allah, Der die Traurigkeit von uns genommen hat. Unser Herr ist wahrlich Allverzeihend, Dankbar\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmdcxcv{Der uns in Seiner Huld in der Wohnstatt der Ewigkeit ansässig machte. Keine Mühsal berührt uns darin, noch berührt uns darin Müdigkeit.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmdcxcvi{Und für diejenigen, die ungläubig sind, ist das Feuer der Gahannam. Der Tod wird nicht über sie verhängt, so daß sie sterben könnten; noch wird ihnen etwas von ihrer Strafe erleichtert. So vergelten Wir jedem Undankbaren.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmdcxcvii{Und sie werden darin schreien: ``Unser Herr, bringe uns (aus der Hölle) heraus; wir wollen rechtschaffene Werke tun, anders als wir (zuvor) zu tun pflegten." ``Gaben Wir euch nicht ein genügend langes Leben, so daß ein jeder, der sich besinnen wollte, sich darin hätte besinnen können? Und (überdies) kam der Warner zu euch. So kostet nun (die Strafe); denn Frevler haben keinen Helfer."\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmdcxcviii{Wahrlich, Allah kennt das Verborgene der Himmel und der Erde. Wahrlich, Er kennt alles, was in den Herzen ist.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmdcxcix{Er ist es, Der euch zu Statthaltern auf Erden gemacht hat. Wer aber ungläubig ist - auf ihm (laste) sein Unglaube! Und den Ungläubigen kann ihr Unglaube nur den Widerwillen ihres Herrn mehren, und ihr Unglaube kann den Ungläubigen nur den Verlust vergrößern.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmdcc{Sprich: ``Habt ihr die Götter gesehen die ihr statt Allah anruft? Zeigt mir, was sie von der Erde erschufen. Oder haben sie einen Anteil (im Reich) der Himmel?" Oder haben Wir ihnen ein Buch gegeben woraus sie einen Beweis hätten (entnehmen können)? Nein, die Ungerechten verheißen einander nur Trug.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmdcci{Wahrlich, Allah hält die Himmel und die Erde, damit sie nicht weichen. Und würden sie weichen, so gäbe es keinen außer Ihm, der sie halten könnte. Wahrlich, Er ist Nachsichtig, Allverzeihend.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmdccii{Und sie schworen bei Allah ihre festen Eide; wenn ein Warner zu ihnen käme, würden sie der Führung besser folgen als eines der anderen Völker. Doch als dann in der Tat ein Warner zu ihnen kam, so bestärkte sie das nur in ihrer Abneigung.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmdcciii{(Sie sind) in Hochmut auf Erden und böse im Planen. Doch der böse Plan fängt nur seine Urheber ein. Erwarten sie denn etwas anderes als das Vorgehen gegenüber den Früheren? Aber in Allahs Vorgehen wirst du nie eine Änderung finden; und in Allahs Verfahren wirst du nie einen Wechsel finden.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmdcciv{Sind sie denn nicht im Lande umhergezogen, so daß sie schauen konnten, wie das Ende derer war, die vor ihnen lebten? Und sie hatten mehr Kraft als sie selber. Und nichts vermag Allah in den Himmeln oder auf Erden zu hemmen; denn Er ist Allwissend, Allmächtig.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmdccv{Und wollte Allah die Menschen für alles bestrafen, was sie tun, würde Er nicht ein Lebewesen auf der (Erd-)oberfläche übrig lassen; doch Er gewährt ihnen Aufschub bis zu einer bestimmten Frist; und wenn ihre Frist um ist, dann durchschaut Allah Seine Diener.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmdccvi{\basmalahde Ya Sin.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmdccvii{Beim vollkommenen Quran\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmdccviii{du bist wahrlich einer der Gesandten\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmdccix{der auf einem geraden Weg ist.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmdccx{(Dies ist) eine Offenbarung des Erhabenen, des Barmherzigen\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmdccxi{auf daß du Leute warnest, deren Väter nicht gewarnt worden sind, und die daher achtlos sind.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmdccxii{Bereits hat sich das Wort gegen die meisten von ihnen als wahr erwiesen; denn sie glauben nicht.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmdccxiii{Um ihren Hals haben Wir Fesseln gelegt, die bis an das Kinn reichen, so daß ihr Haupt hochgezwängt ist.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmdccxiv{Und Wir haben vor ihnen einen Wall errichtet und ebenso hinter ihnen einen Wall (errichtet), und Wir haben sie verhüllt, so daß sie nicht sehen können.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmdccxv{Und ihnen ist es gleich, ob du sie warnst oder ob du sie nicht warnst; sie werden nicht glauben.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmdccxvi{Du vermagst nur den zu warnen, der die Ermahnung befolgt und den Allerbarmer im Verborgenen fürchtet. Gib ihm darum die frohe Botschaft von Vergebung und einem ehrenvollen Lohn.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmdccxvii{Wahrlich, Wir sind es, Die die Toten beleben, und Wir schreiben das auf, was sie begehen, zugleich mit dem, was sie zurücklassen; und alle Dinge haben Wir in einem deutlichen Buch verzeichnet.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmdccxviii{Und präge ihnen ein Gleichnis von den Leuten der Stadt, als die Abgesandten zu ihr kamen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmdccxix{Als Wir zwei zu ihnen schickten und sie von ihnen für Lügner gehalten wurden, da stärkten Wir (sie) durch einen dritten, und sie sagten: ``Wir sind zu euch entsandt worden."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmdccxx{Jene sagten: ``lhr seid nur Menschen wie wir; und der Allerbarmer hat nichts herabgesandt. Ihr sprecht nichts als Lügen."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmdccxxi{Sie sagten: ``Unser Herr weiß, daß wir wahrlich Abgesandte zu euch sind.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmdccxxii{Und uns obliegt nur die klare Verkündigung."\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmdccxxiii{Sie sagten: ``Wir ahnen Böses von euch. Wenn ihr (davon) nicht ablaßt, so werden wir euch gewiß steinigen, und euch wird sicher unsere schmerzliche Strafe treffen."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmdccxxiv{Sie sagten: ``Euer Unheil liegt bei euch selbst. Liegt es daran, daß ihr ermahnt werdet? Nein, ihr seid Leute, die das Maß überschreiten."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmdccxxv{Und es kam vom entferntsten Teil der Stadt ein Mann angelaufen. Er sagte: ``O meine Leute, folgt den Gesandten!\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmdccxxvi{Folgt denen, die keinen Lohn von euch fordern und die rechtgeleitet sind.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmdccxxvii{Und warum sollte ich nicht Dem dienen, Der mich erschaffen hat und zu Dem ihr zurückgebracht werdet?\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmdccxxviii{Soll ich etwa andere außer Ihm zu Göttern nehmen? Wenn der Allerbarmer mir ein Leid zufügen will, so wird ihre Fürsprache mir nichts nützen, noch können sie mich retten.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmdccxxix{Dann befände ich mich wahrlich in einem offenkundigen Irrtum.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmdccxxx{Ich glaube an euren Herrn; darum hört mich an."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmdccxxxi{Da wurde (zu ihm) gesprochen: ``Geh in das Paradies ein." Er sagte: ``O wenn doch meine Leute wüßten\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmdccxxxii{wie mein Herr mir vergeben und mich zu einem der Geehrten gemacht hat!"\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmdccxxxiii{Und nach ihm sandten Wir gegen seine Leute kein Heer vom Himmel herab, noch pflegten Wir (eins) zu senden.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmdccxxxiv{Es war nur ein einziger Schrei, und siehe, sie lagen reglos da.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmdccxxxv{Wehe über die Menschen! Kein Gesandter kommt zu ihnen, den sie nicht verspotteten.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmdccxxxvi{Haben sie nicht gesehen, wie viele Generationen Wir schon vor ihnen vernichtet haben (und) daß sie nicht zu ihnen zurückkehren.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmdccxxxvii{Jedoch sie alle, allesamt versammelt, werden sicher vor Uns gebracht werden.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmdccxxxviii{Und ein Zeichen ist ihnen die tote Erde. Wir beleben sie und bringen aus ihr Korn hervor, von dem sie essen.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmdccxxxix{Und Wir haben auf ihr Gärten mit Dattelpalmen und Beeren angelegt, und Wir ließen Quellen aus ihr entspringen\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmdccxl{damit sie von ihren Früchten essen; und ihre Hände schufen sie nicht. Wollen sie da nicht dankbar sein?\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmdccxli{Preis (sei) Ihm, Der die Arten alle paarweise geschaffen hat von dem, was die Erde sprießen läßt, und von ihnen selber und von dem, was sie nicht kennen.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmdccxlii{Und ein Zeichen ist ihnen die Nacht. Wir entziehen ihr das Tageslicht, und siehe, sie sind in Finsternis.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmdccxliii{Und die Sonne eilt dem ihr gesetzten Ziel zu. Das ist die Anordnung des Erhabenen, des Allwissenden.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmdccxliv{Und für den Mond haben Wir Stationen bestimmt, bis er wie der alte Dattelrispenstiel wiederkehrt.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmdccxlv{Weder hat die Sonne den Mond einzuholen, noch eilt die Nacht dem Tage voraus; und alle schweben auf einer Umlaufbahn.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmdccxlvi{Und ein Zeichen ist es ihnen, daß Wir ihre Nachkommenschaft in dem beladenen Schiff trugen.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmdccxlvii{Und Wir schufen ihnen etwas von gleicher Art, worauf sie fahren.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmdccxlviii{Und wenn Wir wollten, so könnten Wir sie ertrinken lassen; dann würden sie weder Helfer haben, noch könnten sie gerettet werden\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmdccxlix{außer durch Unsere Barmherzigkeit und zu einem Nießbrauch auf gewisse Zeit.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmdccl{Und wenn zu ihnen gesprochen wird: ``Hütet euch vor dem, was vor euch ist und was hinter euch ist, auf daß ihr Erbarmen finden möget" (, so beachten sie die Warnung nicht)\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmdccli{Und es kommt kein Zeichen von den Zeichen ihres Herrn zu ihnen, ohne daß sie sich davon abwenden.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmdcclii{Und wenn zu ihnen gesprochen wird: ``Spendet von dem, was Allah euch gegeben bat", sagen die Ungläubigen zu den Gläubigen: ``Sollen wir einen speisen, den Allah hätte speisen können, wenn Er es gewollt hätte? Ihr befindet euch da zweifellos in einem offenkundigen Irrtum."\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmdccliii{Und sie sagen: ``Wann wird diese Verheißung (in Erfüllung gehen), wenn ihr die Wahrheit sagt?"\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmdccliv{Sie warten nur auf einen einzigen Schrei, der sie erfassen wird, während sie noch streiten.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmdcclv{Und sie werden weder imstande sein, ein Vermächtnis zu treffen, noch werden sie zu ihren Angehörigen zurückkehren.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmdcclvi{Und in den, Sur wird gestoßen, und siehe, sie eilen aus ihren Gräbern zu ihrem Herrn hervor.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmdcclvii{Sie werden sagen: ``O wehe uns! Wer hat uns von unserer Liegestelle erweckt? Das ist es, was der Allerbarmer (uns) verheißen hatte, und die Gesandten sagten doch die Wahrheit."\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmdcclviii{Es wird nur ein einziger Schrei sein, und siehe, sie werden alle vor Uns gebracht werden.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmdcclix{Nun, heute wird keine Seele im geringsten ein Unrecht erleiden; und ihr sollt nur für das entlohnt werden, was ihr zu tun pflegtet.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmdcclx{Wahrlich, die Bewohner des Paradieses sind heute beschäftigt und erfreuen sich am Genuß.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmdcclxi{Sie und ihre Gattinnen liegen im Schatten auf Ruhebetten gestützt.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmdcclxii{Früchte werden sie darin haben, und sie werden bekommen, was immer sie (auch) begehren.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmdcclxiii{``Frieden!" - (dies ist) eine Botschaft von einem Sich Erbarmenden Herrn.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmdcclxiv{Und (es wird gesprochen): ``Sondert euch heute ab, o ihr Schuldigen.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmdcclxv{Habe Ich euch, ihr Kinder Adams, nicht geboten, nicht Satan zu dienen - denn er ist euer offenkundiger Feind -\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmdcclxvi{sondern Mir allein zu dienen? Das ist der gerade Weg.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmdcclxvii{Und doch hat er eine große Menge von euch irregeführt. Hattet ihr denn keinen Verstand?\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmdcclxviii{Das ist Gahannam, die euch angedroht wurde\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmdcclxix{brennt heute in ihr dafür, daß ihr ungläubig waret."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmdcclxx{Heute versiegeln Wir ihre Münder, jedoch ihre Hände werden zu Uns sprechen, und ihre Füße werden all das bezeugen, was sie erworben haben.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmdcclxxi{Und hätten Wir gewollt, hätten Wir ihr Augenlicht auslöschen können; dann würden sie versuchen, möglichst schnell auf den rechten Weg zu kommen. Aber wie hätten sie etwas sehen können?\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmdcclxxii{Und hätten Wir gewollt, hätten Wir sie verwandeln können, wo sie waren; dann wären sie nicht imstande gewesen, vorwärts oder rückwärts zu gehen.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmdcclxxiii{Und den, dem Wir ein langes Leben geben, setzen wir körperlichem Verfall aus. Wollen sie es denn nicht begreifen?\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmdcclxxiv{Und Wir haben ihn nicht die Dichtung gelehrt, noch ziemte sie sich für ihn. Dies ist nichts als eine Ermahnung und ein deutlicher Quran\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmdcclxxv{auf daß er jeden warne, der am Leben ist und auf daß das Wort gegen die Ungläubigen in Erfüllung gehe.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmdcclxxvi{Haben sie nicht gesehen, daß Wir von den Dingen, die Unsere Hände gemacht haben, für sie das Vieh schufen, dessen Besitzer sie geworden sind?\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmdcclxxvii{Und Wir haben es ihnen dienstbar gemacht, so daß manche von ihnen zum Reiten dienen und manche Nahrung geben.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmdcclxxviii{Und sie haben an ihnen noch (anderen) Nutzen und (auch) Trank. Wollen sie also nicht dankbar sein?\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmdcclxxix{Und sie haben sich statt Allah Götter genommen, damit ihnen geholfen würde.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmdcclxxx{Sie vermögen ihnen nicht zu helfen; vielmehr sind sie selbst als eine Heerschar für sie im Einsatz\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmdcclxxxi{so laß dich daher von ihrer Rede nicht betrüben. Wir wissen, was sie verbergen und was sie offenkund tun.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmdcclxxxii{Weiß der Mensch denn nicht, daß Wir ihn aus einem Samentropfen erschufen? Und siehe da, er ist ein offenkundiger Widersacher!\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmdcclxxxiii{Und er prägt Uns Gleichnisse und vergißt seine eigene Erschaffung. Er sagt: ``Wer kann die Gebeine beleben, wenn sie morsch geworden sind?"\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmdcclxxxiv{Sprich: ``Er, Der sie das erstemal erschuf - Er wird sie beleben; denn Er kennt jegliche Schöpfung.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmmdcclxxxv{Er, Der für euch Feuer aus den grünen Bäumen hervorbringt; und siehe, davon habt ihr dann Brennmaterial.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmmdcclxxxvi{Ist Er, Der die Himmel und die Erde erschuf, nicht imstande, ihresgleichen zu erschaffen?" Doch, und Er ist der Erschaffer, der Allwissende.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmmdcclxxxvii{Wenn Er ein Ding will, lautet Sein Befehl nur: ``Sei!" und es ist.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmmdcclxxxviii{Also gepriesen sei Der, in Dessen Hand die Herrschaft über alle Dinge ruht und zu Dem ihr zurückgebracht werdet!\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmmdcclxxxix{\basmalahde Bei den Sich-Reihenden in Reihen.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmdccxc{und denen, die grob zurechtweisen\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmdccxci{und denen, die Ermahnung verlesen!\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmdccxcii{Wahrlich, euer Gott ist Einzig\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmdccxciii{Herr der Himmel und der Erde und all dessen, was zwischen beiden ist, und der Herr aller Orte des Sonnenaufgangs.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmdccxciv{Wir haben den untersten Himmel mit einem Schmuck ausgeschmückt: den Sternen\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmdccxcv{die einen Schutz vor jedem aufrührerischen Satan bilden.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmdccxcvi{Sie können nichts bei den höheren Bewohnern erlauschen, und sie werden von allen Seiten beworfen\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmdccxcvii{als Ausgestoßene; und für sie ist eine dauernde Strafe (vorgesehen)\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmdccxcviii{mit Ausnahme dessen, der etwas aufschnappt, doch ihn verfolgt ein flammendes Feuer von durchbohrender Helligkeit.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmdccxcix{Frage sie darum, ob sie schwerer zu erschaffen sind oder die, die Wir erschaffen haben? Denn Wir haben sie aus formbarem Lehm erschaffen.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmdccc{Nein, du staunst, und sie spotten.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmdccci{Und wenn sie ermahnt werden, so beachten sie es nicht.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmdcccii{Und wenn sie ein Zeichen sehen, so verdrehen sie es zu Spott\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmdccciii{und sie sagen: ``Das ist nichts als offenkundige Zauberei.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmdccciv{Wie? Wenn wir tot sind und zu Staub und Gebeinen geworden sind, dann sollen wir wieder auferweckt werden?\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmdcccv{Oder etwa unsere Vorväter?"\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmdcccvi{Sprich: ``Jawohl; und dabei werdet ihr gedemütigt."\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmdcccvii{Dann wird nur ein einziger Schrei herrschen, und siehe, schon schauen sie zu.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmdcccviii{Und sie werden sagen: ``O wehe uns! Das ist der Tag des Gerichts."\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmdcccix{``Das ist der Tag der Entscheidung, den ihr für gelogen hieltet."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmdcccx{``Versammelt jene, die frevelten, und ihre (Gleichgesinnungs)Paare und das, was sie verehrt haben\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmdcccxi{statt Allah, und führt sie zum Wege der Gahim.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmdcccxii{Und haltet sie an; denn sie sollen befragt werden."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmdcccxiii{``Was ist euch, daß ihr einander nicht helft?"\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmdcccxiv{Nein, heute ergeben sie sich.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmdcccxv{Und sie wenden sich aneinander und fragen sich gegenseitig.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmdcccxvi{Sie werden sagen: ``Wahrlich, ihr pflegtet von rechts zu uns zu kommen."\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmdcccxvii{Jene werden antworten: ``Nein, ihr waret selbst keine Gläubigen.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmdcccxviii{Und wir hatten keine Macht über euch; ihr aber waret ein gewalttätiges Volk.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmdcccxix{Nun hat sich das Wort unseres Herrn gegen uns erfüllt. Wir werden gewiß (die Strafe) kosten müssen.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmdcccxx{Und wir verführten euch, weil wir selbst Irrende waren."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmdcccxxi{An jenem Tage werden sie alle Teilhaber an der Strafe sein.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmdcccxxii{So verfahren Wir mit den Schuldigen\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmdcccxxiii{denn als zu ihnen gesprochen wurde: ``Es ist kein Gott außer Allah", da verhielten sie sich hochmütig\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmdcccxxiv{und sagten: ``Sollen wir unsere Götter wegen eines besessenen Dichters aufgeben?"\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmdcccxxv{Nein, er hat die Wahrheit gebracht und die Gesandten bestätigt.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmdcccxxvi{Ihr werdet sicher die peinvolle Strafe kosten.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmdcccxxvii{Und ihr werdet nur für das, was ihr selbst gewirkt habt, belohnt werden.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmdcccxxviii{Ausgenommen (davon sind) die erwählten Diener Allahs.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmdcccxxix{Diese sollen eine zuvor bekannte Versorgung erhalten\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmdcccxxx{Früchte; und sie sollen geehrt werden\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmdcccxxxi{in den Gärten der Wonne\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmdcccxxxii{auf Ruhebetten einander gegenüber (sitzend)\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmdcccxxxiii{während ein unerschöpflicher Becher unter ihnen die Runde macht.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmdcccxxxiv{(Er ist) weiß und wohlschmeckend für die Trinkenden.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmdcccxxxv{Er wird keinen Rausch erzeugen, noch werden sie davon müde werden.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmdcccxxxvi{Und bei ihnen werden (Keusche) sein, die züchtig aus großen Augen blicken\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmdcccxxxvii{als ob sie verborgene Perlen wären.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmdcccxxxviii{Und einige von ihnen werden sich an die anderen wenden, um sich gegenseitig zu befragen.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmdcccxxxix{Einer ihrer Sprecher wird sagen: ``lch hatte einen Gefährten\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmdcccxl{der zu fragen pflegte: ``Hältst du tatsächlich (die Auferstehung) für wahr?\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmdcccxli{Wenn wir tot sind und zu Staub und Gebeinen geworden sind, dann sollen uns (unsere Taten) wirklich vergolten werden?""\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmdcccxlii{Er wird fragen: ``Wollt ihr (ihn) schauen?"\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmdcccxliii{Dann wird er schauen und ihn inmitten der Gahim sehen.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmdcccxliv{Er wird sagen: ``Bei Allah, beinahe hättest du mich ins Verderben gestürzt.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmdcccxlv{Und wäre nicht die Gnade meines Herrn gewesen, hätte ich sicher zu denen gehört, die (zum Feuer) gebracht werden.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmdcccxlvi{Ist es nicht so, daß wir nicht sterben werden\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmdcccxlvii{außer bei unserem ersten Tod? Und wir sollen nicht bestraft werden.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmdcccxlviii{Wahrlich, das ist der gewaltige Gewinn.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmdcccxlix{Für solches wie dies denn mögen die Wirkenden wirken."\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmdcccl{Ist dies besser als Bewirtung oder der Baum des Zaqqwn?\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmdcccli{Denn Wir haben ihn zu einer Versuchung für die Missetäter gemacht.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmdccclii{Er ist ein Baum, der aus dem Grunde der Gahim emporwächst.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmdcccliii{Seine Früchte scheinen wie Köpfe der Satane zu sein.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmdcccliv{Sie sollen davon essen und (ihre) Bäuche damit füllen.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmdccclv{Darauf sollen sie eine Mischung von siedendem Wasser (zum Trank) erhalten.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmdccclvi{Danach sollen sie zur Gahim zurück kehren.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmdccclvii{Sie fanden ihre Väter als Irrende vor\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmdccclviii{und so traten sie eilends in ihre Fußstapfen.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmdccclix{Und die meisten der Vorfahren waren vor ihnen irregegangen.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmdccclx{Und wahrlich, Wir hatten ihnen Warner gesandt.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmdccclxi{Also, siehe nun, wie da der Ausgang derer war, die gewarnt worden waren\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmdccclxii{mit Ausnahme der erwählten Diener Allahs!\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmdccclxiii{Und wahrlich, Noah rief Uns an, und Wir sind es, die am besten erhören!\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmdccclxiv{Und Wir erretteten ihn und die Seinen aus der großen Bedrängnis.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmdccclxv{Und Wir machten seine Nachkommenschaft zu den einzig Überlebenden.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmdccclxvi{Und Wir bewahrten seinen Namen unter den künftigen Geschlechtern.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmdccclxvii{Friede sei auf Noah in allen Welten!\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmmdccclxviii{So belohnen Wir jene, die Gutes wirken.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmmdccclxix{Er gehörte zu Unseren gläubigen Dienern.\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmmdccclxx{Dann ließen Wir die anderen ertrinken.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmmdccclxxi{Und wahrlich, von seiner Art war Abraham\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmmdccclxxii{als er zu seinem Herrn mit heilem Herzen kam\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmmdccclxxiii{(und) als er zu seinem Vater und zu seinem Volk sagte: ``Was verehrt ihr da?\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmmdccclxxiv{Ist es eine Lüge - Götter außer Allah -, was ihr begehrt?\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmmdccclxxv{Was denkt ihr denn vom Herrn der Welten?"\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmmdccclxxvi{Dann warf er einen Blick zu den Sternen\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmmdccclxxvii{und sagte: ``Mir ist übel."\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmmdccclxxviii{Da kehrten sie ihm den Rücken (und) gingen fort.\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmmdccclxxix{Nun wandte er sich heimlich an ihre Götter und sagte: ``Wollt ihr nicht essen?\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmmdccclxxx{Was ist euch, daß ihr nicht redet?"\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmmdccclxxxi{Dann begann er sie plötzlich mit der Rechten zu schlagen.\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmmdccclxxxii{Da kamen sie zu ihm geeilt.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mmmdccclxxxiii{Er sagte: ``Verehrt ihr das, was ihr gemeißelt habt\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mmmdccclxxxiv{obwohl Allah euch und das, was ihr gemacht habt, erschaffen hat?"\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mmmdccclxxxv{Sie sagten: ``Baut einen Bau für ihn und werft ihn in die Gahim!"\qt@no{(97)}}
\qt@newcmd\qurantrans@de@mmmdccclxxxvi{Sie wollten Ränke gegen ihn schmieden, allein Wir machten sie zu den Niedrig sten.\qt@no{(98)}}
\qt@newcmd\qurantrans@de@mmmdccclxxxvii{Und er sagte: ``Seht, ich gehe zu meinem Herrn, Der mich rechtleiten wird.\qt@no{(99)}}
\qt@newcmd\qurantrans@de@mmmdccclxxxviii{Mein Herr, gewähre mir einen rechtschaffenen (Sohn)"\qt@no{(100)}}
\qt@newcmd\qurantrans@de@mmmdccclxxxix{Dann gaben Wir ihm die frohe Botschaft von einem sanftmütigen Sohn.\qt@no{(101)}}
\qt@newcmd\qurantrans@de@mmmdcccxc{Als er alt genug war, um mit ihm zu arbeiten, sagte er. O mein Sohn, ich sehe im Traum, daß ich dich schlachte. Nun schau, was meinst du dazu?" Er sagte: ``O mein Vater, tu, wie dir befohlen wird; du sollst mich - so Allah will - unter den Geduldigen finden."\qt@no{(102)}}
\qt@newcmd\qurantrans@de@mmmdcccxci{Als sie sich beide (Allahs Willen) ergeben hatten und er ihn mit der Stirn auf den Boden hingelegt hatte\qt@no{(103)}}
\qt@newcmd\qurantrans@de@mmmdcccxcii{da riefen Wir ihm zu: ``O Abraham\qt@no{(104)}}
\qt@newcmd\qurantrans@de@mmmdcccxciii{du hast bereits das Traumgesicht erfüllt." So belohnen Wir die, die Gutes tun.\qt@no{(105)}}
\qt@newcmd\qurantrans@de@mmmdcccxciv{Wahrlich, das ist offenkundig eine schwere Prüfung.\qt@no{(106)}}
\qt@newcmd\qurantrans@de@mmmdcccxcv{Und Wir lösten ihn durch ein großes Schlachttier aus.\qt@no{(107)}}
\qt@newcmd\qurantrans@de@mmmdcccxcvi{Und Wir bewahrten seinen Namen unter den künftigen Geschlechtern.\qt@no{(108)}}
\qt@newcmd\qurantrans@de@mmmdcccxcvii{Friede sei auf Abraham!\qt@no{(109)}}
\qt@newcmd\qurantrans@de@mmmdcccxcviii{So belohnen Wir die, die Gutes tun.\qt@no{(110)}}
\qt@newcmd\qurantrans@de@mmmdcccxcix{Er gehörte zu Unseren gläubigen Dienern.\qt@no{(111)}}
\qt@newcmd\qurantrans@de@mmmcm{Und Wir gaben ihm die frohe Botschaft von Isaak, einem Propheten, der zu den Rechtschaffenen gehörte.\qt@no{(112)}}
\qt@newcmd\qurantrans@de@mmmcmi{Und Wir segneten ihn und Isaak. Und unter ihren Nachkommen sind (manche), die Gutes tun, und (andere), die offenkundig gegen sich selbst freveln.\qt@no{(113)}}
\qt@newcmd\qurantrans@de@mmmcmii{Und wahrlich, Wir hatten Uns (auch) gegen Moses und Aaron Gnädig erwiesen.\qt@no{(114)}}
\qt@newcmd\qurantrans@de@mmmcmiii{Und Wir erretteten sie beide und ihr Volk aus der großen Bedrängnis.\qt@no{(115)}}
\qt@newcmd\qurantrans@de@mmmcmiv{Und Wir halfen ihnen; so waren sie es, die siegten.\qt@no{(116)}}
\qt@newcmd\qurantrans@de@mmmcmv{Und Wir gaben ihnen die deutliche Schrift.\qt@no{(117)}}
\qt@newcmd\qurantrans@de@mmmcmvi{Und Wir führten sie auf den geraden Weg.\qt@no{(118)}}
\qt@newcmd\qurantrans@de@mmmcmvii{Und Wir bewahrten ihren Namen unter den künftigen Geschlechtern.\qt@no{(119)}}
\qt@newcmd\qurantrans@de@mmmcmviii{Friede sei auf Moses und Aaron!\qt@no{(120)}}
\qt@newcmd\qurantrans@de@mmmcmix{So belohnen Wir die, die Gutes tun.\qt@no{(121)}}
\qt@newcmd\qurantrans@de@mmmcmx{Sie gehörten beide zu Unseren gläubigen Dienern.\qt@no{(122)}}
\qt@newcmd\qurantrans@de@mmmcmxi{Und wahrlich, Elias war auch einer der Gesandten.\qt@no{(123)}}
\qt@newcmd\qurantrans@de@mmmcmxii{Da sagte er zu seinem Volk: ``Wollt ihr nicht gottesfürchtig sein?\qt@no{(124)}}
\qt@newcmd\qurantrans@de@mmmcmxiii{Wollt ihr 8a`1 (euren Götzen) anrufen und den besten Schöpfer verlassen\qt@no{(125)}}
\qt@newcmd\qurantrans@de@mmmcmxiv{Allah, euren Herrn und den Herrn eurer Vorväter?"\qt@no{(126)}}
\qt@newcmd\qurantrans@de@mmmcmxv{Jedoch sie erklärten ihn als Lügner, und sie werden bestimmt (zum Gericht) gebracht werden\qt@no{(127)}}
\qt@newcmd\qurantrans@de@mmmcmxvi{ausgenommen die erwählten Diener Allahs.\qt@no{(128)}}
\qt@newcmd\qurantrans@de@mmmcmxvii{Und Wir bewahrten seinen Namen unter den künftigen Geschlechtern.\qt@no{(129)}}
\qt@newcmd\qurantrans@de@mmmcmxviii{Friede sei auf Il-Yasin!\qt@no{(130)}}
\qt@newcmd\qurantrans@de@mmmcmxix{So belohnen Wir die, die Gutes tun.\qt@no{(131)}}
\qt@newcmd\qurantrans@de@mmmcmxx{Er gehörte zu Unseren gläubigen Dienern.\qt@no{(132)}}
\qt@newcmd\qurantrans@de@mmmcmxxi{Und wahrlich, (auch) Lot war einer der Gesandten.\qt@no{(133)}}
\qt@newcmd\qurantrans@de@mmmcmxxii{Da erretteten Wir ihn und alle die Seinen\qt@no{(134)}}
\qt@newcmd\qurantrans@de@mmmcmxxiii{ausgenommen eine alte Frau, die mit den (anderen) zurückblieb.\qt@no{(135)}}
\qt@newcmd\qurantrans@de@mmmcmxxiv{Hierauf zerstörten Wir die anderen.\qt@no{(136)}}
\qt@newcmd\qurantrans@de@mmmcmxxv{Und wahrlich, ihr geht an ihnen am Morgen vorüber\qt@no{(137)}}
\qt@newcmd\qurantrans@de@mmmcmxxvi{und auch am Abend. Wollt ihr es da nicht begreifen?\qt@no{(138)}}
\qt@newcmd\qurantrans@de@mmmcmxxvii{Und sicher war Jonas einer der Gesandten.\qt@no{(139)}}
\qt@newcmd\qurantrans@de@mmmcmxxviii{Da floh er zu dem beladenen Schiff\qt@no{(140)}}
\qt@newcmd\qurantrans@de@mmmcmxxix{und loste und verlor dabei.\qt@no{(141)}}
\qt@newcmd\qurantrans@de@mmmcmxxx{Und der große Fisch verschlang ihn, während er (Jonas, sich selbst) tadelte.\qt@no{(142)}}
\qt@newcmd\qurantrans@de@mmmcmxxxi{Wenn er nicht zu jenen gehört hätte, die (Allah) preisen\qt@no{(143)}}
\qt@newcmd\qurantrans@de@mmmcmxxxii{wäre er gewiß in dessen Bauch bis zum Tage der Auferstehung geblieben.\qt@no{(144)}}
\qt@newcmd\qurantrans@de@mmmcmxxxiii{Dann warfen Wir ihn ins Freie, und er war krank.\qt@no{(145)}}
\qt@newcmd\qurantrans@de@mmmcmxxxiv{Und Wir ließen eine Kürbispflanze über ihm wachsen.\qt@no{(146)}}
\qt@newcmd\qurantrans@de@mmmcmxxxv{Und Wir entsandten ihn zu hunderttausend oder mehr (Menschen)\qt@no{(147)}}
\qt@newcmd\qurantrans@de@mmmcmxxxvi{Und sie wurden gläubig; so gewährten Wir ihnen für eine Zeitlang Versorgung.\qt@no{(148)}}
\qt@newcmd\qurantrans@de@mmmcmxxxvii{Nun frage sie, ob dein Herr Töchter hat, während sie Söhne haben.\qt@no{(149)}}
\qt@newcmd\qurantrans@de@mmmcmxxxviii{Oder haben Wir etwa die Engel weiblich erschaffen, während sie zugegen waren?\qt@no{(150)}}
\qt@newcmd\qurantrans@de@mmmcmxxxix{Es ist bloß ihre eigene Lüge, wenn sie sagen\qt@no{(151)}}
\qt@newcmd\qurantrans@de@mmmcmxl{``Allah hat gezeugt"; und sie sind wahrlich Lügner.\qt@no{(152)}}
\qt@newcmd\qurantrans@de@mmmcmxli{Hat Er Töchter den Söhnen vorgezogen?\qt@no{(153)}}
\qt@newcmd\qurantrans@de@mmmcmxlii{Was verwirrt euch? Wie urteilt ihr nur?\qt@no{(154)}}
\qt@newcmd\qurantrans@de@mmmcmxliii{Wollt ihr euch denn nicht besinnen?\qt@no{(155)}}
\qt@newcmd\qurantrans@de@mmmcmxliv{Oder habt ihr einen klaren Beweis?\qt@no{(156)}}
\qt@newcmd\qurantrans@de@mmmcmxlv{Sodann bringt euer Buch herbei, wenn ihr wahrhaftig seid.\qt@no{(157)}}
\qt@newcmd\qurantrans@de@mmmcmxlvi{Und sie unterstellten Ihm eine Blutsverwandschaft mit den Ginn; während die Ginn doch recht wohl wissen, daß sie (vor Ihn zum Gericht) gebracht werden sollen.\qt@no{(158)}}
\qt@newcmd\qurantrans@de@mmmcmxlvii{Gepriesen sei Allah hoch über all das, was sie beschreiben.\qt@no{(159)}}
\qt@newcmd\qurantrans@de@mmmcmxlviii{Ausgenommen (davon sind) die erwählten Diener Allahs.\qt@no{(160)}}
\qt@newcmd\qurantrans@de@mmmcmxlix{Wahrlich, ihr und das, was ihr verehrt\qt@no{(161)}}
\qt@newcmd\qurantrans@de@mmmcml{ihr vermögt nicht (einen) gegen Ihn zu verführen\qt@no{(162)}}
\qt@newcmd\qurantrans@de@mmmcmli{mit Ausnahme dessen, der in der Gahim brennen wird.\qt@no{(163)}}
\qt@newcmd\qurantrans@de@mmmcmlii{Und da ist keiner unter uns (Engeln), der nicht seinen (ihm) zugewiesenen Platz hätte.\qt@no{(164)}}
\qt@newcmd\qurantrans@de@mmmcmliii{Und wahrlich, wir sind die in Reihen Geordneten.\qt@no{(165)}}
\qt@newcmd\qurantrans@de@mmmcmliv{Und wahrlich, wir sind es, die (Allah) preisen.\qt@no{(166)}}
\qt@newcmd\qurantrans@de@mmmcmlv{Und sie pflegten doch zu sagen\qt@no{(167)}}
\qt@newcmd\qurantrans@de@mmmcmlvi{``Hätten wir nur eine Mahnung von Seiten der Früheren (erhalten)\qt@no{(168)}}
\qt@newcmd\qurantrans@de@mmmcmlvii{so wären wir sicher Allahs erwählte Diener gewesen."\qt@no{(169)}}
\qt@newcmd\qurantrans@de@mmmcmlviii{Dennoch glauben sie nicht an ihn (den Quran), allein sie werden es bald erfahren.\qt@no{(170)}}
\qt@newcmd\qurantrans@de@mmmcmlix{Wahrlich, Unser Wort ist schon an Unsere gesandten Diener ergangen\qt@no{(171)}}
\qt@newcmd\qurantrans@de@mmmcmlx{sie sind wahrlich die, denen geholfen wird.\qt@no{(172)}}
\qt@newcmd\qurantrans@de@mmmcmlxi{Und Unsere Heerschar wird sicher siegreich sein.\qt@no{(173)}}
\qt@newcmd\qurantrans@de@mmmcmlxii{Darum wende dich von ihnen für eine Zeitlang ab\qt@no{(174)}}
\qt@newcmd\qurantrans@de@mmmcmlxiii{und beobachte sie; denn sie werden bald sehen.\qt@no{(175)}}
\qt@newcmd\qurantrans@de@mmmcmlxiv{Ist es etwa Unsere Strafe, die sie beschleunigen möchten?\qt@no{(176)}}
\qt@newcmd\qurantrans@de@mmmcmlxv{Doch wenn sie über ihr Gebiet herabkommt, dann wird der Morgen für die Gewarnten übel sein.\qt@no{(177)}}
\qt@newcmd\qurantrans@de@mmmcmlxvi{So wende dich von ihnen für eine Zeitlang ab\qt@no{(178)}}
\qt@newcmd\qurantrans@de@mmmcmlxvii{und beobachte (sie); denn sie werden bald sehen.\qt@no{(179)}}
\qt@newcmd\qurantrans@de@mmmcmlxviii{Gepriesen sei dein Herr, der Herr der Erhabenheit, Hoch über dem, was sie beschreiben.\qt@no{(180)}}
\qt@newcmd\qurantrans@de@mmmcmlxix{Und Friede sei auf den Gesandten!\qt@no{(181)}}
\qt@newcmd\qurantrans@de@mmmcmlxx{Und alles Lob gebührt Allah, dem Herrn der Welten.\qt@no{(182)}}
\qt@newcmd\qurantrans@de@mmmcmlxxi{\basmalahde Sad. Beim Quran mit der Ermahnung!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmcmlxxii{Die, die aber ungläubig sind, verharren in falschem Stolz und Feindseligkeit.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmcmlxxiii{Wie oft ließen Wir manches Geschlecht schon vor ihnen zugrunde gehen! Sie schrien, als keine Zeit mehr zum Entrinnen war.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmcmlxxiv{Und sie wundern sich, daß ein Warner aus ihrer Mitte zu ihnen gekommen ist; und die Ungläubigen sagen: ``Das ist ein Zauberer, ein Lügner.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmcmlxxv{Macht er die Götter zu einem einzigen Gott? Dies ist wahrlich ein wunderbares Ding."\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmcmlxxvi{Und die Vornehmen unter ihnen liefen davon (und sagten): ``Geht und haltet an euren Göttern fest. Das ist es, was man beabsichtigt.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmcmlxxvii{Wir haben hiervon nie etwas in der früheren Religion gehört. Dies ist nichts als eine Dichtung.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmcmlxxviii{Ist die Ermahnung unter uns nur zu ihm allein gekommen?" Nein, sie hegen Zweifel über Meine Er mahnung. Nein, sie haben Meine Strafe nicht gekostet.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmcmlxxix{Besitzen sie etwa die Schätze der Barmherzigkeit deines Herrn, des Allmächtigen, des Gabenverleihers?\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmcmlxxx{Oder gehört ihnen das Königreich der Himmel und der Erde und dessen, was zwischen beiden ist? Mögen sie nur weiter Mittel und Wege (gegen Mich) ersinnen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmcmlxxxi{Eine Heerschar der Verbündeten wird in die Flucht geschlagen werden.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmcmlxxxii{Vor ihnen haben schon geleugnet: das Volk Noahs und die `Ad und Pharao mit den bodenfesten Bauten.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmcmlxxxiii{und die Tamud und das Volk Lots und die Bewohner des Waldes diese waren die Verbündeten.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmcmlxxxiv{Ein jeder hatte die Gesandten der Lüge bezichtigt, darum war Meine Strafe fällig gewesen.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmcmlxxxv{Und diese erwarteten nichts als einen einzigen Schrei, für den es keinen Aufschub gibt.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmcmlxxxvi{Und sie sagen: ``Unser Herr, beschleunige Unseren Teil (der Strafe) vor dem Tage der Abrechnung."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmcmlxxxvii{Ertrage in Geduld, was sie reden, und gedenke Unseres Dieners David, des Kraftvollen. Er war gehorsam.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmcmlxxxviii{Wahrlich, Wir machten (ihm) die Berge dienstbar, um mit ihm am Abend und beim Sonnenaufgang (Allah) zu lobpreisen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmcmlxxxix{Und die Vögel in Scharen - alle waren sie ihm gehorsam.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmcmxc{Und Wir festigten sein Königreich und gaben ihm Weisheit und ein unwiderrufliches Urteilsvermögen.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmcmxci{Ist die Geschichte von den Streitenden auch zu dir gelangt? Wie sie über die Mauer (seines) Gebetsgemachs kletterten\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmcmxcii{(und) wie sie bei David eindrangen und er sich vor ihnen fürchtete? Sie sagten: ``Fürchte dich nicht. (Wir sind) zwei Streitende, von denen einer sich gegen den anderen vergangen hat; richte darum in Gerechtigkeit zwischen uns und handle nicht ungerecht und leite uns auf den ebenen Weg.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmcmxciii{Dieser ist mein Bruder; er hat neunundneunzig Mutterschafe, und ich habe ein einziges Mutterschaf. Dennoch sagte er: ``Übergib es mir", und hat mich in der Rede überwunden."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmcmxciv{Er (David) sagte: ``Wahrlich, er hat ein Unrecht an dir verübt, als er dein Mutterschaf zu seinen eigenen Mutterschafen hinzu verlangte. Und gewiß, viele Teilhaber vergehen sich gegeneinander; nur die (sind davon) ausgenommen, die glauben und gute Werke tun; und das sind wenige." Und David merkte, daß Wir ihn auf die Probe gestellt hatten; also bat er seinen Herrn um Verzeihung und fiel betend nieder und bekehrte sich.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmcmxcv{Darum vergaben Wir ihm dies; und wahrlich, er hatte nahen Zutritt zu Uns und eine herrliche Einkehr (bei Uns)\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmcmxcvi{``O David, Wir haben dich zu einem Nachfolger auf Erden gemacht; richte darum zwischen den Menschen in Gerechtigkeit, und folge nicht (deinen) persönlichen Neigungen, damit sie dich nicht vom Wege Allahs abirren lassen." Wahrlich jenen, die von Allahs Weg abirren, wird eine strenge Strafe zuteil sein, weil sie den Tag der Abrechnung vergaßen.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmcmxcvii{Und Wir haben den Himmel und die Erde und das, was zwischen beiden ist, nicht sinnlos erschaffen. Das ist die Ansicht derer, die ungläubig sind. Wehe denn den Ungläubigen wegen des Feuers!\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmcmxcviii{Oder sollen Wir etwa diejenigen, die glauben und gute Werke tun, gleich denen behandeln, die Verderben auf Erden stiften? Oder sollen Wir die Gottesfürchtigen wie die Unverschämten behandeln?\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmcmxcix{Es ist ein Buch voll des Segens, das Wir zu dir hinabgesandt haben, auf daß sie über seine Verse nachdenken, und auf daß diejenigen ermahnt werden mögen, die verständig sind.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmm{Und Wir bescherten David Salomo. (Er war) ein vortrefflicher Diener; stets wandte er sich (zu Allah)\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmi{Als vor ihn zur Abendstunde schnelltrabende Rennpferde aus edelster Zucht gebracht wurden\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmii{sagte er: ``lch habe die guten Dinge dieser Welt sehr lieb und habe dabei versäumt, meines Herrn zu gedenken" - bis sie (die Sonne) hinter dem Horizont verborgen war.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmiii{``Bringt sie zu mir zurück." Dann begann er über (ihre) Beine und Hälse zu streichen.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmiv{Und wahrlich, Wir stellten Salomo auf die Probe, und Wir setzten einen Leib auf seinen Thron. Dann bekehrte er sich.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmv{Er sagte: ``O mein Herr, vergib mir und gewähre mir ein Königreich, wie es keinem nach mir geziemt; wahrlich, Du bist der Gabenverleiher."\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmvi{Darauf machten Wir ihm den Wind dienstbar, auf daß er auf sein Geheiß hin sanft wehte, wohin er wollte.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmvii{Und (Wir machten ihm) die Satane, alle die Erbauer und Taucher\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmviii{wie auch andere, die in Fesseln aneinander gekettet waren (, dienstbar)\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmix{``Dies ist Unsere Gabe, so erweise dich als Wohltäter oder sei zurückhaltend (im Geben), ohne abzurechnen."\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmx{Und sicher hatte er nahen Zutritt zu Uns und eine herrliche Einkehr (bei Uns)\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmxi{Und gedenke Unseres Dieners Hiob, als er seinen Herrn anrief: ``Satan hat mich berührt mit Mühsal und Pein."\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmxii{``Stampfe mit deinem Fuß auf. Hier ist kühles Wasser zum Waschen und zum Trinken."\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmxiii{Und Wir schenkten ihm seine Angehörigen (wieder) und noch einmal so viele dazu von Uns als Barmherzigkeit und als Ermahnung für die Verständigen.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmxiv{Und (Wir sprachen): ``Nimm ein Bündel in deine Hand und schlage damit zu und werde nicht eidbrüchig." Wahrlich, Wir fanden ihn geduldig. (Er war) ein vortrefflicher Diener; stets wandte er sich (Allah) zu.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmxv{Und gedenke Unserer Diener Abraham, Isaak und Jakob - Männer von Kraft und Einsicht.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmxvi{Wir erwählten sie zu einem besonderen Zweck - zur Erinnerung an die Wohnstatt (des Jenseits)\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmxvii{Und wahrlich, vor Uns gehören sie zu den Auserwählten, den Besten.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmxviii{Und gedenke Ismaels, Elisas und Du-l-Kifls; alle gehören sie zu den Besten.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmxix{Dies ist eine Ermahnung; den Rechtschaffenen wird gewiß eine herrliche Stätte der Rückkehr zuteil sein\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmxx{die Gärten von Eden, deren Tore für sie geöffnet sind.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmxxi{Dort werden sie zurückgelehnt ruhen; dort werden sie Früchte in Mengen und reichlich Trank haben.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmxxii{Und bei ihnen werden (Keusche) sein, die züchtig blicken, (und) Gefährtinnen gleichen Alters.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmxxiii{Dies ist, was euch für den Tag der Abrechnung verheißen wurde.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmxxiv{Wahrlich, das ist Unsere Versorgung; nie wird sie sich erschöpfen.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmxxv{Dies ist (für die Gläubigen) Doch für die Widerspenstigen ist eine üble Stätte der Rückkehr (bestimmt):\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmxxvi{Gahannam, die sie betreten werden; welch schlimme Stätte!\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmxxvii{Dies ist (für die Ungläubigen). Mögen sie es denn kosten: siedendes Wasser und eine Trankmischung aus Blut und Eiter\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmmxxviii{und anderes gleicher Art und in Vielfalt.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmmxxix{``Hier ist eine Schar, die mit euch zusammen hineingestürzt wird." Kein Willkomm (sei) ihnen! Sie sollen im Feuer brennen.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmmxxx{Sie werden sagen: ``Nein, ihr seid es. Kein Willkomm (sei) euch denn! Ihr seid es, die uns dies bereitet haben. Und welch schlimmer Ort ist das!"\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmmxxxi{Sie werden sagen: ``Unser Herr, wer immer uns dies bereitete füge ihm die doppelte Strafe im Feuer hinzu."\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmmxxxii{Und sie werden sagen: `` Was ist mit uns geschehen, daß wir nicht die Leute sehen, die wir zu den Bösen zu zählen pflegten?\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmmxxxiii{Sollte es sein, daß wir sie (zu Unrecht) zum Gespött gemacht haben, oder haben unsere Augen sie verfehlt?"\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmmxxxiv{Wahrlich, das ist in der Tat ein Redestreit der Bewohner des Feuers untereinander.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmmxxxv{Sprich: ``lch bin nur ein Warner; und es ist kein Gott außer Allah, dem Einzigen, dem Allbezwingenden\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmmxxxvi{dem Herrn der Himmel und der Erde und dessen was zwischen beiden ist, dem Erhabenen, dem Allverzeihenden."\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmmxxxvii{Sprich: ``Es ist eine große Kunde.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmmxxxviii{Ihr wendet euch jedoch davon ab.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmmxxxix{Ich hatte keine Kunde von den höheren Bewohnern, da sie untereinander stritten.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmmxl{Nur dies wurde mir offenbart, daß ich nur ein deutlicher Warner bin."\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmmxli{Da sprach dein Herr zu den Engeln: ``Es ist Mein Wille, einen Menschen aus Ton zu erschaffen.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmmxlii{Und wenn Ich ihn gebildet und Meinen Geist in ihn eingehaucht habe, dann fallt vor ihm nieder."\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmmxliii{Da warfen sich alle Engel nieder\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmmxliv{bis auf Iblis. Er wandte sich hochmütig ab und war ungläubig.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmmxlv{Er sprach: ``O Iblis, was hindert dich daran, dich vor etwas niederzuwerfen, das Ich mit Meinen Händen geschaffen habe? Bist du hochmütig oder gehörst du zu den Überheblichen?"\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmmxlvi{Er sagte: ``lch bin besser als er. Du erschufst mich aus Feuer, und ihn hast Du aus Ton erschaffen."\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmmxlvii{Er sprach: ``So geh hinaus von hier; denn du bist ein Verfluchter.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmmxlviii{Und Mein Fluch soll auf dir bis zum Tage des Gerichts lasten."\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmmxlix{Er sagte: ``O mein Herr, gewähre mir eine Frist bis zu dem Tage, an dem sie auferweckt werden."\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmmml{Er sprach: ``Also, wird dir die Frist gewahrt\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmmmli{bis zum Tage einer vorbestimmten Zeit."\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmmmlii{Er sagte: ``Bei Deiner Erhabenheit, ich will sie sicher alle in die Irre führen.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmmmliii{Ausgenommen (davon sind) Deine erwählten Diener unter ihnen."\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmmmliv{Er sprach: ``Dann ist dies die Wahrheit, und Ich rede die Wahrheit\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmmmlv{daß Ich wahrlich Gahannam mit dir und denen, die dir folgen, insgesamt füllen werde."\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmmmlvi{Sprich: ``lch verlange von euch keinen Lohn dafür, noch bin ich einer derer, die sich (etwas) anmaßen.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmmmlvii{Dieser (Quran) ist nichts als eine Ermahnung für die Welten.\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmmmlviii{Und ihr werdet sicher seine Kunde nach einer Zeit kennen."\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmmmlix{\basmalahde Die Offenbarung des Buches stammt von Allah, dem Erhabenen, dem Allweisen.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmlx{Wahrlich, Wir haben dir das Buch mit der Wahrheit hinabgesandt; so diene denn Allah in lauterem Gehorsam Ihm gegenüber.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmlxi{Wahrlich, Allah (allein) gebührt lauterer Gehorsam. Und diejenigen, die sich andere zu Beschützern nehmen statt Ihn (, sagen): ``Wir dienen ihnen nur, damit sie uns Allah nahebringen." Wahrlich, Allah wird zwischen ihnen über das, worüber sie uneins sind, richten. Wahrlich, Allah weist nicht dem den Weg, der ein Lügner, ein Undankbarer ist.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmlxii{Hätte Allah Sich einen Sohn nehmen wollen, hätte Er wählen können, was Ihm beliebte, von dem, was Er erschaffen hat. Preis (sei) Ihm! Er ist Allah, der Einzige, der Allbezwingende.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmlxiii{Er schuf die Himmel und die Erde in gerechter Weise. Er läßt die Nacht über den Tag und den Tag über die Nacht rollen; und Er hat (euch) die Sonne und den Mond dienstbar gemacht; ein jedes (Gestirn) läuft für eine bestimmte Frist. Wahrlich, Er allein ist der Erhabene, der Allverzeihende.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmlxiv{Er schuf euch aus einem einzigen Wesen, dann machte Er aus diesem seine Gattin, und Er erschuf für euch acht Haustiere in Paaren. Er erschafft euch in den Schößen eurer Mütter, Schöpfung nach Schöpfung, in drei Finsternissen. Das ist Allah, euer Herr. Sein ist das Reich. Es ist kein Gott außer Ihm. Wie lasset ihr euch da (von Ihm) abwenden?\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmlxv{Wenn ihr undankbar seid, so ist Allah auf keinen von euch angewiesen. Und Er findet nicht Wohlgefallen am Unglauben Seiner Diener; doch wenn ihr aber dankbar seid, so gefällt Ihm das an euch. Und keine lasttragende (Seele) soll die Last einer anderen tragen. Danach werdet ihr zu eurem Herrn heimkehren; und Er wird euch verkünden, was ihr zu tun pflegtet. Wahrlich, Er weiß wohl, was in den Herzen ist.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmlxvi{Und wenn den Menschen ein Unheil trifft, so ruft er seinen Herrn an und wendet sich bußfertig Ihm zu. Dann aber, wenn Er ihm eine Gnade von Sich aus gewährt hat, vergißt er, um was er Ihn zuvor zu bitten pflegte, und setzt Allah Partner zur Seite, auf daß er (die Menschen) von Seinem Wege ab in die Irre führe. Sprich: ``Vergnüge dich mit deinem Unglauben für eine kurze Zeit; denn du gehörst zu den Bewohnern des Feuers."\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmlxvii{Ist etwa jener, der zu Allah in den Nachtstunden - sich niederwerfend und stehend - betet, der sich vor dem Jenseits fürchtet und auf die Barmherzigkeit seines Herrn hofft (einem Ungehorsamen gleich)? Sprich: ``Sind solche, die wissen, denen gleich, die nicht wissen?" Allein nur diejenigen lassen sich warnen, die verständig sind.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmlxviii{Sprich: ``O meine Diener, die ihr gläubig seid, fürchtet euren Herrn. Für diejenigen, die in dieser Welt Gutes tun, ist Gutes (bestimmt) Und Allahs Erde ist weit. Wahrlich, den Geduldigen wird ihr Lohn (von Allah) ohne zu rechnen gewährt werden."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmlxix{Sprich: ``Mir wurde befohlen, Allah zu dienen, in lauterem Glauben Ihm gegenüber.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmlxx{Und mir wurde befohlen, der erste der Gottergebenen zu sein."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmlxxi{Sprich: ``Wahrlich, ich fürchte die Strafe eines gewaltigen Tages, wenn ich meinem Herrn ungehorsam wäre."\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmlxxii{Sprich: ``Allah ist es, Dem ich in meinem lauteren Glauben Ihm gegenüber diene.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmlxxiii{Verehrt statt Ihm nur, was ihr wollt." Sprich: ``Wahrlich, die Verlierenden werden jene sein, die sich selbst und die Ihren am Tage der Auferstehung verlieren." Wahrlich, das ist ein offenkundiger Verlust.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmlxxiv{Sie werden über sich Schichten von dem Feuer haben und unter sich (eben solche) Schichten. Das ist es, wovor Allah Seine Diener warnt: ``O Meine Diener, darum fürchtet Mich."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmlxxv{Und diejenigen, die falsche Götter anzubeten scheuen und sich zu Allah wenden - für sie ist die frohe Botschaft (bestimmt) Gib denn die frohe Botschaft Meinen Dienern\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmlxxvi{es sind jene, die auf das Wort hören und dem besten von ihm folgen. Sie sind es, denen Allah den Weg gewiesen hat, und sie sind es, die Verstand besitzen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmlxxvii{Ist denn der, gegen den das Strafurteil fällig geworden ist (in der Lage, gerettet zu werden)? Kannst du etwa den retten, der im Feuer ist?\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmlxxviii{Für die jedoch, die ihren Herrn fürchten, sind Hochgemächer über Hochgemächer erbaut, unter denen Bäche fließen. (Dies ist) eine Verheißung Allahs - Allah bricht Sein Versprechen nicht.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmlxxix{Hast Du nicht gesehen, daß Allah Wasser vom Himmel niedersendet und es als Quellen in die Erde dringen läßt und dadurch Gewächs hervorbringt, das mannigfaltig an Farben ist? Dann wird es reif, und du siehst es gelb werden; dann läßt Er es in Stücke zerbrechen. Hierin liegt wahrlich eine Mahnung für Leute von Verstand.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmlxxx{Ist denn der, dem Allah die Brust für den Islam geweitet hat, so daß er ein Licht von seinem Herrn empfängt (einem Ungläubigen gleich)? Wehe darum denen, deren Herzen vor dem Gedanken an Allah verhärtet sind! Sie sind es, die sich in einem offenkundigen Irrtum befinden.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmlxxxi{Allah hat die schönste Botschaft, ein Buch, hinabgesandt, eine sich gleichartig wiederholende Schrift; vor der denen, die ihren Herrn fürchten, die Haut erschauert; dann erweicht sich ihre Haut und ihr Herz zum Gedenken Allahs. Das ist die Führung Allahs; Er leitet damit recht, wen Er will. Und der, den Allah zum Irrenden erklärt, wird keinen Führer ha ben.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmlxxxii{Ist denn der, der mit seinem Angesicht vor der schrecklichen Strafe am Tage der Auferstehung Schutz sucht (, dem gleich, der gedankenlos ist)? Und zu den Ungerechten wird gesprochen werden: ``Kostet nun, was ihr verdientet."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmlxxxiii{Es leugneten jene, die vor ihnen waren; da kam die Strafe über sie, als sie es nicht ahnten.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmlxxxiv{Und Allah ließ sie im irdischen Leben Schande kosten; doch die Strafe im Jenseits wird gewiß größer sein, wenn sie es nur wüßten!\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmlxxxv{Und wahrlich Wir haben den Menschen in diesem Quran allerlei Gleichnisse geprägt, auf daß sie ermahnt werden.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmlxxxvi{(Wir haben ihn) als einen arabischen Quran (hinabgesandt), an dem nichts ist, was (vom geraden Weg) abweichen würde, auf daß sie gottesfürchtig sein mögen.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmlxxxvii{Allah prägt ein Gleichnis von einem Mann, der mehreren Herren gehört, die unter sich im Zwiespalt sind, und (von) einem Mann, der einem einzigen Herrn gehört. Sind sie beide einander gleich? Alles Lob gebührt Allah. Jedoch die meisten von ihnen wissen es nicht.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmlxxxviii{Wahrlich, du wirst sterben und auch sie werden sterben\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmlxxxix{dann, am Tage der Auferstehung, werdet ihr wahrlich vor eurem Herrn miteinander streiten.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmxc{Wer begeht also ein größeres Unrecht als einer, der Lügen gegen Allah vorbringt, oder einer, der die Wahrheit verwirft, wenn sie zu ihm kommt? Ist nicht in Gahannam eine Herberge für die Ungläubigen?\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmxci{Und der, der die Wahrheit bringt, und (der, der) sie annimmt - das sind die Gottesfürchtigen.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmxcii{Sie werden alles, was sie wünschen, bei ihrem Herrn haben. Das ist der Lohn derer, die Gutes tun\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmxciii{auf daß Allah von ihnen das Schlimmste hinwegnehmen werde von dem, was sie getan haben, und ihnen ihren Lohn geben werde gemäß dem Besten, das sie zu tun pflegten.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmxciv{Genügt Allah Seinem Diener nicht? Und doch möchten sie dich mit jenen außer Ihm in Furcht versetzen. Und für einen, den Allah zum Irrenden erklärt, gibt es keinen Führer.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmxcv{Und für einen, den Allah rechtleitet, gibt es keinen, der ihn irreführen könnte. Ist Allah nicht Erhaben und Mächtig, um Vergeltung zu nehmen?\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmxcvi{Und wenn du sie fragst: ``Wer schuf die Himmel und die Erde?" so werden sie sicher sagen: ``Allah." Sprich: ``Seht ihr denn, was ihr außer Allah anruft? Wenn Allah mir Schaden zufügen will, können sie (dann) den Schaden entfernen? Oder wenn Er mir Barmherzigkeit erweisen will, können sie (dann) Seine Barmherzigkeit verhindern?" Sprich: `` Allah genügt mir. Auf Ihn vertrauen die Vertrauenden."\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmxcvii{Sprich: ``O mein Volk, handelt eurem Standpunkt gemäß; (auch) ich handle (so); (bald aber) werdet ihr erfahren\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmxcviii{über wen eine Strafe kommt, die ihn schänden wird, und auf wen eine ewige Strafe niederfährt."\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmxcix{Wahrlich, Wir haben dir das Buch mit der Wahrheit für die Menschen hinabgesandt. Wer dann rechtgeleitet ist, der ist es zu seinem eigenen Besten; und wer irregeht, der geht dann irre zu seinem (eigenen) Schaden. Und du bist nicht ihr Sachwalter.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmc{Allah nimmt die Seelen (der Menschen) zur Zeit ihres Sterbens (zu Sich) und (auch die Seelen) derer, die nicht gestorben sind, wenn sie schlafen. Dann hält Er die zurück, über die Er den Tod verhängt hat, und schickt die anderen (wieder) bis zu einer bestimmten Frist (ins Leben zurück) Hierin sind sicher Zeichen für Leute, die nachdenken.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmci{Oder haben sie etwa statt Allah Fürsprecher genommen? Sprich: ``Selbst wenn sie keine Macht über irgend etwas besitzen und keinen Verstand?"\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmcii{Sprich: ``Alle Fürsprache gehört Allah. Sein ist das Königreich der Himmel und der Erde. Und zu Ihm werdet ihr zurückgebracht."\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmciii{Und wenn Allah als Einziger genannt wird, dann krampfen sich die Herzen derer, die nicht ans Jenseits glauben, in Widerwillen zusammen; werden aber die genannt, die statt Ihm (verehrt werden), siehe, dann beginnen sie zu frohlocken.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmciv{Sprich: ``O Allah! Schöpfer der Himmel und der Erde! Kenner des Verborgenen und des Offenbaren! Du allein wirst zwischen Deinen Dienern richten über das, worüber sie uneins waren."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmcv{Besäßen diejenigen, die gefrevelt haben, auch alles, was auf Erden ist, und noch einmal soviel dazu, würden sie sich gewiß damit von der schlimmen Strafe am Tage der Auferstehung loskaufen wollen; aber es wird ihnen von Allah das erscheinen, mit dem sie nimmermehr gerechnet haben.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmcvi{Und das Böse dessen, was sie gewirkt haben, wird ihnen deutlich werden, und es wird sie das umschließen, worüber sie zu spotten pflegten.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmcvii{Wenn nun den Menschen ein Schaden trifft, so ruft er Uns an. Dann aber, wenn Wir ihm Unsere Gnade zuteil werden lassen, sagt er: ``Dies wurde mir nur auf Grund (meines) Wissens gegeben." Nein, es ist bloß eine Prüfung; jedoch die meisten von ihnen wissen es nicht.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmcviii{Die vor ihnen waren, sagten auch schon so, doch all das, was sie erworben hatten, nutzte ihnen nichts.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmcix{Und das Böse dessen, was sie gewirkt hatten, erfaßte sie; und diejenigen von diesen, die Unrecht tun, wird (auch) das Böse dessen, was sie gewirkt haben, erfassen; und sie können sich dem nicht entziehen.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmcx{Wissen sie nicht, daß Allah dem die Mittel zum Unterhalt erweitert und beschränkt, dem Er will? Wahrlich, hierin liegen Zeichen für Leute, die glauben.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmcxi{Sprich: ``O meine Diener, die ihr euch gegen eure eigenen Seelen vergangen habt, verzweifelt nicht an Allahs Barmherzigkeit; denn Allah vergibt alle Sünden; Er ist der Allverzeihende, der Barmherzige.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmcxii{Und kehrt euch zu eurem Herrn, und ergebt euch Ihm, bevor die Strafe über euch kommt; (denn) dann werdet ihr keine Hilfe finden.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmcxiii{Und folgt dem Besten, das zu euch von eurem Herrn herabgesandt wurde, bevor die Strafe unversehens über euch kommt, wahrend ihr es nicht merkt\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmcxiv{damit nicht etwa einer spreche: ``O wehe mir um dessentwillen, was ich gegenüber Allah versäumte! Denn wahrlich, ich gehörte zu den Spöttern"\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmcxv{oder damit nicht etwa einer spreche: ``Hätte mich Allah geleitet, so wäre auch ich unter den Gottesfürchtigen gewesen"\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmmcxvi{oder damit nicht einer spreche, wenn er die Strafe sieht: ``Gäbe es für mich doch eine Wiederkehr, dann wollte ich unter denen sein, die Gutes tun.""\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmmcxvii{``Nein; es kamen zu dir Meine Zeichen, aber du verwarfst sie, und du warst hochmütig und warst einer der Ungläubigen."\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmmcxviii{Und am Tage der Auferstehung wirst du diejenigen, die über Allah logen, mit geschwärzten Gesichtern sehen. Ist nicht in Gahannam ein Aufenthalt für die Hochmütigen?\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmmcxix{Und Allah wird diejenigen retten, die (ihn) fürchteten, und ihnen Erfolg (verleihen) Weder wird sie das Übel berühren, noch werden sie trauern.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmmcxx{Allah ist der Schöpfer aller Dinge, und Er ist der Erhalter aller Dinge.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmmcxxi{Sein sind die Schlüssel der Himmel und der Erde; und jene, die nicht an die Zeichen Allah s glauben, sind die Verlierenden.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmmcxxii{Sprich: ``Verlangt ihr von mir etwa, daß ich (etwas) anderes als Allah anbeten, ihr Toren?"\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmmcxxiii{(Dies,) wo es dir doch offenbart worden ist, wie schon denen vor dir: ``Wenn du (Allah) Nebengötter zur Seite stellst, so wird sich dein Werk sicher als eitel erweisen, und du wirst gewiß unter den Verlierenden sein."\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmmcxxiv{Nein, diene denn Allah und sei einer der Dankbaren.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmmcxxv{Und sie haben Allah nicht richtig nach Seinem Wert eingeschätzt. Und am Tage der Auferstehung wird die ganze Erde in Seinem Griff sein, und die Himmel werden in Seiner Rechten zusammengerollt sein. Preis (sei) Ihm! Hoch Erhaben ist Er über das, was sie anbeten.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmmcxxvi{Und in den Sur wird gestoßen, und alle, die in den Himmeln sind, und alle, die auf Erden sind, werden tot niederstürzen; mit Ausnahme derjenigen, die Allah (ausnehmen) will. Dann wird wiederum in den Sur gestoßen, und siehe, da stehen sie auf und schauen zu.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmmcxxvii{Und das (Versammlungs-) Gelände wird erstrahlen im Lichte seines Herrn, und das Buch wird vorgelegt, und die Propheten und die Zeugen werden herbeigebracht; und es wird zwischen ihnen in Gerechtigkeit gerichtet werden, und sie sollen kein Unrecht erleiden.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmmcxxviii{Und jedem von ihnen wird voll vergolten werden, was er getan hat; und Er weiß am besten, was sie tun.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmmcxxix{Und die Ungläubigen werden in Scharen zu Gahannam geführt werden, bis daß, wenn sie sie erreichen, sich ihre Pforten öffnen und ihre Wächter zu ihnen sprechen: ``Sind nicht Gesandte aus eurer Mitte zu euch gekommen, um euch die Verse eures Herrn zu verlesen und euch vor dem Eintreffen dieses euren Tages zu warnen?" Sie werden sagen: ``Ja!" Doch das Strafurteil ist in Gerechtigkeit gegen die Ungläubigen fällig geworden.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmmcxxx{Es wird gesprochen werden: ``Geht denn ein durch die Pforten der Gahannam und bleibt darin auf ewig! Und übel ist die Wohnstatt der Hochmütigen."\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmmcxxxi{Und jene, die ihren Herrn fürchteten, werden in Scharen in das Paradies geführt werden, bis daß, wenn sie es erreichen, seine Pforten sich Tffnen und seine Wächter zu ihnen sprechen: ``Friede sei auf euch! Seid glücklich und geht dort ein und weilt auf ewig darin."\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmmcxxxii{Sie werden sagen: ``Alles Lob gebührt Allah, Der Seine Verheißung an uns erfüllt hat und uns die (Paradies-) Landschaft zum Erbe gegeben hat, so daß wir im Paradies wohnen können, wo immer es uns gefällt." Wie schön ist also der Lohn derer, die (dafür) vorgesorgt haben.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmmcxxxiii{Und du wirst die Engel auf allen Seiten den Thron umgeben sehen, wo sie das Lob ihres Herrn preisen. Und es wird zwischen ihnen in Gerechtigkeit entschieden werden. Und es wird gesprochen werden: ``Alles Lob gebührt Allah, dem Herrn der Welten."\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmmcxxxiv{\basmalahde Ha Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmcxxxv{Die Offenbarung des Buches stammt von Allah, dem Erhabenen, dem Allwissenden\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmcxxxvi{dem die Sünde Vergebenden und die Reue Abnehmenden, dem Strengen in der Bestrafung, dem Besitzer der Gnadenfülle. Es ist kein Gott außer Ihm. Zu Ihm ist die Heimkehr.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmcxxxvii{Niemand streitet über die Zeichen Allahs, außer denen, die ungläubig sind. Laß dich darum von ihrem Hin- und Herziehen im Lande nicht täuschen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmcxxxviii{Vor ihnen leugneten das Volk Noahs und die Verbündeten nach ihnen. Und jedes Volk hat sich vorgenommen, seinen Gesandten zu ergreifen, und sie stritten mit Falschheit, um die Wahrheit damit zu widerlegen. Dann erfaßte Ich sie, und wie war Meine Strafe!\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmcxxxix{Und somit wurde das Wort deines Herrn gegen die Ungläubigen fällig, daß sie die Bewohner des Feuers seien.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmcxl{Die, die den Thron tragen, und die, die ihn umringen, preisen das Lob ihres Herrn und glauben an Ihn und erbitten Vergebung für jene, die gläubig sind: ``Unser Herr, Du umfaßt alle Dinge mit Barmherzigkeit und Wissen. Vergib darum denen, die bereuen und Deinem Weg folgen; und bewahre sie vor der Strafe der Gahim.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmcxli{Unser Herr, und laß sie eintreten in das Paradies von Eden, das Du ihnen verheißen hast, wie auch jenen ihrer Väter und ihrer Frauen und ihrer Kinder, die rechtschaffen sind. Gewiß, Du bist der Erhabene, der Allweise.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmcxlii{Und bewahre sie vor dem Übel; denn wen Du an jenem Tage vor Übel bewahrst ihm hast Du wahrlich Barmherzigkeit erwiesen. Und das ist der gewaltige Gewinn."\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmcxliii{Wahrlich, den Ungläubigen wird zugerufen: ``Allahs Widerwille (gegen euch) ist größer als euer eigener Widerwille gegen euch selbst, als ihr zum Glauben aufgerufen wurdet und im Unglauben verharrtet."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmcxliv{Sie werden sagen: ``Unser Herr Du hast uns zweimal sterben lassen und uns zweimal lebendig gemacht, und wir bekennen unsere Sünden. Ist da nun ein Weg, um zu entkommen?"\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmcxlv{``Dies ist so, weil ihr ungläubig bliebt, als Allah allein angerufen wurde; doch als Ihm Götter zur Seite gesetzt wurden, da glaubtet ihr. Die Entscheidung liegt allein bei Allah, dem Hohen, dem Großen."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmcxlvi{Er ist es, Der euch Seine Zeichen zeigt und euch die Mittel zum Unterhalt vom Himmel hinabsendet; doch keiner außer dem läßt sich ermahnen, der sich bekehrt.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmcxlvii{Ruft denn Allah in lauterem Gehorsam Ihm gegenüber an, und sollte es auch den Ungläubigen zuwider sein.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmcxlviii{(Er ist) der Erhabene über alle Rangstufen, der Herr des Thrones! Nach Seinem Geheiß sendet Er das offenbarte Wort demjenigen Seiner Diener, dem Er will, auf daß er vor dem Tag der Begegnung warne\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmcxlix{dem Tage, an dem sie ohne Versteck zu sehen sind und nichts von ihnen vor Allah verborgen bleibt. Wessen ist das Königreich an diesem Tage? (Es ist) Allahs, des Einzigen, des Allbezwingenden.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmcl{Heute wird jedem vergolten werden, was er verdient hat. Heute gibt es keine Ungerechtigkeit! Wahrlich, Allah ist schnell im Abrechnen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmcli{Und warne sie vor dem immer näher kommenden Tag, da die Herzen voll innerer Trauer zur Kehle emporsteigen werden. Die Ungerechten werden weder einen vertrauten Freund noch einen Fürsprecher haben, auf den gehört werden könnte.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmclii{Er kennt die Verräterei der Blicke und alles, was die Herzen verbergen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmcliii{Und Allah richtet in Gerechtigkeit; die aber, die sie an Seiner Statt anrufen, können nicht richten. Wahrlich, Allah ist der Allhörende, der Allsehende.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmcliv{Sind sie denn nicht im Lande umhergezogen, so daß sie schauen konnten, wie das Ende derer war, die vor ihnen lebten? Diese waren viel mächtiger als sie und hinterließen mehr Spuren im Land. Und doch erfaßte sie Allah um ihrer Sünden willen, und sie hatten keinen, der sie vor Allah hätte schützen können.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmclv{Das geschah, weil ihre Gesandten zu ihnen mit deutlichen Zeichen kamen, sie aber nicht glaubten; darum erfaßte sie Allah. Wahrlich, Er ist Stark und streng im Strafen.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmclvi{Und wahrlich, Wir entsandten Moses mit Unseren Zeichen und mit einer klaren Machtbefugnis\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmclvii{zu Pharao und Haman und Korah; jedoch sie sagten: ``(Er ist nichts anderes als) ein Zauberer, ein Betrüger."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmclviii{Und als er zu ihnen mit der Wahrheit von Uns kam, da sagten sie: ``Tötet die Söhne derer, die mit ihm glauben, und laßet ihre Frauen am Leben." Doch der Anschlag der Ungläubigen ist völlig verfehlt.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmclix{Und Pharao sagte: ``Laßet mich, ich will Moses töten; und laßet ihn seinen Herrn anrufen. Ich fürchte, er könnte sonst euren Glauben ändern oder Unheil im Land stiften."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmclx{Und Moses sagte: ``lch nehme meine Zuflucht zu meinem Herrn und eurem Herrn vor jedem Überheblichen, der nicht an den Tag der Abrechnung glaubt."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmclxi{Und es sagte ein gläubiger Mann von den Leuten Pharaos, der seinen Glauben geheimhielt: ``Wollt ihr einen Mann töten, weil er sagt: ``Mein Herr ist Allah", obwohl er mit klaren Beweisen von eurem Herrn zu euch gekommen ist? Wenn er ein Lügner ist, so lastet seine Lüge auf ihm; ist er aber wahrhaftig, dann wird euch ein Teil von dem treffen, was er euch androht. Wahrlich, Allah weist nicht dem den Weg, der maßlos (und) ein Lügner ist.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmclxii{O meine Leute, euch gehört heute die Herrschaft; denn ihr habt die Oberhand im Land. Wer aber wird uns vor der Strafe Allahs schützen, wenn sie über uns kommt?" Pharao sagte: ``lch weise euch nur auf das hin, was ich selbst sehe, und ich leite euch nur auf den Weg der Rechtschaffenheit."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmclxiii{Da sagte jener, der gläubig war: ``O mein Volk, ich fürchte für euch das gleiche, was den Verbündeten (widerfuhr)\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmclxiv{das gleiche, was dem Volke Noahs und den `Ad und den Tamud und denen nach ihnen widerfuhr. Und Allah will keine Ungerechtigkeit gegen die Menschen.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmclxv{O mein Volk, ich fürchte für euch den Tag der gegenseitigen Hilferufe\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmclxvi{den Tag, an dem ihr den Rücken zur Flucht wenden werdet. Keinen Beschirmer werdet ihr wider Allah haben. Und der, den Allah zum Irrenden erklärt, wird keinen Führer finden."\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmclxvii{Und Yusuf kam ja vordem mit deutlichen Beweisen zu euch, jedoch ihr hörtet nicht auf, das zu bezweifeln, womit er zu euch kam, bis ihr dann, als er starb, sagtet: Allah wird nimmermehr einen Gesandten nach ihm erstehen lassen." Also erklärt Allah jene zu Irrenden, die maßlos (und) Zweifler sind\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmclxviii{solche, die über die Zeichen Allahs streiten, ohne daß irgendeine Ermächtigung (dazu) zu ihnen gekommen wäre. Äußerst hassenswert ist das für Allah und für jene, die gläubig sind. Also versiegelt Allah das Herz eines jeden Überheblichen, Gewalttätigen.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmclxix{Und Pharao sagte: ``O Haman, baue mir einen Turm, so daß ich die Zugänge erreiche\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmclxx{die Zugänge zu den Himmeln, damit ich ihn sehen kann, den Gott Moses', und ich halte ihn wahrlich für einen Lügner." Also erschien Pharao das Böse seines Tuns im schönsten Licht, und er wurde von dem Weg abgewendet; und der Plan Pharaos schlug fehl.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmclxxi{Und jener, der gläubig war, sagte: ``O mein Volk, folgt mir. Ich will euch zu dem Weg der Rechtschaffenheit leiten.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmclxxii{O mein Volk, das Leben auf dieser Erde ist wahrlich nur ein vergänglicher Genuß; und das Jenseits allein ist wahrlich die dauernde Heimstatt.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmclxxiii{Wer Böses tut, dem soll nur mit Gleichem vergolten werden; wer aber Gutes tut - sei es Mann oder Frau und dabei gläubig ist -, diese werden ins Paradies eintreten; darin werden sie mit Unterhalt versorgt werden, ohne daß darüber Rechnung geführt wird.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmclxxiv{O mein Volk, wie kommt es mir zu, daß ich euch zum Heil aufrufe, während ihr mich zum Feuer ruft?\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmclxxv{Ihr ruft mich auf, Allah zu verleugnen und Ihm Götter zur Seite zu stellen, von denen ich keine Kenntnis habe. Ich aber rufe euch zu dem Erhabenen, dem Vergebungsreichen.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmclxxvi{(Es besteht) kein Zweifel, daß das, wozu ihr mich ruft, keinen Anspruch in dieser Welt oder im Jenseits besitzt; und wir werden zu Allah heimkehren, und die Übertreter werden Bewohner des Feuers sein.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmclxxvii{Bald werdet ihr an das denken, was ich zu euch sage Und ich lege meine Sache Allah zur Entscheidung vor; denn Allah durchschaut die Menschen."\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmclxxviii{So schützte ihn Allah vor den Übeln dessen, was sie planten; und eine schlimme Strafe ereilte die Leute Pharaos\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmclxxix{(das) Feuer - sie sind ihm morgens und abends ausgesetzt. Und am Tage, wenn die Stunde kommen wird(, da wird gesprochen werden): ``Laßt Pharaos Leute die strengste Strafe antreten."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmclxxx{Wenn sie miteinander im Feuer streiten, werden die Schwachen zu den Hochmütigen sagen: ``Wir waren ja eure Anhänger; werdet ihr uns deshalb nicht einen Teil des Feuers abnehmen?"\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmclxxxi{Jene, die hochmütig waren, werden sagen: ``Wir sind alle darin. Allah hat nun zwischen den Menschen gerichtet."\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmclxxxii{Und die im Feuer werden zu den Wächtern der Gahannam sagen: ``Bittet euren Herrn, daß Er uns einen Tag von der Strafe erlasse."\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmclxxxiii{Sie werden sprechen: ``Kamen nicht eure Gesandten mit klaren Beweisen zu euch?" Jene werden sagen: ``Doch." (Die Wächter) werden sprechen: ``So fahret fort zu bitten." Doch die Bitte der Ungläubigen ist völlig verfehlt.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmclxxxiv{Wahrlich, helfen werden Wir Unseren Gesandten und denen, die gläubig sind, im diesseitigen Leben und an dem Tage, wo die Zeugen vortreten werden\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmclxxxv{am Tage, an dem den Frevlern ihre Ausrede nichts nützen wird; und sie werden zu Fluch und schlimmem Aufenthalt (verdammt) sein.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmclxxxvi{Und Wir gaben wahrlich Moses die Führung und machten die Kinder Israels zu Erben der Schrift\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmclxxxvii{einer Führung und Ermahnung für die Verständigen.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmclxxxviii{So sei denn geduldig. Wahrlich, die Verheißung Allahs ist wahr. Und suche Vergebung für deine Missetaten und lobpreise deinen Herrn am Abend und am Morgen.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmclxxxix{Wahrlich, diejenigen, die über die Zeichen Allahs streiten, ohne daß irgendeine Ermächtigung (dazu) zu ihnen (gekommen wäre) nichts ist in ihren Herzen als Großmannssucht -, sie werden es nicht erreichen. So nimm Zuflucht bei Allah. Wahrlich, Er ist der Allhörende, der Allsehende.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmcxc{Wahrlich, die Schöpfung der Himmel und der Erde ist größer als die Schöpfung der Menschen; allein die meisten Menschen wissen es nicht.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmmcxci{Doch der Blinde und der Sehende sind nicht gleich; noch sind jene, die glauben und gute Werke tun, denen (gleich), die Böses tun. Wenig ist es, was ihr zu bedenken pflegt!\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmmcxcii{Die Stunde kommt gewiß, darüber herrscht kein Zweifel; doch die meisten Menschen glauben es nicht.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmmcxciii{Und euer Herr sprach: ``Bittet Mich; Ich will eure Bitte erhören. Die aber, die zu Aberheblich sind, um Mir zu dienen, werden unterwürfig in Gahannam eintreten."\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmmcxciv{Allah ist es, Der für euch die Nacht gemacht hat, auf daß ihr darin ruht, und den hellichten Tag. Wahrlich, Allah ist der Herr der Gnadenfülle gegenüber der Menschheit, jedoch die meisten Menschen danken (ihm dafür) nicht.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmmcxcv{Das ist Allah, euer Herr, der Schöpfer aller Dinge. Es ist kein Gott außer Ihm. Wie lasset ihr euch (von Ihm) abwenden?\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmmcxcvi{So lassen sich nur die abwenden, die Allahs Zeichen leugnen.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmmcxcvii{Allah ist es, Der die Erde für euch als festen Grund und den Himmel als Bau geschaffen hat und Der euch Gestalt gegeben und eure Gestalten schön gemacht hat und euch mit guten Dingen versorgt hat. Das ist Allah, euer Herr. Segensreich ist darum Allah, der Herr der Welten.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmmcxcviii{Er ist der Ewiglebendige. Es ist kein Gott außer Ihm. So ruft Ihn an, in lauterem Gehorsam Ihm gegenüber. Alles Lob gebührt Allah, dem Herrn der Welten.\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmmcxcix{Sprich: ``Mir wurde verboten, denen zu dienen, die ihr statt Allah anruft, nachdem zu mir deutliche Beweise von meinem Herrn gekommen sind; und mir wurde befohlen, mich dem Herrn der Welten zu ergeben."\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmmcc{Er ist es, Der euch aus Erde erschuf, dann aus einem Samentropfen, dann aus einem Blutklumpen, dann läßt Er euch als Kind (daraus) hervorgehen, dann (läßt Er euch wachsen,) auf daß ihr eure Vollkraft erreichen möget, dann (läßt Er) euch alt werden wenngleich einige von euch vorher zum Sterben abberufen werden und (Er läßt euch leben,) damit ihr eine bestimmte Frist erreichet und damit ihr begreifen lernet.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmmcci{Er ist es, Der ins Leben ruft und sterben läßt. Und wenn Er etwas bestimmt hat, so spricht Er zu ihm nur: ``Sei!" und es ist.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmmccii{Hast du nicht die gesehen, die über Allahs Zeichen streiten? Wie lassen sie sich abwenden?\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmmcciii{(Es sind) jene, die weder an das Buch noch an das glauben, womit Wir Unsere Gesandten geschickt haben. Bald aber werden sie es wissen.\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmmcciv{wenn die Eisenfesseln und Ketten um ihren Nacken (gelegt) sein werden. Sie werden gezerrt werden\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmmccv{in siedendes Wasser; dann werden sie ins Feuer gezogen werden.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmmccvi{Dann wird zu ihnen gesprochen: ``Wo sind nun jene, die ihr anzubeten pflegtet\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmmccvii{statt Allah?" Sie werden sagen: ``Sie sind von uns gewichen. Nein, wir riefen zuvor nichts an." So führt Allah die Ungläubigen irre\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmmccviii{``Dies (geschieht), weil ihr auf Erden ohne Recht frohlocktet, und weil ihr ausgelassen waret.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmmccix{Geht nun ein durch die Tore der Gahannam, um auf ewig darin zu bleiben. Übel ist nun die Wohnstatt der Überheblichen."\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmmccx{So sei denn standhaft. Wahrlich, die Verheißung Allahs ist wahr. Und ob Wir dir (die Erfüllung) von einigen der Dinge zeigen, die Wir ihnen angedroht haben, oder (ob) Wir dich (vorher) sterben lassen; zu Uns werden sie (jedenfalls) zurückgebracht.\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmmccxi{Und sicher entsandten Wir schon Gesandte vor dir; darunter sind manche, von denen Wir dir bereits berichtet haben, und es sind darunter manche, von denen Wir dir nicht berichtet haben; und kein Gesandter hätte ohne Allahs Erlaubnis ein Zeichen bringen können. Doch wenn Allahs Befehl ergeht, dann wird die Sache zu Recht entschieden, und dann fallen diejenigen dem Verlust anheim, die versucht haben, (Allahs Befehl) außer Kraft zu setzen.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmmccxii{Allah ist es, Der für euch die Tiere gemacht hat, damit ihr auf den einen reiten und von den anderen essen könnt.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmmmccxiii{Und ihr habt noch (anderen) Nutzen an ihnen - damit ihr durch sie jegliches Bedürfnis befriedigen könnt, das in euren Herzen sein mag. Und auf ihnen und auf Schiffen werdet ihr getragen.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmmmccxiv{Und Er zeigt euch Seine Zeichen; welches der Zeichen Allahs wollt ihr denn verleugnen?\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmmmccxv{Sind sie denn nicht im Lande umhergezogen, so daß sie schauen konnten, wie das Ende derer war, die vor ihnen lebten? Sie waren zahlreicher als diese und viel mächtiger und hinterließen mehr Spuren auf Erden. Doch alles, was sie erwarben, nützte ihnen nichts.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmmmccxvi{Und als ihre Gesandten mit deutlichen Beweisen zu ihnen kamen, da frohlockten sie über das Wissen, das sie (selbst) besaßen. Und das, worüber sie zu spotten pflegten, umfing sie.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmmmccxvii{Und als sie Unsere Strafe sahen, sagten sie: ``Wir glauben an Allah als den Einigen, und wir verwerfen all das, was wir Ihm zur Seite zu stellen pflegten."\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmmmccxviii{Aber ihr Glaube - als sie Unsere Strafe sahen - konnte ihnen nichts mehr nützen. Dies ist Allahs Gebot, das stets gegenüber Seinen Dienern befolgt worden ist. Und so gingen die Ungläubigen zugrunde.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmmmccxix{\basmalahde Ha Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmccxx{(Dies ist) eine Offenbarung von dem Allerbarmer, dem Barmherzigen\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmccxxi{ein Buch, dessen Verse als Quran in arabischer Sprache klar gemacht worden sind für Leute, die Wissen besitzen\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmccxxii{als Bringer froher Botschaft und Warner. Doch die meisten von ihnen kehren sich (von ihm) ab, so daß sie (ihn) nicht hören.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmccxxiii{Und sie sagen: ``Unsere Herzen sind vor dem verhüllt, wozu du uns berufst, und unsere Ohren sind taub, und zwischen uns und dir ist eine Scheidewand. So handle, auch wir handeln."\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmccxxiv{Sprich: ``lch bin nur ein Mensch wie ihr. Mir wird offenbart, daß euer Gott ein Einziger Gott ist; so seid aufrichtig gegen Ihn und bittet Ihn um Vergebung." Und wehe den Götzendienern\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmccxxv{die nicht die Zakah entrichten und die das Jenseits leugnen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmccxxvi{Diejenigen, die aber glauben und gute Werke tun, werden einen nimmer endenden Lohn erhalten.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmccxxvii{Sprich: ``Leugnet ihr Den wirklich, Der die Erde in zwei Tagen schuf? Und dichtet ihr Ihm Nebenbuhler an?" Er nur ist der Herr der Welten.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmccxxviii{Und Er gründete in ihr feste Berge, die sie überragen, und segnete sie und ordnete auf ihr ihre Nahrung in richtigem Verhältnis in vier Tagen - gleichmäßig für die Suchenden.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmccxxix{Dann wandte Er Sich zum Himmel, welcher noch Nebel war, und sprach zu ihm und zu der Erde: ``Kommt ihr beide, willig oder widerwillig." Sie sprachen: ``Wir kommen willig."\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmccxxx{So vollendete Er sie als sieben Himmel in zwei Tagen, und jedem Himmel wies Er seine Aufgabe zu. Und Wir schmückten den untersten Himmel mit Leuchten (, welche auch) zum Schutz (dienen) Das ist die Schöpfung des Erhabenen, des Allwissenden.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmccxxxi{Doch wenn sie sich abkehren, so sprich: ``lch habe euch vor einem Blitzschlag wie dem Blitzschlag von `Ad und Tamud gewarnt."\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmccxxxii{Da kamen ihre Gesandten zu ihnen von vorn und hinten (und sagten): ``Dient keinem außer Allah." Da sagten Sie: ``Hätte unser Herr es gewollt, hätte Er zweifellos Engel herabgesandt. So lehnen wir das ab, womit ihr gesandt worden seid."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmccxxxiii{Was nun die `Ad anbelangt, so betrugen sie sich ohne Recht hochmütig auf Erden und sagten: ``Wer hat mehr Macht als wir?" Konnten sie denn nicht sehen, daß Allah, Der sie erschuf, mächtiger ist als sie? Jedoch sie fuhren fort, Unsere Zeichen zu leugnen.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmccxxxiv{Darum sandten Wir gegen sie einen eiskalten Wind mehrere unheilvolle Tage hindurch, auf daß Wir sie die Strafe der Schmach in diesem Leben kosten ließen. Und die Strafe des Jenseits wird gewiß noch schmählicher sein, und es wird ihnen nicht geholfen werden.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmccxxxv{Und was die Tamud anbelangt, so wiesen Wir ihnen den Weg, sie aber zogen die Blindheit dem rechten Weg vor; darum erfaßte sie die blitzschlagartige Strafe der Erniedrigung um dessentwillen, was sie begangen hatten.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmccxxxvi{Und Wir erretteten jene, die glaubten und gottesfürchtig waren.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmccxxxvii{Und an dem Tage, wo die Feinde Allahs allesamt vor dem Feuer versammelt werden, da werden sie in Gruppen geteilt\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmccxxxviii{bis daß, wenn sie es erreichen, ihre Ohren und ihre Augen und ihre Haut Zeugnis gegen sie von dem ablegen, was sie zu tun pflegten.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmccxxxix{Und sie werden zu ihren Häuten sagen: `` Warum zeugt ihr gegen uns?" Sie werden sprechen: ``Allah hat uns das Reden verliehen - Er, Der einem jeden Ding das Reden verliehen hat. Und Er ist es, Der euch erstmals erschuf, und zu Ihm seid ihr zurückgebracht worden.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmccxl{Und ihr pflegtet (eure Sünden) nicht so zu verbergen, daß eure Ohren und eure Augen und eure Haut nicht Zeugnis gegen euch ablegen könnten; vielmehr meintet ihr, Allah wüßte nicht viel von dem, was ihr zu tun pflegtet.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmccxli{Und das, was ihr von eurem Herrn meintet, hat euch ins Verderben geführt; so wurdet ihr die Verlierenden."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmccxlii{Selbst wenn sie es nun aushalten, so ist doch das Feuer ihre Wohnstatt; und wenn sie um Gnade bitten, so wird ihnen keine Gnade erwiesen.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmccxliii{Und Wir hatten Gefährten für sie bestimmt, die ihnen das als wohlgefällig erscheinen ließen, was vor ihnen war und was hinter ihnen war; und (so) wurde der Spruch fällig gegen sie, zusammen mit den Scharen der Ginn und der Menschen, die vor ihnen hingegangen waren. Gewiß, sie waren die Verlierer.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmccxliv{Und die Ungläubigen sagten: ``Hört nicht auf diesen Quran, sondern fügt von euren Worten (etwas hinzu), damit ihr die Oberhand behaltet."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmccxlv{Aber gewiß werden Wir den Ungläubigen eine strenge Strafe zu kosten geben, und gewiß werden Wir ihnen ihre schlimmsten Taten vergelten.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmccxlvi{Das ist der Lohn der Feinde Allahs: das Feuer. Darin wird ihnen die Wohnstatt der Ewigkeit zuteil sein - als Vergeltung dafür, daß sie Unseren Zeichen gegenüber undankbar waren.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmccxlvii{Und die Ungläubigen werden sagen: ``Unser Herr, zeige uns jene der Ginn und der Menschen, die uns irreführten, damit wir sie mit unseren Füßen treten, so daß sie zu den Niedrigsten gehören."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmccxlviii{Wahrlich diejenigen, die sagen: ``Unser Herr ist Allah", und die sich dann aufrichtig verhalten - zu ihnen steigen die Engel nieder (und sprechen): ``Fürchtet euch nicht und seid nicht traurig, und erfreut euch des Paradieses, das euch verheißen wurde.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmccxlix{Wir sind eure Beschützer im irdischen Leben und im Jenseits. In ihm werdet ihr alles haben, was ihr euch wünscht, und in ihm werdet ihr alles haben, wonach ihr verlangt\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmccl{(dies ist) eine Bewirtung von einem Vergebenden, Barmherzigen."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmccli{Und wer ist besser in der Rede als einer, der zu Allah ruft und Gutes tut und sagt: ``lch bin einer der Gottergebenen?"\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmcclii{Und nimmer sind das Gute und das Böse gleich. Wehre (das Böse) in bester Art ab, und siehe da, der, zwischen dem und dir Feindschaft herrschte, wird wie ein treuer Freund sein.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmccliii{Aber dies wird nur denen gewährt, die geduldig sind; und dies wird nur denen gewährt, die ein großes Glück haben.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmccliv{Und wenn du von Seiten des Satans zu einer Untat aufgestachelt wirst, dann nimm deine Zuflucht bei Allah. Wahrlich, Er ist der Allhörende, der Allwissende.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmcclv{Und zu Seinen Zeichen gehören die Nacht und der Tag und die Sonne und der Mond. Werft euch nicht vor der Sonne anbetend nieder, und auch nicht vor dem Mond, sondern werft euch anbetend vor Allah nieder, Der sie erschuf, wenn Er es ist, Den ihr verehrt.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmcclvi{Wenn sie sich aber in Hochmut (von Ihm) abwenden, so preisen Ihn bei Nacht und Tag diejenigen, die bei deinem Herrn sind, und sie sind darin unermüdlich.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmcclvii{Und unter Seinen Zeichen ist, daß du die Erde leblos siehst, doch wenn Wir Wasser auf sie niedersenden, dann regt sie sich und schwillt. Er, Der sie belebte, wird sicher auch die Toten lebendig machen; denn Er hat Macht über alle Dinge.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmcclviii{Wahrlich, diejenigen, die Unsere Zeichen entstellen, sind Uns nicht verborgen. Ist etwa der, der ins Feuer geworfen wird, besser als jener, der am Tage der Auferstehung sicher hervorgeht? Tut, was ihr wollt; denn Er sieht alles, was ihr tut.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmcclix{Wahrlich, diejenigen, die nicht an die Ermahnung glaubten, als sie zu ihnen kam (, werden bestraft) Und wahrlich, es ist ein ehrwürdiges Buch.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmcclx{Falschheit kann nicht an es herankommen, weder von vorn noch von hinten. Es ist eine Offenbarung von einem Allweisen, des Lobes Würdigen.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmcclxi{Nichts anderes wird dir gesagt, als was schon den Gesandten vor dir gesagt wurde. Deinem Herrn eignet wahrlich die Vergebung, (ihm eignet) aber auch die schmerzliche Bestrafung.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmcclxii{Hätten Wir ihn als einen Quran in einer fremden Sprache abgefaßt, hätten sie gesagt: ``Warum sind seine Verse nicht in einer fremden und in einer arabischen (Sprache) klar gemacht worden?" Sprich: ``Er ist eine Führung und eine Heilung für die Gläubigen." Doch diejenigen, die nicht glauben - ihre Ohren sind taub, und er bleibt ihrem Blick entzogen; diese werden von einem weit entfernten Ort angerufen.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmcclxiii{Und wahrlich, Wir gaben Moses die Schrift, doch dann entstand Uneinigkeit über sie. Wäre nicht zuvor ein Wort von deinem Herrn ergangen, wäre gewiß zwischen ihnen entschieden worden; aber wahrhaftig, sie befinden sich in beunruhigendem Zweifel über ihn (den Quran)\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmcclxiv{Wenn jemand das Rechte tut, so tut er es für sich selbst; und wenn jemand Böses tut, so handelt er gegen sich selbst. Und dein Herr ist niemals ungerecht gegen die Menschen.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmcclxv{Auf Ihn allein ist das Wissen um die Stunde zurückzuführen. Keine Früchte kommen aus ihren Hüllen hervor, und kein weibliches Wesen empfängt oder gebärt, es sei denn mit Seinem Wissen. Und an dem Tage, wenn Er ihnen zurufen wird: ``Wo sind Meine Partner?" da werden sie sagen: ``Wir gestehen Dir, keiner von uns ist (ihr) Zeuge (gewesen)"\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmcclxvi{Und alles, was sie zuvor anzurufen pflegten, wird sie im Stich lassen, und sie werden einsehen, daß sie keine Zuflucht haben.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmcclxvii{Keine Müdigkeit trifft den Menschen, wenn er (etwas) Gutes erbitten will; doch wenn ihn ein Übel berührt, dann verzweifelt er (und) gibt alle Hoffnungen auf.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmcclxviii{Und wenn Wir ihn Unsere Barmherzigkeit kosten lassen, nachdem ihn ein Leid betroffen hat, so sagt er sicher: ``Das steht mir zu; und ich glaube nicht, daß die Stunde kommen wird. Doch wenn ich zu meinem Herrn zurückgebracht werden sollte, dann würde ich gewiß das Beste bei Ihm finden." Aber Wir werden den Ungläubigen wahrlich alles ankündigen, was sie getan haben, und Wir werden sie si cherlich von einer harten Strafe kosten lassen.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmcclxix{Und wenn Wir dem Menschen Gnade erweisen, dann kehrt er sich (von Uns) ab und geht seitwärts; doch wenn ihn ein Übel berührt, siehe, dann beginnt er, Bittgebete in großzügiger Weise zu sprechen.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmcclxx{Sprich: ``Besinnt euch: Wenn es von Allah ist und ihr nicht daran glaubt - wer ist irrender als einer, der mit seiner Zwietracht weit gegangen ist?"\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmcclxxi{Wir werden sie Unsere Zeichen überall auf Erden und an ihnen selbst sehen lassen, damit ihnen deutlich wird, daß es die Wahrheit ist. Genügt es denn nicht, daß dein Herr Zeuge aller Dinge ist?\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmcclxxii{Doch sie hegen Zweifel an der Begegnung mit ihrem Herrn. Wahrlich, Er umfaßt alle Dinge.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmcclxxiii{\basmalahde Ha Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmcclxxiv{`Ain Sin Qaf\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmcclxxv{So offenbart Allah, der Erhabene, der Allweise, dir und denen, die vor dir waren.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmcclxxvi{Sein ist, was in den Himmeln und was auf Erden ist, und Er ist der Hohe, der Große.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmcclxxvii{Fast neigen sich die Himmel, um von oben her zu brechen, (so) auch (wenn) die Engel ihren Herrn mit Seiner Lobpreisung verherrlichen und Vergebung für die auf Erden erflehen. Siehe, Allah ist wahrlich der Vergebende, der Barmherzige.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmcclxxviii{Und jene, die sich Beschützer außer Ihm nehmen - Allah gibt auf sie acht; und du bist nicht ihr Wächter.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmcclxxix{Und so haben Wir dir den Quran auf Arabisch offenbart, auf daß du die Mutter der Städte warnest und alle rings um sie, und (auf daß) du (sie) vor dem Tag der Versammlung warnest, über den kein Zweifel herrscht. Eine Gruppe wird im Paradies sein und eine Gruppe im flammenden Feuer.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmcclxxx{Hätte Allah gewollt, hätte Er sie zu einer einzigen Gemeinde gemacht; jedoch läßt Er in Seine Barmherzigkeit ein, wen Er will. Und die Ungerechten werden weder Beschützer noch Helfer haben.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmcclxxxi{Oder haben sie sich etwa Beschützer außer Ihm genommen? Doch Allah allein ist der Beschützer; und Er macht die Toten lebendig; und Er hat Macht über alle Dinge.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmcclxxxii{Und über was immer ihr uneins seid; die Entscheidung darüber ruht bei Allah. Das ist Allah, mein Herr; auf Ihn vertraue ich, und zu Ihm wende ich mich.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmcclxxxiii{Der Schöpfer der Himmel und der Erde - Er hat aus euch selbst Gattinnen für euch gemacht und Paare aus den Tieren. Dadurch vermehrt Er euch. Es gibt nichts Seinesgleichen; und Er ist der Allhörende, der Allsehende.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmcclxxxiv{Sein sind die Schlüssel der Himmel und der Erde. Er erweitert und beschränkt dem die Mittel zum Unterhalt, dem Er will. Wahrlich, Er ist der Allwissende aller Dinge.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmcclxxxv{Er verordnete für euch die Religion, die Er Noah anbefahl und die Wir dir offenbart haben und die Wir Abraham und Moses und Jesus anbefohlen haben. Nämlich (die), in der Einhaltung der Religion treu zu bleiben und euch deswegen nicht zu spalten. Hart ist für die Götzendiener das, wozu du sie aufrufst. Allah erwählt dazu, wen Er will, und leitet dazu den, der sich bekehrt.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmcclxxxvi{Und sie zerfielen erst dann in Spaltung, nachdem das Wissen zu ihnen gekommen war; denn unter ihnen (entstand) selbstsüchtiger Neid. Und wäre nicht bereits ein Wort von deinem Herrn über eine bestimmte Frist ergangen wäre gewiß zwischen ihnen entschieden worden. Wahrlich, jene, denen nach ihnen das Buch zum Erbe gegeben wurde, befinden sich in bedenklichem Zweifel darüber.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmcclxxxvii{Zu diesem (Glauben) also rufe (sie) auf. Und bleibe aufrichtig, wie dir befohlen wurde, und folge ihren persönlichen Neigungen nicht, sondern sprich: ``lch glaube an das Buch, was immer es sei, das Allah herabgesandt hat, und mir ist befohlen worden, gerecht zwischen euch zu richten. Allah ist unser Herr und euer Herr. Für uns unsere Werke und für euch eure Werke! Kein Beweisgrund ist zwischen uns und euch. Allah wird uns zusammenbringen, und zu Ihm ist die Heimkehr."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmcclxxxviii{Und diejenigen, die über Allah streiten, nachdem Er gehört worden ist, deren Beweisführung vor ihrem Herrn ist nichtig; auf ihnen ist Zorn, und ihnen wird eine strenge Strafe zuteil sein.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmcclxxxix{Allah ist es, Der das Buch mit der Wahrheit und der Gerechtigkeit herabgesandt hat. Und wie kannst du es wissen: vielleicht steht die Stunde nahe bevor?\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmccxc{Diejenigen, die nicht an sie glauben, wünschen sie zu beschleunigen; die aber, die (an sie) glauben, haben Furcht vor ihr und wissen, daß es die Wahrheit ist. Wahrlich, diejenigen, die an der Stunde zweifeln, sind weit in die Irre (gegangen)\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmccxci{Allah ist Gütig gegen Seine Diener. Er versorgt, wen Er will. Und Er ist der Starke, der Erhabene.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmccxcii{Dem, der die Ernte des Jenseits begehrt, vermehren Wir seine Ernte; und dem, der die Ernte dieser Welt begehrt, geben Wir davon, doch am Jenseits wird er keinen Anteil haben.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmccxciii{Oder haben sie etwa Partner, die ihnen eine Glaubenslehre vorgeschrieben haben, die Allah nicht verordnet hat? Und wäre es nicht bis zum Urteilsspruch aufgeschoben worden, wäre zwischen ihnen schon gerichtet worden. Und gewiß, den Frevlern wird eine schmerzliche Strafe zuteil sein.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmccxciv{Du wirst die Frevler in Furcht sehen wegen dem, was sie begangen haben, und es wird sicherlich auf sie hereinbrechen. Jene aber, die glauben und gute Werke tun, werden in den Paradiesgärten sein. Sie sollen bei ihrem Herrn alles finden, was sie begehren. Das ist die große Huld.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmccxcv{Dies ist es, wovon Allah Seinen Dienern, die glauben und gute Werke tun, die frohe Botschaft gibt. Sprich: ``lch verlange von euch keinen Lohn dafür, es sei denn die Liebe zu den Ver wandten." Und dem, der eine gute Tat begeht, verschönern Wir sie noch. Wahrlich, Allah ist Allverzeihend, Dankbar.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmccxcvi{Oder sagen sie etwa: ``Er hat eine Lüge gegen Allah ersonnen?" Wenn Allah so wollte, könnte Er dein Herz versiegeln. Doch Allah löscht die Falschheit aus und bewahrt die Wahrheit durch Seine Worte. Wahrlich, Er weiß recht wohl, was in den Herzen ist.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmccxcvii{Und Er ist es, Der Reue von Seinen Dienern annimmt und Sünden vergibt und weiß, was ihr tut.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmccxcviii{Und Er erhört diejenigen, die gläubig sind und gute Werke tun, und gibt ihnen noch mehr von Seiner Gna denfülle; den Ungläubigen aber wird eine strenge Strafe zuteil sein.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmccxcix{Und wenn Allah die Mittel zum Unterhalt für Seine Diener erweitern würde, so würden sie übermütig auf Erden sein; doch Er sendet (Seine Gaben) in dem Maße hinab, wie Er es will; denn Er kennt und durchschaut Seine Diener recht wohl.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmccc{Und Er ist es, Der den Regen hinabsendet, nachdem sie verzweifelten, und Seine Barmherzigkeit ausbreitet. Und Er ist der Beschützer, der Preiswürdige.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmccci{Und zu Seinen Zeichen gehört die Schöpfung der Himmel und der Erde und jeglicher Lebewesen, die Er beiden eingegeben hat. Und Er hat die Macht dazu, sie allesamt zu versammeln, wenn Er will.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmcccii{Und was euch an Unglück treffen mag, es erfolgt auf Grund dessen, was eure Hände gewirkt haben. Und Er vergibt vieles.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmccciii{Und ihr könnt auf Erden nicht siegen, noch habt ihr einen Freund oder Helfer außer Allah.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmccciv{Und zu Seinen Zeichen gehören die wie Berge auf dem Meer fahrenden Schiffe.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmcccv{Wenn Er will, so kann Er den Wind stillhalten, so daß sie reglos auf seiner Oberfläche liegen - hierin sind wahrlich Zeichen für jeden Standhaften, Dankbaren -\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmcccvi{oder Er kann sie untergehen lassen um dessentwillen, was sie begangen haben - und Er vergibt vieles -\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmcccvii{und damit jene, die über Allahs Zeichen streiten, begreifen, daß sie keine Zuflucht haben.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmcccviii{Was euch (auch) immer gegeben wird: es ist nur ein vorübergehender Genuß dieses irdischen Lebens, und das, was bei Allah ist, ist besser und dauerhafter für jene, die glauben und auf ihren Herrn vertrauen\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmcccix{und (für jene, die) die schwersten Sünden und Schändlichkeiten meiden und, wenn sie zornig sind, vergeben\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmcccx{und (für jene,) die auf ihren Herrn hören und das Gebet verrichten und deren Handlungsweise (eine Sache) gegenseitiger Beratung ist, und die von dem spenden, was Wir ihnen gegeben haben\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmcccxi{und (für jene,) die sich wehren, wenn ihnen Gewalt angetan wird.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmcccxii{Die Vergeltung für eine Übeltat soll ein Übel gleichen Ausmaßes sein; dessen Lohn aber, der vergibt und Besserung bewirkt, ruht sicher bei Allah. Wahrlich, Er liebt die Ungerechten nicht.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmcccxiii{Jedoch trifft kein Tadel jene, die sich wehren, nachdem ihnen Unrecht widerfahren ist.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmcccxiv{Tadel trifft nur solche, die den Menschen Unrecht zufügen und auf Erden ohne Rechtfertigung freveln. Ihnen wird eine schmerzliche Strafe zuteil sein.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmcccxv{Und wahrlich, wer geduldig ist und vergibt - das ist gewiß eine Tugend der Entschlossenheit in allen Dingen.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmcccxvi{Und wen Allah irreführt für ihn gibt es außer Ihm keinen Beschützer. Und du wirst die Frevler sehen, wie sie, wenn sie die Strafe sehen, sagen: ``Gibt es denn keinen Weg zur Rückkehr?"\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmcccxvii{Und du wirst sie ihr ausgesetzt sehen, gedemütigt, voller Schmach (und) mit verstohlenem Blick schauend. Diejenigen aber, die gläubig sind, werden sagen: ``Wahrlich, die Verlierenden sind diejenigen, die am Tage der Auferstehung ihrer selbst und ihrer Angehörigen verlustig gegangen sind." Wahrlich, die Frevler sind langdauernder Pein (ausgesetzt)\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmcccxviii{Und sie haben keine Helfer, die ihnen gegen Allah helfen (könnten) Und für einen, den Allah zum Irrtum führt, gibt es keinen Ausweg.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmcccxix{Hört auf euren Herrn, bevor ein Tag kommt, den niemand gegen Allah verwehren kann. An jenem Tag wird es für euch keine Zuflucht geben, noch gibt es für euch irgendeine Möglichkeit, (eure Sünden) zu leugnen.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmcccxx{Kehren sie sich jedoch (vom Glauben) ab, so haben Wir dich nicht als deren Wächter entsandt. Deine Pflicht ist nur die Verkündigung. Wenn Wir dem Menschen von Unserer Barmherzigkeit zu kosten geben, so freut er sich über sie. Doch wenn ein Unheil sie um dessentwillen trifft, was ihre Hände vorausgeschickt haben: siehe, dann ist der Mensch undankbar.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmcccxxi{Allahs ist das Königreich der Himmel und der Erde. Er schafft, was Er will. Er beschert Mädchen, wem Er will, und Er beschert die Knaben, wem Er will.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmcccxxii{Oder Er gibt beide, Knaben und Mädchen, und Er macht unfruchtbar, wen Er will; Er ist Allwissend, Allmächtig.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmcccxxiii{Und keinem Menschen steht es zu, daß Allah zu ihm sprechen sollte, außer durch Eingebung oder hinter einem Vorhang oder, indem Er einen Boten schickt, um durch Sein Geheiß zu offenbaren, was Er will; Er ist Erhaben, Allweise.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmcccxxiv{Und so haben Wir dir nach Unserem Gebot ein Wort offenbart. Weder wußtest du, was die Schrift noch was der Glaube ist. Doch Wir haben sie (die Offenbarung) zu einem Licht gemacht, mit dem Wir jenen von Unseren Dienern, denen Wir wollen, den Weg weisen. Wahrlich, du leitest (sie) auf den geraden Weg\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmcccxxv{den Weg Allahs, Dem alles gehört, was in den Himmeln und was auf Erden ist. Wahrlich, zu Allah kehren alle Dinge zurück.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmcccxxvi{\basmalahde Ha Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmcccxxvii{Bei dem deutlichen Buch!\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmcccxxviii{Wahrlich Wir haben ihn zu einem Quran in arabischer Sprache gemacht, auf daß ihr (es) verstehen möget.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmcccxxix{Und wahrlich, er ist bei Uns in der Mutterschrift hochgehoben (und) voller Weisheit.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmcccxxx{Sollen Wir da die Ermahnung von euch abwenden, weil ihr ein zügelloses Volk seid?\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmcccxxxi{Wie viele Propheten entsandten Wir schon zu den früheren Völkern!\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmcccxxxii{Und nie kam ein Prophet zu ihnen, den sie nicht verspottet hätten.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmcccxxxiii{Darum vertilgten Wir die, die mächtiger als diese waren, und das (abschreckende) Beispiel der Früheren ist zuvor ergangen.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmcccxxxiv{Und wenn du sie fragst: ``Wer erschuf die Himmel und die Erde?" werden sie sicher sagen: ``Der Erhabene, der Allwissende hat sie erschaffen"\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmcccxxxv{(Der,) Der die Erde für euch zu einem Lager gemacht hat; und gemacht hat Er für euch Wege auf ihr, auf daß ihr dem rechten Wege folgen möget.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmcccxxxvi{Und (Er ist es,) Der Wasser vom Himmel nach Maß herniedersendet, durch das Wir ein totes Land zum Leben erwecken ebenso sollt auch ihr auferweckt werden.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmcccxxxvii{Und (Er ist es,) Der alle Arten paarweise erschaffen hat und für euch Schiffe gemacht hat und Tiere, auf denen ihr reitet\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmcccxxxviii{so daß ihr fest auf ihrem Rücken sitzt (und) dann, wenn ihr euch fest auf sie gesetzt habt, der Gnade eures Herrn eingedenk seid und sprechen möget: ``Preis (sei) Ihm, Der uns dies dienstbar gemacht hat, und wir wären hierzu nicht imstande gewesen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmcccxxxix{Und zu unserem Herrn werden wir sicher zurückkehren."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmcccxl{Und aus Seinen Dienern machen sie einen Teil Seiner Selbst. Wahrlich, der Mensch ist offenkundig undankbar.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmcccxli{Hat Er etwa Töchter von dem genommen, was Er erschaffen hat, und euch mit Söhnen ausgezeichnet?\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmcccxlii{Und doch, wenn einem von ihnen Kunde von dem gegeben wird, was er dem Allerbarmer zuschreibt, dann wird sein Gesicht schwarz und er erstickt vor Gram.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmcccxliii{(Ist es) etwa einer, der im Glanz aufgezogen wird und nicht beredt im Wortstreit ist?\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmcccxliv{Und sie machen die Engel, die Diener des Allerbarmers sind, zu weiblichen Wesen. Waren sie etwa Zeugen ihrer Erschaffung? Ihr Zeugnis wird niedergeschrieben, und sie werden befragt werden.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmcccxlv{Und sie sagen: ``Hätte der Allerbarmer es gewollt, hätten wir sie nicht verehrt." Sie haben keinerlei Kenntnis hiervon; sie mutmaßen nur.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmcccxlvi{Oder haben Wir ihnen etwa ein Buch vor diesem (Quran) gegeben, an dem sie festhalten?\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmcccxlvii{Nein, sie sagen: ``Wir fanden unsere Väter auf einem Weg und wir lassen uns von ihren Fußstapfen leiten."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmcccxlviii{Und ebenso sandten Wir keinen Warner vor dir in irgendeine Stadt, ohne daß die Reichen darin gesagt hätten: ``Wir fanden unsere Väter auf einem Weg, und wir treten in ihre Fußstapfen."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmcccxlix{(lhr Warner) sagte: ``Wie? Auch wenn ich euch eine bessere Führung bringe als die, welche ihr eure Väter befolgen saht?". Sie sagten: ``Wir leugnen das, womit ihr gesandt worden seid."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmcccl{Also vergalten Wir es ihnen. Siehe nun, wie das Ende der Leugner war!\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmcccli{Und da sagte Abraham zu seinem Vater und seinem Volk: ``lch sage mich von dem los, was ihr anbetet\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmccclii{statt Dem, Der mich erschuf; denn Er wird mich rechtleiten."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmcccliii{Und er machte es zu einem bleibenden Wort unter seiner Nachkommenschaft, auf daß sie darauf (zum Glauben) zurückfinden mögen.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmcccliv{Nein, aber Ich ließ sie und ihre Väter in Fülle leben, bis die Wahrheit und ein deutlicher Gesandter zu ihnen kamen.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmccclv{Doch als die Wahrheit zu ihnen kam, da sagten sie: ``Das ist Zauberei, und wir glauben nicht daran."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmccclvi{Und sie sagten: ``Warum ist dieser Quran nicht zu einem angesehenen Mann aus den beiden Städten herabgesandt worden?"\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmccclvii{Sind sie es, die die Barmherzigkeit deines Herrn zu verteilen haben? Wir Selbst verteilen unter ihnen ihren Lebensunterhalt im irdischen Leben, und Wir erhöhen einige von ihnen über die anderen im Rang, auf daß die einen die anderen in den Dienst nehmen mögen. Und die Barmherzigkeit deines Herrn ist besser als das, was sie anhäufen.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmccclviii{Und wenn es nicht (geschehen) wäre, daß alle Menschen zu einer einzigen Gemeinde (vereint) worden wären, hätten Wir denen, die nicht an den Allerbarmer glauben, Dächer aus Silber für ihre Häuser gegeben und Treppen, um (zu ihnen) hinaufzusteigen\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmccclix{und Türen für ihre Häuser und Ruhebetten, um darauf zu liegen\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmccclx{und Prunk. Doch all das ist nichts (anderes) als eine Versorgung für dieses irdische Leben. Und das Jenseits bei deinem Herrn ist den Rechtschaffenen (vorbehalten)\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmccclxi{Und für den, der sich vom Gedenken an den Allerbarmer abwendet, bestimmen Wir einen Satan, der sein Begleiter sein wird.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmccclxii{Und wahrlich, sie wenden sie vom Weg ab, jedoch meinen sie, sie seien rechtgeleitet\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmccclxiii{bis zuletzt, wenn ein solcher zu Uns kommt, er (zu seinem Begleiter) sagt: ``O läge doch zwischen mir und dir die Entfernung zwischen dem Osten und dem Westen!" Was für ein schlimmer Begleiter ist er doch!\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmccclxiv{Und euch soll an diesem Tage nichts nützen; denn ihr habt gefrevelt, so daß ihr die Strafe gemeinsam erleidet.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmccclxv{Kannst du etwa die Tauben hörend machen oder die Blinden rechtleiten oder den, der sich in einem offenkundigen Irrtum befindet?\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmccclxvi{Und sollten Wir dich fortnehmen, werden Wir sicher Uns an ihnen rächen.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmccclxvii{Oder Wir werden dir zeigen, was Wir ihnen angedroht haben; denn Wir haben völlige Macht über sie.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmccclxviii{Also halte denn an dem fest, was dir offenbart worden ist; denn du bist auf dem geraden Weg.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmccclxix{Und es ist wahrlich eine Ermahnung für dich und für dein Volk, und ihr werdet zur Rechenschaft gezogen werden.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmccclxx{Und frage jene Unserer Gesandten, die Wir vor dir entsandt haben: ``Machten Wir etwa außer dem Allerbarmer Götter, denen man dienen soll?"\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmccclxxi{Und wahrlich, Wir sandten Moses mit Unseren Zeichen zu Pharao und seinen Vornehmen; da sagte er: ``lch bin ein Gesandter vom Herrn der Welten ``\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmccclxxii{Doch als er mit Unseren Zeichen zu ihnen kam, siehe, da lachten sie über sie.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmccclxxiii{Und Wir zeigten ihnen kein Zeichen, das nicht größer als das vorherige gewesen wäre, und Wir erfaßten sie mit der Strafe, auf daß sie sich bekehren mögen.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmccclxxiv{Und sie sagten: ``O du Zauberer, bete für uns zu deinem Herrn, gemäß dem, was Er dir verheißen hat; denn wir werden dann rechtgeleitet sein."\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmccclxxv{Doch als Wir die Strafe von ihnen nahmen, siehe, da brachen sie ihr Wort.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmccclxxvi{Und Pharao ließ unter seinem Volk ausrufen: ``O mein Volk, gehören mir nicht das Königreich von Ägypten und diese Ströme, die mir zu Füßen fließen? Könnt ihr denn nicht sehen?\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmccclxxvii{Oder bin ich nicht besser als dieser da, der verächtlich ist und sich kaum verständlich ausdrücken kann?\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmccclxxviii{Warum sind ihm dann nicht Armbänder aus Gold angelegt worden oder (warum sind dann nicht) Engel mit ihm im Geleit gekommen?"\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmccclxxix{So verleitete er sein Volk zur Narrheit, und sie gehorchten ihm. Sie waren wahrlich ein frevelhaftes Volk.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmccclxxx{Nachdem sie Uns erzürnt hatten, nahmen Wir Vergeltung an ihnen und ertrankten sie allesamt.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmccclxxxi{Alsdann machten Wir sie zum Vergangenen und zu einem Beispiel für die Späteren.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmccclxxxii{Und wann immer die Rede von dem Sohn der Maria ist, siehe, dann bricht dein Volk darüber in Geschrei aus\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmmccclxxxiii{und sie sagen: ``Sind unsere Götter besser oder er?" Sie erwähnen das vor dir nur aus Widerspruchsgeist. Nein, sie sind aber ein streitsüchtiges Volk.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmmccclxxxiv{Er war nur ein Diener, dem Wir Gnade erwiesen hatten, und Wir machten ihn zu einem Beispiel für die Kinder Israels.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmmccclxxxv{Und wenn Wir es wollten, könnten Wir aus euren Reihen Engel hervorgehen lassen, (um euch) auf Erden zu ersetzen.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmmccclxxxvi{Doch wahrlich, er (Jesus) ist ein Vorzeichen der Stunde. So bezweifelt sie nicht, sondern folgt Mir. Das ist ein gerader Weg.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmmccclxxxvii{Und lasset euch nicht von Satan abwenden. Gewiß, er ist euer offenkundiger Feind.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmmccclxxxviii{Und als Jesus mit klaren Beweisen kam, sagte er: ``Wahrlich, ich bin mit der Weisheit zu euch gekommen, und um euch etwas von dem zu verdeutlichen, worüber ihr uneinig seid. So fürchtet Allah und gehorcht mir.\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmmccclxxxix{Wahrlich, Allah allein ist mein Herr und euer Herr. Darum dient Ihm. Das ist ein gerader Weg."\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmmcccxc{Doch die Parteien wurden dann untereinander uneinig; wehe dann denen, die freveln, vor der Strafe eines schmerzlichen Tages!\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmmcccxci{Sie warten nur darauf, daß die Stunde plötzlich über sie kommt, ohne daß sie es merken.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmmcccxcii{Die Freunde werden an jenem Tage einer des anderen Feind sein, außer den Gottesfürchtigen.\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmmcccxciii{``O Meine Diener, keine Furcht soll euch an diesem Tage bedrücken, noch sollt ihr traurig sein\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmmcccxciv{ihr, die ihr an Unsere Zeichen glaubtet und (Uns) ergeben waret.\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmmcccxcv{Tretet in das Paradies ein, ihr und eure Gattinnen, (und seid) glückselig!"\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmmcccxcvi{Schüsseln aus Gold und Becher werden unter ihnen kreisen, und darin wird alles sein, was die Herzen begehren und (woran) die Augen sich ergötzen ``Und ewig werdet ihr darin verweilen.\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmmcccxcvii{Und dies ist das Paradies, zu dessen Erben ihr berufen wurdet um dessentwillen, was ihr zu tun pflegtet.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmmcccxcviii{Darin gibt es für euch Früchte in Menge, von denen ihr essen könnt."\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmmcccxcix{Wahrlich, die Sünder werden ewig in der Strafe der Gahannam verharren\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmmcd{sie wird für sie nicht gemildert werden, und sie werden in ihr von Verzweiflung erfaßt werden.\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmmcdi{Nicht Wir taten ihnen Unrecht, sondern sie selbst taten (sich) Unrecht.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmmcdii{Und sie werden rufen: ``O Malik, laß deinen Herrn ein Ende mit uns machen!" Er wird sprechen: ``lhr müßt bleiben."\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmmcdiii{Wir brachten euch gewiß die Wahrheit; jedoch die meisten von euch verabscheuten die Wahrheit.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmmcdiv{Oder haben sie sich für einen Plan entschlossen? Nun, auch Wir haben Uns entschlossen.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmmmcdv{Oder meinen sie etwa, daß Wir nicht hören, was sie geheimhalten und was sie besprechen? Doch, und Unsere Boten bei ihnen schreiben es auf.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmmmcdvi{Sprich: ``Hätte der Allerbarmer einen Sohn, so wäre ich der erste, der (ihn) angebetet hätte."\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmmmcdvii{Gepriesen sei der Herr der Himmel und der Erde, der Herr des Thrones, Der frei ist von all dem, was sie behaupten.\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmmmcdviii{So laß sie sich in eitler Rede ergehen und sich vergnügen, bis sie ihrem Tag begegnen, der ihnen angedroht wird.\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmmmcdix{Und Er ist der Gott im Himmel und der Gott auf Erden, und Er ist der Allweise, der Allwissende.\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmmmcdx{Segensreich ist Er, Dessen das Königreich der Himmel und der Erde ist und all das, was zwischen beiden ist; und bei Ihm ruht die Kenntnis der Stunde, und zu Ihm sollt ihr zurückgebracht werden.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmmmcdxi{Und diejenigen, die sie statt Seiner anbeten, haben kein Fürspracherecht, mit Ausnahme dessen, der die Wahrheit bezeugt, und sie wissen Bescheid.\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmmmcdxii{Und wenn du sie fragst: ``Wer schuf sie?" werden sie sicher sagen: ``Allah." Wie lassen sie sich da (von Ihm) abwenden?\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmmmcdxiii{Und seine Aussage (lautet): ``O mein Herr! Dies ist ein Volk, das nicht glauben will."\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmmmcdxiv{Darum wende dich von ihnen ab und sprich: ``Frieden!" Und bald werden sie es wissen.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmmmcdxv{\basmalahde Ha Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmcdxvi{Bei dem deutlichen Buch!\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmcdxvii{Wahrlich, Wir haben es in einer gesegneten Nacht herabgesandt wahrlich, Wir haben damit gewarnt\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmcdxviii{in dieser (Nacht) wird jegliche weise Sache entschieden\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmcdxix{auf Grund Unseres Befehls. Wahrlich, Wir haben (Gesandte) geschickt\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmcdxx{als eine Barmherzigkeit von deinem Herrn; Er ist der Allhörende, der Allwissende\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmcdxxi{der Herr der Himmel und der Erde und all dessen, was zwischen beiden ist, wenn ihr Gewißheit (im Glauben) hättet.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmcdxxii{Es ist kein Gott außer Ihm. Er macht lebendig und läßt sterben - (Er ist) euer Herr und der Herr eurer Vorväter.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmcdxxiii{Doch sie sind im Zweifel und betreiben ein Spiel.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmcdxxiv{Darum aber erwarte den Tag, an dem der Himmel einen sichtbaren Rauch hervorbringt\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmcdxxv{der die Menschen einhüllen wird. Das wird eine schmerzliche Qual sein.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmcdxxvi{``Unser Herr, nimm die Pein von uns; wir wollen glauben."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmcdxxvii{Wie können sie lernen, wo doch ein aufklärender Gesandter zu ihnen gekommen ist?\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmcdxxviii{Und sie haben sich von ihm abgewandt und gesagt: ``(Er hat es) einstudiert, (er ist) besessen."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmcdxxix{Wir werden die Strafe geringfügig hinwegnehmen, ihr aber werdet rückfällig werden\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmcdxxx{an dem Tage, wo Wir (euch) den größten Schlag versetzen. Wahrlich, Wir werden Uns rächen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmcdxxxi{Und vor ihnen haben Wir schon das Volk Pharaos geprüft, und zu ihnen kam ein ehrenwerter Gesandter\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmcdxxxii{(, der sagte): ``Übergebt mir die Diener Allahs. Ich bin für euch ein vertrauenswürdiger Gesandter.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmcdxxxiii{Und überhebt euch nicht gegen Allah. Ich komme mit einem offenkundigen Beweis zu euch\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmcdxxxiv{und ich nehme meine Zuflucht bei meinem Herrn und eurem Herrn, damit ihr mich nicht steinigt.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmcdxxxv{Und wenn ihr mir nicht glaubt, so haltet euch von mir fern."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmcdxxxvi{Dann rief er zu seinem Herrn: ``Dies ist ein sündhaftes Volk."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmcdxxxvii{(Allah sprach:) ``Führe Meine Diener in der Nacht fort; ihr werdet verfolgt werden.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmcdxxxviii{Und verlaß das Meer, (wenn es) reglos ist. Sie sind ein Heer, das ertränkt wird."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmcdxxxix{Wie zahlreich waren die Gärten und die Quellen, die sie zurückließen!\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmcdxl{Und die Kornfelder und die ehrenvollen Stätten!\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmcdxli{Und (wie war) das Wohlleben, dessen sie sich erfreut hatten!\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmcdxlii{So geschah es, daß Wir all dies einem anderen Volk zum Erbe gaben.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmcdxliii{Weder Himmel noch Erde weinten über sie, noch wurde ihnen eine Frist gewährt.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmcdxliv{Und wahrlich, Wir erretteten die Kinder Israels vor der schimpflichen Pein\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmcdxlv{vor Pharao; denn er war hochmütig, einer der Maßlosen.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmcdxlvi{Und wahrlich, Wir erwählten sie auf Grund (Unseres) Wissens vor den Völkern.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmcdxlvii{Und Wir gaben ihnen von den Zeichen, in welchen eine offenkundige Prüfung lag.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmcdxlviii{Wahrlich, diese behaupten\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmcdxlix{``Es gibt nur unseren ersten Tod, und wir werden nicht wiedererweckt werden.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmcdl{So bringt doch unsere Väter (zurück), wenn ihr die Wahrheit redet!"\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmcdli{Sind sie besser oder das Volk des Tubba` und jene, die vor ihnen waren? Wir vertilgten sie; denn sie waren Verbrecher.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmcdlii{Und Wir erschufen die Himmel und die Erde, und das, was zwischen beiden ist, nicht zum Zeitvertreib.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmcdliii{Wir erschufen sie nur in gerechter Weise, jedoch die rneisten von ihnen wissen es nicht.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmcdliv{Der Tag der Entscheidung ist wahrlich die festgesetzte Zeit für sie alle\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmcdlv{jener Tag, an dem ein Schutzherr einem Schutzbefohlenen nichts nützen kann, und an dem ihnen nicht geholfen wird.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmcdlvi{Die (sind davon) ausgenommen, derer Allah Sich erbarmt; denn Er ist der Erhabene, der Barmherzige.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmcdlvii{Wahrlich, der Baum des Zaqqum\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmcdlviii{ist die Speise des Sünders.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmcdlix{Wie geschmolzenes Kupfer wird er in (ihren) Bäuchen brodeln\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmcdlx{wie das Brodeln kochenden Wassers.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmcdlxi{``Ergreift ihn und zerrt ihn in die Mitte der Gahim-Flammen.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmcdlxii{Dann gießt auf sein Haupt die Pein des siedenden Wassers.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmcdlxiii{Koste! Du (meintest) doch, der Erhabene, der Würdige zu sein.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmcdlxiv{Siehe, dies ist nun das, woran ihr zu zweifeln pflegtet."\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmcdlxv{Wahrlich, die Gottesfürchtigen sind an einer Stätte der Sicherheit\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmcdlxvi{in Gärten mit Quellen\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmcdlxvii{gekleidet in Seide und Brokat sitzen (sie) einander gegenüber.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmcdlxviii{So (wird es sein). Und Wir werden sie mit Huris vermählen.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmcdlxix{Sie werden dort Früchte jeder Art verlangen (und) in Sicherheit (leben)\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmcdlxx{Den Tod werden sie dort nicht kosten, außer dem ersten Tod. Und Er wird sie vor der Strafe der Gahim bewahren\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxi{als eine Gnade von deinem Herrn. Das ist das höchste Glück.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxii{Wir haben ihn (den Quran) in deiner Sprache leicht gemacht, damit sie sich ermahnen lassen.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxiii{So gib acht; siehe, sie geben auch acht.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxiv{\basmalahde Ha Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxv{Die Offenbarung des Buches stammt von Allah, dem Erhabenen, dem Allweisen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxvi{Wahrlich, in den Himmeln und auf der Erde sind Zeichen für die Gläubigen.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxvii{Und in eurer Erschaffung und all den Geschöpfen, die Er (über die Erde) verbreitet hat, sind Zeichen für Leute, die einen festen Glauben haben.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxviii{Und in dem Wechsel von Nacht und Tag und in dem, was Allah vom Himmel an Versorgung niedersendet, wodurch Er die Erde nach ihrem Tod neu belebt, und in dem Wechsel der Winde sind Zeichen für Leute, die Verstand besitzen.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxix{Dies sind die Verse Allahs, die Wir dir in Wahrheit verlesen. An welche Verkündigung wollen sie denn nach Allah und Seinen Versen (sonst) glauben?\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxx{Wehe jedem sündigen Lügner\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxxi{der Allahs Verse hört, wenn sie ihm verlesen werden, und dann in Hochmut verharrt, als hätte er sie nicht gehört darum verkünde ihm eine qualvolle Strafe!\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxxii{Und (wehe) dem, der, wenn er etwas von Unseren Zeichen kennenlernt, Spott damit treibt! Für solche (Sünder) ist eine schmahliche Strafe (vorgesehen)\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxxiii{Hinter ihnen ist Gahannam; und das, was sie erworben haben, soll ihnen nichts nützen, auch nicht die Beschützer, die sie sich statt Allah genommen haben. Und ihnen wird eine gewaltige Strafe zuteil sein.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxxiv{Dieser (Quran) ist eine Rechtleitung. Und denjenigen, welche die Zeichen ihres Herrn leugnen, wird eine qualvolle Strafe zugemessen werden.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxxv{Allah ist es, Der euch das Meer dienstbar gemacht hat, auf daß die Schiffe darauf nach Seinem Geheiß fahren, und auf daß ihr nach Seiner Gnadenfülle trachten und dankbar sein möget.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxxvi{Und Er hat das für euch dienstbar gemacht, was in den Himmeln und auf Erden ist; alles ist von Ihm. Hierin liegen wahrlich Zeichen für die Leute, die nachdenken.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxxvii{Sprich zu denen, die glauben, sie mögen denen vergeben, die nicht mit den Tagen Allahs rechnen, auf daß Er die Leute für das belohne, was sie verdienen.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxxviii{Wer Gutes tut, der tut es für seine eigene Seele, und wer Unrecht begeht, der begeht es gegen sich selbst. Alsdann werdet ihr zu eurem Herrn zurückgebracht werden.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmcdlxxxix{Und wahrlich, Wir gaben den Kindern Israels die Schrift und die Herrschaft und das Prophetentum, und Wir versorgten sie mit guten Dingen und bevorzugten sie vor den Völkern.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmcdxc{Und Wir gaben ihnen deutliche Weisungen in der Sache. Und sie wurden nicht eher uneins, als bis das Wissen zu ihnen gekommen war; denn zwischen ihnen (entstand) selbstsüchtiger Neid. Dein Herr wird gewiß zwischen ihnen am Tage der Auferstehung über das richten, worüber sie uneins waren.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmcdxci{Alsdann brachten Wir dich auf einen klaren Weg in der Sache (des Glaubens); so befolge ihn, und folge nicht den persönlichen Neigungen derer, die nicht wissen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmcdxcii{Sie werden dir sicher nichts gegen Allah nützen. Und was die Ungerechten anbelangt, so sind einige von ihnen die Beschützer anderer; Allah aber ist der Beschützer der Gottesfürchtigen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmcdxciii{Dies sind (die Mittel) zur Aufklärung für die Menschheit und eine Führung und Barmherzigkeit für Leute, die einen festen Glauben haben.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmcdxciv{Meinen die, die Böses verüben, etwa, daß Wir sie wie die behandeln würden, die glauben und gute Werke tun, so daß ihr Leben und ihr Tod gleich sein würden? Schlimm ist es, wie sie urteilen!\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmcdxcv{Und Allah hat die Himmel und die Erde in Wahrheit geschaffen, und daher wird jeder für das belohnt werden, was er verdient hat; und sie sollen kein Unrecht erleiden.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmcdxcvi{Hast du den gesehen, der sich seine eigene Neigung zum Gott nimmt und den Allah auf Grund (Seines) Wissens zum Irrenden erklärt, und dem Er Ohren und Herz versiegelt, und auf dessen Augen Er einen Schleier gelegt hat? Wer sollte ihn außer Allah wohl richtig führen? Wollt ihr euch da nicht ermahnen lassen?\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmcdxcvii{Und sie sagen: ``Es gibt nichts als dies unser irdisches Leben; wir sterben und wir leben, und nichts als die Zeit, die uns vernichtet." Jedoch sie besitzen darüber kein Wissen; sie vermuten es nur.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmcdxcviii{Und wenn ihnen Unsere deutlichen Verse verlesen werden, so wenden sie lediglich ein: ``Bringt unsere Väter (zurück), wenn ihr wahrhaftig seid."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmcdxcix{Sprich: ``Allah gibt euch das Leben und läßt euch dann sterben; dann wird Er euch am Tage der Auferstehung (vor Sich) versammeln; darüber besteht kein Zweifel; jedoch die meisten Menschen wissen es nicht."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmd{Und Allahs ist das Königreich der Himmel und der Erde; und an dem Tage, wenn die Stunde kommen soll - an jenem Tage werden die Lügner die Verlierer sein.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmdi{Und du wirst jede Nation auf Knien sehen. Jede Nation wird zu ihrem Buch gerufen werden: ``Heute sollt ihr für das, was ihr getan habt, belohnt werden.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmdii{Das ist Unser Buch; es bezeugt die Wahrheit gegen euch. Wir ließen alles aufschreiben, was ihr getan hattet."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmdiii{Was nun die betrifft, die glaubten und gute Werke vollbrachten ihr Herr wird sie in Seine Barmherzigkeit führen. Das ist die offenbare Glückseligkeit.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmdiv{Doch zu jenen, die ungläubig waren(, wird gesprochen): ``Sind euch Meine Verse nicht verlesen worden? Ihr aber waret hochmütig und ihr wurdet ein sündiges Volk.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmdv{Und als gesprochen wurde: ``Die Verheißung Allahs ist wahr, und über die Stunde herrscht kein Zweifel", da sagtet ihr: ``Wir wissen nicht, was die Stunde ist; wir halten (sie) für einen Wahn, und wir sind (von ihr) nicht überzeugt.""\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmdvi{Und die bösen Folgen ihres Tuns sind ihnen deutlich geworden; und es umschließt sie das, worüber sie zu spotten pflegten.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmdvii{Und es wird gesprochen: ``Heute haben Wir euch vergessen, so wie ihr das Eintreffen dieses euren Tages vergaßt. Eure Herberge ist das Feuer, und ihr habt keine Helfer.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmdviii{Dies (geschieht), weil ihr Allahs Zeichen zum Gespött machtet und (weil) euch das irdische Leben betrog." Darum sollen sie an jenem Tage nicht von dort herausgebracht werden, noch wird es ihnen erlaubt sein, (ihr Unrecht) wiedergutzumachen.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmdix{Alles Lob gebührt denn Allah, dem Herrn der Himmel und dem Herrn der Erde, dem Herrn der Welten!\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmdx{Sein ist die Erhabenheit in den Himmeln und auf der Erde; und Er ist der Erhabene, der Allweise.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmdxi{\basmalahde Ha Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmdxii{Die Offenbarung des Buches stammt von Allah, dem Allmächtigen, dem Allweisen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmdxiii{Wir haben die Himmel und die Erde und das, was zwischen beiden ist, nicht anders als in Wahrheit und für eine bestimmte Zeit erschaffen, diejenigen aber, die nicht daran glauben, wovor sie gewarnt wurden, wenden sich ab.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmdxiv{Sprich: ``Wisset ihr, was das ist, was ihr statt Allah anruft? Zeigt mir, was sie von der Erde erschaffen haben. Oder haben sie einen Anteil an den Himmeln? Bringt mir ein Buch herbei, das vor diesem da war, oder eine Spur von Wissen, wenn ihr wahrhaftig seid."\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmdxv{Und wer irrt mehr als jener, der statt Allah solche anruft, die ihn bis zum Tage der Auferstehung nicht erhören werden und die von seinem Anruf ahnungslos sind?\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmdxvi{Und wenn die Menschen (vor Mir) versammelt werden, werden sie ihre Feinde sein und ihre Anbetung verleugnen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmdxvii{Und wenn ihnen Unsere deutlichen Verse verlesen werden, sagen die Ungläubigen von der Wahrheit, wenn sie zu ihnen kommt: ``Das ist offenkundige Zauberei."\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmdxviii{Oder sie sagen: ``Er hat ihn (den Quran) erdichtet?" Sprich: ``Wenn ich ihn erdichtet habe, könnt ihr mir nichts gegen Allah nützen. Er weiß am besten, in was für Reden ihr euch ergeht. Er genügt als Zeuge gegen mich und euch. Und Er ist der Allvergebende, der Barmherzige."\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmdxix{Sprich: ``lch bin kein neuer Erfinder unter den Gesandten, und ich weiß nicht, was mit mir oder mit euch geschehen wird. Ich folge nur dem, was mir offenbart wird; und ich bin nur ein deutlicher Warner."\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmdxx{Sprich: ``Sagt mir, wenn dies (der Quran) nun aber von Allah stammt, und ihr lehnt es ab, obwohl ein Zeuge von den Kindern Israels bezeugt hat, was ihm gleicht. Er hat geglaubt; ihr aber seid allzu hochmütig!" Wahrlich, Allah weist dem ungerechten Volk nicht den Weg.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmdxxi{Und die Ungläubigen sagen von den Gläubigen: ``Wäre er (der Quran) etwas Gutes, hätten sie ihn nicht vor uns erlangt." Und da sie sich nicht von ihm leiten lassen, sagen sie: ``Dies ist eine alte Lüge."\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmdxxii{Und vor ihm war schon das Buch von Moses eine Führung und Barmherzigkeit; und dies hier ist ein Buch der Bestätigung in arabischer Sprache, auf daß es diejenigen warne, die freveln, und denen eine frohe Botschaft (bringe), die Gutes tun.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmdxxiii{Wahrlich, die da sagen: ``Unser Herr ist Allah" und danach aufrichtig bleiben keine Furcht soll über sie kommen, noch sollen sie traurig sein\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmdxxiv{diese sind die Bewohner des Paradieses; darin sollen sie auf ewig verweilen, als Belohnung für das, was sie zu tun pflegten.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmdxxv{Und Wir haben dem Menschen anbefohlen, gegen seine Eltern gütig zu sein. Seine Mutter trug ihn mit Widerwillen, und mit Widerwillen brachte sie ihn zur Welt. Und ihn zu tragen und ihn zu entwöhnen erfordert dreißig Monate, bis er dann, wenn er seine Vollkraft erlangt und vierzig Jahre erreicht hat, sagt: ``Mein Herr, sporne mich an, dankbar zu sein für Deine Gnade, die Du mir und meinen Eltern erwiesen hast, und (sporne mich an,) Rechtes zu wirken, das Dir wohlgefallen mag. Und laß mir meine Nachkommenschaft rechtschaffen sein. Siehe, ich wende mich zu Dir; und ich bin einer der Gottergebenen."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmdxxvi{Das sind die, von denen Wir die guten Werke annehmen, die sie getan haben, und deren üble Werke Wir übergehen. (Sie gehören) zu den Bewohnern des Paradieses - in Erfüllung der wahrhaftigen Verheißung, die ihnen verheißen wurde.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmdxxvii{Und derjenige, der zu seinen Eltern sagt: ``Pfui über euch! Verkündet ihr mir daß ich auferstehen soll, obwohl schon vor mir Geschlechter dahingegangen sind?" und (der ihnen, wenn) sie beide Allah zu Hilfe rufen (und zu ihm sagen): ``Wehe dir, glaube! Denn die Verheißung Allahs ist wahr", sagt: ``Das sind nichts als Fabeln der Alten"\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmdxxviii{(der gehört zu) jenen, gegen welche der Spruch (der Strafe) fällig wurde, zusammen mit den Scharen, die vor ihnen hingingen von den Ginn und den Menschen. Wahrlich, sie sind die Verlierer gewesen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmdxxix{Und für alle gibt es Rangstufen gemäß dem, was sie getan haben, auf daß Er ihnen ihre Taten voll heimzahle; und kein Unrecht soll ihnen widerfahren.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmdxxx{Und an dem Tage, wenn die Ungläubigen dem Feuer ausgesetzt werden(, wird gesprochen): ``lhr habt eure guten Dinge im diesseitigen Leben aufgezehrt, und ihr hattet Genuß daran. Heute nun sollt ihr mit der Strafe der Schmach belohnt werden, weil ihr ohne jegliches Recht auf Erden hochmütig und weil ihr Frevler waret."\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmdxxxi{Und gedenke des Bruders der `Ad, als er sein Volk bei den Sanddünen warnte - und Warner sind schon vor ihm gewesen und nach ihm - (und sagte): ``Dient Allah allein; denn ich fürchte für euch die Strafe eines großen Tages."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmdxxxii{Sie sagten: ``Bist du zu uns gekommen, um uns von unseren Göttern abzuwenden? So bring uns das, was du uns androhst, wenn du einer der Wahrhaftigen bist."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmdxxxiii{Er sagte: ``Das Wissen (darüber) ist einzig bei Allah. Und ich richte euch nur das aus, womit ich entsandt wurde; jedoch ich sehe, ihr seid ein unwissendes Volk."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmdxxxiv{Dann aber, als sie sahen, wie es sich ihren Tälern gleich einer Wolke näherte, sagten sie: ``Das ist eine Wolke, die uns Regen geben wird." ``Nein, es ist vielmehr das, was ihr zu beschleunigen trachtetet ein Wind, der eine schmerzliche Strafe mitführt.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmdxxxv{Er wird alles zerstören auf den Befehl seines Herrn." Und am Morgen sah man nur noch ihre Wohnungen; so üben Wir Vergeltung am schuldigen Volk.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmdxxxvi{Und Wir hatten ihnen Gewalt über das gegeben, worüber Wir euch keine gegeben haben; und Wir hatten ihnen Ohren und Augen und Herzen gegeben. Aber weder ihre Ohren noch ihre Augen noch ihre Herzen nützten ihnen im geringsten (etwas), da sie die Zeichen Allahs leugneten; und sie wurden von dem erfaßt, worüber sie zu spotten pflegten.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmdxxxvii{Und Wir haben bereits Städte rings um euch zerstört; und Wir haben die Zeichen abgewandelt, damit sie sich bekehren mögen.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmdxxxviii{Warum haben ihnen denn die nicht geholfen, die sie sich statt Allah zu Göttern genommen hatten (und die sie Ihm) nahebringen wollten? Nein, sie entschwanden ihnen. Das war ihre Lüge und das, was sie zu erdichten pflegten.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmdxxxix{Und da wandten Wir dir eine Schar Ginn zu, die den Quran vernehmen konnten; und als sie bei ihm zugegen waren, sprachen sie: ``Hört zu", und als er zu Ende war, kehrten sie zu ihrem Volk zurück (und) warnten (es)\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmdxl{Sie sprachen: ``O unser Volk, wir haben ein Buch gehört das nach Moses herabgesandt worden ist (und) welches das bestätigt, was schon vor ihm da gewesen ist; es leitet zur Wahrheit und zu dem geraden Weg.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmdxli{O unser Volk, hört auf Allahs Rufer und glaubt an Ihn. Er wird euch eure Sünden vergeben und euch vor qualvoller Strafe schützen.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmdxlii{Und der, der nicht auf Allahs Rufer hört, kann (ihm) nicht auf Erden entrinnen, noch kann er Beschützer außer Ihm haben. Solche befinden sich in einem offenkundigen Irrtum."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmdxliii{Haben sie nicht gesehen, daß Allah, Der die Himmel und die Erde erschuf und bei ihrer Erschaffung nicht müde wurde, auch vermag, die Toten lebendig zu machen? Wahrlich, Er hat Macht über alle Dinge.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmdxliv{Und an dem Tage, an dem die Ungläubigen dem Feuer ausgesetzt werden (, heißt es): ``Ist dies nicht die Wahrheit?" Sie werden sagen: ``Doch, bei unserem Herrn." Er spricht dann: ``So kostet nun die Strafe dafür, daß ihr ungläubig waret."\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmdxlv{So gedulde dich denn, wie es die Gesandten taten, die geduldig waren; und überhaste dich nicht ihretwegen. An dem Tage, an dem sie das schauen, was ihnen angedroht wird, wird es ihnen vorkommen, als hätten sie nur eine Stunde eines Tages (im Grabe) verweilt. (Dies ist) eine Ermahnung! Soll niemand anders als das frevelnde Volk vertilgt werden!\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmdxlvi{\basmalahde Die Werke derjenigen, die ungläubig sind und vom Weg Allahs abhalten, macht Er zunichte.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmdxlvii{Denjenigen aber, die gläubig sind und gute Werke tun und an das glauben, was auf Muhammad herabgesandt worden ist - und es ist ja die Wahrheit von ihrem Herrn -, denen tilgt Er ihre schlechten Taten und stellt ihre gute Lage wieder her.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmdxlviii{Dies (ist deshalb so), weil jene, die ungläubig sind, dem Trügerischen folgen, und weil diejenigen, die gläubig sind, der Wahrheit ihres Herrn folgen. So beschreibt Allah den Menschen ihre Lage.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmdxlix{Wenn ihr auf die stoßt, die ungläubig sind, so haut (ihnen) auf den Nacken; und wenn ihr sie schließlich siegreich niedergekämpft habt, dann schnürt ihre Fesseln fest. (Fordert) dann hernach entweder Gnade oder Lösegeld, bis der Krieg seine Lasten (von euch) wegnimmt. Das ist so. Und hätte Allah es gewollt, hätte Er sie Selbst vertilgen können; aber Er wollte die einen von euch durch die anderen prüfen. Und diejenigen, die auf Allahs Weg gefallen sind - nie wird Er ihre Werke zunichte machen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmdl{Er wird sie rechtleiten und ihren Stand verbessern\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmdli{und sie ins Paradies führen, das Er ihnen zu erkennen gegeben hat.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmdlii{O ihr, die ihr glaubt, wenn ihr Allahs (Sache) helft, so wird Er euch helfen und euren Füßen festen Halt geben.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmdliii{Die aber ungläubig sind - nieder mit ihnen! Er läßt ihre Werke fehlgehen.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmdliv{Dies (ist so), weil sie das hassen, was Allah herabgesandt hat; so macht Er ihre Werke zunichte.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmdlv{Sind sie denn nicht im Lande umhergezogen, so daß sie schauen konnten, wie das Ende derer war, die vor ihnen lebten? Allah richtete sie zugrunde, und für die Ungläubigen ist das gleiche wie ihnen bestimmt.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmdlvi{Dies ist (so), weil Allah der Beschützer derer ist, die glauben; die Ungläubigen aber haben keinen Beschützer.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmdlvii{Allah läßt diejenigen, die glauben und gute Werke tun, in Gärten eingehen, in denen Bäche fließen; die aber, die ungläubig sind, genießen und fressen wie das Vieh, und das Feuer wird ihre Wohnstatt sein.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmdlviii{Und wie manche Stadt, mächtiger als deine Stadt, die dich vertrieb, haben Wir schon zerstört; und sie hatten keinen Helfer!\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmdlix{Ist denn der, der sich auf einen klaren Beweis von seinem Herrn stützt, denen gleich, denen das Übel ihres Tuns schön dargestellt wurde und die ihren bösen Neigungen folgen?\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmdlx{(So ist) die Lage des Paradieses, das den Gottesfürchtigen verheißen wurde: Darin sind Bäche von Wasser, das nicht faulig wird, und Bäche von Milch, deren Geschmack sich nicht ändert, und Bäche von berauschendem Getränk - ein Genuß für die Trinkenden - und Bäche von geläutertem Honig. Und darin werden sie Früchte aller Art bekommen und Vergebung von ihrem Herrn. Können sie wohl jenen gleich sein, die ewig im Feuer sind, und denen siedendes Wasser zu trinken gegeben wird, das ihre Därme zerreißt?\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmdlxi{Unter ihnen sind einige, die auf dich hören, doch wenn sie von dir fortgehen, sagen sie jenen, denen das Wissen gegeben wurde: ``Was hat er da soeben gesagt?" Das sind diejenigen, deren Herzen Allah versiegelt hat und die ihren Neigungen folgen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmdlxii{Denen aber, die rechtgeleitet sind, verstärkt Er die Führung und verleiht ihnen Got tesfürchtigkeit.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmdlxiii{Sie warten nur auf die Stunde, daß sie plötzlich über sie komme. Die Zeichen dafür sind schon eingetroffen. Doch was wird ihnen ihr Erinnern nützen, wenn sie über sie gekommen ist?\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmdlxiv{Wisse nun, daß kein Gott außer Allah ist, und bitte um Vergebung für deine Schuld und für die gläubigen Männer und die gläubigen Frauen. Und Allah weiß, wo ihr verkehrt oder euch aufhaltet.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmdlxv{Und die da glauben, sa gen: ``Warum wird keine Sura herabgesandt?" Doch wenn eine entscheidende Sura herabgesandt wird und darin von Kampf die Rede ist, dann siehst du die, in deren Herzen Krankheit ist, dich mit dem Blick eines (Menschen) anschauen, der im Sterben von Ohnmacht befallen wird; also wehe ihnen!\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmdlxvi{Gehorsam und geziemende Worte (ständen ihnen besser an) Und wenn die Sache beschlossen ist, dann wäre es für sie am besten, sie würden Allah gegenüber aufrichtig sein.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmdlxvii{(Wollt) ihr denn, indem ihr euch (vom Glauben) abwendet, Verderben im Land anrichten und die Bande eurer Blutsverwandtschaft zerreißen?\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmdlxviii{Diese sind es, die von Allah verflucht sind, so daß Er sie taub macht und ihre Augen erblinden läßt.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmdlxix{Wollen sie also nicht über den Quran nachdenken, oder ist es (so), daß ihre Herzen verschlossen sind?\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmdlxx{Wahrlich jene, die den Rücken kehren, nachdem ihnen die Rechtleitung sichtbar geworden ist - Satan hat es ihnen eingeredet und ihnen falsche Hoffnungen gemacht.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmdlxxi{Dies (geschah), weil sie zu denen, die das hassen, was Allah herniedersandte, sagten: ``Wir wollen euch in einigen Sachen folgen." Und Allah kennt ihre Heimlichkeiten.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmdlxxii{Was aber, wenn (die) Engel sie abberufen und sie ins Gesicht und auf den Rücken schlagen?\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmdlxxiii{Dies (geschieht), weil sie dem folgten, was Allah erzürnte, und das haßten, was ihm wohlgefällig war. So macht Er ihre Werke zunichte.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmdlxxiv{Oder meinen etwa die, in deren Herzen Krankheit ist, Allah würde ihren Groll nicht an den Tag bringen?\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmdlxxv{Und wenn Wir es wollten, könnten Wir sie dir zeigen, so daß du sie an ihren Merkmalen erkennen würdest. Und du sollst sie gewiß am Klang der Rede erkennen. Und Allah kennt euer Tun.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmdlxxvi{Und Wir wollen euch sicherlich prüfen, bis Wir diejenigen von euch ausscheiden, die kämpfen und standhaft sind. Und Wir wollen eure Verhaltensweise bekannt geben.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmdlxxvii{Wahrlich, jene, die ungläubig sind und die sich von Allahs Weg abwenden und sich dem Gesandten widersetzen, nachdem ihnen der Weg sichtbar geworden ist - sie werden Allah in nichts schaden; doch Er wird ihre Werke zunichte machen.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmdlxxviii{O ihr, die ihr glaubt, gehorcht Allah und gehorcht dem Gesandten und vereitelt nicht eure Werke!\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmdlxxix{Wahrlich jene, die ungläubig sind und die sich von Allahs Weg abwenden und dann als Ungläubige sterben - ihnen wird Allah gewiß nicht verzeihen.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmdlxxx{So lasset (im Kampf) nicht nach und ruft nicht zum Waffenstillstand auf, wo ihr doch die Oberhand habt. Und Allah ist mit euch, und Er wird euch eure Taten nicht schmälern.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmdlxxxi{Wahrlich, das diesseitige Leben ist nur ein Spiel und Zeitvertreib, und wenn ihr gläubig und gottesfürchtig seid, so wird Er euch euren Lohn geben und wird nicht euer Gut von euch verlangen.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmdlxxxii{Sollte Er es von euch verlangen und drängen, würdet ihr geizig sein, und Er würde euren Groll an den Tag bringen.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmdlxxxiii{Seht, ihr seid diejenigen, die (dazu) berufen sind, auf Allahs Weg zu spenden; doch unter euch sind manche, die geizig sind. Und wer geizig ist, der geizt nur gegen sich selber; und Allah ist Derjenige, Der reich ist, und ihr seid die Armen. Und wenn ihr (ihm) den Rücken kehrt, so wird Er ein anderes Volk an eure Stelle setzen; und sie werden nicht so sein wie ihr.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmdlxxxiv{\basmalahde Wahrlich, Wir haben dir einen offenkundigen Sieg beschieden\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmdlxxxv{auf daß Allah dir deine vergangene und künftige Schuld vergebe, und auf daß Er Seine Gnade an dir vollende und dich auf einen geraden Weg leite\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmdlxxxvi{und auf daß Allah dir zu einem würdigen Sieg verhelfe.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmdlxxxvii{Er ist es, Der die Ruhe in die Herzen der Gläubigen niedersandte, damit sie ihrem Glauben Glau ben hinzufügen - und Allahs sind die Heerscharen der Himmel und der Erde, und Allah ist Allwissend, Allweise\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmdlxxxviii{auf daß Er die gläubigen Männer und die gläubigen Frauen einführe in Gärten, durch die Bäche fließen, um ewig darin zu verweilen, und auf daß Er ihre Missetaten von Ihnen nehme - und das ist vor Allah ein großer Gewinn -\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmdlxxxix{und (auf daß Er) die Heuchler und Heuchlerinnen und die Götzendiener und Götzen dienerinnen bestrafe, die üble Gedanken über Allah hegen. Auf solche (Sünder) wird ein böses Unheil niederfallen; und Allah ist zornig auf sie; und Er hat sie verflucht und Gahannam für sie bereitet. Und das ist eine üble Bestimmung.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmdxc{Und Allahs sind die Heerscharen der Himmel und der Erde; und Allah ist Erhaben, Allweise.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmdxci{Wahrlich, Wir haben dich als Zeugen und als Bringer froher Botschaft und als Warner gesandt\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmdxcii{auf daß ihr an Allah und Seinen Gesandten glauben und ihm helfen und ihn ehren und Ihn (Allah) morgens und abends preisen möget.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmdxciii{Wahrlich, diejenigen, die dir huldigen - sie huldigen in der Tat nur Allah; die Hand Allahs ist über ihren Händen. Und wer daher den Eid bricht, bricht ihn zu seinem eigenen Schaden; dem aber, der das hält, wozu er sich Allah gegenüber verpflichtet hat, wird Er einen gewaltigen Lohn geben.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmdxciv{Diejenigen unter den Wüstenarabern, die zurückblieben, werden zu dir sagen: ``Beschäftigt haben uns unsere Besitztümer und unsere Familien, darum bitte um Verzeihung für uns." Sie sagen mit ihren Zungen, was nicht in ihren Herzen ist. Sprich: ``Wer vermag etwas für euch bei Allah (auszurichten), wenn Er euch Schaden oder Nutzen zufügen will? Nein, Allah ist dessen wohl kundig, was ihr tut.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmdxcv{Nein, ihr meintet, daß der Gesandte und die Gläubigen nimmermehr zu ihren Familien zurückkehren würden, und das wurde euren Herzen wohlgefällig gemacht, und ihr hegtet einen bösen Gedanken, und ihr waret ein verderbtes Volk."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmdxcvi{Und jene, die nicht an Allah und Seinen Gesandten glauben - für die Ungläubigen haben Wir ein flammendes Feuer bereitet.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmdxcvii{Und Allahs ist das Königreich der Himmel und der Erde. Er vergibt, wem Er will, und bestraft, wen Er will, und Allah ist Allvergebend, Barmherzig.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmdxcviii{Diejenigen, die zurückblieben, werden sagen: ``Wenn ihr nach Beute auszieht, die ihr zu nehmen beabsichtigt, so erlaubt uns, euch zu folgen." Sie wollen Allahs Spruch ändern. Sprich: ``lhr sollt uns nicht folgen; so hat Allah zuvor gesprochen." Dann werden sie sagen: ``Nein, aber ihr beneidet uns." Das nicht, jedoch sie verstehen nur wenig.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmdxcix{Sprich zu den Wüstenarabern, die zurückblieben: ``lhr sollt gegen ein Volk von starken Kriegern aufgerufen werden; ihr kämpft gegen sie, es sei denn, sie treten zum Islam Aber; und wenn ihr gehorcht, wird Allah euch einen schönen Lohn geben; doch wenn ihr (ihm) den Rücken kehrt, wie ihr ihn zuvor gekehrt habt, dann wird Er euch mit qualvoller Strafe bestrafen."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmdc{Kein Tadel trifft den Blinden noch trifft ein Tadel den Gehbehinderten, noch trifft ein Tadel den Kranken. Und den, der Allah und Seinem Gesandten gehorcht, wird Er in Gärten führen, durch die Bäche fließen; doch den, der (ihm) den Rücken kehrt, wird Er mit schmerzlicher Strafe bestrafen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmdci{Allah ist wohl zufrieden mit den Gläubigen, weil sie dir unter dem Baum Treue gelobten; und Er wußte, was in ihren Herzen war, dann sandte Er Ruhe auf sie hinab und belohnte sie mit einem nahen Sieg\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmdcii{und mit viel Beute, die sie machen werden. Und Allah ist Erhaben, Allweise.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmdciii{Allah hat euch viel Beute verheißen, die ihr machen werdet, und Er hat euch dies eilends aufgegeben und hat die Hände der Menschen von euch abgehalten, auf daß es ein Zeichen für die Gläubigen sei und auf daß Er euch auf einen geraden Weg leite.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmdciv{Und einen anderen (Teil der Beute), den ihr noch nicht zu erlangen vermöchtet, hat Allah jedoch in Seiner Macht. Und Allah hat Macht über alle Dinge.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmdcv{Und wenn die Ungläubigen euch bekämpft hätten, hätten sie (euch) gewiß den Rücken gekehrt; dann hätten sie weder Beschützer noch Helfer finden können.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmdcvi{Derart ist Allahs Vorgehen, wie es zuvor gewesen ist; und nie wirst du in Allahs Vorgehen einen Wandel finden.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmdcvii{Und Er ist es, Der ihre Hände von euch abhielt und eure Hände von ihnen in dem Tal von Makka, nachdem Er euch den Sieg über sie gegeben hatte. Und Allah sieht alles, was ihr tut.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmdcviii{Sie sind es, die ungläubig waren und euch von der heiligen Moschee fernhielten und die Opfertiere daran hinderten, ihren Bestimmungsort zu erreichen. Und wäre es nicht wegen der gläubigen Männer und der gläubigen Frauen gewesen, die ihr nicht kanntet und die ihr vielleicht unwissentlich niedergetreten hättet, so daß ihr euch an ihnen versündigt hättet, (hättet ihr kämpfen können) Damit Allah in Seine Gnade führe, wen Er will. Wären sie getrennt gewesen, hätten Wir sicher jene unter ihnen, die ungläubig waren, mit schmerzlicher Strafe bestraft.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmdcix{Als die Ungläubigen in ihren Herzen Parteilichkeit hegten - die Parteilichkeit der Gahiliya -, sandte Allah auf Seinen Gesandten und auf die Gläubigen Seine Ruhe hinab und ließ sie an dem Wort der Gottesfurcht festhalten, und sie hatten wohl Anspruch auf dieses (Wort) und waren seiner würdig. Und Allah weiß über alle Dinge Bescheid.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmdcx{Wahrlich, Allah hat Seinem Gesandten das Traumgesicht zu Wirklichkeit gemacht. Ihr werdet gewiß; denn Allah wollte (es so), in Sicherheit in die heilige Moschee, mit geschorenem Haupt oder kurzgeschnittenem Haar eintreten; ihr werdet keine Furcht haben. Doch Er wußte, was ihr nicht wußtet; und Er hat (euch) außer diesem (Sieg) einen nahen Sieg bestimmt.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmdcxi{Er ist es, Der Seinen Gesandten mit der Führung und der wahren Religion geschickt hat, auf daß Er sie über jede andere Religion siegen lasse. Und Allah genügt als Zeuge.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmdcxii{Muhammad ist der Gesandte Allahs. Und die, die mit ihm sind, sind hart gegen die Ungläubigen, doch barmherzig zueinander. Du siehst sie sich (im Gebet) beugen, niederwerfen (und) Allahs Huld und Wohlgefallen erstreben. Ihre Merkmale befinden sich auf ihren Gesichtern: die Spuren der Niederwerfungen. Das ist ihre Beschreibung in der Thora. Und ihre Beschreibung im Evangelium lautet: (Sie sind) gleich dem ausgesäten Samenkorn, das seinen Schößling treibt, ihn dann stark werden läßt, dann wird er dick und steht fest auf seinem Halm, zur Freude derer, die die Saat ausgestreut haben - auf daß Er die Ungläubigen bei ihrem (Anblick) in Wut entbrennen lasse. Allah hat denjenigen, die glauben und gute Werke tun, Vergebung und einen gewaltigen Lohn verheißen.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmdcxiii{\basmalahde O ihr, die ihr glaubt, kommt nicht Allah und Seinem Gesandten zuvor, und fürchtet Allah. Wahrlich, Allah ist Allhörend, Allwissend.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmdcxiv{O ihr, die ihr glaubt, erhebt nicht eure Stimmen über die Stimme des Propheten und redet nicht so laut zu ihm, wie ihr zueinander redet, so daß eure Werke nicht eitel werden, ohne daß ihr es merkt.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmdcxv{Wahrlich, diejenigen, die ihre Stimmen dämpfen in der Gegenwart des Gesandten Allahs, sind es, deren Herzen Allah zur Gottesfurcht geläutert hat. Für sie ist Vergebung und ein gewaltiger Lohn (bereitet)\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmdcxvi{Wahrlich, jene, die dich von außerhalb der Gemächer her rufen - die meisten von ihnen haben keinen Verstand.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmdcxvii{Und wenn sie sich geduldeten, bis du zu ihnen herauskämest, so wäre es besser für sie gewesen. Doch Allah ist Allvergebend, Barmherzig.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmdcxviii{O ihr, die ihr glaubt, wenn ein Frevler euch eine Kunde bringt, so vergewissert euch (dessen), damit ihr nicht anderen Leuten in Unwissenheit ein Unrecht zufügt und hernach bereuen müßt, was ihr getan habt.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmdcxix{Und wisset, daß der Gesandte Allahs unter euch ist. Würde er sich in so vielen Dingen nach euren Wünschen richten, würdet ihr sicher in Bedrängnis kommen; jedoch Allah hat euch den Glauben lieb gemacht und sehr begehrenswert für eure Herzen; und Er hat euch Unglauben, Widersetzlichkeit und Ungehorsam verabscheuenswert gemacht. Das sind jene, die der rechten Bahn folgen\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmdcxx{durch die Huld und die Gnade Allahs. Und Allah ist Allwissend, Allweise.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmdcxxi{Und wenn zwei Parteien der Gläubigen einander bekämpfen, dann stiftet Frieden zwischen ihnen; wenn jedoch eine von ihnen sich gegen die andere vergeht, so bekämpft diejenige, die im Unrecht ist, bis sie sich Allahs Befehl fügt. Fügt sie sich, so stiftet in Ge rechtigkeit Frieden zwischen ihnen und seid gerecht. Wahrlich, Allah liebt die Gerechten.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmdcxxii{Die Gläubigen sind ja Brüder. So stiftet Frieden zwischen euren Brüdern und fürchtet Allah, auf daß euch Barmherzigkeit erwiesen werde.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmdcxxiii{O ihr, die ihr glaubt! Laßt nicht eine Schar über die andere spotten, vielleicht sind diese besser als jene; noch (lasset) Frauen über (andere) Frauen (spotten), vielleicht sind diese besser als jene. Und verleumdet einander nicht und gebt einander keine Schimpfnamen. Schlimm ist die Bezeichnung der Sündhaftigkeit, nachdem man den Glauben (angenommen) hat, und jene die nicht umkehren - das sind die Ungerechten.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmdcxxiv{O ihr, die ihr glaubt! Vermeidet häufigen Argwohn; denn mancher Argwohn ist Sünde. Und spioniert nicht und führt keine üble Nachrede übereinander. Würde wohl einer von euch gerne das Fleisch seines toten Bruders essen? Sicher würdet ihr es verabscheuen. So fürchtet Allah. Wahrlich, Allah ist Gnädig, Barmherzig.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmdcxxv{O ihr Menschen, Wir haben euch aus Mann und Frau erschaffen und euch zu Völkern und Stämmen gemacht, auf daß ihr einander erkennen möget. Wahrlich, vor Allah ist von euch der Angesehenste, welcher der Gottesfürchtigste ist. Wahrlich, Allah ist Allwissend, Allkundig.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmdcxxvi{Die Wüstenaraber sagen: ``Wir glauben." Sprich: ``lhr glaubt nicht; sagt vielmehr: ``Wir haben den Islam angenommen", und der Glaube ist noch nicht in eure Herzen eingedrungen." Wenn ihr aber Allah und Seinem Gesandten gehorcht, so wird Er euch nichts von euren Werken verringern. Wahrlich, Allah ist Allvergebend, Barmherzig.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmdcxxvii{Die Gläubigen sind nur jene, die an Allah und Seinen Gesandten glauben und dann nicht (am Glauben) zweifeln und sich mit ihrem Besitz und ihrem eigenen Leben für Allahs Sache einsetzen. Das sind die Wahrhaftigen.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmdcxxviii{Sprich: ``Wollt ihr Allah über eure Religion belehren, wo Allah doch alles kennt, was in den Himmeln und was auf Erden ist, und Allah alle Dinge weiß?"\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmdcxxix{Sie halten es dir als eine Gnade vor, daß sie den Islam angenommen haben. Sprich: ``Haltet mir eure Annahme des Islam nicht als eine Gnade vor. Vielmehr hält Allah euch Seine Gnade vor, indem Er euch zu dem Glauben geleitet hat, wenn ihr wahrhaftig seid."\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmdcxxx{Wahrlich, Allah kennt das Verborgene der Himmel und der Erde; und Allah sieht alles, was ihr tut.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmdcxxxi{\basmalahde Qaf Beim ruhmvollen Quran!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmdcxxxii{Aber sie staunen, daß zu ihnen ein Warner aus ihrer Mitte gekommen ist. Und die Ungläubigen sagen: ``Das ist eine merkwürdige Sache.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmdcxxxiii{Wie? Wenn wir tot sind und zu Staub geworden sind (, dann sollen wir wieder auferweckt werden)? Das ist eine Wiederkehr, die weit abseits liegt."\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmdcxxxiv{Wir wissen wohl, was die Erde von ihnen wegnimmt, und bei Uns ist ein Buch, das alles aufzeichnet.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmdcxxxv{Nein, sie haben die Wahrheit, als sie zu ihnen kam, für eine Lüge erklärt, und nun befinden sie sich in einem Zustand der Verwirrung.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmdcxxxvi{Haben sie nicht zum Himmel über ihnen emporgeschaut, wie Wir ihn erbaut und geschmückt haben und daß er keine Risse aufweist?\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmdcxxxvii{Und die Erde Wir haben sie ausgebreitet und feste Berge darauf gesetzt; und Wir ließen auf ihr all die herrlichen Paare hervorsprießen\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmdcxxxviii{als Aufklärung und Ermahnung für jeden Diener, der sich bekehrt.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmdcxxxix{Und vom Himmel senden Wir Wasser hernieder, das voll des Segens ist, und bringen damit Gärten und Korn zum Ernten hervor\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmdcxl{und hochragende Palmen mit dicht stehenden Fruchtscheiden\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmdcxli{als Versorgung für die Diener; und Wir beleben damit ein totes Land. So wird die Auferstehung sein.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmdcxlii{Schon vor ihnen leugneten das Volk Noahs und das Volk des Brunnens und die Tamud\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmdcxliii{und die `Ad und Pharao und die Brüder des Lot\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmdcxliv{und die Waldbewohner und das Volk von Tubba`. Alle diese haben die Gesandten der Lüge bezichtigt. Darum war Meine Drohung in Erfüllung gegangen.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmdcxlv{Sind Wir denn durch die erste Schöpfung ermüdet? Nein, aber sie sind sich nicht im klaren über eine neue Schöpfung.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmdcxlvi{Und wahrlich, Wir erschufen den Menschen, und Wir wissen, was er in seinem Innern hegt; und Wir sind ihm näher als (seine) Hals schlagader.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmdcxlvii{Wenn die zwei aufnehmenden (Engel etwas) niederschreiben, zur Rechten und zur Linken sitzend\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmdcxlviii{spricht er kein Wort aus, ohne daß neben ihm ein Aufpasser wäre, der stets bereit (ist, es aufzuzeichnen)\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmdcxlix{und es kam die Benommenheit des Todeskampfes in Gerechtigkeit: ``Das ist es, dem du zu entrinnen suchtest."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmdcl{Und es wird in den Sur gestoßen: ``Dies ist der Tag der Drohung."\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmdcli{Und jede Seele ist gekommen; mit ihr wird ein Treiber und ein Zeuge sein.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmdclii{``Wahrlich, du warst dessen ahnungslos gewesen; nun haben Wir deine Hülle von dir genommen, so daß dein Blick heute scharf ist."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmdcliii{Und sein Gefährte spricht: ``Hier (ist), was ich bereit habe."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmdcliv{``Werft ihr beide in Gahannam einen jeden undankbaren Hartnäckigen\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmdclv{den Behinderer des Guten, den Übertreter, den Zweifler\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmdclvi{der einen anderen Gott neben Allah setzte. Werft denn ihr beide ihn in die schreckliche Pein!"\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmdclvii{Sein Gefährte spricht: ``O unser Herr, ich verführte ihn nicht zur Empörung, sondern er selbst ging zu weit in die Irre."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmdclviii{Er spricht: ``Streitet nicht vor Mir, wo Ich euch doch die Warnung im voraus gesandt hatte.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmdclix{Das Wort wird bei Mir nicht abgeändert, und Ich bin in nichts ungerecht gegen die Diener."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmdclx{An jenem Tage sprechen Wir zu Gahannam:: ``Bist du angefüllt?" und sie spricht: ``Gibt es noch mehr?"\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmdclxi{Und das Paradies wird den Gottesfürchtigen nahe gerückt, (und es ist) nicht länger fern.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmdclxii{``Das ist es, was jedem von euch verheißen wurde, der reumütig war und sich in acht nahm\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmdclxiii{der den Allerbarmer im geheimen fürchtete und mit reuigem Herzen (zu Ihm) kam.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmdclxiv{Geht darin (ins Paradies) ein in Frieden. Dies ist der Tag der Ewigkeit."\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmdclxv{Sie haben darin, was immer sie begehren, und bei Uns ist noch weit mehr.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmdclxvi{Und wieviele Generationen haben Wir schon vor ihnen vertilgt, die schlagkräftiger waren als sie und im Lande umherzogen! Gab es da ein Entrinnen?\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmdclxvii{Hierin liegt wahrlich eine Ermahnung für den, der ein Herz hat oder zuhört und bei der Sache ist.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmdclxviii{Und wahrlich, Wir erschufen die Himmel und die Erde und das, was zwischen beiden ist, in sechs Tagen, und keine Ermüdung berührte Uns.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmdclxix{So ertrage geduldig, was sie sagen, und lobpreise deinen Herrn vor dem Aufgang der Sonne und vor dem (Sonnen-)untergang\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmdclxx{und lobpreise Ihn in einem Teil der Nacht und nach jedem Gebet.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmdclxxi{Und lausche am Tage, wenn der Rufer von einem nahen Ort (zum Jüngsten Gericht) rufen wird.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmdclxxii{Der Tag, wenn sie in Wahrheit den Schrei hören werden - das wird dann der Tag der Auferstehung sein.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmdclxxiii{Wahrlich, Wir allein machen lebendig und lassen sterben, und zu Uns ist die Heimkehr.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmdclxxiv{An dem Tage, wenn sich die Erde spalten und freigeben wird, worauf sie sich beeilen, dann wird ein Versammeln vor sich gehen, (das) für Uns ganz leicht (ist)\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmdclxxv{Wir wissen am besten, was sie sagen; und du hast keine Gewalt über sie. Ermahne darum durch den Quran den, der Meine Drohung fürchtet.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmdclxxvi{\basmalahde Bei den heftig aufwirbelnden (Winden)\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmdclxxvii{dann den lasttragenden (Wolken)\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmdclxxviii{dann den leicht dahinziehenden (Schiffen)\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmdclxxix{und den, den Befehl ausführenden (Engeln)!\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmdclxxx{Wahrlich, was euch angedroht wird, ist wahr.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmdclxxxi{Und das Gericht wird ganz sicher eintreffen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmdclxxxii{Und bei dem Himmel mit seiner makellosen Bauweise!\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmdclxxxiii{Wahrlich, ihr seid in eine widerspruchsvolle Rede verwickelt.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmdclxxxiv{Der allein wird von der (Wahrheit) abgewendet, der sich davon abbringen läßt.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmdclxxxv{Verflucht seien die, die Mutmaßungen anstellen\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmdclxxxvi{die in ihrer Verblendung achtlos sind.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmdclxxxvii{Sie fragen: ``Wann wird der Tag des Gerichts sein?"\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmdclxxxviii{Es wird der Tag sein, an dem sie im Feuer gepeinigt werden.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmdclxxxix{``Kostet nun eure Pein. Das ist es, was ihr zu beschleunigen wünschtet."\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmdcxc{Wahrlich, die Gottesfürchtigen werden inmitten von Gärten und Quellen sein\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmdcxci{(und das) empfangen, was ihr Herr ihnen gegeben hat, weil sie vordem Gutes zu tun pflegten.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmdcxcii{Sie schliefen nur einen kleinen Teil der Nacht\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmdcxciii{und vor Tagesanbruch suchten sie stets Vergebung\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmdcxciv{und von ihrem Vermögen war ein Anteil für den Bittenden und den Unbemittelten bestimmt.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmdcxcv{Und auf Erden existieren Zeichen für jene, die fest im Glauben sind\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmdcxcvi{und in euch selber. Wollt ihr es denn nicht sehen?\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmdcxcvii{Und im Himmel ist eure Versorgung und das, was euch verheißen wird.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmdcxcviii{Darum, bei dem Herrn des Himmels und der Erde - dies ist gewiß wahr, eben wie (es wahr ist,) daß ihr redet.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmdcxcix{Ist die Geschichte von Abrahams geehrten Gästen nicht zu dir ge kommen?\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmdcc{Als sie bei ihm eintraten und sprachen: ``Frieden!" sagte er: ``Frieden, unbekannte Leute."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmdcci{Und er ging unauffällig zu seinen Angehörigen und brachte ein gemästetes Kalb.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmdccii{Und er setzte es ihnen vor. Er sagte: ``Wollt ihr nicht essen?"\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmdcciii{Es erfaßte ihn Furcht vor ihnen. Sie sprachen: ``Fürchte dich nicht." Dann gaben sie ihm die frohe Nachricht von einem klugen Knaben.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmdcciv{Da kam seine Frau in Aufregung heran, und sie schlug ihre Wange und sagte: ``(Ich bin doch) eine unfruchtbare alte Frau!"\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmdccv{Sie sprachen: ``Das ist so, aber dein Herr hat gesprochen. Wahrlich, Er ist der Allweise, der Allwissende."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmdccvi{(Abraham) sagte: ``Wohlan, was ist euer Auftrag, ihr Boten?"\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmdccvii{Sie sprachen: ``Wir sind zu einem schuldigen Volke entsandt worden\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmdccviii{auf daß wir Steine von Ton auf sie niedersenden\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmdccix{die von deinem Herrn für diejenigen gekennzeichnet sind, die nicht maßhalten."\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmdccx{Und Wir ließen alle die Gläubigen, die dort waren, fortgehen.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmdccxi{Wir fanden dort nur ein Haus von den Gottergebenen.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmdccxii{Und Wir hinterließen darin ein Zeichen für jene, die die qualvolle Strafe fürchten.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmdccxiii{Und (ein weiteres Zeichen war) in Moses, als Wir ihn zu Pharao mit offenkundiger Beweismacht sandten.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmdccxiv{Da drehte er sich im Gefühl seiner Stärke um und sagte: ``(Dies ist) ein Zauberer oder ein Wahnsinniger!"\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmdccxv{So erfaßten Wir ihn und seine Heerscharen und warfen sie ins Meer; und er ist zu tadeln.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmdccxvi{Und (ein Zeichen war) in den `Ad, als Wir den verheerenden Wind gegen sie sandten\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmdccxvii{er ließ nichts von alledem, was er heimsuchte, zurück, ohne daß er alles gleichsam morsch gemacht hätte.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmdccxviii{Und (ein Zeichen war) in den Tamud, als zu ihnen gesprochen wurde: ``Genießt (das Leben) nur eine Weile."\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmdccxix{Doch sie trotzten dem Befehl ihres Herrn. So ereilte sie der Blitzschlag, als sie dahin schauten.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmdccxx{Und sie vermöchten nicht (wieder) aufzustehen, noch fanden sie Hilfe.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmdccxxi{Und vordem (vertilgten Wir) das Volk Noahs; denn sie waren ein frevelhaftes Volk.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmdccxxii{Und den Himmel haben Wir mit (Unserer) Kraft erbaut; und siehe, wie Wir ihn reichlich geweitet haben.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmdccxxiii{Und die Erde haben Wir ausgebreitet, und wie schön breiten Wir aus!\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmdccxxiv{Und von jeglichem Wesen haben Wir Paare erschaffen, auf daß ihr euch vielleicht doch besinnen möget.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmdccxxv{Flieht darum zu Allah. Ich bin zu euch als deutlicher Warner von Ihm (gesandt worden)\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmdccxxvi{Und setzt keinen anderen Gott neben Allah. Ich bin zu euch als deutlicher Warner von Ihm (gesandt worden)\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmdccxxvii{So kam auch zu denen vor ihnen kein Gesandter, ohne daß sie gesagt hätten: ``(Dies ist) ein Zauberer oder ein Besessener!"\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmdccxxviii{Haben sie es etwa einander ans Herz gelegt? Sie sind vielmehr aufsässige Leute.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmdccxxix{So kehre dich von ihnen ab; und dich soll kein Tadel treffen.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmdccxxx{Doch fahre fort, (sie) zu ermahnen; denn die Ermahnung nützt den Gläubigen.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmdccxxxi{Und Ich habe die Ginn und die Menschen nur darum erschaffen, damit sie Mir dienen (sollen)\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmdccxxxii{Ich will keine Versorgung von ihnen haben, noch will Ich, daß sie Mir Speise geben.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmmdccxxxiii{Wahrlich, Allah allein ist der Versorger, der Stärke und Festigkeit besitzt.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmmdccxxxiv{Und für jene, die Unrecht tun, ist ein Anteil an Sündhaftigkeit (vorgesehen) wie der Anteil ihrer Gefährten; sie sollen Mich darum nicht bitten, (die Strafe) zu beschleunigen.\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmmdccxxxv{Wehe also denen, die ungläubig sind, ihres Tages wegen, der ihnen angedroht ist!\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmmdccxxxvi{\basmalahde Bei dem Berge\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmdccxxxvii{und bei dem Buche, das geschrieben ist\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmdccxxxviii{auf feinem, ausgebreitetem Pergament\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmdccxxxix{und bei dem viel besuchten Haus\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmdccxl{und bei der hochgehobenen Decke\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmdccxli{und beim brennenden Meer!\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmdccxlii{Wahrlich, die Strafe deines Herrn trifft sicher ein.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmdccxliii{Niemand kann sie abwehren\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmdccxliv{am Tage, an dem der Himmel heftig schwankt\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmdccxlv{und die Berge sich von der Stelle bewegen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmdccxlvi{Wehe also an jenem Tage den Leugnern\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmdccxlvii{die mit eitler Rede ein Spiel treiben!\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmdccxlviii{Am Tage, wenn sie nach und nach in Gahannam gestoßen werden, (wird gesprochen)\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmdccxlix{``Das ist das Feuer, das ihr zu leugnen pflegtet.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmdccl{Ist dies wohl ein Zauberwerk, oder seht ihr es nicht?\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmdccli{Brennt darin; und ob ihr euch geduldig oder ungeduldig erweist, es wird für euch gleich sein. Ihr werdet nur für das entlohnt, was ihr getan habt."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmdcclii{Wahrlich, die Gottesfürchtigen sind in Gärten in (einem Zustand) der Wonne\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmdccliii{sie erfreuen sich der Gaben, die ihr Herr ihnen beschert hat, und ihr Herr wird sie vor der Pein der Gahim bewahren.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmdccliv{``Esset und trinkt und lasset es euch wohl bekommen für das, was ihr getan habt."\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmdcclv{Gelehnt werden sie sein auf Ruhebetten in Reihen. Und Wir werden sie mit Huris vermählen.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmdcclvi{Und diejenigen, die glauben und (diejenigen, die ihnen) folgen im Glauben von ihren Nachkommen; mit denen wollen Wir ihre Nachkommen vereinen. Und Wir werden ihnen ihre Werke nicht im geringsten schmälern. Jedermann ist von dem abhängig, was er gewirkt hat.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmdcclvii{Und Wir werden sie mit Früchten und Fleisch versorgen, wie sie es nur wünschen mögen.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmdcclviii{Dort greifen sie nach einem Becher, durch den man weder zu sinnlosem Gerede noch zu Sündhaftigkeit verleitet wird\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmdcclix{und sie werden von ihren Jünglingen bedient, als ob sie wohlverwahrte Perlen wären.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmdcclx{Und sie wenden sich fragend aneinander\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmdcclxi{(und) sie sagen: ``Wahrlich, früher bei unseren Angehörigen waren wir ängstlich\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmdcclxii{doch Allah ist uns Gnädig gewesen und hat uns vor der Pein des sengenden Windes bewahrt.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmdcclxiii{Wir pflegten vormals zu Ihm zu beten. Er ist der Gütige, der Barmherzige."\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmdcclxiv{So ermahne darum; auf Grund der Gnade deines Herrn bist du weder ein Wahrsager noch ein Besessener.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmdcclxv{Oder sagen sie etwa: ``(Er ist) ein Dichter; wir wollen das Unheil abwarten, das die Zeit über ihn bringen wird?"\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmdcclxvi{Sprich: ``Wartet nur! Ich bin mit euch bei den Wartenden."\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmdcclxvii{Ist es ihr Verstand, der ihnen solches anbefiehlt, oder sind sie ein widerspenstiges Volk?\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmdcclxviii{Oder sagen sie etwa: ``Er hat ihn (den Quran) aus der Luft gegriffen?" Nein, aber sie wollen es nicht glauben.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmdcclxix{Laß sie denn eine Verkündigung gleicher Art beibringen, wenn sie die Wahrheit sagen!\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmdcclxx{Oder sind sie wohl durch nichts erschaffen worden, oder sind sie gar selbst die Schöpfer?\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxi{Oder schufen sie die Himmel und die Erde? Nein, aber sie haben keine Gewißheit.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxii{Oder haben sie die Schätze deines Herrn zu eigen, oder sind sie die Herrschenden?\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxiii{Oder haben sie eine Leiter, auf der sie lauschen können? Dann möge ihr Lauscher einen deutlichen Beweis beibringen.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxiv{Oder hat Er wohl die Töchter, und habt ihr die Söhne?\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxv{Oder verlangst du einen Lohn von ihnen, so daß sie mit einer Schuldenlast beladen sind?\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxvi{Oder haben sie Kenntnis von dem Verborgenen, so daß sie (es) niederschreiben?\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxvii{Oder beabsichtigen sie, eine List anzuwenden? Die Ungläubigen sind es, die überlistet werden\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxviii{Oder haben sie einen (anderen) Gott statt Allah? Hoch Erhaben ist Allah über all das, was sie (Ihm) beigesellen.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxix{Und sähen sie ein Stück vom Himmel niederfallen, würden sie sagen: ``(Das ist nur) ein Haufen Wolken."\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxx{So laß sie allein, bis sie ihrem Tag begegnen, an dem sie vom Blitzschlag getroffen werden\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxxi{dem Tag, an dem ihnen ihre List nicht im geringsten nützt, noch wird ihnen geholfen werden.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxxii{Und für jene, die freveln, ist wahrlich (noch) eine Strafe außer dieser (bestimmt) Jedoch die meisten von ihnen wissen es nicht.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxxiii{So sei denn geduldig mit dem Befehl deines Herrn; denn du stehst unter Unserer Aufsicht; und lobpreise deinen Herrn, wenn du aufstehst.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxxiv{Und preise Ihn auch während eines Teils der Nacht und beim Weichen der Sterne.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxxv{\basmalahde Beim Stern, wenn er heruntersaust!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxxvi{Euer Gefährte ist weder verwirrt, noch befindet er sich im Unrecht\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxxvii{noch spricht er aus Begierde.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxxviii{Vielmehr ist es eine Offenbarung, die (ihm) eingegeben wird.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmdcclxxxix{Gelehrt hat ihn einer, der über starke Macht verfügt\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmdccxc{dessen Macht sich auf alles erstreckt; darum stand er aufrecht da\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmdccxci{als er am obersten Horizont war.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmdccxcii{Hierauf näherte er sich; kam dann nach unten\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmdccxciii{bis er eine Entfernung von zwei Bogenlängen erreicht hatte oder noch näher.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmdccxciv{Und er offenbarte Seinem Diener, was er offenbarte.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmdccxcv{(Und) dessen Herz hielt es nicht für gelogen, was er sah.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmdccxcvi{Wollt ihr da mit ihm über das streiten, was er sah?\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmdccxcvii{Und er sah ihn bei einer anderen Begegnung\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmdccxcviii{beim Lotusbaum am äußersten Ende\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmdccxcix{an dem das Paradies der Geborgenheit liegt.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmdccc{Dabei überflutete den Lotusbaum, was (ihn) überflutete.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmdccci{Da wankte der Blick nicht, noch schweifte er ab.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmdcccii{Wahrlich, er hatte eines der größten Zeichen seines Herrn gesehen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmdccciii{Was haltet ihr nun von Al-Lat und AI-`Uzza\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmdccciv{und Manah, der dritten der anderen?\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmdcccv{Wie? Sollten euch die Knaben zustehen und Ihm die Mädchen?\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmdcccvi{Das wäre wahrhaftig eine unbillige Verteilung.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmdcccvii{Wahrlich, es sind nur die Namen, die ihr euch ausgedacht habt ihr und eure Väter -, für die Allah keinerlei Ermächtigung hinabgesandt hat. Sie folgen einem bloßen Wahn und ihren persönlichen Neigungen, obwohl doch die Weisung ihres Herrn zu ihnen kam.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmdcccviii{Kann der Mensch denn haben, was er nur wünscht?\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmdcccix{Aber Allahs ist das Diesseits und das Jenseits.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmdcccx{Und so mancher Engel ist in den Himmeln, dessen Fürsprache nichts nützen wird, es sei denn, nachdem Allah dem die Erlaubnis (dazu) gegeben hat, dem Er will und der Ihm beliebt.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmdcccxi{Solche, die nicht an das Jenseits glauben, benennen die Engel mit weiblichen Namen.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmdcccxii{Jedoch sie besitzen kein Wissen hiervon. Sie gehen nur Vermutungen nach; und Vermutungen ersetzen nicht im geringsten die Wahrheit.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmdcccxiii{Darum wende dich von dem ab, der Unserer Ermahnung den Rücken kehrt und nichts als das Leben in dieser Welt begehrt.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmdcccxiv{Das ist die Summe ihres Wissens. Wahrlich, dein Herr kennt denjenigen recht wohl, der von Seinem Wege abirrt, und Er kennt auch jenen wohl, der den Weg befolgt.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmdcccxv{Und Allahs ist, was in den Himmeln und was auf Erden ist, auf daß Er denen, die Böses tun, ihren Lohn für das gebe, was sie gewirkt haben; und auf daß Er die, die Gutes tun, mit dem Allerbesten belohne.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmdcccxvi{Jene, die die großen Sünden und Schändlichkeiten meiden - mit Ausnahme der Lappalien - wahrlich, dein Herr ist von weitumfassender Vergebung. Er kennt euch sehr wohl; als Er euch aus der Erde hervorbrachte, und als ihr Embryos in den Leibern eurer Mütter waret. Darum erklärt euch nicht selber als rein. Er kennt diejenigen am besten, die (Ihn) fürchten.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmdcccxvii{Siehst du den, der sich abkehrt\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmdcccxviii{und wenig gibt und geizt?\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmdcccxix{Hat er wohl die Kenntnis des Verborgenen, so daß er es sehen könnte?\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmdcccxx{Oder ist ihm nicht erzählt worden, was in den Schriftblättern Moses' steht\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxi{und Abrahams, der (die Gebote) erfüllte?\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxii{(Geschrieben steht,) daß keine lasttragende (Seele) die Last einer anderen tragen soll\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxiii{und daß dem Menschen nichts anderes zuteil wird als das, wonach er strebt\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxiv{und daß sein Streben bald sichtbar wird.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxv{Dann wird er dafür mit reichlichem Lohn belohnt werden.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxvi{Und (es steht geschrieben,) daß es bei deinem Herrn enden wird\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxvii{und daß Er es ist, Der zum Lachen und Weinen bringt\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxviii{und daß Er es ist, Der sterben läßt und lebendig macht\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxix{und daß Er die Paare (als) männliche und weibliche (Wesen) erschaffen hat\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxx{aus einem Samentropfen, der ausgestoßen wird\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxxi{und daß Ihm die zweite Schöpfung obliegt\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxxii{und daß Er allein reich und arm macht\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxxiii{und daß Er der Herr des Sirius ist\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxxiv{und daß Er die einstigen `Ad vernichtete\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxxv{und die Tamud, und keinen verschonte\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxxvi{und (daß Er) vordem das Volk Noahs (vernichtete) - wahrlich, sie waren höchst ungerecht und widerspenstig.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxxvii{Und Er ließ die verderbten Städte einstürzen\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxxviii{so daß sie bedeckte, was (sie) bedeckte.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmdcccxxxix{Welche Wohltaten deines Herrn willst du denn bestreiten?\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmdcccxl{Dies ist ein Warner wie die früheren Warner.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmdcccxli{Die Stunde naht.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmmdcccxlii{Keiner außer Allah kann sie abwenden.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmmdcccxliii{Wundert ihr euch über diese Verkündigung?\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmmdcccxliv{Und ihr lacht; aber Weinen tut ihr nicht?\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmmdcccxlv{Und wollt ihr achtlos (hinsichtlich dieser Verkündigung) bleiben?\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmmdcccxlvi{So fallt denn vor Allah anbetend nieder und dient (Ihm).\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmmdcccxlvii{\basmalahde Die Stunde ist nahe gekommen, und der Mond hat sich gespalten.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmdcccxlviii{Doch wenn sie ein Zeichen sehen, wenden sie sich ab und sagen: ``(Dies ist) ein ewiges Zauberwerk."\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmdcccxlix{Und sie leugnen und folgen ihren Gelüsten. Doch alles steht endgültig fest.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmdcccl{Und zu ihnen kamen schon einige Geschichten, die abschreckende Warnungen enthalten\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmdcccli{- vollendete Weisheit; allein selbst die Warnungen richteten (bei ihnen) nichts aus\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmdccclii{Darum wende dich von ihnen ab. Am Tage, an dem der Rufer (sie) zu schlimmem Geschehen rufen wird\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmdcccliii{werden sie mit niedergeschlagenen Blicken aus den Gräbern hervorkommen, als wären sie weithin zerstreute Heuschrecken\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmdcccliv{(und) hasten dem Rufer entgegen. Die Ungläubigen werden sagen: ``Das ist ein schrecklicher Tag."\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmdccclv{Vor ihnen schon leugnete das Volk Noahs; ja, sie leugneten Unseren Diener und sagten: ``(Er ist) ein Besessener." Und er war eingeschüchtert.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmdccclvi{Da betete er zu seinem Herrn: ``lch bin überwältigt, so hilf Du (mir)"\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmdccclvii{So öffneten Wir denn die Tore des Himmels dem strömenden Wasser\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmdccclviii{und aus der Erde ließen Wir Quellen hervorsprudeln; so vereinigte sich das Wasser zu einem beschlossenen Zweck.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmdccclix{Und Wir trugen ihn auf einem Gefüge aus Planken und Nägeln.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmdccclx{Es trieb unter Unserer Aufsicht dahin, als Belohnung für denjenigen, der Undank geerntet hatte.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmdccclxi{Und Wir machten es zu einem Zeichen. Gibt es also einen, der daraus eine Lehre zieht?\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmdccclxii{Wie war denn Meine Strafe und Meine Warnung?\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmdccclxiii{Und wahrlich, Wir haben den Quran zur Ermahnung leicht gemacht. Gibt es also einen, der ermahnt sein mag?\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmdccclxiv{Die `Ad verleugneten (die Warner) Wie war denn Meine Strafe und Meine Warnung?\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmdccclxv{Wir sandten gegen sie an einem unheilvollen Tag einen eiskalten Sturmwind, (der) ununterbrochen wütete.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmdccclxvi{Er raffte die Menschen dahin, als wären sie Stämme schon entwurzelter Palmen.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmdccclxvii{Wie war denn Meine Strafe und Meine Warnung?\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmdccclxviii{Und wahrlich, Wir haben den Quran zur Ermahnung leicht gemacht. Gibt es also einen, der ermahnt sein mag?\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmdccclxix{Die Tamud verleugneten die Warner\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmdccclxx{und sie sagten: ``Wie? Einem Menschen aus unserer Mitte, einem einzelnen sollen wir folgen? Dann befänden wir uns wahrlich im Irrtum und in brennender Pein.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxi{Ist die Ermahnung ihm (allein) von uns allen gegeben worden? Nein, er ist ein unverschämter Lügner."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxii{``Morgen werden sie erfahren, wer der unverschämte Lügner ist!\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxiii{Wir werden die Kamelstute als eine Prüfung für sie schicken. Darum beobachte sie und harre in Geduld aus.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxiv{Und verkünde ihnen, daß das Wasser zwischen ihnen geteilt ist, (also) soll jede Trinkzeit eingehalten werden."\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxv{Doch sie riefen ihren Gefährten, und er packte (sie) und schnitt (ihr) die Sehnen durch.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxvi{Wie war also Meine Strafe und Meine Warnung?\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxvii{Wahrlich, Wir entsandten einen einzigen Schrei auf sie, und sie wurden wie dürre, zertretene Stoppeln.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxviii{Und wahrlich, Wir haben den Quran zur Ermahnung leicht gemacht. Gibt es also einen, der ermahnt sein mag?\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxix{Das Volk Lots verleugnete die Warner.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxx{Da sandten Wir einen Steinregen über sie; ausgenommen (davon war) die Familie Lots, die Wir vor dem Morgengrauen erretteten\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxxi{als eine Gnade von Uns. So belohnen Wir den, der dankbar ist.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxxii{Und er hatte sie in der Tat vor Unserer Strafe gewarnt, sie aber stritten mit den Warnern.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxxiii{Und sie versuchten ihn zu überreden, ihnen seine Gäste auszuliefern. Daher blendeten Wir ihre Augen (und sprachen): ``Kostet nun Meine Strafe und Meine Warnung."\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxxiv{Und in der Morgenfrühe ereilte sie eine dauernde Strafe.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxxv{``So kostet nun Meine Strafe und Meine Androhung."\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxxvi{Und wahrlich, Wir haben den Quran zur Ermahnung leicht gemacht. Gibt es also einen, der ermahnt sein mag?\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxxvii{Und zu dem Volke Pharaos kamen (ebenfalls) die Warner.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxxviii{Sie aber hielten all Unsere Zeichen für Lügen; darum erfaßten Wir sie mit dem Griff eines Erhabenen, Allmächtigen.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmdccclxxxix{Sind die Ungläubigen unter euch etwa besser als jene? Oder habt ihr in den Schriften einen Freibrief?\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmdcccxc{Oder sagen sie etwa: ``Wir sind allesamt eine siegreiche Schar?"\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmdcccxci{Die Scharen werden alle besiegt werden, und sie werden in die Flucht geschlagen.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmdcccxcii{Nein, die Stunde ist ihr Termin; und die Stunde ist noch unheilvoller und bitterer.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmdcccxciii{Wahrlich, die Schuldigen befinden sich im Irrtum und in brennender Pein.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmdcccxciv{Am Tage, wo sie auf ihren Ge sichtern ins Feuer geschleift werden(, heißt es): ``Fühlt die Berührung der Saqar."\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmdcccxcv{Wir haben jedoch ein jegliches Ding nach (rechtem) Maß geschaffen.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmdcccxcvi{Und Unser Befehl gleicht einem einzigen Akt - (so schnell) wie ein (einziger) Augenblick.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmdcccxcvii{Und Wir haben bereits Leute wie euch vertilgt. Doch gibt es (wenigstens) einen, der ermahnt sein mag?\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmdcccxcviii{Und alles, was sie getan haben, steht in den Büchern.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmdcccxcix{Und alles Kleine und Große ist niedergeschrieben.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmcm{Wahrlich, die Gottesfürchtigen sind inmitten von Gärten an Bächen\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmcmi{in einem würdigen Wohnsitz in der Gegenwart eines Mächtigen Königs.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmcmii{\basmalahde Der Allerbarmer\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmcmiii{hat den Quran gelehrt.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmcmiv{Er hat den Menschen erschaffen.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmcmv{Er hat ihm das deutliche Reden beigebracht.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmcmvi{Die Sonne und der Mond kreisen nach einer festgesetzten Berechnung.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmcmvii{Und die Sterne und Bäume fallen (vor Ihm) anbetend nieder.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmcmviii{Und den Himmel hat Er emporgehoben. Und Er hat das (richtige) Abwiegen zum Gebot gemacht\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmcmix{auf daß ihr euch in der Waage nicht vergeht.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmcmx{so setzt das Gewicht in gerechter Weise und betrügt nicht beim Wiegen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmcmxi{Und Er hat die Erde für die Geschöpfe bereitet\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmcmxii{auf ihr sind Früchte und Palmen mit Fruchthüllen\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmcmxiii{und Korn auf Halmen und duftende Pflanzen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmcmxiv{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmcmxv{Er hat den Menschen aus Ton erschaffen, gleich einer Töpferware.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmcmxvi{Und die Ginn schuf Er aus rauchloser Feuerflamme.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmcmxvii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmcmxviii{(Er ist) der Herr der beiden Osten und der Herr der beiden Westen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmcmxix{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmcmxx{Er hat den beiden Gewässern, die einander begegnen, freien Lauf gelassen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmcmxxi{Zwischen ihnen steht eine Scheidewand, so daß sie nicht ineinander übergreifen.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmcmxxii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmcmxxiii{Perlen kommen aus beiden hervor und Korallen.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmcmxxiv{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmcmxxv{Und Sein sind die hochragenden Schiffe auf dem Meer, gleich Berge.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmcmxxvi{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmcmxxvii{Alles, was auf (Erden) ist, wird vergehen.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmcmxxviii{Aber das Angesicht deines Herrn bleibt bestehen - des Herrn der Majestät und der Ehre.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmcmxxix{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmcmxxx{Ihn bitten alle, die in den Himmeln und auf Erden sind. Er ist tagtäglich in jeglichem Einsatz.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmcmxxxi{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmcmxxxii{Bald aber werden Wir Uns um euch kümmern, ihr beiden Gewichtigen!\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmcmxxxiii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmcmxxxiv{O Wesen der Ginn und der Menschen! Wenn ihr imstande seid, die Grenzen der Himmel und der Erde zu durchdringen, dann dringt hindurch. Doch ihr werdet nicht imstande sein durchzudringen, es sei denn mit der Macht (eures Herrn)\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmcmxxxv{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmcmxxxvi{Entsandt werden soll gegen euch eine lodernde Flamme aus Feuer und Kupfer; dann werdet ihr beide euch nicht zu helfen wissen.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmcmxxxvii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmcmxxxviii{Und wenn der Himmel sich spaltet und so geworden ist wie eine Rose, gleich rotem Leder.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmcmxxxix{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmcmxl{An jenem Tage werden weder Menschen noch Ginn nach ihren Sünden befragt.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmcmxli{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmcmxlii{Die Schuldigen werden an ihren Merkmalen erkannt werden, und sie werden an ihren Stirnlocken und Füßen erfaßt werden.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmcmxliii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmcmxliv{Das ist Gahannam, die die Schuldigen leugnen.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmcmxlv{Zwischen ihr und siedend heißem Wasser werden sie die Runde machen.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmcmxlvi{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmcmxlvii{Und dem aber, der sich vor der Gegenwart seines Herrn fürchtet, werden zwei Gärten zuteil sein.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmcmxlviii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmcmxlix{In beiden (Gärten) wachsen vielerlei Bäume.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmcml{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmcmli{In beiden (Gärten) fließen zwei Quellen.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmcmlii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmcmliii{Darin wird es von jeglicher Fruchtart zwei Arten geben.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmcmliv{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmcmlv{Sie ruhen auf Kissen, die mit Brokat gefüttert sind. Und die Früchte der beiden Gärten sind nahe zur Hand.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmcmlvi{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmcmlvii{Darin sind (keusche Mädchen) mit züchtigem Blick, die weder Menschen noch Ginn vor ihnen berührt haben.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmcmlviii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmmcmlix{(Es scheint,) als wären sie (die Mädchen) Rubine und Korallen.\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmmcmlx{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmmcmlxi{Kann der Lohn für Güte (etwas) anderes sein als Güte.\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmmcmlxii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmmcmlxiii{Und neben diesen beiden gibt es noch zwei (andere) Gärten.\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmmcmlxiv{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmmcmlxv{(Es sind Gärten) mit dunkelgrünem Blattwerk.\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmmcmlxvi{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmmcmlxvii{Darin fließen zwei Quellen, die reichlich Wasser spenden.\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmmcmlxviii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmmcmlxix{In beiden (Gärten) sind Früchte und Dattelpalmen und Granatäpfel.\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmmcmlxx{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxi{Darin sind gute und schöne (Mädchen)\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxiii{(Es sind) Huris, wohlbehütet in Zelten.\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxiv{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxv{Vor ihnen haben weder Menschen noch Ginn sie (die Mädchen) berührt.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxvi{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxvii{Sie ruhen auf grünen Kissen und schönen Teppichen.\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxviii{Welche der Wohltaten eures Herrn wollt ihr beide da leugnen?\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxix{Segensreich ist der Name deines Herrn, des Herrn der Majestät und Ehre.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxx{\basmalahde Wenn das Ereignis eintrifft\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxxi{gibt es keinen, der sein Eintreffen verleugnen könnte.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxxii{Dann wird es (die einen) erniedrigen, (andere) wird es erhöhen.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxxiii{Wenn die Erde heftig geschüttelt wird\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxxiv{und die Berge gänzlich zerbröckelt werden\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxxv{dann sollen sie zu weithin zerstreutem Staub werden.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxxvi{Und ihr sollt in drei Gattungen (gegliedert) werden\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxxvii{(In) die zur Rechten was (wißt ihr) von denen die zur Rechten sein werden?\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxxviii{Und (in) die zur Linken - was (wißt ihr) von denen, die zur Linken sein werden.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmcmlxxxix{Und (in) die Vordersten - (sie) werden die Vordersten sein.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmcmxc{Das sind die, die Allah nahe sein werden\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmcmxci{in den Gärten der Wonne.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmcmxcii{(Dies sind) eine große Schar der Früheren\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmcmxciii{und einige wenige der Späteren.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmcmxciv{Auf Polstern, die mit Gold durchwoben sind\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmcmxcv{lehnen (sie) auf diesen einander gegenüber.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmcmxcvi{Bedient werden sie von Jünglingen, die nicht altern\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmcmxcvii{mit Bechern und Krü gen aus einer fließenden Quelle.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmcmxcviii{Keinen Kopfschmerz werden sie davon bekommen, noch werden sie das Bewußtsein verlieren.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmcmxcix{Und Früchte, die sie sich wünschen\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmm{und Fleisch vom Geflügel, das sie begehren\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmi{und Huris\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmii{wohlbehüteten Perlen gleich\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmiii{(werden sie erhalten) als Belohnung für das, was sie zu tun pflegten.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmiv{Sie werden dort weder leeres Gerede noch Anschuldigung der Sünde hören\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmv{nur das Wort: ``Frieden, Frieden!"\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmvi{Und die zur Rechten - was (wißt ihr) von denen, die zur Rechten sein werden?\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmvii{(Sie werden) unter dornlosen Lotusbäumen (sein)\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmviii{und gebüschelten Bananen\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmix{und endlosem Schatten\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmx{bei fließendem Wasser\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmxi{und vielen Früchten\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmxii{die weder zu Ende gehen, noch für verboten erklärt werden\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmxiii{und auf erhöhten Ruhekissen.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmxiv{Wir haben sie (die Huris) in herrlicher Schöpfung gestaltet\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmxv{und sie zu Jungfrauen gemacht\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmxvi{zu liebevollen Altersgenossinnen\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmxvii{derer zur Rechten.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmxviii{(Dies sind) eine große Schar der Früheren\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmxix{und eine große Schar der Späteren.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmxx{Und die zur Linken - was (wißt ihr) von denen, die zur Linken sein werden?\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmmxxi{(Sie werden) inmitten von glühenden Winden und siedendem Wasser (sein)\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmmxxii{und im Schatten schwarzen Rauches\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmmxxiii{der weder kühl noch erfrischend ist.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmmxxiv{Vor diesem (Schicksal) wurden sie in der Tat mit Wohlleben verwöhnt\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmmxxv{und (sie) verharrten in großer Sünde.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmmxxvi{Und sie pflegten zu sagen: ``Wie? Wenn wir tot sind und zu Staub und Gebeinen geworden sind, dann sollen wir wirklich auferweckt werden?\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmmxxvii{Und unsere Vorväter auch?"\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmmxxviii{Sprich: ``Wahrlich, die Früheren und die Späteren\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmmxxix{werden alle zur gesetzten Frist eines bestimmten Tages versammelt werden.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmmxxx{Dann, o ihr Irregegangenen und Leugner\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmmxxxi{sollt ihr vom Baume Zaqqum essen\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmmxxxii{und damit eure Bäuche füllen\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmmxxxiii{und darauf von sie dendem Wasser trinken.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmmxxxiv{Dann trinkt (ihr,) wie die durstigen Kamele trinken."\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmmxxxv{Das wird ihre Bewirtung am Tage des Gerichts sein.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmmxxxvi{Wir haben euch erschaffen. Warum wollt ihr da nicht die Wahrheit zugeben.\qt@no{(57)}}
\qt@newcmd\qurantrans@de@mmmmmxxxvii{Habt ihr betrachtet, was euch an Sperma entfließt?\qt@no{(58)}}
\qt@newcmd\qurantrans@de@mmmmmxxxviii{Erschafft ihr es oder sind Wir die Schöpfer?\qt@no{(59)}}
\qt@newcmd\qurantrans@de@mmmmmxxxix{Wir haben für euch den Tod verordnet, und Wir sind nicht unfähig dazu\qt@no{(60)}}
\qt@newcmd\qurantrans@de@mmmmmxl{an eurer Stelle andere wie euch hervorzubringen und euch in einen Zustand zu versetzen, den ihr nicht kennt.\qt@no{(61)}}
\qt@newcmd\qurantrans@de@mmmmmxli{Und ihr kennt doch gewiß die erste Schöpfung. Warum also wollt ihr euch nicht besinnen?\qt@no{(62)}}
\qt@newcmd\qurantrans@de@mmmmmxlii{Habt ihr betrachtet, was ihr aussät?\qt@no{(63)}}
\qt@newcmd\qurantrans@de@mmmmmxliii{Seid ihr es, die es wachsen lassen, oder lassen Wir es wachsen?\qt@no{(64)}}
\qt@newcmd\qurantrans@de@mmmmmxliv{Wollten Wir, könnten Wir es in brüchiges Zeug verwandeln; dann würdet ihr nicht aufhören, euch zu beklagen\qt@no{(65)}}
\qt@newcmd\qurantrans@de@mmmmmxlv{`` Wir sind zugrunde gerichtet!\qt@no{(66)}}
\qt@newcmd\qurantrans@de@mmmmmxlvi{Nein, wir sind beraubt."\qt@no{(67)}}
\qt@newcmd\qurantrans@de@mmmmmxlvii{Habt ihr das Was ser betrachtet, das ihr trinkt?\qt@no{(68)}}
\qt@newcmd\qurantrans@de@mmmmmxlviii{Seid ihr es, die es aus den Wolken niedersenden, oder sind Wir es, die es niedersenden?\qt@no{(69)}}
\qt@newcmd\qurantrans@de@mmmmmxlix{Wollten Wir, könnten Wir es bittersalzig machen. Warum also dankt ihr (Mir) nicht?\qt@no{(70)}}
\qt@newcmd\qurantrans@de@mmmmml{Habt ihr das Feuer betrachtet, das ihr entzündet?\qt@no{(71)}}
\qt@newcmd\qurantrans@de@mmmmmli{Seid ihr es, die den Baum dazu hervorbrachten, oder sind Wir dessen Urheber?\qt@no{(72)}}
\qt@newcmd\qurantrans@de@mmmmmlii{Wir haben das (Feuer) zur Ermahnung (vor der Hölle) erschaffen und zum Nutzen für die Wanderer durch die Wildnisse.\qt@no{(73)}}
\qt@newcmd\qurantrans@de@mmmmmliii{Darum preise den Namen deines Großen Herrn.\qt@no{(74)}}
\qt@newcmd\qurantrans@de@mmmmmliv{Ich schwöre bei den Stationen der Sterne -\qt@no{(75)}}
\qt@newcmd\qurantrans@de@mmmmmlv{und wahrlich, das ist ein großer Schwur, wenn ihr es nur wüßtet\qt@no{(76)}}
\qt@newcmd\qurantrans@de@mmmmmlvi{daß dies wahrlich ein edler Quran ist\qt@no{(77)}}
\qt@newcmd\qurantrans@de@mmmmmlvii{in einer wohlaufbewahrten Urschrift.\qt@no{(78)}}
\qt@newcmd\qurantrans@de@mmmmmlviii{Keiner kann sie berühren, außer den Reinen.\qt@no{(79)}}
\qt@newcmd\qurantrans@de@mmmmmlix{(Sie ist) eine Offenbarung vom Herrn der Welten.\qt@no{(80)}}
\qt@newcmd\qurantrans@de@mmmmmlx{Wollt ihr denn gegenüber dieser Verkündigung undankbar sein?\qt@no{(81)}}
\qt@newcmd\qurantrans@de@mmmmmlxi{Und daß ihr (sie) leugnet, soll das euer Dank sein?\qt@no{(82)}}
\qt@newcmd\qurantrans@de@mmmmmlxii{Warum wohl, wenn (die Seele des Sterbenden) zur Kehle steigt\qt@no{(83)}}
\qt@newcmd\qurantrans@de@mmmmmlxiii{und ihr in jenem Augenblick zuschaut?\qt@no{(84)}}
\qt@newcmd\qurantrans@de@mmmmmlxiv{Und Wir sind ihm näher als ihr, nur daß ihr es nicht seht.\qt@no{(85)}}
\qt@newcmd\qurantrans@de@mmmmmlxv{Warum wohl, wenn ihr nicht zur Re chenschaft gezogen werden sollt?\qt@no{(86)}}
\qt@newcmd\qurantrans@de@mmmmmlxvi{Zwingt ihr sie nicht zurück (in den Leib), wenn ihr wahrhaftig seid?\qt@no{(87)}}
\qt@newcmd\qurantrans@de@mmmmmlxvii{Wenn er nun zu denen gehört, die (Allah) nahe sind\qt@no{(88)}}
\qt@newcmd\qurantrans@de@mmmmmlxviii{dann (wird er) Glückseligkeit (genießen) und Düfte und Gärten der Wonne.\qt@no{(89)}}
\qt@newcmd\qurantrans@de@mmmmmlxix{Und wenn er zu denen gehört, die zur Rechten sind\qt@no{(90)}}
\qt@newcmd\qurantrans@de@mmmmmlxx{(wird ein) ``Friede sei auf dir" von denen, die der Rechten angehö ren(, zugerufen).\qt@no{(91)}}
\qt@newcmd\qurantrans@de@mmmmmlxxi{Wenn er aber zu den Leugnern, Irregegangenen gehört\qt@no{(92)}}
\qt@newcmd\qurantrans@de@mmmmmlxxii{dann (wird ihm) eine Bewirtung mit siedendem Wasser zuteil\qt@no{(93)}}
\qt@newcmd\qurantrans@de@mmmmmlxxiii{und Brennen in der Gahim.\qt@no{(94)}}
\qt@newcmd\qurantrans@de@mmmmmlxxiv{Wahrlich, dies ist die Wahrheit in aller Gewißheit.\qt@no{(95)}}
\qt@newcmd\qurantrans@de@mmmmmlxxv{Lobpreise darum den Namen deines Großen Herrn.\qt@no{(96)}}
\qt@newcmd\qurantrans@de@mmmmmlxxvi{\basmalahde Es preist Allah, was in den Himmeln und was auf der Erde ist, und Er ist der Erhabene, der Allweise.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmlxxvii{Sein ist das Königreich der Himmel und der Erde. Er macht lebendig und läßt sterben, und Er hat Macht über alle Dinge.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmlxxviii{Er ist der Erste und der Letzte, der Sichtbare und der Verborgene, und Er ist der Kenner aller Dinge.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmlxxix{Er ist es, Der die Himmel und die Erde in sechs Tagen erschuf, dann wandte Er Sich majestätisch Seinem Reich zu. Er weiß, was in die Erde eingeht und was aus ihr hervorkommt, was vom Himmel herniederkommt und was zu ihm aufsteigt. Und Er ist mit euch, wo immer ihr (auch) sein möget. Und Allah sieht alles, was ihr tut.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmlxxx{Sein ist das Königreich der Himmel und der Erde; und zu Allah werden alle Dinge zurückgebracht.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmlxxxi{Er läßt die Nacht in den Tag und den Tag in die Nacht eintreten; und Er ist der Kenner all dessen, was (ihr) in den Herzen hegt.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmlxxxii{Glaubt an Allah und Seinen Gesandten und spendet von dem, zu dessen Erben Er euch gemacht hat. Und jenen von euch, die glauben und spenden, wird ein großer Lohn zuteil sein.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmlxxxiii{Was ist euch, daß ihr nicht an Allah glaubt, obwohl der Gesandte euch aufruft, an euren Herrn zu glauben; und Er hat von euch bereits ein Versprechen abgenommen, wenn ihr Gläubige seid.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmlxxxiv{Er ist es, Der deutliche Zeichen auf Seinen Diener hinabsendet, auf daß Er euch aus den Finsternissen ins Licht führe. Und wahrlich, Allah ist gegen euch Gnädig, Barmherzig.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmlxxxv{Was ist euch, daß ihr nicht für Allahs Sache spendet, obwohl die Erbschaft der Himmel und der Erde Allah gehört? Es sind nicht gleich diejenigen unter euch, die spendeten und kämpften vor dem Sieg. Sie stehen höher im Rang als jene, die erst nachher spendeten und kämpften. Allen aber verhieß Allah Gutes. Und Allah ist dessen wohl kundig, was ihr tut.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmlxxxvi{Wer ist es, der Allah ein gutes Darlehen geben will? Er wird es ihm um ein Vielfaches mehren, und ihm wird ein würdiger Lohn zuteil sein.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmlxxxvii{Am Tage, da du die gläubigen Männer und die gläubigen Frauen sehen wirst, während (die Strahlen) ihres Lichts vor ihnen und zu ihrer Rechten hervorbrechen (heißt es): ``Eine frohe Botschaft (sei) euch heute (beschieden)! In den Gärten, durch die Bäche fließen, werdet ihr auf ewig weilen. Das ist der gewaltige Gewinn."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmlxxxviii{Am Tage, wenn die Heuchler und die Heuchlerinnen zu den Gläubigen sagen werden: ``Wartet auf uns! Wir wollen ein wenig von eurem Lichtstrahl bekommen", da wird (zu ihnen) gesprochen werden: ``Kehrt zurück und sucht (dort) Licht." Dann wird zwischen ihnen eine Mauer mit einem Tor darin errichtet werden. Innerhalb davon befindet sich die Barmherzigkeit und außerhalb davon die Strafe.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmlxxxix{Sie werden jenen (Gläubigen) zurufen: ``Waren wir nicht mit euch?" Jene werden sagen: ``Doch, aber ihr versuchtet euch selber und wartetet und zweifeltet, und es betörten euch die eitlen Wünsche, bis Allahs Befehl kam. Und der Betörer hat euch über Allah betört.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmxc{So soll heute kein Lösegeld angenommen werden weder von euch noch von den Ungläubigen. Eure Herberge ist das Feuer; es ist euer Schutzspender. Und eine schlimme Bestimmung ist das!"\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmxci{Ist nicht für die Gläubigen die Zeit gekommen, ihre Herzen zu demütigen vor der Ermahnung Allahs und vor der Wahrheit, die herabkam, und nicht so zu werden wie jene, denen zuvor die Schrift gegeben wurde und denen es zu lange dauerte, so daß ihre Herzen verstockt und viele von ihnen zu Frevlern wurden?\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmxcii{Wisset, daß Allah die Erde nach ihrem Tode belebt. Wahrlich, Wir haben euch die Zeichen klar gemacht, auf daß ihr (sie) begreifen möget.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmxciii{Wahrlich, die mildtätigen Männer und die mildtätigen Frauen und jene, die Allah ein gutes Darlehen geben - es wird ihnen um ein Vielfaches gemehrt, und ihnen wird ein würdiger Lohn zuteil sein.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmxciv{Und diejenigen, die an Allah und Seine Gesandten glauben, sind die Wahrhaftigen und die Bezeugenden vor ihrem Herrn; sie werden ihren Lohn und ihr Licht empfangen. Diejenigen aber, die ungläubig sind und Unsere Zeichen leugnen, sind die Insassen der Gahim.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmxcv{Wisset, daß wahrlich das diesseitige Leben nur ein Spiel und ein Zeitvertreib ist und ein Prunk und Geprahle unter euch und ein Wettrennen um Vermehrung von Gut und Kindern. Es gleicht dem reichlichen Regen, dessen Pflanzenwuchs den Säern gefällt. Dann verdorrt er; und du siehst ihn vergilben; hierauf wird er brüchig; und im Jenseits gibt es eine strenge Strafe, aber auch Vergebung von Allah und Wohlgefallen. Und das diesseitige Leben ist nichts anderes als eine Nutznießung, durch die man sich betören läßt.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmxcvi{Wetteifert denn miteinander um die Vergebung eures Herrn und um das Paradies, dessen Größe gleich der Größe des Himmels und der Erde ist. (Es ist für) jene bereitet, die an Allah und Seine Gesandten glauben. Das ist Allahs Huld; Er gewährt sie, wem Er will. Und Allah verfügt über die große Huld.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmxcvii{Es geschieht kein Unheil auf Erden oder an euch, das nicht in einem Buch (verzeichnet) wäre, bevor Wir es ins Dasein rufen wahrlich, das ist für Allah ein leichtes -\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmxcviii{auf daß ihr euch nicht darüber betrüben möget, was euch entging, noch darüber frohlocken möget, was Er euch gegeben hat. Und Allah liebt keinen der eingebildeten Prahler\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmxcix{die geizig sind und die Menschen zum Geiz anhalten. Und wer da den Rücken wendet - siehe, Allah ist dann gewiß Der, Der auf keinen angewiesen, des Lobes Würdig ist.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmc{Wahrlich, Wir schickten Unsere Gesandten mit klaren Beweisen und sandten mit ihnen das Buch und die Waagewerte herab, auf daß die Menschen Gerechtigkeit üben mögen. Und Wir schufen das Eisen, worin (Kraft zu) gewaltigem Krieg wie auch zu (vielerlei) Nutzen für die Menschheit ist, damit Allah die bezeichne, die Ihm und Seinem Gesandten, wenngleich ungesehen, beistehen. Wahrlich, Allah ist Allmächtig, Erhaben.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmci{Und Wir entsandten ja auch Noah und Abraham und verbreiteten unter ihren Nachkommen das Prophetentum und die Schrift. Einige von ihnen waren auf dem rechten Weg, doch viele von ihnen waren Frevler.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmcii{Dann ließen Wir Unsere Gesandten ihren Spuren folgen; und Wir ließen (ihnen) Jesus, den Sohn der Maria, folgen, und Wir gaben ihm das Evangelium. Und in die Herzen derer, die ihm folgten, legten Wir Güte und Barmherzigkeit. Doch das Mönchtum, das sie im Trachten nach Allah s Wohlgefallen erfanden - das schrieben Wir ihnen nicht vor; und doch befolgten sie es nicht auf die richtige Art. Dennoch gaben Wir denen von ihnen, die gläubig waren, ihren Lohn, aber viele von ihnen waren Frevler.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmciii{O ihr, die ihr glaubt, fürchtet Allah und glaubt an Seinen Gesandten! Er wird euch einen doppelten Anteil von Seiner Barmherzigkeit geben und wird euch ein Licht bereiten, worin ihr wandeln werdet, und wird euch vergeben - und Allah ist Allvergebend, Barmherzig\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmciv{damit die Leute der Schrift nicht meinen, daß sie (die Muslime) nicht imstande seien, die Huld Allahs zu erlangen, und (damit sie wissen), daß die Huld in Allahs Hand ist, auf daß Er sie verleihe, wem Er will. Und Allah verfügt über die große Huld.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmcv{\basmalahde Allah hat doch das Wort jener gehört, die mit dir wegen ihres Mannes stritt und sich vor Allah beklagte. Und Allah hat euer Gespräch gehört. Wahrlich, Allah ist Allhörend, Allsehend.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcvi{Diejenigen von euch, die sich von ihren Frauen scheiden, indem sie sagen: ``Du bist mir (verboten) wie der Rücken meiner Mutter", (irren; denn) ihre Mütter sind sie nicht; ihre Mütter sind einzig jene, die sie geboren haben; und sie äußern da nur Worte, die unziemlich und unwahr sind; doch wahrlich, Allah ist Tilger der Sünden, Allvergebend.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcvii{Und jene nun, die ihre Frauen Mütter nennen und dann zurücknehmen möchten, was sie gesagt haben - (die Buße dafür) ist die Befreiung eines Sklaven, bevor sie einander berühren. Dies (wird euch gesagt), um euch zu ermahnen. Und Allah ist dessen wohl kundig, was ihr tut.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcviii{Wer aber keine Möglichkeit (zur Freilassung eines Sklaven) findet, (soll) dann zwei Monate hintereinander fasten, bevor sie einander berühren. Und wer es nicht vermag, (soll) dann sechzig Arme speisen. Dies (soll so sein), damit ihr an Allah und Seinen Gesandten glaubt. Das sind die Schranken Allahs; und den Ungläubigen wird eine qualvolle Strafe zuteil sein.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcix{Wahrlich, diejenigen, die sich Allah und Seinem Gesandten widersetzen, werden gewiß erniedrigt werden, eben wie die vor ihnen erniedrigt wurden; und wahrlich, Wir haben bereits deutliche Zeichen herniedergesandt. Und den Ungläubigen wird eine schmähliche Strafe zuteil sein.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcx{Am Tage, an dem Allah sie alle zusammen auferweckt, da wird Er ihnen verkünden, was sie getan haben. Allah hat die Rechnung darüber geführt, wahrend sie es vergaßen. Und Allah ist der Zeuge aller Dinge.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcxi{Siehst du denn nicht, daß Allah alles weiß, was in den Himmeln ist, und alles, was auf Erden ist? Keine geheime Unterredung zwischen dreien gibt es, bei der Er nicht vierter wäre, noch eine zwischen fünfen, bei der Er nicht sechster wäre, noch zwischen weniger oder mehr als diesen, ohne daß Er mit ihnen wäre, wo immer sie sein mögen. Dann wird Er ihnen am Tage der Auferstehung verkünden, was sie getan haben. Wahrlich, Allah ist über alle Dinge Allwissend.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcxii{Hast du nicht die gesehen, denen die geheime Verschwörung verboten worden ist und die doch zu dem zurückkehren, was ihnen verboten worden ist, und sich insgeheim zu Sünde und Übertretung und Ungehorsam gegen den Gesandten verschwören? Und wenn sie zu dir kommen, so begrüßen sie dich mit dem, womit dich Allah nicht begrüßt hat; bei sich aber sagen sie: ``Warum bestraft uns Allah nicht für das, was wir (gegen Ihn) sagen?" Genügend für sie ist Gahannam worin sie brennen werden; und übel ist die Bestimmung!\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcxiii{O ihr, die ihr glaubt, wenn ihr heimlich miteinander redet, so redet nicht in Sünde und Feindseligkeit und Ungehorsam gegen den Gesandten, sondern redet miteinander in Rechtschaffenheit und Gottesfurcht, und fürchtet Allah, vor Dem ihr versammelt werdet.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcxiv{Die geheime Verschwörung rührt allein von Satan her, der die betrüben will, die gläubig sind; doch er kann ihnen nicht den geringsten Schaden zufügen, es sei denn mit Allahs Erlaubnis. Und auf Allah sollen die Gläubigen vertrauen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcxv{O ihr, die ihr glaubt, wenn in Versammlungen zu euch gesagt wird: ``Macht Platz!" dann macht Platz; Allah wird ausgiebig Platz für euch machen. Und wenn gesagt wird: ``Erhebt euch!" - dann erhebt euch; Allah wird die unter euch, die gläubig sind, und die, denen Wissen gegeben wurde, um Rangstufen erhöhen. Und Allah ist dessen wohl kundig, was ihr tut.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcxvi{O ihr, die ihr glaubt, wenn ihr euch mit dem Gesandten vertraulich beraten wollt, so schickt eurer vertraulichen Beratung Almosen voraus. Das ist besser für euch und lauterer. Wenn ihr aber nicht (die Möglichkeit dazu) findet, dann ist Allah wahrlich All verzeihend, Barmherzig.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcxvii{Seid ihr wegen des Gebens von Almosen vor eurer vertraulichen Beratung besorgt? Nun denn, wenn ihr es nicht tut und Allah euch in Seine Barmherzigkeit aufnimmt, dann verrichtet das Gebet und entrichtet die Zakah und gehorcht Allah und Seinem Gesandten. Und Allah ist dessen wohl kundig, was ihr tut.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcxviii{Hast du nicht diejenigen gesehen, die sich ein Volk zu Freunden nehmen, dem Allah zürnt? Sie gehö ren weder zu euch noch zu ihnen, und sie beschwören eine Lüge, und sie sind sich dessen bewußt.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcxix{Allah hat für sie eine strenge Strafe bereitet. Übel ist wahrlich das, was sie zu tun pflegen.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcxx{Sie haben ihre Eide als Schutzbehauptung benutzt, und sie wenden vom Weg Allahs ab; ihnen wird darum eine erniedrigende Strafe zuteil sein.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcxxi{Weder ihre Reichtümer noch ihre Kinder werden ihnen im geringsten (etwas) gegen Allah nützen. Sie sind die Bewohner des Feuers; darin müssen sie ewig bleiben.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcxxii{Am Tage, wenn Allah sie allesamt versammeln wird, da werden sie Ihm schwören, wie sie euch schwören, und sie werden meinen, sie fußten auf etwas. Wahrlich, sicherlich sind sie es, die zu den Lügnern gehören.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcxxiii{Satan hat sie völlig in die Macht bekommen und hat sie die Ermahnung Allahs vergessen lassen. Sie sind Satans Partei. Wahrlich, Satans Partei ist die verlierende.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcxxiv{Wahrlich, jene, die sich Allah und Seinem Gesandten widersetzen, werden unter den Erniedrigsten sein.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcxxv{Allah hat es vorgeschrieben: Sicherlich werde Ich siegen, Ich und Meine Gesandten. Wahrlich, Allah ist Allmächtig, Erhaben.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcxxvi{Du wirst kein Volk finden, das an Allah und an den Jüngsten Tag glaubt und dabei diejenigen liebt, die sich Allah und Seinem Gesandten widersetzen, selbst wenn es ihre Väter wären oder ihre Söhne oder ihre Brüder oder ihre Verwandten. Das sind diejenigen, in deren Herzen Allah den Glauben eingeschrieben hat und die Er mit Seinem Sieg gestärkt hat. Er wird sie in Gärten führen, durch die Bäche fließen. Darin werden sie auf ewig weilen. Allah ist wohl zufrieden mit ihnen, und sie sind wohl zufrieden mit Ihm. Sie sind Allahs Partei. Wahrlich, Allahs Partei ist die erfolgreiche.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcxxvii{\basmalahde Alles, was in den Himmeln, und alles, was auf Erden ist, preist Allah; und Er ist der Erhabene, der Allweise.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcxxviii{Er ist es, Der diejenigen vom Volke der Schrift, die ungläubig waren, aus ihren Heimstätten zur ersten Versammlung austrieb. Ihr glaubtet nicht, daß sie hinausziehen würden, und sie dachten, daß ihre Burgen sie gegen Allah schützen würden. Doch Allah kam von (dort) über sie, woher sie es nicht erwarteten, und warf Schrecken in ihre Herzen, so daß sie ihre Häuser mit ihren eigenen Händen und den Händen der Gläubigen zerstörten. So zieht eine Lehre daraus, o die ihr Einsicht habt!\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcxxix{Und wäre es nicht gewesen, daß Allah für sie die Verbannung angeordnet hätte, hätte Er sie sicher in (dieser) Welt bestraft; und im Jenseits wird ihnen die Strafe des Feuers zuteil sein.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcxxx{Dies (geschieht), weil sie sich Allah und Seinem Gesandten widersetzten; und wer sich Allah widersetzt - wahrlich, dann ist Allah streng im Strafen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcxxxi{Was ihr an Palmen umgehauen habt oder auf Wurzeln stehen ließet - es geschah mit Allahs Erlaubnis und (deswegen,) damit Er die Übertreter in Schmach stürzen ließ.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcxxxii{Und was Allah Seinem Gesandten als Beute von ihnen gegeben hat - ihr brauchtet weder Pferde noch Kamele dazu aufzubieten; aber Allah gibt Seinen Gesandten Gewalt über wen Er will; und Allah hat Macht über alle Dinge.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcxxxiii{Was Allah Seinem Gesandten gegeben hat, das ist für Allah und für den Gesandten und für die Verwandten und die Waisen und die Armen und den Sohn des Weges, damit es nicht nur bei den Reichen unter euch umläuft. Und was euch der Gesandte gibt, das nehmt an; und was er euch untersagt, dessen enthaltet euch. Und fürchtet Allah; wahrlich, Allah ist streng im Strafen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcxxxiv{(Dies ist) für die armen Auswanderer, die aus ihren Heimstätten und von ihren Besitztümern vertrieben wurden, während sie nach Allahs Huld und Wohlgefallen trachteten und Allah und Seinem Gesandten beistanden. Diese sind die Wahrhaftigen.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcxxxv{Und jene, die vor ihnen in der Behausung (des Islam) wohnten und im Glauben heimisch geworden sind, lieben jene, die bei ihnen Zuflucht suchten, und hegen in sich kein Verlangen nach dem, was ihnen gegeben wurde, sondern sehen (die Flüchtlinge gern) vor ihnen selbst bevorzugt, auch wenn sie selbst in Dürftigkeit leben. Und wer vor seiner eigenen Habsucht bewahrt ist - das sind die Erfolgreichen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcxxxvi{Und diejenigen, die nach ihnen kamen, sagen: ``Unser Herr, vergib uns und unseren Brüdern, die uns im Glauben vorangingen, und laß in unsere Herzen keinen Groll gegen die Gläubigen. Unser Herr! Du bist wahrlich Gütig, Barmherzig."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcxxxvii{Hast du nicht die gesehen, die Heuchler sind? Sie sagen zu ihren Brüdern vom Volk der Schrift, die ungläubig sind: ``Wenn ihr vertrieben werdet, so werden wir sicher mit euch ziehen, und wir werden nie jemandem gegen euch gehorchen; und wenn ihr angegriffen werdet, so werden wir euch sicher helfen." Doch Allah ist Zeuge, daß sie gewiß Lügner sind.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcxxxviii{Wenn sie vertrieben würden, würden sie nie mit ihnen ausziehen; und wenn sie angegriffen würden, würden sie ihnen niemals helfen. Und wenn sie ihnen schon helfen, so werden sie sicher den Rücken wenden (und fliehen); und dann sollen sie (selbst) keine Hilfe finden.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcxxxix{Wahrlich, sie hegen größere Furcht vor euch in ihren Herzen als vor Allah. Dies (ist so), weil sie ein Volk sind, das nichts begreift.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcxl{Sie würden euch nicht bekämpfen - nicht einmal alle zusammen -, außer in befestigten Städten oder hinter Mauern, (obgleich) ihre Heldentaten untereinander groß sind. Du würdest denken, sie seien eine Einheit, aber ihre Herzen sind uneinig. Dies (ist so), weil sie ein Volk sind, das keinen Verstand hat\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcxli{gleich jenen, die kurz vor ihnen die bösen Folgen ihrer Handlungsweise kosteten. Und für sie ist eine qualvolle Strafe (bereitet)\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcxlii{wie dem Satan, wenn er zu dem Menschen spricht: ``Sei ungläubig!" Ist er aber ungläubig, so spricht er: ``lch habe nichts mit dir zu schaffen; denn ich fürchte Allah, den Herrn der Welten."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcxliii{Und die Folge (davon) wird sein, daß beide im Feuer sein werden und darin auf ewig bleiben. Und das ist der Lohn der Ungerechten.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcxliv{O ihr, die ihr glaubt, fürchtet Allah; und eine jede Seele schaue nach dem, was sie für morgen vorausschickt. Und fürchtet Allah; wahrlich, Allah ist dessen wohl kundig, was ihr tut.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcxlv{Und seid nicht wie jene, die Allah vergaßen und die Er darum ihre eigenen Seelen vergessen ließ. Das sind die Frevler.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcxlvi{Nicht gleich sind die Bewohner des Feuers und die Bewohner des Paradieses. Es sind die Bewohner des Paradieses, die erfolgreich sind.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcxlvii{Hätten Wir diesen Quran auf einen Berg herabgesandt, hättest du gesehen, wie er sich gedemütigt und aus Furcht vor Allah gespalten hätte. Und solche Gleichnisse prägen Wir für die Menschen, auf daß sie nachdenken mögen.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcxlviii{Er ist Allah, außer Dem kein Gott ist; Er ist der Kenner des Verborgenen und des Sichtbaren. Er ist der Allerbarmer, der Barmherzige.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcxlix{Er ist Allah, außer Dem kein Gott ist; Er ist der Herrscher, der Einzig Heilige, der Friede, der Verleiher von Sicherheit, der Überwacher, der Erhabene, der Unterwerfer, der Majestätische. Gepriesen sei Allah über all das, was sie (Ihm) beigesellen.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmcl{Er ist Allah, der Schöpfer, der Bildner, der Gestalter. Ihm stehen die schönsten Namen zu. Alles, was in den Himmeln und auf Erden ist, preist Ihn, und Er ist der Erhabene, der Allweise.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmcli{\basmalahde O ihr, die ihr glaubt, nehmt euch nicht Meine Feinde und eure Feinde zu Beschützern, indem ihr ihnen Zuneigung gutmütig zeigt, wo sie doch die Wahrheit leugnen, die zu euch gekommen ist, und den Gesandten und euch selbst austreiben, weil ihr an Allah, euren Herrn, glaubt. Wenn ihr zum Kampf für Meine Sache und im Trachten nach Meinem Wohlgefallen ausgezogen seid, gebt ihr ihnen insgeheim Zuneigung zu verstehen, während Ich doch am besten weiß, was ihr verbergt und was ihr kundtut. Und der, der von euch das tut, ist sicherlich vom geraden Weg abgeirrt.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmclii{Wenn sie die Oberhand über euch gewinnen, dann werden sie sich gegen euch als Feinde betragen und ihre Hände und Zungen zum Bösen gegen euch ausstrecken; und sie wünschen inständig, daß ihr ungläubig würdet.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcliii{Weder eure Blutsverwandtschaft noch eure Kinder werden euch nützen. Er wird zwischen euch am Tage der Auferstehung entscheiden. Und Allah sieht alles, was ihr tut.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcliv{Ihr habt bereits ein vortreffliches Beispiel an Abraham und denen mit ihm, als sie zu ihrem Volk sagten: ``Wir haben nichts mit euch noch mit dem zu schaffen was ihr statt Allah anbetet. Wir verwerfen euch. Und zwischen uns und euch ist offenbar für immer Feindschaft und Haß entstanden; (solange,) bis ihr an Allah glaubt und an Ihn allein" - abgesehen von Abrahams Wort zu seinem Vater: ``lch will gewiß für dich um Verzeihung bitten, obwohl ich nicht die Macht dazu habe, bei Allah für dich etwas auszurichten." (Sie beteten:) ``Unser Herr, in Dich setzen wir unser Vertrauen, und zu Dir kehren wir reumütig zurück, und zu Dir ist die letzte Einkehr.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmclv{Unser Herr, mache uns nicht zu einer Versuchung für die Ungläubigen und vergib uns, unser Herr; denn Du, und Du allein, bist der Erhabene, der Allweise."\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmclvi{Wahrlich, ihr habt an ihnen ein vortreffliches Beispiel (und so) ein jeder, der auf Allah hofft und den Jüngsten Tag fürchtet. Und wer sich abwendet - wahrlich, Allah ist es, Der auf keinen angewiesen, Der des Lobes Würdige.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmclvii{Vielleicht wird Allah Zuneigung setzen zwischen euch und denen unter ihnen, mit denen ihr in Feindschaft lebt; denn Allah ist Allmächtig und Allah ist Allverzeihend, Barmherzig.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmclviii{Allah verbietet euch nicht, gegen jene, die euch nicht des Glaubens wegen bekämpft haben und euch nicht aus euren Häusern vertrieben haben, gütig zu sein und redlich mit ihnen zu verfahren; wahrlich, Allah liebt die Gerechten.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmclix{Doch Allah verbietet euch, mit denen, die euch des Glaubens wegen bekämpft haben und euch aus euren Häusern vertrieben und (anderen) geholfen haben, euch zu vertreiben, Freundschaft zu schließen. Und wer mit ihnen Freundschaft schließt - das sind die Missetäter.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmclx{O ihr, die ihr glaubt, wenn gläubige Frauen als Flüchtlinge zu euch kommen, so prüft sie. Allah weiß am besten, wie ihr Glaube in Wirklichkeit ist. Wenn ihr sie dann gläubig findet, so schickt sie nicht zu den Ungläubigen zurück. Diese (Frauen) sind ihnen nicht erlaubt, noch sind sie (als Ehemänner) diesen (Frauen) erlaubt. Jedoch zahlt (ihren ungläubigen Ehemännern) das zurück, was sie (für sie) ausgegeben haben. Und es ist keine Sünde für euch, sie zu heiraten, wenn ihr ihnen ihre Brautgabe gegeben habt. Und haltet nicht am Eheband mit den ungläubigen Frauen fest, sondern verlangt das zurück, was ihr (für sie) ausgegeben habt, und lasset (die Ungläubigen) das zurückverlangen, was sie (für sie) ausgegeben haben. Das ist Allahs Gebot. Er richtet zwischen euch. Und Allah ist Allwissend, Allweise.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmclxi{Und wenn irgendeine von euren Frauen von euch zu den Ungläubigen fortgeht, dann gebt, wenn ihr (bei den Ungläubigen) Beute macht, jenen (Gläubigen), deren Frauen fortgegangen sind, das gleiche von dem, was sie (für ihre Frauen) ausgegeben haben. Und fürchtet Allah, an Den ihr glaubt.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmclxii{O Prophet! Wenn gläubige Frauen zu dir kommen und dir den Treueeid leisten, daß sie Allah nichts zur Seite stellen und daß sie weder stehlen noch Unzucht begehen, noch ihre Kinder töten, noch ein Unrecht begehen werden zwischen ihren Händen und Beinen, das sie selbst wissentlich ersonnen haben, noch dir ungehorsam sein werden in dem, was rechtens ist, dann nimm ihren Treueeid an und bitte Allah um Vergebung für sie. Wahrlich, Allah ist Allvergebend, Barmher zig.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmclxiii{O ihr, die ihr glaubt, schließt keine Freundschaft mit einem Volk, dem Allah zürnt; denn sie haben die Hoffnung auf das Jenseits gerade so aufgegeben, wie die Ungläubigen die Hoffnung auf die Wiederbelebung derer aufgegeben haben, die in den Gräbern liegen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmclxiv{\basmalahde Es preist Allah, was in den Himmeln und was auf der Erde ist; und Er ist der Erhabene, der Allweise.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmclxv{O ihr, die ihr glaubt, warum sagt ihr, was ihr nicht tut?\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmclxvi{Höchst hassenswert ist es vor Allah, daß ihr sagt, was ihr nicht tut.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmclxvii{Wahrlich, Allah liebt diejenigen, die für Seine Sache kämpfen, (in eine Schlachtordnung) gereiht, als wären sie ein festgefügtes Mauerwerk.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmclxviii{Und da sagte Moses zu seinem Volk: ``O mein Volk, warum kränkt ihr mich, wo ihr doch wisset, daß ich Allah s Gesandter bei euch bin?" Als sie dann (vom Glauben) abschweiften, da ließ Allah ihre Herzen abschweifen. Und Allah leitet kein frevelhaftes Volk.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmclxix{Und da sagte Jesus, der Sohn der Maria: ``O ihr Kinder Israels, ich bin Allahs Gesandter bei euch, der Bestätiger dessen, was von der Thora vor mir gewesen ist, und Bringer der frohen Botschaft eines Gesandten, der nach mir kommen wird. Sein Name wird Ahmad sein `` Und als er zu ihnen mit den Beweisen kam, sagten sie: ``Das ist ein offenkundiger Zauber."\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmclxx{Und wer ist ungerechter als der, der gegen Allah eine Lüge erdichtet und selbst zum Islam aufgefordert wird? Und Allah leitet kein ungerechtes Volk.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmclxxi{Sie wollen Allahs Licht mit ihren Mündern auslöschen, doch Allah wird Sein Licht vollenden, auch wenn die Ungläubigen es verwünschen.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmclxxii{Er ist es, Der Seinen Gesandten mit der Führung und der wahren Religion geschickt hat, auf daß Er sie über alle Religionen siegen lasse, auch wenn die Götzendiener es verwünschen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmclxxiii{O ihr, die ihr glaubt, soll Ich euch (den Weg) zu einem Handel weisen, der euch vor qualvoller Strafe retten wird?\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmclxxiv{Ihr sollt an Allah und an Seinen Gesandten glauben und sollt für Allahs Sache mit eurem Gut und eurem Blut streiten. Das ist besser für euch, wenn ihr es nur wüßtet.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmclxxv{Er wird euch eure Sünden vergeben und euch in Gärten führen, durch die Bäche fließen, und in gute Wohnungen in den Gärten von Eden. Das ist die große Glückseligkeit.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmclxxvi{Und noch etwas anderes, das ihr liebt, (wird euch zuteil sein): Hilfe von Allah und naher Sieg. So verkünde den Gläubigen die frohe Botschaft.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmclxxvii{O ihr, die ihr glaubt, seid Allahs Helfer wie Jesus, der Sohn der Maria, (als er) zu den Jüngern sagte: ``Wer sind meine Helfer für Allah?" Die Jünger sagten: ``Wir sind Allahs Helfer." So glaubte ein Teil der Kinder Israels, während ein Teil ungläubig blieb. Da verliehen Wir denen, die glaubten, Stärke gegen ihren Feind, und sie wurden siegreich.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmclxxviii{\basmalahde Was in den Himmeln und was auf der Erde ist, preist Allah, Den Herrscher, Den Einzig Heiligen, den Erhabenen, den Allweisen.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmclxxix{Er ist es, Der unter den Analphabeten einen Gesandten aus ihrer Mitte erweckt hat, um ihnen Seine Verse zu verlesen und sie zu reinigen und sie die Schrift und die Weisheit zu lehren, obwohl sie sich zuvor in einem offenkundigen Irrtum befanden\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmclxxx{und anderen von ihnen, die sie noch nicht eingeholt haben. Und Er ist der Erhabene, der Allweise.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmclxxxi{Das ist Allahs Huld; Er gewährt sie, wem Er will; und Allah ist der Herr der großen Huld.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmclxxxii{Das Gleichnis derer, denen die Thora auferlegt wurde, und die ihr dann nicht nachlebten, ist wie das Gleichnis eines Esels, der Bücher trägt. Übel steht es um die Leute, die Allahs Zeichen leugnen. Und Allah rechtleitet kein ungerechtes Volk.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmclxxxiii{Sprich: ``O die ihr Juden seid, wenn ihr meint, ihr seid die Schutzbefohlenen Allahs unter Ausschluß der anderen Menschen, dann wünscht euch den Tod, wenn ihr wahrhaftig seid."\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmclxxxiv{Doch sie werden sich ihn niemals wünschen um dessentwillen, was ihre Hände ihnen vorausgeschickt haben. Und Allah kennt die Ungerechten recht wohl.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmclxxxv{Sprich: ``Der Tod vor dem ihr flieht, wird euch sicher ereilen. Dann werdet ihr zu Dem zurückgebracht werden, Der es kennt, das Verborgene und das Sichtbare; und Er wird euch verkünden, was ihr zu tun pflegtet."\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmclxxxvi{O ihr, die ihr glaubt, wenn zum Freitagsgebet gerufen wird, dann eilt zum Gedenken Allahs und stellt den Geschäftsbetrieb ein. Das ist besser für euch, wenn ihr es nur wüßtet.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmclxxxvii{Und wenn das Gebet beendet ist, dann zerstreut euch im Land und trachtet nach Allahs Gnadenfülle und gedenkt Allahs häufig, auf daß ihr Erfolg haben möget.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmclxxxviii{Doch wenn sie eine Handelsware oder ein Spiel sehen, dann brechen sie sogleich dazu auf und lassen dich (im Gebet) stehen. Sprich: ``Was bei Allah ist, das ist besser als Spiel und Handelsware, und Allah ist der beste Versorger."\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmclxxxix{\basmalahde Wenn die Heuchler zu dir kommen, sagen sie: ``Wir bezeugen, daß du in Wahrheit der Gesandte Allahs bist." Und Allah weiß, daß du wahrhaftig Sein Gesandter bist. Doch Allah bezeugt, daß die Heuchler Lügner sind.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcxc{Sie haben ihre Eide als Schutzbehauptung vorgebracht; so wenden sie vom Wege Allahs ab. Schlimm ist wahrlich das, was sie zu tun pflegen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcxci{Dies (ist so), weil sie glaubten und hernach ungläubig wurden. So ist ein Siegel auf ihre Herzen gesetzt worden, so daß sie nicht be greifen (können)\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcxcii{Und wenn du sie siehst, so gefallen dir ihre Gestalten; und wenn sie sprechen, horchst du auf ihre Rede. Sie sind, als wären sie aufgerichtete Holzklötze. Sie glauben, jeder Schrei sei gegen sie (gerichtet) Sie sind der Feind, darum nimm dich vor ihnen in acht. Allahs Fluch über sie! Wie werden sie abgewendet?\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcxciii{Und wenn zu ihnen gesprochen wird: ``Kommt her, der Gesandte Allahs will für euch um Verzeihung bitten", dann wenden sie ihre Köpfe zur Seite, und du siehst, wie sie sich in Hochmut abkehren.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcxciv{Es ist ihnen gleich, ob du für sie um Verzeihung bittest oder nicht für sie um Verzeihung bittest. Allah wird ihnen nie verzeihen; wahrlich, Allah rechtleitet kein frevelhaftes Volk.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcxcv{Sie sind es, die sagen: ``Spendet nicht für die, die mit dem Gesandten Allahs sind, bis sie (ihn) verlassen", während doch die Schätze der Himmel und der Erde Allahs sind; allein die Heuchler verstehen nichts.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcxcvi{Sie sagen: ``Wenn wir nach Madina zurückkehren, dann wird der Würdigste sicher den Geringsten aus ihr vertreiben", obwohl die Würdigkeit nur Allah und Seinem Gesandten und den Gläubigen zusteht; aber die Heuchler wissen es nicht.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcxcvii{O ihr, die ihr glaubt, lasset euch durch euer Vermögen und eure Kinder nicht vom Gedenken an Allah abhalten. Und wer das tut - das sind die Verlierenden.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcxcviii{Und spendet von dem, was Wir euch gegeben haben, bevor einen von euch der Tod ereilt und er sagt: ``Mein Herr! Wenn Du mir nur Aufschub für eine kurze Frist gewähren würdest, dann würde ich Almosen geben und einer der Rechtschaffenen sein."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcxcix{Und nie wird Allah jemandem Aufschub gewähren, wenn seine Frist um ist; und Allah ist dessen wohl kundig, was ihr tut.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcc{\basmalahde Es preist Allah, was in den Himmeln und auf der Erde ist; Sein ist das Königreich und Sein ist das Lob, und Er hat Macht über alle Dinge.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcci{Er ist es, Der euch erschaffen hat, aber einige von euch sind ungläubig und einige von euch sind gläubig; und Allah durchschaut das, was ihr tut.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmccii{Er schuf die Himmel und die Erde in gerechter Weise, und Er gestaltete euch und machte eure Gestalt schön, und zu Ihm ist die Heimkehr.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcciii{Er weiß, was in den Himmeln und auf Erden ist, und Er weiß, was ihr geheimhaltet und was ihr offenkund tut; und Allah kennt alles, was in den Herzen ist.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcciv{Ist nicht die Geschichte von denen, die zuvor ungläubig waren, zu euch gekommen? So kosteten sie die bösen Folgen ihres Betragens, und ihnen wird eine qualvolle Strafe zuteil sein.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmccv{Dies (soll so sein), weil ihre Gesandten mit klaren Beweisen zu ihnen kamen, sie aber sagten: ``Sollen Menschen uns rechtleiten?" Also glaubten sie nicht und wandten sich ab, doch Allah hat dies nicht nötig; und Allah ist auf keinen angewiesen, des Lobes Würdig.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmccvi{Diejenigen, die da ungläubig sind, behaupten, sie würden nicht auferweckt werden. Sprich: ``Doch, bei meinem Herrn, ihr werdet gewiß auferweckt werden; dann wird euch gewiß verkündet, was ihr getan habt. Und das ist für Allah ein leichtes."\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmccvii{Darum glaubt an Allah und Seinen Gesandten und an das Licht, das Wir herniedergesandt haben. Und Allah ist dessen wohl kundig, was ihr tut.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmccviii{Der Zeitpunkt, wo Er euch am Tage der Versammlung versammeln wird - das wird der Tag des verlorenen Gewinns sein. Und wer an Allah glaubt und das Rechte tut - Er wird seine Übel von ihm nehmen und wird ihn in Gärten führen, durch die Bäche fließen, worin (sie) auf ewig verweilen. Das ist das große Glück.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmccix{Diejenigen aber, die ungläubig sind und Unsere Zeichen leugnen, sollen die Bewohner des Feuers sein. Darin bleiben sie auf ewig; und das ist eine schlimme Bestimmung!\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmccx{Kein Unglück trifft ein, es sei denn mit Allahs Erlaubnis. Und wer an Allah glaubt, dem leitet Er sein Herz. Und Allah weiß alle Dinge.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmccxi{Und gehorcht Allah und gehorcht dem Gesandten. Doch wenn ihr euch (von ihm) abkehrt, dann obliegt Unserem Gesandten nur die Pflicht zur deutlichen Verkündigung.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmccxii{Allah! Es ist kein Gott außer Ihm; und auf Allah sollen die Gläubigen vertrauen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmccxiii{O ihr, die ihr glaubt, wahrlich, unter euren Frauen und Kindern sind welche, die euch feindlich gesonnen sind; so hütet euch vor ihnen. Und wenn ihr verzeiht und Nachsicht übt und vergebt, dann ist Allah Allvergebend, Barmherzig.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmccxiv{Eure Reichtümer und eure Kinder sind wahrlich eine Versuchung; doch bei Allah ist großer Lohn.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmccxv{So fürchtet Allah, soviel ihr nur könnt, und hört und gehorcht und spendet; es wird für euch selbst besser sein. Und wer vor seiner eigenen Habsucht bewahrt ist das sind die Erfolgreichen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmccxvi{Wenn ihr Allah ein gutes Darlehen gebt, so wird Er es euch um ein Vielfaches vermehren und wird euch vergeben; und Allah ist Dankbar, Nachsichtig\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmccxvii{der Kenner des Verborgenen und des Sichtbaren, der Erhabene, der Allweise.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmccxviii{\basmalahde O du Prophet, wenn ihr euch von den Frauen scheidet, so scheidet euch von ihnen zu ihrer festgesetzten Zeit und berechnet die Zeit und fürchtet Allah, euren Herrn. Treibt sie nicht aus ihren Häusern noch lasset sie hinausgehen; es sei denn, sie hätten eine offenkundige Schändlichkeit begangen. Und dies sind Allahs Gebote; und wer Allahs Gebote übertritt, der hat sich selber Unrecht getan. Du weißt nicht, ob Allah danach etwas (Unvermutetes) geschehen lassen würde.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmccxix{Wenn sie aber ihren Termin erreicht haben, dann haltet sie in Güte zurück oder trennt euch in Güte von ihnen; und nehmt als Zeugen Leute von Billigkeit unter euch, und legt Zeugnis vor Allah ab. Dies ist eine Ermahnung für diejenigen, die an Allah und an den Jüngsten Tag glauben; und dem, der Allah fürchtet, verschafft Er einen Ausweg\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmccxx{und versorgt ihn in der Art und Weise, mit der er nicht rechnet. Und wer auf Allah vertraut - für den ist Er sein Genüge. Wahrlich, Allah setzt durch, was Er will; siehe Allah hat für alles eine Bestimmung gemacht.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmccxxi{Wenn ihr Zweifel hegt (über) jene eurer Frauen, die keine Menstruation mehr erhoffen, (dann wisset, daß) ihre Frist drei Monate beträgt, und (das gleiche gilt für) diejenigen, die noch keine Menstruation gehabt haben. Und für die Schwangeren soll die Frist solange dauern, bis sie zur Welt bringen, was sie getragen haben. Und dem, der Allah fürchtet, wird Er Erleichterung in seinen Angelegenheiten verschaffen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmccxxii{Das ist Allahs Befehl, den Er euch herabgesandt hat. Und wer Allah fürchtet - Er wird seine Übel von ihm nehmen und ihm einen würdigen Lohn geben.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmccxxiii{Laßt sie wohnen, wo ihr wohnt, gemäß euren Mitteln; und tut ihnen nichts zuleide in der Absicht, es ihnen schwer zu machen. Und wenn sie schwanger sind, so bestreitet ihren Unterhalt, bis sie zur Welt bringen, was sie getragen haben. Und wenn sie (das Kind) für euch stillen, (dann) gebt ihnen ihren Lohn und geht gütig miteinander um; wenn ihr aber Schwierigkeiten miteinander habt, dann soll eine andere (das Kind) für den (Vater) stillen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmccxxiv{Jeder soll aus seiner Fülle ausgeben, wenn er die Fülle hat; und der, dessen Mittel beschränkt sind, soll gemäß dem ausgeben, was ihm Allah gegeben hat. Allah fordert von keiner Seele etwas über das hinaus, was Er ihr gegeben hat. Allah wird nach einer Bedrängnis Erleichterung schaffen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmccxxv{Wie so manche Stadt widersetzte sich dem Befehl ihres Herrn und Seiner Gesandten, und Wir zogen sie streng zur Rechenschaft und bestraften sie mit gräßlicher Strafe!\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmccxxvi{So kostete sie die bösen Folgen ihres Betragens, und am Ende ihres Betragens stand ein Verlust.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmccxxvii{Allah hat für sie eine strenge Strafe bereitet; so fürchtet Allah, o ihr Leute von Verstand, die ihr glaubt. Allah hat euch wahrlich eine Ermahnung herniedergesandt\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmccxxviii{einen Gesandten, der euch die deutlichen Verse Allahs verliest, auf daß er jene, die glauben und gute Werke tun, aus den Finsternissen ans Licht führe. Und den, der an Allah glaubt und recht handelt, wird Er in Gärten führen, durch die Bäche fließen, worin (er) auf ewig verweilen wird. Allah hat ihm wahrlich eine treffliche Versorgung gewährt.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmccxxix{Allah ist es, Der sieben Himmel erschuf und von der Erde die gleiche Anzahl. Der Befehl steigt zwischen ihnen herab, auf daß ihr erfahren möget, daß Allah über alle Dinge Macht hat und daß Allahs Wissen alle Dinge umfaßt.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmccxxx{\basmalahde O Prophet! Warum verbietest du das, was Allah dir erlaubt hat, um nach der Zufriedenheit deiner Frauen zu trachten? Und Allah ist Allvergebend, Barmherzig.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmccxxxi{Wahrlich, Allah hat für euch die Lösung eurer Eide angeordnet, und Allah ist euer Beschützer; und Er ist der Allwissende, der Allweise.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmccxxxii{Und als der Prophet sich zu einer seiner Frauen im Vertrauen geäußert hatte und sie es dann kundtat und Allah ihm davon Kenntnis gab, da ließ er (sie) einen Teil davon wissen und verschwieg einen Teil. Und als er es ihr vorhielt, da sagte sie: ``Wer hat dich davon unterrichtet?" Er sagte: ``Unterrichtet hat mich der Allwissende, der Allkundige."\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmccxxxiii{Wenn ihr beide euch Allah reumütig zuwendet, so sind eure Herzen bereits (dazu) geneigt. Doch wenn ihr euch gegenseitig gegen ihn unterstützt, wahrlich, dann ist Allah sein Beschützer; und Gabriel und die Rechtschaffenen unter den Gläubigen (sind ebenso seine Beschützer); und außerdem sind die Engel (seine) Helfer.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmccxxxiv{Vielleicht wird sein Herr ihm, wenn er sich von euch scheidet, an eurer Stelle bessere Frauen als euch geben, muslimische, gläubige, gehorsame, reuige, fromme, fastende (Frauen), Taiyibat und Jungfrauen.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmccxxxv{O ihr, die ihr glaubt, rettet euch und die Euren vor einem Feuer, dessen Brennstoff Menschen und Steine sind, worüber strenge, gewaltige Engel gesetzt sind, die Allah nicht ungehorsam sind in dem, was Er ihnen befiehlt, und die alles vollbringen, was ihnen befohlen wird.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmccxxxvi{O die ihr ungläubig seid, bringt heute keine Entschuldigung vor. Ihr werdet nur für das belohnt, was ihr zu tun pflegtet.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmccxxxvii{O ihr, die ihr glaubt, wendet euch in aufrichtiger Reue zu Allah. Vielleicht wird euer Herr eure Übel von euch nehmen und euch in Gärten führen, durch die Bäche fließen; am Tage, da Allah den Propheten nicht zuschanden macht, noch jene, die mit ihm glauben. Ihr Licht wird vor ihnen her eilen und auf ihrer Rechten (sein) Sie werden sagen: ``Unser Herr mache unser Licht für uns vollkommen und vergib uns; denn Du hast Macht über alle Dinge."\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmccxxxviii{O Prophet! Bekämpfe die Ungläubigen und die Heuchler; und sei streng gegen sie. Ihre Herberge wird Gahannam sein, und dies ist ein schlimmes Ende!\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmccxxxix{Allah legt denen die ungläubig sind, das Beispiel von Noahs Frau und von Lots Frau vor: Diese zwei waren unter zwei Unserer rechtschaffenen Diener, doch sie handelten untreu an ihnen. Darum nützten sie ihnen nichts gegen Allah, und es wurde gesprochen: ``Geht ihr beide ins Feuer ein zusammen mit denen, die (darin) eingehen!"\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmccxl{Und Allah legt denen, die glauben, das Beispiel von Pharaos Frau vor, als sie sagte: ``Mein Herr! Baue mir ein Haus bei Dir im Paradies und befreie mich von Pharao und seinen Taten und befreie mich von dem Volk der Ungerechten!"\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmccxli{Und (Allah legt das Beispiel) von Maria, der Tochter `lmrans, (vor,) die ihre Scham bewahrte - darum hauchten Wir von Unserem Geist in diese ein; und sie glaubte an die Worte ihres Herrn und an Seine Schrift und war eine der Gehorsamen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmccxlii{\basmalahde Segensreich ist Der, in Dessen Hand die Herrschaft ruht; und Er hat Macht über alle Dinge\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmccxliii{(Er,) Der den Tod erschaffen hat und das Leben, auf daß Er euch prüfe, wer von euch die besseren Taten verrichte; und Er ist der Erhabene, der Allvergebende\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmccxliv{Der die sieben Himmel in Schichten erschaffen hat. Keinen Fehler kannst du in der Schöpfung des Allerbarmers sehen. So wende den Blick (zu ihnen) zurück: erblickst du irgendeinen Mangel?\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmccxlv{Dann wende den Blick abermals zum zweiten Mal zurück: so wird dein Blick nur ermüdet und geschwächt zu dir zurückkehren.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmccxlvi{Und Wir haben den untersten Himmel wahrlich mit Leuchten geschmückt, und Wir haben sie zu einem Mittel zur Vernichtung der Satane gemacht, und für sie haben Wir die Strafe des flammenden Feuers bereitet.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmccxlvii{Und für jene, die nicht an ihren Herrn glauben, ist die Strafe der Gahannam, und eine üble Bestimmung ist das!\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmccxlviii{Wenn sie hin eingeworfen werden, dann werden sie sie aufheulen hören, während sie in Wallung gerät.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmccxlix{Fast möchte sie bersten vor Wut. Sooft eine Schar hineingeworfen wird, werden ihre Wächter sie fragen: ``Ist denn kein Warner zu euch gekommen?"\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmccl{Sie werden sagen: ``Doch, sicherlich, es kam ein Warner zu uns, aber wir leugneten es und sagten: ``Allah hat nichts herabgesandt; ihr befindet euch bloß in einem großen Irrtum.""\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmccli{Und sie werden (weiter) sagen: ``Hätten wir nur zugehört oder Verstand gehabt, wären wir nicht unter den Bewohnern des flammenden Feuers gewesen."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcclii{So werden sie ihre Sündhaftigkeit zugeben; doch nieder mit den Bewohnern des flammenden Feuers!\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmccliii{Wahrlich, diejenigen, die ihren Herrn im verborgenen fürchten, werden Vergebung und einen großen Lohn erhalten.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmccliv{Und ob ihr euer Wort verbergt oder es offen verkündet, Er kennt die innersten Gedanken der Herzen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcclv{Kennt Er den denn nicht, den Er erschaffen hat? Und Er ist der Nachsichtige, der Allkundige.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcclvi{Er ist es, Der euch die Erde untertan gemacht hat; wandert also auf ihren Wegen und genießt Seine Versorgung. Und zu Ihm führt die Auferstehung.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcclvii{Fühlt ihr euch sicher davor, daß Der, Der im Himmel ist, nicht die Erde unter euch versinken läßt, und sie dann ins Wanken gerät?\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcclviii{Oder fühlt ihr euch sicher davor, daß Der, Der im Himmel ist, nicht einen Sandsturm gegen euch schickt? Dann werdet ihr wissen, wie Meine Warnung war!\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcclix{Und schon jene leugneten, die vor ihnen waren; wie war dann (die Folge) Meiner Verleugnung!\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcclx{Haben sie nicht die Vögel über sich gesehen, wie sie ihre Flügel ausbreiten und sie dann einziehen? Kein Anderer als der Allerbarmer hält sie zurück. Wahrlich, Er durchschaut alle Dinge.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcclxi{Oder wer ist es, der eine Heerschar für euch wäre, um euch gegen den Allerbarmer beizustehen? Die Ungläubigen sind wahrlich völlig betört.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcclxii{Oder wer ist es, der euch versorgen würde, wenn Er Seine Versorgung zurückhielte? Nein, sie verharren in Trotz und in Widerwillen.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcclxiii{Wie? Ist denn der, der mit zur Erde gebeugtem Gesicht einhergeht, besser rechtgeleitet als jener, der aufrecht auf dem geraden Weg geht?\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcclxiv{Sprich: ``Er ist es, Der euch ins Dasein rief und Der euch Ohren und Augen und Herzen gab; (aber) gering ist es, was ihr an Dank wißt!"\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmcclxv{Sprich: ``Er ist es, Der euch auf Erden mehrte, und vor Ihm werdet ihr versammelt werden."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmcclxvi{Und sie sagen: ``Wann wird sich diese Androhung erfüllen, wenn ihr wahrhaftig seid?"\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmcclxvii{Sprich:" Das Wissen (darum) ist wahrlich bei Allah, und ich bin nur ein deutlicher Warner."\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmcclxviii{Doch wenn sie es nahe sehen, dann werden die Gesichter derer, die ungläubig sind, verzerrt sein, und es wird gesprochen werden: ``Das ist es wonach ihr verlangt habt."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmcclxix{Sprich: ``Was meint ihr wenn Allah mich und diejenigen, die mit mir sind, vernichten sollte, oder wenn Er uns Barmherzigkeit erweisen sollte, wer würde (dann) die Ungläubigen vor qualvoller Strafe schützen?"\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmcclxx{Sprich: ``Er ist der Allerbarmer; an Ihn glauben wir und auf Ihn vertrauen wir. Ihr werdet bald erfahren, wer sich in einem offenbaren Irrtum befindet."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxi{Sprich: ``Was meint ihr, wenn euer Wasser versickern würde, wer könnte euch dann reichlich Wasser bringen?"\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxii{\basmalahde Nun - und beim Schreibrohr und bei dem, was sie nie derschreiben!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxiii{Wahrlich, du bist - durch die Gnade deines Herrn - kein Besessener.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxiv{Und für dich ist gewiß ein Lohn bestimmt, der dir nicht vorenthalten wird.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxv{Und du verfügst wahrlich über großartige Tugendeigenschaften.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxvi{Also wirst du sehen und sie werden auch sehen\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxvii{wer von euch der Besessene ist.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxviii{Wahrlich, dein Herr weiß am besten, wer von Seinem Weg abirrt, und Er kennt auch die Rechtgeleiteten am besten.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxix{Darum richte dich nicht nach den Wünschen der Leugner.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxx{Sie wünschen, daß du dich (ihnen gegenüber) entgegenkommend verhältst, dann würden (auch) sie sich (dir gegenüber) entgegenkommend verhalten.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxxi{Und füge dich nicht irgendeinem verächtlichen Schwüremacher\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxxii{Verleumder, einem, der umhergeht, um üble Nachrede zu verbreiten\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxxiii{einem Behinderer des Guten, Übertreter, Sünder\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxxiv{groben Benehmens, einem Bastard.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxxv{Nur weil er Reichtümer und Kinder besitzt\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxxvi{sagt er, wenn ihm Unsere Verse verlesen werden: ``(Dies sind) Fabeln der Alten!"\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxxvii{Wir wollen ihn auf der Nase brandmarken.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxxviii{Wir prüfen sie, wie Wir die Eigentümer des Gartens prüften, als sie schworen, sie würden sicherlich (all) seine Früchte am Morgen pflücken.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcclxxxix{Und sie machten keinen Vorbehalt.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmccxc{Dann kam eine Heimsuchung deines Herrn über ihn, während sie schliefen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmccxci{Und am Morgen war (der Garten) bereits verwüstet.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmccxcii{Dann riefen sie am Morgen einander zu\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmccxciii{``Geht in der Frühe zu eurem Acker hinaus, wenn ihr ernten möchtet."\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmccxciv{Und sie machten sich auf den Weg und redeten dabei flüsternd miteinander\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmccxcv{``Zu euch hinein darf ihn heute kein Armer betreten."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmccxcvi{Und sie gingen in der Frühe hin mit dem festen Vorsatz, geizig zu sein.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmccxcvii{Doch als sie ihn sahen, sagten sie: ``Wahrlich, wir befinden uns im Irrtum!\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmccxcviii{Nein, wir sind beraubt."\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmccxcix{Der Gemäßigte unter ihnen sagte: ``Habe ich euch nicht gesagt: ``Warum preist ihr (Allah) nicht?""\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmccc{(Nun) sagten sie: ``Preis sei unserem Herrn! Gewiß, wir sind ungerecht gewesen."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmccci{Dann wandten sich einige von ihnen an die anderen, indem sie sich gegenseitig Vorwürfe machten.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmcccii{Sie sagten: ``Wehe uns! Wir waren wahrlich widerspenstig.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmccciii{Vielleicht wird unser Herr uns einen besseren (Garten) als Ersatz für diesen geben; wir flehen demütig zu unserem Herrn."\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmccciv{So ist die Strafe. Und wahrlich, die Strafe des Jenseits ist (noch) schwerer. Wenn sie es nur wüßten!\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmcccv{Für die Gerechten sind wahrlich Gärten der Wonne bei ihrem Herrn (bestimmt)\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmcccvi{Sollten Wir etwa die Gottergebenen wie die Schuldigen behandeln.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmcccvii{Was ist euch? Wie urteilt ihr?\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmcccviii{Oder habt ihr etwa ein Buch, in dem ihr studiert\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmcccix{so daß ihr danach alles erhalten sollt, was ihr wünscht?\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmcccx{Oder habt ihr Gelöbnisse von Uns - bindend bis zum Tage der Auferstehung -, daß alles für euch sei, was ihr befehlt?\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmcccxi{Frage sie, wer von ihnen dafür bürgen mag.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmcccxii{Oder haben sie Partner? So sollen sie ihre Partner herbeibringen, wenn sie die Wahrheit reden.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmmcccxiii{Am Tage, wenn die Beine entblößt werden und sie aufgefordert werden, sich anbetend niederzuwerfen, werden sie es nicht können.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmmcccxiv{Ihre Blicke werden niedergeschlagen sein, (und) Schande wird sie bedecken; denn sie waren (vergebens) aufgefordert worden, sich anbetend niederzuwerfen, als sie wohlbehalten waren.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmmcccxv{So überlaß Mir diejenigen, die diese Verkündigung leugnen. Wir werden sie Schritt um Schritt gehen lassen, ohne daß sie es wissen.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmmcccxvi{Und Ich gewähre ihnen einen Aufschub; wahrlich, Mein Plan ist vollkommen.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmmcccxvii{Oder verlangst du einen Lohn von ihnen, so daß sie sich von einer Schuldenlast bedrückt fühlen?\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmmcccxviii{Oder ist das Verborgene bei ihnen, so daß sie (es) niederschreiben können?\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmmcccxix{So warte geduldig auf den Befehl deines Herrn, und sei nicht wie der Mann des Fisches (Jonas), als er (seinen Herrn) anrief, während er von Kummer erfüllt war.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmmcccxx{Wäre ihm keine Gnade von seinem Herrn erwiesen worden, wäre er sicher an ein kahles Land geworfen worden, und er wäre geschmäht worden.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxi{Doch sein Herr erwählte ihn und machte ihn zu einem der Rechtschaffenen.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxii{Und jene, die ungläubig sind, möchten dich gerne mit ihren (zornigen) Blicken zu Fall bringen, wenn sie die Ermahnung hören; und sie sagen: ``Er ist gewiß verrückt!"\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxiii{Und es ist nichts anderes als eine Ermahnung für alle Welten.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxiv{\basmalahde Al-Haqqa.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxv{Was ist Al-Haqqa?\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxvi{Und wie kannst du wissen, was Al-Haqqa ist?\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxvii{Die Tamud und die `Ad leugneten Al- Qaria.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxviii{Dann, was die Tamud anbelangt, so wurden sie durch einen fürchterlichen Schall vernichtet.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxix{Und was die `Ad anbelangt, so wurden sie durch einen gewaltigen, eiskalten Wind vernichtet\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxx{den Er sieben Nächte und acht Tage lang ununterbrochen gegen sie wüten ließ, so daß du das Volk hättest sehen können, dort niedergestreckt, als wären sie hohle Palm stämme.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxxi{Siehst du von ihnen einen übrig (geblieben)?\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxxii{Und Pharao und diejenigen, die vor ihm waren, und die zusammengestürzten Städte waren großen Frevels schuldig\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxxiii{und sie waren widerspenstig gegen den Gesandten ihres Herrn, darum erfaßte Er sie mit drosselndem Griff.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxxiv{Siehe, als das Wasser schwoll, da trugen Wir euch auf dem Schiff\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxxv{so daß Wir es zu einer Erinnerung für euch machten, und auf daß bewahrende Ohren sie bewahren mögen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxxvi{Und wenn in den Sur gestoßen wird mit einem einzigen Stoß\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxxvii{und die Erde samt den Bergen emporgehoben und dann mit einem einzigen Schlag niedergeschmettert wird\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxxviii{an jenem Tage wird das Ereignis schon eingetroffen sein.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcccxxxix{Und der Himmel wird sich spalten; denn an jenem Tage wird er brüchig sein.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcccxl{Und die Engel werden an seinen Rändern stehen, und acht (Engel) werden an jenem Tage den Thron deines Herrn über sich tragen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcccxli{An jenem Tage werdet ihr (Allah) vorstellig sein - keines eurer Geheimnisse wird verborgen bleiben.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcccxlii{Was dann den anbelangt, dem sein Buch in die Rechte gegeben wird, so wird er sagen: ``Wohlan, lest mein Buch.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcccxliii{Wahrlich, ich habe damit gerechnet, daß ich meiner Rechenschaft begegnen werde."\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcccxliv{So wird er ein Wohlleben\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcccxlv{in einem hochgelegenen Paradies führen\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcccxlvi{dessen Früchte leicht erreichbar sind.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmcccxlvii{``Esset und trinkt und lasset es euch wohl bekommen für das, was ihr in den vergangenen Tagen gewirkt habt."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmcccxlviii{Was aber den anbelangt, dem sein Buch in die Linke gegeben wird, so wird er sagen: ``O wäre mir mein Buch doch nicht gegeben worden!\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmcccxlix{Und hätte ich doch nie erfahren, was meine Rechenschaft ist!\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmcccl{O hätte doch der Tod (mit mir) ein Ende gemacht!\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmcccli{Mein Besitz hat mir nichts genützt.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmccclii{Meine Macht ist von mir gegangen."\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmcccliii{``Ergreift ihn und fesselt ihn\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmcccliv{dann lasset ihn hierauf in der Gahim brennen.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmccclv{Dann legt ihn in eine Kette, deren Länge siebzig Ellen mißt\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmccclvi{denn er glaubte ja nicht an Allah, den Großen\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmccclvii{und forderte nicht zur Speisung der Armen auf.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmccclviii{Hier hat er nun heute keinen Freund\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmccclix{und keine Nahrung außer aus Wunden geflossenem Eiter\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmccclx{den nur die Sünder essen."\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmccclxi{Doch Ich schwöre bei dem, was ihr seht\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmccclxii{und bei dem, was ihr nicht seht\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmccclxiii{daß dies wahrlich das Wort (Allahs durch den Mund) eines ehrwürdigen Gesandten ist.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmccclxiv{Es ist aber nicht das Werk eines Dichters; wenig ist das, was ihr glaubt\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmmccclxv{noch ist es die Rede eines Wahrsagers; wenig ist das, was ihr bedenkt.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmmccclxvi{(Es ist) eine Offenbarung vom Herrn der Welten.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmmccclxvii{Und hätte er irgendwelche Aussprüche in Unserem Namen ersonnen\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmmccclxviii{hätten Wir ihn gewiß bei der Rechten gefaßt\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmmccclxix{und ihm dann die Herzader durchschnitten.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmmccclxx{Und keiner von euch hätte (Uns) von ihm abhalten können.\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxi{Und wahrlich, es ist eine Ermahnung für die Gottesfürchtigen.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxii{Und Wir wissen wahrlich, daß einige von euch Leugner sind.\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxiii{Und wahrlich, es ist ein schmerzhaftes Bedauern für die Ungläubigen.\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxiv{Und wahrlich, es ist die Wahrheit mit aller Gewißheit.\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxv{Darum preise den Namen deines Großen Herrn.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxvi{\basmalahde Ein Fragender fragt nach einer Strafe, die hereinbrechen wird\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxvii{die für die Ungläubigen unabwendbar ist\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxviii{sie ist von Allah, Der über die Himmelsleiter verfügt.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxix{Die Engel und Gabriel steigen zu Ihm auf in einem Tage, dessen Ausmaß fünfzigtausend Jahre beträgt.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxx{Harre darum schön geduldig aus.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxxi{Sie meinen, er sei ferne\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxxii{aber Wir sehen, er ist nahe.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxxiii{Am Tage, da der Himmel wie geschmolzenes Metall sein wird\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxxiv{und die Berge wie farbige Wollflocken\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxxv{und ein Freund nicht mehr nach einem Freunde fragen wird\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxxvi{werden sie in Sichtweite zueinander gebracht werden, und der Schuldige würde sich wohl (gern) loskaufen von der Strafe jenes Tages mit seinen Kindern\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxxvii{und seiner Frau und seinem Bruder\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxxviii{und seiner Verwandtschaft, die ihn beherbergt hat\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmccclxxxix{und allen, die insgesamt auf Erden sind, wenn es ihn nur retten könnte.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcccxc{Nein! Es ist wahrlich eine Feuerflamme\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcccxci{die die Kopfhaut gänzlich wegbrennt.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcccxcii{Den wird sie rufen, der (Mir) den Rücken kehrt und sich (von Mir) abwendet\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcccxciii{und (Reichtum) aufhäuft und hortet.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcccxciv{Wahrlich, der Mensch ist (seiner Natur nach) kleinmütig geschaffen worden.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcccxcv{Wenn ihn ein Unheil trifft, so gerät er in große Panik\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcccxcvi{doch wenn ihm (etwas) Gutes zukommt, ist er geizig.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcccxcvii{Nicht so sind diejenigen, die beten\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcccxcviii{und (die Verrichtung) ihrer Gebete einhalten\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmcccxcix{und die, in deren Besitztum ein bestimmter Anteil ist\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmcd{für den Bittenden und den Unbemittelten\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmcdi{und die, die an den Tag des Gerichts glauben\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmcdii{und die, die vor der Strafe ihres Herrn besorgt sind\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmcdiii{- wahrlich die Strafe ihres Herrn ist nichts, wovor man sicher sein könnte -\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmcdiv{und die, die ihre Scham bewahren\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmcdv{außer bei ihren Gattinnen oder denen, die sie von Rechts wegen besitzen; denn da sind sie nicht zu tadeln.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmcdvi{Diejenigen aber, die darüber hinaus etwas suchen, das sind die Übertreter.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmcdvii{Und die, die mit dem ihnen anvertrauten Gut redlich umgehen und erfüllen, wozu sie sich verpflichtet haben\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmcdviii{und die, die in ihrer Zeugenaussage aufrichtig sind\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmcdix{und die, die ihr Gebet getreulich verrichten\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmcdx{diese sind es, die in den Gärten hochgeehrt sein werden.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmcdxi{Was aber ist mit denen, die ungläubig sind, daß sie auf dich zugelaufen kommen\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmcdxii{von rechts und links, nach Gruppen plaziert?\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmcdxiii{Hofft jeder einzelne von ihnen wohl, den Garten der Wonne zu betreten?\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmcdxiv{Nimmermehr! Sie wissen doch, woraus Wir sie erschufen.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmcdxv{Aber nein! Ich schwöre beim Herrn der Aufgänge und der Untergänge, daß Wir imstande sind\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmcdxvi{bessere als sie an ihre Stelle zu setzen, und keiner kann Uns (daran) hindern.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmmcdxvii{So laß sie nur plaudern und sich vergnügen, bis sie ihrem Tag begegnen, der ihnen angedroht wird\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmmcdxviii{dem Tag, an dem sie aus ihren Gräbern eilends hervorkommen, als eilten sie zu ihren Götzenfiguren.\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmmcdxix{Ihre Augen werden niedergeschlagen sein; Schmach wird sie bedecken. Das ist der Tag, der ihnen angedroht wird.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmmcdxx{\basmalahde Wahrlich, Wir sandten Noah zu seinem Volk (und sprachen:) ``Warne dein Volk, bevor über sie eine schmerzliche Strafe kommt."\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxi{Er sagte: ``O mein Volk! Wahrlich, ich bin für euch ein deutlicher Warner\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxii{auf daß ihr Allah dienen und Ihn fürchten und mir gehorchen möget.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxiii{Dann wird Er euch etwas von euren Sünden vergeben und euch Aufschub bis zu einer bestimmten Frist gewähren. Wahrlich, Allahs Termin kann nicht verschoben werden, wenn er fällig ist - wenn ihr es nur wüßtet!"\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxiv{Er sagte: ``Mein Herr, ich habe mein Volk bei Nacht und Tag (zum Glauben) aufgerufen.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxv{Doch mein Ruf hat nur bewirkt, daß sie mehr und mehr davonliefen\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxvi{und sooft ich sie rief, daß Du ihnen vergeben mögest, steckten sie ihre Finger in die Ohren und hüllten sich in ihre Gewänder und verharrten (in ihrem Zustand) und wurden allzu hochmütig.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxvii{Dann rief ich sie in aller Öffentlichkeit auf.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxviii{Dann predigte ich ihnen öffentlich, und ich redete zu ihnen im geheimen\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxix{und ich sagte: ``Sucht Vergebung bei eurem Herrn; denn Er ist Allvergebend.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxx{Er wird Regen für euch in Fülle her niedersenden\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxxi{und Er wird euch mit Glücksgütern und Kindern stärken und wird euch Gärten bescheren und für euch Flüsse strömen lassen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxxii{Was ist mit euch, daß ihr Allah nicht (in der Ihm gebührenden Weise) ehrt\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxxiii{wo Er euch doch in (verschiedenen) Phasen erschaffen hat?\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxxiv{Habt ihr nicht gesehen, wie Allah sieben aufeinander geschichtete Himmel geschaffen hat\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxxv{und den Mond als ein Licht in sie gesetzt hat? Und gemacht hat Er die Sonne zu einer Leuchte.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxxvi{Und Allah hat euch wie die Pflanzen aus der Erde wachsen lassen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxxvii{Dann wird Er euch wieder in sie zurückkehren lassen, und Er wird euch dann aus ihr hervorbringen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxxviii{Und Allah hat die Erde für euch zu einer ausgelegten Fläche gemacht\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcdxxxix{auf daß ihr auf ihren gangbaren Wegen ziehen möget.""\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcdxl{Noah sagte: ``Mein Herr, sie haben mir nicht gehorcht und sind einem gefolgt, dessen Reichtum und Kinder nur sein Verderben verstärkt haben.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcdxli{Und sie haben gewaltige Ränke geschmiedet.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcdxlii{Und sie sagen (zueinander): ``Laßt eure Götter nicht im Stich. Und verlaßt weder Wadd noch Suwa noch Yagutund Yauq und Nasr."\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmcdxliii{Und wahrlich, sie haben viele verführt; so mache, daß die Ungerechten selber um so mehr in die Irre gehen."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmcdxliv{Ihrer Sünden wegen wurden sie ertränkt und in ein Feuer gebracht. Und dort konnten sie keine Helfer für sich gegen Allah finden.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmcdxlv{Und Noah sagte: ``Mein Herr, laß auf der Erdoberfläche keinen einzigen von den Ungläubigen (übrig)\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmcdxlvi{denn wenn Du sie läßt, so werden sie nur Deine Diener verführen und werden nur eine unverschämte Nachkommenschaft von Ungläubigen zeugen.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmcdxlvii{Mein Herr, vergib mir und meinen Eltern und dem, der mein Haus gläubig betritt, und den gläubigen Männern und den gläubigen Frauen; und stürze die Ungerechten aber um so tiefer ins Verderben."\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmcdxlviii{\basmalahde Sprich: ``Es wurde mir offenbart, daß eine Schar der Ginn zuhörte und dann sagte: ``Wahrlich, wir haben einen wunderbaren Quran gehört\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcdxlix{der zur Rechtschaffenheit leitet; so haben wir an ihn geglaubt, und wir werden unserem Herrn nie jemanden zur Seite stellen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcdl{Und (wir haben gehört,) daß unser Herr - Erhaben ist Er - Sich weder Gattin noch Sohn genommen hat\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcdli{und daß die Toren unter uns abscheuliche Lügen über Allah zu äußern pflegten.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcdlii{Und wir hatten angenommen, daß weder Menschen noch Ginn je eine Lüge über Allah sprechen würden\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcdliii{und daß freilich einige Leute von den Menschen bei einigen Leuten der Ginn Schutz zu suchen pflegten, so daß sie letztere in ihrer Schlechtigkeit bestärkten\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcdliv{und daß sie freilich dachten, ebenso wie ihr denkt, Allah würde nie einen (Propheten) erwecken.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcdlv{Und wir suchten den Himmel, doch wir fanden ihn mit starken Wächtern und (schießenden) Sternschnuppen erfüllt.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcdlvi{Und wir pflegten auf einigen seiner Sitze zu sitzen, um zu lauschen. Wer aber jetzt lauscht, der findet einen schießenden Stern für sich auf der Lauer.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcdlvii{Und wir wissen nicht, ob (etwas) Böses für diejenigen beabsichtigt ist, die auf Erden sind, oder ob ihnen der Herr (etwas) Gutes zukommen lassen will.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcdlviii{Und manche unter uns sind solche, die rechtschaffen (handeln), und manche unter uns sind weit davon entfernt; wir sind Sekten, die verschiedene Wege gehen.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcdlix{Und wir wissen, daß wir auf keine Weise Allah auf Erden zuschanden machen können, noch können wir Ihm durch Flucht entrinnen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcdlx{Und als wir aber von der Rechtleitung vernahmen, da glaubten wir an sie. Und der, der an seinen Herrn glaubt, fürchtet weder Einbuße noch Unrecht.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxi{Und manche unter uns sind Gottergebene, und manche unter uns sind vom rechten Weg abgewichen."" Und die sich ergeben haben diese haben den rechten Weg gefunden.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxii{Diejenigen, die aber vom rechten Wege abweichen, werden Brennstoff der Gahannam sein.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxiii{Wenn sie aber den (rechten) Weg einhalten, dann werden Wir ihnen reichlich Wasser zu trinken geben\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxiv{um sie dadurch zu prüfen. Wer sich dann von der Ermahnung seines Herrn abwendet - Er wird ihn in eine zunehmende Strafe stoßen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxv{Und wahrlich, die Moscheen sind Allahs; so ruft niemanden neben Allah an.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxvi{Und als der Diener Allahs aufstand, um zu Ihm zu beten, da umdrängten sie ihn, so daß sie sich fast erdrückten.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxvii{Sprich: ``lch rufe einzig meinen Herrn an, und ich stelle Ihm niemanden zur Seite."\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxviii{Sprich: ``lch habe nicht die Macht, euch Schaden oder Nutzen zuzufügen."\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxix{Sprich: ``Wahrlich, keiner kann mich vor Allah beschützen, noch kann ich eine Zuflucht außer bei Ihm finden.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxx{(lch habe) nur die Übermittlung (der Offenbarung) von Allah und Seine Botschaften (auszurichten)" Und für diejenigen, die sich Allah und Seinem Gesandten widersetzen, ist das Feuer der Hölle bestimmt; darin werden sie auf ewig bleiben.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxi{Wenn sie dann das sehen werden, das ihnen angedroht wird, so werden sie erfahren, wer schwächer an Helfern und geringer an Zahl ist.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxii{Sprich: ``lch weiß nicht, ob das euch Angedrohte nahe ist, oder ob mein Herr eine lange Frist dafür angesetzt hat."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxiii{Er ist der Kenner des Verborgenen - Er enthüllt keinem Seine Kenntnis vom Verborgenen\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxiv{außer allein dem, den Er unter Seinen Gesandten erwählt hat. Und dann läßt Er vor ihm und hinter ihm eine Schutzwache\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxv{damit Er gewährleistet sieht, daß sie (Seine Gesandten) die Botschaften ihres Herrn verkündet haben. Und Er umfaßt alles, was bei ihnen ist, und Er zeichnet alle Dinge ganz genau auf.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxvi{\basmalahde O du Verhüllter!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxvii{Verbringe die Nacht stehend (im Gebet) bis auf wenige Zeit davon\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxviii{die Hälfte von ihr, oder verringere sie ein wenig\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxix{oder füge ein wenig hinzu - und trage den Quran mit Tartil vor.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxx{Wahrlich, Wir legen dir da ein Wort auf, das gewichtig ist.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxxi{Wahrlich, der Anbruch der Nacht ist die beste Zeit zur Selbstzucht und zur Erreichung von Aufrichtigkeit im Reden.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxxii{Du hast ja gewiß während des Tages eine lange Beschäftigung.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxxiii{Und gedenke des Namens deines Herrn und wende dich Ihm von ganzem Herzen zu.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxxiv{(Er ist) der Herr des Ostens und des Westens - es ist kein Gott außer Ihm; darum nimm Ihn zum Beschützer.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxxv{Und ertrage in Geduld alles, was sie reden; und halte dich von ihnen in angenehmer Weise zurück.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxxvi{Und überlaß Mir diejenigen, die (die Wahrheit) leugnen und sich des Wohllebens erfreuen; und gewähre ihnen eine kurze Frist.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxxvii{Bei Uns sind wahrlich Fesseln und Gahim\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxxviii{und erstickende Speise und schmerzliche Strafe\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcdlxxxix{an dem Tage, da die Erde und die Berge erbeben und die Berge eine Menge zusammengesunkener Dünen sein werden.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcdxc{Wahrlich, Wir haben euch einen Gesandten geschickt, der euer Zeuge ist, wie Wir zu Pharao einen Gesandten geschickt hatten.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcdxci{Doch Pharao widersetzte sich dem Gesandten; darum erfaßten Wir ihn mit einem schrecklichen Strafgericht.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcdxcii{Wie wollt ihr euch, wenn ihr ungläubig seid, wohl vor einem Tag schützen, der Kinder zu Greisen macht?\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcdxciii{Der Himmel wird sich an ihm spalten! Seine Verheißung muß in Erfüllung gehen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcdxciv{Dies ist wahrlich eine Ermahnung. So nehme nun, wer da will, den Weg zu seinem Herrn.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcdxcv{Dein Herr weiß wahrlich, daß du (im Gebet etwas) weniger als zwei Drittel der Nacht stehst und (manchmal) eine Hälfte oder ein Drittel (der Nacht), und ein Teil derer, die mit dir sind (, tut desgleichen) Und Allah bestimmt das Maß der Nacht und des Tages. Er weiß, daß ihr sie (die Ausdauer) nicht werdet verkraften können. Darum hat Er Sich euch mit Nachsicht zugewandt. So tragt denn so viel vom Quran vor, wie es (euch) leicht fällt. Er weiß, daß einige unter euch sein werden, die krank sind, und andere, die im Lande umherreisen - nach Allahs Gnadenfülle strebend -, und wieder andere, die für Allahs Sache kämpfen. So tragt von ihm das vor, was (euch) leicht fällt, und verrichtet das Gebet und entrichtet die Zakah und gebt Allah ein gutes Darlehen. Und das, was ihr an Gutem für eure Seelen vorausschickt, werdet ihr bei Allah als besseren und größeren Lohn finden. Und bittet Allah um Vergebung. Wahrlich, Allah ist Allvergebend, Barmherzig.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcdxcvi{\basmalahde O du Bedeckter!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcdxcvii{Erhebe dich und warne\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcdxcviii{und verherrliche deinen Herrn\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcdxcix{und reinige deine Kleider\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmd{und meide den Götzendienst\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdi{und sei nicht wohltätig in Erwartung von persönlichen Vorteilen\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdii{und sei standhaft um deines Herrn willen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdiii{Wenn in den Sur gestoßen wird\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdiv{dann wird der Tag ein schwerer Tag sein\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdv{kein leichter für die Ungläubigen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdvi{Laß Mich mit dem, den Ich als Einsamen geschaffen habe\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdvii{und dem Ich Besitz in Fülle verlieh\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdviii{und Söhne, die immer zugegen waren\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdix{und für den Ich alle Bequemlichkeit bereitete.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdx{Dennoch wünscht er, daß Ich noch mehr gebe.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdxi{Nein; denn er ist Unseren Zeichen feindlich gesonnen gewesen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdxii{Ich werde ihm bald schreckliche Mühsal aufbürden.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdxiii{Siehe, er sann und wog ab!\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdxiv{Darum Verderben über ihn! Wie wog er ab!\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdxv{Wiederum Verderben über ihn! Wie wog er ab!\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmdxvi{Dann schaute er,\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmdxvii{dann runzelte er die Stirn und blickte verdrießlich,\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmdxviii{dann wandte er sich ab und wurde hochmütig\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmdxix{und sagte: ``Das ist nichts als Zauberei die weitergegeben wird.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmdxx{Das ist nur ein Menschenwort."\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmdxxi{Bald werde Ich ihn in Saqar brennen lassen.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmdxxii{Und wie kannst du wissen, was Saqar ist?\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmdxxiii{Sie verschont nichts und läßt nichts übrig\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmdxxiv{und wird von den Menschen aus großer Entfernung wahrgenommen\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmdxxv{sie wird von neunzehn (Engeln) überwacht.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmdxxvi{Und Wir haben einzig und allein Engel zu Hütern des Feuers gemacht. Und Wir setzten ihre Anzahl nicht fest, außer zur Prüfung derer, die ungläubig sind, auf daß die, denen das Buch gegeben wurde, Gewißheit erreichen, und auf daß die, die gläubig sind, an Glauben zunehmen, und auf daß die, denen die Schrift gegeben wurde, und die Gläubigen, nicht zweifeln, und auf daß die, in deren Herzen Krankheit ist, und die Ungläubigen sagen mögen: ``Was meint Allah mit diesem Gleichnis?" Somit erklärt Allah zum Irrenden, wen Er will, und leitet recht, wen Er will. Und keiner kennt die Heerscharen deines Herrn als Er allein. Dies ist nur eine Ermahnung für die Menschen.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmdxxvii{Nein, bei dem Mond\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmdxxviii{und bei der Nacht, wenn sie zu Ende geht\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmdxxix{und bei dem Morgen, wenn er anbricht!\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmdxxx{Wahrlich, es ist eine der größten (Katastrophen)\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmdxxxi{eine Warnung für die Menschen\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmdxxxii{für die unter euch, die vorwärts schreiten oder zurückbleiben wollen.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmdxxxiii{Ein jeder wird für das aufkommen, was er vorausgeschickt hat\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmdxxxiv{ausgenommen die von der Rechten\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmdxxxv{die einander in Gärten fragen\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmdxxxvi{nach den Schuldigen\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmmdxxxvii{``Was hat euch in Saqar gebracht?"\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmmdxxxviii{Sie sagen: ``Wir waren nicht bei denen die beteten\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmmdxxxix{noch speisten wir die Armen.\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmmdxl{Und wir ließen uns ein im Geschwätz mit den Schwätzern.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmmdxli{Und wir pflegten den Tag des Gerichts zu leugnen\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmmdxlii{bis der Tod uns ereilte."\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmmdxliii{Darum wird ihnen die Fürsprache der Fürsprecher nichts nützen.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmmdxliv{Was ist ihnen denn, daß sie sich von der Ermahnung abwenden\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmmdxlv{als wären sie erschreckte Wildesel\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmmdxlvi{die vor einem Löwen fliehen?\qt@no{(51)}}
\qt@newcmd\qurantrans@de@mmmmmdxlvii{Nein, jeder von ihnen wünscht, es möchten ihm offene Tafeln der Offenbarung gegeben werden.\qt@no{(52)}}
\qt@newcmd\qurantrans@de@mmmmmdxlviii{Nein! Wahrlich, sie fürchten nicht das Jenseits.\qt@no{(53)}}
\qt@newcmd\qurantrans@de@mmmmmdxlix{Nein! Wahrlich, dies ist eine Ermahnung.\qt@no{(54)}}
\qt@newcmd\qurantrans@de@mmmmmdl{So möge, wer da will, ihrer gedenken.\qt@no{(55)}}
\qt@newcmd\qurantrans@de@mmmmmdli{Und sie werden sich nicht ermahnen lassen, bis es Allah so will. Er ist der Ehrfurcht und der Vergebung Würdig.\qt@no{(56)}}
\qt@newcmd\qurantrans@de@mmmmmdlii{\basmalahde Ich schwöre beim Tag der Auferstehung\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdliii{und Ich schwöre bei jeder reumütigen Seele.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdliv{Meint der Mensch etwa, daß Wir seine Gebeine nicht sammeln werden?\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdlv{Aber ja, Wir sind imstande, seine Finger gleichmäßig zu formen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdlvi{Doch der Mensch wünscht sich, Sündhaftigkeit vorauszuschicken.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdlvii{Er fragt: ``Wann wird der Tag der Auferstehung sein?"\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdlviii{Dann, wenn das Auge geblendet ist\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdlix{und der Mond sich verfinstert\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdlx{und die Sonne und der Mond miteinander vereinigt werden.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdlxi{An jenem Tage wird der Mensch sagen: ``Wohin (könnte ich) nun fliehen?"\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdlxii{Nein! Es gibt keine Zuflucht!\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdlxiii{(Nur) bei deinem Herrn wird an jenem Tage die Endstation sein.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdlxiv{Verkündet wird dem Menschen an jenem Tage, was er vorausgeschickt und was er zurückgelassen hat.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdlxv{Nein, der Mensch ist Zeuge gegen sich selber\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdlxvi{auch wenn er seine Entschuldigungen vorbringt.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdlxvii{Bewege deine Zunge nicht mit ihm (dem Quran), um dich damit zu übereilen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdlxviii{Uns obliegt seine Sammlung und seine Verlesung.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdlxix{Darum folge seiner Verlesung, wenn Wir ihn verlesen lassen\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdlxx{dann obliegt Uns, seine Bedeutung darzulegen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxi{Nein, ihr aber liebt das Weltliche\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxii{und vernachlässigt das Jenseits.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxiii{An jenem Tage wird es strahlende Gesichter geben\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxiv{die zu ihrem Herrn schauen.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxv{Und manche Gesichter werden an jenem Tage gramvoll sein\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxvi{denn sie ahnen, daß ihnen bald darauf ein schreckliches Unglück widerfahren soll.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxvii{Ja! Wenn (die Seele eines Sterbenden) bis zum Schlüsselbein emporsteigt\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxviii{und gesprochen wird: ``Wer kann die Zauberformel sprechen(, um sie zu retten)?"\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxix{und er (der Mensch) wähnt, daß (die Stunde des) Abschieds gekommen ist\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxx{und (daß) sich Bein mit Bein (im Todeskampf) verfängt\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxxi{dann wird an jenem Tage das Treiben zu deinem Herrn sein\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxxii{denn er spendete nicht und betete nicht\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxxiii{sondern er leugnete und wandte sich (von Ihm) ab.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxxiv{Dann ging er mit stolzem Gang zu den Seinen.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxxv{``Wehe dir denn! Wehe!\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxxvi{Und abermals wehe dir! Und nochmals wehe!"\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxxvii{Meint der Mensch etwa, er würde sich selber überlassen sein?\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxxviii{War er nicht ein Erguß verspritzten Spermas?\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmdlxxxix{Dann wurde er ein Blutklumpen; dann bildete und vervollkommnete Er (ihn)\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmdxc{Alsdann schuf Er aus ihm ein Paar, den Mann und die Frau.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmdxci{Ist Er denn nicht imstande, die Toten ins Leben zu rufen?\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmdxcii{\basmalahde Gab es nicht für den Menschen eine Zeit, da er nichts Nennenswertes war?\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdxciii{Wahrlich, Wir erschufen den Menschen aus einer Ergußmischung, auf daß Wir ihn prüfen möchten; dann machten Wir ihn hörend und sehend.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdxciv{Wir haben ihm den rechten Weg gezeigt, möchte er nun dankbar oder undankbar sein.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdxcv{Wahr lich, Wir haben für die Ungläubigen Ketten, eiserne Nackenfesseln und einen Feuerbrand bereitet.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdxcvi{Die Rechtschaffenen aber trinken aus einem Becher, dem Kampfer beigemischt ist.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdxcvii{(Er wird gespeist aus) einer Quelle, von der die Diener Allahs trinken, und die sie in reichlichem Maße hervorsprudeln lassen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdxcviii{Sie vollbringen das Gelübde, und sie fürchten einen Tag, dessen Übel sich weithin ausbreitet.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdxcix{Und sie geben Speise und mag sie ihnen (auch) noch so lieb sein dem Armen, der Waise und dem Gefangenen\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdc{(indem sie sagen:) ``Wir speisen euch nur um Allahs willen. Wir begehren von euch weder Lohn noch Dank dafür.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdci{Wahrlich, wir fürchten von unserem Herrn einen finsteren, unheilvollen Tag."\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdcii{Darum wird Allah sie vor dem Übel jenes Tages bewahren und ihnen Herzensfreude und Glückseligkeit bescheren.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdciii{Und Er wird sie für ihre Geduld mit einem Paradies und seidenen (Gewändern) belohnen.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdciv{Darin lehnen sie auf erhöhten Sitzen, (und) sie werden dort weder Sonnenhitze noch Eiseskälte erleben.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdcv{Und seine Schatten werden tief auf sie herabreichen, und seine gebüschelten Früchte machen sich ganz leicht zu greifen.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdcvi{Und Trinkgefäße aus Silber werden unter ihnen die Runde machen, und Pokale, (durchsichtig) wie Glas\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdcvii{doch Gläser aus Silber, und sie werden ihren Umfang nach Maß bemessen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdcviii{Und es wird ihnen dort ein Becher zu trinken gereicht werden, dem Ingwer beigemischt ist.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdcix{(Er wird gespeist aus) einer Quelle darin, die Salsabil genannt wird.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdcx{Und es werden sie dort ewig junge Knaben bedienen. Wenn du sie siehst, hältst du sie für verstreute Perlen.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdcxi{Und wohin du dort auch schauen magst, so wirst du ein Wohlleben und ein großes Reich erblicken.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmdcxii{Sie werden Gewänder aus feiner, grüner Seide und Brokat tragen. Sie werden mit silbernen Spangen geschmückt sein. Und ihr Herr wird sie von einem reinen Trank trinken lassen.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmdcxiii{``Das ist euer Lohn, und euer Bemühen ist mit Dank angenommen worden ``\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmdcxiv{Wahrlich, Wir Selbst haben dir den Quran als Offenbarung herabgesandt.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmdcxv{So warte geduldig auf den Befehl deines Herrn und gehorche keinem, der ein Sünder oder ein Ungläubiger unter ihnen ist.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmdcxvi{Und gedenke des Namens deines Herrn am Morgen und am Abend.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmdcxvii{Und wirf dich in einem Teil der Nacht vor Ihm in Anbetung nieder und preise Seine Herrlichkeit einen langen Teil der Nacht hindurch.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmdcxviii{Wahrlich, diese lieben das Weltliche und vernachlässigen den Tag, der hinterher auf (ihnen) lastet.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmdcxix{Wir haben sie erschaffen und ihrer Beschaffenheit Festigkeit verliehen; und wenn Wir wollen, können Wir andere ihresgleichen an ihre Stelle setzten.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmdcxx{Wahrlich, dies ist eine Ermahnung. So möge, wer da will, einen Weg zu seinem Herrn einschlagen.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxi{Und ihr könnt nur wollen, wenn Allah will. Wahrlich, Allah ist Allwissend, Allweise.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxii{Er läßt, wen Er will, in Seine Barmherzigkeit eingehen, und für die Ungerechten hat Er eine qualvolle Strafe bereitet.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxiii{\basmalahde Bei den Windstößen, die einander folgen\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxiv{und bei den Stürmen, die durcheinander wirbeln\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxv{und bei den (Engeln), die stets (die Wolken) verbreiten\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxvi{und dann zwischen (Gut und Böse) unterscheiden\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxvii{und dann die Ermahnung überall hinabtragen\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxviii{um zu entschuldigen oder zu warnen!\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxix{Wahrlich, was euch verheißen wird, wird bestimmt in Erfüllung gehen\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxx{dann, wenn die Sterne erlöschen\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxxi{und der Himmel sich öffnet\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxxii{und wenn die Berge hinweggeblasen sind\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxxiii{und die Gesandten zu ihrer vorbestimmten Zeit gebracht werden.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxxiv{Für welchen Tag sind (diese Geschehnisse) aufgeschoben worden?\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxxv{Für den Tag der Entscheidung.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxxvi{Und wie kannst du wissen, was der Tag der Entscheidung ist?\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxxvii{Wehe an jenem Tag den Leugnern!\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxxviii{Haben Wir nicht die früheren (Generationen) vernichtet\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdcxxxix{alsdann ihnen die späte ren folgen lassen?\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdcxl{So verfahren Wir mit den Schuldigen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdcxli{Wehe an jenem Tag den Leugnern!\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdcxlii{Schufen Wir euch nicht aus einer verächtlichen Flüssigkeit\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmdcxliii{die Wir dann an eine geschützte Bleibe brachten\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmdcxliv{für eine bestimmte Fügung?\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmdcxlv{So setzten Wir das Maß fest. Wie trefflich ist Unsere Bemessung!\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmdcxlvi{Wehe an jenem Tag den Leugnern!\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmdcxlvii{Haben Wir die Erde nicht zu eurer Aufnahme ge macht\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmdcxlviii{für die Lebenden und die Toten\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmdcxlix{und auf sie hohe Berge gesetzt und euch wohlschmeckendes Wasser zu trinken gegeben?\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmdcl{Wehe an jenem Tag den Leugnern!\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmdcli{``Geht nun hin zu dem, was ihr verleugnet habt.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmdclii{Geht hin zu einem Schatten, der drei Verzweigungen hat\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmdcliii{der weder Schatten spendet noch vor der Flamme schützt."\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmdcliv{Siehe, sie (die Hölle) wirft Funken gleich den Türmen eines Palastes empor\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmdclv{als wären sie Kamele von hellgelber Farbe.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmdclvi{Wehe an jenem Tag den Leugnern!\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmdclvii{Das ist ein Tag, an dem ihnen die Sprache versagt.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmdclviii{Es wird ihnen nicht erlaubt sein, Entschuldigungen vorzubringen.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmdclix{Wehe an jenem Tag den Leugnern!\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmdclx{Dies ist der Tag der Entscheidung. Wir haben euch und die Früheren versammelt.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmdclxi{Habt ihr nun eine List, so setzt eure List gegen Mich ein.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmdclxii{Wehe an jenem Tag den Leugnern!\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmdclxiii{Die Gottesfürchtigen werden inmitten von Schatten und Quellen sein\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmmdclxiv{und Früchten, welche sie sich wünschen.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmmdclxv{``Esset und trinkt in Gesundheit um dessentwillen, was ihr getan habt."\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmmdclxvi{Wahrlich, so belohnen Wir diejenigen, die Gutes tun\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmmdclxvii{Wehe an jenem Tag den Leugnern!\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmmdclxviii{``Esset und ergötzt euch eine kleine Weile. Gewiß, ihr seid die Sünder."\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmmdclxix{Wehe an jenem Tag den Leugnern!\qt@no{(47)}}
\qt@newcmd\qurantrans@de@mmmmmdclxx{Und wenn zu ihnen gesprochen wird: ``Beugt euch!" beugen sie sich nicht.\qt@no{(48)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxi{Wehe an jenem Tag den Leugnern!\qt@no{(49)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxii{An welches Wort, nach diesem, wollen sie denn glauben?\qt@no{(50)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxiii{\basmalahde Wonach befragen sie einander?\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxiv{Nach einer gewaltigen Ankündigung\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxv{über die sie uneinig sind.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxvi{Nein! Sie werden es bald erfahren.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxvii{Und abermals nein! Sie werden es bald erfahren.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxviii{Haben Wir nicht die Erde zu einem Lager gemacht\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxix{und die Berge zu Pflöcken?\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxx{Und Wir haben euch in Paaren erschaffen\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxxi{und Wir haben euch den Schlaf zur Ruhe gemacht\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxxii{und die Nacht zu einer Hülle\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxxiii{und den Tag zum Erwerb des Unterhalts\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxxiv{und Wir haben über euch sieben starke (Himmel) erbaut\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxxv{und Wir haben eine hellbrennende Leuchte gemacht\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxxvi{und Wir senden aus den Regenwolken Wasser in Strömen hernieder\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxxvii{auf daß Wir damit Korn und Kraut hervorbringen\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxxviii{sowie üppige Gärten.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdclxxxix{Wahrlich, der Tag der Entscheidung ist ein fester Termin\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdcxc{an jenem Tag, da in den Sur gestoßen wird und ihr in Scharen kommt\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdcxci{und der Himmel sich öffnet und zu Toren wird\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdcxcii{und die Berge sich bewegen und zur Luftspiegelung werden.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmdcxciii{Wahrlich, Gahannam ist ein Hinterhalt\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmdcxciv{- eine Heimstätte für die Widerspenstigen\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmdcxcv{die dort Epoche für Epoche bleiben\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmdcxcvi{sie werden dort weder Kühle noch Trank kosten\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmdcxcvii{außer siedendem Wasser und Eiter.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmdcxcviii{(Dies ist) ein Lohn in angemessener Weise\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmdcxcix{(weil) sie mit keiner Rechenschaft gerechnet haben\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmdcc{und gänzlich Unsere Zeichen verleugneten.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmdcci{Und alle Dinge haben Wir restlos niedergeschrieben.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmdccii{``Kostet! Wir werden es euch nicht anders mehren als in der Pein."\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmdcciii{Wahrlich, für die Gottesfürchtigen gibt es einen Gewinn\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmdcciv{Gärten und Beerengehege\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmdccv{und Mädchen mit schwellenden Brüsten, Altersgenossinnen\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmdccvi{und übervolle Schalen.\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmdccvii{Dort hören sie weder Geschwätz noch Lüge\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmdccviii{(dies ist) ein Lohn von deinem Herrn - eine angemessene Gabe.\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmdccix{Dem Herrn der Himmel und der Erde und alles dessen, was zwischen den beiden ist, dem Allerbarmer; Dem sie nichts vortragen können.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmdccx{Am Tage, da Gabriel und die Engel in Reihen stehen, da werden sie nicht sprechen dürfen; ausgenommen der, dem der Allerbarmer es erlaubt, und der nur das Rechte spricht.\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmdccxi{Dies ist gewiß der Tag. So möge, wer da will, bei seinem Herrn Einkehr halten.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmdccxii{Wahrlich, Wir haben euch gewarnt vor einer Strafe, die nahe bevorsteht: an einem Tag, da der Mensch erblicken wird, was seine Hände vorausgeschickt haben, und der Ungläubige sagen wird: ``O daß ich doch Staub wäre!"\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmdccxiii{\basmalahde Bei den (Engeln, die die Seelen der Ungläubigen) heftig entreißen\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdccxiv{und bei denen (, die die Seelen der Gläubigen) leicht emporheben\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdccxv{und bei denen (, die auf Geheiß Allahs zwischen Himmel und Erde) einher schweben\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdccxvi{dann bei denen (, die mit den Seelen der Gläubigen ins Paradies) eifrig voraneilen\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdccxvii{dann bei denen, die jegliche Angelegenheit (des irdischen Lebens) lenken!\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdccxviii{Eines Tages wird die Dröhnende dröhnen\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdccxix{gefolgt von der Darauffolgenden.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdccxx{Herzen werden an jenem Tage zittern\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxi{und ihre Augen werden niedergeschlagen sein.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxii{Sie sagen: ``Sollen wir wirklich in unseren früheren Zustand zurückgebracht werden?\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxiii{Wie? Selbst wenn wir verwestes Gebein geworden sind?"\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxiv{Sie sagen: ``Das wäre dann eine verlustreiche Wiederkehr."\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxv{Es wird nur ein einziger Schreckenslaut sein\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxvi{und siehe, sie sind dann auf der Erdoberfläche.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxvii{Ist die Geschichte von Moses zu dir gedrungen?\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxviii{Damals rief ihn sein Herr im heiligen Wadi Tuwa\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxix{``Geh hin zu Pharao; denn er hat das Maß überschritten.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxx{Sprich dann (zu ihm): ``Willst du dich nicht reinigen?\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxxi{Und ich werde dich zu deinem Herrn führen, auf daß du dich fürchten mögest!""\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxxii{So zeigte er ihm das große Wunder.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxxiii{Er aber leugnete und blieb ungehorsam.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxxiv{Dann kehrte er den Rücken und lief weg\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxxv{versammelte alsdann (sein Volk) und rief aus\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxxvi{indem er sagte: ``lch bin euer höchster Herr."\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxxvii{Da erfaßte ihn Allah zur Strafe für jene und diese Tat.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxxviii{Hierin ist wahrlich eine Lehre für den, der fürchtet.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmdccxxxix{Seid ihr denn schwerer zu erschaffen oder der Himmel, den Er gebaut hat?\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmdccxl{Er hat seine Höhe gehoben und ihn dann vollkommen gemacht.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmdccxli{Und Er machte seine Nacht finster und ließ sein Tageslicht hervorgehen.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmdccxlii{Und Er breitete hernach die Erde aus.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmdccxliii{Aus ihr brachte Er ihr Wasser und ihr Weideland hervor.\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmdccxliv{Und Er festigte die Berge\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmdccxlv{(dies alles) als eine Versorgung für euch und für euer Vieh.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmdccxlvi{Doch wenn das größte Unheil kommt\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmdccxlvii{an jenem Tag, da der Mensch sich (all) das ins Gedächtnis zurückrufen wird, was er erstrebt hat\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmdccxlviii{und die Gahim vor Augen gestellt wird für den, der sieht\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmdccxlix{Wer aber aufsässig war\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmdccl{und das irdische Leben vorzog\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmdccli{so wird wahrlich die Gahim (seine) Herberge sein.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmdcclii{Wer aber das Stehen vor seinem Herrn gefürchtet hatte und die eigne Seele von niedrem Gelüst abhielt\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmdccliii{so wird das Paradies sicherlich (seine) Herberge sein.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmmdccliv{Sie befragen dich wegen der Stunde: ``Wann wird ihr Termin wohl sein?"\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmmdcclv{Was weißt du von ihr zu sagen!\qt@no{(43)}}
\qt@newcmd\qurantrans@de@mmmmmdcclvi{Das endgültige Wissen darum ist allein deinem Herrn (vorbehalten)\qt@no{(44)}}
\qt@newcmd\qurantrans@de@mmmmmdcclvii{Du bist nur ein Warner für den, der sie fürchtet.\qt@no{(45)}}
\qt@newcmd\qurantrans@de@mmmmmdcclviii{An jenem Tage, an dem sie sie schauen, als hätten sie (auf der Erde) nicht länger geweilt als einen Abend oder den Morgen darauf.\qt@no{(46)}}
\qt@newcmd\qurantrans@de@mmmmmdcclix{\basmalahde Er runzelte die Stirn und wandte sich ab\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdcclx{als der blinde Mann zu ihm kam.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxi{Was läßt dich aber wissen, daß er sich nicht reinigen wollte\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxii{oder daß er Ermahnung suchte und ihm somit die Lehre nützlich würde?\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxiii{Wer aber es nicht für nötig hält\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxiv{dem kommst du (bereitwillig) entgegen\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxv{ohne dir etwas daraus zu machen, daß er sich nicht reinigen will.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxvi{Was aber den anbelangt, der in Eifer zu dir kommt\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxvii{und gottesfürchtig ist\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxviii{um den kümmerst du dich nicht.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxix{Nicht so. Wahrlich, dies ist eine Ermahnung\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxx{so möge, wer da will, diesem eingedenk sein.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxi{Auf geehrten Seiten, die in Ehren gehalten werden\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxii{sind sie emporgehoben, rein\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxiii{in den Händen rechtschaffener Sendboten\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxiv{die edel und tugendhaft sind.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxv{Verderben auf den Menschen! Wie undankbar ist er!\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxvi{Woraus hat Er ihn erschaffen?\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxvii{Aus einem Samenerguß hat Er ihn erschaffen und gebildet.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxviii{Dann ermöglicht Er ihm den Ausgang.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxix{Dann läßt Er ihn sterben und läßt ihn ins Grab bringen.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxx{Dann, wenn Er will, erweckt Er ihn wieder.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxxi{Wahrlich; er hat nicht getan, was Er ihm geboten hat.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxxii{So soll der Mensch doch seine Nahrung betrachten.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxxiii{Siehe, Wir gossen das Wasser in Fülle aus.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxxiv{alsdann spalteten Wir die Erde in wunderbarer Weise\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxxv{und ließen Korn in ihr wachsen\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxxvi{und Reben und Gezweig\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxxvii{und Ölbäume und Palmen\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxxviii{und dicht bepflanzte Gartengehege\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmdcclxxxix{und Obst und Futtergras\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmdccxc{als Versorgung für euch und euer Vieh.\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmdccxci{Doch wenn das betäubende Getöse kommt\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmdccxcii{am Tage, da der Mensch seinen Bruder fluchtartig verläßt\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmdccxciii{sowie seine Mutter und seinen Vater\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmdccxciv{und seine Frau und seine Söhne\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmdccxcv{an jenem Tage wird jeder eigene Sorgen genug haben, die ihn beschäftigen.\qt@no{(37)}}
\qt@newcmd\qurantrans@de@mmmmmdccxcvi{An jenem Tage werden manche Gesichter strahlend sein\qt@no{(38)}}
\qt@newcmd\qurantrans@de@mmmmmdccxcvii{heiter und freudig.\qt@no{(39)}}
\qt@newcmd\qurantrans@de@mmmmmdccxcviii{Und andere Gesichter, an jenem Tage, werden staubbedeckt sein.\qt@no{(40)}}
\qt@newcmd\qurantrans@de@mmmmmdccxcix{Trübung wird darauf liegen.\qt@no{(41)}}
\qt@newcmd\qurantrans@de@mmmmmdccc{Das sind die Ungläubigen, die Unverschämten.\qt@no{(42)}}
\qt@newcmd\qurantrans@de@mmmmmdccci{\basmalahde Wenn die Sonne eingerollt ist\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdcccii{und wenn die Sterne trübe sind\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdccciii{und wenn die Berge fortbewegt werden\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdccciv{und wenn die trächtigen Kamelstuten vernachlässigt werden\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdcccv{und wenn wildes Getier versammelt wird\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdcccvi{und wenn die Meere zu einem Flammenmeer werden\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdcccvii{und wenn die Seelen (mit ihren Leibern) gepaart werden\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdcccviii{und wenn das lebendig begrabene Mädchen gefragt wird\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdcccix{``Für welch ein Verbrechen wurdest du getötet?"\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdcccx{Und wenn Schriften weithin aufgerollt werden\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxi{und wenn der Himmel weggezogen wird\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxii{und wenn die Gahim angefacht wird\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxiii{und wenn das Paradies nahegerückt wird\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxiv{dann wird jede Seele wissen, was sie mitgebracht hat.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxv{Wahrlich, Ich schwöre bei den rückläufigen Sternen\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxvi{den voraneilenden und den sich verbergenden\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxvii{und bei der Nacht, wenn sie vergeht\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxviii{und Ich schwöre beim Morgen, wenn er zu aufatmen beginnt\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxix{daß dies in Wahrheit ein Wort eines edlen Boten ist\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxx{der mit Macht begabt ist bei dem Herrn des Throns und in Ansehen steht\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxi{dem gehorcht wird und der getreu ist\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxii{und euer Gefährte ist nicht ein Besessener.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxiii{Wahrlich, er sah ihn am klaren Horizont.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxiv{Und er ist weder geizig hinsichtlich des Verborgenen\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxv{noch ist dies das Wort Satans, des Verfluchten.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxvi{Wohin also wollt ihr gehen?\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxvii{Dies ist ja nur eine Ermahnung für alle Welten.\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxviii{Für denjenigen unter euch, der aufrichtig sein will.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxix{Und ihr werdet nicht wollen, es sei denn, daß Allah will, der Herr der Welten.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxx{\basmalahde Wenn der Himmel sich spaltet\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxxi{und wenn die Sterne zerstreut sind\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxxii{und wenn die Meere über die Ufer treten\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxxiii{und wenn die Gräber ausgeräumt werden\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxxiv{dann wird jede Seele wissen, was sie getan und was sie unterlassen hat.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxxv{O du Mensch! Was hat dich hinsichtlich deines Ehrwürdigen Herrn betört\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxxvi{Der dich erschuf und dich dann ebenmäßig geformt, und in einer geraden Gestalt gemacht hat?\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxxvii{In solchem Bild, das Er immer wollte, hat Er dich zusammengesetzt.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxxviii{Seht aber, wie ihr das Gericht leugnet!\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxxxix{Und über euch sind wahrlich Hüter\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxl{edle Schreibende\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxli{die wissen, was ihr tut.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxlii{Wahrlich, die Rechtschaffenen werden in der Wonne sein\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxliii{und wahrlich, die Unverschämten werden in der Gahim sein.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxliv{Sie werden dort brennen am Tage des Gerichts.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxlv{Und sie werden nicht imstande sein, daraus zu entrinnen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxlvi{Und was lehrt dich wissen, was der Tag des Gerichts ist?\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxlvii{Und wiederum, was lehrt dich wissen, was der Tag des Gerichts ist?\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxlviii{An jenem Tag wird keine Seele etwas für eine andere Seele zu tun vermögen; und der Befehl an jenem Tage steht (einzig) Allah zu.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxlix{\basmalahde Wehe denjenigen, die das Maß verkürzen\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdcccl{die, wenn sie sich von den Leuten zumessen lassen, volles Maß verlangen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdcccli{Und dann jedoch, wenn sie es ihnen ausmessen oder auswägen, verkürzen sie es.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdccclii{Glauben diese nicht, daß sie auferweckt werden\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdcccliii{an einem großen Tag\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdcccliv{an dem die Menschen vor dem Herrn der Welten stehen werden?\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdccclv{Nein! Das Buch der Unverschämten ist in Siggin.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdccclvi{Und was lehrt dich wissen, was Siggin ist?\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdccclvii{(Es ist) ein geschriebenes Buch.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdccclviii{Wehe an jenem Tage den Leugnern\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdccclix{die den Tag des Gerichts leugnen!\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdccclx{Und es leugnet ihn keiner als ein jeder sündhafter Übertreter\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxi{der, wenn ihm Unsere Verse verlesen werden, sagt: ``Fabeln der Früheren!"\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxii{Nein, jedoch das, was sie zu tun pflegten, hat auf ihre Herzen Schmutz gelegt.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxiii{Nein, sie werden an jenem Tage gewiß keinen Zugang zu ihrem Herrn haben.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxiv{Dann werden sie doch in der Gahim brennen.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxv{Und es wird gesprochen werden: ``Dies ist es, was ihr zu leugnen pflegtet!"\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxvi{Nein! Das Buch der Rechtschaffenen ist gewiß in Illiyun.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxvii{Und was lehrt dich wissen, was `Illiyun ist?\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxviii{(Es ist) ein geschriebenes Buch.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxix{Die Erwählten (Allahs) werden es sehen.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxx{Wahrlich, die Rechtschaffenen werden in Wonne sein.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxi{Auf Ruhesitzen werden sie zuschauen.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxii{Erkennen wirst du auf ihren Gesichtern den Glanz der Seligkeit.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxiii{Ihnen wird ein reiner, versiegelter Trank gegeben\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxiv{dessen Siegel Moschus ist - und um dies mögen die Begehrenden wetteifern.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxv{Und es wird ihm von Tasnim beige mischt sein\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxvi{von einer Quelle, aus der die Erwählten trinken werden.\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxvii{Jene Frevler haben sich über die Gläubigen lustig gemacht\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxviii{und wenn sie an ihnen vorübergingen, blinzelten sie einander zu\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxix{und wenn sie zu den Ihren zurückkehrten, kehrten sie frohlockend zurück\qt@no{(31)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxx{und wenn sie sie sahen, sagten sie: ``Das sind wahrlich Irrende"\qt@no{(32)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxxi{obwohl sie nicht als Hüter über sie gesandt worden waren.\qt@no{(33)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxxii{Heute aber sind die Gläubigen diejenigen, die sich über die Ungläubigen lustig machen\qt@no{(34)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxxiii{sie schauen von ihren Ruhesitzen zu.\qt@no{(35)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxxiv{Hat es sich für die Ungläubigen gelohnt, was sie getan haben?\qt@no{(36)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxxv{\basmalahde Wenn der Himmel zerbricht\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxxvi{und seinem Herrn gehorcht und sich Ihm gefügig zeigt\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxxvii{und wenn die Erde ausgebreitet wird\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxxviii{und herauswirft, was sie verbirgt, und sich (von allem) freimacht\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmdccclxxxix{und ihrem Herrn gehorcht und sich Ihm gefügig zeigt.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxc{Du Mensch! Du strebst mit aller Mühe deinem Herrn zu; und du sollstIhm begegnen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxci{Was nun den anbelangt, dem sein Buch in seine Rechte gegeben wird\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxcii{der wird einer leichten Rechenschaft unterzogen sein\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxciii{und wird fröhlich zu seinen Angehörigen zurückkehren.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxciv{Was aber den anbelangt, dem sein Buch hinter seinem Rücken gegeben wird\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxcv{der wird sich bald Vernichtung herbeiwünschen\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxcvi{und wird im Höllenfeuer brennen\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxcvii{er war gewiß glücklich unter seinen Angehörigen.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxcviii{Siehe, er dachte, daß er nie davon abkommen (und zu Allah zurückkehren) würde.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmdcccxcix{Wahrlich, sein Herr hat ihn wohl durchschaut.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcm{Doch! Ich schwöre bei der Abenddämmerung\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcmi{und bei der Nacht und dem, was sie verhüllt\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcmii{und bei dem Mond, wenn er voll wird\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcmiii{daß ihr sicherlich von einem Zustand (der Not) in den anderen versetzt werdet.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcmiv{Was also ist ihnen, daß sie nicht glauben\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcmv{und wenn ihnen der Quran verlesen wird, sich nicht in Anbetung niederwerfen?\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcmvi{Im Gegenteil, die da ungläubig sind, erklären (die Botschaft Allahs) für eine Lüge.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcmvii{Und Allah weiß am besten, was sie verbergen.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmcmviii{Darum verkünde ihnen eine schmerzliche Strafe.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmcmix{Nicht so denjenigen, die glauben und gute Werke tun - ihnen wird unendlicher Lohn zuteil sein.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmcmx{\basmalahde Beim Himmel mit seinen Türmen\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcmxi{und beim verheißenen Tage\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcmxii{und beim Zeugen und beim Bezeugten!\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcmxiii{Verflucht sind die Leute des Grabens\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcmxiv{des Feuers, mit seinem Brennstoff.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcmxv{Wie sie daran saßen!\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcmxvi{Und sie werden das bezeugen, was sie den Gläubigen angetan haben.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcmxvii{Und sie haßten sie aus keinem anderen Grund, als weil sie an Allah glaubten, den Erhabenen, den Preiswürdigen\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcmxviii{Dem das Königreich der Himmel und der Erde gehört; und Allah ist Zeuge von allem.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcmxix{Diejenigen, die die gläubigen Männer und die gläubigen Frauen heimsuchen und es dann nicht bereuen - für sie ist die Strafe der Gahannam, und für sie ist die Strafe des Brennens (bestimmt)\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcmxx{Doch jene, die glauben und gute Werke tun - für sie sind die Gärten, durch die Bäche fließen (, bestimmt) Das ist der größte Gewinn.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxi{Wahrlich, die Rache deines Herrn ist enorm.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxii{Er ist es, Der erschafft und wiederkehren läßt.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxiii{Und Er ist der Allvergebende, der Liebvolle\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxiv{Der Herr des Ruhmvollen Throns.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxv{Er tut, was Er will.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxvi{Hat die Geschichte von den Heerscharen dich erreicht\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxvii{von Pharao und den Tamud?\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxviii{Nein, aber die Ungläubigen bestehen auf dem Leugnen\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxix{und Allah ist hinter ihnen her (und) umfaßt sie von allen Seiten.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxx{Ja, es ist ein ruhmvoller Quran\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxxi{auf einer wohlverwahrten Tafel.\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxxii{\basmalahde Bei dem Himmel und bei At-Tariq!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxxiii{Und was lehrt dich wissen, was At-Tariq ist?\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxxiv{(Es ist) ein Stern von durchdringender Helligkeit.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxxv{Wahrlich, jede Seele hat über sich einen Hüter.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxxvi{Darum soll der Mensch denn bedenken, woraus er erschaffen ist!\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxxvii{Erschaffen wurde er aus einer herausschießenden Flüssigkeit\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxxviii{das zwischen den Lenden und den Rippen hervorkommt.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcmxxxix{Wahrlich, Er hat die Macht, ihn zurückzubringen\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcmxl{am Tage, wenn die Geheimnisse enthüllt werden\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcmxli{dann wird er keine Kraft und keinen Helfer haben.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcmxlii{Und beim Himmel mit seiner Wiederkehr\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcmxliii{und bei der Erde, die sich spaltet!\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcmxliv{Dies ist wahrlich ein entscheidendes, letztes Wort\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcmxlv{und es ist nicht zum Scherzen.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcmxlvi{Wahrlich, sie planen eine List.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcmxlvii{Und Ich plane eine List.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcmxlviii{Darum gewähre nun den Ungläubigen Aufschub, ein klein wenig Aufschub.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcmxlix{\basmalahde Preise den Namen deines Allerhöchsten Herrn\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcml{Der erschaffen und geformt hat\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcmli{Der bestimmt und leitet\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcmlii{Der die Weide hervorbringt\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcmliii{und sie zu versengter Spreu macht.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcmliv{Wir werden dir (den Quran) verlesen lassen, und du sollst (ihn) nicht vergessen\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcmlv{es sei denn, was Allah will; denn Er kennt das Offenkundige und das Verborgene.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcmlvi{Und Wir werden es dir zum Heil leicht machen.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcmlvii{So ermahne, wo die Ermahnung nützt!\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcmlviii{Mahnen lassen wird sich derjenige, der gottesfürchtig ist\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcmlix{Ermahnung meiden wird der Unselige\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcmlx{der im größten Feuer brennt\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxi{und in ihm wird er weder sterben noch leben.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxii{Erfolgreich ist wahrlich derjenige, der sich rein hält\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxiii{und des Namens seines Herrn gedenkt (und) alsdann betet.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxiv{Doch ihr zieht das irdische Leben vor\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxv{wo doch das Jenseits besser und dauerhafter ist.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxvi{Dies stand wahrlich in den ersten Schriften\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxvii{den Schriften Abrahams und Moses'.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxviii{\basmalahde Hat die Geschichte der Al-Gasiya dich erreicht?\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxix{Manche Gesichter werden an jenem Tag niedergeschlagen sein\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxx{sie werden sich plagen und abmühen\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxi{sie werden in einem heißen Feuer brennen\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxii{sie werden aus einer kochendheißen Quelle trinken\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxiii{für sie wird es keine andere Speise geben außer Dornsträuchern\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxiv{die weder nähren noch Hunger stillen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxv{(Und manche) Gesichter werden an jenem Tage fröhlich sein\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxvi{wohlzufrieden mit ihrer Mühe\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxvii{in einem hohen Garten\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxviii{in dem sie kein Geschwätz hören\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxix{in dem eine strömende Quelle ist\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxx{in dem es erhöhte Ruhebetten gibt\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxxi{und bereitgestellte Becher\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxxii{und aufgereihte Kissen\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxxiii{und ausgebreitete Teppiche.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxxiv{Schauen sie denn nicht zu den Kamelen, wie sie erschaffen sind\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxxv{und zu dem Himmel, wie er emporgehoben ist\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxxvi{und zu den Bergen, wie sie aufgerichtet sind\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxxvii{und zu der Erde, wie sie ausgebreitet worden ist?\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxxviii{So ermahne; denn du bist zwar ein Ermahner\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmcmlxxxix{du hast aber keine Macht über sie\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmcmxc{was jedoch den anbelangt, der sich abkehrt und im Unglauben verharrt.\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmcmxci{Allah wird ihn dann mit der schwersten Strafe bestrafen.\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmcmxcii{Zu Uns ist ihre Heimkehr.\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmcmxciii{Alsdann obliegt es Uns, mit ihnen abzurechnen.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmcmxciv{\basmalahde Bei der Morgenröte\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmcmxcv{und bei den zehn Nächten\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmcmxcvi{und beim (an Zahl) Geraden und Ungeraden\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmcmxcvii{und bei der Nacht, wenn sie vergeht!\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmcmxcviii{Ist hierin ein ausreichender Beweis für einen, der Verstand hat?\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmcmxcix{Hast du nicht gesehen, wie dein Herr mit den `Ad verfuhr\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmm{mit Iram, der Säulenreichen\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmi{dergleichen nicht erschaffen wurde in (anderen) Ländern?\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmii{Und den Tamud, die die Felsen im Tal aushöhlten?\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmmiii{Und Pharao mit seinen bodenfesten Bauten?\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmmiv{Denjenigen, die im Lande gewalttätig waren\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmmv{und dort viel Verderbnis stifteten?\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmmvi{Darum ließ dein Herr die Geißel der Strafe auf sie schütten.\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmmvii{Wahrlich, dein Herr ist auf der Hut.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmmviii{Wenn aber der Mensch von seinem Herrn geprüft wird, indem Er ihm Wohltaten erweist und Gnaden auf ihn häuft, dann sagt er: ``Mein Herr hat mich gewürdigt."\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmmix{Wenn Er ihn aber prüft, indem Er ihm seine Versorgung verkürzt, dann sagt er: ``Mein Herr hat mich erniedrigt."\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmmx{Nein, ihr seid nicht freigebig gegen die Waise\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmmxi{und treibt einander nicht an, den Armen zu speisen.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmmxii{Und ihr verzehrt das Erbe (anderer) ganz und gar.\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmmxiii{Und ihr liebt den Reichtum mit übermäßiger Liebe.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmmxiv{Nicht aber so wenn die Erde kurz und klein zermalmt wird\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmmxv{und dein Herr kommt und (auch) die Engel in Reihen auf Reihen (kommen)\qt@no{(22)}}
\qt@newcmd\qurantrans@de@mmmmmmxvi{und Gahannam an jenem Tage nahegebracht wird. An jenem Tage wird der Mensch bereit sein, sich mahnen zu lassen; aber was wird ihm dann das Mahnen nutzen?\qt@no{(23)}}
\qt@newcmd\qurantrans@de@mmmmmmxvii{Er wird sagen: ``O hätte ich doch im voraus für (dieses) mein Leben Sorge getragen!"\qt@no{(24)}}
\qt@newcmd\qurantrans@de@mmmmmmxviii{An jenem Tag wird niemand so bestrafen wie Er\qt@no{(25)}}
\qt@newcmd\qurantrans@de@mmmmmmxix{und niemand wird so festbinden wie Er.\qt@no{(26)}}
\qt@newcmd\qurantrans@de@mmmmmmxx{O du ruhige Seele!\qt@no{(27)}}
\qt@newcmd\qurantrans@de@mmmmmmxxi{Komm zufrieden zurück zu deinem Herrn und mit (Allahs) Wohlwollen\qt@no{(28)}}
\qt@newcmd\qurantrans@de@mmmmmmxxii{so schließ' dich dem Kreis Meiner Diener an.\qt@no{(29)}}
\qt@newcmd\qurantrans@de@mmmmmmxxiii{Und tritt ein in Mein Paradies.\qt@no{(30)}}
\qt@newcmd\qurantrans@de@mmmmmmxxiv{\basmalahde Ich schwöre bei dieser Ortschaft.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmxxv{Und du wohnst in dieser Ortschaft\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmxxvi{und bei dem Zeugenden und bei dem, was er gezeugt hat.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmxxvii{Wahrlich, Wir haben den Menschen (zu einem Dasein) in Bedrängnis erschaffen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmxxviii{Meint er, niemand habe Macht über ihn?\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmxxix{Er sagt: ``lch habe viel Vermögen ausgegeben."\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmxxx{Meint er, niemand hätte ihn gesehen?\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmxxxi{Haben Wir ihm nicht zwei Augen gemacht\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmxxxii{und eine Zunge und zwei Lippen?\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmmxxxiii{Und ihm haben Wir die beiden Wege gezeigt.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmmxxxiv{Doch er bezwang das Hindernis nicht.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmmxxxv{Und was lehrt dich wissen, was das Hindernis ist?\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmmxxxvi{(Es sind:) das Befreien eines Nackens\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmmxxxvii{oder an einem Tage während der Hungersnot das Speisen\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmmxxxviii{einer nahverwandten Waise\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmmxxxix{oder eines Armen, der sich im Staube wälzt\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmmxl{(oder) alsdann unter denen zu sein, die glauben und einander ermahnen zur Geduld und einander ermahnen zur Barmherzigkeit.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmmxli{Dies sind diejenigen, die von der rechten (Seite) sind.\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmmxlii{Diejenigen aber, die nicht an Unsere Zeichen glauben sie werden von der linken (Seite) sein\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmmxliii{sie werden vom Feuer ringsum eingeschlossen sein.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmmxliv{\basmalahde Bei der Sonne und bei ihrem Morgenglanz\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmxlv{und bei dem Mond, wenn er ihr folgt\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmxlvi{und bei dem Tage, wenn er sie erstrahlen läßt\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmxlvii{und bei der Nacht, wenn sie sie bedeckt\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmxlviii{und bei dem Himmel und bei Dem, Der ihn aufgebaut hat\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmxlix{und bei der Erde und bei Dem, Der sie ausgebreitet hat\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmml{und bei einer (jeden menschlichen) Seele und bei Dem, Der sie gebildet\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmli{und ihr den Sinn für ihre Sündhaftigkeit und für ihre Gottesfurcht eingegeben hat!\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmlii{Erfolgreich ist derjenige, der sie rein hält\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmmliii{und versagt hat derjenige, der sie verkommen läßt.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmmliv{So leugneten die Tamud (die Wahrheit) in ihrem Trotz.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmmlv{Als der Unseligste unter ihnen auftrat\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmmlvi{da sagte der Gesandte Allahs zu ihnen: ``Haltet euch von der Kamelstute Allahs und von ihrer Tränke fern!"\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmmlvii{Sie aber bezichtigten ihn der Lüge und töteten sie; darum kam ihr Herr (zur Vergeltung) für ihre Schuld mit Seinem Zorn über sie und ebnete sie ein.\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmmlviii{Und Er fürchtet ihre Folgen nicht.\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmmlix{\basmalahde Bei der Nacht, wenn sie zudeckt\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmlx{und bei dem Tage, wenn er erstrahlt\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmlxi{und bei Dem, Der das Männliche und das Weibliche erschaffen hat!\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmlxii{Wahrlich, euer Eifer ist verschieden.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmlxiii{Jener aber, der gibt und gottesfürchtig ist\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmlxiv{und an das Beste glaubt\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmlxv{dem wollen Wir den Weg zum Heil leicht machen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmlxvi{Jener aber, der geizt und gleichgültig ist\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmlxvii{und das Beste leugnet\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmmlxviii{dem wollen Wir den Weg zur Drangsal leicht machen.\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmmlxix{Und sein Vermögen soll ihm nichts nützen, wenn er zugrunde geht.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmmlxx{Wahrlich, Uns obliegt die Rechtleitung.\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxi{Und Uns gehört das Jenseits und das Diesseits\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxii{darum warne Ich euch vor einem loderenden Feuer\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxiii{in dem nur derjenige brennen wird, der unselig ist\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxiv{der da leugnet und den Rücken kehrt.\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxv{Geschont von ihm wird derjenige sein, der gottesfürchtig ist\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxvi{der sein Vermögen hergibt, um sich zu reinigen\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxvii{und der keinem eine Gunst schuldet, die zurückgezahlt werden müßte\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxviii{außer im Trachten nach dem Wohlgefallen seines Herrn, des Allerhöchsten.\qt@no{(20)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxix{Und er wird wohlzufrieden sein.\qt@no{(21)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxx{\basmalahde Beim Vormittag\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxxi{und bei der Nacht, wenn alles still ist!\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxxii{Dein Herr hat dich weder verlassen, noch verabscheut.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxxiii{Wahrlich, das Jenseits ist besser für dich als das Diesseits.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxxiv{Und wahrlich, dein Herr wird dir geben und du wirst wohlzufrieden sein.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxxv{Hat Er dich nicht als Waise gefunden und aufgenommen\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxxvi{und dich auf dem Irrweg gefunden und richtig geführt\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxxvii{und dich dürftig gefunden und reich gemacht?\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxxviii{Darum unterdrücke nicht die Waise\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmmlxxxix{und fahre nicht den Bettler an\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmmxc{und sprich überall von der Gnade deines Herrn.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmmxci{\basmalahde Haben Wir dir nicht deine Brust geweitet\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmxcii{und dir deine Last abgenommen\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmxciii{die schwer auf deinem Rücken lastete\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmxciv{und deinen Namen erhöht?\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmxcv{Also, wahrlich, mit der Drangsal geht Erleichterung einher\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmxcvi{wahrlich, mit der Drangsal geht Erleichterung (einher).\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmxcvii{Also, wenn du (mit allem) fertig bist, dann mühe dich ab\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmxcviii{und begehre die Nähe deines Herrn.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmxcix{\basmalahde Beim Feigenbaum und beim Ölbaum\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmc{und beim Berge Sinai\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmci{und bei dieser sicheren Ortschaft!\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmcii{Wahrlich, Wir haben den Menschen in bester Form erschaffen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmciii{Alsdann haben Wir ihn in die niedrigste Tiefe zurückgebracht\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmciv{ausgenommen (davon) sind diejenigen, die glauben und Gutes tun; ihnen wird ein unverkürzter Lohn zuteil sein.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmcv{Und was veranlaßt dich hernach, die Religion zu leugnen?\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmcvi{Ist nicht Allah der gerechteste Richter?\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmcvii{\basmalahde Lies im Namen deines Herrn, Der erschuf.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmcviii{Er erschuf den Menschen aus einem Blutklumpen.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmcix{Lies; denn dein Herr ist Allgütig.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmcx{Der mit dem Schreibrohr lehrt\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmcxi{lehrt den Menschen, was er nicht wußte.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmcxii{Keineswegs! Wahrlich, der Mensch übt Gewalttätigkeit\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmcxiii{weil er sich im Reichtum sieht.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmcxiv{Wahrlich, zu deinem Herrn ist die Heimkehr.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmcxv{Hast du den gesehen, der da verwehrt\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmmcxvi{(Unserem) Diener, daß er betet?\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmmcxvii{Hast du gesehen, ob er auf dem rechten Weg ist\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmmcxviii{oder zur Gerechtigkeit auffordert?\qt@no{(12)}}
\qt@newcmd\qurantrans@de@mmmmmmcxix{Hast du (den) gesehen, der ungläubig ist und sich abwendet?\qt@no{(13)}}
\qt@newcmd\qurantrans@de@mmmmmmcxx{Weiß er nicht, daß Allah (ihn) sieht?\qt@no{(14)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxi{Keineswegs! Wenn er nicht (davon) abläßt, werden Wir ihn gewiß ergreifen bei der Stirnlocke\qt@no{(15)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxii{der lügenden, sündigen Stirnlocke\qt@no{(16)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxiii{er mag dann seine Mitverschworenen anrufen.\qt@no{(17)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxiv{Wir werden die Höllenwächter herbeirufen\qt@no{(18)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxv{gehorche ihm doch nicht und wirf dich in Anbetung nieder und nahe dich (Allah).\qt@no{(19)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxvi{\basmalahde Wahrlich, Wir haben ihn (den Quran) hinabgesandt in der Nacht von Al-Qadr.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxvii{Und was lehrt dich wissen, ist? was die Nacht von Al-Qadr\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxviii{Die Nacht von Al Qadr ist besser als tausend Monate.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxix{In ihr steigen die Engel und Gabriel herab mit der Erlaubnis ihres Herrn zu jeglichem Geheiß.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxx{Frieden ist sie bis zum Anbruch der Morgenröte.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxxi{\basmalahde Diejenigen, die ungläubig sind unter dem Volk der Schrift und die Götzendiener können (von ihrem Irrtum) nichtbefreit werden, bis der deutliche Beweis zu ihnen kommt\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxxii{ein Gesandter von Allah, der (ihnen) reinerhaltene (Quran-) Abschnitte verliest\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxxiii{in denen geradlinigeVorschriften enthalten sind.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxxiv{Und die, denen die Schrift gegeben wurde, waren nicht eher gespalten, alsbis der deutliche Beweis zu ihnen gekommen war.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxxv{Und doch war ihnen nichts anderes befohlen worden, als Allah treu in lauterem Glauben zu dienen und das Gebet zu verrichten und die Zakah zu entrichten. Und das ist die Religion der Geradlinigkeit.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxxvi{Wahrlich, jene, die ungläubig sind unter dem Volk der Schrift und die Götzendiener werden im Feuer der Gahannam sein; ewig werden sie darin bleiben; diese sind die schlechtesten der Geschöpfe.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxxvii{Wahrlich, diejenigen aber, die glauben und gute Werke tun, sind die besten der Geschöpfe.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxxviii{Ihr Lohn bei ihrem Herrn sind die Gärten von Eden, durcheilt von Bächen; ewig und immerdar werden sie darin verweilen. Allah ist mit ihnen wohlzufrieden und sie sind wohlzufrieden mit Ihm. Dies ist für den, der seinen Herrn fürchtet.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmcxxxix{\basmalahde Wenn die Erde in aller Heftigkeit erbebt\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmcxl{und wenn die Erde ihre Lasten herausgibt\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmcxli{und wenn der Mensch sagt: ``Was ist mit ihr?"\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmcxlii{An jenem Tage wird sie ihre Geschichten erzählen\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmcxliii{so wie ihr Herr (es) ihr eingegeben hat.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmcxliv{An jenem Tage kommen die Menschen in Gruppen zerstreut hervor, damit ihnen ihre Werke gezeigt werden.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmcxlv{Wer auch nur eines Stäubchens Gewicht Gutes tut, der wird es dann sehen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmcxlvi{Und wer auch nur eines Stäubchens Gewicht Böses tut, der wird es dann sehen.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmcxlvii{\basmalahde Bei den schnaubenden Rennern\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmcxlviii{die dann Feuerfunken schlagen\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmcxlix{alsdann frühmorgens anstürmen\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmcl{und damit Staub aufwirbeln\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmcli{und so in die Mitte (des Feindes) eindringen!\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmclii{Wahrlich, der Mensch ist undankbar gegen seinen Herrn\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmcliii{und wahrlich, er bezeugt es selber\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmcliv{und wahrlich, stark ist seine Liebe zum (irdischen) Gut.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmclv{Weiß er denn nicht, wenn der Inhalt der Gräber herausgeworfen wird\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmmclvi{und das herausgeholt wird, was in den Herzen ist\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmmclvii{daß ihr Herr sie wahrlich an jenem Tag wohl kennt?\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmmclviii{\basmalahde Al-Qaria!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmclix{Was ist AI-Qaria?\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmclx{Und was läßt dich wissen, was Al-Qaria ist?\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmclxi{An einem Tage, da die Menschen gleich verstreuten Motten sein werden\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmclxii{und die Berge gleich bunter, zerflockter Wolle\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmclxiii{dann wird der, dessen Waage schwer ist\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmclxiv{ein Wohlleben genießen\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmclxv{dem aber, dessen Waage leicht ist\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmclxvi{wird die Hawiya sein Endziel sein.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmmclxvii{Und was lehrt dich wissen, was die (Hawiya) ist?\qt@no{(10)}}
\qt@newcmd\qurantrans@de@mmmmmmclxviii{(Sie ist) ein glühendes Feuer.\qt@no{(11)}}
\qt@newcmd\qurantrans@de@mmmmmmclxix{\basmalahde Das Streben nach Mehr lenkt euch solange ab\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmclxx{bis ihr die Gräber besucht.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxi{Aber nein! Ihr werdet es bald erfahren.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxii{Wiederum: Aber nein! Ihr werdet es bald erfahren.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxiii{Aber nein! Wenn ihr es sicher wüßtet!\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxiv{Ihr werdet die Gahim sehen.\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxv{Doch, ihr sollt sie noch mit dem Auge der Gewißheit sehen.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxvi{Dann werdet ihr, an jenem Tage, nach dem Wohlstand befragt.\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxvii{\basmalahde Beim Nachmittag!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxviii{Die Menschen sind wahrhaftig im Verlust\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxix{außer denjenigen, die glauben und gute Werke tun und sich gegenseitig die Wahrheit ans Herz legen und sich gegenseitig zur Geduld anhalten.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxx{\basmalahde Wehe jedem Stichler, Verleumder\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxxi{der ein Vermögen zusammenträgt und es gezählt zurücklegt!\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxxii{Er meint, daß sein Vermögen ihn unsterblich mache.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxxiii{Aber nein! Er wird wahrlich in Al-Hutama geschleudert werden.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxxiv{Doch was läßt dich wissen, was Al-Hutama ist?\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxxv{(Es ist) Allahs angezündetes Feuer\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxxvi{das bis zu dem (innersten der) Herzen vordringt.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxxvii{Es schlägt über ihnen zusammen\qt@no{(8)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxxviii{in langgestreckten Säulen.\qt@no{(9)}}
\qt@newcmd\qurantrans@de@mmmmmmclxxxix{\basmalahde Hast du nicht gesehen, wie dein Herr mit den Leuten des Elefanten verfahren ist?\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmcxc{Hat Er nicht ihre List mißlingen lassen\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmcxci{und Vögel in Scharen über sie gesandt\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmcxcii{die sie mit brennenden Steinen bewarfen\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmcxciii{und sie dadurch wie abgefressene Saat gemacht?\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmcxciv{\basmalahde Für die Vereinigung der Qurais\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmcxcv{(für) ihre Vereinigung zur Reise in der Karawane des Winters und des Sommers.\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmcxcvi{So sollen sie denn dem Herrn dieses Hauses dienen\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmcxcvii{Der sie speist nachdem sie gehungert haben, und ihnen Sicherheit gewährleistet, nachdem sie in Angst lebten!\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmcxcviii{\basmalahde Hast du den gesehen, der das Gericht leugnet?\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmcxcix{Das ist der, der die Waise wegstößt\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmcc{und nicht zur Speisung des Armen anspornt.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmcci{Wehe denjenigen Betenden\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmccii{die (bei der Verrichtung) ihres Gebets nachlässig sind\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmcciii{die (nur dabei) gesehen werden wollen\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmcciv{und die Hilfeleistung verweigern.\qt@no{(7)}}
\qt@newcmd\qurantrans@de@mmmmmmccv{\basmalahde Wir haben dir die Überfülle gegeben.\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmccvi{Darum bete zu deinem Herrn und schlachte (Opfertiere).\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmccvii{Wahrlich, der dich haßt, ist es, der (vom Segen der Nachkommenschaft) abgeschnitten ist.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmccviii{\basmalahde Sprich: ``O ihr Ungläubigen!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmccix{Ich diene nicht dem, dem ihr dient\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmccx{und ihr dient nicht Dem, Dem ich diene.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmccxi{Und ich werde nicht Diener dessen sein, dem ihr dient\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmccxii{und ihr werdet nicht Diener Dessen sein, Dem ich diene.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmccxiii{Ihr habt eure Religion und ich habe meine Religion."\qt@no{(6)}}
\qt@newcmd\qurantrans@de@mmmmmmccxiv{\basmalahde Wenn die Hilfe Allahs kommt und der Sieg\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmccxv{und du die Menschen zur Religion Allahs in Scharen übertreten siehst\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmccxvi{dann lobpreise deinen Herrn und bitte Ihn um Vergebung! Er ist wahrlich Der, Der die Reue an nimmt.\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmccxvii{\basmalahde Zugrunde gehen sollen die Hände Abu Lahabs! Und (auch er selbst) soll zugrunde gehen!\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmccxviii{Nichts soll ihm sein Vermögen nützen, noch das, was er erworben hat\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmccxix{er wird in einem flammenden Feuer brennen\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmccxx{und seine Frau wird das Brennholz tragen.\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxi{Um ihren Hals ist ein Strick aus Palmfasern.\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxii{\basmalahde Sprich: ``Er ist Allah, ein Einziger\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxiii{Allah, der Absolute (ewig Unabhängige, von Dem alles abhängt).\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxiv{Er zeugt nicht und ist nicht gezeugt worden\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxv{und Ihm ebenbürtig ist keiner."\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxvi{\basmalahde Sprich: ``ich nehme meine Zuflucht beim Herrn des Frühlichts\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxvii{vor dem Übel dessen, was Er erschaffen hat\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxviii{und vor dem Übel der Dunkelheit, wenn sie hereinbricht\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxix{und vor dem Übel der Knotenanbläserinnen\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxx{und vor dem Übel eines (jeden) Neiders, wenn er neidet."\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxxi{\basmalahde Sprich: ``lch nehme meine Zuflucht beim Herrn der Menschen\qt@no{(1)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxxii{dem König der Menschen\qt@no{(2)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxxiii{dem Gott der Menschen\qt@no{(3)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxxiv{vor dem Übel des Einflüsterers, der entweicht und wiederkehrt\qt@no{(4)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxxv{der in die Herzen der Menschen einflüstert\qt@no{(5)}}
\qt@newcmd\qurantrans@de@mmmmmmccxxxvi{sei dieser aus den Ginn oder den Menschen"\qt@no{(6)}}
