%% This is file `qurantext-de.transliteration.def',
%% 
%% Copyright © 2015-2021
%% Seiied-Mohammad-Javad Razavian <javadr@gmail.com>
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%% 
%% This work is “author-maintained” (as per LPPL maintenance status).
%% 
%% The Current Maintainer of this work is Seiied-Mohammad-Javad Razavian.
%% 
%% to one who has devoted his life to Quran
%%
\qt@newcmd\qurantrans@lt@i{Bismi All\q@u{a}hi a\q@b{l}rra\q@u{h}m\q@u{a}ni a\q@b{l}rra\q@u{h}eem\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@ii{Al\q@u{h}amdu lill\q@u{a}hi rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@iii{A\q@b{l}rra\q@u{h}m\q@u{a}ni a\q@b{l}rra\q@u{h}eem\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@iv{M\q@u{a}liki yawmi a\q@b{l}ddeen\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@v{Iyy\q@u{a}ka naAAbudu waiyy\q@u{a}ka nastaAAeen\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@vi{Ihdin\q@u{a} a\q@b{l}\q@u{ss}ir\q@u{at}a almustaqeem\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@vii{\q@u{S}ir\q@u{at}a alla\q@u{th}eena anAAamta AAalayhim ghayri almagh\q@u{d}oobi AAalayhim wal\q@u{a} a\q@b{l}\q@u{dda}lleen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@viii{\basmalahlt Alifl\q@u{a}mmeem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@ix{\q@u{Tha}lika alkit\q@u{a}bu l\q@u{a} rayba feehi hudan lilmuttaqeen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@x{Alla\q@u{th}eena yuminoona bi\q@b{a}lghaybi wayuqeemoona a\q@b{l}\q@u{ss}al\q@u{a}ta wamimm\q@u{a} razaqn\q@u{a}hum yunfiqoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@xi{Wa\q@b{a}lla\q@u{th}eena yuminoona bim\q@u{a} onzila ilayka wam\q@u{a} onzila min qablika wabi\q@b{a}l\q@u{a}khirati hum yooqinoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@xii{Ol\q@u{a}ika AAal\q@u{a} hudan min rabbihim waol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@xiii{Inna alla\q@u{th}eena kafaroo saw\q@u{a}on AAalayhim aan\q@u{th}artahum am lam tun\q@u{th}irhum l\q@u{a} yuminoon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@xiv{Khatama All\q@u{a}hu AAal\q@u{a} quloobihim waAAal\q@u{a} samAAihim waAAal\q@u{a} ab\q@u{sa}rihim ghish\q@u{a}watun walahum AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@xv{Wamina a\q@b{l}nn\q@u{a}si man yaqoolu \q@u{a}mann\q@u{a} biAll\q@u{a}hi wabi\q@b{a}lyawmi al\q@u{a}khiri wam\q@u{a} hum bimumineen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@xvi{Yukh\q@u{a}diAAoona All\q@u{a}ha wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo wam\q@u{a} yakhdaAAoona ill\q@u{a} anfusahum wam\q@u{a} yashAAuroon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@xvii{Fee quloobihim mara\q@u{d}un faz\q@u{a}dahumu All\q@u{a}hu mara\q@u{d}an walahum AAa\q@u{tha}bun aleemun bim\q@u{a} k\q@u{a}noo yak\q@u{th}iboon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@xviii{Wai\q@u{tha} qeela lahum l\q@u{a} tufsidoo fee alar\q@u{d}i q\q@u{a}loo innam\q@u{a} na\q@u{h}nu mu\q@u{s}li\q@u{h}oon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@xix{Al\q@u{a} innahum humu almufsidoona wal\q@u{a}kin l\q@u{a} yashAAuroon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@xx{Wai\q@u{tha} qeela lahum \q@u{a}minoo kam\q@u{a} \q@u{a}mana a\q@b{l}nn\q@u{a}su q\q@u{a}loo anuminu kam\q@u{a} \q@u{a}mana a\q@b{l}ssufah\q@u{a}o al\q@u{a} innahum humu a\q@b{l}ssufah\q@u{a}o wal\q@u{a}kin l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@xxi{Wai\q@u{tha} laqoo alla\q@u{th}eena \q@u{a}manoo q\q@u{a}loo \q@u{a}mann\q@u{a} wai\q@u{tha} khalaw il\q@u{a} shay\q@u{at}eenihim q\q@u{a}loo inn\q@u{a} maAAakum innam\q@u{a} na\q@u{h}nu mustahzioon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@xxii{All\q@u{a}hu yastahzio bihim wayamudduhum fee \q@u{t}ughy\q@u{a}nihim yaAAmahoon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@xxiii{Ol\q@u{a}ika alla\q@u{th}eena ishtarawoo a\q@b{l}\q@u{dd}al\q@u{a}lata bi\q@b{a}lhud\q@u{a} fam\q@u{a} rabi\q@u{h}at tij\q@u{a}ratuhum wam\q@u{a} k\q@u{a}noo muhtadeen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@xxiv{Mathaluhum kamathali alla\q@u{th}ee istawqada n\q@u{a}ran falamm\q@u{a} a\q@u{da}at m\q@u{a} \q@u{h}awlahu \q@u{th}ahaba All\q@u{a}hu binoorihim watarakahum fee \q@i{\q@u{th}}ulum\q@u{a}tin l\q@u{a} yub\q@u{s}iroon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@xxv{\q@u{S}ummun bukmun AAumyun fahum l\q@u{a} yarjiAAoon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@xxvi{Aw ka\q@u{s}ayyibin mina a\q@b{l}ssam\q@u{a}i feehi \q@i{\q@u{th}}ulum\q@u{a}tun waraAAdun wabarqun yajAAaloona a\q@u{sa}biAAahum fee \q@u{atha}nihim mina a\q@b{l}\q@u{ss}aw\q@u{a}AAiqi \q@u{h}a\q@u{th}ara almawti wa\q@b{A}ll\q@u{a}hu mu\q@u{h}ee\q@u{t}un bi\q@b{a}lk\q@u{a}fireen\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@xxvii{Yak\q@u{a}du albarqu yakh\q@u{t}afu ab\q@u{sa}rahum kullam\q@u{a} a\q@u{da}a lahum mashaw feehi wai\q@u{tha} a\q@i{\q@u{th}}lama AAalayhim q\q@u{a}moo walaw sh\q@u{a}a All\q@u{a}hu la\q@u{th}ahaba bisamAAihim waab\q@u{sa}rihim inna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@xxviii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su oAAbudoo rabbakumu alla\q@u{th}ee khalaqakum wa\q@b{a}lla\q@u{th}eena min qablikum laAAallakum tattaqoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@xxix{Alla\q@u{th}ee jaAAala lakumu alar\q@u{d}a fir\q@u{a}shan wa\q@b{al}ssam\q@u{a}a bin\q@u{a}an waanzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faakhraja bihi mina a\q@b{l}ththamar\q@u{a}ti rizqan lakum fal\q@u{a} tajAAaloo lill\q@u{a}hi and\q@u{a}dan waantum taAAlamoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@xxx{Wain kuntum fee raybin mimm\q@u{a} nazzaln\q@u{a} AAal\q@u{a} AAabdin\q@u{a} fatoo bisooratin min mithlihi wa\q@b{o}dAAoo shuhad\q@u{a}akum min dooni All\q@u{a}hi in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@xxxi{Fain lam tafAAaloo walan tafAAaloo fa\q@b{i}ttaqoo a\q@b{l}nn\q@u{a}ra allatee waqooduh\q@u{a} a\q@b{l}nn\q@u{a}su wa\q@b{a}l\q@u{h}ij\q@u{a}ratu oAAiddat lilk\q@u{a}fireen\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@xxxii{Wabashshiri alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti anna lahum jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kullam\q@u{a} ruziqoo minh\q@u{a} min thamaratin rizqan q\q@u{a}loo h\q@u{atha} alla\q@u{th}ee ruziqn\q@u{a} min qablu waotoo bihi mutash\q@u{a}bihan walahum feeh\q@u{a} azw\q@u{a}jun mu\q@u{t}ahharatun wahum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@xxxiii{Inna All\q@u{a}ha l\q@u{a} yasta\q@u{h}yee an ya\q@u{d}riba mathalan m\q@u{a} baAAoo\q@u{d}atan fam\q@u{a} fawqah\q@u{a} faamm\q@u{a} alla\q@u{th}eena \q@u{a}manoo fayaAAlamoona annahu al\q@u{h}aqqu min rabbihim waamm\q@u{a} alla\q@u{th}eena kafaroo fayaqooloona m\q@u{atha} ar\q@u{a}da All\q@u{a}hu bih\q@u{atha} mathalan yu\q@u{d}illu bihi katheeran wayahdee bihi katheeran wam\q@u{a} yu\q@u{d}illu bihi ill\q@u{a} alf\q@u{a}siqeen\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@xxxiv{Alla\q@u{th}eena yanqu\q@u{d}oona AAahda All\q@u{a}hi min baAAdi meeth\q@u{a}qihi wayaq\q@u{t}aAAoona m\q@u{a} amara All\q@u{a}hu bihi an yoo\q@u{s}ala wayufsidoona fee alar\q@u{d}i ol\q@u{a}ika humu alkh\q@u{a}siroon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@xxxv{Kayfa takfuroona bi\emph{A}ll\q@u{a}hi wakuntum amw\q@u{a}tan faa\q@u{h}y\q@u{a}kum thumma yumeetukum thumma yu\q@u{h}yeekum thumma ilayhi turjaAAoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@xxxvi{Huwa alla\q@u{th}ee khalaqa lakum m\q@u{a} fee alar\q@u{d}i jameeAAan thumma istaw\q@u{a} il\q@u{a} a\q@b{l}ssam\q@u{a}i fasaww\q@u{a}hunna sabAAa sam\q@u{a}w\q@u{a}tin wahuwa bikulli shayin AAaleem\q@b{un}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@xxxvii{Wai\q@u{th} q\q@u{a}la rabbuka lilmal\q@u{a}ikati innee j\q@u{a}AAilun fee alar\q@u{d}i khaleefatan q\q@u{a}loo atajAAalu feeh\q@u{a} man yufsidu feeh\q@u{a} wayasfiku a\q@b{l}ddim\q@u{a}a wana\q@u{h}nu nusabbi\q@u{h}u bi\q@u{h}amdika wanuqaddisu laka q\q@u{a}la innee aAAlamu m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@xxxviii{WaAAallama \q@u{a}dama alasm\q@u{a}a kullah\q@u{a} thumma AAara\q@u{d}ahum AAal\q@u{a} almal\q@u{a}ikati faq\q@u{a}la anbioonee biasm\q@u{a}i h\q@u{a}ol\q@u{a}i in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@xxxix{Q\q@u{a}loo sub\q@u{ha}naka l\q@u{a} AAilma lan\q@u{a} ill\q@u{a} m\q@u{a} AAallamtan\q@u{a} innaka anta alAAaleemu al\q@u{h}akeem\q@b{u}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@xl{Q\q@u{a}la y\q@u{a} \q@u{a}damu anbihum biasm\q@u{a}ihim falamm\q@u{a} anbaahum biasm\q@u{a}ihim q\q@u{a}la alam aqul lakum innee aAAlamu ghayba a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i waaAAlamu m\q@u{a} tubdoona wam\q@u{a} kuntum taktumoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@xli{Wai\q@u{th} quln\q@u{a} lilmal\q@u{a}ikati osjudoo li\q@u{a}dama fasajadoo ill\q@u{a} ibleesa ab\q@u{a} wa\q@b{i}stakbara wak\q@u{a}na mina alk\q@u{a}fireen\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@xlii{Waquln\q@u{a} y\q@u{a} \q@u{a}damu oskun anta wazawjuka aljannata wakul\q@u{a} minh\q@u{a} raghadan \q@u{h}aythu shitum\q@u{a} wal\q@u{a} taqrab\q@u{a} h\q@u{ath}ihi a\q@b{l}shshajarata fatakoon\q@u{a} mina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@xliii{Faazallahum\q@u{a} a\q@b{l}shshay\q@u{ta}nu AAanh\q@u{a} faakhrajahum\q@u{a} mimm\q@u{a} k\q@u{a}n\q@u{a} feehi waquln\q@u{a} ihbi\q@u{t}oo baAA\q@u{d}ukum libaAA\q@u{d}in AAaduwwun walakum fee alar\q@u{d}i mustaqarrun wamat\q@u{a}AAun il\q@u{a} \q@u{h}een\q@b{in}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@xliv{Fatalaqq\q@u{a} \q@u{a}damu min rabbihi kalim\q@u{a}tin fat\q@u{a}ba AAalayhi innahu huwa a\q@b{l}ttaww\q@u{a}bu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@xlv{Quln\q@u{a} ihbi\q@u{t}oo minh\q@u{a} jameeAAan faimm\q@u{a} yatiyannakum minnee hudan faman tabiAAa hud\q@u{a}ya fal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@xlvi{Wa\q@b{a}lla\q@u{th}eena kafaroo waka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} ol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@xlvii{Y\q@u{a} banee isr\q@u{a}eela o\q@u{th}kuroo niAAmatiya allatee anAAamtu AAalaykum waawfoo biAAahdee oofi biAAahdikum waiyy\q@u{a}ya fa\q@b{i}rhaboon\q@b{i}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@xlviii{Wa\q@u{a}minoo bim\q@u{a} anzaltu mu\q@u{s}addiqan lim\q@u{a} maAAakum wal\q@u{a} takoonoo awwala k\q@u{a}firin bihi wal\q@u{a} tashtaroo bi\q@u{a}y\q@u{a}tee thamanan qaleelan waiyy\q@u{a}ya fa\q@b{i}ttaqoon\q@b{i}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@xlix{Wal\q@u{a} talbisoo al\q@u{h}aqqa bi\q@b{a}lb\q@u{at}ili wataktumoo al\q@u{h}aqqa waantum taAAlamoon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@l{Waaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}too a\q@b{l}zzak\q@u{a}ta wa\q@b{i}rkaAAoo maAAa a\q@b{l}rr\q@u{a}kiAAeen\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@li{Atamuroona a\q@b{l}nn\q@u{a}sa bi\q@b{a}lbirri watansawna anfusakum waantum tatloona alkit\q@u{a}ba afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@lii{Wa\q@b{i}staAAeenoo bi\q@b{al}\q@u{ss}abri wa\q@b{al}\q@u{ss}al\q@u{a}ti wainnah\q@u{a} lakabeeratun ill\q@u{a} AAal\q@u{a} alkh\q@u{a}shiAAeen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@liii{Alla\q@u{th}eena ya\q@i{\q@u{th}}unnoona annahum mul\q@u{a}qoo rabbihim waannahum ilayhi r\q@u{a}jiAAoon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@liv{Y\q@u{a} banee isr\q@u{a}eela o\q@u{th}kuroo niAAmatiya allatee anAAamtu AAalaykum waannee fa\q@u{dd}altukum AAal\q@u{a} alAA\q@u{a}lameen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@lv{Wa\q@b{i}ttaqoo yawman l\q@u{a} tajzee nafsun AAan nafsin shayan wal\q@u{a} yuqbalu minh\q@u{a} shaf\q@u{a}AAatun wal\q@u{a} yukha\q@u{th}u minh\q@u{a} AAadlun wal\q@u{a} hum yun\q@u{s}aroon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@lvi{Wai\q@u{th} najjayn\q@u{a}kum min \q@u{a}li firAAawna yasoomoonakum sooa alAAa\q@u{tha}bi yu\q@u{th}abbi\q@u{h}oona abn\q@u{a}akum wayasta\q@u{h}yoona nis\q@u{a}akum wafee \q@u{tha}likum bal\q@u{a}on min rabbikum AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@lvii{Wai\q@u{th} faraqn\q@u{a} bikumu alba\q@u{h}ra faanjayn\q@u{a}kum waaghraqn\q@u{a} \q@u{a}la firAAawna waantum tan\q@i{\q@u{th}}uroon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@lviii{Wai\q@u{th} w\q@u{a}AAadn\q@u{a} moos\q@u{a} arbaAAeena laylatan thumma ittakha\q@u{th}tumu alAAijla min baAAdihi waantum \q@i{\q@u{th}}\q@u{a}limoon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@lix{Thumma AAafawn\q@u{a} AAankum min baAAdi \q@u{tha}lika laAAallakum tashkuroon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@lx{Wai\q@u{th} \q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba wa\q@b{a}lfurq\q@u{a}na laAAallakum tahtadoon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@lxi{Wai\q@u{th} q\q@u{a}la moos\q@u{a} liqawmihi y\q@u{a} qawmi innakum \q@i{\q@u{th}}alamtum anfusakum bi\q@b{i}ttikh\q@u{ath}ikumu alAAijla fatooboo il\q@u{a} b\q@u{a}riikum fa\q@b{o}qtuloo anfusakum \q@u{tha}likum khayrun lakum AAinda b\q@u{a}riikum fat\q@u{a}ba AAalaykum innahu huwa a\q@b{l}ttaww\q@u{a}bu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@lxii{Wai\q@u{th} qultum y\q@u{a} moos\q@u{a} lan numina laka \q@u{h}att\q@u{a} nar\q@u{a} All\q@u{a}ha jahratan faakha\q@u{th}atkumu a\q@b{l}\q@u{ssa}AAiqatu waantum tan\q@i{\q@u{th}}uroon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@lxiii{Thumma baAAathn\q@u{a}kum min baAAdi mawtikum laAAallakum tashkuroon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@lxiv{Wa\q@i{\q@u{th}}allaln\q@u{a} AAalaykumu algham\q@u{a}ma waanzaln\q@u{a} AAalaykumu almanna wa\q@b{al}ssalw\q@u{a} kuloo min \q@u{t}ayyib\q@u{a}ti m\q@u{a} razaqn\q@u{a}kum wam\q@u{a} \q@i{\q@u{th}}alamoon\q@u{a} wal\q@u{a}kin k\q@u{a}noo anfusahum ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@lxv{Wai\q@u{th} quln\q@u{a} odkhuloo h\q@u{ath}ihi alqaryata fakuloo minh\q@u{a} \q@u{h}aythu shitum raghadan wa\q@b{o}dkhuloo alb\q@u{a}ba sujjadan waqooloo \q@u{h}i\q@u{tt}atun naghfir lakum kha\q@u{ta}y\q@u{a}kum wasanazeedu almu\q@u{h}sineen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@lxvi{Fabaddala alla\q@u{th}eena \q@i{\q@u{th}}alamoo qawlan ghayra alla\q@u{th}ee qeela lahum faanzaln\q@u{a} AAal\q@u{a} alla\q@u{th}eena \q@i{\q@u{th}}alamoo rijzan mina a\q@b{l}ssam\q@u{a}i bim\q@u{a} k\q@u{a}noo yafsuqoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@lxvii{Wai\q@u{th}i istasq\q@u{a} moos\q@u{a} liqawmihi faquln\q@u{a} i\q@u{d}rib biAAa\q@u{sa}ka al\q@u{h}ajara fa\q@b{i}nfajarat minhu ithnat\q@u{a} AAashrata AAaynan qad AAalima kullu on\q@u{a}sin mashrabahum kuloo wa\q@b{i}shraboo min rizqi All\q@u{a}hi wal\q@u{a} taAAthaw fee alar\q@u{d}i mufsideen\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@lxviii{Wai\q@u{th} qultum y\q@u{a} moos\q@u{a} lan na\q@u{s}bira AAal\q@u{a} \q@u{t}aAA\q@u{a}min w\q@u{ah}idin fa\q@b{o}dAAu lan\q@u{a} rabbaka yukhrij lan\q@u{a} mimm\q@u{a} tunbitu alar\q@u{d}u min baqlih\q@u{a} waqithth\q@u{a}ih\q@u{a} wafoomih\q@u{a} waAAadasih\q@u{a} waba\q@u{s}alih\q@u{a} q\q@u{a}la atastabdiloona alla\q@u{th}ee huwa adn\q@u{a} bi\q@b{a}lla\q@u{th}ee huwa khayrun ihbi\q@u{t}oo mi\q@u{s}ran fainna lakum m\q@u{a} saaltum wa\q@u{d}uribat AAalayhimu a\q@b{l}\q@u{thth}illatu wa\q@b{a}lmaskanatu wab\q@u{a}oo bigha\q@u{d}abin mina All\q@u{a}hi \q@u{tha}lika biannahum k\q@u{a}noo yakfuroona bi\q@u{a}y\q@u{a}ti All\q@u{a}hi wayaqtuloona a\q@b{l}nnabiyyeena bighayri al\q@u{h}aqqi \q@u{tha}lika bim\q@u{a} AAa\q@u{s}aw wak\q@u{a}noo yaAAtadoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@lxix{Inna alla\q@u{th}eena \q@u{a}manoo wa\q@b{a}lla\q@u{th}eena h\q@u{a}doo wa\q@b{al}nna\q@u{sa}r\q@u{a} wa\q@b{al}\q@u{ssa}bieena man \q@u{a}mana biAll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri waAAamila \q@u{sa}li\q@u{h}an falahum ajruhum AAinda rabbihim wal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@lxx{Wai\q@u{th} akha\q@u{th}n\q@u{a} meeth\q@u{a}qakum warafaAAn\q@u{a} fawqakumu a\q@b{l}\q@u{tt}oora khu\q@u{th}oo m\q@u{a} \q@u{a}tayn\q@u{a}kum biquwwatin wa\q@b{o}\q@u{th}kuroo m\q@u{a} feehi laAAallakum tattaqoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@lxxi{Thumma tawallaytum min baAAdi \q@u{tha}lika falawl\q@u{a} fa\q@u{d}lu All\q@u{a}hi AAalaykum wara\q@u{h}matuhu lakuntum mina alkh\q@u{a}sireen\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@lxxii{Walaqad AAalimtumu alla\q@u{th}eena iAAtadaw minkum fee a\q@b{l}ssabti faquln\q@u{a} lahum koonoo qiradatan kh\q@u{a}sieen\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@lxxiii{FajaAAaln\q@u{a}h\q@u{a} nak\q@u{a}lan lim\q@u{a} bayna yadayh\q@u{a} wam\q@u{a} khalfah\q@u{a} wamawAAi\q@i{\q@u{th}}atan lilmuttaqeen\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@lxxiv{Wai\q@u{th} q\q@u{a}la moos\q@u{a} liqawmihi inna All\q@u{a}ha yamurukum an ta\q@u{th}ba\q@u{h}oo baqaratan q\q@u{a}loo atattakhi\q@u{th}un\q@u{a} huzuwan q\q@u{a}la aAAoo\q@u{th}u biAll\q@u{a}hi an akoona mina alj\q@u{a}hileen\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@lxxv{Q\q@u{a}loo odAAu lan\q@u{a} rabbaka yubayyin lan\q@u{a} m\q@u{a} hiya q\q@u{a}la innahu yaqoolu innah\q@u{a} baqaratun l\q@u{a} f\q@u{a}ri\q@u{d}un wal\q@u{a} bikrun AAaw\q@u{a}nun bayna \q@u{tha}lika fa\q@b{i}fAAaloo m\q@u{a} tumaroon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@lxxvi{Q\q@u{a}loo odAAu lan\q@u{a} rabbaka yubayyin lan\q@u{a} m\q@u{a} lawnuh\q@u{a} q\q@u{a}la innahu yaqoolu innah\q@u{a} baqaratun \q@u{s}afr\q@u{a}o f\q@u{a}qiAAun lawnuh\q@u{a} tasurru a\q@b{l}nn\q@u{a}\q@i{\q@u{th}}ireen\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@lxxvii{Q\q@u{a}loo odAAu lan\q@u{a} rabbaka yubayyin lan\q@u{a} m\q@u{a} hiya inna albaqara tash\q@u{a}baha AAalayn\q@u{a} wainn\q@u{a} in sh\q@u{a}a All\q@u{a}hu lamuhtadoon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@lxxviii{Q\q@u{a}la innahu yaqoolu innah\q@u{a} baqaratun l\q@u{a} \q@u{th}aloolun tutheeru alar\q@u{d}a wal\q@u{a} tasqee al\q@u{h}artha musallamatun l\q@u{a} shiyata feeh\q@u{a} q\q@u{a}loo al\q@u{a}na jita bi\q@b{a}l\q@u{h}aqqi fa\q@u{th}aba\q@u{h}ooh\q@u{a} wam\q@u{a} k\q@u{a}doo yafAAaloon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@lxxix{Wai\q@u{th} qataltum nafsan fa\q@b{i}dd\q@u{a}ratum feeh\q@u{a} wa\q@b{A}ll\q@u{a}hu mukhrijun m\q@u{a }kuntum taktumoon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@lxxx{Faquln\q@u{a} i\q@u{d}riboohu bibaAA\q@u{d}ih\q@u{a} ka\q@u{tha}lika yu\q@u{h}yee All\q@u{a}hu almawt\q@u{a} wayureekum \q@u{a}y\q@u{a}tihi laAAallakum taAAqiloon\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@lxxxi{Thumma qasat quloobukum min baAAdi \q@u{tha}lika fahiya ka\q@b{a}l\q@u{h}ij\q@u{a}rati aw ashaddu qaswatan wainna mina al\q@u{h}ij\q@u{a}rati lam\q@u{a} yatafajjaru minhu alanh\q@u{a}ru wainna minh\q@u{a} lam\q@u{a} yashshaqqaqu fayakhruju minhu alm\q@u{a}o wainna minh\q@u{a} lam\q@u{a} yahbi\q@u{t}u min khashyati All\q@u{a}hi wam\q@u{a} All\q@u{a}hu bigh\q@u{a}filin AAamm\q@u{a} taAAmaloon\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@lxxxii{Afata\q@u{t}maAAoona an yuminoo lakum waqad k\q@u{a}na fareequn minhum yasmaAAoona kal\q@u{a}ma All\q@u{a}hi thumma yu\q@u{h}arrifoonahu min baAAdi m\q@u{a} AAaqaloohu wahum yaAAlamoon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@lxxxiii{Wai\q@u{tha} laqoo alla\q@u{th}eena \q@u{a}manoo q\q@u{a}loo \q@u{a}mann\q@u{a} wai\q@u{tha} khal\q@u{a} baAA\q@u{d}uhum il\q@u{a} baAA\q@u{d}in q\q@u{a}loo atu\q@u{h}addithoonahum bim\q@u{a} fata\q@u{h}a All\q@u{a}hu AAalaykum liyu\q@u{ha}jjookum bihi AAinda rabbikum afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@lxxxiv{Awal\q@u{a} yaAAlamoona anna All\q@u{a}ha yaAAlamu m\q@u{a} yusirroona wam\q@u{a} yuAAlinoon\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@lxxxv{Waminhum ommiyyoona l\q@u{a} yaAAlamoona alkit\q@u{a}ba ill\q@u{a} am\q@u{a}niyya wain hum ill\q@u{a} ya\q@i{\q@u{th}}unnoon\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@lxxxvi{Fawaylun lilla\q@u{th}eena yaktuboona alkit\q@u{a}ba biaydeehim thumma yaqooloona h\q@u{atha} min AAindi All\q@u{a}hi liyashtaroo bihi thamanan qaleelan fawaylun lahum mimm\q@u{a} katabat aydeehim wawaylun lahum mimm\q@u{a} yaksiboon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@lxxxvii{Waq\q@u{a}loo lan tamassan\q@u{a} a\q@b{l}nn\q@u{a}ru ill\q@u{a} ayy\q@u{a}man maAAdoodatan qul attakha\q@u{th}tum AAinda All\q@u{a}hi AAahdan falan yukhlifa All\q@u{a}hu AAahdahu am taqooloona AAal\q@u{a} All\q@u{a}hi m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@lxxxviii{Bal\q@u{a} man kasaba sayyiatan waa\q@u{hat}at bihi kha\q@u{t}eeatuhu faol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@lxxxix{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti ol\q@u{a}ika a\q@u{s}\q@u{ha}bu aljannati hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@xc{Wai\q@u{th} akha\q@u{th}n\q@u{a} meeth\q@u{a}qa banee isr\q@u{a}eela l\q@u{a} taAAbudoona ill\q@u{a} All\q@u{a}ha wabi\q@b{a}lw\q@u{a}lidayni i\q@u{h}s\q@u{a}nan wa\q@u{th}ee alqurb\q@u{a} wa\q@b{a}lyat\q@u{a}m\q@u{a} wa\q@b{a}lmas\q@u{a}keeni waqooloo li\q@b{l}nn\q@u{a}si \q@u{h}usnan waaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}too a\q@b{l}zzak\q@u{a}ta thumma tawallaytum ill\q@u{a} qaleelan minkum waantum muAAri\q@u{d}oon\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@xci{Wai\q@u{th} akha\q@u{th}n\q@u{a} meeth\q@u{a}qakum l\q@u{a} tasfikoona dim\q@u{a}akum wal\q@u{a} tukhrijoona anfusakum min diy\q@u{a}rikum thumma aqrartum waantum tashhadoon\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@xcii{Thumma antum h\q@u{a}ol\q@u{a}i taqtuloona anfusakum watukhrijoona fareeqan minkum min diy\q@u{a}rihim ta\q@i{\q@u{th}}\q@u{a}haroona AAalayhim bi\q@b{a}lithmi wa\q@b{a}lAAudw\q@u{a}ni wain yatookum os\q@u{a}r\q@u{a} tuf\q@u{a}doohum wahuwa mu\q@u{h}arramun AAalaykum ikhr\q@u{a}juhum afatuminoona bibaAA\q@u{d}i alkit\q@u{a}bi watakfuroona bibaAA\q@u{d}in fam\q@u{a} jaz\q@u{a}o man yafAAalu \q@u{tha}lika minkum ill\q@u{a} khizyun fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wayawma alqiy\q@u{a}mati yuraddoona il\q@u{a} ashaddi alAAa\q@u{tha}bi wam\q@u{a} All\q@u{a}hu bigh\q@u{a}filin AAamm\q@u{a} taAAmaloon\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@xciii{Ol\q@u{a}ika alla\q@u{th}eena ishtarawoo al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a} bi\q@b{a}l\q@u{a}khirati fal\q@u{a} yukhaffafu AAanhumu alAAa\q@u{tha}bu wal\q@u{a} hum yun\q@u{s}aroon\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@xciv{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba waqaffayn\q@u{a} min baAAdihi bi\q@b{al}rrusuli wa\q@u{a}tayn\q@u{a} AAees\q@u{a} ibna maryama albayyin\q@u{a}ti waayyadn\q@u{a}hu biroo\q@u{h}i alqudusi afakullam\q@u{a} j\q@u{a}akum rasoolun bim\q@u{a} l\q@u{a} tahw\q@u{a} anfusukumu istakbartum fafareeqan ka\q@u{thth}abtum wafareeqan taqtuloon\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@xcv{Waq\q@u{a}loo quloobun\q@u{a} ghulfun bal laAAanahumu All\q@u{a}hu bikufrihim faqaleelan m\q@u{a} yuminoon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@xcvi{Walamm\q@u{a} j\q@u{a}ahum kit\q@u{a}bun min AAindi All\q@u{a}hi mu\q@u{s}addiqun lim\q@u{a} maAAahum wak\q@u{a}noo min qablu yastafti\q@u{h}oona AAal\q@u{a} alla\q@u{th}eena kafaroo falamm\q@u{a} j\q@u{a}ahum m\q@u{a} AAarafoo kafaroo bihi falaAAnatu All\q@u{a}hi AAal\q@u{a} alk\q@u{a}fireen\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@xcvii{Bisam\q@u{a} ishtaraw bihi anfusahum an yakfuroo bim\q@u{a} anzala All\q@u{a}hu baghyan an yunazzila All\q@u{a}hu min fa\q@u{d}lihi AAal\q@u{a} man yash\q@u{a}o min AAib\q@u{a}dihi fab\q@u{a}oo bigha\q@u{d}abin AAal\q@u{a} gha\q@u{d}abin walilk\q@u{a}fireena AAa\q@u{tha}bun muheen\q@b{un}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@xcviii{Wai\q@u{tha} qeela lahum \q@u{a}minoo bim\q@u{a} anzala All\q@u{a}hu q\q@u{a}loo numinu bim\q@u{a} onzila AAalayn\q@u{a} wayakfuroona bim\q@u{a} war\q@u{a}ahu wahuwa al\q@u{h}aqqu mu\q@u{s}addiqan lim\q@u{a} maAAahum qul falima taqtuloona anbiy\q@u{a}a All\q@u{a}hi min qablu in kuntum mumineen\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@xcix{Walaqad j\q@u{a}akum moos\q@u{a} bi\q@b{a}lbayyin\q@u{a}ti thumma ittakha\q@u{th}tumu alAAijla min baAAdihi waantum \q@i{\q@u{th}}\q@u{a}limoon\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@c{Wai\q@u{th} akha\q@u{th}n\q@u{a} meeth\q@u{a}qakum warafaAAn\q@u{a} fawqakumu a\q@b{l}\q@u{tt}oora khu\q@u{th}oo m\q@u{a} \q@u{a}tayn\q@u{a}kum biquwwatin wa\q@b{i}smaAAoo q\q@u{a}loo samiAAn\q@u{a} waAAa\q@u{s}ayn\q@u{a} waoshriboo fee quloobihimu alAAijla bikufrihim qul bisam\q@u{a} yamurukum bihi eem\q@u{a}nukum in kuntum mumineen\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@ci{Qul in k\q@u{a}nat lakumu a\q@b{l}dd\q@u{a}ru al\q@u{a}khiratu AAinda All\q@u{a}hi kh\q@u{a}li\q@u{s}atan min dooni a\q@b{l}nn\q@u{a}si fatamannawoo almawta in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@cii{Walan yatamannawhu abadan bim\q@u{a} qaddamat aydeehim wa\q@b{A}ll\q@u{a}hu AAaleemun bia\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@ciii{Walatajidannahum a\q@u{h}ra\q@u{s}a a\q@b{l}nn\q@u{a}si AAal\q@u{a} \q@u{h}ay\q@u{a}tin wamina alla\q@u{th}eena ashrakoo yawaddu a\q@u{h}aduhum law yuAAammaru alfa sanatin wam\q@u{a} huwa bimuza\q@u{h}zi\q@u{h}ihi mina alAAa\q@u{tha}bi an yuAAammara wa\q@b{A}ll\q@u{a}hu ba\q@u{s}eerun bim\q@u{a} yaAAmaloon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@civ{Qul man k\q@u{a}na AAaduwwan lijibreela fainnahu nazzalahu AAal\q@u{a} qalbika bii\q@u{th}ni All\q@u{a}hi mu\q@u{s}addiqan lim\q@u{a} bayna yadayhi wahudan wabushr\q@u{a} lilmumineen\q@b{a}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@cv{Man k\q@u{a}na AAaduwwan lill\q@u{a}hi wamal\q@u{a}ikatihi warusulihi wajibreela wameek\q@u{a}la fainna All\q@u{a}ha AAaduwwun lilk\q@u{a}fireen\q@b{a}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@cvi{Walaqad anzaln\q@u{a} ilayka \q@u{a}y\q@u{a}tin bayyin\q@u{a}tin wam\q@u{a} yakfuru bih\q@u{a} ill\q@u{a} alf\q@u{a}siqoon\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@cvii{Awakullam\q@u{a} AA\q@u{a}hadoo AAahdan naba\q@u{th}ahu fareequn minhum bal aktharuhum l\q@u{a} yuminoon\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@cviii{Walamm\q@u{a} j\q@u{a}ahum rasoolun min AAindi All\q@u{a}hi mu\q@u{s}addiqun lim\q@u{a} maAAahum naba\q@u{th}a fareequn mina alla\q@u{th}eena ootoo alkit\q@u{a}ba kit\q@u{a}ba All\q@u{a}hi war\q@u{a}a \q@i{\q@u{th}}uhoorihim kaannahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@cix{Wa\q@b{i}ttabaAAoo m\q@u{a} tatloo a\q@b{l}shshay\q@u{at}eenu AAal\q@u{a} mulki sulaym\q@u{a}na wam\q@u{a} kafara sulaym\q@u{a}nu wal\q@u{a}kinna a\q@b{l}shshay\q@u{at}eena kafaroo yuAAallimoona a\q@b{l}nn\q@u{a}sa a\q@b{l}ssi\q@u{h}ra wam\q@u{a} onzila AAal\q@u{a} almalakayni bib\q@u{a}bila h\q@u{a}roota wam\q@u{a}roota wam\q@u{a} yuAAallim\q@u{a}ni min a\q@u{h}adin \q@u{h}att\q@u{a} yaqool\q@u{a} innam\q@u{a} na\q@u{h}nu fitnatun fal\q@u{a} takfur fayataAAallamoona minhum\q@u{a} m\q@u{a} yufarriqoona bihi bayna almari wazawjihi wam\q@u{a} hum bi\q@u{da}rreena bihi min a\q@u{h}adin ill\q@u{a} bii\q@u{th}ni All\q@u{a}hi wayataAAallamoona m\q@u{a} ya\q@u{d}urruhum wal\q@u{a} yanfaAAuhum walaqad AAalimoo lamani ishtar\q@u{a}hu m\q@u{a} lahu fee al\q@u{a}khirati min khal\q@u{a}qin walabisa m\q@u{a} sharaw bihi anfusahum law k\q@u{a}noo yaAAlamoon\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@cx{Walaw annahum \q@u{a}manoo wa\q@b{i}ttaqaw lamathoobatun min AAindi All\q@u{a}hi khayrun law k\q@u{a}noo yaAAlamoon\q@b{a}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@cxi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} taqooloo r\q@u{a}AAin\q@u{a} waqooloo on\q@i{\q@u{th}}urn\q@u{a} wa\q@b{i}smaAAoo walilk\q@u{a}fireena AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@cxii{M\q@u{a} yawaddu alla\q@u{th}eena kafaroo min ahli alkit\q@u{a}bi wal\q@u{a} almushrikeena an yunazzala AAalaykum min khayrin min rabbikum wa\q@b{A}ll\q@u{a}hu yakhta\q@u{ss}u bira\q@u{h}matihi man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu \q@u{th}oo alfa\q@u{d}li alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@cxiii{M\q@u{a} nansakh min \q@u{a}yatin aw nunsih\q@u{a} nati bikhayrin minh\q@u{a} aw mithlih\q@u{a} alam taAAlam anna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@cxiv{Alam taAAlam anna All\q@u{a}ha lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} lakum min dooni All\q@u{a}hi min waliyyin wal\q@u{a} na\q@u{s}eer\q@b{in}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@cxv{Am tureedoona an tasaloo rasoolakum kam\q@u{a} suila moos\q@u{a} min qablu waman yatabaddali alkufra bi\q@b{a}leem\q@u{a}ni faqad \q@u{d}alla saw\q@u{a}a a\q@b{l}ssabeel\q@b{i}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@cxvi{Wadda katheerun min ahli alkit\q@u{a}bi law yaruddoonakum min baAAdi eem\q@u{a}nikum kuff\q@u{a}ran \q@u{h}asadan min AAindi anfusihim min baAAdi m\q@u{a} tabayyana lahumu al\q@u{h}aqqu fa\q@b{o}AAfoo wa\q@b{i}\q@u{s}fa\q@u{h}oo \q@u{h}att\q@u{a} yatiya All\q@u{a}hu biamrihi inna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@cxvii{Waaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}too a\q@b{l}zzak\q@u{a}ta wam\q@u{a} tuqaddimoo lianfusikum min khayrin tajidoohu AAinda All\q@u{a}hi inna All\q@u{a}ha bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@cxviii{Waq\q@u{a}loo lan yadkhula aljannata ill\q@u{a} man k\q@u{a}na hoodan aw na\q@u{sa}r\q@u{a} tilka am\q@u{a}niyyuhum qul h\q@u{a}too burh\q@u{a}nakum in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@cxix{Bal\q@u{a} man aslama wajhahu lill\q@u{a}hi wahuwa mu\q@u{h}sinun falahu ajruhu AAinda rabbihi wal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@cxx{Waq\q@u{a}lati alyahoodu laysati a\q@b{l}nna\q@u{sa}r\q@u{a} AAal\q@u{a} shayin waq\q@u{a}lati a\q@b{l}nna\q@u{sa}r\q@u{a} laysati alyahoodu AAal\q@u{a} shayin wahum yatloona alkit\q@u{a}ba ka\q@u{tha}lika q\q@u{a}la alla\q@u{th}eena l\q@u{a} yaAAlamoona mithla qawlihim fa\q@b{A}ll\q@u{a}hu ya\q@u{h}kumu baynahum yawma alqiy\q@u{a}mati feem\q@u{a} k\q@u{a}noo feehi yakhtalifoon\q@b{a}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@cxxi{Waman a\q@i{\q@u{th}}lamu mimman manaAAa mas\q@u{a}jida All\q@u{a}hi an yu\q@u{th}kara feeh\q@u{a} ismuhu wasaAA\q@u{a} fee khar\q@u{a}bih\q@u{a} ol\q@u{a}ika m\q@u{a} k\q@u{a}na lahum an yadkhulooh\q@u{a} ill\q@u{a} kh\q@u{a}ifeena lahum fee a\q@b{l}dduny\q@u{a} khizyun walahum fee al\q@u{a}khirati AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@cxxii{Walill\q@u{a}hi almashriqu wa\q@b{a}lmaghribu faaynam\q@u{a} tuwalloo fathamma wajhu All\q@u{a}hi inna All\q@u{a}ha w\q@u{a}siAAun AAaleem\q@b{un}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@cxxiii{Waq\q@u{a}loo itakha\q@u{th}a All\q@u{a}hu waladan sub\q@u{ha}nahu bal lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i kullun lahu q\q@u{a}nitoon\q@b{a}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@cxxiv{BadeeAAu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wai\q@u{tha} qa\q@u{da} amran fainnam\q@u{a} yaqoolu lahu kun fayakoon\q@b{u}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@cxxv{Waq\q@u{a}la alla\q@u{th}eena l\q@u{a} yaAAlamoona lawl\q@u{a} yukallimun\q@u{a} All\q@u{a}hu aw tateen\q@u{a} \q@u{a}yatun ka\q@u{tha}lika q\q@u{a}la alla\q@u{th}eena min qablihim mithla qawlihim tash\q@u{a}bahat quloobuhum qad bayyann\q@u{a} al\q@u{a}y\q@u{a}ti liqawmin yooqinoon\q@b{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@cxxvi{Inn\q@u{a} arsaln\q@u{a}ka bi\q@b{a}l\q@u{h}aqqi basheeran wana\q@u{th}eeran wal\q@u{a} tusalu Aaan a\q@u{s}\q@u{ha}bi alja\q@u{h}eem\q@b{i}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@cxxvii{Walan tar\q@u{da} AAanka alyahoodu wal\q@u{a} a\q@b{l}nna\q@u{sa}r\q@u{a} \q@u{h}att\q@u{a} tattabiAAa millatahum qul inna hud\q@u{a} All\q@u{a}hi huwa alhud\q@u{a} walaini ittabaAAta ahw\q@u{a}ahum baAAda alla\q@u{th}ee j\q@u{a}aka mina alAAilmi m\q@u{a} laka mina All\q@u{a}hi min waliyyin wal\q@u{a} na\q@u{s}eer\q@b{in}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@cxxviii{Alla\q@u{th}eena \q@u{a}tayn\q@u{a}humu alkit\q@u{a}ba yatloonahu \q@u{h}aqqa til\q@u{a}watihi ol\q@u{a}ika yuminoona bihi waman yakfur bihi faol\q@u{a}ika humu alkh\q@u{a}siroon\q@b{a}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@cxxix{Y\q@u{a} banee isr\q@u{a}eela o\q@u{th}kuroo niAAmatiya allatee anAAamtu AAalaykum waannee fa\q@u{dd}altukum AAal\q@u{a} alAA\q@u{a}lameen\q@b{a}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@cxxx{Wa\q@b{i}ttaqoo yawman l\q@u{a} tajzee nafsun AAan nafsin shayan wal\q@u{a} yuqbalu minh\q@u{a} AAadlun wal\q@u{a} tanfaAAuh\q@u{a} shaf\q@u{a}AAatun wal\q@u{a} hum yun\q@u{s}aroon\q@b{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@cxxxi{Wai\q@u{th}i ibtal\q@u{a} ibr\q@u{a}heema rabbuhu bikalim\q@u{a}tin faatammahunna q\q@u{a}la innee j\q@u{a}AAiluka li\q@b{l}nn\q@u{a}si im\q@u{a}man q\q@u{a}la wamin \q@u{th}urriyyatee q\q@u{a}la l\q@u{a} yan\q@u{a}lu AAahdee a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@cxxxii{Wai\q@u{th} jaAAaln\q@u{a} albayta math\q@u{a}batan li\q@b{l}nn\q@u{a}si waamnan wa\q@b{i}ttakhi\q@u{th}oo min maq\q@u{a}mi ibr\q@u{a}heema mu\q@u{s}allan waAAahidn\q@u{a} il\q@u{a} ibr\q@u{a}heema waism\q@u{a}AAeela an \q@u{t}ahhir\q@u{a} baytiya li\q@b{l}\q@u{tta}ifeena wa\q@b{a}lAA\q@u{a}kifeena wa\q@b{al}rrukkaAAi a\q@b{l}ssujood\q@b{i}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@cxxxiii{Wai\q@u{th} q\q@u{a}la ibr\q@u{a}heemu rabbi ijAAal h\q@u{atha} baladan \q@u{a}minan wa\q@b{o}rzuq ahlahu mina a\q@b{l}ththamar\q@u{a}ti man \q@u{a}mana minhum bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri q\q@u{a}la waman kafara faomattiAAuhu qaleelan thumma a\q@u{dt}arruhu il\q@u{a} AAa\q@u{tha}bi a\q@b{l}nn\q@u{a}ri wabisa alma\q@u{s}eer\q@b{u}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@cxxxiv{Wai\q@u{th} yarfaAAu ibr\q@u{a}heemu alqaw\q@u{a}AAida mina albayti waism\q@u{a}AAeelu rabban\q@u{a} taqabbal minn\q@u{a} innaka anta a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@cxxxv{Rabban\q@u{a} wa\q@b{i}jAAaln\q@u{a} muslimayni laka wamin \q@u{th}urriyyatin\q@u{a} ommatan muslimatan laka waarin\q@u{a} man\q@u{a}sikan\q@u{a} watub AAalayn\q@u{a} innaka anta a\q@b{l}ttaww\q@u{a}bu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@cxxxvi{Rabban\q@u{a} wa\q@b{i}bAAath feehim rasoolan minhum yatloo AAalayhim \q@u{a}y\q@u{a}tika wayuAAallimuhumu alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ikmata wayuzakkeehim innaka anta alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(129)}}
\qt@newcmd\qurantrans@lt@cxxxvii{Waman yarghabu AAan millati ibr\q@u{a}heema ill\q@u{a} man safiha nafsahu walaqadi i\q@u{st}afayn\q@u{a}hu fee a\q@b{l}dduny\q@u{a} wainnahu fee al\q@u{a}khirati lamina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(130)}}
\qt@newcmd\qurantrans@lt@cxxxviii{I\q@u{th} q\q@u{a}la lahu rabbuhu aslim q\q@u{a}la aslamtu lirabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(131)}}
\qt@newcmd\qurantrans@lt@cxxxix{Wawa\q@u{ssa} bih\q@u{a} ibr\q@u{a}heemu baneehi wayaAAqoobu y\q@u{a} baniyya inna All\q@u{a}ha i\q@u{st}af\q@u{a} lakumu a\q@b{l}ddeena fal\q@u{a} tamootunna ill\q@u{a} waantum muslimoon\q@b{a}\qt@no{(132)}}
\qt@newcmd\qurantrans@lt@cxl{Am kuntum shuhad\q@u{a}a i\q@u{th} \q@u{h}a\q@u{d}ara yaAAqooba almawtu i\q@u{th} q\q@u{a}la libaneehi m\q@u{a} taAAbudoona min baAAdee q\q@u{a}loo naAAbudu il\q@u{a}haka wail\q@u{a}ha \q@u{a}b\q@u{a}ika ibr\q@u{a}heema waism\q@u{a}AAeela wais\q@u{ha}qa il\q@u{a}han w\q@u{ah}idan wana\q@u{h}nu lahu muslimoon\q@b{a}\qt@no{(133)}}
\qt@newcmd\qurantrans@lt@cxli{Tilka ommatun qad khalat lah\q@u{a} m\q@u{a} kasabat walakum m\q@u{a} kasabtum wal\q@u{a} tusaloona AAamm\q@u{a} k\q@u{a}no yaAAmaloon\q@b{a}\qt@no{(134)}}
\qt@newcmd\qurantrans@lt@cxlii{Waq\q@u{a}loo koonoo hoodan aw na\q@u{sa}r\q@u{a} tahtadoo qul bal millata ibr\q@u{a}heema \q@u{h}aneefan wam\q@u{a} k\q@u{a}na mina almushrikeen\q@b{a}\qt@no{(135)}}
\qt@newcmd\qurantrans@lt@cxliii{Qooloo \q@u{a}mann\q@u{a} bi\q@b{A}ll\q@u{a}hi wam\q@u{a} onzila ilayn\q@u{a} wam\q@u{a} onzila il\q@u{a} ibr\q@u{a}heema waism\q@u{a}AAeela wais\q@u{ha}qa wayaAAqooba wa\q@b{a}lasb\q@u{at}i wam\q@u{a} ootiya moos\q@u{a} waAAees\q@u{a} wam\q@u{a} ootiya a\q@b{l}nnabiyyoona min rabbihim l\q@u{a} nufarriqu bayna a\q@u{h}adin minhum wana\q@u{h}nu lahu muslimoon\q@b{a}\qt@no{(136)}}
\qt@newcmd\qurantrans@lt@cxliv{Fain \q@u{a}manoo bimithli m\q@u{a} \q@u{a}mantum bihi faqadi ihtadaw wain tawallaw fainnam\q@u{a} hum fee shiq\q@u{a}qin fasayakfeekahumu All\q@u{a}hu wahuwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(137)}}
\qt@newcmd\qurantrans@lt@cxlv{\q@u{S}ibghata All\q@u{a}hi waman a\q@u{h}sanu mina All\q@u{a}hi \q@u{s}ibghatan wana\q@u{h}nu lahu AA\q@u{a}bidoon\q@b{a}\qt@no{(138)}}
\qt@newcmd\qurantrans@lt@cxlvi{Qul atu\q@u{ha}jjoonan\q@u{a} fee All\q@u{a}hi wahuwa rabbun\q@u{a} warabbukum walan\q@u{a} aAAm\q@u{a}lun\q@u{a} walakum aAAm\q@u{a}lukum wana\q@u{h}nu lahu mukhli\q@u{s}oon\q@b{a}\qt@no{(139)}}
\qt@newcmd\qurantrans@lt@cxlvii{Am taqooloona inna ibr\q@u{a}heema waism\q@u{a}AAeela wais\q@u{ha}qa wayaAAqooba wa\q@b{a}lasb\q@u{at}a k\q@u{a}noo hoodan aw na\q@u{sa}r\q@u{a} qul aantum aAAlamu ami All\q@u{a}hu waman a\q@i{\q@u{th}}lamu mimman katama shah\q@u{a}datan AAindahu mina All\q@u{a}hi wam\q@u{a} All\q@u{a}hu bigh\q@u{a}filin AAamm\q@u{a} taAAmaloon\q@b{a}\qt@no{(140)}}
\qt@newcmd\qurantrans@lt@cxlviii{Tilka ommatun qad khalat lah\q@u{a} m\q@u{a} kasabat walakum m\q@u{a} kasabtum wal\q@u{a} tusaloona AAamm\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(141)}}
\qt@newcmd\qurantrans@lt@cxlix{Sayaqoolu a\q@b{l}ssufah\q@u{a}o mina a\q@b{l}nn\q@u{a}si m\q@u{a} wall\q@u{a}hum AAan qiblatihimu allatee k\q@u{a}noo AAalayh\q@u{a} qul lill\q@u{a}hi almashriqu wa\q@b{a}lmaghribu yahdee man yash\q@u{a}o il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(142)}}
\qt@newcmd\qurantrans@lt@cl{Waka\q@u{tha}lika jaAAaln\q@u{a}kum ommatan wasa\q@u{t}an litakoonoo shuhad\q@u{a}a AAal\q@u{a} a\q@b{l}nn\q@u{a}si wayakoona a\q@b{l}rrasoolu AAalaykum shaheedan wam\q@u{a} jaAAaln\q@u{a} alqiblata allatee kunta AAalayh\q@u{a} ill\q@u{a} linaAAlama man yattabiAAu a\q@b{l}rrasoola mimman yanqalibu AAal\q@u{a} AAaqibayhi wain k\q@u{a}nat lakabeeratan ill\q@u{a} AAal\q@u{a} alla\q@u{th}eena had\q@u{a} All\q@u{a}hu wam\q@u{a} k\q@u{a}na All\q@u{a}hu liyu\q@u{d}eeAAa eem\q@u{a}nakum inna All\q@u{a}ha bi\q@b{al}nn\q@u{a}si laraoofun ra\q@u{h}eem\q@b{un}\qt@no{(143)}}
\qt@newcmd\qurantrans@lt@cli{Qad nar\q@u{a} taqalluba wajhika fee a\q@b{l}ssam\q@u{a}i falanuwalliyannaka qiblatan tar\q@u{da}h\q@u{a} fawalli wajhaka sha\q@u{t}ra almasjidi al\q@u{h}ar\q@u{a}mi wa\q@u{h}aythu m\q@u{a} kuntum fawalloo wujoohakum sha\q@u{t}rahu wainna alla\q@u{th}eena ootoo alkit\q@u{a}ba layaAAlamoona annahu al\q@u{h}aqqu min rabbihim wam\q@u{a} All\q@u{a}hu bigh\q@u{a}filin AAamm\q@u{a} yaAAmaloon\q@b{a}\qt@no{(144)}}
\qt@newcmd\qurantrans@lt@clii{Walain atayta alla\q@u{th}eena ootoo alkit\q@u{a}ba bikulli \q@u{a}yatin m\q@u{a} tabiAAoo qiblataka wam\q@u{a} anta bit\q@u{a}biAAin qiblatahum wam\q@u{a} baAA\q@u{d}uhum bit\q@u{a}biAAin qiblata baAA\q@u{d}in walaini ittabaAAta ahw\q@u{a}ahum min baAAdi m\q@u{a} j\q@u{a}aka mina alAAilmi innaka i\q@u{th}an lamina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(145)}}
\qt@newcmd\qurantrans@lt@cliii{Alla\q@u{th}eena \q@u{a}tayn\q@u{a}humu alkit\q@u{a}ba yaAArifoonahu kam\q@u{a} yaAArifoona abn\q@u{a}ahum wainna fareeqan minhum layaktumoona al\q@u{h}aqqa wahum yaAAlamoon\q@b{a}\qt@no{(146)}}
\qt@newcmd\qurantrans@lt@cliv{Al\q@u{h}aqqu min rabbika fal\q@u{a} takoonanna mina almumtareen\q@b{a}\qt@no{(147)}}
\qt@newcmd\qurantrans@lt@clv{Walikullin wijhatun huwa muwalleeh\q@u{a} fa\q@b{i}stabiqoo alkhayr\q@u{a}ti ayna m\q@u{a} takoonoo yati bikumu All\q@u{a}hu jameeAAan inna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(148)}}
\qt@newcmd\qurantrans@lt@clvi{Wamin \q@u{h}aythu kharajta fawalli wajhaka sha\q@u{t}ra almasjidi al\q@u{h}ar\q@u{a}mi wainnahu lal\q@u{h}aqqu min rabbika wam\q@u{a} All\q@u{a}hu bigh\q@u{a}filin AAamm\q@u{a} taAAmaloon\q@b{a}\qt@no{(149)}}
\qt@newcmd\qurantrans@lt@clvii{Wamin \q@u{h}aythu kharajta fawalli wajhaka sha\q@u{t}ra almasjidi al\q@u{h}ar\q@u{a}mi wa\q@u{h}aythu m\q@u{a} kuntum fawalloo wujoohakum sha\q@u{t}rahu liall\q@u{a} yakoona li\q@b{l}nn\q@u{a}si AAalaykum \q@u{h}ujjatun ill\q@u{a} alla\q@u{th}eena \q@i{\q@u{th}}alamoo minhum fal\q@u{a} takhshawhum wa\q@b{i}khshawnee waliotimma niAAmatee AAalaykum walaAAallakum tahtadoon\q@b{a}\qt@no{(150)}}
\qt@newcmd\qurantrans@lt@clviii{Kam\q@u{a} arsaln\q@u{a} feekum rasoolan minkum yatloo AAalaykum \q@u{a}y\q@u{a}tin\q@u{a} wayuzakkeekum wayuAAallimukumu alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ikmata wayuAAallimukum m\q@u{a} lam takoonoo taAAlamoon\q@b{a}\qt@no{(151)}}
\qt@newcmd\qurantrans@lt@clix{Fa\q@b{o}\q@u{th}kuroonee a\q@u{th}kurkum wa\q@b{o}shkuroo lee wal\q@u{a} takfuroon\q@b{i}\qt@no{(152)}}
\qt@newcmd\qurantrans@lt@clx{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo istaAAeenoo bi\q@b{al}\q@u{ss}abri wa\q@b{al}\q@u{ss}al\q@u{a}ti inna All\q@u{a}ha maAAa a\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(153)}}
\qt@newcmd\qurantrans@lt@clxi{Wal\q@u{a} taqooloo liman yuqtalu fee sabeeli All\q@u{a}hi amw\q@u{a}tun bal a\q@u{h}y\q@u{a}on wal\q@u{a}kin l\q@u{a} tashAAuroon\q@b{a}\qt@no{(154)}}
\qt@newcmd\qurantrans@lt@clxii{Walanabluwannakum bishayin mina alkhawfi wa\q@b{a}ljooAAi wanaq\q@u{s}in mina alamw\q@u{a}li wa\q@b{a}lanfusi wa\q@b{al}ththamar\q@u{a}ti wabashshiri a\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(155)}}
\qt@newcmd\qurantrans@lt@clxiii{Alla\q@u{th}eena i\q@u{tha} a\q@u{sa}bathum mu\q@u{s}eebatun q\q@u{a}loo inn\q@u{a} lill\q@u{a}hi wainn\q@u{a} ilayhi r\q@u{a}jiAAoon\q@b{a}\qt@no{(156)}}
\qt@newcmd\qurantrans@lt@clxiv{Ol\q@u{a}ika AAalayhim \q@u{s}alaw\q@u{a}tun min rabbihim wara\q@u{h}matun waol\q@u{a}ika humu almuhtadoon\q@b{a}\qt@no{(157)}}
\qt@newcmd\qurantrans@lt@clxv{Inna a\q@b{l}\q@u{ss}af\q@u{a} wa\q@b{a}lmarwata min shaAA\q@u{a}iri All\q@u{a}hi faman \q@u{h}ajja albayta awi iAAtamara fal\q@u{a} jun\q@u{ah}a AAalayhi an ya\q@u{tt}awwafa bihim\q@u{a} waman ta\q@u{t}awwaAAa khayran fainna All\q@u{a}ha sh\q@u{a}kirun AAaleem\q@b{un}\qt@no{(158)}}
\qt@newcmd\qurantrans@lt@clxvi{Inna alla\q@u{th}eena yaktumoona m\q@u{a} anzaln\q@u{a} mina albayyin\q@u{a}ti wa\q@b{a}lhud\q@u{a} min baAAdi m\q@u{a} bayyann\q@u{a}hu li\q@b{l}nn\q@u{a}si fee alkit\q@u{a}bi ol\q@u{a}ika yalAAanuhumu All\q@u{a}hu wayalAAanuhumu all\q@u{a}AAinoon\q@b{a}\qt@no{(159)}}
\qt@newcmd\qurantrans@lt@clxvii{Ill\q@u{a} alla\q@u{th}eena t\q@u{a}boo waa\q@u{s}la\q@u{h}oo wabayyanoo faol\q@u{a}ika atoobu AAalayhim waan\q@u{a} a\q@b{l}ttaww\q@u{a}bu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(160)}}
\qt@newcmd\qurantrans@lt@clxviii{Inna alla\q@u{th}eena kafaroo wam\q@u{a}too wahum kuff\q@u{a}run ol\q@u{a}ika AAalayhim laAAnatu All\q@u{a}hi wa\q@b{a}lmal\q@u{a}ikati wa\q@b{al}nn\q@u{a}si ajmaAAeen\q@b{a}\qt@no{(161)}}
\qt@newcmd\qurantrans@lt@clxix{Kh\q@u{a}lideena feeh\q@u{a} l\q@u{a} yukhaffafu AAanhumu alAAa\q@u{tha}bu wal\q@u{a} hum yun\q@i{\q@u{th}}aroon\q@b{a}\qt@no{(162)}}
\qt@newcmd\qurantrans@lt@clxx{Wail\q@u{a}hukum il\q@u{a}hun w\q@u{ah}idun l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa a\q@b{l}rra\q@u{h}m\q@u{a}nu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(163)}}
\qt@newcmd\qurantrans@lt@clxxi{Inna fee khalqi a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{i}khtil\q@u{a}fi allayli wa\q@b{al}nnah\q@u{a}ri wa\q@b{a}lfulki allatee tajree fee alba\q@u{h}ri bim\q@u{a} yanfaAAu a\q@b{l}nn\q@u{a}sa wam\q@u{a} anzala All\q@u{a}hu mina a\q@b{l}ssam\q@u{a}i min m\q@u{a}in faa\q@u{h}y\q@u{a} bihi alar\q@u{d}a baAAda mawtih\q@u{a} wabaththa feeh\q@u{a} min kulli d\q@u{a}bbatin wata\q@u{s}reefi a\q@b{l}rriy\q@u{ah}i wa\q@b{al}ssa\q@u{ha}bi almusakhkhari bayna a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i la\q@u{a}y\q@u{a}tin liqawmin yaAAqiloon\q@b{a}\qt@no{(164)}}
\qt@newcmd\qurantrans@lt@clxxii{Wamina a\q@b{l}nn\q@u{a}si man yattakhi\q@u{th}u min dooni All\q@u{a}hi and\q@u{a}dan yu\q@u{h}ibboonahum ka\q@u{h}ubbi All\q@u{a}hi wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo ashaddu \q@u{h}ubban lill\q@u{a}hi walaw yar\q@u{a} alla\q@u{th}eena \q@i{\q@u{th}}alamoo i\q@u{th} yarawna alAAa\q@u{tha}ba anna alquwwata lill\q@u{a}hi jameeAAan waanna All\q@u{a}ha shadeedu alAAa\q@u{tha}b\q@b{i}\qt@no{(165)}}
\qt@newcmd\qurantrans@lt@clxxiii{I\q@u{th} tabarraa alla\q@u{th}eena ittubiAAoo mina alla\q@u{th}eena ittabaAAoo waraawoo alAAa\q@u{tha}ba wataqa\q@u{tt}aAAat bihimu alasb\q@u{a}b\q@b{u}\qt@no{(166)}}
\qt@newcmd\qurantrans@lt@clxxiv{Waq\q@u{a}la alla\q@u{th}eena ittabaAAoo law anna lan\q@u{a} karratan fanatabarraa minhum kam\q@u{a} tabarraoo minn\q@u{a} ka\q@u{tha}lika yureehimu All\q@u{a}hu aAAm\q@u{a}lahum \q@u{h}asar\q@u{a}tin AAalayhim wam\q@u{a} hum bikh\q@u{a}rijeena mina a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(167)}}
\qt@newcmd\qurantrans@lt@clxxv{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su kuloo mimm\q@u{a} fee alar\q@u{d}i \q@u{h}al\q@u{a}lan \q@u{t}ayyiban wal\q@u{a} tattabiAAoo khu\q@u{t}uw\q@u{a}ti a\q@b{l}shshay\q@u{ta}ni innahu lakum AAaduwwun mubeen\q@b{un}\qt@no{(168)}}
\qt@newcmd\qurantrans@lt@clxxvi{Innam\q@u{a} yamurukum bi\q@b{al}ssooi wa\q@b{a}lfa\q@u{h}sh\q@u{a}i waan taqooloo AAal\q@u{a} All\q@u{a}hi m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(169)}}
\qt@newcmd\qurantrans@lt@clxxvii{Wai\q@u{tha} qeela lahumu ittabiAAoo m\q@u{a} anzala All\q@u{a}hu q\q@u{a}loo bal nattabiAAu m\q@u{a} alfayn\q@u{a} AAalayhi \q@u{a}b\q@u{a}an\q@u{a} awalaw k\q@u{a}na \q@u{a}b\q@u{a}ohum l\q@u{a} yaAAqiloona shayan wal\q@u{a} yahtadoon\q@b{a}\qt@no{(170)}}
\qt@newcmd\qurantrans@lt@clxxviii{Wamathalu alla\q@u{th}eena kafaroo kamathali alla\q@u{th}ee yanAAiqu bim\q@u{a} l\q@u{a} yasmaAAu ill\q@u{a} duAA\q@u{a}an wanid\q@u{a}an \q@u{s}ummun bukmun AAumyun fahum l\q@u{a} yaAAqiloon\q@b{a}\qt@no{(171)}}
\qt@newcmd\qurantrans@lt@clxxix{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo kuloo min \q@u{t}ayyib\q@u{a}ti m\q@u{a} razaqn\q@u{a}kum wa\q@b{o}shkuroo lill\q@u{a}hi in kuntum iyy\q@u{a}hu taAAbudoon\q@b{a}\qt@no{(172)}}
\qt@newcmd\qurantrans@lt@clxxx{Innam\q@u{a} \q@u{h}arrama AAalaykumu almaytata wa\q@b{al}ddama wala\q@u{h}ma alkhinzeeri wam\q@u{a} ohilla bihi lighayri All\q@u{a}hi famani i\q@u{dt}urra ghayra b\q@u{a}ghin wal\q@u{a} AA\q@u{a}din fal\q@u{a} ithma AAalayhi inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(173)}}
\qt@newcmd\qurantrans@lt@clxxxi{Inna alla\q@u{th}eena yaktumoona m\q@u{a} anzala All\q@u{a}hu mina alkit\q@u{a}bi wayashtaroona bihi thamanan qaleelan ol\q@u{a}ika m\q@u{a} yakuloona fee bu\q@u{t}oonihim ill\q@u{a} a\q@b{l}nn\q@u{a}ra wal\q@u{a} yukallimuhumu All\q@u{a}hu yawma alqiy\q@u{a}mati wal\q@u{a} yuzakkeehim walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(174)}}
\qt@newcmd\qurantrans@lt@clxxxii{Ol\q@u{a}ika alla\q@u{th}eena ishtarawoo a\q@b{l}\q@u{dd}al\q@u{a}lata bi\q@b{a}lhud\q@u{a} wa\q@b{a}lAAa\q@u{tha}ba bi\q@b{a}lmaghfirati fam\q@u{a} a\q@u{s}barahum AAal\q@u{a} a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(175)}}
\qt@newcmd\qurantrans@lt@clxxxiii{\q@u{Tha}lika bianna All\q@u{a}ha nazzala alkit\q@u{a}ba bi\q@b{a}l\q@u{h}aqqi wainna alla\q@u{th}eena ikhtalafoo fee alkit\q@u{a}bi lafee shiq\q@u{a}qin baAAeed\q@b{in}\qt@no{(176)}}
\qt@newcmd\qurantrans@lt@clxxxiv{Laysa albirra an tuwalloo wujoohakum qibala almashriqi wa\q@b{a}lmaghribi wal\q@u{a}kinna albirra man \q@u{a}mana bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri wa\q@b{a}lmal\q@u{a}ikati wa\q@b{a}lkit\q@u{a}bi wa\q@b{al}nnabiyyeena wa\q@u{a}t\q@u{a} alm\q@u{a}la AAal\q@u{a} \q@u{h}ubbihi \q@u{th}awee alqurb\q@u{a} wa\q@b{a}lyat\q@u{a}m\q@u{a} wa\q@b{a}lmas\q@u{a}keena wa\q@b{i}bna alssabeeli wa\q@b{al}ss\q@u{a}ileena wafee a\q@b{l}rriq\q@u{a}bi waaq\q@u{a}ma a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}t\q@u{a} a\q@b{l}zzak\q@u{a}ta wa\q@b{a}lmoofoona biAAahdihim i\q@u{tha} AA\q@u{a}hadoo wa\q@b{al}\q@u{ssa}bireena fee albas\q@u{a}i wa\q@b{al}\q@u{dd}arr\q@u{a}i wa\q@u{h}eena albasi ol\q@u{a}ika alla\q@u{th}eena \q@u{s}adaqoo waol\q@u{a}ika humu almuttaqoon\q@b{a}\qt@no{(177)}}
\qt@newcmd\qurantrans@lt@clxxxv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo kutiba AAalaykumu alqi\q@u{sas}u fee alqatl\q@u{a} al\q@u{h}urru bi\q@b{a}l\q@u{h}urri wa\q@b{a}lAAabdu bi\q@b{a}lAAabdi wa\q@b{a}lonth\q@u{a} bi\q@b{a}lonth\q@u{a} faman AAufiya lahu min akheehi shayon fa\q@b{i}ttib\q@u{a}AAun bi\q@b{a}lmaAAroofi waad\q@u{a}on ilayhi bii\q@u{h}s\q@u{a}nin \q@u{tha}lika takhfeefun min rabbikum wara\q@u{h}matun famani iAAtad\q@u{a} baAAda \q@u{tha}lika falahu AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(178)}}
\qt@newcmd\qurantrans@lt@clxxxvi{Walakum fee alqi\q@u{sas}i \q@u{h}ay\q@u{a}tun y\q@u{a} olee alalb\q@u{a}bi laAAallakum tattaqoon\q@b{a}\qt@no{(179)}}
\qt@newcmd\qurantrans@lt@clxxxvii{Kutiba AAalaykum i\q@u{tha} \q@u{h}a\q@u{d}ara a\q@u{h}adakumu almawtu in taraka khayran alwa\q@u{s}iyyatu lilw\q@u{a}lidayni wa\q@b{a}laqrabeena bi\q@b{a}lmaAAroofi \q@u{h}aqqan AAal\q@u{a} almuttaqeen\q@b{a}\qt@no{(180)}}
\qt@newcmd\qurantrans@lt@clxxxviii{Faman baddalahu baAAdam\q@u{a} samiAAahu fainnam\q@u{a} ithmuhu AAal\q@u{a} alla\q@u{th}eena yubaddiloonahu inna All\q@u{a}ha sameeAAun AAaleem\q@b{un}\qt@no{(181)}}
\qt@newcmd\qurantrans@lt@clxxxix{Faman kh\q@u{a}fa min moo\q@u{s}in janafan aw ithman faa\q@u{s}la\q@u{h}a baynahum fal\q@u{a} ithma AAalayhi inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(182)}}
\qt@newcmd\qurantrans@lt@cxc{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo kutiba AAalaykumu a\q@b{l}\q@u{ss}iy\q@u{a}mu kam\q@u{a} kutiba AAal\q@u{a} alla\q@u{th}eena min qablikum laAAallakum tattaqoon\q@b{a}\qt@no{(183)}}
\qt@newcmd\qurantrans@lt@cxci{Ayy\q@u{a}man maAAdood\q@u{a}tin faman k\q@u{a}na minkum maree\q@u{d}an aw AAal\q@u{a} safarin faAAiddatun min ayy\q@u{a}min okhara waAAal\q@u{a} alla\q@u{th}eena yu\q@u{t}eeqoonahu fidyatun \q@u{t}aAA\q@u{a}mu miskeenin faman ta\q@u{t}awwaAAa khayran fahuwa khayrun lahu waan ta\q@u{s}oomoo khayrun lakum in kuntum taAAlamoon\q@b{a}\qt@no{(184)}}
\qt@newcmd\qurantrans@lt@cxcii{Shahru rama\q@u{da}na alla\q@u{th}ee onzila feehi alqur\q@u{a}nu hudan li\q@b{l}nn\q@u{a}si wabayyin\q@u{a}tin mina alhud\q@u{a} wa\q@b{a}lfurq\q@u{a}ni faman shahida minkumu a\q@b{l}shshahra falya\q@u{s}umhu waman k\q@u{a}na maree\q@u{d}an aw AAal\q@u{a} safarin faAAiddatun min ayy\q@u{a}min okhara yureedu All\q@u{a}hu bikumu alyusra wal\q@u{a} yureedu bikumu alAAusra walitukmiloo alAAiddata walitukabbiroo All\q@u{a}ha AAal\q@u{a} m\q@u{a} had\q@u{a}kum walaAAallakum tashkuroon\q@b{a}\qt@no{(185)}}
\qt@newcmd\qurantrans@lt@cxciii{Wai\q@u{tha} saalaka AAib\q@u{a}dee AAannee fainnee qareebun ojeebu daAAwata a\q@b{l}dd\q@u{a}AAi i\q@u{tha} daAA\q@u{a}ni falyastajeeboo lee walyuminoo bee laAAallahum yarshudoon\q@b{a}\qt@no{(186)}}
\qt@newcmd\qurantrans@lt@cxciv{O\q@u{h}illa lakum laylata a\q@b{l}\q@u{ss}iy\q@u{a}mi a\q@b{l}rrafathu il\q@u{a} nis\q@u{a}ikum hunna lib\q@u{a}sun lakum waantum lib\q@u{a}sun lahunna AAalima All\q@u{a}hu annakum kuntum takht\q@u{a}noona anfusakum fat\q@u{a}ba AAalaykum waAAaf\q@u{a} AAankum fa\q@b{a}l\q@u{a}na b\q@u{a}shiroohunna wa\q@b{i}btaghoo m\q@u{a} kataba All\q@u{a}hu lakum wakuloo wa\q@b{i}shraboo \q@u{h}att\q@u{a} yatabayyana lakumu alkhay\q@u{t}u alabya\q@u{d}u mina alkhay\q@u{t}i alaswadi mina alfajri thumma atimmoo a\q@b{l}\q@u{ss}iy\q@u{a}ma il\q@u{a} allayli wal\q@u{a} tub\q@u{a}shiroohunna waantum AA\q@u{a}kifoona fee almas\q@u{a}jidi tilka \q@u{h}udoodu All\q@u{a}hi fal\q@u{a} taqrabooh\q@u{a} ka\q@u{tha}lika yubayyinu All\q@u{a}hu \q@u{a}y\q@u{a}tihi li\q@b{l}nn\q@u{a}si laAAallahum yattaqoon\q@b{a}\qt@no{(187)}}
\qt@newcmd\qurantrans@lt@cxcv{Wal\q@u{a} takuloo amw\q@u{a}lakum baynakum bi\q@b{a}lb\q@u{at}ili watudloo bih\q@u{a} il\q@u{a} al\q@u{h}ukk\q@u{a}mi litakuloo fareeqan min amw\q@u{a}li a\q@b{l}nn\q@u{a}si bi\q@b{a}lithmi waantum taAAlamoon\q@b{a}\qt@no{(188)}}
\qt@newcmd\qurantrans@lt@cxcvi{Yasaloonaka AAani alahillati qul hiya maw\q@u{a}qeetu li\q@b{l}nn\q@u{a}si wa\q@b{a}l\q@u{h}ajji walaysa albirru bian tatoo albuyoota min \q@i{\q@u{th}}uhoorih\q@u{a} wal\q@u{a}kinna albirra mani ittaq\q@u{a} watoo albuyoota min abw\q@u{a}bih\q@u{a} wa\q@b{i}ttaqoo All\q@u{a}ha laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(189)}}
\qt@newcmd\qurantrans@lt@cxcvii{Waq\q@u{a}tiloo fee sabeeli All\q@u{a}hi alla\q@u{th}eena yuq\q@u{a}tiloonakum wal\q@u{a} taAAtadoo inna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu almuAAtadeen\q@b{a}\qt@no{(190)}}
\qt@newcmd\qurantrans@lt@cxcviii{Wa\q@b{o}qtuloohum \q@u{h}aythu thaqiftumoohum waakhrijoohum min \q@u{h}aythu akhrajookum wa\q@b{a}lfitnatu ashaddu mina alqatli wal\q@u{a} tuq\q@u{a}tiloohum AAinda almasjidi al\q@u{h}ar\q@u{a}mi \q@u{h}att\q@u{a} yuq\q@u{a}tilookum feehi fain q\q@u{a}talookum fa\q@b{o}qtuloohum ka\q@u{tha}lika jaz\q@u{a}o alk\q@u{a}fireen\q@b{a}\qt@no{(191)}}
\qt@newcmd\qurantrans@lt@cxcix{Faini intahaw fainna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(192)}}
\qt@newcmd\qurantrans@lt@cc{Waq\q@u{a}tiloohum \q@u{h}att\q@u{a} l\q@u{a} takoona fitnatun wayakoona a\q@b{l}ddeenu lill\q@u{a}hi faini intahaw fal\q@u{a} AAudw\q@u{a}na ill\q@u{a} AAal\q@u{a} a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(193)}}
\qt@newcmd\qurantrans@lt@cci{A\q@b{l}shshahru al\q@u{h}ar\q@u{a}mu bi\q@b{al}shshahri al\q@u{h}ar\q@u{a}mi wa\q@b{a}l\q@u{h}urum\q@u{a}tu qi\q@u{sas}un famani iAAtad\q@u{a} AAalaykum fa\q@b{i}AAtadoo AAalayhi bimithli m\q@u{a} iAAtad\q@u{a} AAalaykum wa\q@b{i}ttaqoo All\q@u{a}ha wa\q@b{i}AAlamoo anna All\q@u{a}ha maAAa almuttaqeen\q@b{a}\qt@no{(194)}}
\qt@newcmd\qurantrans@lt@ccii{Waanfiqoo fee sabeeli All\q@u{a}hi wal\q@u{a} tulqoo biaydeekum il\q@u{a} a\q@b{l}ttahlukati waa\q@u{h}sinoo inna All\q@u{a}ha yu\q@u{h}ibbu almu\q@u{h}sineen\q@b{a}\qt@no{(195)}}
\qt@newcmd\qurantrans@lt@cciii{Waatimmoo al\q@u{h}ajja wa\q@b{a}lAAumrata lill\q@u{a}hi fain o\q@u{hs}irtum fam\q@u{a} istaysara mina alhadyi wal\q@u{a} ta\q@u{h}liqoo ruoosakum \q@u{h}att\q@u{a} yablugha alhadyu ma\q@u{h}illahu faman k\q@u{a}na minkum maree\q@u{d}an aw bihi a\q@u{th}an min rasihi fafidyatun min \q@u{s}iy\q@u{a}min aw \q@u{s}adaqatin aw nusukin fai\q@u{tha} amintum faman tamattaAAa bi\q@b{a}lAAumrati il\q@u{a} al\q@u{h}ajji fam\q@u{a} istaysara mina alhadyi faman lam yajid fa\q@u{s}iy\q@u{a}mu thal\q@u{a}thati ayy\q@u{a}min fee al\q@u{h}ajji wasabAAatin i\q@u{tha} rajaAAtum tilka AAasharatun k\q@u{a}milatun \q@u{tha}lika liman lam yakun ahluhu \q@u{had}iree almasjidi al\q@u{h}ar\q@u{a}mi wa\q@b{i}ttaqoo All\q@u{a}ha wa\q@b{i}AAlamoo anna All\q@u{a}ha shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(196)}}
\qt@newcmd\qurantrans@lt@cciv{Al\q@u{h}ajju ashhurun maAAloom\q@u{a}tun faman fara\q@u{d}a feehinna al\q@u{h}ajja fal\q@u{a} rafatha wal\q@u{a} fusooqa wal\q@u{a} jid\q@u{a}la fee al\q@u{h}ajji wam\q@u{a} tafAAaloo min khayrin yaAAlamhu All\q@u{a}hu watazawwadoo fainna khayra a\q@b{l}zz\q@u{a}di a\q@b{l}ttaqw\q@u{a} wa\q@b{i}ttaqooni y\q@u{a} olee alalb\q@u{a}b\q@b{i}\qt@no{(197)}}
\qt@newcmd\qurantrans@lt@ccv{Laysa AAalaykum jun\q@u{ah}un an tabtaghoo fa\q@u{d}lan min rabbikum fai\q@u{tha} afa\q@u{d}tum min AAaraf\q@u{a}tin fa\q@b{o}\q@u{th}kuroo All\q@u{a}ha AAinda almashAAari al\q@u{h}ar\q@u{a}mi wa\q@b{o}\q@u{th}kuroohu kam\q@u{a} had\q@u{a}kum wain kuntum min qablihi lamina a\q@b{l}\q@u{dda}lleen\q@b{a}\qt@no{(198)}}
\qt@newcmd\qurantrans@lt@ccvi{Thumma afee\q@u{d}oo min \q@u{h}aythu af\q@u{ad}a a\q@b{l}nn\q@u{a}su wa\q@b{i}staghfiroo All\q@u{a}ha inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(199)}}
\qt@newcmd\qurantrans@lt@ccvii{Fai\q@u{tha} qa\q@u{d}aytum man\q@u{a}sikakum fa\q@b{o}\q@u{th}kuroo All\q@u{a}ha ka\q@u{th}ikrikum \q@u{a}b\q@u{a}akum aw ashadda \q@u{th}ikran famina a\q@b{l}nn\q@u{a}si man yaqoolu rabban\q@u{a} \q@u{a}tin\q@u{a} fee a\q@b{l}dduny\q@u{a} wam\q@u{a} lahu fee al\q@u{a}khirati min khal\q@u{a}q\q@b{in}\qt@no{(200)}}
\qt@newcmd\qurantrans@lt@ccviii{Waminhum man yaqoolu rabban\q@u{a} \q@u{a}tin\q@u{a} fee a\q@b{l}dduny\q@u{a} \q@u{h}asanatan wafee al\q@u{a}khirati \q@u{h}asanatan waqin\q@u{a} AAa\q@u{tha}ba a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(201)}}
\qt@newcmd\qurantrans@lt@ccix{Ol\q@u{a}ika lahum na\q@u{s}eebun mimm\q@u{a} kasaboo wa\q@b{A}ll\q@u{a}hu sareeAAu al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(202)}}
\qt@newcmd\qurantrans@lt@ccx{Wa\q@b{o}\q@u{th}kuroo All\q@u{a}ha fee ayy\q@u{a}min maAAdood\q@u{a}tin faman taAAajjala fee yawmayni fal\q@u{a} ithma AAalayhi waman taakhkhara fal\q@u{a} ithma AAalayhi limani ittaq\q@u{a} wa\q@b{i}ttaqoo All\q@u{a}ha wa\q@b{i}AAlamoo annakum ilayhi tu\q@u{h}sharoon\q@b{a}\qt@no{(203)}}
\qt@newcmd\qurantrans@lt@ccxi{Wamina a\q@b{l}nn\q@u{a}si man yuAAjibuka qawluhu fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wayushhidu All\q@u{a}ha AAal\q@u{a} m\q@u{a} fee qalbihi wahuwa aladdu alkhi\q@u{sa}m\q@b{i}\qt@no{(204)}}
\qt@newcmd\qurantrans@lt@ccxii{Wai\q@u{tha} tawall\q@u{a} saAA\q@u{a} fee alar\q@u{d}i liyufsida feeh\q@u{a} wayuhlika al\q@u{h}artha wa\q@b{al}nnasla wa\q@b{A}ll\q@u{a}hu l\q@u{a} yu\q@u{h}ibbu alfas\q@u{a}d\q@b{a}\qt@no{(205)}}
\qt@newcmd\qurantrans@lt@ccxiii{Wai\q@u{tha} qeela lahu ittaqi All\q@u{a}ha akha\q@u{th}athu alAAizzatu bi\q@b{a}lithmi fa\q@u{h}asbuhu jahannamu walabisa almih\q@u{a}d\q@b{u}\qt@no{(206)}}
\qt@newcmd\qurantrans@lt@ccxiv{Wamina a\q@b{l}nn\q@u{a}si man yashree nafsahu ibtigh\q@u{a}a mar\q@u{da}ti All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu raoofun bi\q@b{a}lAAib\q@u{a}d\q@b{i}\qt@no{(207)}}
\qt@newcmd\qurantrans@lt@ccxv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo odkhuloo fee a\q@b{l}ssilmi k\q@u{a}ffatan wal\q@u{a} tattabiAAoo khu\q@u{t}uw\q@u{a}ti a\q@b{l}shshay\q@u{ta}ni innahu lakum AAaduwwun mubeen\q@b{un}\qt@no{(208)}}
\qt@newcmd\qurantrans@lt@ccxvi{Fain zalaltum min baAAdi m\q@u{a} j\q@u{a}atkumu albayyin\q@u{a}tu fa\q@b{i}AAlamoo anna All\q@u{a}ha AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(209)}}
\qt@newcmd\qurantrans@lt@ccxvii{Hal yan\q@i{\q@u{th}}uroona ill\q@u{a} an yatiyahumu All\q@u{a}hu fee \q@i{\q@u{th}}ulalin mina algham\q@u{a}mi wa\q@b{a}lmal\q@u{a}ikatu waqu\q@u{d}iya alamru wail\q@u{a} All\q@u{a}hi turjaAAu alomoor\q@b{u}\qt@no{(210)}}
\qt@newcmd\qurantrans@lt@ccxviii{Sal banee isr\q@u{a}eela kam \q@u{a}tayn\q@u{a}hum min \q@u{a}yatin bayyinatin waman yubaddil niAAmata All\q@u{a}hi min baAAdi m\q@u{a} j\q@u{a}athu fainna All\q@u{a}ha shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(211)}}
\qt@newcmd\qurantrans@lt@ccxix{Zuyyina lilla\q@u{th}eena kafaroo al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} wayaskharoona mina alla\q@u{th}eena \q@u{a}manoo wa\q@b{a}lla\q@u{th}eena ittaqaw fawqahum yawma alqiy\q@u{a}mati wa\q@b{A}ll\q@u{a}hu yarzuqu man yash\q@u{a}o bighayri \q@u{h}is\q@u{a}b\q@b{in}\qt@no{(212)}}
\qt@newcmd\qurantrans@lt@ccxx{K\q@u{a}na a\q@b{l}nn\q@u{a}su ommatan w\q@u{ah}idatan fabaAAatha All\q@u{a}hu a\q@b{l}nnabiyyeena mubashshireena wamun\q@u{th}ireena waanzala maAAahumu alkit\q@u{a}ba bi\q@b{a}l\q@u{h}aqqi liya\q@u{h}kuma bayna a\q@b{l}nn\q@u{a}si feem\q@u{a} ikhtalafoo feehi wam\q@u{a} ikhtalafa feehi ill\q@u{a} alla\q@u{th}eena ootoohu min baAAdi m\q@u{a} j\q@u{a}athumu albayyin\q@u{a}tu baghyan baynahum fahad\q@u{a} All\q@u{a}hu alla\q@u{th}eena \q@u{a}manoo lim\q@u{a} ikhtalafoo feehi mina al\q@u{h}aqqi bii\q@u{th}nihi wa\q@b{A}ll\q@u{a}hu yahdee man yash\q@u{a}o il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(213)}}
\qt@newcmd\qurantrans@lt@ccxxi{Am \q@u{h}asibtum an tadkhuloo aljannata walamm\q@u{a} yatikum mathalu alla\q@u{th}eena khalaw min qablikum massathumu albas\q@u{a}o wa\q@b{al}\q@u{dd}arr\q@u{a}o wazulziloo \q@u{h}att\q@u{a} yaqoola a\q@b{l}rrasoolu wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo maAAahu mat\q@u{a} na\q@u{s}ru All\q@u{a}hi al\q@u{a} inna na\q@u{s}ra All\q@u{a}hi qareeb\q@b{un}\qt@no{(214)}}
\qt@newcmd\qurantrans@lt@ccxxii{Yasaloonaka m\q@u{atha} yunfiqoona qul m\q@u{a} anfaqtum min khayrin falilw\q@u{a}lidayni wa\q@b{a}laqrabeena wa\q@b{a}lyat\q@u{a}m\q@u{a} wa\q@b{a}lmas\q@u{a}keeni wa\q@b{i}bni a\q@b{l}ssabeeli wam\q@u{a} tafAAaloo min khayrin fainna All\q@u{a}ha bihi AAaleem\q@b{un}\qt@no{(215)}}
\qt@newcmd\qurantrans@lt@ccxxiii{Kutiba AAalaykumu alqit\q@u{a}lu wahuwa kurhun lakum waAAas\q@u{a} an takrahoo shayan wahuwa khayrun lakum waAAas\q@u{a} an tu\q@u{h}ibboo shayan wahuwa sharrun lakum wa\q@b{A}ll\q@u{a}hu yaAAlamu waantum l\q@u{a} taAAlamoon\q@b{a}\qt@no{(216)}}
\qt@newcmd\qurantrans@lt@ccxxiv{Yasaloonaka AAani a\q@b{l}shshahri al\q@u{h}ar\q@u{a}mi qit\q@u{a}lin feehi qul qit\q@u{a}lun feehi kabeerun wa\q@u{s}addun AAan sabeeli All\q@u{a}hi wakufrun bihi wa\q@b{a}lmasjidi al\q@u{h}ar\q@u{a}mi waikhr\q@u{a}ju ahlihi minhu akbaru AAinda All\q@u{a}hi wa\q@b{a}lfitnatu akbaru mina alqatli wal\q@u{a} yaz\q@u{a}loona yuq\q@u{a}tiloonakum \q@u{h}att\q@u{a} yaruddookum AAan deenikum ini ista\q@u{ta}AAoo waman yartadid minkum AAan deenihi fayamut wahuwa k\q@u{a}firun faol\q@u{a}ika \q@u{h}abi\q@u{t}at aAAm\q@u{a}luhum fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati waol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(217)}}
\qt@newcmd\qurantrans@lt@ccxxv{Inna alla\q@u{th}eena \q@u{a}manoo wa\q@b{a}lla\q@u{th}eena h\q@u{a}jaroo waj\q@u{a}hadoo fee sabeeli All\q@u{a}hi ol\q@u{a}ika yarjoona ra\q@u{h}mata All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(218)}}
\qt@newcmd\qurantrans@lt@ccxxvi{Yasaloonaka AAani alkhamri wa\q@b{a}lmaysiri qul feehim\q@u{a} ithmun kabeerun waman\q@u{a}fiAAu li\q@b{l}nn\q@u{a}si waithmuhum\q@u{a} akbaru min nafAAihim\q@u{a} wayasaloonaka m\q@u{atha} yunfiqoona quli alAAafwa ka\q@u{tha}lika yubayyinu All\q@u{a}hu lakumu al\q@u{a}y\q@u{a}ti laAAallakum tatafakkaroon\q@b{a}\qt@no{(219)}}
\qt@newcmd\qurantrans@lt@ccxxvii{Fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati wayasaloonaka AAani alyat\q@u{a}m\q@u{a} qul i\q@u{s}l\q@u{ah}un lahum khayrun wain tukh\q@u{a}li\q@u{t}oohum faikhw\q@u{a}nukum wa\q@b{A}ll\q@u{a}hu yaAAlamu almufsida mina almu\q@u{s}li\q@u{h}i walaw sh\q@u{a}a All\q@u{a}hu laaAAnatakum inna All\q@u{a}ha AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(220)}}
\qt@newcmd\qurantrans@lt@ccxxviii{Wal\q@u{a} tanki\q@u{h}oo almushrik\q@u{a}ti \q@u{h}att\q@u{a} yuminna walaamatun muminatun khayrun min mushrikatin walaw aAAjabatkum wal\q@u{a} tunki\q@u{h}oo almushrikeena \q@u{h}att\q@u{a} yuminoo walaAAabdun muminun khayrun min mushrikin walaw aAAjabakum ol\q@u{a}ika yadAAoona il\q@u{a} a\q@b{l}nn\q@u{a}ri wa\q@b{A}ll\q@u{a}hu yadAAoo il\q@u{a} aljannati wa\q@b{a}lmaghfirati bii\q@u{th}nihi wayubayyinu \q@u{a}y\q@u{a}tihi li\q@b{l}nn\q@u{a}si laAAallahum yata\q@u{th}akkaroon\q@b{a}\qt@no{(221)}}
\qt@newcmd\qurantrans@lt@ccxxix{Wayasaloonaka AAani alma\q@u{h}ee\q@u{d}i qul huwa a\q@u{th}an fa\q@b{i}AAtaziloo a\q@b{l}nnis\q@u{a}a fee alma\q@u{h}ee\q@u{d}i wal\q@u{a} taqraboohunna \q@u{h}att\q@u{a} ya\q@u{t}hurna fai\q@u{tha} ta\q@u{t}ahharna fatoohunna min \q@u{h}aythu amarakumu All\q@u{a}hu inna All\q@u{a}ha yu\q@u{h}ibbu a\q@b{l}ttaww\q@u{a}beena wayu\q@u{h}ibbu almuta\q@u{t}ahhireen\q@b{a}\qt@no{(222)}}
\qt@newcmd\qurantrans@lt@ccxxx{Nis\q@u{a}okum \q@u{h}arthun lakum fatoo \q@u{h}arthakum ann\q@u{a} shitum waqaddimoo lianfusikum wa\q@b{i}ttaqoo All\q@u{a}ha wa\q@b{i}AAlamoo annakum mul\q@u{a}qoohu wabashshiri almumineen\q@b{a}\qt@no{(223)}}
\qt@newcmd\qurantrans@lt@ccxxxi{Wal\q@u{a} tajAAaloo All\q@u{a}ha AAur\q@u{d}atan liaym\q@u{a}nikum an tabarroo watattaqoo watu\q@u{s}li\q@u{h}oo bayna a\q@b{l}nn\q@u{a}si wa\q@b{A}ll\q@u{a}hu sameeAAun AAaleem\q@b{un}\qt@no{(224)}}
\qt@newcmd\qurantrans@lt@ccxxxii{L\q@u{a} yu\q@u{a}khi\q@u{th}ukumu All\q@u{a}hu bi\q@b{a}llaghwi fee aym\q@u{a}nikum wal\q@u{a}kin yu\q@u{a}khi\q@u{th}ukum bim\q@u{a} kasabat quloobukum wa\q@b{A}ll\q@u{a}hu ghafoorun \q@u{h}aleem\q@b{un}\qt@no{(225)}}
\qt@newcmd\qurantrans@lt@ccxxxiii{Lilla\q@u{th}eena yuloona min nis\q@u{a}ihim tarabbu\q@u{s}u arbaAAati ashhurin fain f\q@u{a}oo fainna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(226)}}
\qt@newcmd\qurantrans@lt@ccxxxiv{Wain AAazamoo a\q@b{l}\q@u{tt}al\q@u{a}qa fainna All\q@u{a}ha sameeAAun AAaleem\q@b{un}\qt@no{(227)}}
\qt@newcmd\qurantrans@lt@ccxxxv{Wa\q@b{a}lmu\q@u{t}allaq\q@u{a}tu yatarabba\q@u{s}na bianfusihinna thal\q@u{a}thata qurooin wal\q@u{a} ya\q@u{h}illu lahunna an yaktumna m\q@u{a} khalaqa All\q@u{a}hu fee ar\q@u{ha}mihinna in kunna yuminna bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri wabuAAoolatuhunna a\q@u{h}aqqu biraddihinna fee \q@u{tha}lika in ar\q@u{a}doo i\q@u{s}l\q@u{ah}an walahunna mithlu alla\q@u{th}ee AAalayhinna bi\q@b{a}lmaAAroofi wali\q@b{l}rrij\q@u{a}li AAalayhinna darajatun wa\q@b{A}ll\q@u{a}hu AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(228)}}
\qt@newcmd\qurantrans@lt@ccxxxvi{A\q@b{l}\q@u{tt}al\q@u{a}qu marrat\q@u{a}ni faims\q@u{a}kun bimaAAroofin aw tasree\q@u{h}un bii\q@u{h}s\q@u{a}nin wal\q@u{a} ya\q@u{h}illu lakum an takhu\q@u{th}oo mimm\q@u{a} \q@u{a}taytumoohunna shayan ill\q@u{a} an yakh\q@u{a}f\q@u{a} all\q@u{a} yuqeem\q@u{a} \q@u{h}udooda All\q@u{a}hi fain khiftum all\q@u{a} yuqeem\q@u{a} \q@u{h}udooda All\q@u{a}hi fal\q@u{a} jun\q@u{ah}a AAalayhim\q@u{a} feem\q@u{a} iftadat bihi tilka \q@u{h}udoodu All\q@u{a}hi fal\q@u{a} taAAtadooh\q@u{a} waman yataAAadda \q@u{h}udooda All\q@u{a}hi faol\q@u{a}ika humu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(229)}}
\qt@newcmd\qurantrans@lt@ccxxxvii{Fain \q@u{t}allaqah\q@u{a} fal\q@u{a} ta\q@u{h}illu lahu min baAAdu \q@u{h}att\q@u{a} tanki\q@u{h}a zawjan ghayrahu fain \q@u{t}allaqah\q@u{a} fal\q@u{a} jun\q@u{ah}a AAalayhim\q@u{a} an yatar\q@u{a}jaAA\q@u{a} in \q@i{\q@u{th}}ann\q@u{a} an yuqeem\q@u{a} \q@u{h}udooda All\q@u{a}hi watilka \q@u{h}udoodu All\q@u{a}hi yubayyinuh\q@u{a} liqawmin yaAAlamoon\q@b{a}\qt@no{(230)}}
\qt@newcmd\qurantrans@lt@ccxxxviii{Wai\q@u{tha} \q@u{t}allaqtumu a\q@b{l}nnis\q@u{a}a fabalaghna ajalahunna faamsikoohunna bimaAAroofin aw sarri\q@u{h}oohunna bimaAAroofin wal\q@u{a} tumsikoohunna \q@u{d}ir\q@u{a}ran litaAAtadoo waman yafAAal \q@u{tha}lika faqad \q@i{\q@u{th}}alama nafsahu wal\q@u{a} tattakhi\q@u{th}oo \q@u{a}y\q@u{a}ti All\q@u{a}hi huzuwan wa\q@b{o}\q@u{th}kuroo niAAmata All\q@u{a}hi AAalaykum wam\q@u{a} anzala AAalaykum mina alkit\q@u{a}bi wa\q@b{a}l\q@u{h}ikmati yaAAi\q@i{\q@u{th}}ukum bihi wa\q@b{i}ttaqoo All\q@u{a}ha wa\q@b{i}AAlamoo anna All\q@u{a}ha bikulli shayin AAaleem\q@b{un}\qt@no{(231)}}
\qt@newcmd\qurantrans@lt@ccxxxix{Wai\q@u{tha} \q@u{t}allaqtumu a\q@b{l}nnis\q@u{a}a fabalaghna ajalahunna fal\q@u{a} taAA\q@u{d}uloohunna an yanki\q@u{h}na azw\q@u{a}jahunna i\q@u{tha} tar\q@u{ad}aw baynahum bi\q@b{a}lmaAAroofi \q@u{tha}lika yooAAa\q@i{\q@u{th}}u bihi man k\q@u{a}na minkum yuminu bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri \q@u{tha}likum azk\q@u{a} lakum waa\q@u{t}haru wa\q@b{A}ll\q@u{a}hu yaAAlamu waantum l\q@u{a} taAAlamoon\q@b{a}\qt@no{(232)}}
\qt@newcmd\qurantrans@lt@ccxl{Wa\q@b{a}lw\q@u{a}lid\q@u{a}tu yur\q@u{d}iAAna awl\q@u{a}dahunna \q@u{h}awlayni k\q@u{a}milayni liman ar\q@u{a}da an yutimma a\q@b{l}rra\q@u{da}AAata waAAal\q@u{a} almawloodi lahu rizquhunna wakiswatuhunna bi\q@b{a}lmaAAroofi l\q@u{a} tukallafu nafsun ill\q@u{a} wusAAah\q@u{a} l\q@u{a} tu\q@u{da}rra w\q@u{a}lidatun biwaladih\q@u{a} wal\q@u{a} mawloodun lahu biwaladihi waAAal\q@u{a} alw\q@u{a}rithi mithlu \q@u{tha}lika fain ar\q@u{a}d\q@u{a} fi\q@u{sa}lan AAan tar\q@u{ad}in minhum\q@u{a} watash\q@u{a}wurin fal\q@u{a} jun\q@u{ah}a AAalayhim\q@u{a} wain aradtum an tastar\q@u{d}iAAoo awl\q@u{a}dakum fal\q@u{a} jun\q@u{ah}a AAalaykum i\q@u{tha} sallamtum m\q@u{a} \q@u{a}taytum bi\q@b{a}lmaAAroofi wa\q@b{i}ttaqoo All\q@u{a}ha wa\q@b{i}AAlamoo anna All\q@u{a}ha bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(233)}}
\qt@newcmd\qurantrans@lt@ccxli{Wa\q@b{a}lla\q@u{th}eena yutawaffawna minkum waya\q@u{th}aroona azw\q@u{a}jan yatarabba\q@u{s}na bianfusihinna arbaAAata ashhurin waAAashran fai\q@u{tha} balaghna ajalahunna fal\q@u{a} jun\q@u{ah}a AAalaykum feem\q@u{a} faAAalna fee anfusihinna bi\q@b{a}lmaAAroofi wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona khabeer\q@b{un}\qt@no{(234)}}
\qt@newcmd\qurantrans@lt@ccxlii{Wal\q@u{a} jun\q@u{ah}a AAalaykum feem\q@u{a} AAarra\q@u{d}tum bihi min khi\q@u{t}bati a\q@b{l}nnis\q@u{a}i aw aknantum fee anfusikum AAalima All\q@u{a}hu annakum sata\q@u{th}kuroonahunna wal\q@u{a}kin l\q@u{a} tuw\q@u{a}AAidoohunna sirran ill\q@u{a} an taqooloo qawlan maAAroofan wal\q@u{a} taAAzimoo AAuqdata a\q@b{l}nnik\q@u{ah}i \q@u{h}att\q@u{a} yablugha alkit\q@u{a}bu ajalahu wa\q@b{i}AAlamoo anna All\q@u{a}ha yaAAlamu m\q@u{a} fee anfusikum fa\q@b{i}\q@u{hth}aroohu wa\q@b{i}AAlamoo anna All\q@u{a}ha ghafoorun \q@u{h}aleem\q@b{un}\qt@no{(235)}}
\qt@newcmd\qurantrans@lt@ccxliii{L\q@u{a} jun\q@u{ah}a AAalaykum in \q@u{t}allaqtumu a\q@b{l}nnis\q@u{a}a m\q@u{a} lam tamassoohunna aw tafri\q@u{d}oo lahunna faree\q@u{d}atan wamattiAAoohunna AAal\q@u{a} almoosiAAi qadaruhu waAAal\q@u{a} almuqtiri qadaruhu mat\q@u{a}AAan bi\q@b{a}lmaAAroofi \q@u{h}aqqan AAal\q@u{a} almu\q@u{h}sineen\q@b{a}\qt@no{(236)}}
\qt@newcmd\qurantrans@lt@ccxliv{Wain \q@u{t}allaqtumoohunna min qabli an tamassoohunna waqad fara\q@u{d}tum lahunna faree\q@u{d}atan fani\q@u{s}fu m\q@u{a} fara\q@u{d}tum ill\q@u{a} an yaAAfoona aw yaAAfuwa alla\q@u{th}ee biyadihi AAuqdatu a\q@b{l}nnik\q@u{ah}i waan taAAfoo aqrabu li\q@b{l}ttaqw\q@u{a} wal\q@u{a} tansawoo alfa\q@u{d}la baynakum inna All\q@u{a}ha bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(237)}}
\qt@newcmd\qurantrans@lt@ccxlv{\q@u{Ha}fi\q@i{\q@u{th}}oo AAal\q@u{a} a\q@b{l}\q@u{ss}alaw\q@u{a}ti wa\q@b{al}\q@u{ss}al\q@u{a}ti alwus\q@u{ta} waqoomoo lill\q@u{a}hi q\q@u{a}niteen\q@b{a}\qt@no{(238)}}
\qt@newcmd\qurantrans@lt@ccxlvi{Fain khiftum farij\q@u{a}lan aw rukb\q@u{a}nan fai\q@u{tha} amintum fa\q@b{o}\q@u{th}kuroo All\q@u{a}ha kam\q@u{a} AAallamakum m\q@u{a} lam takoonoo taAAlamoon\q@b{a}\qt@no{(239)}}
\qt@newcmd\qurantrans@lt@ccxlvii{Wa\q@b{a}lla\q@u{th}eena yutawaffawna minkum waya\q@u{th}aroona azw\q@u{a}jan wa\q@u{s}iyyatan liazw\q@u{a}jihim mat\q@u{a}AAan il\q@u{a} al\q@u{h}awli ghayra ikhr\q@u{a}jin fain kharajna fal\q@u{a} jun\q@u{ah}a AAalaykum fee m\q@u{a} faAAalna fee anfusihinna min maAAroofin wa\q@b{A}ll\q@u{a}hu AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(240)}}
\qt@newcmd\qurantrans@lt@ccxlviii{Walilmu\q@u{t}allaq\q@u{a}ti mat\q@u{a}AAun bi\q@b{a}lmaAAroofi \q@u{h}aqqan AAal\q@u{a} almuttaqeen\q@b{a}\qt@no{(241)}}
\qt@newcmd\qurantrans@lt@ccxlix{Ka\q@u{tha}lika yubayyinu All\q@u{a}hu lakum \q@u{a}y\q@u{a}tihi laAAallakum taAAqiloon\q@b{a}\qt@no{(242)}}
\qt@newcmd\qurantrans@lt@ccl{Alam tara il\q@u{a} alla\q@u{th}eena kharajoo min diy\q@u{a}rihim wahum oloofun \q@u{h}a\q@u{th}ara almawti faq\q@u{a}la lahumu All\q@u{a}hu mootoo thumma a\q@u{h}y\q@u{a}hum inna All\q@u{a}ha la\q@u{th}oo fa\q@u{d}lin AAal\q@u{a} a\q@b{l}nn\q@u{a}si wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yashkuroon\q@b{a}\qt@no{(243)}}
\qt@newcmd\qurantrans@lt@ccli{Waq\q@u{a}tiloo fee sabeeli All\q@u{a}hi wa\q@b{i}AAlamoo anna All\q@u{a}ha sameeAAun AAaleem\q@b{un}\qt@no{(244)}}
\qt@newcmd\qurantrans@lt@cclii{Man \q@u{tha} alla\q@u{th}ee yuqri\q@u{d}u All\q@u{a}ha qar\q@u{d}an \q@u{h}asanan fayu\q@u{da}AAifahu lahu a\q@u{d}AA\q@u{a}fan katheeratan wa\q@b{A}ll\q@u{a}hu yaqbi\q@u{d}u wayabsu\q@u{t}u wailayhi turjaAAoon\q@b{a}\qt@no{(245)}}
\qt@newcmd\qurantrans@lt@ccliii{Alam tara il\q@u{a} almalai min banee isr\q@u{a}eela min baAAdi moos\q@u{a} i\q@u{th} q\q@u{a}loo linabiyyin lahumu ibAAath lan\q@u{a} malikan nuq\q@u{a}til fee sabeeli All\q@u{a}hi q\q@u{a}la hal AAasaytum in kutiba AAalaykumu alqit\q@u{a}lu all\q@u{a} tuq\q@u{a}tiloo q\q@u{a}loo wam\q@u{a} lan\q@u{a} all\q@u{a} nuq\q@u{a}tila fee sabeeli All\q@u{a}hi waqad okhrijn\q@u{a} min diy\q@u{a}rin\q@u{a} waabn\q@u{a}in\q@u{a} falamm\q@u{a} kutiba AAalayhimu alqit\q@u{a}lu tawallaw ill\q@u{a} qaleelan minhum wa\q@b{A}ll\q@u{a}hu AAaleemun bi\q@b{al}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(246)}}
\qt@newcmd\qurantrans@lt@ccliv{Waq\q@u{a}la lahum nabiyyuhum inna All\q@u{a}ha qad baAAatha lakum \q@u{ta}loota malikan q\q@u{a}loo ann\q@u{a} yakoonu lahu almulku AAalayn\q@u{a} wana\q@u{h}nu a\q@u{h}aqqu bi\q@b{a}lmulki minhu walam yuta saAAatan mina alm\q@u{a}li q\q@u{a}la inna All\q@u{a}ha i\q@u{st}af\q@u{a}hu AAalaykum waz\q@u{a}dahu bas\q@u{t}atan fee alAAilmi wa\q@b{a}ljismi wa\q@b{A}ll\q@u{a}hu yutee mulkahu man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu w\q@u{a}siAAun AAaleem\q@b{un}\qt@no{(247)}}
\qt@newcmd\qurantrans@lt@cclv{Waq\q@u{a}la lahum nabiyyuhum inna \q@u{a}yata mulkihi an yatiyakumu a\q@b{l}tt\q@u{a}bootu feehi sakeenatun min rabbikum wabaqiyyatun mimm\q@u{a} taraka \q@u{a}lu moos\q@u{a} wa\q@u{a}lu h\q@u{a}roona ta\q@u{h}miluhu almal\q@u{a}ikatu inna fee \q@u{tha}lika la\q@u{a}yatan lakum in kuntum mumineen\q@b{a}\qt@no{(248)}}
\qt@newcmd\qurantrans@lt@cclvi{Falamm\q@u{a} fa\q@u{s}ala \q@u{ta}lootu bi\q@b{a}ljunoodi q\q@u{a}la inna All\q@u{a}ha mubtaleekum binaharin faman shariba minhu falaysa minnee waman lam ya\q@u{t}AAamhu fainnahu minnee ill\q@u{a} mani ightarafa ghurfatan biyadihi fashariboo minhu ill\q@u{a} qaleelan minhum falamm\q@u{a} j\q@u{a}wazahu huwa wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo maAAahu q\q@u{a}loo l\q@u{a} \q@u{ta}qata lan\q@u{a} alyawma bij\q@u{a}loota wajunoodihi q\q@u{a}la alla\q@u{th}eena ya\q@i{\q@u{th}}unnoona annahum mul\q@u{a}qoo All\q@u{a}hi kam min fiatin qaleelatin ghalabat fiatan katheeratan bii\q@u{th}ni All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu maAAa a\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(249)}}
\qt@newcmd\qurantrans@lt@cclvii{Walamm\q@u{a} barazoo lij\q@u{a}loota wajunoodihi q\q@u{a}loo rabban\q@u{a} afrigh AAalayn\q@u{a} \q@u{s}abran wathabbit aqd\q@u{a}man\q@u{a} wa\q@b{o}n\q@u{s}urn\q@u{a} AAal\q@u{a} alqawmi alk\q@u{a}fireen\q@b{a}\qt@no{(250)}}
\qt@newcmd\qurantrans@lt@cclviii{Fahazamoohum bii\q@u{th}ni All\q@u{a}hi waqatala d\q@u{a}woodu j\q@u{a}loota wa\q@u{a}t\q@u{a}hu All\q@u{a}hu almulka wa\q@b{a}l\q@u{h}ikmata waAAallamahu mimm\q@u{a} yash\q@u{a}o walawl\q@u{a} dafAAu All\q@u{a}hi a\q@b{l}nn\q@u{a}sa baAA\q@u{d}ahum bibaAA\q@u{d}in lafasadati alar\q@u{d}u wal\q@u{a}kinna All\q@u{a}ha \q@u{th}oo fa\q@u{d}lin AAal\q@u{a} alAA\q@u{a}lameen\q@b{a}\qt@no{(251)}}
\qt@newcmd\qurantrans@lt@cclix{Tilka \q@u{a}y\q@u{a}tu All\q@u{a}hi natlooh\q@u{a} AAalayka bi\q@b{a}l\q@u{h}aqqi wainnaka lamina almursaleen\q@b{a}\qt@no{(252)}}
\qt@newcmd\qurantrans@lt@cclx{Tilka a\q@b{l}rrusulu fa\q@u{dd}aln\q@u{a} baAA\q@u{d}ahum AAal\q@u{a} baAA\q@u{d}in minhum man kallama All\q@u{a}hu warafaAAa baAA\q@u{d}ahum daraj\q@u{a}tin wa\q@u{a}tayn\q@u{a} AAees\q@u{a} ibna maryama albayyin\q@u{a}ti waayyadn\q@u{a}hu biroo\q@u{h}i alqudusi walaw sh\q@u{a}a All\q@u{a}hu m\q@u{a} iqtatala alla\q@u{th}eena min baAAdihim min baAAdi m\q@u{a} j\q@u{a}athumu albayyin\q@u{a}tu wal\q@u{a}kini ikhtalafoo faminhum man \q@u{a}mana waminhum man kafara walaw sh\q@u{a}a All\q@u{a}hu m\q@u{a} iqtataloo wal\q@u{a}kinna All\q@u{a}ha yafAAalu m\q@u{a} yureed\q@b{u}\qt@no{(253)}}
\qt@newcmd\qurantrans@lt@cclxi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo anfiqoo mimm\q@u{a} razaqn\q@u{a}kum min qabli an yatiya yawmun l\q@u{a} bayAAun feehi wal\q@u{a} khullatun wal\q@u{a} shaf\q@u{a}AAatun wa\q@b{a}lk\q@u{a}firoona humu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(254)}}
\qt@newcmd\qurantrans@lt@cclxii{All\q@u{a}hu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa al\q@u{h}ayyu alqayyoomu l\q@u{a} takhu\q@u{th}uhu sinatun wal\q@u{a} nawmun lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i man \q@u{tha} alla\q@u{th}ee yashfaAAu AAindahu ill\q@u{a} bii\q@u{th}nihi yaAAlamu m\q@u{a} bayna aydeehim wam\q@u{a} khalfahum wal\q@u{a} yu\q@u{h}ee\q@u{t}oona bishayin min AAilmihi ill\q@u{a} bim\q@u{a} sh\q@u{a}a wasiAAa kursiyyuhu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wal\q@u{a} yaooduhu \q@u{h}if\q@i{\q@u{th}}uhum\q@u{a} wahuwa alAAaliyyu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(255)}}
\qt@newcmd\qurantrans@lt@cclxiii{L\q@u{a} ikr\q@u{a}ha fee a\q@b{l}ddeeni qad tabayyana a\q@b{l}rrushdu mina alghayyi faman yakfur bi\q@b{al}\q@u{tta}ghooti wayumin bi\q@b{A}ll\q@u{a}hi faqadi istamsaka bi\q@b{a}lAAurwati alwuthq\q@u{a} l\q@u{a} infi\q@u{sa}ma lah\q@u{a} wa\q@b{A}ll\q@u{a}hu sameeAAun AAaleem\q@b{un}\qt@no{(256)}}
\qt@newcmd\qurantrans@lt@cclxiv{All\q@u{a}hu waliyyu alla\q@u{th}eena \q@u{a}manoo yukhrijuhum mina a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti il\q@u{a} a\q@b{l}nnoori wa\q@b{a}lla\q@u{th}eena kafaroo awliy\q@u{a}ohumu a\q@b{l}\q@u{tta}ghootu yukhrijoonahum mina a\q@b{l}nnoori il\q@u{a} a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti ol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(257)}}
\qt@newcmd\qurantrans@lt@cclxv{Alam tara il\q@u{a} alla\q@u{th}ee \q@u{ha}jja ibr\q@u{a}heema fee rabbihi an \q@u{a}t\q@u{a}hu All\q@u{a}hu almulka i\q@u{th} q\q@u{a}la ibr\q@u{a}heemu rabbiya alla\q@u{th}ee yu\q@u{h}yee wayumeetu q\q@u{a}la an\q@u{a} o\q@u{h}yee waomeetu q\q@u{a}la ibr\q@u{a}heemu fainna All\q@u{a}ha yatee bi\q@b{al}shshamsi mina almashriqi fati bih\q@u{a} mina almaghribi fabuhita alla\q@u{th}ee kafara wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(258)}}
\qt@newcmd\qurantrans@lt@cclxvi{Aw ka\q@b{a}lla\q@u{th}ee marra AAal\q@u{a} qaryatin wahiya kh\q@u{a}wiyatun AAal\q@u{a} AAurooshih\q@u{a} q\q@u{a}la ann\q@u{a} yu\q@u{h}yee h\q@u{ath}ihi All\q@u{a}hu baAAda mawtih\q@u{a} faam\q@u{a}tahu All\q@u{a}hu miata AA\q@u{a}min thumma baAAathahu q\q@u{a}la kam labithta q\q@u{a}la labithtu yawman aw baAA\q@u{d}a yawmin q\q@u{a}la bal labithta miata AA\q@u{a}min fa\q@b{o}n\q@i{\q@u{th}}ur il\q@u{a} \q@u{t}aAA\q@u{a}mika washar\q@u{a}bika lam yatasannah wa\q@b{o}n\q@i{\q@u{th}}ur il\q@u{a} \q@u{h}im\q@u{a}rika walinajAAalaka \q@u{a}yatan li\q@b{l}nn\q@u{a}si wa\q@b{o}n\q@i{\q@u{th}}ur il\q@u{a} alAAi\q@i{\q@u{th}}\q@u{a}mi kayfa nunshizuh\q@u{a} thumma naksooh\q@u{a} la\q@u{h}man falamm\q@u{a} tabayyana lahu q\q@u{a}la aAAlamu anna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(259)}}
\qt@newcmd\qurantrans@lt@cclxvii{Wai\q@u{th} q\q@u{a}la ibr\q@u{a}heemu rabbi arinee kayfa tu\q@u{h}yee almawt\q@u{a} q\q@u{a}la awalam tumin q\q@u{a}la bal\q@u{a} wal\q@u{a}kin liya\q@u{t}mainna qalbee q\q@u{a}la fakhu\q@u{th} arbaAAatan mina a\q@b{l}\q@u{tt}ayri fa\q@u{s}urhunna ilayka thumma ijAAal AAal\q@u{a} kulli jabalin minhunna juzan thumma odAAuhunna yateenaka saAAyan wa\q@b{i}AAlam anna All\q@u{a}ha AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(260)}}
\qt@newcmd\qurantrans@lt@cclxviii{Mathalu alla\q@u{th}eena yunfiqoona amw\q@u{a}lahum fee sabeeli All\q@u{a}hi kamathali \q@u{h}abbatin anbatat sabAAa san\q@u{a}bila fee kulli sunbulatin miatu \q@u{h}abbatin wa\q@b{A}ll\q@u{a}hu yu\q@u{da}AAifu liman yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu w\q@u{a}siAAun AAaleem\q@b{un}\qt@no{(261)}}
\qt@newcmd\qurantrans@lt@cclxix{Alla\q@u{th}eena yunfiqoona amw\q@u{a}lahum fee sabeeli All\q@u{a}hi thumma l\q@u{a} yutbiAAoona m\q@u{a} anfaqoo mannan wal\q@u{a} a\q@u{th}an lahum ajruhum AAinda rabbihim wal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(262)}}
\qt@newcmd\qurantrans@lt@cclxx{Qawlun maAAroofun wamaghfiratun khayrun min \q@u{s}adaqatin yatbaAAuh\q@u{a} a\q@u{th}an wa\q@b{A}ll\q@u{a}hu ghaniyyun \q@u{h}aleem\q@b{un}\qt@no{(263)}}
\qt@newcmd\qurantrans@lt@cclxxi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tub\q@u{t}iloo \q@u{s}adaq\q@u{a}tikum bi\q@b{a}lmanni wa\q@b{a}la\q@u{tha} ka\q@b{a}lla\q@u{th}ee yunfiqu m\q@u{a}lahu ri\q@u{a}a a\q@b{l}nn\q@u{a}si wal\q@u{a} yuminu bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri famathaluhu kamathali \q@u{s}afw\q@u{a}nin AAalayhi tur\q@u{a}bun faa\q@u{sa}bahu w\q@u{a}bilun fatarakahu \q@u{s}aldan l\q@u{a} yaqdiroona AAal\q@u{a} shayin mimm\q@u{a} kasaboo wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma alk\q@u{a}fireen\q@b{a}\qt@no{(264)}}
\qt@newcmd\qurantrans@lt@cclxxii{Wamathalu alla\q@u{th}eena yunfiqoona amw\q@u{a}lahumu ibtigh\q@u{a}a mar\q@u{da}ti All\q@u{a}hi watathbeetan min anfusihim kamathali jannatin birabwatin a\q@u{sa}bah\q@u{a} w\q@u{a}bilun fa\q@u{a}tat okulah\q@u{a} \q@u{d}iAAfayni fain lam yu\q@u{s}ibh\q@u{a} w\q@u{a}bilun fa\q@u{t}allun wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(265)}}
\qt@newcmd\qurantrans@lt@cclxxiii{Ayawaddu a\q@u{h}adukum an takoona lahu jannatun min nakheelin waaAAn\q@u{a}bin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru lahu feeh\q@u{a} min kulli a\q@b{l}ththamar\q@u{a}ti waa\q@u{sa}bahu alkibaru walahu \q@u{th}urriyyatun \q@u{d}uAAaf\q@u{a}o faa\q@u{sa}bah\q@u{a} iAA\q@u{sa}run feehi n\q@u{a}run fa\q@b{i}\q@u{h}taraqat ka\q@u{tha}lika yubayyinu All\q@u{a}hu lakumu al\q@u{a}y\q@u{a}ti laAAallakum tatafakkaroon\q@b{a}\qt@no{(266)}}
\qt@newcmd\qurantrans@lt@cclxxiv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo anfiqoo min \q@u{t}ayyib\q@u{a}ti m\q@u{a} kasabtum wamimm\q@u{a} akhrajn\q@u{a} lakum mina alar\q@u{d}i wal\q@u{a} tayammamoo alkhabeetha minhu tunfiqoona walastum bi\q@u{a}khi\q@u{th}eehi ill\q@u{a} an tughmi\q@u{d}oo feehi wa\q@b{i}AAlamoo anna All\q@u{a}ha ghaniyyun \q@u{h}ameed\q@b{un}\qt@no{(267)}}
\qt@newcmd\qurantrans@lt@cclxxv{A\q@b{l}shshay\q@u{ta}nu yaAAidukumu alfaqra wayamurukum bi\q@b{a}lfa\q@u{h}sh\q@u{a}i wa\q@b{A}ll\q@u{a}hu yaAAidukum maghfiratan minhu wafa\q@u{d}lan wa\q@b{A}ll\q@u{a}hu w\q@u{a}siAAun AAaleem\q@b{un}\qt@no{(268)}}
\qt@newcmd\qurantrans@lt@cclxxvi{Yutee al\q@u{h}ikmata man yash\q@u{a}o waman yuta al\q@u{h}ikmata faqad ootiya khayran katheeran wam\q@u{a} ya\q@u{thth}akkaru ill\q@u{a} oloo alalb\q@u{a}b\q@b{i}\qt@no{(269)}}
\qt@newcmd\qurantrans@lt@cclxxvii{Wam\q@u{a} anfaqtum min nafaqatin aw na\q@u{th}artum min na\q@u{th}rin fainna All\q@u{a}ha yaAAlamuhu wam\q@u{a} li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena min an\q@u{sa}r\q@b{in}\qt@no{(270)}}
\qt@newcmd\qurantrans@lt@cclxxviii{In tubdoo a\q@b{l}\q@u{ss}adaq\q@u{a}ti faniAAimm\q@u{a} hiya wain tukhfooh\q@u{a} watutooh\q@u{a} alfuqar\q@u{a}a fahuwa khayrun lakum wayukaffiru AAankum min sayyi\q@u{a}tikum wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona khabeer\q@b{un}\qt@no{(271)}}
\qt@newcmd\qurantrans@lt@cclxxix{Laysa AAalayka hud\q@u{a}hum wal\q@u{a}kinna All\q@u{a}ha yahdee man yash\q@u{a}o wam\q@u{a} tunfiqoo min khayrin falianfusikum wam\q@u{a} tunfiqoona ill\q@u{a} ibtigh\q@u{a}a wajhi All\q@u{a}hi wam\q@u{a} tunfiqoo min khayrin yuwaffa ilaykum waantum l\q@u{a} tu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(272)}}
\qt@newcmd\qurantrans@lt@cclxxx{Lilfuqar\q@u{a}i alla\q@u{th}eena o\q@u{hs}iroo fee sabeeli All\q@u{a}hi l\q@u{a} yasta\q@u{t}eeAAoona \q@u{d}arban fee alar\q@u{d}i ya\q@u{h}sabuhumu alj\q@u{a}hilu aghniy\q@u{a}a mina a\q@b{l}ttaAAaffufi taAArifuhum biseem\q@u{a}hum l\q@u{a} yasaloona a\q@b{l}nn\q@u{a}sa il\q@u{ha}fan wam\q@u{a} tunfiqoo min khayrin fainna All\q@u{a}ha bihi AAaleem\q@b{un}\qt@no{(273)}}
\qt@newcmd\qurantrans@lt@cclxxxi{Alla\q@u{th}eena yunfiqoona amw\q@u{a}lahum bi\q@b{a}llayli wa\q@b{al}nnah\q@u{a}ri sirran waAAal\q@u{a}niyatan falahum ajruhum AAinda rabbihim wal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(274)}}
\qt@newcmd\qurantrans@lt@cclxxxii{Alla\q@u{th}eena yakuloona a\q@b{l}rrib\q@u{a} l\q@u{a} yaqoomoona ill\q@u{a} kam\q@u{a} yaqoomu alla\q@u{th}ee yatakhabba\q@u{t}uhu a\q@b{l}shshay\q@u{ta}nu mina almassi \q@u{tha}lika biannahum q\q@u{a}loo innam\q@u{a} albayAAu mithlu a\q@b{l}rrib\q@u{a} waa\q@u{h}alla All\q@u{a}hu albayAAa wa\q@u{h}arrama a\q@b{l}rrib\q@u{a} faman j\q@u{a}ahu mawAAi\q@i{\q@u{th}}atun min rabbihi fa\q@b{i}ntah\q@u{a} falahu m\q@u{a} salafa waamruhu il\q@u{a} All\q@u{a}hi waman AA\q@u{a}da faol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(275)}}
\qt@newcmd\qurantrans@lt@cclxxxiii{Yam\q@u{h}aqu All\q@u{a}hu a\q@b{l}rrib\q@u{a} wayurbee a\q@b{l}\q@u{ss}adaq\q@u{a}ti wa\q@b{A}ll\q@u{a}hu l\q@u{a} yu\q@u{h}ibbu kulla kaff\q@u{a}rin atheem\q@b{in}\qt@no{(276)}}
\qt@newcmd\qurantrans@lt@cclxxxiv{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti waaq\q@u{a}moo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}tawoo a\q@b{l}zzak\q@u{a}ta lahum ajruhum AAinda rabbihim wal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(277)}}
\qt@newcmd\qurantrans@lt@cclxxxv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo ittaqoo All\q@u{a}ha wa\q@u{th}aroo m\q@u{a} baqiya mina a\q@b{l}rrib\q@u{a} in kuntum mumineen\q@b{a}\qt@no{(278)}}
\qt@newcmd\qurantrans@lt@cclxxxvi{Fain lam tafAAaloo fa\q@u{th}anoo bi\q@u{h}arbin mina All\q@u{a}hi warasoolihi wain tubtum falakum ruoosu amw\q@u{a}likum l\q@u{a} ta\q@i{\q@u{th}}limoona wal\q@u{a} tu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(279)}}
\qt@newcmd\qurantrans@lt@cclxxxvii{Wain k\q@u{a}na \q@u{th}oo AAusratin fana\q@i{\q@u{th}}iratun il\q@u{a} maysaratin waan ta\q@u{s}addaqoo khayrun lakum in kuntum taAAlamoon\q@b{a}\qt@no{(280)}}
\qt@newcmd\qurantrans@lt@cclxxxviii{Wa\q@b{i}ttaqoo yawman turjaAAoona feehi il\q@u{a} All\q@u{a}hi thumma tuwaff\q@u{a} kullu nafsin m\q@u{a} kasabat wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(281)}}
\qt@newcmd\qurantrans@lt@cclxxxix{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} tad\q@u{a}yantum bidaynin il\q@u{a} ajalin musamman fa\q@b{o}ktuboohu walyaktub baynakum k\q@u{a}tibun bi\q@b{a}lAAadli wal\q@u{a} yaba k\q@u{a}tibun an yaktuba kam\q@u{a} AAallamahu All\q@u{a}hu falyaktub walyumlili alla\q@u{th}ee AAalayhi al\q@u{h}aqqu walyattaqi All\q@u{a}ha rabbahu wal\q@u{a} yabkhas minhu shayan fain k\q@u{a}na alla\q@u{th}ee AAalayhi al\q@u{h}aqqu safeehan aw \q@u{d}aAAeefan aw l\q@u{a} yasta\q@u{t}eeAAu an yumilla huwa falyumlil waliyyuhu bi\q@b{a}lAAadli wa\q@b{i}stashhidoo shaheedayni min rij\q@u{a}likum fain lam yakoon\q@u{a} rajulayni farajulun wa\q@b{i}mraat\q@u{a}ni mimman tar\q@u{d}awna mina a\q@b{l}shshuhad\q@u{a}i an ta\q@u{d}illa i\q@u{h}d\q@u{a}hum\q@u{a} fatu\q@u{th}akkira i\q@u{h}d\q@u{a}hum\q@u{a} alokhr\q@u{a} wal\q@u{a} yaba a\q@b{l}shshuhad\q@u{a}o i\q@u{tha} m\q@u{a} duAAoo wal\q@u{a} tasamoo an taktuboohu \q@u{s}agheeran aw kabeeran il\q@u{a} ajalihi \q@u{tha}likum aqsa\q@u{t}u AAinda All\q@u{a}hi waaqwamu li\q@b{l}shshah\q@u{a}dati waadn\q@u{a} all\q@u{a} tart\q@u{a}boo ill\q@u{a} an takoona tij\q@u{a}ratan \q@u{had}iratan tudeeroonah\q@u{a} baynakum falaysa AAalaykum jun\q@u{ah}un all\q@u{a} taktubooh\q@u{a} waashhidoo i\q@u{tha} tab\q@u{a}yaAAtum wal\q@u{a} yu\q@u{da}rra k\q@u{a}tibun wal\q@u{a} shaheedun wain tafAAaloo fainnahu fusooqun bikum wa\q@b{i}ttaqoo All\q@u{a}ha wayuAAallimukumu All\q@u{a}hu wa\q@b{A}ll\q@u{a}hu bikulli shayin AAaleem\q@b{un}\qt@no{(282)}}
\qt@newcmd\qurantrans@lt@ccxc{Wain kuntum AAal\q@u{a} safarin walam tajidoo k\q@u{a}tiban farih\q@u{a}nun maqboo\q@u{d}atun fain amina baAA\q@u{d}ukum baAA\q@u{d}an falyuaddi alla\q@u{th}ee\q@u{ }itumina am\q@u{a}natahu walyattaqi All\q@u{a}ha rabbahu wal\q@u{a} taktumoo a\q@b{l}shshah\q@u{a}data waman yaktumh\q@u{a} fainnahu \q@u{a}thimun qalbuhu wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona AAaleem\q@b{un}\qt@no{(283)}}
\qt@newcmd\qurantrans@lt@ccxci{Lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wain tubdoo m\q@u{a} fee anfusikum aw tukhfoohu yu\q@u{ha}sibkum bihi All\q@u{a}hu fayaghfiru liman yash\q@u{a}o wayuAAa\q@u{thth}ibu man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(284)}}
\qt@newcmd\qurantrans@lt@ccxcii{\q@u{A}mana a\q@b{l}rrasoolu bim\q@u{a} onzila ilayhi min rabbihi wa\q@b{a}lmuminoona kullun \q@u{a}mana bi\q@b{A}ll\q@u{a}hi wamal\q@u{a}ikatihi wakutubihi warusulihi l\q@u{a} nufarriqu bayna a\q@u{h}adin min rusulihi waq\q@u{a}loo samiAAn\q@u{a} waa\q@u{t}aAAn\q@u{a} ghufr\q@u{a}naka rabban\q@u{a} wailayka alma\q@u{s}eer\q@b{u}\qt@no{(285)}}
\qt@newcmd\qurantrans@lt@ccxciii{L\q@u{a} yukallifu All\q@u{a}hu nafsan ill\q@u{a} wusAAah\q@u{a} lah\q@u{a} m\q@u{a} kasabat waAAalayh\q@u{a} m\q@u{a} iktasabat rabban\q@u{a} l\q@u{a} tu\q@u{a}khi\q@u{th}n\q@u{a} in naseen\q@u{a} aw akh\q@u{t}an\q@u{a} rabban\q@u{a} wal\q@u{a} ta\q@u{h}mil AAalayn\q@u{a} i\q@u{s}ran kam\q@u{a} \q@u{h}amaltahu AAal\q@u{a} alla\q@u{th}eena min qablin\q@u{a} rabban\q@u{a} wal\q@u{a} tu\q@u{h}ammiln\q@u{a} m\q@u{a} l\q@u{a} \q@u{ta}qata lan\q@u{a} bihi wa\q@b{o}AAfu AAann\q@u{a} wa\q@b{i}ghfir lan\q@u{a} wa\q@b{i}r\q@u{h}amn\q@u{a} anta mawl\q@u{a}n\q@u{a} fa\q@b{o}n\q@u{s}urn\q@u{a} AAal\q@u{a} alqawmi alk\q@u{a}fireen\q@b{a}\qt@no{(286)}}
\qt@newcmd\qurantrans@lt@ccxciv{\basmalahlt Alifl\q@u{a}mmeem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@ccxcv{All\q@u{a}hu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa al\q@u{h}ayyu alqayyoom\q@b{u}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@ccxcvi{Nazzala AAalayka alkit\q@u{a}ba bi\q@b{a}l\q@u{h}aqqi mu\q@u{s}addiqan lim\q@u{a} bayna yadayhi waanzala a\q@b{l}ttawr\q@u{a}ta wa\q@b{a}linjeel\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@ccxcvii{Min qablu hudan li\q@b{l}nn\q@u{a}si waanzala alfurq\q@u{a}na inna alla\q@u{th}eena kafaroo bi\q@u{a}y\q@u{a}ti All\q@u{a}hi lahum AAa\q@u{tha}bun shadeedun wa\q@b{A}ll\q@u{a}hu AAazeezun \q@u{th}oo intiq\q@u{a}m\q@b{in}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@ccxcviii{Inna All\q@u{a}ha l\q@u{a} yakhf\q@u{a} AAalayhi shayon fee alar\q@u{d}i wal\q@u{a} fee a\q@b{l}ssam\q@u{a}\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@ccxcix{Huwa alla\q@u{th}ee yu\q@u{s}awwirukum fee alar\q@u{ha}mi kayfa yash\q@u{a}o l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@ccc{Huwa alla\q@u{th}ee anzala AAalayka alkit\q@u{a}ba minhu \q@u{a}y\q@u{a}tun mu\q@u{h}kam\q@u{a}tun hunna ommu alkit\q@u{a}bi waokharu mutash\q@u{a}bih\q@u{a}tun faamm\q@u{a} alla\q@u{th}eena fee quloobihim zayghun fayattabiAAoona m\q@u{a} tash\q@u{a}baha minhu ibtigh\q@u{a}a alfitnati wa\q@b{i}btigh\q@u{a}a taweelihi wam\q@u{a} yaAAlamu taweelahu ill\q@u{a} All\q@u{a}hu wa\q@b{al}rr\q@u{a}sikhoona fee alAAilmi yaqooloona \q@u{a}mann\q@u{a} bihi kullun min AAindi rabbin\q@u{a} wam\q@u{a} ya\q@u{thth}akkaru ill\q@u{a} oloo alalb\q@u{a}b\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@ccci{Rabban\q@u{a} l\q@u{a} tuzigh qulooban\q@u{a} baAAda i\q@u{th} hadaytan\q@u{a} wahab lan\q@u{a} min ladunka ra\q@u{h}matan innaka anta alwahh\q@u{a}b\q@b{u}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@cccii{Rabban\q@u{a} innaka j\q@u{a}miAAu a\q@b{l}nn\q@u{a}si liyawmin l\q@u{a} rayba feehi inna All\q@u{a}ha l\q@u{a} yukhlifu almeeAA\q@u{a}d\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@ccciii{Inna alla\q@u{th}eena kafaroo lan tughniya AAanhum amw\q@u{a}luhum wal\q@u{a} awl\q@u{a}duhum mina All\q@u{a}hi shayan waol\q@u{a}ika hum waqoodu a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@ccciv{Kadabi \q@u{a}li firAAawna wa\q@b{a}lla\q@u{th}eena min qablihim ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} faakha\q@u{th}ahumu All\q@u{a}hu bi\q@u{th}unoobihim wa\q@b{A}ll\q@u{a}hu shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@cccv{Qul lilla\q@u{th}eena kafaroo satughlaboona watu\q@u{h}sharoona il\q@u{a} jahannama wabisa almih\q@u{a}d\q@b{u}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@cccvi{Qad k\q@u{a}na lakum \q@u{a}yatun fee fiatayni iltaqat\q@u{a} fiatun tuq\q@u{a}tilu fee sabeeli All\q@u{a}hi waokhr\q@u{a} k\q@u{a}firatun yarawnahum mithlayhim raya alAAayni wa\q@b{A}ll\q@u{a}hu yuayyidu bina\q@u{s}rihi man yash\q@u{a}o inna fee \q@u{tha}lika laAAibratan liolee alab\q@u{sa}r\q@b{i}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@cccvii{Zuyyina li\q@b{l}nn\q@u{a}si \q@u{h}ubbu a\q@b{l}shshahaw\q@u{a}ti mina a\q@b{l}nnis\q@u{a}i wa\q@b{a}lbaneena wa\q@b{a}lqan\q@u{at}eeri almuqan\q@u{t}arati mina a\q@b{l}\q@u{thth}ahabi wa\q@b{a}lfi\q@u{dd}ati wa\q@b{a}lkhayli almusawwamati wa\q@b{a}lanAA\q@u{a}mi wa\q@b{a}l\q@u{h}arthi \q@u{tha}lika mat\q@u{a}AAu al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wa\q@b{A}ll\q@u{a}hu AAindahu \q@u{h}usnu alma\q@u{a}b\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@cccviii{Qul aonabbiokum bikhayrin min \q@u{tha}likum lilla\q@u{th}eena ittaqaw AAinda rabbihim jann\q@u{a}tun tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} waazw\q@u{a}jun mu\q@u{t}ahharatun wari\q@u{d}w\q@u{a}nun mina All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu ba\q@u{s}eerun bi\q@b{a}lAAib\q@u{a}d\q@b{i}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@cccix{Alla\q@u{th}eena yaqooloona rabban\q@u{a} innan\q@u{a} \q@u{a}mann\q@u{a} fa\q@b{i}ghfir lan\q@u{a} \q@u{th}unooban\q@u{a} waqin\q@u{a} AAa\q@u{tha}ba a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@cccx{A\q@b{l}\q@u{ssa}bireena wa\q@b{al}\q@u{ssa}diqeena wa\q@b{a}lq\q@u{a}niteena wa\q@b{a}lmunfiqeena wa\q@b{a}lmustaghfireena bi\q@b{a}las\q@u{ha}r\q@b{i}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@cccxi{Shahida All\q@u{a}hu annahu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa wa\q@b{a}lmal\q@u{a}ikatu waoloo alAAilmi q\q@u{a}iman bi\q@b{a}lqis\q@u{t}i l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@cccxii{Inna a\q@b{l}ddeena AAinda All\q@u{a}hi alisl\q@u{a}mu wam\q@u{a} ikhtalafa alla\q@u{th}eena ootoo alkit\q@u{a}ba ill\q@u{a} min baAAdi m\q@u{a} j\q@u{a}ahumu alAAilmu baghyan baynahum waman yakfur bi\q@u{a}y\q@u{a}ti All\q@u{a}hi fainna All\q@u{a}ha sareeAAu al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@cccxiii{Fain \q@u{ha}jjooka faqul aslamtu wajhiya lill\q@u{a}hi wamani ittabaAAani waqul lilla\q@u{th}eena ootoo alkit\q@u{a}ba wa\q@b{a}l\q@b{}ommiyyeena aaslamtum fain aslamoo faqadi ihtadaw wain tawallaw fainnam\q@u{a} AAalayka albal\q@u{a}ghu wa\q@b{A}ll\q@u{a}hu ba\q@u{s}eerun bi\q@b{a}lAAib\q@u{a}d\q@b{i}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@cccxiv{Inna alla\q@u{th}eena yakfuroona bi\q@u{a}y\q@u{a}ti All\q@u{a}hi wayaqtuloona a\q@b{l}nnabiyyeena bighayri \q@u{h}aqqin wayaqtuloona alla\q@u{th}eena yamuroona bi\q@b{a}lqis\q@u{t}i mina a\q@b{l}nn\q@u{a}si fabashshirhum biAAa\q@u{tha}bin aleem\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@cccxv{Ol\q@u{a}ika alla\q@u{th}eena \q@u{h}abi\q@u{t}at aAAm\q@u{a}luhum fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati wam\q@u{a} lahum min n\q@u{as}ireen\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@cccxvi{Alam tara il\q@u{a} alla\q@u{th}eena ootoo na\q@u{s}eeban mina alkit\q@u{a}bi yudAAawna il\q@u{a} kit\q@u{a}bi All\q@u{a}hi liya\q@u{h}kuma baynahum thumma yatawall\q@u{a} fareequn minhum wahum muAAri\q@u{d}oon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@cccxvii{\q@u{Tha}lika biannahum q\q@u{a}loo lan tamassan\q@u{a} a\q@b{l}nn\q@u{a}ru ill\q@u{a} ayy\q@u{a}man maAAdood\q@u{a}tin wagharrahum fee deenihim m\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@cccxviii{Fakayfa i\q@u{tha} jamaAAn\q@u{a}hum liyawmin l\q@u{a} rayba feehi wawuffiyat kullu nafsin m\q@u{a} kasabat wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@cccxix{Quli all\q@u{a}humma m\q@u{a}lika almulki tutee almulka man tash\q@u{a}o watanziAAu almulka mimman tash\q@u{a}o watuAAizzu man tash\q@u{a}o watu\q@u{th}illu man tash\q@u{a}o biyadika alkhayru innaka AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@cccxx{Tooliju allayla fee a\q@b{l}nnah\q@u{a}ri watooliju a\q@b{l}nnah\q@u{a}ra fee allayli watukhriju al\q@u{h}ayya mina almayyiti watukhriju almayyita mina al\q@u{h}ayyi watarzuqu man tash\q@u{a}o bighayri \q@u{h}is\q@u{a}b\q@b{in}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@cccxxi{L\q@u{a} yattakhi\q@u{th}i almuminoona alk\q@u{a}fireena awliy\q@u{a}a min dooni almumineena waman yafAAal \q@u{tha}lika falaysa mina All\q@u{a}hi fee shayin ill\q@u{a} an tattaqoo minhum tuq\q@u{a}tan wayu\q@u{h}a\q@u{thth}irukumu All\q@u{a}hu nafsahu wail\q@u{a} All\q@u{a}hi alma\q@u{s}eer\q@b{u}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@cccxxii{Qul in tukhfoo m\q@u{a} fee \q@u{s}udoorikum aw tubdoohu yaAAlamhu All\q@u{a}hu wayaAAlamu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@cccxxiii{Yawma tajidu kullu nafsin m\q@u{a} AAamilat min khayrin mu\q@u{hd}aran wam\q@u{a} AAamilat min sooin tawaddu law anna baynah\q@u{a} wabaynahu amadan baAAeedan wayu\q@u{h}a\q@u{thth}irukumu All\q@u{a}hu nafsahu wa\q@b{A}ll\q@u{a}hu raoofun bi\q@b{a}lAAib\q@u{a}d\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@cccxxiv{Qul in kuntum tu\q@u{h}ibboona All\q@u{a}ha fa\q@b{i}ttabiAAoonee yu\q@u{h}bibkumu All\q@u{a}hu wayaghfir lakum \q@u{th}unoobakum wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@cccxxv{Qul a\q@u{t}eeAAoo All\q@u{a}ha wa\q@b{al}rrasoola fain tawallaw fainna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu alk\q@u{a}fireen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@cccxxvi{Inna All\q@u{a}ha i\q@u{st}af\q@u{a} \q@u{a}dama wanoo\q@u{h}an wa\q@u{a}la ibr\q@u{a}heema wa\q@u{a}la AAimr\q@u{a}na AAal\q@u{a} alAA\q@u{a}lameen\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@cccxxvii{\q@u{Th}urriyyatan baAA\q@u{d}uh\q@u{a} min baAA\q@u{d}in wa\q@b{A}ll\q@u{a}hu sameeAAun AAaleem\q@b{un}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@cccxxviii{I\q@u{th} q\q@u{a}lati imraatu AAimr\q@u{a}na rabbi innee na\q@u{th}artu laka m\q@u{a} fee ba\q@u{t}nee mu\q@u{h}arraran fataqabbal minnee innaka anta a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@cccxxix{Falamm\q@u{a} wa\q@u{d}aAAath\q@u{a} q\q@u{a}lat rabbi innee wa\q@u{d}aAAtuh\q@u{a} onth\q@u{a} wa\q@b{A}ll\q@u{a}hu aAAlamu bim\q@u{a} wa\q@u{d}aAAat walaysa a\q@b{l}\q@u{thth}akaru ka\q@b{a}lonth\q@u{a} wainnee sammaytuh\q@u{a} maryama wainnee oAAee\q@u{th}uh\q@u{a} bika wa\q@u{th}urriyyatah\q@u{a} mina a\q@b{l}shshay\q@u{ta}ni a\q@b{l}rrajeem\q@b{i}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@cccxxx{Fataqabbalah\q@u{a} rabbuh\q@u{a} biqaboolin \q@u{h}asanin waanbatah\q@u{a} nab\q@u{a}tan \q@u{h}asanan wakaffalah\q@u{a} zakariyy\q@u{a} kullam\q@u{a} dakhala AAalayh\q@u{a} zakariyy\q@u{a} almi\q@u{h}r\q@u{a}ba wajada AAindah\q@u{a} rizqan q\q@u{a}la y\q@u{a} maryamu ann\q@u{a} laki h\q@u{atha} q\q@u{a}lat huwa min AAindi All\q@u{a}hi inna All\q@u{a}ha yarzuqu man yash\q@u{a}o bighayri \q@u{h}is\q@u{a}b\q@b{in}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@cccxxxi{Hun\q@u{a}lika daAA\q@u{a} zakariyy\q@u{a} rabbahu q\q@u{a}la rabbi hab lee min ladunka \q@u{th}urriyyatan \q@u{t}ayyibatan innaka sameeAAu a\q@b{l}dduAA\q@u{a}\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@cccxxxii{Fan\q@u{a}dathu almal\q@u{a}ikatu wahuwa q\q@u{a}imun yu\q@u{s}allee fee almi\q@u{h}r\q@u{a}bi anna All\q@u{a}ha yubashshiruka biya\q@u{h}y\q@u{a} mu\q@u{s}addiqan bikalimatin mina All\q@u{a}hi wasayyidan wa\q@u{h}a\q@u{s}ooran wanabiyyan mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@cccxxxiii{Q\q@u{a}la rabbi ann\q@u{a} yakoonu lee ghul\q@u{a}mun waqad balaghaniya alkibaru wa\q@b{i}mraatee AA\q@u{a}qirun q\q@u{a}la ka\q@u{tha}lika All\q@u{a}hu yafAAalu m\q@u{a} yash\q@u{a}\q@b{o}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@cccxxxiv{Q\q@u{a}la rabbi ijAAal lee \q@u{a}yatan q\q@u{a}la \q@u{a}yatuka all\q@u{a} tukallima a\q@b{l}nn\q@u{a}sa thal\q@u{a}thata ayy\q@u{a}min ill\q@u{a} ramzan wa\q@b{o}\q@u{th}kur rabbaka katheeran wasabbi\q@u{h} bi\q@b{a}lAAashiyyi wa\q@b{a}libk\q@u{a}r\q@b{i}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@cccxxxv{Wai\q@u{th} q\q@u{a}lati almal\q@u{a}ikatu y\q@u{a} maryamu inna All\q@u{a}ha i\q@u{st}af\q@u{a}ki wa\q@u{t}ahharaki wa\q@b{i}\q@u{st}af\q@u{a}ki AAal\q@u{a} nis\q@u{a}i alAA\q@u{a}lameen\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@cccxxxvi{Y\q@u{a} maryamu oqnutee lirabbiki wa\q@b{o}sjudee wa\q@b{i}rkaAAee maAAa a\q@b{l}rr\q@u{a}kiAAeen\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@cccxxxvii{\q@u{Tha}lika min anb\q@u{a}i alghaybi noo\q@u{h}eehi ilayka wam\q@u{a} kunta ladayhim i\q@u{th} yulqoona aql\q@u{a}mahum ayyuhum yakfulu maryama wam\q@u{a} kunta ladayhim i\q@u{th} yakhta\q@u{s}imoon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@cccxxxviii{I\q@u{th} q\q@u{a}lati almal\q@u{a}ikatu y\q@u{a} maryamu inna All\q@u{a}ha yubashshiruki bikalimatin minhu ismuhu almasee\q@u{h}u AAees\q@u{a} ibnu maryama wajeehan fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati wamina almuqarrabeen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@cccxxxix{Wayukallimu a\q@b{l}nn\q@u{a}sa fee almahdi wakahlan wamina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@cccxl{Q\q@u{a}lat rabbi ann\q@u{a} yakoonu lee waladun walam yamsasnee basharun q\q@u{a}la ka\q@u{tha}liki All\q@u{a}hu yakhluqu m\q@u{a} yash\q@u{a}o i\q@u{tha} qa\q@u{da} amran fainnam\q@u{a} yaqoolu lahu kun fayakoon\q@b{u}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@cccxli{WayuAAallimuhu alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ikmata wa\q@b{al}ttawr\q@u{a}ta wa\q@b{a}linjeel\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@cccxlii{Warasoolan il\q@u{a} banee isr\q@u{a}eela annee qad jitukum bi\q@u{a}yatin min rabbikum annee akhluqu lakum mina a\q@b{l}\q@u{tt}eeni kahayati a\q@b{l}\q@u{tt}ayri faanfukhu feehi fayakoonu \q@u{t}ayran bii\q@u{th}ni All\q@u{a}hi waobrio alakmaha wa\q@b{a}labra\q@u{s}a wao\q@u{h}yee almawt\q@u{a} bii\q@u{th}ni All\q@u{a}hi waonabbiokum bim\q@u{a} takuloona wam\q@u{a} taddakhiroona fee buyootikum inna fee \q@u{tha}lika la\q@u{a}yatan lakum in kuntum mumineen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@cccxliii{Wamu\q@u{s}addiqan lim\q@u{a} bayna yadayya mina a\q@b{l}ttawr\q@u{a}ti walio\q@u{h}illa lakum baAA\q@u{d}a alla\q@u{th}ee \q@u{h}urrima AAalaykum wajitukum bi\q@u{a}yatin min rabbikum fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@cccxliv{Inna All\q@u{a}ha rabbee warabbukum fa\q@b{o}AAbudoohu h\q@u{atha} \q@u{s}ir\q@u{at}un mustaqeem\q@b{un}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@cccxlv{Falamm\q@u{a} a\q@u{h}assa AAees\q@u{a} minhumu alkufra q\q@u{a}la man an\q@u{sa}ree il\q@u{a} All\q@u{a}hi q\q@u{a}la al\q@u{h}aw\q@u{a}riyyoona na\q@u{h}nu an\q@u{sa}ru All\q@u{a}hi \q@u{a}mann\q@u{a} bi\q@b{A}ll\q@u{a}hi wa\q@b{i}shhad biann\q@u{a} muslimoon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@cccxlvi{Rabban\q@u{a} \q@u{a}mann\q@u{a} bim\q@u{a} anzalta wa\q@b{i}ttabaAAn\q@u{a} a\q@b{l}rrasoola fa\q@b{o}ktubn\q@u{a} maAAa a\q@b{l}shsh\q@u{a}hideen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@cccxlvii{Wamakaroo wamakara All\q@u{a}hu wa\q@b{A}ll\q@u{a}hu khayru alm\q@u{a}kireen\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@cccxlviii{I\q@u{th} q\q@u{a}la All\q@u{a}hu y\q@u{a} AAees\q@u{a} innee mutawaffeeka war\q@u{a}fiAAuka ilayya wamu\q@u{t}ahhiruka mina alla\q@u{th}eena kafaroo waj\q@u{a}AAilu alla\q@u{th}eena ittabaAAooka fawqa alla\q@u{th}eena kafaroo il\q@u{a} yawmi alqiy\q@u{a}mati thumma ilayya marjiAAukum faa\q@u{h}kumu baynakum feem\q@u{a} kuntum feehi takhtalifoon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@cccxlix{Faamm\q@u{a} alla\q@u{th}eena kafaroo faoAAa\q@u{thth}ibuhum AAa\q@u{tha}ban shadeedan fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati wam\q@u{a} lahum min n\q@u{as}ireen\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@cccl{Waamm\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti fayuwaffeehim ojoorahum wa\q@b{A}ll\q@u{a}hu l\q@u{a} yu\q@u{h}ibbu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@cccli{\q@u{Tha}lika natloohu AAalayka mina al\q@u{a}y\q@u{a}ti wa\q@b{al}\q@u{thth}ikri al\q@u{h}akeem\q@b{i}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@ccclii{Inna mathala AAees\q@u{a} AAinda All\q@u{a}hi kamathali \q@u{a}dama khalaqahu min tur\q@u{a}bin thumma q\q@u{a}la lahu kun fayakoon\q@b{u}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@cccliii{Al\q@u{h}aqqu min rabbika fal\q@u{a} takun mina almumtareen\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@cccliv{Faman \q@u{ha}jjaka feehi min baAAdi m\q@u{a} j\q@u{a}aka mina alAAilmi faqul taAA\q@u{a}law nadAAu abn\q@u{a}an\q@u{a} waabn\q@u{a}akum wanis\q@u{a}an\q@u{a} wanis\q@u{a}akum waanfusan\q@u{a} waanfusakum thumma nabtahil fanajAAal laAAnata All\q@u{a}hi AAal\q@u{a} alk\q@u{ath}ibeen\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@ccclv{Inna h\q@u{atha} lahuwa alqa\q@u{s}a\q@u{s}u al\q@u{h}aqqu wam\q@u{a} min il\q@u{a}hin ill\q@u{a} All\q@u{a}hu wainna All\q@u{a}ha lahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@ccclvi{Fain tawallaw fainna All\q@u{a}ha AAaleemun bi\q@b{a}lmufsideen\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@ccclvii{Qul y\q@u{a} ahla alkit\q@u{a}bi taAA\q@u{a}law il\q@u{a} kalimatin saw\q@u{a}in baynan\q@u{a} wabaynakum all\q@u{a} naAAbuda ill\q@u{a} All\q@u{a}ha wal\q@u{a} nushrika bihi shayan wal\q@u{a} yattakhi\q@u{th}a baAA\q@u{d}un\q@u{a} baAA\q@u{d}an arb\q@u{a}ban min dooni All\q@u{a}hi fain tawallaw faqooloo ishhadoo biann\q@u{a} muslimoon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@ccclviii{Y\q@u{a} ahla alkit\q@u{a}bi lima tu\q@u{ha}jjoona fee ibr\q@u{a}heema wam\q@u{a} onzilati a\q@b{l}ttawr\q@u{a}tu wa\q@b{a}linjeelu ill\q@u{a} min baAAdihi afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@ccclix{H\q@u{a}antum h\q@u{a}ol\q@u{a}i \q@u{ha}jajtum feem\q@u{a} lakum bihi AAilmun falima tu\q@u{ha}jjoona feem\q@u{a} laysa lakum bihi AAilmun wa\q@b{A}ll\q@u{a}hu yaAAlamu waantum l\q@u{a} taAAlamoon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@ccclx{M\q@u{a} k\q@u{a}na ibr\q@u{a}heemu yahoodiyyan wal\q@u{a} na\q@u{s}r\q@u{a}niyyan wal\q@u{a}kin k\q@u{a}na \q@u{h}aneefan musliman wam\q@u{a} k\q@u{a}na mina almushrikeen\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@ccclxi{Inna awl\q@u{a} a\q@b{l}nn\q@u{a}si biibr\q@u{a}heema lalla\q@u{th}eena ittabaAAoohu wah\q@u{atha} a\q@b{l}nnabiyyu wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo wa\q@b{A}ll\q@u{a}hu waliyyu almumineen\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@ccclxii{Waddat \q@u{ta}ifatun min ahli alkit\q@u{a}bi law yu\q@u{d}illoonakum wam\q@u{a} yu\q@u{d}illoona ill\q@u{a} anfusahum wam\q@u{a} yashAAuroon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@ccclxiii{Y\q@u{a} ahla alkit\q@u{a}bi lima takfuroona bi\q@u{a}y\q@u{a}ti All\q@u{a}hi waantum tashhadoon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@ccclxiv{Y\q@u{a} ahla alkit\q@u{a}bi lima talbisoona al\q@u{h}aqqa bi\q@b{a}lb\q@u{at}ili wataktumoona al\q@u{h}aqqa waantum taAAlamoon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@ccclxv{Waq\q@u{a}lat \q@u{ta}ifatun min ahli alkit\q@u{a}bi \q@u{a}minoo bi\q@b{a}lla\q@u{th}ee onzila AAal\q@u{a} alla\q@u{th}eena \q@u{a}manoo wajha a\q@b{l}nnah\q@u{a}ri wa\q@b{o}kfuroo \q@u{a}khirahu laAAallahum yarjiAAoon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@ccclxvi{Wal\q@u{a} tuminoo ill\q@u{a} liman tabiAAa deenakum qul inna alhud\q@u{a} hud\q@u{a} All\q@u{a}hi an yut\q@u{a} a\q@u{h}adun mithla m\q@u{a} ooteetum aw yu\q@u{ha}jjookum AAinda rabbikum qul inna alfa\q@u{d}la biyadi All\q@u{a}hi yuteehi man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu w\q@u{a}siAAun AAaleem\q@b{un}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@ccclxvii{Yakhta\q@u{ss}u bira\q@u{h}matihi man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu \q@u{th}oo alfa\q@u{d}li alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@ccclxviii{Wamin ahli alkit\q@u{a}bi man in tamanhu biqin\q@u{ta}rin yuaddihi ilayka waminhum man in tamanhu bideen\q@u{a}rin l\q@u{a} yuaddihi ilayka ill\q@u{a} m\q@u{a} dumta AAalayhi q\q@u{a}iman \q@u{tha}lika biannahum q\q@u{a}loo laysa AAalayn\q@u{a} fee alommiyyeena sabeelun wayaqooloona AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba wahum yaAAlamoon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@ccclxix{Bal\q@u{a} man awf\q@u{a} biAAahdihi wa\q@b{i}ttaq\q@u{a} fainna All\q@u{a}ha yu\q@u{h}ibbu almuttaqeen\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@ccclxx{Inna alla\q@u{th}eena yashtaroona biAAahdi All\q@u{a}hi waaym\q@u{a}nihim thamanan qaleelan ol\q@u{a}ika l\q@u{a} khal\q@u{a}qa lahum fee al\q@u{a}khirati wal\q@u{a} yukallimuhumu All\q@u{a}hu wal\q@u{a} yan\q@i{\q@u{th}}uru ilayhim yawma alqiy\q@u{a}mati wal\q@u{a} yuzakkeehim walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@ccclxxi{Wainna minhum lafareeqan yalwoona alsinatahum bi\q@b{a}lkit\q@u{a}bi lita\q@u{h}saboohu mina alkit\q@u{a}bi wam\q@u{a} huwa mina alkit\q@u{a}bi wayaqooloona huwa min AAindi All\q@u{a}hi wam\q@u{a} huwa min AAindi All\q@u{a}hi wayaqooloona AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba wahum yaAAlamoon\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@ccclxxii{M\q@u{a} k\q@u{a}na libasharin an yutiyahu All\q@u{a}hu alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ukma wa\q@b{al}nnubuwwata thumma yaqoola li\q@b{l}nn\q@u{a}si koonoo AAib\q@u{a}dan lee min dooni All\q@u{a}hi wal\q@u{a}kin koonoo rabb\q@u{a}niyyeena bim\q@u{a} kuntum tuAAallimoona alkit\q@u{a}ba wabim\q@u{a} kuntum tadrusoon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@ccclxxiii{Wal\q@u{a} yamurakum an tattakhi\q@u{th}oo almal\q@u{a}ikata wa\q@b{al}nnabiyyeena arb\q@u{a}ban ayamurukum bi\q@b{a}lkufri baAAda i\q@u{th} antum muslimoon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@ccclxxiv{Wai\q@u{th} akha\q@u{th}a All\q@u{a}hu meeth\q@u{a}qa a\q@b{l}nnabiyyeena lam\q@u{a} \q@u{a}taytukum min kit\q@u{a}bin wa\q@u{h}ikmatin thumma j\q@u{a}akum rasoolun mu\q@u{s}addiqun lim\q@u{a} maAAakum latuminunna bihi walatan\q@u{s}urunnahu q\q@u{a}la aaqrartum waakha\q@u{th}tum AAal\q@u{a} \q@u{tha}likum i\q@u{s}ree q\q@u{a}loo aqrarn\q@u{a} q\q@u{a}la fa\q@b{i}shhadoo waan\q@u{a} maAAakum mina a\q@b{l}shsh\q@u{a}hideen\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@ccclxxv{Faman tawall\q@u{a} baAAda \q@u{tha}lika faol\q@u{a}ika humu alf\q@u{a}siqoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@ccclxxvi{Afaghayra deeni All\q@u{a}hi yabghoona walahu aslama man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i \q@u{t}awAAan wakarhan wailayhi yurjaAAoon\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@ccclxxvii{Qul \q@u{a}mann\q@u{a} bi\q@b{A}ll\q@u{a}hi wam\q@u{a} onzila AAalayn\q@u{a} wam\q@u{a} onzila AAal\q@u{a} ibr\q@u{a}heema waism\q@u{a}AAeela wais\q@u{ha}qa wayaAAqooba wa\q@b{a}lasb\q@u{at}i wam\q@u{a} ootiya moos\q@u{a} waAAees\q@u{a} wa\q@b{al}nnabiyyoona min rabbihim l\q@u{a} nufarriqu bayna a\q@u{h}adin minhum wana\q@u{h}nu lahu muslimoon\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@ccclxxviii{Waman yabtaghi ghayra alisl\q@u{a}mi deenan falan yuqbala minhu wahuwa fee al\q@u{a}khirati mina alkh\q@u{a}sireen\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@ccclxxix{Kayfa yahdee All\q@u{a}hu qawman kafaroo baAAda eem\q@u{a}nihim washahidoo anna a\q@b{l}rrasoola \q@u{h}aqqun waj\q@u{a}ahumu albayyin\q@u{a}tu wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@ccclxxx{Ol\q@u{a}ika jaz\q@u{a}ohum anna AAalayhim laAAnata All\q@u{a}hi wa\q@b{a}lmal\q@u{a}ikati wa\q@b{al}nn\q@u{a}si ajmaAAeen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@ccclxxxi{Kh\q@u{a}lideena feeh\q@u{a} l\q@u{a} yukhaffafu AAanhumu alAAa\q@u{tha}bu wal\q@u{a} hum yun\q@i{\q@u{th}}aroon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@ccclxxxii{Ill\q@u{a} alla\q@u{th}eena t\q@u{a}boo min baAAdi \q@u{tha}lika waa\q@u{s}la\q@u{h}oo fainna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@ccclxxxiii{Inna alla\q@u{th}eena kafaroo baAAda eem\q@u{a}nihim thumma izd\q@u{a}doo kufran lan tuqbala tawbatuhum waol\q@u{a}ika humu a\q@b{l}\q@u{dda}lloon\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@ccclxxxiv{Inna alla\q@u{th}eena kafaroo wam\q@u{a}too wahum kuff\q@u{a}run falan yuqbala min a\q@u{h}adihim milo alar\q@u{d}i \q@u{th}ahaban walawi iftad\q@u{a} bihi ol\q@u{a}ika lahum AAa\q@u{tha}bun aleemun wam\q@u{a} lahum min n\q@u{as}ireen\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@ccclxxxv{Lan tan\q@u{a}loo albirra \q@u{h}att\q@u{a} tunfiqoo mimm\q@u{a} tu\q@u{h}ibboona wam\q@u{a} tunfiqoo min shayin fainna All\q@u{a}ha bihi AAaleem\q@b{un}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@ccclxxxvi{Kullu a\q@b{l}\q@u{tt}aAA\q@u{a}mi k\q@u{a}na \q@u{h}illan libanee isr\q@u{a}eela ill\q@u{a} m\q@u{a} \q@u{h}arrama isr\q@u{a}eelu AAal\q@u{a} nafsihi min qabli an tunazzala a\q@b{l}ttawr\q@u{a}tu qul fatoo bi\q@b{al}ttawr\q@u{a}ti fa\q@b{o}tlooh\q@u{a} in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@ccclxxxvii{Famani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba min baAAdi \q@u{tha}lika faol\q@u{a}ika humu a\q@b{l}\q@i{\q@u{th}}\q@u{a}limoon\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@ccclxxxviii{Qul \q@u{s}adaqa All\q@u{a}hu fa\q@b{i}ttabiAAoo millata ibr\q@u{a}heema \q@u{h}aneefan wam\q@u{a} k\q@u{a}na mina almushrikeen\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@ccclxxxix{Inna awwala baytin wu\q@u{d}iAAa li\q@b{l}nn\q@u{a}si lalla\q@u{th}ee bibakkata mub\q@u{a}rakan wahudan lilAA\q@u{a}lameen\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@cccxc{Feehi \q@u{a}y\q@u{a}tun bayyin\q@u{a}tun maq\q@u{a}mu ibr\q@u{a}heema waman dakhalahu k\q@u{a}na \q@u{a}minan walill\q@u{a}hi AAal\q@u{a} a\q@b{l}nn\q@u{a}si \q@u{h}ijju albayti mani ista\q@u{ta}AAa ilayhi sabeelan waman kafara fainna All\q@u{a}ha ghaniyyun AAani alAA\q@u{a}lameen\q@b{a}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@cccxci{Qul y\q@u{a} ahla alkit\q@u{a}bi lima takfuroona bi\q@u{a}y\q@u{a}ti All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu shaheedun AAal\q@u{a} m\q@u{a} taAAmaloon\q@b{a}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@cccxcii{Qul y\q@u{a} ahla alkit\q@u{a}bi lima ta\q@u{s}uddoona AAan sabeeli All\q@u{a}hi man \q@u{a}mana tabghoonah\q@u{a} AAiwajan waantum shuhad\q@u{a}o wam\q@u{a} All\q@u{a}hu bigh\q@u{a}filin AAamm\q@u{a} taAAmaloon\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@cccxciii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo in tu\q@u{t}eeAAoo fareeqan mina alla\q@u{th}eena ootoo alkit\q@u{a}ba yaruddookum baAAda eem\q@u{a}nikum k\q@u{a}fireen\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@cccxciv{Wakayfa takfuroona waantum tutl\q@u{a} AAalaykum \q@u{a}y\q@u{a}tu All\q@u{a}hi wafeekum rasooluhu waman yaAAta\q@u{s}im bi\q@b{A}ll\q@u{a}hi faqad hudiya il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@cccxcv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo ittaqoo All\q@u{a}ha \q@u{h}aqqa tuq\q@u{a}tihi wal\q@u{a} tamootunna ill\q@u{a} waantum muslimoon\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@cccxcvi{Wa\q@b{i}AAta\q@u{s}imoo bi\q@u{h}abli All\q@u{a}hi jameeAAan wal\q@u{a} tafarraqoo wa\q@b{o}\q@u{th}kuroo niAAmata All\q@u{a}hi AAalaykum i\q@u{th} kuntum aAAd\q@u{a}an faallafa bayna quloobikum faa\q@u{s}ba\q@u{h}tum biniAAmatihi ikhw\q@u{a}nan wakuntum AAal\q@u{a} shaf\q@u{a} \q@u{h}ufratin mina a\q@b{l}nn\q@u{a}ri faanqa\q@u{th}akum minh\q@u{a} ka\q@u{tha}lika yubayyinu All\q@u{a}hu lakum \q@u{a}y\q@u{a}tihi laAAallakum tahtadoon\q@b{a}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@cccxcvii{Waltakun minkum ommatun yadAAoona il\q@u{a} alkhayri wayamuroona bi\q@b{a}lmaAAroofi wayanhawna AAani almunkari waol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@cccxcviii{Wal\q@u{a} takoonoo ka\q@b{a}lla\q@u{th}eena tafarraqoo wa\q@b{i}khtalafoo min baAAdi m\q@u{a} j\q@u{a}ahumu albayyin\q@u{a}tu waol\q@u{a}ika lahum AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@cccxcix{Yawma tabya\q@u{dd}u wujoohun wataswaddu wujoohun faamm\q@u{a} alla\q@u{th}eena iswaddat wujoohuhum akafartum baAAda eem\q@u{a}nikum fa\q@u{th}ooqoo alAAa\q@u{tha}ba bim\q@u{a} kuntum takfuroon\q@b{a}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@cd{Waamm\q@u{a} alla\q@u{th}eena ibya\q@u{dd}at wujoohuhum fafee ra\q@u{h}mati All\q@u{a}hi hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@cdi{Tilka \q@u{a}y\q@u{a}tu All\q@u{a}hi natlooh\q@u{a} AAalayka bi\q@b{a}l\q@u{h}aqqi wam\q@u{a} All\q@u{a}hu yureedu \q@i{\q@u{th}}ulman lilAA\q@u{a}lameen\q@b{a}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@cdii{Walill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wail\q@u{a} All\q@u{a}hi turjaAAu alomoor\q@b{u}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@cdiii{Kuntum khayra ommatin okhrijat li\q@b{l}nn\q@u{a}si tamuroona bi\q@b{a}lmaAAroofi watanhawna AAani almunkari watuminoona bi\q@b{A}ll\q@u{a}hi walaw \q@u{a}mana ahlu alkit\q@u{a}bi lak\q@u{a}na khayran lahum minhumu almuminoona waaktharuhumu alf\q@u{a}siqoon\q@b{a}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@cdiv{Lan ya\q@u{d}urrookum ill\q@u{a} a\q@u{th}an wain yuq\q@u{a}tilookum yuwallookumu aladb\q@u{a}ra thumma l\q@u{a} yun\q@u{s}aroon\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@cdv{\q@u{D}uribat AAalayhimu a\q@b{l}\q@u{thth}illatu ayna m\q@u{a} thuqifoo ill\q@u{a} bi\q@u{h}ablin mina All\q@u{a}hi wa\q@u{h}ablin mina a\q@b{l}nn\q@u{a}si wab\q@u{a}oo bigha\q@u{d}abin mina All\q@u{a}hi wa\q@u{d}uribat AAalayhimu almaskanatu \q@u{tha}lika biannahum k\q@u{a}noo yakfuroona bi\q@u{a}y\q@u{a}ti All\q@u{a}hi wayaqtuloona alanbiy\q@u{a}a bighayri \q@u{h}aqqin \q@u{tha}lika bim\q@u{a} AAa\q@u{s}aw wak\q@u{a}noo yaAAtadoon\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@cdvi{Laysoo saw\q@u{a}an min ahli alkit\q@u{a}bi ommatun q\q@u{a}imatun yatloona \q@u{a}y\q@u{a}ti All\q@u{a}hi \q@u{a}n\q@u{a}a allayli wahum yasjudoon\q@b{a}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@cdvii{Yuminoona bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri wayamuroona bi\q@b{a}lmaAAroofi wayanhawna AAani almunkari wayus\q@u{a}riAAoona fee alkhayr\q@u{a}ti waol\q@u{a}ika mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@cdviii{Wam\q@u{a} yafAAaloo min khayrin falan yukfaroohu wa\q@b{A}ll\q@u{a}hu AAaleemun bi\q@b{a}lmuttaqeen\q@b{a}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@cdix{Inna alla\q@u{th}eena kafaroo lan tughniya AAanhum amw\q@u{a}luhum wal\q@u{a} awl\q@u{a}duhum mina All\q@u{a}hi shayan waol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@cdx{Mathalu m\q@u{a} yunfiqoona fee h\q@u{ath}ihi al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} kamathali ree\q@u{h}in feeh\q@u{a} \q@u{s}irrun a\q@u{sa}bat \q@u{h}artha qawmin \q@i{\q@u{th}}alamoo anfusahum faahlakathu wam\q@u{a} \q@i{\q@u{th}}alamahumu All\q@u{a}hu wal\q@u{a}kin anfusahum ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@cdxi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tattakhi\q@u{th}oo bi\q@u{ta}natan min doonikum l\q@u{a} yaloonakum khab\q@u{a}lan waddoo m\q@u{a} AAanittum qad badati albagh\q@u{da}o min afw\q@u{a}hihim wam\q@u{a} tukhfee \q@u{s}udooruhum akbaru qad bayyann\q@u{a} lakumu al\q@u{a}y\q@u{a}ti in kuntum taAAqiloon\q@b{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@cdxii{H\q@u{a}antum ol\q@u{a}i tu\q@u{h}ibboonahum wal\q@u{a} yu\q@u{h}ibboonakum watuminoona bi\q@b{a}lkit\q@u{a}bi kullihi wai\q@u{tha} laqookum q\q@u{a}loo \q@u{a}mann\q@u{a} wai\q@u{tha} khalaw AAa\q@u{dd}oo AAalaykumu alan\q@u{a}mila mina alghay\q@i{\q@u{th}}i qul mootoo bighay\q@i{\q@u{th}}ikum inna All\q@u{a}ha AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@cdxiii{In tamsaskum \q@u{h}asanatun tasuhum wain tu\q@u{s}ibkum sayyiatun yafra\q@u{h}oo bih\q@u{a} wain ta\q@u{s}biroo watattaqoo l\q@u{a} ya\q@u{d}urrukum kayduhum shayan inna All\q@u{a}ha bim\q@u{a} yaAAmaloona mu\q@u{h}ee\q@u{t}\q@b{un}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@cdxiv{Wai\q@u{th} ghadawta min ahlika tubawwio almumineena maq\q@u{a}AAida lilqit\q@u{a}li wa\q@b{A}ll\q@u{a}hu sameeAAun AAaleem\q@b{un}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@cdxv{I\q@u{th} hammat \q@u{ta}ifat\q@u{a}ni minkum an tafshal\q@u{a} wa\q@b{A}ll\q@u{a}hu waliyyuhum\q@u{a} waAAal\q@u{a} All\q@u{a}hi falyatawakkali almuminoon\q@b{a}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@cdxvi{Walaqad na\q@u{s}arakumu All\q@u{a}hu bibadrin waantum a\q@u{th}illatun fa\q@b{i}ttaqoo All\q@u{a}ha laAAallakum tashkuroon\q@b{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@cdxvii{I\q@u{th} taqoolu lilmumineena alan yakfiyakum an yumiddakum rabbukum bithal\q@u{a}thati \q@u{a}l\q@u{a}fin mina almal\q@u{a}ikati munzaleen\q@b{a}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@cdxviii{Bal\q@u{a} in ta\q@u{s}biroo watattaqoo wayatookum min fawrihim h\q@u{atha} yumdidkum rabbukum bikhamsati \q@u{a}l\q@u{a}fin mina almal\q@u{a}ikati musawwimeen\q@b{a}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@cdxix{Wam\q@u{a} jaAAalahu All\q@u{a}hu ill\q@u{a} bushr\q@u{a} lakum walita\q@u{t}mainna quloobukum bihi wam\q@u{a} a\q@b{l}nna\q@u{s}ru ill\q@u{a} min AAindi All\q@u{a}hi alAAazeezi al\q@u{h}akeem\q@b{i}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@cdxx{Liyaq\q@u{t}aAAa \q@u{t}arafan mina alla\q@u{th}eena kafaroo aw yakbitahum fayanqaliboo kh\q@u{a}ibeen\q@b{a}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@cdxxi{Laysa laka mina alamri shayon aw yatooba AAalayhim aw yuAAa\q@u{thth}ibahum fainnahum \q@i{\q@u{th}}\q@u{a}limoon\q@b{a}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@cdxxii{Walill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i yaghfiru liman yash\q@u{a}o wayuAAa\q@u{thth}ibu man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(129)}}
\qt@newcmd\qurantrans@lt@cdxxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} takuloo a\q@b{l}rrib\q@u{a} a\q@u{d}AA\q@u{a}fan mu\q@u{da}AAafatan wa\q@b{i}ttaqoo All\q@u{a}ha laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(130)}}
\qt@newcmd\qurantrans@lt@cdxxiv{Wa\q@b{i}ttaqoo a\q@b{l}nn\q@u{a}ra allatee oAAiddat lilk\q@u{a}fireen\q@b{a}\qt@no{(131)}}
\qt@newcmd\qurantrans@lt@cdxxv{Waa\q@u{t}eeAAoo All\q@u{a}ha wa\q@b{al}rrasoola laAAallakum tur\q@u{h}amoon\q@b{a}\qt@no{(132)}}
\qt@newcmd\qurantrans@lt@cdxxvi{Was\q@u{a}riAAoo il\q@u{a} maghfiratin min rabbikum wajannatin AAar\q@u{d}uh\q@u{a} a\q@b{l}ssam\q@u{a}w\q@u{a}tu wa\q@b{a}lar\q@u{d}u oAAiddat lilmuttaqeen\q@b{a}\qt@no{(133)}}
\qt@newcmd\qurantrans@lt@cdxxvii{Alla\q@u{th}eena yunfiqoona fee a\q@b{l}ssarr\q@u{a}i wa\q@b{al}\q@u{dd}arr\q@u{a}i wa\q@b{a}lk\q@u{a}\q@i{\q@u{th}}imeena alghay\q@i{\q@u{th}}a wa\q@b{a}lAA\q@u{a}feena AAani a\q@b{l}nn\q@u{a}si wa\q@b{A}ll\q@u{a}hu yu\q@u{h}ibbu almu\q@u{h}sineen\q@b{a}\qt@no{(134)}}
\qt@newcmd\qurantrans@lt@cdxxviii{Wa\q@b{a}lla\q@u{th}eena i\q@u{tha} faAAaloo f\q@u{ah}ishatan aw \q@i{\q@u{th}}alamoo anfusahum \q@u{th}akaroo All\q@u{a}ha fa\q@b{i}staghfaroo li\q@u{th}unoobihim waman yaghfiru a\q@b{l}\q@u{thth}unooba ill\q@u{a} All\q@u{a}hu walam yu\q@u{s}irroo AAal\q@u{a} m\q@u{a} faAAaloo wahum yaAAlamoon\q@b{a}\qt@no{(135)}}
\qt@newcmd\qurantrans@lt@cdxxix{Ol\q@u{a}ika jaz\q@u{a}ohum maghfiratun min rabbihim wajann\q@u{a}tun tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} waniAAma ajru alAA\q@u{a}mileen\q@b{a}\qt@no{(136)}}
\qt@newcmd\qurantrans@lt@cdxxx{Qad khalat min qablikum sunanun faseeroo fee alar\q@u{d}i fa\q@b{o}n\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu almuka\q@u{thth}ibeen\q@b{a}\qt@no{(137)}}
\qt@newcmd\qurantrans@lt@cdxxxi{H\q@u{atha} bay\q@u{a}nun li\q@b{l}nn\q@u{a}si wahudan wamawAAi\q@i{\q@u{th}}atun lilmuttaqeen\q@b{a}\qt@no{(138)}}
\qt@newcmd\qurantrans@lt@cdxxxii{Wal\q@u{a} tahinoo wal\q@u{a} ta\q@u{h}zanoo waantumu alaAAlawna in kuntum mumineen\q@b{a}\qt@no{(139)}}
\qt@newcmd\qurantrans@lt@cdxxxiii{In yamsaskum qar\q@u{h}un faqad massa alqawma qar\q@u{h}un mithluhu watilka alayy\q@u{a}mu nud\q@u{a}wiluh\q@u{a} bayna a\q@b{l}nn\q@u{a}si waliyaAAlama All\q@u{a}hu alla\q@u{th}eena \q@u{a}manoo wayattakhi\q@u{th}a minkum shuhad\q@u{a}a wa\q@b{A}ll\q@u{a}hu l\q@u{a} yu\q@u{h}ibbu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(140)}}
\qt@newcmd\qurantrans@lt@cdxxxiv{Waliyuma\q@u{hh}i\q@u{s}a All\q@u{a}hu alla\q@u{th}eena \q@u{a}manoo wayam\q@u{h}aqa alk\q@u{a}fireen\q@b{a}\qt@no{(141)}}
\qt@newcmd\qurantrans@lt@cdxxxv{Am \q@u{h}asibtum an tadkhuloo aljannata walamm\q@u{a} yaAAlami All\q@u{a}hu alla\q@u{th}eena j\q@u{a}hadoo minkum wayaAAlama a\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(142)}}
\qt@newcmd\qurantrans@lt@cdxxxvi{Walaqad kuntum tamannawna almawta min qabli an talqawhu faqad raaytumoohu waantum tan\q@i{\q@u{th}}uroon\q@b{a}\qt@no{(143)}}
\qt@newcmd\qurantrans@lt@cdxxxvii{Wam\q@u{a} mu\q@u{h}ammadun ill\q@u{a} rasoolun qad khalat min qablihi a\q@b{l}rrusulu afain m\q@u{a}ta aw qutila inqalabtum AAal\q@u{a} aAAq\q@u{a}bikum waman yanqalib AAal\q@u{a} AAaqibayhi falan ya\q@u{d}urra All\q@u{a}ha shayan wasayajzee All\q@u{a}hu a\q@b{l}shsh\q@u{a}kireen\q@b{a}\qt@no{(144)}}
\qt@newcmd\qurantrans@lt@cdxxxviii{Wam\q@u{a} k\q@u{a}na linafsin an tamoota ill\q@u{a} bii\q@u{th}ni All\q@u{a}hi kit\q@u{a}ban muajjalan waman yurid thaw\q@u{a}ba a\q@b{l}dduny\q@u{a} nutihi minh\q@u{a} waman yurid thaw\q@u{a}ba al\q@u{a}khirati nutihi minh\q@u{a} wasanajzee a\q@b{l}shsh\q@u{a}kireen\q@b{a}\qt@no{(145)}}
\qt@newcmd\qurantrans@lt@cdxxxix{Wakaayyin min nabiyyin q\q@u{a}tala maAAahu ribbiyyoona katheerun fam\q@u{a} wahanoo lim\q@u{a} a\q@u{sa}bahum fee sabeeli All\q@u{a}hi wam\q@u{a} \q@u{d}aAAufoo wam\q@u{a} istak\q@u{a}noo wa\q@b{A}ll\q@u{a}hu yu\q@u{h}ibbu a\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(146)}}
\qt@newcmd\qurantrans@lt@cdxl{Wam\q@u{a} k\q@u{a}na qawlahum ill\q@u{a} an q\q@u{a}loo rabban\q@u{a} ighfir lan\q@u{a} \q@u{th}unooban\q@u{a} waisr\q@u{a}fan\q@u{a} fee amrin\q@u{a} wathabbit aqd\q@u{a}man\q@u{a} wa\q@b{o}n\q@u{s}urn\q@u{a} AAal\q@u{a} alqawmi alk\q@u{a}fireen\q@b{a}\qt@no{(147)}}
\qt@newcmd\qurantrans@lt@cdxli{Fa\q@u{a}t\q@u{a}humu All\q@u{a}hu thaw\q@u{a}ba a\q@b{l}dduny\q@u{a} wa\q@u{h}usna thaw\q@u{a}bi al\q@u{a}khirati wa\q@b{A}ll\q@u{a}hu yu\q@u{h}ibbu almu\q@u{h}sineen\q@b{a}\qt@no{(148)}}
\qt@newcmd\qurantrans@lt@cdxlii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo in tu\q@u{t}eeAAoo alla\q@u{th}eena kafaroo yaruddookum AAal\q@u{a} aAAq\q@u{a}bikum fatanqaliboo kh\q@u{a}sireen\q@b{a}\qt@no{(149)}}
\qt@newcmd\qurantrans@lt@cdxliii{Bali All\q@u{a}hu mawl\q@u{a}kum wahuwa khayru a\q@b{l}nn\q@u{as}ireen\q@b{a}\qt@no{(150)}}
\qt@newcmd\qurantrans@lt@cdxliv{Sanulqee fee quloobi alla\q@u{th}eena kafaroo a\q@b{l}rruAAba bim\q@u{a} ashrakoo bi\q@b{A}ll\q@u{a}hi m\q@u{a} lam yunazzil bihi sul\q@u{ta}nan wamaw\q@u{a}humu a\q@b{l}nn\q@u{a}ru wabisa mathw\q@u{a} a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(151)}}
\qt@newcmd\qurantrans@lt@cdxlv{Walaqad \q@u{s}adaqakumu All\q@u{a}hu waAAdahu i\q@u{th} ta\q@u{h}ussoonahum bii\q@u{th}nihi \q@u{h}att\q@u{a} i\q@u{tha} fashiltum watan\q@u{a}zaAAtum fee alamri waAAa\q@u{s}aytum min baAAdi m\q@u{a} ar\q@u{a}kum m\q@u{a} tu\q@u{h}ibboona minkum man yureedu a\q@b{l}dduny\q@u{a} waminkum man yureedu al\q@u{a}khirata thumma \q@u{s}arafakum AAanhum liyabtaliyakum walaqad AAaf\q@u{a} AAankum wa\q@b{A}ll\q@u{a}hu \q@u{th}oo fa\q@u{d}lin AAal\q@u{a} almumineen\q@b{a}\qt@no{(152)}}
\qt@newcmd\qurantrans@lt@cdxlvi{I\q@u{th} tu\q@u{s}AAidoona wal\q@u{a} talwoona AAal\q@u{a} a\q@u{h}adin wa\q@b{al}rrasoolu yadAAookum fee okhr\q@u{a}kum faath\q@u{a}bakum ghamman bighammin likayl\q@u{a} ta\q@u{h}zanoo AAal\q@u{a} m\q@u{a} f\q@u{a}takum wal\q@u{a} m\q@u{a} a\q@u{sa}bakum wa\q@b{A}ll\q@u{a}hu khabeerun bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(153)}}
\qt@newcmd\qurantrans@lt@cdxlvii{Thumma anzala AAalaykum min baAAdi alghammi amanatan nuAA\q@u{a}san yaghsh\q@u{a} \q@u{ta}ifatan minkum wa\q@u{ta}ifatun qad ahammathum anfusuhum ya\q@i{\q@u{th}}unnoona bi\q@b{A}ll\q@u{a}hi ghayra al\q@u{h}aqqi \q@i{\q@u{th}}anna alj\q@u{a}hiliyyati yaqooloona hal lan\q@u{a} mina alamri min shayin qul inna alamra kullahu lill\q@u{a}hi yukhfoona fee anfusihim m\q@u{a} l\q@u{a} yubdoona laka yaqooloona law k\q@u{a}na lan\q@u{a} mina alamri shayon m\q@u{a} qutiln\q@u{a} h\q@u{a}hun\q@u{a} qul law kuntum fee buyootikum labaraza alla\q@u{th}eena kutiba AAalayhimu alqatlu il\q@u{a} ma\q@u{da}jiAAihim waliyabtaliya All\q@u{a}hu m\q@u{a} fee \q@u{s}udoorikum waliyuma\q@u{hh}i\q@u{s}a m\q@u{a} fee quloobikum wa\q@b{A}ll\q@u{a}hu AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(154)}}
\qt@newcmd\qurantrans@lt@cdxlviii{Inna alla\q@u{th}eena tawallaw minkum yawma iltaq\q@u{a} aljamAA\q@u{a}ni innam\q@u{a} istazallahumu a\q@b{l}shshay\q@u{ta}nu bibaAA\q@u{d}i m\q@u{a} kasaboo walaqad AAaf\q@u{a} All\q@u{a}hu AAanhum inna All\q@u{a}ha ghafoorun \q@u{h}aleem\q@b{un}\qt@no{(155)}}
\qt@newcmd\qurantrans@lt@cdxlix{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} takoonoo ka\q@b{a}lla\q@u{th}eena kafaroo waq\q@u{a}loo liikhw\q@u{a}nihim i\q@u{tha} \q@u{d}araboo fee alar\q@u{d}i aw k\q@u{a}noo ghuzzan law k\q@u{a}noo AAindan\q@u{a} m\q@u{a} m\q@u{a}too wam\q@u{a} qutiloo liyajAAala All\q@u{a}hu \q@u{tha}lika \q@u{h}asratan fee quloobihim wa\q@b{A}ll\q@u{a}hu yu\q@u{h}yee wayumeetu wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(156)}}
\qt@newcmd\qurantrans@lt@cdl{Walain qutiltum fee sabeeli All\q@u{a}hi aw muttum lamaghfiratun mina All\q@u{a}hi wara\q@u{h}matun khayrun mimm\q@u{a} yajmaAAoon\q@b{a}\qt@no{(157)}}
\qt@newcmd\qurantrans@lt@cdli{Walain muttum aw qutiltum lail\q@u{a} All\q@u{a}hi tu\q@u{h}sharoon\q@b{a}\qt@no{(158)}}
\qt@newcmd\qurantrans@lt@cdlii{Fabim\q@u{a} ra\q@u{h}matin mina All\q@u{a}hi linta lahum walaw kunta fa\q@i{\q@u{thth}}an ghalee\q@i{\q@u{th}}a alqalbi la\q@b{i}nfa\q@u{dd}oo min \q@u{h}awlika fa\q@b{o}AAfu AAanhum wa\q@b{i}staghfir lahum wash\q@u{a}wirhum fee alamri fai\q@u{tha} AAazamta fatawakkal AAal\q@u{a} All\q@u{a}hi inna All\q@u{a}ha yu\q@u{h}ibbu almutawakkileen\q@b{a}\qt@no{(159)}}
\qt@newcmd\qurantrans@lt@cdliii{In yan\q@u{s}urkumu All\q@u{a}hu fal\q@u{a} gh\q@u{a}liba lakum wain yakh\q@u{th}ulkum faman \q@u{tha} alla\q@u{th}ee yan\q@u{s}urukum min baAAdihi waAAal\q@u{a} All\q@u{a}hi falyatawakkali almuminoon\q@b{a}\qt@no{(160)}}
\qt@newcmd\qurantrans@lt@cdliv{Wam\q@u{a} k\q@u{a}na linabiyyin an yaghulla waman yaghlul yati bim\q@u{a} ghalla yawma alqiy\q@u{a}mati thumma tuwaff\q@u{a} kullu nafsin m\q@u{a} kasabat wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(161)}}
\qt@newcmd\qurantrans@lt@cdlv{Afamani ittabaAAa ri\q@u{d}w\q@u{a}na All\q@u{a}hi kaman b\q@u{a}a bisakha\q@u{t}in mina All\q@u{a}hi wamaw\q@u{a}hu jahannamu wabisa alma\q@u{s}eer\q@b{u}\qt@no{(162)}}
\qt@newcmd\qurantrans@lt@cdlvi{Hum daraj\q@u{a}tun AAinda All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu ba\q@u{s}eerun bim\q@u{a} yaAAmaloon\q@b{a}\qt@no{(163)}}
\qt@newcmd\qurantrans@lt@cdlvii{Laqad manna All\q@u{a}hu AAal\q@u{a} almumineena i\q@u{th} baAAatha feehim rasoolan min anfusihim yatloo AAalayhim \q@u{a}y\q@u{a}tihi wayuzakkeehim wayuAAallimuhumu alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ikmata wain k\q@u{a}noo min qablu lafee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(164)}}
\qt@newcmd\qurantrans@lt@cdlviii{Awalamm\q@u{a} a\q@u{sa}batkum mu\q@u{s}eebatun qad a\q@u{s}abtum mithlayh\q@u{a} qultum ann\q@u{a} h\q@u{atha} qul huwa min AAindi anfusikum inna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(165)}}
\qt@newcmd\qurantrans@lt@cdlix{Wam\q@u{a} a\q@u{sa}bakum yawma iltaq\q@u{a} aljamAA\q@u{a}ni fabii\q@u{th}ni All\q@u{a}hi waliyaAAlama almumineen\q@b{a}\qt@no{(166)}}
\qt@newcmd\qurantrans@lt@cdlx{WaliyaAAlama alla\q@u{th}eena n\q@u{a}faqoo waqeela lahum taAA\q@u{a}law q\q@u{a}tiloo fee sabeeli All\q@u{a}hi awi idfaAAoo q\q@u{a}loo law naAAlamu qit\q@u{a}lan la\q@b{i}ttabaAAn\q@u{a}kum hum lilkufri yawmai\q@u{th}in aqrabu minhum lileem\q@u{a}ni yaqooloona biafw\q@u{a}hihim m\q@u{a} laysa fee quloobihim wa\q@b{A}ll\q@u{a}hu aAAlamu bim\q@u{a} yaktumoon\q@b{a}\qt@no{(167)}}
\qt@newcmd\qurantrans@lt@cdlxi{Alla\q@u{th}eena q\q@u{a}loo liikhw\q@u{a}nihim waqaAAadoo law a\q@u{ta}AAoon\q@u{a} m\q@u{a} qutiloo qul fa\q@b{i}draoo AAan anfusikumu almawta in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(168)}}
\qt@newcmd\qurantrans@lt@cdlxii{Wal\q@u{a} ta\q@u{h}sabanna alla\q@u{th}eena qutiloo fee sabeeli All\q@u{a}hi amw\q@u{a}tan bal a\q@u{h}y\q@u{a}on AAinda rabbihim yurzaqoon\q@b{a}\qt@no{(169)}}
\qt@newcmd\qurantrans@lt@cdlxiii{Fari\q@u{h}eena bim\q@u{a} \q@u{a}t\q@u{a}humu All\q@u{a}hu min fa\q@u{d}lihi wayastabshiroona bi\q@b{a}lla\q@u{th}eena lam yal\q@u{h}aqoo bihim min khalfihim all\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(170)}}
\qt@newcmd\qurantrans@lt@cdlxiv{Yastabshiroona biniAAmatin mina All\q@u{a}hi wafa\q@u{d}lin waanna All\q@u{a}ha l\q@u{a} yu\q@u{d}eeAAu ajra almumineen\q@b{a}\qt@no{(171)}}
\qt@newcmd\qurantrans@lt@cdlxv{Alla\q@u{th}eena istaj\q@u{a}boo lill\q@u{a}hi wa\q@b{al}rrasooli min baAAdi m\q@u{a} a\q@u{sa}bahumu alqar\q@u{h}u lilla\q@u{th}eena a\q@u{h}sanoo minhum wa\q@b{i}ttaqaw ajrun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(172)}}
\qt@newcmd\qurantrans@lt@cdlxvi{Alla\q@u{th}eena q\q@u{a}la lahumu a\q@b{l}nn\q@u{a}su inna a\q@b{l}nn\q@u{a}sa qad jamaAAoo lakum fa\q@b{i}khshawhum faz\q@u{a}dahum eem\q@u{a}nan waq\q@u{a}loo \q@u{h}asbun\q@u{a} All\q@u{a}hu waniAAma alwakeel\q@b{u}\qt@no{(173)}}
\qt@newcmd\qurantrans@lt@cdlxvii{Fa\q@b{i}nqalaboo biniAAmatin mina All\q@u{a}hi wafa\q@u{d}lin lam yamsashum sooon wa\q@b{i}ttabaAAoo ri\q@u{d}w\q@u{a}na All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu \q@u{th}oo fa\q@u{d}lin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(174)}}
\qt@newcmd\qurantrans@lt@cdlxviii{Innam\q@u{a} \q@u{tha}likumu a\q@b{l}shshay\q@u{ta}nu yukhawwifu awliy\q@u{a}ahu fal\q@u{a} takh\q@u{a}foohum wakh\q@u{a}fooni in kuntum mumineen\q@b{a}\qt@no{(175)}}
\qt@newcmd\qurantrans@lt@cdlxix{Wal\q@u{a} ya\q@u{h}zunka alla\q@u{th}eena yus\q@u{a}riAAoona fee alkufri innahum lan ya\q@u{d}urroo All\q@u{a}ha shayan yureedu All\q@u{a}hu all\q@u{a} yajAAala lahum \q@u{h}a\q@i{\q@u{thth}}an fee al\q@u{a}khirati walahum AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(176)}}
\qt@newcmd\qurantrans@lt@cdlxx{Inna alla\q@u{th}eena ishtarawoo alkufra bi\q@b{a}leem\q@u{a}ni lan ya\q@u{d}urroo All\q@u{a}ha shayan walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(177)}}
\qt@newcmd\qurantrans@lt@cdlxxi{Wal\q@u{a} ya\q@u{h}sabanna alla\q@u{th}eena kafaroo annam\q@u{a} numlee lahum khayrun lianfusihim innam\q@u{a} numlee lahum liyazd\q@u{a}doo ithman walahum AAa\q@u{tha}bun muheen\q@b{un}\qt@no{(178)}}
\qt@newcmd\qurantrans@lt@cdlxxii{M\q@u{a} k\q@u{a}na All\q@u{a}hu liya\q@u{th}ara almumineena AAal\q@u{a} m\q@u{a} antum AAalayhi \q@u{h}att\q@u{a} yameeza alkhabeetha mina a\q@b{l}\q@u{tt}ayyibi wam\q@u{a} k\q@u{a}na All\q@u{a}hu liyu\q@u{t}liAAakum AAal\q@u{a} alghaybi wal\q@u{a}kinna All\q@u{a}ha yajtabee min rusulihi man yash\q@u{a}o fa\q@u{a}minoo bi\q@b{A}ll\q@u{a}hi warusulihi wain tuminoo watattaqoo falakum ajrun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(179)}}
\qt@newcmd\qurantrans@lt@cdlxxiii{Wal\q@u{a} ya\q@u{h}sabanna alla\q@u{th}eena yabkhaloona bim\q@u{a} \q@u{a}t\q@u{a}hummu All\q@u{a}hu min fa\q@u{d}lihi huwa khayran lahum bal huwa sharrun lahum sayu\q@u{t}awwaqoona m\q@u{a} bakhiloo bihi yawma alqiy\q@u{a}mati walill\q@u{a}hi meer\q@u{a}thu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona khabeer\q@b{un}\qt@no{(180)}}
\qt@newcmd\qurantrans@lt@cdlxxiv{Laqad samiAAa All\q@u{a}hu qawla alla\q@u{th}eena q\q@u{a}loo inna All\q@u{a}ha faqeerun wana\q@u{h}nu aghniy\q@u{a}on sanaktubu m\q@u{a} q\q@u{a}loo waqatlahumu alanbiy\q@u{a}a bighayri \q@u{h}aqqin wanaqoolu \q@u{th}ooqoo AAa\q@u{tha}ba al\q@u{h}areeq\q@b{i}\qt@no{(181)}}
\qt@newcmd\qurantrans@lt@cdlxxv{\q@u{Tha}lika bim\q@u{a} qaddamat aydeekum waanna All\q@u{a}ha laysa bi\q@i{\q@u{th}}all\q@u{a}min lilAAabeed\q@b{i}\qt@no{(182)}}
\qt@newcmd\qurantrans@lt@cdlxxvi{Alla\q@u{th}eena q\q@u{a}loo inna All\q@u{a}ha AAahida ilayn\q@u{a} all\q@u{a} numina lirasoolin \q@u{h}att\q@u{a} yatiyan\q@u{a} biqurb\q@u{a}nin takuluhu a\q@b{l}nn\q@u{a}ru qul qad j\q@u{a}akum rusulun min qablee bi\q@b{a}lbayyin\q@u{a}ti wabi\q@b{a}lla\q@u{th}ee qultum falima qataltumoohum in kutum \q@u{sa}diqeen\q@b{a}\qt@no{(183)}}
\qt@newcmd\qurantrans@lt@cdlxxvii{Fain ka\q@u{thth}abooka faqad ku\q@u{thth}iba rusulun min qablika j\q@u{a}oo bi\q@b{a}lbayyin\q@u{a}ti wa\q@b{al}zzuburi wa\q@b{a}lkit\q@u{a}bi almuneer\q@b{i}\qt@no{(184)}}
\qt@newcmd\qurantrans@lt@cdlxxviii{Kullu nafsin \q@u{tha}iqatu almawti wainnam\q@u{a} tuwaffawna ojoorakum yawma alqiy\q@u{a}mati faman zu\q@u{h}zi\q@u{h}a AAani a\q@b{l}nn\q@u{a}ri waodkhila aljannata faqad f\q@u{a}za wam\q@u{a} al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} ill\q@u{a} mat\q@u{a}AAu alghuroor\q@b{i}\qt@no{(185)}}
\qt@newcmd\qurantrans@lt@cdlxxix{Latublawunna fee amw\q@u{a}likum waanfusikum walatasmaAAunna mina alla\q@u{th}eena ootoo alkit\q@u{a}ba min qablikum wamina alla\q@u{th}eena ashrakoo a\q@u{th}an katheeran wain ta\q@u{s}biroo watattaqoo fainna \q@u{tha}lika min AAazmi alomoor\q@b{i}\qt@no{(186)}}
\qt@newcmd\qurantrans@lt@cdlxxx{Wai\q@u{th} akha\q@u{th}a All\q@u{a}hu meeth\q@u{a}qa alla\q@u{th}eena ootoo alkit\q@u{a}ba latubayyinunnahu li\q@b{l}nn\q@u{a}si wal\q@u{a} taktumoonahu fanaba\q@u{th}oohu war\q@u{a}a \q@i{\q@u{th}}uhoorihim wa\q@b{i}shtaraw bihi thamanan qaleelan fabisa m\q@u{a} yashtaroon\q@b{a}\qt@no{(187)}}
\qt@newcmd\qurantrans@lt@cdlxxxi{L\q@u{a} ta\q@u{h}sabanna alla\q@u{th}eena yafra\q@u{h}oona bim\q@u{a} ataw wayu\q@u{h}ibboona an yu\q@u{h}madoo bim\q@u{a} lam yafAAaloo fal\q@u{a} ta\q@u{h}sabannahum bimaf\q@u{a}zatin mina alAAa\q@u{tha}bi walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(188)}}
\qt@newcmd\qurantrans@lt@cdlxxxii{Walill\q@u{a}hi mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(189)}}
\qt@newcmd\qurantrans@lt@cdlxxxiii{Inna fee khalqi a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{i}khtil\q@u{a}fi allayli wa\q@b{al}nnah\q@u{a}ri la\q@u{a}y\q@u{a}tin liolee alalb\q@u{a}b\q@b{i}\qt@no{(190)}}
\qt@newcmd\qurantrans@lt@cdlxxxiv{Alla\q@u{th}eena ya\q@u{th}kuroona All\q@u{a}ha qiy\q@u{a}man waquAAoodan waAAal\q@u{a} junoobihim wayatafakkaroona fee khalqi a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i rabban\q@u{a} m\q@u{a} khalaqta h\q@u{atha} b\q@u{at}ilan sub\q@u{ha}naka faqin\q@u{a} AAa\q@u{tha}ba a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(191)}}
\qt@newcmd\qurantrans@lt@cdlxxxv{Rabban\q@u{a} innaka man tudkhili a\q@b{l}nn\q@u{a}ra faqad akhzaytahu wam\q@u{a} li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena min an\q@u{sa}r\q@b{in}\qt@no{(192)}}
\qt@newcmd\qurantrans@lt@cdlxxxvi{Rabban\q@u{a} innan\q@u{a} samiAAn\q@u{a} mun\q@u{a}diyan yun\q@u{a}dee lileem\q@u{a}ni an \q@u{a}minoo birabbikum fa\q@u{a}mann\q@u{a} rabban\q@u{a} fa\q@b{i}ghfir lan\q@u{a} \q@u{th}unooban\q@u{a} wakaffir AAann\q@u{a} sayyi\q@u{a}tin\q@u{a} watawaffan\q@u{a} maAAa alabr\q@u{a}r\q@b{i}\qt@no{(193)}}
\qt@newcmd\qurantrans@lt@cdlxxxvii{Rabban\q@u{a} wa\q@u{a}tin\q@u{a} m\q@u{a} waAAadtan\q@u{a} AAal\q@u{a} rusulika wal\q@u{a} tukhzin\q@u{a} yawma alqiy\q@u{a}mati innaka l\q@u{a} tukhlifu almeeAA\q@u{a}d\q@b{a}\qt@no{(194)}}
\qt@newcmd\qurantrans@lt@cdlxxxviii{Fa\q@b{i}staj\q@u{a}ba lahum rabbuhum annee l\q@u{a} o\q@u{d}eeAAu AAamala AA\q@u{a}milin minkum min \q@u{th}akarin aw onth\q@u{a} baAA\q@u{d}ukum min baAA\q@u{d}in fa\q@b{a}lla\q@u{th}eena h\q@u{a}jaroo waokhrijoo min diy\q@u{a}rihim waoo\q@u{th}oo fee sabeelee waq\q@u{a}taloo waqutiloo laokaffiranna AAanhum sayyi\q@u{a}tihim walaodkhilannahum jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru thaw\q@u{a}ban min AAindi All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu AAindahu \q@u{h}usnu a\q@b{l}ththaw\q@u{a}b\q@b{i}\qt@no{(195)}}
\qt@newcmd\qurantrans@lt@cdlxxxix{L\q@u{a} yaghurrannaka taqallubu alla\q@u{th}eena kafaroo fee albil\q@u{a}d\q@b{i}\qt@no{(196)}}
\qt@newcmd\qurantrans@lt@cdxc{Mat\q@u{a}AAun qaleelun thumma maw\q@u{a}hum jahannamu wabisa almih\q@u{a}d\q@b{u}\qt@no{(197)}}
\qt@newcmd\qurantrans@lt@cdxci{L\q@u{a}kini alla\q@u{th}eena ittaqaw rabbahum lahum jann\q@u{a}tun tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} nuzulan min AAindi All\q@u{a}hi wam\q@u{a} AAinda All\q@u{a}hi khayrun lilabr\q@u{a}r\q@b{i}\qt@no{(198)}}
\qt@newcmd\qurantrans@lt@cdxcii{Wainna min ahli alkit\q@u{a}bi laman yuminu bi\q@b{A}ll\q@u{a}hi wam\q@u{a} onzila ilaykum wam\q@u{a} onzila ilayhim kh\q@u{a}shiAAeena lill\q@u{a}hi l\q@u{a} yashtaroona bi\q@u{a}y\q@u{a}ti All\q@u{a}hi thamanan qaleelan ol\q@u{a}ika lahum ajruhum AAinda rabbihim inna All\q@u{a}ha sareeAAu al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(199)}}
\qt@newcmd\qurantrans@lt@cdxciii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{s}biroo wa\q@u{sa}biroo war\q@u{a}bi\q@u{t}oo wa\q@b{i}ttaqoo All\q@u{a}ha laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(200)}}
\qt@newcmd\qurantrans@lt@cdxciv{\basmalahlt Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su ittaqoo rabbakumu alla\q@u{th}ee khalaqakum min nafsin w\q@u{ah}idatin wakhalaqa minh\q@u{a} zawjah\q@u{a} wabaththa minhum\q@u{a} rij\q@u{a}lan katheeran wanis\q@u{a}an wa\q@b{i}ttaqoo All\q@u{a}ha alla\q@u{th}ee tas\q@u{a}aloona bihi wa\q@b{a}lar\q@u{ha}ma inna All\q@u{a}ha k\q@u{a}na AAalaykum raqeeb\q@b{an}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@cdxcv{Wa\q@u{a}too alyat\q@u{a}m\q@u{a} amw\q@u{a}lahum wal\q@u{a} tatabaddaloo alkhabeetha bi\q@b{al}\q@u{tt}ayyibi wal\q@u{a} takuloo amw\q@u{a}lahum il\q@u{a} amw\q@u{a}likum innahu k\q@u{a}na \q@u{h}ooban kabeer\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@cdxcvi{Wain khiftum all\q@u{a} tuqsi\q@u{t}oo fee alyat\q@u{a}m\q@u{a} fa\q@b{i}nki\q@u{h}oo m\q@u{a} \q@u{ta}ba lakum mina a\q@b{l}nnis\q@u{a}i mathn\q@u{a} wathul\q@u{a}tha warub\q@u{a}AAa fain khiftum all\q@u{a} taAAdiloo faw\q@u{ah}idatan aw m\q@u{a} malakat aym\q@u{a}nukum \q@u{tha}lika adn\q@u{a} all\q@u{a} taAAooloo\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@cdxcvii{Wa\q@u{a}too a\q@b{l}nnis\q@u{a}a \q@u{s}aduq\q@u{a}tihinna ni\q@u{h}latan fain \q@u{t}ibna lakum AAan shayin minhu nafsan fakuloohu haneean maree\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@cdxcviii{Wal\q@u{a} tutoo a\q@b{l}ssufah\q@u{a}a amw\q@u{a}lakumu allatee jaAAala All\q@u{a}hu lakum qiy\q@u{a}man wa\q@b{o}rzuqoohum feeh\q@u{a} wa\q@b{o}ksoohum waqooloo lahum qawlan maAAroof\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@cdxcix{Wa\q@b{i}btaloo alyat\q@u{a}m\q@u{a} \q@u{h}att\q@u{a} i\q@u{tha} balaghoo a\q@b{l}nnik\q@u{ah}a fain \q@u{a}nastum minhum rushdan fa\q@b{i}dfaAAoo ilayhim amw\q@u{a}lahum wal\q@u{a} takulooh\q@u{a} isr\q@u{a}fan wabid\q@u{a}ran an yakbaroo waman k\q@u{a}na ghaniyyan falyastaAAfif waman k\q@u{a}na faqeeran falyakul bi\q@b{a}lmaAAroofi fai\q@u{tha} dafaAAtum ilayhim amw\q@u{a}lahum faashhidoo AAalayhim wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi \q@u{h}aseeb\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@d{Li\q@b{l}rrij\q@u{a}li na\q@u{s}eebun mimm\q@u{a} taraka alw\q@u{a}lid\q@u{a}ni wa\q@b{a}laqraboona wali\q@b{l}nnis\q@u{a}i na\q@u{s}eebun mimm\q@u{a} taraka alw\q@u{a}lid\q@u{a}ni wa\q@b{a}laqraboona mimm\q@u{a} qalla minhu aw kathura na\q@u{s}eeban mafroo\q@u{da}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@di{Wai\q@u{tha} \q@u{h}a\q@u{d}ara alqismata oloo alqurb\q@u{a} wa\q@b{a}lyat\q@u{a}m\q@u{a} wa\q@b{a}lmas\q@u{a}keenu fa\q@b{o}rzuqoohum minhu waqooloo lahum qawlan maAAroof\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@dii{Walyakhsha alla\q@u{th}eena law tarakoo min khalfihim \q@u{th}urriyyatan \q@u{d}iAA\q@u{a}fan kh\q@u{a}foo AAalayhim falyattaqoo All\q@u{a}ha walyaqooloo qawlan sadeed\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@diii{Inna alla\q@u{th}eena yakuloona amw\q@u{a}la alyat\q@u{a}m\q@u{a} \q@i{\q@u{th}}ulman innam\q@u{a} yakuloona fee bu\q@u{t}oonihim n\q@u{a}ran wasaya\q@u{s}lawna saAAeer\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@div{Yoo\q@u{s}eekumu All\q@u{a}hu fee awl\q@u{a}dikum li\q@b{l}\q@u{thth}akari mithlu \q@u{h}a\q@i{\q@u{thth}}i alonthayayni fain kunna nis\q@u{a}an fawqa ithnatayni falahunna thuluth\q@u{a} m\q@u{a} taraka wain k\q@u{a}nat w\q@u{ah}idatan falah\q@u{a} a\q@b{l}nni\q@u{s}fu waliabawayhi likulli w\q@u{ah}idin minhum\q@u{a} a\q@b{l}ssudusu mimm\q@u{a} taraka in k\q@u{a}na lahu waladun fain lam yakun lahu waladun wawarithahu abaw\q@u{a}hu faliommihi a\q@b{l}ththuluthu fain k\q@u{a}na lahu ikhwatun faliommihi a\q@b{l}ssudusu min baAAdi wa\q@u{s}iyyatin yoo\q@u{s}ee bih\q@u{a} aw daynin \q@u{a}b\q@u{a}okum waabn\q@u{a}okum l\q@u{a} tadroona ayyuhum aqrabu lakum nafAAan faree\q@u{d}atan mina All\q@u{a}hi inna All\q@u{a}ha k\q@u{a}na AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@dv{Walakum ni\q@u{s}fu m\q@u{a} taraka azw\q@u{a}jukum in lam yakun lahunna waladun fain k\q@u{a}na lahunna waladun falakumu a\q@b{l}rrubuAAu mimm\q@u{a} tarakna min baAAdi wa\q@u{s}iyyatin yoo\q@u{s}eena bih\q@u{a} aw daynin walahunna a\q@b{l}rrubuAAu mimm\q@u{a} taraktum in lam yakun lakum waladun fain k\q@u{a}na lakum waladun falahunna a\q@b{l}ththumunu mimm\q@u{a} taraktum min baAAdi wa\q@u{s}iyyatin too\q@u{s}oona bih\q@u{a} aw daynin wain k\q@u{a}na rajulun yoorathu kal\q@u{a}latan awi imraatun walahu akhun aw okhtun falikulli w\q@u{ah}idin minhum\q@u{a} a\q@b{l}ssudusu fain k\q@u{a}noo akthara min \q@u{tha}lika fahum shurak\q@u{a}o fee a\q@b{l}ththuluthi min baAAdi wa\q@u{s}iyyatin yoo\q@u{sa} bih\q@u{a} aw daynin ghayra mu\q@u{da}rrin wa\q@u{s}iyyatan mina All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}aleem\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@dvi{Tilka \q@u{h}udoodu All\q@u{a}hi waman yu\q@u{t}iAAi All\q@u{a}ha warasoolahu yudkhilhu jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} wa\q@u{tha}lika alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@dvii{Waman yaAA\q@u{s}i All\q@u{a}ha warasoolahu wayataAAadda \q@u{h}udoodahu yudkhilhu n\q@u{a}ran kh\q@u{a}lidan feeh\q@u{a} walahu AAa\q@u{tha}bun muheen\q@b{un}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@dviii{Wa\q@b{a}ll\q@u{a}tee yateena alf\q@u{ah}ishata min nis\q@u{a}ikum fa\q@b{i}stashhidoo AAalayhinna arbaAAatan minkum fain shahidoo faamsikoohunna fee albuyooti \q@u{h}att\q@u{a} yatawaff\q@u{a}hunna almawtu aw yajAAala All\q@u{a}hu lahunna sabeel\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@dix{Wa\q@b{a}lla\q@u{tha}ni yatiy\q@u{a}nih\q@u{a} minkum fa\q@u{ath}oohum\q@u{a} fain t\q@u{a}b\q@u{a} waa\q@u{s}la\q@u{ha} faaAAri\q@u{d}oo AAanhum\q@u{a} inna All\q@u{a}ha k\q@u{a}na taww\q@u{a}ban ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@dx{Innam\q@u{a} a\q@b{l}ttawbatu AAal\q@u{a} All\q@u{a}hi lilla\q@u{th}eena yaAAmaloona a\q@b{l}ssooa bijah\q@u{a}latin thumma yatooboona min qareebin faol\q@u{a}ika yatoobu All\q@u{a}hu AAalayhim wak\q@u{a}na All\q@u{a}hu AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@dxi{Walaysati a\q@b{l}ttawbatu lilla\q@u{th}eena yaAAmaloona a\q@b{l}ssayyi\q@u{a}ti \q@u{h}att\q@u{a} i\q@u{tha} \q@u{h}a\q@u{d}ara a\q@u{h}adahumu almawtu q\q@u{a}la innee tubtu al\q@u{a}na wal\q@u{a} alla\q@u{th}eena yamootoona wahum kuff\q@u{a}run ol\q@u{a}ika aAAtadn\q@u{a} lahum AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@dxii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} ya\q@u{h}illu lakum an tarithoo a\q@b{l}nnis\q@u{a}a karhan wal\q@u{a} taAA\q@u{d}uloohunna lita\q@u{th}haboo bibaAA\q@u{d}i m\q@u{a} \q@u{a}taytumoohunna ill\q@u{a} an yateena bif\q@u{ah}ishatin mubayyinatin waAA\q@u{a}shiroohunna bi\q@b{a}lmaAAroofi fain karihtumoohunna faAAas\q@u{a} an takrahoo shayan wayajAAala All\q@u{a}hu feehi khayran katheer\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@dxiii{Wain aradtumu istibd\q@u{a}la zawjin mak\q@u{a}na zawjin wa\q@u{a}taytum i\q@u{h}d\q@u{a}hunna qin\q@u{ta}ran fal\q@u{a} takhu\q@u{th}oo minhu shayan atakhu\q@u{th}oonahu buht\q@u{a}nan waithman mubeen\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@dxiv{Wakayfa takhu\q@u{th}oonahu waqad af\q@u{da} baAA\q@u{d}ukum il\q@u{a} baAA\q@u{d}in waakha\q@u{th}na minkum meeth\q@u{a}qan ghalee\q@i{\q@u{th}}\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@dxv{Wal\q@u{a} tanki\q@u{h}oo m\q@u{a} naka\q@u{h}a \q@u{a}b\q@u{a}okum mina a\q@b{l}nnis\q@u{a}i ill\q@u{a} m\q@u{a} qad salafa innahu k\q@u{a}na f\q@u{ah}ishatan wamaqtan was\q@u{a}a sabeel\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@dxvi{\q@u{H}urrimat AAalaykum ommah\q@u{a}tukum waban\q@u{a}tukum waakhaw\q@u{a}tukum waAAamm\q@u{a}tukum wakh\q@u{a}l\q@u{a}tukum waban\q@u{a}tu alakhi waban\q@u{a}tu alokhti waommah\q@u{a}tukumu all\q@u{a}tee ar\q@u{d}aAAnakum waakhaw\q@u{a}tukum mina a\q@b{l}rra\q@u{da}AAati waommah\q@u{a}tu nis\q@u{a}ikum warab\q@u{a}ibukumu all\q@u{a}tee fee \q@u{h}ujoorikum min nis\q@u{a}ikumu all\q@u{a}tee dakhaltum bihinna fain lam takoonoo dakhaltum bihinna fal\q@u{a} jun\q@u{ah}a AAalaykum wa\q@u{h}al\q@u{a}ilu abn\q@u{a}ikumu alla\q@u{th}eena min a\q@u{s}l\q@u{a}bikum waan tajmaAAoo bayna alokhtayni ill\q@u{a} m\q@u{a} qad salafa inna All\q@u{a}ha k\q@u{a}na ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@dxvii{Wa\q@b{a}lmu\q@u{hs}an\q@u{a}tu mina a\q@b{l}nnis\q@u{a}i ill\q@u{a} m\q@u{a} malakat aym\q@u{a}nukum kit\q@u{a}ba All\q@u{a}hi AAalaykum wao\q@u{h}illa lakum m\q@u{a} war\q@u{a}a \q@u{tha}likum an tabtaghoo biamw\q@u{a}likum mu\q@u{hs}ineena ghayra mus\q@u{a}fi\q@u{h}eena fam\q@u{a} istamtaAAtum bihi minhunna fa\q@u{a}toohunna ojoorahunna faree\q@u{d}atan wal\q@u{a} jun\q@u{ah}a AAalaykum feem\q@u{a} tar\q@u{ad}aytum bihi min baAAdi alfaree\q@u{d}ati inna All\q@u{a}ha k\q@u{a}na AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@dxviii{Waman lam yasta\q@u{t}iAA minkum \q@u{t}awlan an yanki\q@u{h}a almu\q@u{hs}an\q@u{a}ti almumin\q@u{a}ti famin m\q@u{a} malakat aym\q@u{a}nukum min fatay\q@u{a}tikumu almumin\q@u{a}ti wa\q@b{A}ll\q@u{a}hu aAAlamu bieem\q@u{a}nikum baAA\q@u{d}ukum min baAA\q@u{d}in fa\q@b{i}nki\q@u{h}oohunna bii\q@u{th}ni ahlihinna wa\q@u{a}toohunna ojoorahunna bi\q@b{a}lmaAAroofi mu\q@u{hs}an\q@u{a}tin ghayra mas\q@u{a}fi\q@u{ha}tin wal\q@u{a} muttakhi\q@u{tha}ti akhd\q@u{a}nin fai\q@u{tha} o\q@u{hs}inna fain atayna bif\q@u{ah}ishatin faAAalayhinna ni\q@u{s}fu m\q@u{a} AAal\q@u{a} almu\q@u{hs}an\q@u{a}ti mina alAAa\q@u{tha}bi \q@u{tha}lika liman khashiya alAAanata minkum waan ta\q@u{s}biroo khayrun lakum wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@dxix{Yureedu All\q@u{a}hu liyubayyina lakum wayahdiyakum sunana alla\q@u{th}eena min qablikum wayatooba AAalaykum wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@dxx{Wa\q@b{A}ll\q@u{a}hu yureedu an yatooba AAalaykum wayureedu alla\q@u{th}eena yattabiAAoona a\q@b{l}shshahaw\q@u{a}ti an tameeloo maylan AAa\q@i{\q@u{th}}eem\q@b{an}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@dxxi{Yureedu All\q@u{a}hu an yukhaffifa AAankum wakhuliqa alins\q@u{a}nu \q@u{d}aAAeef\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@dxxii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} takuloo amw\q@u{a}lakum baynakum bi\q@b{a}lb\q@u{at}ili ill\q@u{a} an takoona tij\q@u{a}ratan AAan tar\q@u{ad}in minkum wal\q@u{a} taqtuloo anfusakum inna All\q@u{a}ha k\q@u{a}na bikum ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@dxxiii{Waman yafAAal \q@u{tha}lika AAudw\q@u{a}nan wa\q@i{\q@u{th}}ulman fasawfa nu\q@u{s}leehi n\q@u{a}ran wak\q@u{a}na \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi yaseer\q@u{a}\q@b{n}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@dxxiv{In tajtaniboo kab\q@u{a}ira m\q@u{a} tunhawna AAanhu nukaffir AAankum sayyi\q@u{a}tikum wanudkhilkum mudkhalan kareem\q@u{a}\q@b{n}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@dxxv{Wal\q@u{a} tatamannaw m\q@u{a} fa\q@u{dd}ala All\q@u{a}hu bihi baAA\q@u{d}akum AAal\q@u{a} baAA\q@u{d}in li\q@b{l}rrij\q@u{a}li na\q@u{s}eebun mimm\q@u{a} iktasaboo wali\q@b{l}nnis\q@u{a}i na\q@u{s}eebun mimm\q@u{a} iktasabna wa\q@b{i}saloo All\q@u{a}ha min fa\q@u{d}lihi inna All\q@u{a}ha k\q@u{a}na bikulli shayin AAaleem\q@u{a}\q@b{n}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@dxxvi{Walikullin jaAAaln\q@u{a} maw\q@u{a}liya mimm\q@u{a} taraka alw\q@u{a}lid\q@u{a}ni wa\q@b{a}laqraboona wa\q@b{a}lla\q@u{th}eena AAaqadat aym\q@u{a}nukum fa\q@u{a}toohum na\q@u{s}eebahum inna All\q@u{a}ha k\q@u{a}na AAal\q@u{a} kulli shayin shaheed\q@u{a}\q@b{n}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@dxxvii{A\q@b{l}rrij\q@u{a}lu qaww\q@u{a}moona AAal\q@u{a} a\q@b{l}nnis\q@u{a}i bim\q@u{a} fa\q@u{dd}ala All\q@u{a}hu baAA\q@u{d}ahum AAal\q@u{a} baAA\q@u{d}in wabim\q@u{a} anfaqoo min amw\q@u{a}lihim fa\q@b{al}\q@u{ssa}li\q@u{ha}tu q\q@u{a}nit\q@u{a}tun \q@u{ha}fi\q@i{\q@u{th}}\q@u{a}tun lilghaybi bim\q@u{a} \q@u{h}afi\q@i{\q@u{th}}a All\q@u{a}hu wa\q@b{a}ll\q@u{a}tee takh\q@u{a}foona nushoozahunna faAAi\q@i{\q@u{th}}oohunna wa\q@b{o}hjuroohunna fee alma\q@u{da}jiAAi wa\q@b{i}\q@u{d}riboohunna fain a\q@u{t}aAAnakum fal\q@u{a} tabghoo AAalayhinna sabeelan inna All\q@u{a}ha k\q@u{a}na AAaliyyan kabeer\q@u{a}\q@b{n}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@dxxviii{Wain khiftum shiq\q@u{a}qa baynihim\q@u{a} fa\q@b{i}bAAathoo \q@u{h}akaman min ahlihi wa\q@u{h}akaman min ahlih\q@u{a} in yureed\q@u{a} i\q@u{s}l\q@u{ah}an yuwaffiqi All\q@u{a}hu baynahum\q@u{a} inna All\q@u{a}ha k\q@u{a}na AAaleeman khabeer\q@u{a}\q@b{n}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@dxxix{Wa\q@b{o}AAbudoo All\q@u{a}ha wal\q@u{a} tushrikoo bihi shayan wabi\q@b{a}lw\q@u{a}lidayni i\q@u{h}s\q@u{a}nan wabi\q@u{th}ee alqurb\q@u{a} wa\q@b{a}lyat\q@u{a}m\q@u{a} wa\q@b{a}lmas\q@u{a}keeni wa\q@b{a}lj\q@u{a}ri \q@u{th}ee alqurb\q@u{a} wa\q@b{a}lj\q@u{a}ri aljunubi wa\q@b{al}\q@u{ssah}ibi bi\q@b{a}ljanbi wa\q@b{i}bni a\q@b{l}ssabeeli wam\q@u{a} malakat aym\q@u{a}nukum inna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu man k\q@u{a}na mukht\q@u{a}lan fakhoor\q@u{a}\q@b{n}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@dxxx{Alla\q@u{th}eena yabkhaloona wayamuroona a\q@b{l}nn\q@u{a}sa bi\q@b{a}lbukhli wayaktumoona m\q@u{a} \q@u{a}t\q@u{a}humu All\q@u{a}hu min fa\q@u{d}lihi waaAAtadn\q@u{a} lilk\q@u{a}fireena AAa\q@u{tha}ban muheen\q@u{a}\q@b{n}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@dxxxi{Wa\q@b{a}lla\q@u{th}eena yunfiqoona amw\q@u{a}lahum ri\q@u{a}a a\q@b{l}nn\q@u{a}si wal\q@u{a} yuminoona bi\q@b{A}ll\q@u{a}hi wal\q@u{a} bi\q@b{a}lyawmi al\q@u{a}khiri waman yakuni a\q@b{l}shshay\q@u{ta}nu lahu qareenan fas\q@u{a}a qareen\q@u{a}\q@b{n}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@dxxxii{Wam\q@u{atha} AAalayhim law \q@u{a}manoo bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri waanfaqoo mimm\q@u{a} razaqahumu All\q@u{a}hu wak\q@u{a}na All\q@u{a}hu bihim AAaleem\q@u{a}\q@b{n}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@dxxxiii{Inna All\q@u{a}ha l\q@u{a} ya\q@i{\q@u{th}}limu mithq\q@u{a}la \q@u{th}arratin wain taku \q@u{h}asanatan yu\q@u{da}AAifh\q@u{a} wayuti min ladunhu ajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@dxxxiv{Fakayfa i\q@u{tha} jin\q@u{a} min kulli ommatin bishaheedin wajin\q@u{a} bika AAal\q@u{a} h\q@u{a}ol\q@u{a}i shaheed\q@u{a}\q@b{n}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@dxxxv{Yawmai\q@u{th}in yawaddu alla\q@u{th}eena kafaroo waAAa\q@u{s}awoo a\q@b{l}rrasoola law tusaww\q@u{a} bihimu alar\q@u{d}u wal\q@u{a} yaktumoona All\q@u{a}ha \q@u{h}adeeth\q@u{a}\q@b{n}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@dxxxvi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} taqraboo a\q@b{l}\q@u{ss}al\q@u{a}ta waantum suk\q@u{a}r\q@u{a} \q@u{h}att\q@u{a} taAAlamoo m\q@u{a} taqooloona wal\q@u{a} junuban ill\q@u{a} AA\q@u{a}biree sabeelin \q@u{h}att\q@u{a} taghtasiloo wain kuntum mar\q@u{da} aw AAal\q@u{a} safarin aw j\q@u{a}a a\q@u{h}adun minkum mina algh\q@u{a}i\q@u{t}i aw l\q@u{a}mastumu a\q@b{l}nnis\q@u{a}a falam tajidoo m\q@u{a}an fatayammamoo \q@u{s}aAAeedan \q@u{t}ayyiban fa\q@b{i}msa\q@u{h}oo biwujoohikum waaydeekum inna All\q@u{a}ha k\q@u{a}na AAafuwwan ghafoor\q@u{a}\q@b{n}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@dxxxvii{Alam tara il\q@u{a} alla\q@u{th}eena ootoo na\q@u{s}eeban mina alkit\q@u{a}bi yashtaroona a\q@b{l}\q@u{dd}al\q@u{a}lata wayureedoona an ta\q@u{d}illoo a\q@b{l}ssabeel\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@dxxxviii{Wa\q@b{A}ll\q@u{a}hu aAAlamu biaAAd\q@u{a}ikum wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi waliyyan wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@dxxxix{Mina alla\q@u{th}eena h\q@u{a}doo yu\q@u{h}arrifoona alkalima AAan maw\q@u{ad}iAAihi wayaqooloona samiAAn\q@u{a} waAAa\q@u{s}ayn\q@u{a} wa\q@b{i}smaAA ghayra musmaAAin war\q@u{a}AAin\q@u{a} layyan bialsinatihim wa\q@u{t}aAAnan fee a\q@b{l}ddeeni walaw annahum q\q@u{a}loo samiAAn\q@u{a} waa\q@u{t}aAAn\q@u{a} wa\q@b{i}smaAA wa\q@b{o}n\q@i{\q@u{th}}urn\q@u{a} lak\q@u{a}na khayran lahum waaqwama wal\q@u{a}kin laAAanahumu All\q@u{a}hu bikufrihim fal\q@u{a} yuminoona ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@dxl{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena ootoo alkit\q@u{a}ba \q@u{a}minoo bim\q@u{a} nazzaln\q@u{a} mu\q@u{s}addiqan lim\q@u{a} maAAakum min qabli an na\q@u{t}misa wujoohan fanaruddah\q@u{a} AAal\q@u{a} adb\q@u{a}rih\q@u{a} aw nalAAanahum kam\q@u{a} laAAann\q@u{a} a\q@u{s}\q@u{ha}ba a\q@b{l}ssabti wak\q@u{a}na amru All\q@u{a}hi mafAAool\q@u{a}\q@b{n}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@dxli{Inna All\q@u{a}ha l\q@u{a} yaghfiru an yushraka bihi wayaghfiru m\q@u{a} doona \q@u{tha}lika liman yash\q@u{a}o waman yushrik bi\q@b{A}ll\q@u{a}hi faqadi iftar\q@u{a} ithman AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@dxlii{Alam tara il\q@u{a} alla\q@u{th}eena yuzakkoona anfusahum bali All\q@u{a}hu yuzakkee man yash\q@u{a}o wal\q@u{a} yu\q@i{\q@u{th}}lamoona fateel\q@u{a}\q@b{n}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@dxliii{On\q@i{\q@u{th}}ur kayfa yaftaroona AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba wakaf\q@u{a} bihi ithman mubeen\q@u{a}\q@b{n}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@dxliv{Alam tara il\q@u{a} alla\q@u{th}eena ootoo na\q@u{s}eeban mina alkit\q@u{a}bi yuminoona bi\q@b{a}ljibti wa\q@b{al}\q@u{tta}ghooti wayaqooloona lilla\q@u{th}eena kafaroo h\q@u{a}ol\q@u{a}i ahd\q@u{a} mina alla\q@u{th}eena \q@u{a}manoo sabeel\q@u{a}\q@b{n}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@dxlv{Ol\q@u{a}ika alla\q@u{th}eena laAAanahumu All\q@u{a}hu waman yalAAani All\q@u{a}hu falan tajida lahu na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@dxlvi{Am lahum na\q@u{s}eebun mina almulki fai\q@u{th}an l\q@u{a} yutoona a\q@b{l}nn\q@u{a}sa naqeer\q@u{a}\q@b{n}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@dxlvii{Am ya\q@u{h}sudoona a\q@b{l}nn\q@u{a}sa AAal\q@u{a} m\q@u{a} \q@u{a}t\q@u{a}humu All\q@u{a}hu min fa\q@u{d}lihi faqad \q@u{a}tayn\q@u{a} \q@u{a}la ibr\q@u{a}heema alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ikmata wa\q@u{a}tayn\q@u{a}hum mulkan AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@dxlviii{Faminhum man \q@u{a}mana bihi waminhum man \q@u{s}adda AAanhu wakaf\q@u{a} bijahannama saAAeer\q@u{a}\q@b{n}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@dxlix{Inna alla\q@u{th}eena kafaroo bi\q@u{a}y\q@u{a}tin\q@u{a} sawfa nu\q@u{s}leehim n\q@u{a}ran kullam\q@u{a} na\q@u{d}ijat julooduhum baddaln\q@u{a}hum juloodan ghayrah\q@u{a} liya\q@u{th}ooqoo alAAa\q@u{tha}ba inna All\q@u{a}ha k\q@u{a}na AAazeezan \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@dl{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti sanudkhiluhum jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} abadan lahum feeh\q@u{a} azw\q@u{a}jun mu\q@u{t}ahharatun wanudkhiluhum \q@i{\q@u{th}}illan \q@i{\q@u{th}}aleel\q@u{a}\q@b{n}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@dli{Inna All\q@u{a}ha yamurukum an tuaddoo alam\q@u{a}n\q@u{a}ti il\q@u{a} ahlih\q@u{a} wai\q@u{tha} \q@u{h}akamtum bayna a\q@b{l}nn\q@u{a}si an ta\q@u{h}kumoo bi\q@b{a}lAAadli inna All\q@u{a}ha niAAimm\q@u{a} yaAAi\q@i{\q@u{th}}ukum bihi inna All\q@u{a}ha k\q@u{a}na sameeAAan ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@dlii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo a\q@u{t}eeAAoo All\q@u{a}ha waa\q@u{t}eeAAoo a\q@b{l}rrasoola waolee alamri minkum fain tan\q@u{a}zaAAtum fee shayin faruddoohu il\q@u{a} All\q@u{a}hi wa\q@b{al}rrasooli in kuntum tuminoona bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri \q@u{tha}lika khayrun waa\q@u{h}sanu taweel\q@u{a}\q@b{n}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@dliii{Alam tara il\q@u{a} alla\q@u{th}eena yazAAumoona annahum \q@u{a}manoo bim\q@u{a} onzila ilayka wam\q@u{a} onzila min qablika yureedoona an yata\q@u{ha}kamoo il\q@u{a} a\q@b{l}\q@u{tta}ghooti waqad omiroo an yakfuroo bihi wayureedu a\q@b{l}shshay\q@u{ta}nu an yu\q@u{d}illahum \q@u{d}al\q@u{a}lan baAAeed\q@u{a}\q@b{n}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@dliv{Wai\q@u{tha} qeela lahum taAA\q@u{a}law il\q@u{a} m\q@u{a} anzala All\q@u{a}hu wail\q@u{a} a\q@b{l}rrasooli raayta almun\q@u{a}fiqeena ya\q@u{s}uddoona AAanka \q@u{s}udood\q@u{a}\q@b{n}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@dlv{Fakayfa i\q@u{tha} a\q@u{sa}bathum mu\q@u{s}eebatun bim\q@u{a} qaddamat aydeehim thumma j\q@u{a}ooka ya\q@u{h}lifoona bi\q@b{A}ll\q@u{a}hi in aradn\q@u{a} ill\q@u{a} i\q@u{h}s\q@u{a}nan watawfeeq\q@u{a}\q@b{n}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@dlvi{Ol\q@u{a}ika alla\q@u{th}eena yaAAlamu All\q@u{a}hu m\q@u{a} fee quloobihim faaAAri\q@u{d} AAanhum waAAi\q@i{\q@u{th}}hum waqul lahum fee anfusihim qawlan baleegh\q@u{a}\q@b{n}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@dlvii{Wam\q@u{a} arsaln\q@u{a} min rasoolin ill\q@u{a} liyu\q@u{ta}AAa bii\q@u{th}ni All\q@u{a}hi walaw annahum i\q@u{th} \q@i{\q@u{th}}alamoo anfusahum j\q@u{a}ooka fa\q@b{i}staghfaroo All\q@u{a}ha wa\q@b{i}staghfara lahumu a\q@b{l}rrasoolu lawajadoo All\q@u{a}ha taww\q@u{a}ban ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@dlviii{Fal\q@u{a} warabbika l\q@u{a} yuminoona \q@u{h}att\q@u{a} yu\q@u{h}akkimooka feem\q@u{a} shajara baynahum thumma l\q@u{a} yajidoo fee anfusihim \q@u{h}arajan mimm\q@u{a} qa\q@u{d}ayta wayusallimoo tasleem\q@u{a}\q@b{n}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@dlix{Walaw ann\q@u{a} katabn\q@u{a} AAalayhim ani oqtuloo anfusakum awi okhrujoo min diy\q@u{a}rikum m\q@u{a} faAAaloohu ill\q@u{a} qaleelun minhum walaw annahum faAAaloo m\q@u{a} yooAAa\q@i{\q@u{th}}oona bihi lak\q@u{a}na khayran lahum waashadda tathbeet\q@u{a}\q@b{n}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@dlx{Wai\q@u{th}an la\q@u{a}tayn\q@u{a}hum min ladunn\q@u{a} ajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@dlxi{Walahadayn\q@u{a}hum \q@u{s}ir\q@u{at}an mustaqeem\q@u{a}\q@b{n}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@dlxii{Waman yu\q@u{t}iAAi All\q@u{a}ha wa\q@b{al}rrasoola faol\q@u{a}ika maAAa alla\q@u{th}eena anAAama All\q@u{a}hu AAalayhim mina a\q@b{l}nnabiyyeena wa\q@b{al}\q@u{ss}iddeeqeena wa\q@b{al}shshuhad\q@u{a}i wa\q@b{al}\q@u{ssa}li\q@u{h}eena wa\q@u{h}asuna ol\q@u{a}ika rafeeq\q@u{a}\q@b{n}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@dlxiii{\q@u{Tha}lika alfa\q@u{d}lu mina All\q@u{a}hi wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi AAaleem\q@u{a}\q@b{n}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@dlxiv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo khu\q@u{th}oo \q@u{h}i\q@u{th}rakum fa\q@b{i}nfiroo thub\q@u{a}tin awi infiroo jameeAA\q@u{a}\q@b{n}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@dlxv{Wainna minkum laman layuba\q@u{tt}ianna fain a\q@u{sa}batkum mu\q@u{s}eebatun q\q@u{a}la qad anAAama All\q@u{a}hu AAalayya i\q@u{th} lam akun maAAahum shaheed\q@u{a}\q@b{n}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@dlxvi{Walain a\q@u{sa}bakum fa\q@u{d}lun mina All\q@u{a}hi layaqoolanna kaan lam takun baynakum wabaynahu mawaddatun y\q@u{a} laytanee kuntu maAAahum faafooza fawzan AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@dlxvii{Falyuq\q@u{a}til fee sabeeli All\q@u{a}hi alla\q@u{th}eena yashroona al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a} bi\q@b{a}l\q@u{a}khirati waman yuq\q@u{a}til fee sabeeli All\q@u{a}hi fayuqtal aw yaghlib fasawfa nuteehi ajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@dlxviii{Wam\q@u{a} lakum l\q@u{a} tuq\q@u{a}tiloona fee sabeeli All\q@u{a}hi wa\q@b{a}lmusta\q@u{d}AAafeena mina a\q@b{l}rrij\q@u{a}li wa\q@b{al}nnis\q@u{a}i wa\q@b{a}lwild\q@u{a}ni alla\q@u{th}eena yaqooloona rabban\q@u{a} akhrijn\q@u{a} min h\q@u{ath}ihi alqaryati a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limi ahluh\q@u{a} wa\q@b{i}jAAal lan\q@u{a} min ladunka waliyyan wa\q@b{i}jAAal lan\q@u{a} min ladunka na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@dlxix{Alla\q@u{th}eena \q@u{a}manoo yuq\q@u{a}tiloona fee sabeeli All\q@u{a}hi wa\q@b{a}lla\q@u{th}eena kafaroo yuq\q@u{a}tiloona fee sabeeli a\q@b{l}\q@u{tta}ghooti faq\q@u{a}tiloo awliy\q@u{a}a a\q@b{l}shshay\q@u{ta}ni inna kayda a\q@b{l}shshay\q@u{ta}ni k\q@u{a}na \q@u{d}aAAeef\q@u{a}\q@b{n}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@dlxx{Alam tara il\q@u{a} alla\q@u{th}eena qeela lahum kuffoo aydiyakum waaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}too a\q@b{l}zzak\q@u{a}ta falamm\q@u{a} kutiba AAalayhimu alqit\q@u{a}lu i\q@u{tha} fareequn minhum yakhshawna a\q@b{l}nn\q@u{a}sa kakhashyati All\q@u{a}hi aw ashadda khashyatan waq\q@u{a}loo rabban\q@u{a} lima katabta AAalayn\q@u{a} alqit\q@u{a}la lawl\q@u{a} akhkhartan\q@u{a} il\q@u{a} ajalin qareebin qul mat\q@u{a}AAu a\q@b{l}dduny\q@u{a} qaleelun wa\q@b{a}l\q@u{a}khiratu khayrun limani ittaq\q@u{a} wal\q@u{a} tu\q@i{\q@u{th}}lamoona fateel\q@u{a}\q@b{n}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@dlxxi{Aynam\q@u{a} takoonoo yudrikkumu almawtu walaw kuntum fee buroojin mushayyadatin wain tu\q@u{s}ibhum \q@u{h}asanatun yaqooloo h\q@u{ath}ihi min AAindi All\q@u{a}hi wain tu\q@u{s}ibhum sayyiatun yaqooloo h\q@u{ath}ihi min AAindika qul kullun min AAindi All\q@u{a}hi fam\q@u{a}li h\q@u{a}ol\q@u{a}i alqawmi l\q@u{a} yak\q@u{a}doona yafqahoona \q@u{h}adeeth\q@u{a}\q@b{n}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@dlxxii{M\q@u{a} a\q@u{sa}baka min \q@u{h}asanatin famina All\q@u{a}hi wam\q@u{a} a\q@u{sa}baka min sayyiatin famin nafsika waarsaln\q@u{a}ka li\q@b{l}nn\q@u{a}si rasoolan wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi shaheedan\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@dlxxiii{Man yu\q@u{t}iAAi a\q@b{l}rrasoola faqad a\q@u{ta}AAa All\q@u{a}ha waman tawall\q@u{a} fam\q@u{a} arsaln\q@u{a}ka AAalayhim \q@u{h}afee\q@i{\q@u{th}}\q@u{a}\q@b{n}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@dlxxiv{Wayaqooloona \q@u{ta}AAatun fai\q@u{tha} barazoo min AAindika bayyata \q@u{ta}ifatun minhum ghayra alla\q@u{th}ee taqoolu wa\q@b{A}ll\q@u{a}hu yaktubu m\q@u{a} yubayyitoona faaAAri\q@u{d} AAanhum watawakkal AAal\q@u{a} All\q@u{a}hi wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi wakeel\q@u{a}\q@b{n}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@dlxxv{Afal\q@u{a} yatadabbaroona alqur\q@u{a}na walaw k\q@u{a}na min AAindi ghayri All\q@u{a}hi lawajadoo feehi ikhtil\q@u{a}fan katheer\q@u{a}\q@b{n}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@dlxxvi{Wai\q@u{tha} j\q@u{a}ahum amrun mina alamni awi alkhawfi a\q@u{tha}AAoo bihi walaw raddoohu il\q@u{a} a\q@b{l}rrasooli wail\q@u{a} olee alamri minhum laAAalimahu alla\q@u{th}eena yastanbi\q@u{t}oonahu minhum walawl\q@u{a} fa\q@u{d}lu All\q@u{a}hi AAalaykum wara\q@u{h}matuhu la\q@b{i}ttabaAAtumu a\q@b{l}shshay\q@u{ta}na ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@dlxxvii{Faq\q@u{a}til fee sabeeli All\q@u{a}hi l\q@u{a} tukallafu ill\q@u{a} nafsaka wa\q@u{h}arri\q@u{d}i almumineena AAas\q@u{a} All\q@u{a}hu an yakuffa basa alla\q@u{th}eena kafaroo wa\q@b{A}ll\q@u{a}hu ashaddu basan waashaddu tankeel\q@u{a}\q@b{n}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@dlxxviii{Man yashfaAA shaf\q@u{a}AAatan \q@u{h}asanatan yakun lahu na\q@u{s}eebun minh\q@u{a} waman yashfaAA shaf\q@u{a}AAatan sayyiatan yakun lahu kiflun minh\q@u{a} wak\q@u{a}na All\q@u{a}hu AAal\q@u{a} kulli shayin muqeet\q@u{a}\q@b{n}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@dlxxix{Wai\q@u{tha} \q@u{h}uyyeetum bita\q@u{h}iyyatin fa\q@u{h}ayyoo bia\q@u{h}sana minh\q@u{a} aw ruddooh\q@u{a} inna All\q@u{a}ha k\q@u{a}na AAal\q@u{a} kulli shayin \q@u{h}aseeb\q@u{a}\q@b{n}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@dlxxx{All\q@u{a}hu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa layajmaAAannakum il\q@u{a} yawmi alqiy\q@u{a}mati l\q@u{a} rayba feehi waman a\q@u{s}daqu mina All\q@u{a}hi \q@u{h}adeeth\q@u{a}\q@b{n}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@dlxxxi{Fam\q@u{a} lakum fee almun\q@u{a}fiqeena fiatayni wa\q@b{A}ll\q@u{a}hu arkasahum bim\q@u{a} kasaboo atureedoona an tahdoo man a\q@u{d}alla All\q@u{a}hu waman yu\q@u{d}lili All\q@u{a}hu falan tajida lahu sabeel\q@u{a}\q@b{n}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@dlxxxii{Waddoo law takfuroona kam\q@u{a} kafaroo fatakoonoona saw\q@u{a}an fal\q@u{a} tattakhi\q@u{th}oo minhum awliy\q@u{a}a \q@u{h}att\q@u{a} yuh\q@u{a}jiroo fee sabeeli All\q@u{a}hi fain tawallaw fakhu\q@u{th}oohum wa\q@b{o}qtuloohum \q@u{h}aythu wajadtumoohum wal\q@u{a} tattakhi\q@u{th}oo minhum waliyyan wal\q@u{a} na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@dlxxxiii{Ill\q@u{a} alla\q@u{th}eena ya\q@u{s}iloona il\q@u{a} qawmin baynakum wabaynahum meeth\q@u{a}qun aw j\q@u{a}ookum \q@u{h}a\q@u{s}irat \q@u{s}udooruhum an yuq\q@u{a}tilookum aw yuq\q@u{a}tiloo qawmahum walaw sh\q@u{a}a All\q@u{a}hu lasalla\q@u{t}ahum AAalaykum falaq\q@u{a}talookum faini iAAtazalookum falam yuq\q@u{a}tilookum waalqaw ilaykumu a\q@b{l}ssalama fam\q@u{a} jaAAala All\q@u{a}hu lakum AAalayhim sabeel\q@u{a}\q@b{n}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@dlxxxiv{Satajidoona \q@u{a}khareena yureedoona an yamanookum wayamanoo qawmahum kulla m\q@u{a} ruddoo il\q@u{a} alfitnati orkisoo feeh\q@u{a} fain lam yaAAtazilookum wayulqoo ilaykumu a\q@b{l}ssalama wayakuffoo aydiyahum fakhu\q@u{th}oohum wa\q@b{o}qtuloohum \q@u{h}aythu thaqiftumoohum waol\q@u{a}ikum jaAAaln\q@u{a} lakum AAalayhim sul\q@u{ta}nan mubeen\q@u{a}\q@b{n}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@dlxxxv{Wam\q@u{a} k\q@u{a}na limuminin an yaqtula muminan ill\q@u{a} kha\q@u{t}aan waman qatala muminan kha\q@u{t}aan fata\q@u{h}reeru raqabatin muminatin wadiyatun musallamatun il\q@u{a} ahlihi ill\q@u{a} an ya\q@u{ss}addaqoo fain k\q@u{a}na min qawmin AAaduwwin lakum wahuwa muminun fata\q@u{h}reeru raqabatin muminatin wain k\q@u{a}na min qawmin baynakum wabaynahum meeth\q@u{a}qun fadiyatun musallamatun il\q@u{a} ahlihi wata\q@u{h}reeru raqabatin muminatin faman lam yajid fa\q@u{s}iy\q@u{a}mu shahrayni mutat\q@u{a}biAAayni tawbatan mina All\q@u{a}hi wak\q@u{a}na All\q@u{a}hu AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@dlxxxvi{Waman yaqtul muminan mutaAAammidan fajaz\q@u{a}ohu jahannamu kh\q@u{a}lidan feeh\q@u{a} wagha\q@u{d}iba All\q@u{a}hu AAalayhi walaAAanahu waaAAadda lahu AAa\q@u{tha}ban AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@dlxxxvii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} \q@u{d}arabtum fee sabeeli All\q@u{a}hi fatabayyanoo wal\q@u{a} taqooloo liman alq\q@u{a} ilaykumu a\q@b{l}ssal\q@u{a}ma lasta muminan tabtaghoona AAara\q@u{d}a al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} faAAinda All\q@u{a}hi magh\q@u{a}nimu katheeratun ka\q@u{tha}lika kuntum min qablu famanna All\q@u{a}hu AAalaykum fatabayyanoo inna All\q@u{a}ha k\q@u{a}na bim\q@u{a} taAAmaloona khabeer\q@u{a}\q@b{n}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@dlxxxviii{L\q@u{a} yastawee alq\q@u{a}AAidoona mina almumineena ghayru olee a\q@b{l}\q@u{dd}arari wa\q@b{a}lmuj\q@u{a}hidoona fee sabeeli All\q@u{a}hi biamw\q@u{a}lihim waanfusihim fa\q@u{dd}ala All\q@u{a}hu almuj\q@u{a}hideena biamw\q@u{a}lihim waanfusihim AAal\q@u{a} alq\q@u{a}AAideena darajatan wakullan waAAada All\q@u{a}hu al\q@u{h}usn\q@u{a} wafa\q@u{dd}ala All\q@u{a}hu almuj\q@u{a}hideena AAal\q@u{a} alq\q@u{a}AAideena ajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@dlxxxix{Daraj\q@u{a}tin minhu wamaghfiratan wara\q@u{h}matan wak\q@u{a}na All\q@u{a}hu ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@dxc{Inna alla\q@u{th}eena tawaff\q@u{a}humu almal\q@u{a}ikatu \q@i{\q@u{th}}\q@u{a}limee anfusihim q\q@u{a}loo feema kuntum q\q@u{a}loo kunn\q@u{a} musta\q@u{d}AAafeena fee alar\q@u{d}i q\q@u{a}loo alam takun ar\q@u{d}u All\q@u{a}hi w\q@u{a}siAAatan fatuh\q@u{a}jiroo feeh\q@u{a} faol\q@u{a}ika maw\q@u{a}hum jahannamu was\q@u{a}at ma\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@dxci{Ill\q@u{a} almusta\q@u{d}AAafeena mina a\q@b{l}rrij\q@u{a}li wa\q@b{al}nnis\q@u{a}i wa\q@b{a}lwild\q@u{a}ni l\q@u{a} yasta\q@u{t}eeAAoona \q@u{h}eelatan wal\q@u{a} yahtadoona sabeel\q@u{a}\q@b{n}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@dxcii{Faol\q@u{a}ika AAas\q@u{a} All\q@u{a}hu an yaAAfuwa AAanhum wak\q@u{a}na All\q@u{a}hu AAafuwwan ghafoor\q@u{a}\q@b{n}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@dxciii{Waman yuh\q@u{a}jir fee sabeeli All\q@u{a}hi yajid fee alar\q@u{d}i mur\q@u{a}ghaman katheeran wasaAAatan waman yakhruj min baytihi muh\q@u{a}jiran il\q@u{a} All\q@u{a}hi warasoolihi thumma yudrikhu almawtu faqad waqaAAa ajruhu AAal\q@u{a} All\q@u{a}hi wak\q@u{a}na All\q@u{a}hu ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@dxciv{Wai\q@u{tha} \q@u{d}arabtum fee alar\q@u{d}i falaysa AAalaykum jun\q@u{ah}un an taq\q@u{s}uroo mina a\q@b{l}\q@u{ss}al\q@u{a}ti in khiftum an yaftinakumu alla\q@u{th}eena kafaroo inna alk\q@u{a}fireena k\q@u{a}noo lakum AAaduwwan mubeen\q@u{a}\q@b{n}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@dxcv{Wai\q@u{tha} kunta feehim faaqamta lahumu a\q@b{l}\q@u{ss}al\q@u{a}ta faltaqum \q@u{ta}ifatun minhum maAAaka walyakhu\q@u{th}oo asli\q@u{h}atahum fai\q@u{tha} sajadoo falyakoonoo min war\q@u{a}ikum waltati \q@u{ta}ifatun okhr\q@u{a} lam yu\q@u{s}alloo falyu\q@u{s}alloo maAAaka walyakhu\q@u{th}oo \q@u{h}i\q@u{th}rahum waasli\q@u{h}atahum wadda alla\q@u{th}eena kafaroo law taghfuloona AAan asli\q@u{h}atikum waamtiAAatikum fayameeloona AAalaykum maylatan w\q@u{ah}idatan wal\q@u{a} jun\q@u{ah}a AAalaykum in k\q@u{a}na bikum a\q@u{th}an min ma\q@u{t}arin aw kuntum mar\q@u{da} an ta\q@u{d}aAAoo asli\q@u{h}atakum wakhu\q@u{th}oo \q@u{h}i\q@u{th}rakum inna All\q@u{a}ha aAAadda lilk\q@u{a}fireena AAa\q@u{tha}ban muheen\q@u{a}\q@b{n}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@dxcvi{Fai\q@u{tha} qa\q@u{d}aytumu a\q@b{l}\q@u{ss}al\q@u{a}ta fa\q@b{o}\q@u{th}kuroo All\q@u{a}ha qiy\q@u{a}man waquAAoodan waAAal\q@u{a} junoobikum fai\q@u{tha} i\q@u{t}manantum faaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta inna a\q@b{l}\q@u{ss}al\q@u{a}ta k\q@u{a}nat AAal\q@u{a} almumineena kit\q@u{a}ban mawqoot\q@u{a}\q@b{n}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@dxcvii{Wal\q@u{a} tahinoo fee ibtigh\q@u{a}i alqawmi in takoonoo talamoona fainnahum yalamoona kam\q@u{a} talamoona watarjoona mina All\q@u{a}hi m\q@u{a} l\q@u{a} yarjoona wak\q@u{a}na All\q@u{a}hu AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@dxcviii{Inn\q@u{a} anzaln\q@u{a} ilayka alkit\q@u{a}ba bi\q@b{a}l\q@u{h}aqqi lita\q@u{h}kuma bayna a\q@b{l}nn\q@u{a}si bim\q@u{a} ar\q@u{a}ka All\q@u{a}hu wal\q@u{a} takun lilkh\q@u{a}ineena kha\q@u{s}eem\q@u{a}\q@b{n}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@dxcix{Wa\q@b{i}staghfiri All\q@u{a}ha inna All\q@u{a}ha k\q@u{a}na ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@dc{Wal\q@u{a} tuj\q@u{a}dil AAani alla\q@u{th}eena yakht\q@u{a}noona anfusahum inna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu man k\q@u{a}na khaww\q@u{a}nan atheem\q@u{a}\q@b{n}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@dci{Yastakhfoona mina a\q@b{l}nn\q@u{a}si wal\q@u{a} yastakhfoona mina All\q@u{a}hi wahuwa maAAahum i\q@u{th} yubayyitoona m\q@u{a} l\q@u{a} yar\q@u{da} mina alqawli wak\q@u{a}na All\q@u{a}hu bim\q@u{a} yaAAmaloona mu\q@u{h}ee\q@u{ta}\q@b{n}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@dcii{H\q@u{a}antum h\q@u{a}ol\q@u{a}i j\q@u{a}daltum AAanhum fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} faman yuj\q@u{a}dilu All\q@u{a}ha AAanhum yawma alqiy\q@u{a}mati am man yakoonu AAalayhim wakeel\q@u{a}\q@b{n}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@dciii{Waman yaAAmal sooan aw ya\q@i{\q@u{th}}lim nafsahu thumma yastaghfiri All\q@u{a}ha yajidi All\q@u{a}ha ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@dciv{Waman yaksib ithman fainnam\q@u{a} yaksibuhu AAal\q@u{a} nafsihi wak\q@u{a}na All\q@u{a}hu AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@dcv{Waman yaksib kha\q@u{t}eeatan aw ithman thumma yarmi bihi bareean faqadi i\q@u{h}tamala buht\q@u{a}nan waithman mubeen\q@u{a}\q@b{n}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@dcvi{Walawl\q@u{a} fa\q@u{d}lu All\q@u{a}hi AAalayka wara\q@u{h}matuhu lahammat \q@u{ta}ifatun minhum an yu\q@u{d}illooka wam\q@u{a} yu\q@u{d}illoona ill\q@u{a} anfusahum wam\q@u{a} ya\q@u{d}urroonaka min shayin waanzala All\q@u{a}hu AAalayka alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ikmata waAAallamaka m\q@u{a} lam takun taAAlamu wak\q@u{a}na fa\q@u{d}lu All\q@u{a}hi AAalayka AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@dcvii{L\q@u{a} khayra fee katheerin min najw\q@u{a}hum ill\q@u{a} man amara bi\q@u{s}adaqatin aw maAAroofin aw i\q@u{s}l\q@u{ah}in bayna a\q@b{l}nn\q@u{a}si waman yafAAal \q@u{tha}lika ibtigh\q@u{a}a mar\q@u{da}ti All\q@u{a}hi fasawfa nuteehi ajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@dcviii{Waman yush\q@u{a}qiqi a\q@b{l}rrasoola min baAAdi m\q@u{a} tabayyana lahu alhud\q@u{a} wayattabiAA ghayra sabeeli almumineena nuwallihi m\q@u{a} tawall\q@u{a} wanu\q@u{s}lihi jahannama was\q@u{a}at ma\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@dcix{Inna All\q@u{a}ha l\q@u{a} yaghfiru an yushraka bihi wayaghfiru m\q@u{a} doona \q@u{tha}lika liman yash\q@u{a}o waman yushrik bi\q@b{A}ll\q@u{a}hi faqad \q@u{d}alla \q@u{d}al\q@u{a}lan baAAeed\q@u{a}\q@b{n}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@dcx{In yadAAoona min doonihi ill\q@u{a} in\q@u{a}than wain yadAAoona ill\q@u{a} shay\q@u{ta}nan mareed\q@u{a}\q@b{n}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@dcxi{LaAAanahu All\q@u{a}hu waq\q@u{a}la laattakhi\q@u{th}anna min AAib\q@u{a}dika na\q@u{s}eeban mafroo\q@u{da}\q@b{n}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@dcxii{Walao\q@u{d}illannahum walaomanniyannahum wala\q@u{a}murannahum falayubattikunna \q@u{atha}na alanAA\q@u{a}mi wala\q@u{a}murannahum falayughayyirunna khalqa All\q@u{a}hi waman yattakhi\q@u{th}i a\q@b{l}shshay\q@u{ta}na waliyyan min dooni All\q@u{a}hi faqad khasira khusr\q@u{a}nan mubeen\q@u{a}\q@b{n}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@dcxiii{YaAAiduhum wayumanneehim wam\q@u{a} yaAAiduhumu a\q@b{l}shshay\q@u{ta}nu ill\q@u{a} ghuroor\q@u{a}\q@b{n}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@dcxiv{Ol\q@u{a}ika maw\q@u{a}hum jahannamu wal\q@u{a} yajidoona AAanh\q@u{a} ma\q@u{h}ee\q@u{sa}\q@b{n}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@dcxv{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti sanudkhiluhum jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} abadan waAAda All\q@u{a}hi \q@u{h}aqqan waman a\q@u{s}daqu mina All\q@u{a}hi qeel\q@u{a}\q@b{n}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@dcxvi{Laysa biam\q@u{a}niyyikum wal\q@u{a} am\q@u{a}niyyi ahli alkit\q@u{a}bi man yaAAmal sooan yujza bihi wal\q@u{a} yajid lahu min dooni All\q@u{a}hi waliyyan wal\q@u{a} na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@dcxvii{Waman yaAAmal mina a\q@b{l}\q@u{ssa}li\q@u{ha}ti min \q@u{th}akarin aw onth\q@u{a} wahuwa muminun faol\q@u{a}ika yadkhuloona aljannata wal\q@u{a} yu\q@i{\q@u{th}}lamoona naqeer\q@u{a}\q@b{n}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@dcxviii{Waman a\q@u{h}sanu deenan mimman aslama wajhahu lill\q@u{a}hi wahuwa mu\q@u{h}sinun wa\q@b{i}ttabaAAa millata ibr\q@u{a}heema \q@u{h}aneefan wa\q@b{i}ttakha\q@u{th}a All\q@u{a}hu ibr\q@u{a}heema khaleel\q@u{a}\q@b{n}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@dcxix{Walill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wak\q@u{a}na All\q@u{a}hu bikulli shayin mu\q@u{h}ee\q@u{ta}\q@b{n}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@dcxx{Wayastaftoonaka fee a\q@b{l}nnis\q@u{a}i quli All\q@u{a}hu yufteekum feehinna wam\q@u{a} yutl\q@u{a} AAalaykum fee alkit\q@u{a}bi fee yat\q@u{a}m\q@u{a} a\q@b{l}nnis\q@u{a}i all\q@u{a}tee l\q@u{a} tutoonahunna m\q@u{a} kutiba lahunna watarghaboona an tanki\q@u{h}oohunna wa\q@b{a}lmusta\q@u{d}AAafeena mina alwild\q@u{a}ni waan taqoomoo lilyat\q@u{a}m\q@u{a} bi\q@b{a}lqis\q@u{t}i wam\q@u{a} tafAAaloo min khayrin fainna All\q@u{a}ha k\q@u{a}na bihi AAaleem\q@u{a}\q@b{n}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@dcxxi{Waini imraatun kh\q@u{a}fat min baAAlih\q@u{a} nushoozan aw iAAr\q@u{ad}an fal\q@u{a} jun\q@u{ah}a AAalayhim\q@u{a} an yu\q@u{s}li\q@u{ha} baynahum\q@u{a} \q@u{s}ul\q@u{h}an wa\q@b{al}\q@u{ss}ul\q@u{h}u khayrun wao\q@u{hd}irati alanfusu a\q@b{l}shshu\q@u{hh}a wain tu\q@u{h}sinoo watattaqoo fainna All\q@u{a}ha k\q@u{a}na bim\q@u{a} taAAmaloona khabeer\q@u{a}\q@b{n}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@dcxxii{Walan tasta\q@u{t}eeAAoo an taAAdiloo bayna a\q@b{l}nnis\q@u{a}i walaw \q@u{h}ara\q@u{s}tum fal\q@u{a} tameeloo kulla almayli fata\q@u{th}arooh\q@u{a} ka\q@b{a}lmuAAallaqati wain tu\q@u{s}li\q@u{h}oo watattaqoo fainna All\q@u{a}ha k\q@u{a}na ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(129)}}
\qt@newcmd\qurantrans@lt@dcxxiii{Wain yatafarraq\q@u{a} yughni All\q@u{a}hu kullan min saAAatihi wak\q@u{a}na All\q@u{a}hu w\q@u{a}siAAan \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(130)}}
\qt@newcmd\qurantrans@lt@dcxxiv{Walill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i walaqad wa\q@u{ss}ayn\q@u{a} alla\q@u{th}eena ootoo alkit\q@u{a}ba min qablikum waiyy\q@u{a}kum ani ittaqoo All\q@u{a}ha wain takfuroo fainna lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wak\q@u{a}na All\q@u{a}hu ghaniyyan \q@u{h}ameed\q@u{a}\q@b{n}\qt@no{(131)}}
\qt@newcmd\qurantrans@lt@dcxxv{Walill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi wakeel\q@u{a}\q@b{n}\qt@no{(132)}}
\qt@newcmd\qurantrans@lt@dcxxvi{In yasha yu\q@u{th}hibkum ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su wayati bi\q@u{a}khareena wak\q@u{a}na All\q@u{a}hu AAal\q@u{a} \q@u{tha}lika qadeer\q@u{a}\q@b{n}\qt@no{(133)}}
\qt@newcmd\qurantrans@lt@dcxxvii{Man k\q@u{a}na yureedu thaw\q@u{a}ba a\q@b{l}dduny\q@u{a} faAAinda All\q@u{a}hi thaw\q@u{a}bu a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati wak\q@u{a}na All\q@u{a}hu sameeAAan ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(134)}}
\qt@newcmd\qurantrans@lt@dcxxviii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo koonoo qaww\q@u{a}meena bi\q@b{a}lqis\q@u{t}i shuhad\q@u{a}a lill\q@u{a}hi walaw AAal\q@u{a} anfusikum awi alw\q@u{a}lidayni wa\q@b{a}laqrabeena in yakun ghaniyyan aw faqeeran fa\q@b{A}ll\q@u{a}hu awl\q@u{a} bihim\q@u{a} fal\q@u{a} tattabiAAoo alhaw\q@u{a} an taAAdiloo wain talwoo aw tuAAri\q@u{d}oo fainna All\q@u{a}ha k\q@u{a}na bim\q@u{a} taAAmaloona khabeer\q@u{a}\q@b{n}\qt@no{(135)}}
\qt@newcmd\qurantrans@lt@dcxxix{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo \q@u{a}minoo bi\q@b{A}ll\q@u{a}hi warasoolihi wa\q@b{a}lkit\q@u{a}bi alla\q@u{th}ee nazzala AAal\q@u{a} rasoolihi wa\q@b{a}lkit\q@u{a}bi alla\q@u{th}ee anzala min qablu waman yakfur bi\q@b{A}ll\q@u{a}hi wamal\q@u{a}ikatihi wakutubihi warusulihi wa\q@b{a}lyawmi al\q@u{a}khiri faqad \q@u{d}alla \q@u{d}al\q@u{a}lan baAAeed\q@u{a}\q@b{n}\qt@no{(136)}}
\qt@newcmd\qurantrans@lt@dcxxx{Inna alla\q@u{th}eena \q@u{a}manoo thumma kafaroo thumma \q@u{a}manoo thumma kafaroo thumma izd\q@u{a}doo kufran lam yakuni All\q@u{a}hu liyaghfira lahum wal\q@u{a} liyahdiyahum sabeel\q@u{a}\q@b{n}\qt@no{(137)}}
\qt@newcmd\qurantrans@lt@dcxxxi{Bashshiri almun\q@u{a}fiqeena bianna lahum AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(138)}}
\qt@newcmd\qurantrans@lt@dcxxxii{Alla\q@u{th}eena yattakhi\q@u{th}oona alk\q@u{a}fireena awliy\q@u{a}a min dooni almumineena ayabtaghoona AAindahumu alAAizzata fainna alAAizzata lill\q@u{a}hi jameeAA\q@u{a}\q@b{n}\qt@no{(139)}}
\qt@newcmd\qurantrans@lt@dcxxxiii{Waqad nazzala AAalaykum fee alkit\q@u{a}bi an i\q@u{tha} samiAAtum \q@u{a}y\q@u{a}ti All\q@u{a}hi yukfaru bih\q@u{a} wayustahzao bih\q@u{a} fal\q@u{a} taqAAudoo maAAahum \q@u{h}att\q@u{a} yakhoo\q@u{d}oo fee \q@u{h}adeethin ghayrihi innakum i\q@u{th}an mithluhum inna All\q@u{a}ha j\q@u{a}miAAu almun\q@u{a}fiqeena wa\q@b{a}lk\q@u{a}fireena fee jahannama jameeAA\q@u{a}\q@b{n}\qt@no{(140)}}
\qt@newcmd\qurantrans@lt@dcxxxiv{Alla\q@u{th}eena yatarabba\q@u{s}oona bikum fain k\q@u{a}na lakum fat\q@u{h}un mina All\q@u{a}hi q\q@u{a}loo alam nakun maAAakum wain k\q@u{a}na lilk\q@u{a}fireena na\q@u{s}eebun q\q@u{a}loo alam nasta\q@u{h}wi\q@u{th} AAalaykum wanamnaAAkum mina almumineena fa\q@b{A}ll\q@u{a}hu ya\q@u{h}kumu baynakum yawma alqiy\q@u{a}mati walan yajAAala All\q@u{a}hu lilk\q@u{a}fireena AAal\q@u{a} almumineena sabeel\q@u{a}\q@b{n}\qt@no{(141)}}
\qt@newcmd\qurantrans@lt@dcxxxv{Inna almun\q@u{a}fiqeena yukh\q@u{a}diAAoona All\q@u{a}ha wahuwa kh\q@u{a}diAAuhum wai\q@u{tha} q\q@u{a}moo il\q@u{a} a\q@b{l}\q@u{ss}al\q@u{a}ti q\q@u{a}moo kus\q@u{a}l\q@u{a} yur\q@u{a}oona a\q@b{l}nn\q@u{a}sa wal\q@u{a} ya\q@u{th}kuroona All\q@u{a}ha ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(142)}}
\qt@newcmd\qurantrans@lt@dcxxxvi{Mu\q@u{th}ab\q@u{th}abeena bayna \q@u{tha}lika l\q@u{a} il\q@u{a} h\q@u{a}ol\q@u{a}i wal\q@u{a} il\q@u{a} h\q@u{a}ol\q@u{a}i waman yu\q@u{d}lili All\q@u{a}hu falan tajida lahu sabeel\q@u{a}\q@b{n}\qt@no{(143)}}
\qt@newcmd\qurantrans@lt@dcxxxvii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tattakhi\q@u{th}oo alk\q@u{a}fireena awliy\q@u{a}a min dooni almumineena atureedoona an tajAAaloo lill\q@u{a}hi AAalaykum sul\q@u{ta}nan mubeen\q@u{a}\q@b{n}\qt@no{(144)}}
\qt@newcmd\qurantrans@lt@dcxxxviii{Inna almun\q@u{a}fiqeena fee a\q@b{l}ddarki alasfali mina a\q@b{l}nn\q@u{a}ri walan tajida lahum na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(145)}}
\qt@newcmd\qurantrans@lt@dcxxxix{Ill\q@u{a} alla\q@u{th}eena t\q@u{a}boo waa\q@u{s}la\q@u{h}oo wa\q@b{i}AAta\q@u{s}amoo bi\q@b{A}ll\q@u{a}hi waakhla\q@u{s}oo deenahum lill\q@u{a}hi faol\q@u{a}ika maAAa almumineena wasawfa yuti All\q@u{a}hu almumineena ajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(146)}}
\qt@newcmd\qurantrans@lt@dcxl{M\q@u{a} yafAAalu All\q@u{a}hu biAAa\q@u{tha}bikum in shakartum wa\q@u{a}mantum wak\q@u{a}na All\q@u{a}hu sh\q@u{a}kiran AAaleem\q@u{a}\q@b{n}\qt@no{(147)}}
\qt@newcmd\qurantrans@lt@dcxli{L\q@u{a} yu\q@u{h}ibbu All\q@u{a}hu aljahra bi\q@b{al}ssooi mina alqawli ill\q@u{a} man \q@i{\q@u{th}}ulima wak\q@u{a}na All\q@u{a}hu sameeAAan AAaleem\q@u{a}\q@b{n}\qt@no{(148)}}
\qt@newcmd\qurantrans@lt@dcxlii{In tubdoo khayran aw tukhfoohu aw taAAfoo AAan sooin fainna All\q@u{a}ha k\q@u{a}na AAafuwwan qadeer\q@u{a}\q@b{n}\qt@no{(149)}}
\qt@newcmd\qurantrans@lt@dcxliii{Inna alla\q@u{th}eena yakfuroona bi\q@b{A}ll\q@u{a}hi warusulihi wayureedoona an yufarriqoo bayna All\q@u{a}hi warusulihi wayaqooloona numinu bibaAA\q@u{d}in wanakfuru bibaAA\q@u{d}in wayureedoona an yattakhi\q@u{th}oo bayna \q@u{tha}lika sabeel\q@u{a}\q@b{n}\qt@no{(150)}}
\qt@newcmd\qurantrans@lt@dcxliv{Ol\q@u{a}ika humu alk\q@u{a}firoona \q@u{h}aqqan waaAAtadn\q@u{a} lilk\q@u{a}fireena AAa\q@u{tha}ban muheen\q@u{a}\q@b{n}\qt@no{(151)}}
\qt@newcmd\qurantrans@lt@dcxlv{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo bi\q@b{A}ll\q@u{a}hi warusulihi walam yufarriqoo bayna a\q@u{h}adin minhum ol\q@u{a}ika sawfa yuteehim ojoorahum wak\q@u{a}na All\q@u{a}hu ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(152)}}
\qt@newcmd\qurantrans@lt@dcxlvi{Yasaluka ahlu alkit\q@u{a}bi an tunazzila AAalayhim kit\q@u{a}ban mina a\q@b{l}ssam\q@u{a}i faqad saaloo moos\q@u{a} akbara min \q@u{tha}lika faq\q@u{a}loo arin\q@u{a} All\q@u{a}ha jahratan faakha\q@u{th}athumu a\q@b{l}\q@u{ssa}AAiqatu bi\q@i{\q@u{th}}ulmihim thumma ittakha\q@u{th}oo alAAijla min baAAdi m\q@u{a} j\q@u{a}athumu albayyin\q@u{a}tu faAAafawn\q@u{a} AAan \q@u{tha}lika wa\q@u{a}tayn\q@u{a} moos\q@u{a} sul\q@u{ta}nan mubeen\q@u{a}\q@b{n}\qt@no{(153)}}
\qt@newcmd\qurantrans@lt@dcxlvii{WarafaAAn\q@u{a} fawqahumu a\q@b{l}\q@u{tt}oora bimeeth\q@u{a}qihim waquln\q@u{a} lahumu odkhuloo alb\q@u{a}ba sujjadan waquln\q@u{a} lahum l\q@u{a} taAAdoo fee a\q@b{l}ssabti waakha\q@u{th}n\q@u{a} minhum meeth\q@u{a}qan ghalee\q@i{\q@u{th}}\q@u{a}\q@b{n}\qt@no{(154)}}
\qt@newcmd\qurantrans@lt@dcxlviii{Fabim\q@u{a} naq\q@u{d}ihim meeth\q@u{a}qahum wakufrihim bi\q@u{a}y\q@u{a}ti All\q@u{a}hi waqatlihimu alanbiy\q@u{a}a bighayri \q@u{h}aqqin waqawlihim quloobun\q@u{a} ghulfun bal \q@u{t}abaAAa All\q@u{a}hu AAalayh\q@u{a} bikufrihim fal\q@u{a} yuminoona ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(155)}}
\qt@newcmd\qurantrans@lt@dcxlix{Wabikufrihim waqawlihim AAal\q@u{a} maryama buht\q@u{a}nan AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(156)}}
\qt@newcmd\qurantrans@lt@dcl{Waqawlihim inn\q@u{a} qataln\q@u{a} almasee\q@u{h}a AAees\q@u{a} ibna maryama rasoola All\q@u{a}hi wam\q@u{a} qataloohu wam\q@u{a} \q@u{s}alaboohu wal\q@u{a}kin shubbiha lahum wainna alla\q@u{th}eena ikhtalafoo feehi lafee shakkin minhu m\q@u{a} lahum bihi min AAilmin ill\q@u{a} ittib\q@u{a}AAa a\q@b{l}\q@i{\q@u{thth}}anni wam\q@u{a} qataloohu yaqeen\q@u{a}\q@b{n}\qt@no{(157)}}
\qt@newcmd\qurantrans@lt@dcli{Bal rafaAAahu All\q@u{a}hu ilayhi wak\q@u{a}na All\q@u{a}hu AAazeezan \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(158)}}
\qt@newcmd\qurantrans@lt@dclii{Wain min ahli alkit\q@u{a}bi ill\q@u{a} layuminanna bihi qabla mawtihi wayawma alqiy\q@u{a}mati yakoonu AAalayhim shaheed\q@u{a}\q@b{n}\qt@no{(159)}}
\qt@newcmd\qurantrans@lt@dcliii{Fabi\q@i{\q@u{th}}ulmin mina alla\q@u{th}eena h\q@u{a}doo \q@u{h}arramn\q@u{a} AAalayhim \q@u{t}ayyib\q@u{a}tin o\q@u{h}illat lahum wabi\q@u{s}addihim AAan sabeeli All\q@u{a}hi katheer\q@u{a}\q@b{n}\qt@no{(160)}}
\qt@newcmd\qurantrans@lt@dcliv{Waakh\q@u{th}ihimu a\q@b{l}rrib\q@u{a} waqad nuhoo AAanhu waaklihim amw\q@u{a}la a\q@b{l}nn\q@u{a}si bi\q@b{a}lb\q@u{at}ili waaAAtadn\q@u{a} lilk\q@u{a}fireena minhum AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(161)}}
\qt@newcmd\qurantrans@lt@dclv{L\q@u{a}kini a\q@b{l}rr\q@u{a}sikhoona fee alAAilmi minhum wa\q@b{a}lmuminoona yuminoona bim\q@u{a} onzila ilayka wam\q@u{a} onzila min qablika wa\q@b{a}lmuqeemeena a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@b{a}lmutoona a\q@b{l}zzak\q@u{a}ta wa\q@b{a}lmuminoona bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri ol\q@u{a}ika sanuteehim ajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(162)}}
\qt@newcmd\qurantrans@lt@dclvi{Inn\q@u{a} aw\q@u{h}ayn\q@u{a} ilayka kam\q@u{a} aw\q@u{h}ayn\q@u{a} il\q@u{a} noo\q@u{h}in wa\q@b{al}nnabiyyeena min baAAdihi waaw\q@u{h}ayn\q@u{a} il\q@u{a} ibr\q@u{a}heema waism\q@u{a}AAeela wais\q@u{ha}qa wayaAAqooba wa\q@b{a}lasb\q@u{at}i waAAees\q@u{a} waayyooba wayoonusa wah\q@u{a}roona wasulaym\q@u{a}na wa\q@u{a}tayn\q@u{a} d\q@u{a}wooda zaboor\q@u{a}\q@b{n}\qt@no{(163)}}
\qt@newcmd\qurantrans@lt@dclvii{Warusulan qad qa\q@u{s}a\q@u{s}n\q@u{a}hum AAalayka min qablu warusulan lam naq\q@u{s}u\q@u{s}hum AAalayka wakallama All\q@u{a}hu moos\q@u{a} takleem\q@u{a}\q@b{n}\qt@no{(164)}}
\qt@newcmd\qurantrans@lt@dclviii{Rusulan mubashshireena wamun\q@u{th}ireena liall\q@u{a} yakoona li\q@b{l}nn\q@u{a}si AAal\q@u{a} All\q@u{a}hi \q@u{h}ujjatun baAAda a\q@b{l}rrusuli wak\q@u{a}na All\q@u{a}hu AAazeezan \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(165)}}
\qt@newcmd\qurantrans@lt@dclix{L\q@u{a}kini All\q@u{a}hu yashhadu bim\q@u{a} anzala ilayka anzalahu biAAilmihi wa\q@b{a}lmal\q@u{a}ikatu yashhadoona wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi shaheed\q@u{a}\q@b{n}\qt@no{(166)}}
\qt@newcmd\qurantrans@lt@dclx{Inna alla\q@u{th}eena kafaroo wa\q@u{s}addoo AAan sabeeli All\q@u{a}hi qad \q@u{d}alloo \q@u{d}al\q@u{a}lan baAAeed\q@u{a}\q@b{n}\qt@no{(167)}}
\qt@newcmd\qurantrans@lt@dclxi{Inna alla\q@u{th}eena kafaroo wa\q@i{\q@u{th}}alamoo lam yakuni All\q@u{a}hu liyaghfira lahum wal\q@u{a} liyahdiyahum \q@u{t}areeq\q@u{a}\q@b{n}\qt@no{(168)}}
\qt@newcmd\qurantrans@lt@dclxii{Ill\q@u{a} \q@u{t}areeqa jahannama kh\q@u{a}lideena feeh\q@u{a} abadan wak\q@u{a}na \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi yaseer\q@u{a}\q@b{n}\qt@no{(169)}}
\qt@newcmd\qurantrans@lt@dclxiii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su qad j\q@u{a}akumu a\q@b{l}rrasoolu bi\q@b{a}l\q@u{h}aqqi min rabbikum fa\q@u{a}minoo khayran lakum wain takfuroo fainna lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wak\q@u{a}na All\q@u{a}hu AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(170)}}
\qt@newcmd\qurantrans@lt@dclxiv{Y\q@u{a} ahla alkit\q@u{a}bi l\q@u{a} taghloo fee deenikum wal\q@u{a} taqooloo AAal\q@u{a} All\q@u{a}hi ill\q@u{a} al\q@u{h}aqqa innam\q@u{a} almasee\q@u{h}u AAees\q@u{a} ibnu maryama rasoolu All\q@u{a}hi wakalimatuhu alq\q@u{a}h\q@u{a} il\q@u{a} maryama waroo\q@u{h}un minhu fa\q@u{a}minoo bi\q@b{A}ll\q@u{a}hi warusulihi wal\q@u{a} taqooloo thal\q@u{a}thatun intahoo khayran lakum innam\q@u{a} All\q@u{a}hu il\q@u{a}hun w\q@u{ah}idun sub\q@u{ha}nahu an yakoona lahu waladun lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi wakeel\q@u{a}\q@b{n}\qt@no{(171)}}
\qt@newcmd\qurantrans@lt@dclxv{Lan yastankifa almasee\q@u{h}u an yakoona AAabdan lill\q@u{a}hi wal\q@u{a} almal\q@u{a}ikatu almuqarraboona waman yastankif AAan AAib\q@u{a}datihi wayastakbir fasaya\q@u{h}shuruhum ilayhi jameeAA\q@u{a}\q@b{n}\qt@no{(172)}}
\qt@newcmd\qurantrans@lt@dclxvi{Faamm\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti fayuwaffeehim ojoorahum wayazeeduhum min fa\q@u{d}lihi waamm\q@u{a} alla\q@u{th}eena istankafoo wa\q@b{i}stakbaroo fayuAAa\q@u{thth}ibuhum AAa\q@u{tha}ban aleeman wal\q@u{a} yajidoona lahum min dooni All\q@u{a}hi waliyyan wal\q@u{a} na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(173)}}
\qt@newcmd\qurantrans@lt@dclxvii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su qad j\q@u{a}akum burh\q@u{a}nun min rabbikum waanzaln\q@u{a} ilaykum nooran mubeen\q@u{a}\q@b{n}\qt@no{(174)}}
\qt@newcmd\qurantrans@lt@dclxviii{Faamm\q@u{a} alla\q@u{th}eena \q@u{a}manoo bi\q@b{A}ll\q@u{a}hi wa\q@b{i}AAta\q@u{s}amoo bihi fasayudkhiluhum fee ra\q@u{h}matin minhu wafa\q@u{d}lin wayahdeehim ilayhi \q@u{s}ir\q@u{at}an mustaqeem\q@u{a}\q@b{n}\qt@no{(175)}}
\qt@newcmd\qurantrans@lt@dclxix{Yastaftoonaka quli All\q@u{a}hu yufteekum fee alkal\q@u{a}lati ini imruon halaka laysa lahu waladun walahu okhtun falah\q@u{a} ni\q@u{s}fu m\q@u{a} taraka wahuwa yarithuh\q@u{a} in lam yakun lah\q@u{a} waladun fain k\q@u{a}nat\q@u{a} ithnatayni falahum\q@u{a} a\q@b{l}ththuluth\q@u{a}ni mimm\q@u{a} taraka wain k\q@u{a}noo ikhwatan rij\q@u{a}lan wanis\q@u{a}an fali\q@b{l}\q@u{thth}akari mithlu \q@u{h}a\q@i{\q@u{thth}}i alonthayayni yubayyinu All\q@u{a}hu lakum an ta\q@u{d}illoo wa\q@b{A}ll\q@u{a}hu bikulli shayin AAaleem\q@b{un}\qt@no{(176)}}
\qt@newcmd\qurantrans@lt@dclxx{\basmalahlt Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo awfoo bi\q@b{a}lAAuqoodi o\q@u{h}illat lakum baheematu alanAA\q@u{a}mi ill\q@u{a} m\q@u{a} yutl\q@u{a} AAalaykum ghayra mu\q@u{h}illee a\q@b{l}\q@u{ss}aydi waantum \q@u{h}urumun inna All\q@u{a}ha ya\q@u{h}kumu m\q@u{a} yureed\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@dclxxi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tu\q@u{h}illoo shaAA\q@u{a}ira All\q@u{a}hi wal\q@u{a} a\q@b{l}shshahra al\q@u{h}ar\q@u{a}ma wal\q@u{a} alhadya wal\q@u{a} alqal\q@u{a}ida wal\q@u{a} \q@u{a}mmeena albayta al\q@u{h}ar\q@u{a}ma yabtaghoona fa\q@u{d}lan min rabbihim wari\q@u{d}w\q@u{a}nan wai\q@u{tha} \q@u{h}alaltum fa\q@b{i}\q@u{sta}doo wal\q@u{a} yajrimannakum shana\q@u{a}nu qawmin an \q@u{s}addookum AAani almasjidi al\q@u{h}ar\q@u{a}mi an taAAtadoo wataAA\q@u{a}wanoo AAal\q@u{a} albirri wa\q@b{al}ttaqw\q@u{a} wal\q@u{a} taAA\q@u{a}wanoo AAal\q@u{a} alithmi wa\q@b{a}lAAudw\q@u{a}ni wa\q@b{i}ttaqoo All\q@u{a}ha inna All\q@u{a}ha shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@dclxxii{\q@u{H}urrimat AAalaykumu almaytatu wa\q@b{al}ddamu wala\q@u{h}mu alkhinzeeri wam\q@u{a} ohilla lighayri All\q@u{a}hi bihi wa\q@b{a}lmunkhaniqatu wa\q@b{a}lmawqoo\q@u{th}atu wa\q@b{a}lmutaraddiyatu wa\q@b{al}nna\q@u{t}ee\q@u{h}atu wam\q@u{a} akala a\q@b{l}ssabuAAu ill\q@u{a} m\q@u{a th}akkaytum wam\q@u{a} \q@u{th}ubi\q@u{h}a AAal\q@u{a} a\q@b{l}nnu\q@u{s}ubi waan tastaqsimoo bi\q@b{a}lazl\q@u{a}mi \q@u{tha}likum fisqun alyawma yaisa alla\q@u{th}eena kafaroo min deenikum fal\q@u{a} takhshawhum wa\q@b{i}khshawni alyawma akmaltu lakum deenakum waatmamtu AAalaykum niAAmatee wara\q@u{d}eetu lakumu alisl\q@u{a}ma deenan famani i\q@u{dt}urra fee makhma\q@u{s}atin ghayra mutaj\q@u{a}nifin liithmin fainna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@dclxxiii{Yasaloonaka m\q@u{atha} o\q@u{h}illa lahum qul o\q@u{h}illa lakumu a\q@b{l}\q@u{tt}ayyib\q@u{a}tu wam\q@u{a} AAallamtum mina aljaw\q@u{a}ri\q@u{h}i mukallibeena tuAAallimoonahunna mimm\q@u{a} AAallamakumu All\q@u{a}hu fakuloo mimm\q@u{a} amsakna AAalaykum wa\q@b{o}\q@u{th}kuroo isma All\q@u{a}hi AAalayhi wa\q@b{i}ttaqoo All\q@u{a}ha inna All\q@u{a}ha sareeAAu al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@dclxxiv{Alyawma o\q@u{h}illa lakumu a\q@b{l}\q@u{tt}ayyib\q@u{a}tu wa\q@u{t}aAA\q@u{a}mu alla\q@u{th}eena ootoo alkit\q@u{a}ba \q@u{h}illun lakum wa\q@u{t}aAA\q@u{a}mukum \q@u{h}illun lahum wa\q@b{a}lmu\q@u{hs}an\q@u{a}tu mina almumin\q@u{a}ti wa\q@b{a}lmu\q@u{hs}an\q@u{a}tu mina alla\q@u{th}eena ootoo alkit\q@u{a}ba min qablikum i\q@u{tha} \q@u{a}taytumoohunna ojoorahunna mu\q@u{hs}ineena ghayra mus\q@u{a}fi\q@u{h}eena wal\q@u{a} muttakhi\q@u{th}ee akhd\q@u{a}nin waman yakfur bi\q@b{a}leem\q@u{a}ni faqad \q@u{h}abi\q@u{t}a AAamaluhu wahuwa fee al\q@u{a}khirati mina alkh\q@u{a}sireen\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@dclxxv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} qumtum il\q@u{a} a\q@b{l}\q@u{ss}al\q@u{a}ti fa\q@b{i}ghsiloo wujoohakum waaydiyakum il\q@u{a} almar\q@u{a}fiqi wa\q@b{i}msa\q@u{h}oo biruoosikum waarjulakum il\q@u{a} alkaAAbayni wain kuntum junuban fa\q@b{i}\q@u{tt}ahharoo wain kuntum mar\q@u{da} aw AAal\q@u{a} safarin aw j\q@u{a}a a\q@u{h}adun minkum mina algh\q@u{a}i\q@u{t}i aw l\q@u{a}mastumu a\q@b{l}nnis\q@u{a}a falam tajidoo m\q@u{a}an fatayammamoo \q@u{s}aAAeedan \q@u{t}ayyiban fa\q@b{i}msa\q@u{h}oo biwujoohikum waaydeekum minhu m\q@u{a} yureedu All\q@u{a}hu liyajAAala AAalaykum min \q@u{h}arajin wal\q@u{a}kin yureedu liyu\q@u{t}ahhirakum waliyutimma niAAmatahu AAalaykum laAAallakum tashkuroon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@dclxxvi{Wa\q@b{o}\q@u{th}kuroo niAAmata All\q@u{a}hi AAalaykum wameeth\q@u{a}qahu alla\q@u{th}ee w\q@u{a}thaqakum bihi i\q@u{th} qultum samiAAn\q@u{a} waa\q@u{t}aAAn\q@u{a} wa\q@b{i}ttaqoo All\q@u{a}ha inna All\q@u{a}ha AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@dclxxvii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo koonoo qaww\q@u{a}meena lill\q@u{a}hi shuhad\q@u{a}a bi\q@b{a}lqis\q@u{t}i wal\q@u{a} yajrimannakum shana\q@u{a}nu qawmin AAal\q@u{a} all\q@u{a} taAAdiloo iAAdiloo huwa aqrabu li\q@b{l}ttaqw\q@u{a} wa\q@b{i}ttaqoo All\q@u{a}ha inna All\q@u{a}ha khabeerun bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@dclxxviii{WaAAada All\q@u{a}hu alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lahum maghfiratun waajrun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@dclxxix{Wa\q@b{a}lla\q@u{th}eena kafaroo waka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} ol\q@u{a}ika a\q@u{s}\q@u{ha}bu alja\q@u{h}eem\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@dclxxx{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo o\q@u{th}kuroo niAAmata All\q@u{a}hi AAalaykum i\q@u{th} hamma qawmun an yabsu\q@u{t}oo ilaykum aydiyahum fakaffa aydiyahum AAankum wa\q@b{i}ttaqoo All\q@u{a}ha waAAal\q@u{a} All\q@u{a}hi falyatawakkali almuminoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@dclxxxi{Walaqad akha\q@u{th}a All\q@u{a}hu meeth\q@u{a}qa banee isr\q@u{a}eela wabaAAathn\q@u{a} minhumu ithnay AAashara naqeeban waq\q@u{a}la All\q@u{a}hu innee maAAakum lain aqamtumu a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}taytumu a\q@b{l}zzak\q@u{a}ta wa\q@u{a}mantum birusulee waAAazzartumoohum waaqra\q@u{d}tumu All\q@u{a}ha qar\q@u{d}an \q@u{h}asanan laokaffiranna AAankum sayyi\q@u{a}tikum walaodkhilannakum jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru faman kafara baAAda \q@u{tha}lika minkum faqad \q@u{d}alla saw\q@u{a}a a\q@b{l}ssabeel\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@dclxxxii{Fabim\q@u{a} naq\q@u{d}ihim meeth\q@u{a}qahum laAAann\q@u{a}hum wajaAAaln\q@u{a} quloobahum q\q@u{a}siyatan yu\q@u{h}arrifoona alkalima AAan maw\q@u{ad}iAAihi wanasoo \q@u{h}a\q@i{\q@u{thth}}an mimm\q@u{a} \q@u{th}ukkiroo bihi wal\q@u{a} taz\q@u{a}lu ta\q@u{tt}aliAAu AAal\q@u{a} kh\q@u{a}inatin minhum ill\q@u{a} qaleelan minhum fa\q@b{o}AAfu AAanhum wa\q@b{i}\q@u{s}fa\q@u{h} inna All\q@u{a}ha yu\q@u{h}ibbu almu\q@u{h}sineen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@dclxxxiii{Wamina alla\q@u{th}eena q\q@u{a}loo inn\q@u{a} na\q@u{sa}r\q@u{a} akha\q@u{th}n\q@u{a} meeth\q@u{a}qahum fanasoo \q@u{h}a\q@i{\q@u{thth}}an mimm\q@u{a} \q@u{th}ukkiroo bihi faaghrayn\q@u{a} baynahumu alAAad\q@u{a}wata wa\q@b{a}lbagh\q@u{da}a il\q@u{a} yawmi alqiy\q@u{a}mati wasawfa yunabbiohumu All\q@u{a}hu bim\q@u{a} k\q@u{a}noo ya\q@u{s}naAAoon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@dclxxxiv{Y\q@u{a} ahla alkit\q@u{a}bi qad j\q@u{a}akum rasoolun\q@u{a} yubayyinu lakum katheeran mimm\q@u{a} kuntum tukhfoona mina alkit\q@u{a}bi wayaAAfoo AAan katheerin qad j\q@u{a}akum mina All\q@u{a}hi noorun wakit\q@u{a}bun mubeen\q@b{un}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@dclxxxv{Yahdee bihi All\q@u{a}hu mani ittabaAAa ri\q@u{d}w\q@u{a}nahu subula a\q@b{l}ssal\q@u{a}mi wayukhrijuhum mina a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti il\q@u{a} a\q@b{l}nnoori bii\q@u{th}nihi wayahdeehim il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@dclxxxvi{Laqad kafara alla\q@u{th}eena q\q@u{a}loo inna All\q@u{a}ha huwa almasee\q@u{h}u ibnu maryama qul faman yamliku mina All\q@u{a}hi shayan in ar\q@u{a}da an yuhlika almasee\q@u{h}a ibna maryama waommahu waman fee alar\q@u{d}i jameeAAan walill\q@u{a}hi mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} yakhluqu m\q@u{a} yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@dclxxxvii{Waq\q@u{a}lati alyahoodu wa\q@b{al}nna\q@u{sa}r\q@u{a} na\q@u{h}nu abn\q@u{a}o All\q@u{a}hi waa\q@u{h}ibb\q@u{a}ohu qul falima yuAAa\q@u{thth}ibukum bi\q@u{th}unoobikum bal antum basharun mimman khalaqa yaghfiru liman yash\q@u{a}o wayuAAa\q@u{thth}ibu man yash\q@u{a}o walill\q@u{a}hi mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} wailayhi alma\q@u{s}eer\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@dclxxxviii{Y\q@u{a} ahla alkit\q@u{a}bi qad j\q@u{a}akum rasoolun\q@u{a} yubayyinu lakum AAal\q@u{a} fatratin mina a\q@b{l}rrusuli an taqooloo m\q@u{a} j\q@u{a}an\q@u{a} min basheerin wal\q@u{a} na\q@u{th}eerin faqad j\q@u{a}akum basheerun wana\q@u{th}eerun wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@dclxxxix{Wai\q@u{th} q\q@u{a}la moos\q@u{a} liqawmihi y\q@u{a} qawmi o\q@u{th}kuroo niAAmata All\q@u{a}hi AAalaykum i\q@u{th} jaAAala feekum anbiy\q@u{a}a wajaAAalakum mulookan wa\q@u{a}t\q@u{a}kum m\q@u{a} lam yuti a\q@u{h}adan mina alAA\q@u{a}lameen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@dcxc{Y\q@u{a} qawmi odkhuloo alar\q@u{d}a almuqaddasata allatee kataba All\q@u{a}hu lakum wal\q@u{a} tartaddoo AAal\q@u{a} adb\q@u{a}rikum fatanqaliboo kh\q@u{a}sireen\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@dcxci{Q\q@u{a}loo y\q@u{a} moos\q@u{a} inna feeh\q@u{a} qawman jabb\q@u{a}reena wainn\q@u{a} lan nadkhulah\q@u{a} \q@u{h}att\q@u{a} yakhrujoo minh\q@u{a} fain yakhrujoo minh\q@u{a} fainn\q@u{a} d\q@u{a}khiloon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@dcxcii{Q\q@u{a}la rajul\q@u{a}ni mina alla\q@u{th}eena yakh\q@u{a}foona anAAama All\q@u{a}hu AAalayhim\q@u{a} odkhuloo AAalayhimu alb\q@u{a}ba fai\q@u{tha} dakhaltumoohu fainnakum gh\q@u{a}liboona waAAal\q@u{a} All\q@u{a}hi fatawakkaloo in kuntum mumineen\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@dcxciii{Q\q@u{a}loo y\q@u{a} moos\q@u{a} inn\q@u{a} lan nadkhulah\q@u{a} abadan m\q@u{a} d\q@u{a}moo feeh\q@u{a} fai\q@u{th}hab anta warabbuka faq\q@u{a}til\q@u{a} inn\q@u{a} h\q@u{a}hun\q@u{a} q\q@u{a}AAidoon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@dcxciv{Q\q@u{a}la rabbi innee l\q@u{a} amliku ill\q@u{a} nafsee waakhee fa\q@b{o}fruq baynan\q@u{a} wabayna alqawmi alf\q@u{a}siqeen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@dcxcv{Q\q@u{a}la fainnah\q@u{a} mu\q@u{h}arramatun AAalayhim arbaAAeena sanatan yateehoona fee alar\q@u{d}i fal\q@u{a} tasa AAal\q@u{a} alqawmi alf\q@u{a}siqeen\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@dcxcvi{Wa\q@b{o}tlu AAalayhim nabaa ibnay \q@u{a}dama bi\q@b{a}l\q@u{h}aqqi i\q@u{th} qarrab\q@u{a} qurb\q@u{a}nan fatuqubbila min a\q@u{h}adihim\q@u{a} walam yutaqabbal mina al\q@u{a}khari q\q@u{a}la laaqtulannaka q\q@u{a}la innam\q@u{a} yataqabbalu All\q@u{a}hu mina almuttaqeen\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@dcxcvii{Lain basa\q@u{t}ta ilayya yadaka litaqtulanee m\q@u{a} an\q@u{a} bib\q@u{a}si\q@u{t}in yadiya ilayka liaqtulaka innee akh\q@u{a}fu All\q@u{a}ha rabba alAA\q@u{a}lameen\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@dcxcviii{Innee oreedu an tabooa biithmee waithmika fatakoona min a\q@u{s}\q@u{ha}bi a\q@b{l}nn\q@u{a}ri wa\q@u{tha}lika jaz\q@u{a}o a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@dcxcix{Fa\q@u{t}awwaAAat lahu nafsuhu qatla akheehi faqatalahu faa\q@u{s}ba\q@u{h}a mina alkh\q@u{a}sireen\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@dcc{FabaAAatha All\q@u{a}hu ghur\q@u{a}ban yab\q@u{h}athu fee alar\q@u{d}i liyuriyahu kayfa yuw\q@u{a}ree sawata akheehi q\q@u{a}la y\q@u{a} waylat\q@u{a} aAAajaztu an akoona mithla h\q@u{atha} alghur\q@u{a}bi faow\q@u{a}riya sawata akhee faa\q@u{s}ba\q@u{h}a mina a\q@b{l}nn\q@u{a}dimeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@dcci{Min ajli \q@u{tha}lika katabn\q@u{a} AAal\q@u{a} banee isr\q@u{a}eela annahu man qatala nafsan bighayri nafsin aw fas\q@u{a}din fee alar\q@u{d}i fakaannam\q@u{a} qatala a\q@b{l}nn\q@u{a}sa jameeAAan waman a\q@u{h}y\q@u{a}h\q@u{a} fakaannam\q@u{a} a\q@u{h}y\q@u{a} a\q@b{l}nn\q@u{a}sa jameeAAan walaqad j\q@u{a}a thum rusulun\q@u{a} bi\q@b{a}lbayyin\q@u{a}ti thumma inna katheeran minhum baAAda \q@u{tha}lika fee alar\q@u{d}i lamusrifoon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@dccii{Innam\q@u{a} jaz\q@u{a}o alla\q@u{th}eena yu\q@u{ha}riboona All\q@u{a}ha warasoolahu wayasAAawna fee alar\q@u{d}i fas\q@u{a}dan an yuqattaloo aw yu\q@u{s}allaboo aw tuqa\q@u{tt}aAAa aydeehim waarjuluhum min khil\q@u{a}fin aw yunfaw mina alar\q@u{d}i \q@u{tha}lika lahum khizyun fee a\q@b{l}dduny\q@u{a} walahum fee al\q@u{a}khirati AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@dcciii{Ill\q@u{a} alla\q@u{th}eena t\q@u{a}boo min qabli an taqdiroo AAalayhim fa\q@b{i}AAlamoo anna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@dcciv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo ittaqoo All\q@u{a}ha wa\q@b{i}btaghoo ilayhi alwaseelata waj\q@u{a}hidoo fee sabeelihi laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@dccv{Inna alla\q@u{th}eena kafaroo law anna lahum m\q@u{a} fee alar\q@u{d}i jameeAAan wamithlahu maAAahu liyaftadoo bihi min AAa\q@u{tha}bi yawmi alqiy\q@u{a}mati m\q@u{a} tuqubbila minhum walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@dccvi{Yureedoona an yakhrujoo mina a\q@b{l}nn\q@u{a}ri wam\q@u{a} hum bikh\q@u{a}rijeena minh\q@u{a} walahum AAa\q@u{tha}bun muqeem\q@b{un}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@dccvii{Wa\q@b{al}ss\q@u{a}riqu wa\q@b{al}ss\q@u{a}riqatu fa\q@b{i}q\q@u{t}aAAoo aydiyahum\q@u{a} jaz\q@u{a}an bim\q@u{a} kasab\q@u{a} nak\q@u{a}lan mina All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@dccviii{Faman t\q@u{a}ba min baAAdi \q@i{\q@u{th}}ulmihi waa\q@u{s}la\q@u{h}a fainna All\q@u{a}ha yatoobu AAalayhi inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@dccix{Alam taAAlam anna All\q@u{a}ha lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i yuAAa\q@u{thth}ibu man yash\q@u{a}o wayaghfiru liman yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@dccx{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}rrasoolu l\q@u{a} ya\q@u{h}zunka alla\q@u{th}eena yus\q@u{a}riAAoona fee alkufri mina alla\q@u{th}eena q\q@u{a}loo \q@u{a}mann\q@u{a} biafw\q@u{a}hihim walam tumin quloobuhum wamina alla\q@u{th}eena h\q@u{a}doo samm\q@u{a}AAoona lilka\q@u{th}ibi samm\q@u{a}AAoona liqawmin \q@u{a}khareena lam yatooka yu\q@u{h}arrifoona alkalima min baAAdi maw\q@u{ad}iAAihi yaqooloona in ooteetum h\q@u{atha} fakhu\q@u{th}oohu wain lam tutawhu fa\q@b{i}\q@u{hth}aroo waman yuridi All\q@u{a}hu fitnatahu falan tamlika lahu mina All\q@u{a}hi shayan ol\q@u{a}ika alla\q@u{th}eena lam yuridi All\q@u{a}hu an yu\q@u{t}ahhira quloobahum lahum fee a\q@b{l}dduny\q@u{a} khizyun walahum fee al\q@u{a}khirati AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@dccxi{Samm\q@u{a}AAoona lilka\q@u{th}ibi akk\q@u{a}loona li\q@b{l}ssu\q@u{h}ti fain j\q@u{a}ooka fa\q@b{o}\q@u{h}kum baynahum aw aAAri\q@u{d} AAanhum wain tuAAri\q@u{d} AAanhum falan ya\q@u{d}urrooka shayan wain \q@u{h}akamta fa\q@b{o}\q@u{h}kum baynahum bi\q@b{a}lqis\q@u{t}i inna All\q@u{a}ha yu\q@u{h}ibbu almuqsi\q@u{t}een\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@dccxii{Wakayfa yu\q@u{h}akkimoonaka waAAindahumu a\q@b{l}ttawr\q@u{a}tu feeh\q@u{a} \q@u{h}ukmu All\q@u{a}hi thumma yatawallawna min baAAdi \q@u{tha}lika wam\q@u{a} ol\q@u{a}ika bi\q@b{a}lmumineen\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@dccxiii{Inn\q@u{a} anzaln\q@u{a} a\q@b{l}ttawr\q@u{a}ta feeh\q@u{a} hudan wanoorun ya\q@u{h}kumu bih\q@u{a} a\q@b{l}nnabiyyoona alla\q@u{th}eena aslamoo lilla\q@u{th}eena h\q@u{a}doo wa\q@b{al}rrabb\q@u{a}niyyoona wa\q@b{a}la\q@u{h}b\q@u{a}ru bim\q@u{a} istu\q@u{h}fi\q@i{\q@u{th}}oo min kit\q@u{a}bi All\q@u{a}hi wak\q@u{a}noo AAalayhi shuhad\q@u{a}a fal\q@u{a} takhshawoo a\q@b{l}nn\q@u{a}sa wa\q@b{i}khshawni wal\q@u{a} tashtaroo bi\q@u{a}y\q@u{a}tee thamanan qaleelan waman lam ya\q@u{h}kum bim\q@u{a} anzala All\q@u{a}hu faol\q@u{a}ika humu alk\q@u{a}firoon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@dccxiv{Wakatabn\q@u{a} AAalayhim feeh\q@u{a} anna a\q@b{l}nnafsa bi\q@b{al}nnafsi wa\q@b{a}lAAayna bi\q@b{a}lAAayni wa\q@b{a}lanfa bi\q@b{a}lanfi wa\q@b{a}lo\q@u{th}una bi\q@b{a}lo\q@u{th}uni wa\q@b{al}ssinna bi\q@b{al}ssinni wa\q@b{a}ljuroo\q@u{h}a qi\q@u{sas}un faman ta\q@u{s}addaqa bihi fahuwa kaff\q@u{a}ratun lahu waman lam ya\q@u{h}kum bim\q@u{a} anzala All\q@u{a}hu faol\q@u{a}ika humu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@dccxv{Waqaffayn\q@u{a} AAal\q@u{a} \q@u{a}th\q@u{a}rihim biAAees\q@u{a} ibni maryama mu\q@u{s}addiqan lim\q@u{a} bayna yadayhi mina a\q@b{l}ttawr\q@u{a}ti wa\q@u{a}tayn\q@u{a}hu alinjeela feehi hudan wanoorun wamu\q@u{s}addiqan lim\q@u{a} bayna yadayhi mina a\q@b{l}ttawr\q@u{a}ti wahudan wamawAAi\q@i{\q@u{th}}atan lilmuttaqeen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@dccxvi{Walya\q@u{h}kum ahlu alinjeeli bim\q@u{a} anzala All\q@u{a}hu feehi waman lam ya\q@u{h}kum bim\q@u{a} anzala All\q@u{a}hu faol\q@u{a}ika humu alf\q@u{a}siqoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@dccxvii{Waanzaln\q@u{a} ilayka alkit\q@u{a}ba bi\q@b{a}l\q@u{h}aqqi mu\q@u{s}addiqan lim\q@u{a} bayna yadayhi mina alkit\q@u{a}bi wamuhayminan AAalayhi fa\q@b{o}\q@u{h}kum baynahum bim\q@u{a} anzala All\q@u{a}hu wal\q@u{a} tattabiAA ahw\q@u{a}ahum AAamm\q@u{a} j\q@u{a}aka mina al\q@u{h}aqqi likullin jaAAaln\q@u{a} minkum shirAAatan waminh\q@u{a}jan walaw sh\q@u{a}a All\q@u{a}hu lajaAAalakum ommatan w\q@u{ah}idatan wal\q@u{a}kin liyabluwakum fee m\q@u{a} \q@u{a}t\q@u{a}kum fa\q@b{i}stabiqoo alkhayr\q@u{a}ti il\q@u{a} All\q@u{a}hi marjiAAukum jameeAAan fayunabbiokum bim\q@u{a} kuntum feehi takhtalifoon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@dccxviii{Waani o\q@u{h}kum baynahum bim\q@u{a} anzala All\q@u{a}hu wal\q@u{a} tattabiAA ahw\q@u{a}ahum wa\q@b{i}\q@u{hth}arhum an yaftinooka AAan baAA\q@u{d}i m\q@u{a} anzala All\q@u{a}hu ilayka fain tawallaw fa\q@b{i}AAlam annam\q@u{a} yureedu All\q@u{a}hu an yu\q@u{s}eebahum bibaAA\q@u{d}i \q@u{th}unoobihim wainna katheeran mina a\q@b{l}nn\q@u{a}si laf\q@u{a}siqoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@dccxix{Afa\q@u{h}ukma alj\q@u{a}hiliyyati yabghoona waman a\q@u{h}sanu mina All\q@u{a}hu \q@u{h}ukman liqawmin yooqinoon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@dccxx{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tattakhi\q@u{th}oo alyahooda wa\q@b{al}nna\q@u{sa}r\q@u{a} awliy\q@u{a}a baAA\q@u{d}uhum awliy\q@u{a}o baAA\q@u{d}in waman yatawallahum minkum fainnahu minhum inna All\q@u{a}ha l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@dccxxi{Fatar\q@u{a} alla\q@u{th}eena fee quloobihim mara\q@u{d}un yus\q@u{a}riAAoona feehim yaqooloona nakhsh\q@u{a} an tu\q@u{s}eeban\q@u{a} d\q@u{a}iratun faAAas\q@u{a} All\q@u{a}hu an yatiya bi\q@b{a}lfat\q@u{h}i aw amrin min AAindihi fayu\q@u{s}bi\q@u{h}oo AAal\q@u{a} m\q@u{a} asarroo fee anfusihim n\q@u{a}dimeen\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@dccxxii{Wayaqoolu alla\q@u{th}eena \q@u{a}manoo ah\q@u{a}ol\q@u{a}i alla\q@u{th}eena aqsamoo bi\q@b{A}ll\q@u{a}hi jahda aym\q@u{a}nihim innahum lamaAAakum \q@u{h}abi\q@u{t}at aAAm\q@u{a}luhum faa\q@u{s}ba\q@u{h}oo kh\q@u{a}sireen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@dccxxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo man yartadda minkum AAan deenihi fasawfa yatee All\q@u{a}hu biqawmin yu\q@u{h}ibbuhum wayu\q@u{h}ibboonahu a\q@u{th}illatin AAal\q@u{a} almumineena aAAizzatin AAal\q@u{a} alk\q@u{a}fireena yuj\q@u{a}hidoona fee sabeeli All\q@u{a}hi wal\q@u{a} yakh\q@u{a}foona lawmata l\q@u{a}imin \q@u{tha}lika fa\q@u{d}lu All\q@u{a}hi yuteehi man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu w\q@u{a}siAAun AAaleem\q@b{un}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@dccxxiv{Innam\q@u{a} waliyyukumu All\q@u{a}hu warasooluhu wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo alla\q@u{th}eena yuqeemoona a\q@b{l}\q@u{ss}al\q@u{a}ta wayutoona a\q@b{l}zzak\q@u{a}ta wahum r\q@u{a}kiAAoon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@dccxxv{Waman yatawalla All\q@u{a}ha warasoolahu wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo fainna \q@u{h}izba All\q@u{a}hi humu algh\q@u{a}liboon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@dccxxvi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tattakhi\q@u{th}oo alla\q@u{th}eena ittakha\q@u{th}oo deenakum huzuwan walaAAiban mina alla\q@u{th}eena ootoo alkit\q@u{a}ba min qablikum wa\q@b{a}lkuff\q@u{a}ra awliy\q@u{a}a wa\q@b{i}ttaqoo All\q@u{a}ha in kuntum mumineen\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@dccxxvii{Wai\q@u{tha} n\q@u{a}daytum il\q@u{a} a\q@b{l}\q@u{ss}al\q@u{a}ti ittakha\q@u{th}ooh\q@u{a} huzuwan walaAAiban \q@u{tha}lika biannahum qawmun l\q@u{a} yaAAqiloon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@dccxxviii{Qul y\q@u{a} ahla alkit\q@u{a}bi hal tanqimoona minn\q@u{a} ill\q@u{a} an \q@u{a}mann\q@u{a} bi\q@b{A}ll\q@u{a}hi wam\q@u{a} onzila ilayn\q@u{a} wam\q@u{a} onzila min qablu waanna aktharakum f\q@u{a}siqoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@dccxxix{Qul hal onabbiokum bisharrin min \q@u{tha}lika mathoobatan AAinda All\q@u{a}hi man laAAanahu All\q@u{a}hu wagha\q@u{d}iba AAalayhi wajaAAala minhumu alqiradata wa\q@b{a}lkhan\q@u{a}zeera waAAabada a\q@b{l}\q@u{tta}ghooti ol\q@u{a}ika sharrun mak\q@u{a}nan waa\q@u{d}allu AAan saw\q@u{a}i a\q@b{l}ssabeel\q@b{i}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@dccxxx{Wai\q@u{tha} j\q@u{a}ookum q\q@u{a}loo \q@u{a}mann\q@u{a} waqad dakhaloo bi\q@b{a}lkufri wahum qad kharajoo bihi wa\q@b{A}ll\q@u{a}hu aAAlamu bim\q@u{a} k\q@u{a}noo yaktumoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@dccxxxi{Watar\q@u{a} katheeran minhum yus\q@u{a}riAAoona fee alithmi wa\q@b{a}lAAudw\q@u{a}ni waaklihimu a\q@b{l}ssu\q@u{h}ta labisa m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@dccxxxii{Lawl\q@u{a} yanh\q@u{a}humu a\q@b{l}rrabb\q@u{a}niyyoona wa\q@b{a}la\q@u{h}b\q@u{a}ru AAan qawlihimu alithma waaklihimu a\q@b{l}ssu\q@u{h}ta labisa m\q@u{a} k\q@u{a}noo ya\q@u{s}naAAoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@dccxxxiii{Waq\q@u{a}lati alyahoodu yadu All\q@u{a}hi maghloolatun ghullat aydeehim waluAAinoo bim\q@u{a} q\q@u{a}loo bal yad\q@u{a}hu mabsoo\q@u{t}at\q@u{a}ni yunfiqu kayfa yash\q@u{a}o walayazeedanna katheeran minhum m\q@u{a} onzila ilayka min rabbika \q@u{t}ughy\q@u{a}nan wakufran waalqayn\q@u{a} baynahumu alAAad\q@u{a}wata wa\q@b{a}lbagh\q@u{da}a il\q@u{a} yawmi alqiy\q@u{a}mati kullam\q@u{a} awqadoo n\q@u{a}ran lil\q@u{h}arbi a\q@u{t}faah\q@u{a} All\q@u{a}hu wayasAAawna fee alar\q@u{d}i fas\q@u{a}dan wa\q@b{A}ll\q@u{a}hu l\q@u{a} yu\q@u{h}ibbu almufsideen\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@dccxxxiv{Walaw anna ahla alkit\q@u{a}bi \q@u{a}manoo wa\q@b{i}ttaqaw lakaffarn\q@u{a} AAanhum sayyi\q@u{a}tihim walaadkhaln\q@u{a}hum jann\q@u{a}ti a\q@b{l}nnaAAeem\q@b{i}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@dccxxxv{Walaw annahum aq\q@u{a}moo a\q@b{l}ttawr\q@u{a}ta wa\q@b{a}linjeela wam\q@u{a} onzila ilayhim min rabbihim laakaloo min fawqihim wamin ta\q@u{h}ti arjulihim minhum ommatun muqta\q@u{s}idatun wakatheerun minhum s\q@u{a}a m\q@u{a} yaAAmaloon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@dccxxxvi{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}rrasoolu balligh m\q@u{a} onzila ilayka min rabbika wain lam tafAAal fam\q@u{a} ballaghta ris\q@u{a}latahu wa\q@b{A}ll\q@u{a}hu yaAA\q@u{s}imuka mina a\q@b{l}nn\q@u{a}si inna All\q@u{a}ha l\q@u{a} yahdee alqawma alk\q@u{a}fireen\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@dccxxxvii{Qul y\q@u{a} ahla alkit\q@u{a}bi lastum AAal\q@u{a} shayin \q@u{h}att\q@u{a} tuqeemoo a\q@b{l}ttawr\q@u{a}ta wa\q@b{a}linjeela wam\q@u{a} onzila ilaykum min rabbikum walayazeedanna katheeran minhum m\q@u{a} onzila ilayka min rabbika \q@u{t}ughy\q@u{a}nan wakufran fal\q@u{a} tasa AAal\q@u{a} alqawmi alk\q@u{a}fireen\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@dccxxxviii{Inna alla\q@u{th}eena \q@u{a}manoo wa\q@b{a}lla\q@u{th}eena h\q@u{a}doo wa\q@b{al}\q@u{ssa}bioona wa\q@b{al}nna\q@u{sa}r\q@u{a} man \q@u{a}mana bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri waAAamila \q@u{sa}li\q@u{h}an fal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@dccxxxix{Laqad akha\q@u{th}n\q@u{a} meeth\q@u{a}qa banee isr\q@u{a}eela waarsaln\q@u{a} ilayhim rusulan kullam\q@u{a} j\q@u{a}ahum rasoolun bim\q@u{a} l\q@u{a} tahw\q@u{a} anfusuhum fareeqan ka\q@u{thth}aboo wafareeqan yaqtuloon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@dccxl{Wa\q@u{h}asiboo all\q@u{a} takoona fitnatun faAAamoo wa\q@u{s}ammoo thumma t\q@u{a}ba All\q@u{a}hu AAalayhim thumma AAamoo wa\q@u{s}ammoo katheerun minhum wa\q@b{A}ll\q@u{a}hu ba\q@u{s}eerun bim\q@u{a} yaAAmaloon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@dccxli{Laqad kafara alla\q@u{th}eena q\q@u{a}loo inna All\q@u{a}ha huwa almasee\q@u{h}u ibnu maryama waq\q@u{a}la almasee\q@u{h}u y\q@u{a} banee isr\q@u{a}eela oAAbudoo All\q@u{a}ha rabbee warabbakum innahu man yushrik bi\q@b{A}ll\q@u{a}hi faqad \q@u{h}arrama All\q@u{a}hu AAalayhi aljannata wamaw\q@u{a}hu a\q@b{l}nn\q@u{a}ru wam\q@u{a} li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena min an\q@u{sa}r\q@b{in}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@dccxlii{Laqad kafara alla\q@u{th}eena q\q@u{a}loo inna All\q@u{a}ha th\q@u{a}lithu thal\q@u{a}thatin wam\q@u{a} min il\q@u{a}hin ill\q@u{a} il\q@u{a}hun w\q@u{ah}idun wain lam yantahoo AAamm\q@u{a} yaqooloona layamassanna alla\q@u{th}eena kafaroo minhum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@dccxliii{Afal\q@u{a} yatooboona il\q@u{a} All\q@u{a}hi wayastaghfiroonahu wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@dccxliv{M\q@u{a} almasee\q@u{h}u ibnu maryama ill\q@u{a} rasoolun qad khalat min qablihi a\q@b{l}rrusulu waommuhu \q@u{s}iddeeqatun k\q@u{a}n\q@u{a} yakul\q@u{a}ni a\q@b{l}\q@u{tt}aAA\q@u{a}ma on\q@i{\q@u{th}}ur kayfa nubayyinu lahumu al\q@u{a}y\q@u{a}ti thumma on\q@i{\q@u{th}}ur ann\q@u{a} yufakoon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@dccxlv{Qul ataAAbudoona min dooni All\q@u{a}hi m\q@u{a} l\q@u{a} yamliku lakum \q@u{d}arran wal\q@u{a} nafAAan wa\q@b{A}ll\q@u{a}hu huwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@dccxlvi{Qul y\q@u{a} ahla alkit\q@u{a}bi l\q@u{a} taghloo fee deenikum ghayra al\q@u{h}aqqi wal\q@u{a }tattabiAAoo ahw\q@u{a}a qawmin qad \q@u{d}alloo min qablu waa\q@u{d}alloo katheeran wa\q@u{d}alloo AAan saw\q@u{a}i a\q@b{l}ssabeel\q@b{i}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@dccxlvii{LuAAina alla\q@u{th}eena kafaroo min banee isr\q@u{a}eela AAal\q@u{a} lis\q@u{a}ni d\q@u{a}wooda waAAees\q@u{a} ibni maryama \q@u{tha}lika bim\q@u{a} AAa\q@u{s}aw wak\q@u{a}noo yaAAtadoon\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@dccxlviii{K\q@u{a}noo l\q@u{a} yatan\q@u{a}hawna AAan munkarin faAAaloohu labisa m\q@u{a} k\q@u{a}noo yafAAaloon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@dccxlix{Tar\q@u{a} katheeran minhum yatawallawna alla\q@u{th}eena kafaroo labisa m\q@u{a }qaddamat lahum anfusuhum an sakhi\q@u{t}a All\q@u{a}hu AAalayhim wafee alAAa\q@u{tha}bi hum kh\q@u{a}lidoon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@dccl{Walaw k\q@u{a}noo yuminoona bi\q@b{A}ll\q@u{a}hi wa\q@b{al}nnabiyyi wam\q@u{a} onzila ilayhi m\q@u{a} ittakha\q@u{th}oohum awliy\q@u{a}a wal\q@u{a}kinna katheeran minhum f\q@u{a}siqoon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@dccli{Latajidanna ashadda a\q@b{l}nn\q@u{a}si AAad\q@u{a}watan lilla\q@u{th}eena \q@u{a}manoo alyahooda wa\q@b{a}lla\q@u{th}eena ashrakoo walatajidanna aqrabahum mawaddatan lilla\q@u{th}eena \q@u{a}manoo alla\q@u{th}eena q\q@u{a}loo inn\q@u{a} na\q@u{sa}r\q@u{a} \q@u{tha}lika bianna minhum qisseeseena waruhb\q@u{a}nan waannahum l\q@u{a} yastakbiroon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@dcclii{Wai\q@u{tha} samiAAoo m\q@u{a} onzila il\q@u{a} a\q@b{l}rrasooli tar\q@u{a} aAAyunahum tafee\q@u{d}u mina a\q@b{l}ddamAAi mimm\q@u{a} AAarafoo mina al\q@u{h}aqqi yaqooloona rabban\q@u{a} \q@u{a}mann\q@u{a} fa\q@b{o}ktubn\q@u{a} maAAa a\q@b{l}shsh\q@u{a}hideen\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@dccliii{Wam\q@u{a} lan\q@u{a} l\q@u{a} numinu bi\q@b{A}ll\q@u{a}hi wam\q@u{a} j\q@u{a}an\q@u{a} mina al\q@u{h}aqqi wana\q@u{t}maAAu an yudkhilan\q@u{a} rabbun\q@u{a} maAAa alqawmi a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@dccliv{Faath\q@u{a}bahumu All\q@u{a}hu bim\q@u{a} q\q@u{a}loo jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} wa\q@u{tha}lika jaz\q@u{a}o almu\q@u{h}sineen\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@dcclv{Wa\q@b{a}lla\q@u{th}eena kafaroo waka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} ol\q@u{a}ika a\q@u{s}\q@u{ha}bu alja\q@u{h}eem\q@b{i}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@dcclvi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tu\q@u{h}arrimoo \q@u{t}ayyib\q@u{a}ti m\q@u{a} a\q@u{h}alla All\q@u{a}hu lakum wal\q@u{a} taAAtadoo inna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu almuAAtadeen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@dcclvii{Wakuloo mimm\q@u{a} razaqakumu All\q@u{a}hu \q@u{h}al\q@u{a}lan \q@u{t}ayyiban wa\q@b{i}ttaqoo All\q@u{a}ha alla\q@u{th}ee antum bihi muminoon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@dcclviii{L\q@u{a} yu\q@u{a}khi\q@u{th}ukumu All\q@u{a}hu bi\q@b{a}llaghwi fee aym\q@u{a}nikum wal\q@u{a}kin yu\q@u{a}khi\q@u{th}ukum bim\q@u{a} AAaqqadtumu alaym\q@u{a}na fakaff\q@u{a}ratuhu i\q@u{t}AA\q@u{a}mu AAasharati mas\q@u{a}keena min awsa\q@u{t}i m\q@u{a} tu\q@u{t}AAimoona ahleekum aw kiswatuhum aw ta\q@u{h}reeru raqabatin faman lam yajid fa\q@u{s}iy\q@u{a}mu thal\q@u{a}thati ayy\q@u{a}min \q@u{tha}lika kaff\q@u{a}ratu aym\q@u{a}nikum i\q@u{tha} \q@u{h}alaftum wa\q@b{i}\q@u{h}fa\q@i{\q@u{th}}oo aym\q@u{a}nakum ka\q@u{tha}lika yubayyinu All\q@u{a}hu lakum \q@u{a}y\q@u{a}tihi laAAallakum tashkuroon\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@dcclix{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo innam\q@u{a} alkhamru wa\q@b{a}lmaysiru wa\q@b{a}lan\q@u{sa}bu wa\q@b{a}lazl\q@u{a}mu rijsun min AAamali a\q@b{l}shshay\q@u{ta}ni fa\q@b{i}jtaniboohu laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@dcclx{Innam\q@u{a} yureedu a\q@b{l}shshay\q@u{ta}nu an yooqiAAa baynakumu alAAad\q@u{a}wata wa\q@b{a}lbagh\q@u{da}a fee alkhamri wa\q@b{a}lmaysiri waya\q@u{s}uddakum AAan \q@u{th}ikri All\q@u{a}hi waAAani a\q@b{l}\q@u{ss}al\q@u{a}ti fahal antum muntahoon\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@dcclxi{Waa\q@u{t}eeAAoo All\q@u{a}ha waa\q@u{t}eeAAoo a\q@b{l}rrasoola wa\q@b{i}\q@u{hth}aroo fain tawallaytum fa\q@b{i}AAlamoo annam\q@u{a} AAal\q@u{a} rasoolin\q@u{a} albal\q@u{a}ghu almubeen\q@b{u}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@dcclxii{Laysa AAal\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti jun\q@u{ah}un feem\q@u{a} \q@u{t}aAAimoo i\q@u{tha} m\q@u{a} ittaqaw wa\q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti thumma ittaqaw wa\q@u{a}manoo thumma ittaqaw waa\q@u{h}sanoo wa\q@b{A}ll\q@u{a}hu yu\q@u{h}ibbu almu\q@u{h}sineen\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@dcclxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo layabluwannakumu All\q@u{a}hu bishayin mina a\q@b{l}\q@u{ss}aydi tan\q@u{a}luhu aydeekum warim\q@u{ah}ukum liyaAAlama All\q@u{a}hu man yakh\q@u{a}fuhu bi\q@b{a}lghaybi famani iAAtad\q@u{a} baAAda \q@u{tha}lika falahu AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@dcclxiv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} taqtuloo a\q@b{l}\q@u{ss}ayda waantum \q@u{h}urumun waman qatalahu minkum mutaAAammidan fajaz\q@u{a}on mithlu m\q@u{a} qatala mina a\q@b{l}nnaAAami ya\q@u{h}kumu bihi \q@u{th}aw\q@u{a} AAadlin minkum hadyan b\q@u{a}ligha alkaAAbati aw kaff\q@u{a}ratun \q@u{t}aAA\q@u{a}mu mas\q@u{a}keena aw AAadlu \q@u{tha}lika \q@u{s}iy\q@u{a}man liya\q@u{th}ooqa wab\q@u{a}la amrihi AAaf\q@u{a} All\q@u{a}hu AAamm\q@u{a} salafa waman AA\q@u{a}da fayantaqimu All\q@u{a}hu minhu wa\q@b{A}ll\q@u{a}hu AAazeezun \q@u{th}oo intiq\q@u{a}m\q@b{in}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@dcclxv{O\q@u{h}illa lakum \q@u{s}aydu alba\q@u{h}ri wa\q@u{t}aAA\q@u{a}muhu mat\q@u{a}AAan lakum wali\q@b{l}ssayy\q@u{a}rati wa\q@u{h}urrima AAalaykum \q@u{s}aydu albarri m\q@u{a} dumtum \q@u{h}uruman wa\q@b{i}ttaqoo All\q@u{a}ha alla\q@u{th}ee ilayhi tu\q@u{h}sharoon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@dcclxvi{JaAAala All\q@u{a}hu alkaAAbata albayta al\q@u{h}ar\q@u{a}ma qiy\q@u{a}man li\q@b{l}nn\q@u{a}si wa\q@b{al}shshahra al\q@u{h}ar\q@u{a}ma wa\q@b{a}lhadya wa\q@b{a}lqal\q@u{a}ida \q@u{tha}lika litaAAlamoo anna All\q@u{a}ha yaAAlamu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i waanna All\q@u{a}ha bikulli shayin AAaleem\q@b{un}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@dcclxvii{IAAlamoo anna All\q@u{a}ha shadeedu alAAiq\q@u{a}bi waanna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@dcclxviii{M\q@u{a} AAal\q@u{a} a\q@b{l}rrasooli ill\q@u{a} albal\q@u{a}ghu wa\q@b{A}ll\q@u{a}hu yaAAlamu m\q@u{a} tubdoona wam\q@u{a} taktumoon\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@dcclxix{Qul l\q@u{a} yastawee alkhabeethu wa\q@b{al}\q@u{tt}ayyibu walaw aAAjabaka kathratu alkhabeethi fa\q@b{i}ttaqoo All\q@u{a}ha y\q@u{a} olee alalb\q@u{a}bi laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@dcclxx{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tasaloo AAan ashy\q@u{a}a in tubda lakum tasukum wain tasaloo AAanh\q@u{a} \q@u{h}eena yunazzalu alqur\q@u{a}nu tubda lakum AAaf\q@u{a} All\q@u{a}hu AAanh\q@u{a} wa\q@b{A}ll\q@u{a}hu ghafoorun \q@u{h}aleem\q@b{un}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@dcclxxi{Qad saalah\q@u{a} qawmun min qablikum thumma a\q@u{s}ba\q@u{h}oo bih\q@u{a} k\q@u{a}fireen\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@dcclxxii{M\q@u{a} jaAAala All\q@u{a}hu min ba\q@u{h}eeratin wal\q@u{a} s\q@u{a}ibatin wal\q@u{a} wa\q@u{s}eelatin wal\q@u{a} \q@u{ha}min wal\q@u{a}kinna alla\q@u{th}eena kafaroo yaftaroona AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba waaktharuhum l\q@u{a} yaAAqiloon\q@b{a}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@dcclxxiii{Wai\q@u{tha} qeela lahum taAA\q@u{a}law il\q@u{a} m\q@u{a} anzala All\q@u{a}hu wail\q@u{a} a\q@b{l}rrasooli q\q@u{a}loo \q@u{h}asbun\q@u{a} m\q@u{a} wajadn\q@u{a} AAalayhi \q@u{a}b\q@u{a}an\q@u{a} awalaw k\q@u{a}na \q@u{a}b\q@u{a}ohum l\q@u{a} yaAAlamoona shayan wal\q@u{a} yahtadoon\q@b{a}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@dcclxxiv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo AAalaykum anfusakum l\q@u{a} ya\q@u{d}urrukum man \q@u{d}alla i\q@u{th}a ihtadaytum il\q@u{a} All\q@u{a}hi marjiAAukum jameeAAan fayunabbiokum bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@dcclxxv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo shah\q@u{a}datu baynikum i\q@u{tha} \q@u{h}a\q@u{d}ara a\q@u{h}adakumu almawtu \q@u{h}eena alwa\q@u{s}iyyati ithn\q@u{a}ni \q@u{th}aw\q@u{a} AAadlin minkum aw \q@u{a}khar\q@u{a}ni min ghayrikum in antum \q@u{d}arabtum fee alar\q@u{d}i faa\q@u{sa}batkum mu\q@u{s}eebatu almawti ta\q@u{h}bisoonahum\q@u{a} min baAAdi a\q@b{l}\q@u{ss}al\q@u{a}ti fayuqsim\q@u{a}ni bi\q@b{A}ll\q@u{a}hi ini irtabtum l\q@u{a} nashtaree bihi thamanan walaw k\q@u{a}na \q@u{tha} qurb\q@u{a} wal\q@u{a} naktumu shah\q@u{a}data All\q@u{a}hi inn\q@u{a} i\q@u{th}an lamina al\q@u{a}thimeen\q@b{a}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@dcclxxvi{Fain AAuthira AAal\q@u{a} annahum\q@u{a} ista\q@u{h}aqq\q@u{a} ithman fa\q@u{a}khara\q@u{n}i yaqoom\q@u{a}ni maq\q@u{a}mahum\q@u{a} mina alla\q@u{th}eena ista\q@u{h}aqqa AAalayhimu alawlay\q@u{a}ni fayuqsim\q@u{a}ni bi\q@b{A}ll\q@u{a}hi lashah\q@u{a}datun\q@u{a} a\q@u{h}aqqu min shah\q@u{a}datihim\q@u{a} wam\q@u{a} iAAtadayn\q@u{a} inn\q@u{a} i\q@u{th}an lamina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@dcclxxvii{\q@u{Tha}lika adn\q@u{a} an yatoo bi\q@b{al}shshah\q@u{a}dati AAal\q@u{a} wajhih\q@u{a} aw yakh\q@u{a}foo an turadda aym\q@u{a}nun baAAda aym\q@u{a}nihim wa\q@b{i}ttaqoo All\q@u{a}ha wa\q@b{i}smaAAoo wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma alf\q@u{a}siqeen\q@b{a}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@dcclxxviii{Yawma yajmaAAu All\q@u{a}hu a\q@b{l}rrusula fayaqoolu m\q@u{atha} ojibtum q\q@u{a}loo l\q@u{a} AAilma lan\q@u{a} innaka anta AAall\q@u{a}mu alghuyoob\q@b{i}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@dcclxxix{I\q@u{th} q\q@u{a}la All\q@u{a}hu y\q@u{a} AAees\q@u{a} ibna maryama o\q@u{th}kur niAAmatee AAalayka waAAal\q@u{a} w\q@u{a}lidatika i\q@u{th} ayyadtuka biroo\q@u{h}i alqudusi tukallimu a\q@b{l}nn\q@u{a}sa fee almahdi wakahlan wai\q@u{th} AAallamtuka alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ikmata wa\q@b{al}ttawr\q@u{a}ta wa\q@b{a}linjeela wai\q@u{th} takhluqu mina a\q@b{l}\q@u{tt}eeni kahayati a\q@b{l}\q@u{tt}ayri bii\q@u{th}nee fatanfukhu feeh\q@u{a} fatakoonu \q@u{t}ayran bii\q@u{th}nee watubrio alakmaha wa\q@b{a}labra\q@u{s}a bii\q@u{th}nee wai\q@u{th} tukhriju almawt\q@u{a} bii\q@u{th}nee wai\q@u{th} kafaftu banee isr\q@u{a}eela AAanka i\q@u{th} jitahum bi\q@b{a}lbayyin\q@u{a}ti faq\q@u{a}la alla\q@u{th}eena kafaroo minhum in h\q@u{atha} ill\q@u{a} si\q@u{h}run mubeen\q@b{un}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@dcclxxx{Wai\q@u{th} aw\q@u{h}aytu il\q@u{a} al\q@u{h}aw\q@u{a}riyyeena an \q@u{a}minoo bee wabirasoolee q\q@u{a}loo \q@u{a}mann\q@u{a} wa\q@b{i}shhad biannan\q@u{a} muslimoon\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@dcclxxxi{I\q@u{th} q\q@u{a}la al\q@u{h}aw\q@u{a}riyyoona y\q@u{a} AAees\q@u{a} ibna maryama hal yasta\q@u{t}eeAAu rabbuka an yunazzila AAalayn\q@u{a} m\q@u{a}idatan mina a\q@b{l}ssam\q@u{a}i q\q@u{a}la ittaqoo All\q@u{a}ha in kuntum mumineen\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@dcclxxxii{Q\q@u{a}loo nureedu an nakula minh\q@u{a} wata\q@u{t}mainna quloobun\q@u{a} wanaAAlama an qad \q@u{s}adaqtan\q@u{a} wanakoona AAalayh\q@u{a} mina a\q@b{l}shsh\q@u{a}hideen\q@b{a}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@dcclxxxiii{Q\q@u{a}la AAees\q@u{a} ibnu maryama all\q@u{a}humma rabban\q@u{a} anzil AAalayn\q@u{a} m\q@u{a}idatan mina a\q@b{l}ssam\q@u{a}i takoonu lan\q@u{a} AAeedan liawwalin\q@u{a} wa\q@u{a}khirin\q@u{a} wa\q@u{a}yatan minka wa\q@b{o}rzuqn\q@u{a} waanta khayru a\q@b{l}rr\q@u{a}ziqeen\q@b{a}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@dcclxxxiv{Q\q@u{a}la All\q@u{a}hu innee munazziluh\q@u{a} AAalaykum faman yakfur baAAdu minkum fainnee oAAa\q@u{thth}ibuhu AAa\q@u{tha}ban l\q@u{a} oAAa\q@u{thth}ibuhu a\q@u{h}adan mina alAA\q@u{a}lameen\q@b{a}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@dcclxxxv{Wai\q@u{th} q\q@u{a}la All\q@u{a}hu y\q@u{a} AAees\q@u{a} ibna maryama aanta qulta li\q@b{l}nn\q@u{a}si ittakhi\q@u{th}oonee waommiya il\q@u{a}hayni min dooni All\q@u{a}hi q\q@u{a}la sub\q@u{ha}naka m\q@u{a} yakoonu lee an aqoola m\q@u{a} laysa lee bi\q@u{h}aqqin in kuntu qultuhu faqad AAalimtahu taAAlamu m\q@u{a} fee nafsee wal\q@u{a} aAAlamu m\q@u{a} fee nafsika innaka anta AAall\q@u{a}mu alghuyoob\q@b{i}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@dcclxxxvi{M\q@u{a} qultu lahum ill\q@u{a} m\q@u{a} amartanee bihi ani oAAbudoo All\q@u{a}ha rabbee warabbakum wakuntu AAalayhim shaheedan m\q@u{a} dumtu feehim falamm\q@u{a} tawaffaytanee kunta anta a\q@b{l}rraqeeba AAalayhim waanta AAal\q@u{a} kulli shayin shaheed\q@b{un}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@dcclxxxvii{In tuAAa\q@u{thth}ibhum fainnahum AAib\q@u{a}duka wain taghfir lahum fainnaka anta alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@dcclxxxviii{Q\q@u{a}la All\q@u{a}hu h\q@u{atha} yawmu yanfaAAu a\q@b{l}\q@u{ssa}diqeena \q@u{s}idquhum lahum jann\q@u{a}tun tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} abadan ra\q@u{d}iya All\q@u{a}hu AAanhum wara\q@u{d}oo AAanhu \q@u{tha}lika alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@dcclxxxix{Lill\q@u{a}hi mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} feehinna wahuwa AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@dccxc{\basmalahlt Al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wajaAAala a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti wa\q@b{al}nnoora thumma alla\q@u{th}eena kafaroo birabbihim yaAAdiloon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@dccxci{Huwa alla\q@u{th}ee khalaqakum min \q@u{t}eenin thumma qa\q@u{da} ajalan waajalun musamman AAindahu thumma antum tamtaroon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@dccxcii{Wahuwa All\q@u{a}hu fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wafee alar\q@u{d}i yaAAlamu sirrakum wajahrakum wayaAAlamu m\q@u{a} taksiboon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@dccxciii{Wam\q@u{a} tateehim min \q@u{a}yatin min \q@u{a}y\q@u{a}ti rabbihim ill\q@u{a} k\q@u{a}noo AAanh\q@u{a} muAAri\q@u{d}een\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@dccxciv{Faqad ka\q@u{thth}aboo bi\q@b{a}l\q@u{h}aqqi lamm\q@u{a} j\q@u{a}ahum fasawfa yateehim anb\q@u{a}o m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@dccxcv{Alam yaraw kam ahlakn\q@u{a} min qablihim min qarnin makkann\q@u{a}hum fee alar\q@u{d}i m\q@u{a} lam numakkin lakum waarsaln\q@u{a} a\q@b{l}ssam\q@u{a}a AAalayhim midr\q@u{a}ran wajaAAaln\q@u{a} alanh\q@u{a}ra tajree min ta\q@u{h}tihim faahlakn\q@u{a}hum bi\q@u{th}unoobihim waanshan\q@u{a} min baAAdihim qarnan \q@u{a}khareen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@dccxcvi{Walaw nazzaln\q@u{a} AAalayka kit\q@u{a}ban fee qir\q@u{ta}sin falamasoohu biaydeehim laq\q@u{a}la alla\q@u{th}eena kafaroo in h\q@u{atha} ill\q@u{a} si\q@u{h}run mubeen\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@dccxcvii{Waq\q@u{a}loo lawl\q@u{a} onzila AAalayhi malakun walaw anzaln\q@u{a} malakan laqu\q@u{d}iya alamru thumma l\q@u{a} yun\q@i{\q@u{th}}aroon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@dccxcviii{Walaw jaAAaln\q@u{a}hu malakan lajaAAaln\q@u{a}hu rajulan walalabasn\q@u{a} AAalayhim m\q@u{a} yalbisoon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@dccxcix{Walaqadi istuhzia birusulin min qablika fa\q@u{ha}qa bi\q@b{a}lla\q@u{th}eena sakhiroo minhum m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@dccc{Qul seeroo fee alar\q@u{d}i thumma on\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu almuka\q@u{thth}ibeen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@dccci{Qul liman m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i qul lill\q@u{a}hi kataba AAal\q@u{a} nafsihi a\q@b{l}rra\q@u{h}mata layajmaAAannakum il\q@u{a} yawmi alqiy\q@u{a}mati l\q@u{a} rayba feehi alla\q@u{th}eena khasiroo anfusahum fahum l\q@u{a} yuminoon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@dcccii{Walahu m\q@u{a} sakana fee allayli wa\q@b{al}nnah\q@u{a}ri wahuwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@dccciii{Qul aghayra All\q@u{a}hi attakhi\q@u{th}u waliyyan f\q@u{at}iri a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wahuwa yu\q@u{t}AAimu wal\q@u{a} yu\q@u{t}AAamu qul innee omirtu an akoona awwala man aslama wal\q@u{a} takoonanna mina almushrikeen\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@dccciv{Qul innee akh\q@u{a}fu in AAa\q@u{s}aytu rabbee AAa\q@u{tha}ba yawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@dcccv{Man yu\q@u{s}raf AAanhu yawmai\q@u{th}in faqad ra\q@u{h}imahu wa\q@u{tha}lika alfawzu almubeen\q@b{u}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@dcccvi{Wain yamsaska All\q@u{a}hu bi\q@u{d}urrin fal\q@u{a} k\q@u{a}shifa lahu ill\q@u{a} huwa wain yamsaska bikhayrin fahuwa AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@dcccvii{Wahuwa alq\q@u{a}hiru fawqa AAib\q@u{a}dihi wahuwa al\q@u{h}akeemu alkhabeer\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@dcccviii{Qul ayyu shayin akbaru shah\q@u{a}datan quli All\q@u{a}hu shaheedun baynee wabaynakum waoo\q@u{h}iya ilayya h\q@u{atha} alqur\q@u{a}nu lion\q@u{th}irakum bihi waman balagha ainnakum latashhadoona anna maAAa All\q@u{a}hi \q@u{a}lihatan okhr\q@u{a} qul l\q@u{a} ashhadu qul innam\q@u{a} huwa il\q@u{a}hun w\q@u{ah}idun wainnanee bareeon mimm\q@u{a} tushrikoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@dcccix{Alla\q@u{th}eena \q@u{a}tayn\q@u{a}humu alkit\q@u{a}ba yaAArifoonahu kam\q@u{a} yaAArifoona abn\q@u{a}ahum alla\q@u{th}eena khasiroo anfusahum fahum l\q@u{a} yuminoon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@dcccx{Waman a\q@i{\q@u{th}}lamu mimmani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban aw ka\q@u{thth}aba bi\q@u{a}y\q@u{a}tihi innahu l\q@u{a} yufli\q@u{h}u a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@dcccxi{Wayawma na\q@u{h}shuruhum jameeAAan thumma naqoolu lilla\q@u{th}eena ashrakoo ayna shurak\q@u{a}okumu alla\q@u{th}eena kuntum tazAAumoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@dcccxii{Thumma lam takun fitnatuhum ill\q@u{a} an q\q@u{a}loo wa\q@b{A}ll\q@u{a}hi rabbin\q@u{a} m\q@u{a} kunn\q@u{a} mushrikeen\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@dcccxiii{On\q@i{\q@u{th}}ur kayfa ka\q@u{th}aboo AAal\q@u{a} anfusihim wa\q@u{d}alla AAanhum m\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@dcccxiv{Waminhum man yastamiAAu ilayka wajaAAaln\q@u{a} AAal\q@u{a} quloobihim akinnatan an yafqahoohu wafee \q@u{atha}nihim waqran wain yaraw kulla \q@u{a}yatin l\q@u{a} yuminoo bih\q@u{a} \q@u{h}att\q@u{a} i\q@u{tha} j\q@u{a}ooka yuj\q@u{a}diloonaka yaqoolu alla\q@u{th}eena kafaroo in h\q@u{atha} ill\q@u{a} as\q@u{at}eeru alawwaleen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@dcccxv{Wahum yanhawna AAanhu wayanawna AAanhu wain yuhlikoona ill\q@u{a} anfusahum wam\q@u{a} yashAAuroon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@dcccxvi{Walaw tar\q@u{a} i\q@u{th} wuqifoo AAal\q@u{a} a\q@b{l}nn\q@u{a}ri faq\q@u{a}loo y\q@u{a} laytan\q@u{a} nuraddu wal\q@u{a} nuka\q@u{thth}iba bi\q@u{a}y\q@u{a}ti rabbin\q@u{a} wanakoona mina almumineen\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@dcccxvii{Bal bad\q@u{a} lahum m\q@u{a} k\q@u{a}noo yukhfoona min qablu walaw ruddoo laAA\q@u{a}doo lim\q@u{a} nuhoo AAanhu wainnahum lak\q@u{ath}iboon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@dcccxviii{Waq\q@u{a}loo in hiya ill\q@u{a} \q@u{h}ay\q@u{a}tun\q@u{a} a\q@b{l}dduny\q@u{a} wam\q@u{a} na\q@u{h}nu bimabAAootheen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@dcccxix{Walaw tar\q@u{a} i\q@u{th} wuqifoo AAal\q@u{a} rabbihim q\q@u{a}la alaysa h\q@u{atha} bi\q@b{a}l\q@u{h}aqqi q\q@u{a}loo bal\q@u{a} warabbin\q@u{a} q\q@u{a}la fa\q@u{th}ooqoo alAAa\q@u{tha}ba bim\q@u{a} kuntum takfuroon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@dcccxx{Qad khasira alla\q@u{th}eena ka\q@u{thth}aboo biliq\q@u{a}i All\q@u{a}hi \q@u{h}att\q@u{a} i\q@u{tha} j\q@u{a}athumu a\q@b{l}ss\q@u{a}AAatu baghtatan q\q@u{a}loo y\q@u{a} \q@u{h}asratan\q@u{a} AAal\q@u{a} m\q@u{a} farra\q@u{t}n\q@u{a} feeh\q@u{a} wahum ya\q@u{h}miloona awz\q@u{a}rahum AAal\q@u{a} \q@i{\q@u{th}}uhoorihim al\q@u{a} s\q@u{a}a m\q@u{a} yaziroon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@dcccxxi{Wam\q@u{a} al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} ill\q@u{a} laAAibun walahwun wala\q@b{l}dd\q@u{a}ru al\q@u{a}khirati khayrun lilla\q@u{th}eena yattaqoona afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@dcccxxii{Qad naAAlamu innahu laya\q@u{h}zunuka alla\q@u{th}ee yaqooloona fainnahum l\q@u{a} yuka\q@u{thth}iboonaka wal\q@u{a}kinna a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena bi\q@u{a}y\q@u{a}ti All\q@u{a}hi yaj\q@u{h}adoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@dcccxxiii{Walaqad ku\q@u{thth}ibat rusulun min qablika fa\q@u{s}abaroo AAal\q@u{a} m\q@u{a} ku\q@u{thth}iboo waoo\q@u{th}oo \q@u{h}att\q@u{a} at\q@u{a}hum na\q@u{s}run\q@u{a} wal\q@u{a} mubaddila likalim\q@u{a}ti All\q@u{a}hi walaqad j\q@u{a}aka min nabai almursaleen\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@dcccxxiv{Wain k\q@u{a}na kabura AAalayka iAAr\q@u{ad}uhum faini ista\q@u{t}aAAta an tabtaghiya nafaqan fee alar\q@u{d}i aw sullaman fee a\q@b{l}ssam\q@u{a}i fatatiyahum bi\q@u{a}yatin walaw sh\q@u{a}a All\q@u{a}hu lajamaAAahum AAal\q@u{a} alhud\q@u{a} fal\q@u{a} takoonanna mina alj\q@u{a}hileen\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@dcccxxv{Innam\q@u{a} yastajeebu alla\q@u{th}eena yasmaAAoona wa\q@b{a}lmawt\q@u{a} yabAAathuhumu All\q@u{a}hu thumma ilayhi yurjaAAoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@dcccxxvi{Waq\q@u{a}loo lawl\q@u{a} nuzzila AAalayhi \q@u{a}yatun min rabbihi qul inna All\q@u{a}ha q\q@u{a}dirun AAal\q@u{a} an yunazzila \q@u{a}yatan wal\q@u{a}kinna aktharahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@dcccxxvii{Wam\q@u{a} min d\q@u{a}bbatin fee alar\q@u{d}i wal\q@u{a} \q@u{ta}irin ya\q@u{t}eeru bijan\q@u{ah}ayhi ill\q@u{a} omamun amth\q@u{a}lukum m\q@u{a} farra\q@u{t}n\q@u{a} fee alkit\q@u{a}bi min shayin thumma il\q@u{a} rabbihim yu\q@u{h}sharoon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@dcccxxviii{Wa\q@b{a}lla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} \q@u{s}ummun wabukmun fee a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti man yashai All\q@u{a}hu yu\q@u{d}lilhu waman yasha yajAAalhu AAal\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@dcccxxix{Qul araaytakum in at\q@u{a}kum AAa\q@u{tha}bu All\q@u{a}hi aw atatkumu a\q@b{l}ss\q@u{a}AAatu aghayra All\q@u{a}hi tadAAoona in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@dcccxxx{Bal iyy\q@u{a}hu tadAAoona fayakshifu m\q@u{a} tadAAoona ilayhi in sh\q@u{a}a watansawna m\q@u{a} tushrikoon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@dcccxxxi{Walaqad arsaln\q@u{a} il\q@u{a} omamin min qablika faakha\q@u{th}n\q@u{a}hum bi\q@b{a}lbas\q@u{a}i wa\q@b{al}\q@u{dd}arr\q@u{a}i laAAallahum yata\q@u{d}arraAAoon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@dcccxxxii{Falawl\q@u{a} i\q@u{th} j\q@u{a}ahum basun\q@u{a} ta\q@u{d}arraAAoo wal\q@u{a}kin qasat quloobuhum wazayyana lahumu a\q@b{l}shshay\q@u{ta}nu m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@dcccxxxiii{Falamm\q@u{a} nasoo m\q@u{a} \q@u{th}ukkiroo bihi fata\q@u{h}n\q@u{a} AAalayhim abw\q@u{a}ba kulli shayin \q@u{h}att\q@u{a} i\q@u{tha} fari\q@u{h}oo bim\q@u{a} ootoo akha\q@u{th}n\q@u{a}hum baghtatan fai\q@u{tha} hum mublisoon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@dcccxxxiv{Faqu\q@u{t}iAAa d\q@u{a}biru alqawmi alla\q@u{th}eena \q@i{\q@u{th}}alamoo wa\q@b{a}l\q@u{h}amdu lill\q@u{a}hi rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@dcccxxxv{Qul araaytum in akha\q@u{th}a All\q@u{a}hu samAAakum waab\q@u{sa}rakum wakhatama AAal\q@u{a} quloobikum man il\q@u{a}hun ghayru All\q@u{a}hi yateekum bihi on\q@i{\q@u{th}}ur kayfa nu\q@u{s}arrifu al\q@u{a}y\q@u{a}ti thumma hum ya\q@u{s}difoon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@dcccxxxvi{Qul araaytakum in at\q@u{a}kum AAa\q@u{tha}bu All\q@u{a}hi baghtatan aw jahratan hal yuhlaku ill\q@u{a} alqawmu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@dcccxxxvii{Wam\q@u{a} nursilu almursaleena ill\q@u{a} mubashshireena wamun\q@u{th}ireena faman \q@u{a}mana waa\q@u{s}la\q@u{h}a fal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@dcccxxxviii{Wa\q@b{a}lla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} yamassuhumu alAAa\q@u{tha}bu bim\q@u{a} k\q@u{a}noo yafsuqoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@dcccxxxix{Qul l\q@u{a} aqoolu lakum AAindee khaz\q@u{a}inu All\q@u{a}hi wal\q@u{a} aAAlamu alghayba wal\q@u{a} aqoolu lakum innee malakun in attabiAAu ill\q@u{a} m\q@u{a} yoo\q@u{ha} ilayya qul hal yastawee alaAAm\q@u{a} wa\q@b{a}lba\q@u{s}eeru afal\q@u{a} tatafakkaroon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@dcccxl{Waan\q@u{th}ir bihi alla\q@u{th}eena yakh\q@u{a}foona an yu\q@u{h}sharoo il\q@u{a} rabbihim laysa lahum min doonihi waliyyun wal\q@u{a} shafeeAAun laAAallahum yattaqoon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@dcccxli{Wal\q@u{a} ta\q@u{t}rudi alla\q@u{th}eena yadAAoona rabbahum bi\q@b{a}lghad\q@u{a}ti wa\q@b{a}lAAashiyyi yureedoona wajhahu m\q@u{a} AAalayka min \q@u{h}is\q@u{a}bihim min shayin wam\q@u{a} min \q@u{h}is\q@u{a}bika AAalayhim min shayin fata\q@u{t}rudahum fatakoona mina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@dcccxlii{Waka\q@u{tha}lika fatann\q@u{a} baAA\q@u{d}ahum bibaAA\q@u{d}in liyaqooloo ah\q@u{a}ol\q@u{a}i manna All\q@u{a}hu AAalayhim min baynin\q@u{a} alaysa All\q@u{a}hu biaAAlama bi\q@b{al}shsh\q@u{a}kireen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@dcccxliii{Wai\q@u{tha} j\q@u{a}aka alla\q@u{th}eena yuminoona bi\q@u{a}y\q@u{a}tin\q@u{a} faqul sal\q@u{a}mun AAalaykum kataba rabbukum AAal\q@u{a} nafsihi a\q@b{l}rra\q@u{h}mata annahu man AAamila minkum sooan bijah\q@u{a}latin thumma t\q@u{a}ba min baAAdihi waa\q@u{s}la\q@u{h}a faannahu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@dcccxliv{Waka\q@u{tha}lika nufa\q@u{ss}ilu al\q@u{a}y\q@u{a}ti walitastabeena sabeelu almujrimeen\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@dcccxlv{Qul innee nuheetu an aAAbuda alla\q@u{th}eena tadAAoona min dooni All\q@u{a}hi qul l\q@u{a} attabiAAu ahw\q@u{a}akum qad \q@u{d}alaltu i\q@u{th}an wam\q@u{a} an\q@u{a} mina almuhtadeen\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@dcccxlvi{Qul innee AAal\q@u{a} bayyinatin min rabbee waka\q@u{thth}abtum bihi m\q@u{a} AAindee m\q@u{a} tastaAAjiloona bihi ini al\q@u{h}ukmu ill\q@u{a} lill\q@u{a}hi yaqu\q@u{ss}u al\q@u{h}aqqa wahuwa khayru alf\q@u{as}ileen\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@dcccxlvii{Qul law anna AAindee m\q@u{a} tastaAAjiloona bihi laqu\q@u{d}iya alamru baynee wabaynakum wa\q@b{A}ll\q@u{a}hu aAAlamu bi\q@b{al}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@dcccxlviii{WaAAindahu maf\q@u{a}ti\q@u{h}u alghaybi l\q@u{a} yaAAlamuh\q@u{a} ill\q@u{a} huwa wayaAAlamu m\q@u{a} fee albarri wa\q@b{a}lba\q@u{h}ri wam\q@u{a} tasqu\q@u{t}u min waraqatin ill\q@u{a} yaAAlamuh\q@u{a} wal\q@u{a} \q@u{h}abbatin fee \q@i{\q@u{th}}ulum\q@u{a}ti alar\q@u{d}i wal\q@u{a} ra\q@u{t}bin wal\q@u{a} y\q@u{a}bisin ill\q@u{a} fee kit\q@u{a}bin mubeen\q@b{in}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@dcccxlix{Wahuwa alla\q@u{th}ee yatawaff\q@u{a}kum bi\q@b{a}llayli wayaAAlamu m\q@u{a} jara\q@u{h}tum bi\q@b{al}nnah\q@u{a}ri thumma yabAAathukum feehi liyuq\q@u{da} ajalun musamman thumma ilayhi marjiAAukum thumma yunabbiokum bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@dcccl{Wahuwa alq\q@u{a}hiru fawqa AAib\q@u{a}dihi wayursilu AAalaykum \q@u{h}afa\q@i{\q@u{th}}atan \q@u{h}att\q@u{a} i\q@u{tha} j\q@u{a}a a\q@u{h}adakumu almawtu tawaffathu rusulun\q@u{a} wahum l\q@u{a} yufarri\q@u{t}oon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@dcccli{Thumma ruddoo il\q@u{a} All\q@u{a}hi mawl\q@u{a}humu al\q@u{h}aqqi al\q@u{a} lahu al\q@u{h}ukmu wahuwa asraAAu al\q@u{ha}sibeen\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@dccclii{Qul man yunajjeekum min \q@i{\q@u{th}}ulum\q@u{a}ti albarri wa\q@b{a}lba\q@u{h}ri tadAAoonahu ta\q@u{d}arruAAan wakhufyatan lain anj\q@u{a}n\q@u{a} min h\q@u{ath}ihi lanakoonanna mina a\q@b{l}shsh\q@u{a}kireen\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@dcccliii{Quli All\q@u{a}hu yunajjeekum minh\q@u{a} wamin kulli karbin thumma antum tushrikoon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@dcccliv{Qul huwa alq\q@u{a}diru AAal\q@u{a} an yabAAatha AAalaykum AAa\q@u{tha}ban min fawqikum aw min ta\q@u{h}ti arjulikum aw yalbisakum shiyaAAan wayu\q@u{th}eeqa baAA\q@u{d}akum basa baAA\q@u{d}in on\q@i{\q@u{th}}ur kayfa nu\q@u{s}arrifu al\q@u{a}y\q@u{a}ti laAAallahum yafqahoon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@dccclv{Waka\q@u{thth}aba bihi qawmuka wahuwa al\q@u{h}aqqu qul lastu AAalaykum biwakeel\q@b{in}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@dccclvi{Likulli nabain mustaqarrun wasawfa taAAlamoon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@dccclvii{Wai\q@u{tha} raayta alla\q@u{th}eena yakhoo\q@u{d}oona fee \q@u{a}y\q@u{a}tin\q@u{a} faaAAri\q@u{d} AAanhum \q@u{h}att\q@u{a} yakhoo\q@u{d}oo fee \q@u{h}adeethin ghayrihi waimm\q@u{a} yunsiyannaka a\q@b{l}shshay\q@u{ta}nu fal\q@u{a} taqAAud baAAda a\q@b{l}\q@u{thth}ikr\q@u{a} maAAa alqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@dccclviii{Wam\q@u{a} AAal\q@u{a} alla\q@u{th}eena yattaqoona min \q@u{h}is\q@u{a}bihim min shayin wal\q@u{a}kin \q@u{th}ikr\q@u{a} laAAallahum yattaqoon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@dccclix{Wa\q@u{th}ari alla\q@u{th}eena ittakha\q@u{th}oo deenahum laAAiban walahwan wagharrathumu al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} wa\q@u{th}akkir bihi an tubsala nafsun bim\q@u{a} kasabat laysa lah\q@u{a} min dooni All\q@u{a}hi waliyyun wal\q@u{a} shafeeAAun wain taAAdil kulla AAadlin l\q@u{a} yukha\q@u{th} minh\q@u{a} ol\q@u{a}ika alla\q@u{th}eena obsiloo bim\q@u{a} kasaboo lahum shar\q@u{a}bun min \q@u{h}ameemin waAAa\q@u{tha}bun aleemun bim\q@u{a} k\q@u{a}noo yakfuroon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@dccclx{Qul anadAAoo min dooni All\q@u{a}hi m\q@u{a} l\q@u{a} yanfaAAun\q@u{a} wal\q@u{a} ya\q@u{d}urrun\q@u{a} wanuraddu AAal\q@u{a} aAAq\q@u{a}bin\q@u{a} baAAda i\q@u{th} had\q@u{a}n\q@u{a} All\q@u{a}hu ka\q@b{a}lla\q@u{th}ee\q@u{ }istahwathu a\q@b{l}shshay\q@u{at}eenu fee alar\q@u{d}i \q@u{h}ayr\q@u{a}na lahu a\q@u{s}\q@u{ha}bun yadAAoonahu il\q@u{a} alhud\q@u{a} itin\q@u{a} qul inna hud\q@u{a} All\q@u{a}hi huwa alhud\q@u{a} waomirn\q@u{a} linuslima lirabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@dccclxi{Waan aqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@b{i}ttaqoohu wahuwa alla\q@u{th}ee ilayhi tu\q@u{h}sharoon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@dccclxii{Wahuwa alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a bi\q@b{a}l\q@u{h}aqqi wayawma yaqoolu kun fayakoonu qawluhu al\q@u{h}aqqu walahu almulku yawma yunfakhu fee a\q@b{l}\q@u{ss}oori AA\q@u{a}limu alghaybi wa\q@b{al}shshah\q@u{a}dati wahuwa al\q@u{h}akeemu alkhabeer\q@b{u}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@dccclxiii{Wai\q@u{th} q\q@u{a}la ibr\q@u{a}heemu liabeehi \q@u{a}zara atattakhi\q@u{th}u a\q@u{s}n\q@u{a}man \q@u{a}lihatan innee ar\q@u{a}ka waqawmaka fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@dccclxiv{Waka\q@u{tha}lika nuree ibr\q@u{a}heema malakoota a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i waliyakoona mina almooqineen\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@dccclxv{Falamm\q@u{a} janna AAalayhi allaylu ra\q@u{a} kawkaban q\q@u{a}la h\q@u{atha} rabbee falamm\q@u{a} afala q\q@u{a}la l\q@u{a} o\q@u{h}ibbu al\q@u{a}fileen\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@dccclxvi{Falamm\q@u{a} ra\q@u{a} alqamara b\q@u{a}zighan q\q@u{a}la h\q@u{atha} rabbee falamm\q@u{a} afala q\q@u{a}la lain lam yahdinee rabbee laakoonanna mina alqawmi a\q@b{l}\q@u{dda}lleen\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@dccclxvii{Falamm\q@u{a} ra\q@u{a} a\q@b{l}shshamsa b\q@u{a}zighatan q\q@u{a}la h\q@u{atha} rabbee h\q@u{atha} akbaru falamm\q@u{a} afalat q\q@u{a}la y\q@u{a} qawmi innee bareeon mimm\q@u{a} tushrikoon\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@dccclxviii{Innee wajjahtu wajhiya lilla\q@u{th}ee fa\q@u{t}ara a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a \q@u{h}aneefan wam\q@u{a} an\q@u{a} mina almushrikeen\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@dccclxix{Wa\q@u{ha}jjahu qawmuhu q\q@u{a}la atu\q@u{ha}jjoonnee fee All\q@u{a}hi waqad had\q@u{a}ni wal\q@u{a} akh\q@u{a}fu m\q@u{a} tushrikoona bihi ill\q@u{a} an yash\q@u{a}a rabbee shayan wasiAAa rabbee kulla shayin AAilman afal\q@u{a} tata\q@u{th}akkaroon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@dccclxx{Wakayfa akh\q@u{a}fu m\q@u{a} ashraktum wal\q@u{a} takh\q@u{a}foona annakum ashraktum bi\q@b{A}ll\q@u{a}hi m\q@u{a} lam yunazzil bihi AAalaykum sul\q@u{ta}nan faayyu alfareeqayni a\q@u{h}aqqu bi\q@b{a}lamni in kuntum taAAlamoon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@dccclxxi{Alla\q@u{th}eena \q@u{a}manoo walam yalbisoo eem\q@u{a}nahum bi\q@i{\q@u{th}}ulmin ol\q@u{a}ika lahumu alamnu wahum muhtadoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@dccclxxii{Watilka \q@u{h}ujjatun\q@u{a} \q@u{a}tayn\q@u{a}h\q@u{a} ibr\q@u{a}heema AAal\q@u{a} qawmihi narfaAAu daraj\q@u{a}tin man nash\q@u{a}o inna rabbaka \q@u{h}akeemun AAaleem\q@b{un}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@dccclxxiii{Wawahabn\q@u{a} lahu is\q@u{ha}qa wayaAAqooba kullan hadayn\q@u{a} wanoo\q@u{h}an hadayn\q@u{a} min qablu wamin \q@u{th}urriyyatihi d\q@u{a}wooda wasulaym\q@u{a}na waayyooba wayoosufa wamoos\q@u{a} wah\q@u{a}roona waka\q@u{tha}lika najzee almu\q@u{h}sineen\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@dccclxxiv{Wazakariyy\q@u{a} waya\q@u{h}y\q@u{a} waAAees\q@u{a} wa\q@b{i}ly\q@u{a}sa kullun mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@dccclxxv{Waism\q@u{a}AAeela wa\q@b{i}lyasaAAa wayoonusa waloo\q@u{t}an wakullan fa\q@u{dd}aln\q@u{a} AAal\q@u{a} alAA\q@u{a}lameen\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@dccclxxvi{Wamin \q@u{a}b\q@u{a}ihim wa\q@u{th}urriyy\q@u{a}tihim waikhw\q@u{a}nihim wa\q@b{i}jtabayn\q@u{a}hum wahadayn\q@u{a}hum il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@dccclxxvii{\q@u{Tha}lika hud\q@u{a} All\q@u{a}hi yahdee bihi man yash\q@u{a}o min AAib\q@u{a}dihi walaw ashrakoo la\q@u{h}abi\q@u{t}a AAanhum m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@dccclxxviii{Ol\q@u{a}ika alla\q@u{th}eena \q@u{a}tayn\q@u{a}humu alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ukma wa\q@b{al}nnubuwwata fain yakfur bih\q@u{a} h\q@u{a}ol\q@u{a}i faqad wakkaln\q@u{a} bih\q@u{a} qawman laysoo bih\q@u{a} bik\q@u{a}fireen\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@dccclxxix{Ol\q@u{a}ika alla\q@u{th}eena had\q@u{a} All\q@u{a}hu fabihud\q@u{a}humu iqtadih qul l\q@u{a} asalukum AAalayhi ajran in huwa ill\q@u{a} \q@u{th}ikr\q@u{a} lilAA\q@u{a}lameen\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@dccclxxx{Wam\q@u{a} qadaroo All\q@u{a}ha \q@u{h}aqqa qadrihi i\q@u{th} q\q@u{a}loo m\q@u{a} anzala All\q@u{a}hu AAal\q@u{a} basharin min shayin qul man anzala alkit\q@u{a}ba alla\q@u{th}ee j\q@u{a}a bihi moos\q@u{a} nooran wahudan li\q@b{l}nn\q@u{a}si tajAAaloonahu qar\q@u{at}eesa tubdoonah\q@u{a} watukhfoona katheeran waAAullimtum m\q@u{a} lam taAAlamoo antum wal\q@u{a} \q@u{a}b\q@u{a}okum quli All\q@u{a}hu thumma \q@u{th}arhum fee khaw\q@u{d}ihim yalAAaboon\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@dccclxxxi{Wah\q@u{atha} kit\q@u{a}bun anzaln\q@u{a}hu mub\q@u{a}rakun mu\q@u{s}addiqu alla\q@u{th}ee bayna yadayhi walitun\q@u{th}ira omma alqur\q@u{a} waman \q@u{h}awlah\q@u{a} wa\q@b{a}lla\q@u{th}eena yuminoona bi\q@b{a}l\q@u{a}khirati yuminoona bihi wahum AAal\q@u{a} \q@u{s}al\q@u{a}tihim yu\q@u{ha}fi\q@i{\q@u{th}}oon\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@dccclxxxii{Waman a\q@i{\q@u{th}}lamu mimmani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban aw q\q@u{a}la oo\q@u{h}iya ilayya walam yoo\q@u{h}a ilayhi shayon waman q\q@u{a}la saonzilu mithla m\q@u{a} anzala All\q@u{a}hu walaw tar\q@u{a} i\q@u{th}i a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoona fee ghamar\q@u{a}ti almawti wa\q@b{a}lmal\q@u{a}ikatu b\q@u{a}si\q@u{t}oo aydeehim akhrijoo anfusakumu alyawma tujzawna AAa\q@u{tha}ba alhooni bim\q@u{a} kuntum taqooloona AAal\q@u{a} All\q@u{a}hi ghayra al\q@u{h}aqqi wakuntum AAan \q@u{a}y\q@u{a}tihi tastakbiroon\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@dccclxxxiii{Walaqad jitumoon\q@u{a} fur\q@u{a}d\q@u{a} kam\q@u{a} khalaqn\q@u{a}kum awwala marratin wataraktum m\q@u{a} khawwaln\q@u{a}kum war\q@u{a}a \q@i{\q@u{th}}uhoorikum wam\q@u{a} nar\q@u{a} maAAakum shufaAA\q@u{a}akumu alla\q@u{th}eena zaAAamtum annahum feekum shurak\q@u{a}o laqad taqa\q@u{tt}aAAa baynakum wa\q@u{d}alla AAankum m\q@u{a} kuntum tazAAumoon\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@dccclxxxiv{Inna All\q@u{a}ha f\q@u{a}liqu al\q@u{h}abbi wa\q@b{al}nnaw\q@u{a} yukhriju al\q@u{h}ayya mina almayyiti wamukhriju almayyiti mina al\q@u{h}ayyi \q@u{tha}likumu All\q@u{a}hu faann\q@u{a} tufakoon\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@dccclxxxv{F\q@u{a}liqu ali\q@u{s}b\q@u{ah}i wajaAAala allayla sakanan wa\q@b{al}shshamsa wa\q@b{a}lqamara \q@u{h}usb\q@u{a}nan \q@u{tha}lika taqdeeru alAAazeezi alAAaleem\q@b{i}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@dccclxxxvi{Wahuwa alla\q@u{th}ee jaAAala lakumu a\q@b{l}nnujooma litahtadoo bih\q@u{a} fee \q@i{\q@u{th}}ulum\q@u{a}ti albarri wa\q@b{a}lba\q@u{h}ri qad fa\q@u{ss}aln\q@u{a} al\q@u{a}y\q@u{a}ti liqawmin yaAAlamoon\q@b{a}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@dccclxxxvii{Wahuwa alla\q@u{th}ee anshaakum min nafsin w\q@u{ah}idatin famustaqarrun wamustawdaAAun qad fa\q@u{ss}aln\q@u{a} al\q@u{a}y\q@u{a}ti liqawmin yafqahoon\q@b{a}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@dccclxxxviii{Wahuwa alla\q@u{th}ee anzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faakhrajn\q@u{a} bihi nab\q@u{a}ta kulli shayin faakhrajn\q@u{a} minhu kha\q@u{d}iran nukhriju minhu \q@u{h}abban mutar\q@u{a}kiban wamina a\q@b{l}nnakhli min \q@u{t}alAAih\q@u{a} qinw\q@u{a}nun d\q@u{a}niyatun wajann\q@u{a}tin min aAAn\q@u{a}bin wa\q@b{al}zzaytoona wa\q@b{al}rrumm\q@u{a}na mushtabihan waghayra mutash\q@u{a}bihin on\q@i{\q@u{th}}uroo il\q@u{a} thamarihi i\q@u{tha} athmara wayanAAihi inna fee \q@u{tha}likum la\q@u{a}y\q@u{a}tin liqawmin yuminoon\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@dccclxxxix{WajaAAaloo lill\q@u{a}hi shurak\q@u{a}a aljinna wakhalaqahum wakharaqoo lahu baneena waban\q@u{a}tin bighayri AAilmin sub\q@u{ha}nahu wataAA\q@u{a}l\q@u{a} AAamm\q@u{a} ya\q@u{s}ifoon\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@dcccxc{BadeeAAu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i ann\q@u{a} yakoonu lahu waladun walam takun lahu \q@u{sah}ibatun wakhalaqa kulla shayin wahuwa bikulli shayin AAaleem\q@b{un}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@dcccxci{\q@u{Tha}likumu All\q@u{a}hu rabbukum l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa kh\q@u{a}liqu kulli shayin fa\q@b{o}AAbudoohu wahuwa AAal\q@u{a} kulli shayin wakeel\q@b{un}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@dcccxcii{L\q@u{a} tudrikuhu alab\q@u{sa}ru wahuwa yudriku alab\q@u{sa}ra wahuwa alla\q@u{t}eefu alkhabeer\q@b{u}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@dcccxciii{Qad j\q@u{a}akum ba\q@u{sa}iru min rabbikum faman ab\q@u{s}ara falinafsihi waman AAamiya faAAalayh\q@u{a} wam\q@u{a} an\q@u{a} AAalaykum bi\q@u{h}afee\q@i{\q@u{th}}\q@b{in}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@dcccxciv{Waka\q@u{tha}lika nu\q@u{s}arrifu al\q@u{a}y\q@u{a}ti waliyaqooloo darasta walinubayyinahu liqawmin yaAAlamoon\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@dcccxcv{IttabiAA m\q@u{a} oo\q@u{h}iya ilayka min rabbika l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa waaAAri\q@u{d} AAani almushrikeen\q@b{a}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@dcccxcvi{Walaw sh\q@u{a}a All\q@u{a}hu m\q@u{a} ashrakoo wam\q@u{a} jaAAaln\q@u{a}ka AAalayhim \q@u{h}afee\q@i{\q@u{th}}an wam\q@u{a} anta AAalayhim biwakeel\q@b{in}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@dcccxcvii{Wal\q@u{a} tasubboo alla\q@u{th}eena yadAAoona min dooni All\q@u{a}hi fayasubboo All\q@u{a}ha AAadwan bighayri AAilmin ka\q@u{tha}lika zayyann\q@u{a} likulli ommatin AAamalahum thumma il\q@u{a} rabbihim marjiAAuhum fayunabbiohum bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@dcccxcviii{Waaqsamoo bi\q@b{A}ll\q@u{a}hi jahda aym\q@u{a}nihim lain j\q@u{a}athum \q@u{a}yatun layuminunna bih\q@u{a} qul innam\q@u{a} al\q@u{a}y\q@u{a}tu AAinda All\q@u{a}hi wam\q@u{a} yushAAirukum annah\q@u{a} i\q@u{tha} j\q@u{a}at l\q@u{a} yuminoon\q@b{a}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@dcccxcix{Wanuqallibu afidatahum waab\q@u{sa}rahum kam\q@u{a} lam yuminoo bihi awwala marratin wana\q@u{th}aruhum fee \q@u{t}ughy\q@u{a}nihim yaAAmahoon\q@b{a}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@cm{Walaw annan\q@u{a} nazzaln\q@u{a} ilayhimu almal\q@u{a}ikata wakallamahumu almawt\q@u{a} wa\q@u{h}asharn\q@u{a} AAalayhim kulla shayin qubulan m\q@u{a} k\q@u{a}noo liyuminoo ill\q@u{a} an yash\q@u{a}a All\q@u{a}hu wal\q@u{a}kinna aktharahum yajhaloon\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@cmi{Waka\q@u{tha}lika jaAAaln\q@u{a} likulli nabiyyin AAaduwwan shay\q@u{at}eena alinsi wa\q@b{a}ljinni yoo\q@u{h}ee baAA\q@u{d}uhum il\q@u{a} baAA\q@u{d}in zukhrufa alqawli ghurooran walaw sh\q@u{a}a rabbuka m\q@u{a} faAAaloohu fa\q@u{th}arhum wam\q@u{a} yaftaroon\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@cmii{Walita\q@u{s}gh\q@u{a} ilayhi afidatu alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati waliyar\q@u{d}awhu waliyaqtarifoo m\q@u{a} hum muqtarifoon\q@b{a}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@cmiii{Afaghayra All\q@u{a}hi abtaghee \q@u{h}akaman wahuwa alla\q@u{th}ee anzala ilaykumu alkit\q@u{a}ba mufa\q@u{ss}alan wa\q@b{a}lla\q@u{th}eena \q@u{a}tayn\q@u{a}humu alkit\q@u{a}ba yaAAlamoona annahu munazzalun min rabbika bi\q@b{a}l\q@u{h}aqqi fal\q@u{a} takoonanna mina almumtareen\q@b{a}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@cmiv{Watammat kalimatu rabbika \q@u{s}idqan waAAadlan l\q@u{a} mubaddila likalim\q@u{a}tihi wahuwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@cmv{Wain tu\q@u{t}iAA akthara man fee alar\q@u{d}i yu\q@u{d}illooka AAan sabeeli All\q@u{a}hi in yattabiAAoona ill\q@u{a} a\q@b{l}\q@i{\q@u{thth}}anna wain hum ill\q@u{a} yakhru\q@u{s}oon\q@b{a}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@cmvi{Inna rabbaka huwa aAAlamu man ya\q@u{d}illu AAan sabeelihi wahuwa aAAlamu bi\q@b{a}lmuhtadeen\q@b{a}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@cmvii{Fakuloo mimm\q@u{a} \q@u{th}ukira ismu All\q@u{a}hi AAalayhi in kuntum bi\q@u{a}y\q@u{a}tihi mumineen\q@b{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@cmviii{Wam\q@u{a} lakum all\q@u{a} takuloo mimm\q@u{a} \q@u{th}ukira ismu All\q@u{a}hi AAalayhi waqad fa\q@u{ss}ala lakum m\q@u{a} \q@u{h}arrama AAalaykum ill\q@u{a} m\q@u{a} i\q@u{dt}urirtum ilayhi wainna katheeran layu\q@u{d}illoona biahw\q@u{a}ihim bighayri AAilmin inna rabbaka huwa aAAlamu bi\q@b{a}lmuAAtadeen\q@b{a}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@cmix{Wa\q@u{th}aroo \q@i{\q@u{th}}\q@u{a}hira alithmi wab\q@u{at}inahu inna alla\q@u{th}eena yaksiboona alithma sayujzawna bim\q@u{a} k\q@u{a}noo yaqtarifoon\q@b{a}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@cmx{Wal\q@u{a} takuloo mimm\q@u{a} lam yu\q@u{th}kari ismu All\q@u{a}hi AAalayhi wainnahu lafisqun wainna a\q@b{l}shshay\q@u{at}eena layoo\q@u{h}oona il\q@u{a} awliy\q@u{a}ihim liyuj\q@u{a}dilookum wain a\q@u{t}aAAtumoohum innakum lamushrikoon\q@b{a}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@cmxi{Awa man k\q@u{a}na maytan faa\q@u{h}yayn\q@u{a}hu wajaAAaln\q@u{a} lahu nooran yamshee bihi fee a\q@b{l}nn\q@u{a}si kaman mathaluhu fee a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti laysa bikh\q@u{a}rijin minh\q@u{a} ka\q@u{tha}lika zuyyina lilk\q@u{a}fireena m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@cmxii{Waka\q@u{tha}lika jaAAaln\q@u{a} fee kulli qaryatin ak\q@u{a}bira mujrimeeh\q@u{a} liyamkuroo feeh\q@u{a} wam\q@u{a} yamkuroona ill\q@u{a} bianfusihim wam\q@u{a} yashAAuroon\q@b{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@cmxiii{Wai\q@u{tha} j\q@u{a}athum \q@u{a}yatun q\q@u{a}loo lan numina \q@u{h}att\q@u{a} nut\q@u{a} mithla m\q@u{a} ootiya rusulu All\q@u{a}hi All\q@u{a}hu aAAlamu \q@u{h}aythu yajAAalu ris\q@u{a}latahu sayu\q@u{s}eebu alla\q@u{th}eena ajramoo \q@u{s}agh\q@u{a}run AAinda All\q@u{a}hi waAAa\q@u{tha}bun shadeedun bim\q@u{a} k\q@u{a}noo yamkuroon\q@b{a}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@cmxiv{Faman yuridi All\q@u{a}hu an yahdiyahu yashra\q@u{h} \q@u{s}adrahu lilisl\q@u{a}mi waman yurid an yu\q@u{d}illahu yajAAal \q@u{s}adrahu \q@u{d}ayyiqan \q@u{h}arajan kaannam\q@u{a} ya\q@u{ss}aAAAAadu fee a\q@b{l}ssam\q@u{a}i ka\q@u{tha}lika yajAAalu All\q@u{a}hu a\q@b{l}rrijsa AAal\q@u{a} alla\q@u{th}eena l\q@u{a} yuminoon\q@b{a}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@cmxv{Wah\q@u{atha} \q@u{s}ir\q@u{at}u rabbika mustaqeeman qad fa\q@u{ss}aln\q@u{a} al\q@u{a}y\q@u{a}ti liqawmin ya\q@u{thth}akkaroon\q@b{a}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@cmxvi{Lahum d\q@u{a}ru a\q@b{l}ssal\q@u{a}mi AAinda rabbihim wahuwa waliyyuhum bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@cmxvii{Wayawma ya\q@u{h}shuruhum jameeAAan y\q@u{a} maAAshara aljinni qadi istakthartum mina alinsi waq\q@u{a}la awliy\q@u{a}ohum mina alinsi rabban\q@u{a} istamtaAAa baAA\q@u{d}un\q@u{a} bibaAA\q@u{d}in wabalaghn\q@u{a} ajalan\q@u{a} alla\q@u{th}ee ajjalta lan\q@u{a} q\q@u{a}la a\q@b{l}nn\q@u{a}ru mathw\q@u{a}kum kh\q@u{a}lideena feeh\q@u{a} ill\q@u{a} m\q@u{a} sh\q@u{a}a All\q@u{a}hu inna rabbaka \q@u{h}akeemun AAaleem\q@b{un}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@cmxviii{Waka\q@u{tha}lika nuwallee baAA\q@u{d}a a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena baAA\q@u{d}an bim\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(129)}}
\qt@newcmd\qurantrans@lt@cmxix{Y\q@u{a} maAAshara aljinni wa\q@b{a}linsi alam yatikum rusulun minkum yaqu\q@u{ss}oona AAalaykum \q@u{a}y\q@u{a}tee wayun\q@u{th}iroonakum liq\q@u{a}a yawmikum h\q@u{atha} q\q@u{a}loo shahidn\q@u{a} AAal\q@u{a} anfusin\q@u{a} wagharrathumu al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} washahidoo AAal\q@u{a} anfusihim annahum k\q@u{a}noo k\q@u{a}fireen\q@b{a}\qt@no{(130)}}
\qt@newcmd\qurantrans@lt@cmxx{\q@u{Tha}lika an lam yakun rabbuka muhlika alqur\q@u{a} bi\q@i{\q@u{th}}ulmin waahluh\q@u{a} gh\q@u{a}filoon\q@b{a}\qt@no{(131)}}
\qt@newcmd\qurantrans@lt@cmxxi{Walikullin daraj\q@u{a}tun mimm\q@u{a} AAamiloo wam\q@u{a} rabbuka bigh\q@u{a}filin AAamm\q@u{a} yaAAmaloon\q@b{a}\qt@no{(132)}}
\qt@newcmd\qurantrans@lt@cmxxii{Warabbuka alghaniyyu \q@u{th}oo a\q@b{l}rra\q@u{h}mati in yasha yu\q@u{th}hibkum wayastakhlif min baAAdikum m\q@u{a} yash\q@u{a}o kam\q@u{a} anshaakum min \q@u{th}urriyyati qawmin \q@u{a}khareen\q@b{a}\qt@no{(133)}}
\qt@newcmd\qurantrans@lt@cmxxiii{Inna m\q@u{a} tooAAadoona la\q@u{a}tin wam\q@u{a} antum bimuAAjizeen\q@b{a}\qt@no{(134)}}
\qt@newcmd\qurantrans@lt@cmxxiv{Qul y\q@u{a} qawmi iAAmaloo AAal\q@u{a} mak\q@u{a}natikum innee AA\q@u{a}milun fasawfa taAAlamoona man takoonu lahu AA\q@u{a}qibatu a\q@b{l}dd\q@u{a}ri innahu l\q@u{a} yufli\q@u{h}u a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(135)}}
\qt@newcmd\qurantrans@lt@cmxxv{WajaAAaloo lill\q@u{a}hi mimm\q@u{a} \q@u{th}araa mina al\q@u{h}arthi wa\q@b{a}lanAA\q@u{a}mi na\q@u{s}eeban faq\q@u{a}loo h\q@u{atha} lill\q@u{a}hi bizaAAmihim wah\q@u{atha} lishurak\q@u{a}in\q@u{a} fam\q@u{a} k\q@u{a}na lishurak\q@u{a}ihim fal\q@u{a} ya\q@u{s}ilu il\q@u{a} All\q@u{a}hi wam\q@u{a} k\q@u{a}na lill\q@u{a}hi fahuwa ya\q@u{s}ilu il\q@u{a} shurak\q@u{a}ihim s\q@u{a}a m\q@u{a} ya\q@u{h}kumoon\q@b{a}\qt@no{(136)}}
\qt@newcmd\qurantrans@lt@cmxxvi{Waka\q@u{tha}lika zayyana likatheerin mina almushrikeena qatla awl\q@u{a}dihim shurak\q@u{a}ohum liyurdoohum waliyalbisoo AAalayhim deenahum walaw sh\q@u{a}a All\q@u{a}hu m\q@u{a} faAAaloohu fa\q@u{th}arhum wam\q@u{a} yaftaroon\q@b{a}\qt@no{(137)}}
\qt@newcmd\qurantrans@lt@cmxxvii{Waq\q@u{a}loo h\q@u{ath}ihi anAA\q@u{a}mun wa\q@u{h}arthun \q@u{h}ijrun l\q@u{a} ya\q@u{t}AAamuh\q@u{a} ill\q@u{a} man nash\q@u{a}o bizaAAmihim waanAA\q@u{a}mun \q@u{h}urrimat \q@i{\q@u{th}}uhooruh\q@u{a} waanAA\q@u{a}mun l\q@u{a} ya\q@u{th}kuroona isma All\q@u{a}hi AAalayh\q@u{a} iftir\q@u{a}an AAalayhi sayajzeehim bim\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(138)}}
\qt@newcmd\qurantrans@lt@cmxxviii{Waq\q@u{a}loo m\q@u{a} fee bu\q@u{t}ooni h\q@u{ath}ihi alanAA\q@u{a}mi kh\q@u{a}li\q@u{s}atun li\q@u{th}ukoorin\q@u{a} wamu\q@u{h}arramun AAal\q@u{a} azw\q@u{a}jin\q@u{a} wain yakun maytatan fahum feehi shurak\q@u{a}o sayajzeehim wa\q@u{s}fahum innahu \q@u{h}akeemun AAaleem\q@b{un}\qt@no{(139)}}
\qt@newcmd\qurantrans@lt@cmxxix{Qad khasira alla\q@u{th}eena qataloo awl\q@u{a}dahum safahan bighayri AAilmin wa\q@u{h}arramoo m\q@u{a} razaqahumu All\q@u{a}hu iftir\q@u{a}an AAal\q@u{a} All\q@u{a}hi qad \q@u{d}alloo wam\q@u{a} k\q@u{a}noo muhtadeen\q@b{a}\qt@no{(140)}}
\qt@newcmd\qurantrans@lt@cmxxx{Wahuwa alla\q@u{th}ee anshaa jann\q@u{a}tin maAAroosh\q@u{a}tin waghayra maAAroosh\q@u{a}tin wa\q@b{al}nnakhla wa\q@b{al}zzarAAa mukhtalifan okuluhu wa\q@b{al}zzaytoona wa\q@b{al}rrumm\q@u{a}na mutash\q@u{a}bihan waghayra mutash\q@u{a}bihin kuloo min thamarihi i\q@u{tha} athmara wa\q@u{a}too \q@u{h}aqqahu yawma \q@u{h}a\q@u{sa}dihi wal\q@u{a} tusrifoo innahu l\q@u{a} yu\q@u{h}ibbu almusrifeen\q@b{a}\qt@no{(141)}}
\qt@newcmd\qurantrans@lt@cmxxxi{Wamina alanAA\q@u{a}mi \q@u{h}amoolatan wafarshan kuloo mimm\q@u{a} razaqakumu All\q@u{a}hu wal\q@u{a} tattabiAAoo khu\q@u{t}uw\q@u{a}ti a\q@b{l}shshay\q@u{ta}ni innahu lakum AAaduwwun mubeen\q@b{un}\qt@no{(142)}}
\qt@newcmd\qurantrans@lt@cmxxxii{Tham\q@u{a}niyata azw\q@u{a}jin mina a\q@b{l}\q@u{dd}ani ithnayni wamina almaAAzi ithnayni qul \q@u{a}\q@b{l}\q@u{thth}akarayni \q@u{h}arrama ami alonthayayni amm\q@u{a} ishtamalat AAalayhi ar\q@u{ha}mu alonthayayni nabbioonee biAAilmin in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(143)}}
\qt@newcmd\qurantrans@lt@cmxxxiii{Wamina alibili ithnayni wamina albaqari ithnayni qul \q@u{a}\q@b{l}\q@u{thth}akarayni \q@u{h}arrama ami alonthayayni amm\q@u{a} ishtamalat AAalayhi ar\q@u{ha}mu alonthayayni am kuntum shuhad\q@u{a}a i\q@u{th} wa\q@u{ssa}kumu All\q@u{a}hu bih\q@u{atha} faman a\q@i{\q@u{th}}lamu mimmani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban liyu\q@u{d}illa a\q@b{l}nn\q@u{a}sa bighayri AAilmin inna All\q@u{a}ha l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(144)}}
\qt@newcmd\qurantrans@lt@cmxxxiv{Qul l\q@u{a} ajidu fee m\q@u{a} oo\q@u{h}iya ilayya mu\q@u{h}arraman AAal\q@u{a} \q@u{ta}AAimin ya\q@u{t}AAamuhu ill\q@u{a} an yakoona maytatan aw daman masfoo\q@u{h}an aw la\q@u{h}ma khinzeerin fainnahu rijsun aw fisqan ohilla lighayri All\q@u{a}hi bihi famani i\q@u{dt}urra ghayra b\q@u{a}ghin wal\q@u{a} AA\q@u{a}din fainna rabbaka ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(145)}}
\qt@newcmd\qurantrans@lt@cmxxxv{WaAAal\q@u{a} alla\q@u{th}eena h\q@u{a}doo \q@u{h}arramn\q@u{a} kulla \q@u{th}ee \q@i{\q@u{th}}ufurin wamina albaqari wa\q@b{a}lghanami \q@u{h}arramn\q@u{a} AAalayhim shu\q@u{h}oomahum\q@u{a} ill\q@u{a} m\q@u{a} \q@u{h}amalat \q@i{\q@u{th}}uhooruhum\q@u{a} awi al\q@u{h}aw\q@u{a}y\q@u{a} aw m\q@u{a} ikhtala\q@u{t}a biAAa\q@i{\q@u{th}}min \q@u{tha}lika jazayn\q@u{a}hum bibaghyihim wainn\q@u{a} la\q@u{sa}diqoon\q@b{a}\qt@no{(146)}}
\qt@newcmd\qurantrans@lt@cmxxxvi{Fain ka\q@u{thth}abooka faqul rabbukum \q@u{th}oo ra\q@u{h}matin w\q@u{a}siAAatin wal\q@u{a} yuraddu basuhu AAani alqawmi almujrimeen\q@b{a}\qt@no{(147)}}
\qt@newcmd\qurantrans@lt@cmxxxvii{Sayaqoolu alla\q@u{th}eena ashrakoo law sh\q@u{a}a All\q@u{a}hu m\q@u{a} ashrakn\q@u{a} wal\q@u{a} \q@u{a}b\q@u{a}on\q@u{a} wal\q@u{a} \q@u{h}arramn\q@u{a} min shayin ka\q@u{tha}lika ka\q@u{thth}aba alla\q@u{th}eena min qablihim \q@u{h}att\q@u{a} \q@u{tha}qoo basan\q@u{a} qul hal AAindakum min AAilmin fatukhrijoohu lan\q@u{a} in tattabiAAoona ill\q@u{a} a\q@b{l}\q@i{\q@u{thth}}anna wain antum ill\q@u{a} takhru\q@u{s}oon\q@b{a}\qt@no{(148)}}
\qt@newcmd\qurantrans@lt@cmxxxviii{Qul falill\q@u{a}hi al\q@u{h}ujjatu alb\q@u{a}lighatu falaw sh\q@u{a}a lahad\q@u{a}kum ajmaAAeen\q@b{a}\qt@no{(149)}}
\qt@newcmd\qurantrans@lt@cmxxxix{Qul halumma shuhad\q@u{a}akumu alla\q@u{th}eena yashhadoona anna All\q@u{a}ha \q@u{h}arrama h\q@u{atha} fain shahidoo fal\q@u{a} tashhad maAAahum wal\q@u{a} tattabiAA ahw\q@u{a}a alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} wa\q@b{a}lla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati wahum birabbihim yaAAdiloon\q@b{a}\qt@no{(150)}}
\qt@newcmd\qurantrans@lt@cmxl{Qul taAA\q@u{a}law atlu m\q@u{a} \q@u{h}arrama rabbukum AAalaykum all\q@u{a} tushrikoo bihi shayan wabi\q@b{a}lw\q@u{a}lidayni i\q@u{h}s\q@u{a}nan wal\q@u{a} taqtuloo awl\q@u{a}dakum min iml\q@u{a}qin na\q@u{h}nu narzuqukum waiyy\q@u{a}hum wal\q@u{a} taqraboo alfaw\q@u{ah}isha m\q@u{a} \q@i{\q@u{th}}ahara minh\q@u{a} wam\q@u{a} ba\q@u{t}ana wal\q@u{a} taqtuloo a\q@b{l}nnafsa allatee \q@u{h}arrama All\q@u{a}hu ill\q@u{a} bi\q@b{a}l\q@u{h}aqqi \q@u{tha}likum wa\q@u{ssa}kum bihi laAAallakum taAAqiloon\q@b{a}\qt@no{(151)}}
\qt@newcmd\qurantrans@lt@cmxli{Wal\q@u{a} taqraboo m\q@u{a}la alyateemi ill\q@u{a} bi\q@b{a}llatee hiya a\q@u{h}sanu \q@u{h}att\q@u{a} yablugha ashuddahu waawfoo alkayla wa\q@b{a}lmeez\q@u{a}na bi\q@b{a}lqis\q@u{t}i l\q@u{a} nukallifu nafsan ill\q@u{a} wusAAah\q@u{a} wai\q@u{tha} qultum fa\q@b{i}AAdiloo walaw k\q@u{a}na \q@u{tha} qurb\q@u{a} wabiAAahdi All\q@u{a}hi awfoo \q@u{tha}likum wa\q@u{ssa}kum bihi laAAallakum ta\q@u{th}akkaroon\q@b{a}\qt@no{(152)}}
\qt@newcmd\qurantrans@lt@cmxlii{Waanna h\q@u{atha} \q@u{s}ir\q@u{at}ee mustaqeeman fa\q@b{i}ttabiAAoohu wal\q@u{a} tattabiAAoo a\q@b{l}ssubula fatafarraqa bikum AAan sabeelihi \q@u{tha}likum wa\q@u{ssa}kum bihi laAAallakum tattaqoon\q@b{a}\qt@no{(153)}}
\qt@newcmd\qurantrans@lt@cmxliii{Thumma \q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba tam\q@u{a}man AAal\q@u{a} alla\q@u{th}ee a\q@u{h}sana wataf\q@u{s}eelan likulli shayin wahudan wara\q@u{h}matan laAAallahum biliq\q@u{a}i rabbihim yuminoon\q@b{a}\qt@no{(154)}}
\qt@newcmd\qurantrans@lt@cmxliv{Wah\q@u{atha} kit\q@u{a}bun anzaln\q@u{a}hu mub\q@u{a}rakun fa\q@b{i}ttabiAAoohu wa\q@b{i}ttaqoo laAAallakum tur\q@u{h}amoon\q@b{a}\qt@no{(155)}}
\qt@newcmd\qurantrans@lt@cmxlv{An taqooloo innam\q@u{a} onzila alkit\q@u{a}bu AAal\q@u{a} \q@u{ta}ifatayni min qablin\q@u{a} wain kunn\q@u{a} AAan dir\q@u{a}satihim lagh\q@u{a}fileen\q@b{a}\qt@no{(156)}}
\qt@newcmd\qurantrans@lt@cmxlvi{Aw taqooloo law ann\q@u{a} onzila AAalayn\q@u{a} alkit\q@u{a}bu lakunn\q@u{a} ahd\q@u{a} minhum faqad j\q@u{a}akum bayyinatun min rabbikum wahudan wara\q@u{h}matun faman a\q@i{\q@u{th}}lamu mimman ka\q@u{thth}aba bi\q@u{a}y\q@u{a}ti All\q@u{a}hi wa\q@u{s}adafa AAanh\q@u{a} sanajzee alla\q@u{th}eena ya\q@u{s}difoona AAan \q@u{a}y\q@u{a}tin\q@u{a} sooa alAAa\q@u{tha}bi bim\q@u{a} k\q@u{a}noo ya\q@u{s}difoon\q@b{a}\qt@no{(157)}}
\qt@newcmd\qurantrans@lt@cmxlvii{Hal yan\q@i{\q@u{th}}uroona ill\q@u{a} an tatiyahumu almal\q@u{a}ikatu aw yatiya rabbuka aw yatiya baAA\q@u{d}u \q@u{a}y\q@u{a}ti rabbika yawma yatee baAA\q@u{d}u \q@u{a}y\q@u{a}ti rabbika l\q@u{a} yanfaAAu nafsan eem\q@u{a}nuh\q@u{a} lam takun \q@u{a}manat min qablu aw kasabat fee eem\q@u{a}nih\q@u{a} khayran quli inta\q@i{\q@u{th}}iroo inn\q@u{a} munta\q@i{\q@u{th}}iroon\q@b{a}\qt@no{(158)}}
\qt@newcmd\qurantrans@lt@cmxlviii{Inna alla\q@u{th}eena farraqoo deenahum wak\q@u{a}noo shiyaAAan lasta minhum fee shayin innam\q@u{a} amruhum il\q@u{a} All\q@u{a}hi thumma yunabbiohum bim\q@u{a} k\q@u{a}noo yafAAaloon\q@b{a}\qt@no{(159)}}
\qt@newcmd\qurantrans@lt@cmxlix{Man j\q@u{a}a bi\q@b{a}l\q@u{h}asanati falahu AAashru amth\q@u{a}lih\q@u{a} waman j\q@u{a}a bi\q@b{al}ssayyi\q@u{a}ti fal\q@u{a} yujz\q@u{a} ill\q@u{a} mithlah\q@u{a} wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(160)}}
\qt@newcmd\qurantrans@lt@cml{Qul innanee had\q@u{a}nee rabbee il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeemin deenan qiyaman millata ibr\q@u{a}heema \q@u{h}aneefan wam\q@u{a} k\q@u{a}na mina almushrikeen\q@b{a}\qt@no{(161)}}
\qt@newcmd\qurantrans@lt@cmli{Qul inna \q@u{s}al\q@u{a}tee wanusukee wama\q@u{h}y\q@u{a}ya wamam\q@u{a}tee lill\q@u{a}hi rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(162)}}
\qt@newcmd\qurantrans@lt@cmlii{L\q@u{a} shareeka lahu wabi\q@u{tha}lika omirtu waan\q@u{a} awwalu almuslimeen\q@b{a}\qt@no{(163)}}
\qt@newcmd\qurantrans@lt@cmliii{Qul aghayra All\q@u{a}hi abghee rabban wahuwa rabbu kulli shayin wal\q@u{a} taksibu kullu nafsin ill\q@u{a} AAalayh\q@u{a} wal\q@u{a} taziru w\q@u{a}ziratun wizra okhr\q@u{a} thumma il\q@u{a} rabbikum marjiAAukum fayunabbiokum bim\q@u{a} kuntum feehi takhtalifoon\q@b{a}\qt@no{(164)}}
\qt@newcmd\qurantrans@lt@cmliv{Wahuwa alla\q@u{th}ee jaAAalakum khal\q@u{a}ifa alar\q@u{d}i warafaAAa baAA\q@u{d}akum fawqa baAA\q@u{d}in daraj\q@u{a}tin liyabluwakum fee m\q@u{a} \q@u{a}t\q@u{a}kum inna rabbaka sareeAAu alAAiq\q@u{a}bi wainnahu laghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(165)}}
\qt@newcmd\qurantrans@lt@cmlv{\basmalahlt Alifl\q@u{a}mmeem\q@u{sa}d\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@cmlvi{Kit\q@u{a}bun onzila ilayka fal\q@u{a} yakun fee \q@u{s}adrika \q@u{h}arajun minhu litun\q@u{th}ira bihi wa\q@u{th}ikr\q@u{a} lilmumineen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@cmlvii{IttabiAAoo m\q@u{a} onzila ilaykum min rabbikum wal\q@u{a} tattabiAAoo min doonihi awliy\q@u{a}a qaleelan m\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@cmlviii{Wakam min qaryatin ahlakn\q@u{a}h\q@u{a} faj\q@u{a}ah\q@u{a} basun\q@u{a} bay\q@u{a}tan aw hum q\q@u{a}iloon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@cmlix{Fam\q@u{a} k\q@u{a}na daAAw\q@u{a}hum i\q@u{th} j\q@u{a}ahum basun\q@u{a} ill\q@u{a} an q\q@u{a}loo inn\q@u{a} kunn\q@u{a} \q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@cmlx{Falanasalanna alla\q@u{th}eena orsila ilayhim walanasalanna almursaleen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@cmlxi{Falanaqu\q@u{ss}anna AAalayhim biAAilmin wam\q@u{a} kunn\q@u{a} gh\q@u{a}ibeen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@cmlxii{Wa\q@b{a}lwaznu yawmai\q@u{th}ini al\q@u{h}aqqu faman thaqulat maw\q@u{a}zeenuhu faol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@cmlxiii{Waman khaffat maw\q@u{a}zeenuhu faol\q@u{a}ika alla\q@u{th}eena khasiroo anfusahum bim\q@u{a} k\q@u{a}noo bi\q@u{a}y\q@u{a}tin\q@u{a} ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@cmlxiv{Walaqad makkann\q@u{a}kum fee alar\q@u{d}i wajaAAaln\q@u{a} lakum feeh\q@u{a} maAA\q@u{a}yisha qaleelan m\q@u{a} tashkuroon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@cmlxv{Walaqad khalaqn\q@u{a}kum thumma \q@u{s}awwarn\q@u{a}kum thumma quln\q@u{a} lilmal\q@u{a}ikati osjudoo li\q@u{a}dama fasajadoo ill\q@u{a} ibleesa lam yakun mina a\q@b{l}ss\q@u{a}jideen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@cmlxvi{Q\q@u{a}la m\q@u{a} manaAAaka all\q@u{a} tasjuda i\q@u{th} amartuka q\q@u{a}la an\q@u{a} khayrun minhu khalaqtanee min n\q@u{a}rin wakhalaqtahu min \q@u{t}een\q@b{in}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@cmlxvii{Q\q@u{a}la fa\q@b{i}hbi\q@u{t} minh\q@u{a} fam\q@u{a} yakoonu laka an tatakabbara feeh\q@u{a} fa\q@b{o}khruj innaka mina a\q@b{l}\q@u{ssa}ghireen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@cmlxviii{Q\q@u{a}la an\q@i{\q@u{th}}irnee il\q@u{a} yawmi yubAAathoon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@cmlxix{Q\q@u{a}la innaka mina almun\q@i{\q@u{th}}areen\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@cmlxx{Q\q@u{a}la fabim\q@u{a} aghwaytanee laaqAAudanna lahum \q@u{s}ir\q@u{at}aka almustaqeem\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@cmlxxi{Thumma la\q@u{a}tiyannahum min bayni aydeehim wamin khalfihim waAAan aym\q@u{a}nihim waAAan sham\q@u{a}ilihim wal\q@u{a} tajidu aktharahum sh\q@u{a}kireen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@cmlxxii{Q\q@u{a}la okhruj minh\q@u{a} ma\q@u{th}ooman mad\q@u{h}ooran laman tabiAAaka minhum laamlaanna jahannama minkum ajmaAAeen\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@cmlxxiii{Way\q@u{a} \q@u{a}damu oskun anta wazawjuka aljannata fakul\q@u{a} min \q@u{h}aythu shitum\q@u{a} wal\q@u{a} taqrab\q@u{a} h\q@u{ath}ihi a\q@b{l}shshajarata fatakoon\q@u{a} mina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@cmlxxiv{Fawaswasa lahum\q@u{a} a\q@b{l}shshay\q@u{ta}nu liyubdiya lahum\q@u{a} m\q@u{a} wooriya AAanhum\q@u{a} min saw\q@u{a}tihim\q@u{a} waq\q@u{a}la m\q@u{a} nah\q@u{a}kum\q@u{a} rabbukum\q@u{a} AAan h\q@u{ath}ihi a\q@b{l}shshajarati ill\q@u{a} an takoon\q@u{a} malakayni aw takoon\q@u{a} mina alkh\q@u{a}lideen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@cmlxxv{Waq\q@u{a}samahum\q@u{a} innee lakum\q@u{a} lamina a\q@b{l}nn\q@u{as}i\q@u{h}een\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@cmlxxvi{Fadall\q@u{a}hum\q@u{a} bighuroorin falamm\q@u{a} \q@u{tha}q\q@u{a} a\q@b{l}shshajarata badat lahum\q@u{a} saw\q@u{a}tuhum\q@u{a} wa\q@u{t}afiq\q@u{a} yakh\q@u{s}if\q@u{a}ni AAalayhim\q@u{a} min waraqi aljannati wan\q@u{a}d\q@u{a}hum\q@u{a} rabbuhum\q@u{a} alam anhakum\q@u{a} AAan tilkum\q@u{a} a\q@b{l}shshajarati waaqul lakum\q@u{a} inna a\q@b{l}shshay\q@u{ta}na lakum\q@u{a} AAaduwwun mubeen\q@b{un}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@cmlxxvii{Q\q@u{a}l\q@u{a} rabban\q@u{a} \q@i{\q@u{th}}alamn\q@u{a} anfusan\q@u{a} wain lam taghfir lan\q@u{a} watar\q@u{h}amn\q@u{a }lanakoonanna mina alkh\q@u{a}sireen\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@cmlxxviii{Q\q@u{a}la ihbi\q@u{t}oo baAA\q@u{d}ukum libaAA\q@u{d}in AAaduwwun walakum fee alar\q@u{d}i mustaqarrun wamat\q@u{a}AAun il\q@u{a} \q@u{h}een\q@b{in}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@cmlxxix{Q\q@u{a}la feeh\q@u{a} ta\q@u{h}yawna wafeeh\q@u{a} tamootoona waminh\q@u{a} tukhrajoon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@cmlxxx{Y\q@u{a} banee \q@u{a}dama qad anzaln\q@u{a} AAalaykum lib\q@u{a}san yuw\q@u{a}ree saw\q@u{a}tikum wareeshan walib\q@u{a}su a\q@b{l}ttaqw\q@u{a} \q@u{tha}lika khayrun \q@u{tha}lika min \q@u{a}y\q@u{a}ti All\q@u{a}hi laAAallahum ya\q@u{thth}akkaroon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@cmlxxxi{Y\q@u{a} banee \q@u{a}dama l\q@u{a} yaftinannakumu a\q@b{l}shshay\q@u{ta}nu kam\q@u{a} akhraja abawaykum mina aljannati yanziAAu AAanhum\q@u{a} lib\q@u{a}sahum\q@u{a} liyuriyahum\q@u{a} saw\q@u{a}tihim\q@u{a} innahu yar\q@u{a}kum huwa waqabeeluhu min \q@u{h}aythu l\q@u{a} tarawnahum inn\q@u{a} jaAAaln\q@u{a} a\q@b{l}shshay\q@u{at}eena awliy\q@u{a}a lilla\q@u{th}eena l\q@u{a} yuminoon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@cmlxxxii{Wai\q@u{tha} faAAaloo f\q@u{ah}ishatan q\q@u{a}loo wajadn\q@u{a} AAalayh\q@u{a} \q@u{a}b\q@u{a}an\q@u{a} wa\q@b{A}ll\q@u{a}hu amaran\q@u{a} bih\q@u{a} qul inna All\q@u{a}ha l\q@u{a} yamuru bi\q@b{a}lfa\q@u{h}sh\q@u{a}i ataqooloona AAal\q@u{a} All\q@u{a}hi m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@cmlxxxiii{Qul amara rabbee bi\q@b{a}lqis\q@u{t}i waaqeemoo wujoohakum AAinda kulli masjidin wa\q@b{o}dAAoohu mukhli\q@u{s}eena lahu a\q@b{l}ddeena kam\q@u{a} badaakum taAAoodoon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@cmlxxxiv{Fareeqan had\q@u{a} wafareeqan \q@u{h}aqqa AAalayhimu a\q@b{l}\q@u{dd}al\q@u{a}latu innahumu ittakha\q@u{th}oo a\q@b{l}shshay\q@u{at}eena awliy\q@u{a}a min dooni All\q@u{a}hi waya\q@u{h}saboona annahum muhtadoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@cmlxxxv{Y\q@u{a} banee \q@u{a}dama khu\q@u{th}oo zeenatakum AAinda kulli masjidin wakuloo wa\q@b{i}shraboo wal\q@u{a} tusrifoo innahu l\q@u{a} yu\q@u{h}ibbu almusrifeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@cmlxxxvi{Qul man \q@u{h}arrama zeenata All\q@u{a}hi allatee akhraja liAAib\q@u{a}dihi wa\q@b{al}\q@u{tt}ayyib\q@u{a}ti mina a\q@b{l}rrizqi qul hiya lilla\q@u{th}eena \q@u{a}manoo fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} kh\q@u{a}li\q@u{s}atan yawma alqiy\q@u{a}mati ka\q@u{tha}lika nufa\q@u{ss}ilu al\q@u{a}y\q@u{a}ti liqawmin yaAAlamoon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@cmlxxxvii{Qul innam\q@u{a} \q@u{h}arrama rabbiya alfaw\q@u{ah}isha m\q@u{a} \q@i{\q@u{th}}ahara minh\q@u{a} wam\q@u{a} ba\q@u{t}ana wa\q@b{a}lithma wa\q@b{a}lbaghya bighayri al\q@u{h}aqqi waan tushrikoo bi\q@b{A}ll\q@u{a}hi m\q@u{a} lam yunazzil bihi sul\q@u{ta}nan waan taqooloo AAal\q@u{a} All\q@u{a}hi m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@cmlxxxviii{Walikulli ommatin ajalun fai\q@u{tha} j\q@u{a}a ajaluhum l\q@u{a} yastakhiroona s\q@u{a}AAatan wal\q@u{a} yastaqdimoon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@cmlxxxix{Y\q@u{a} banee \q@u{a}dama imm\q@u{a} yatiyannakum rusulun minkum yaqu\q@u{ss}oona AAalaykum \q@u{a}y\q@u{a}tee famani ittaq\q@u{a} waa\q@u{s}la\q@u{h}a fal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@cmxc{Wa\q@b{a}lla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} wa\q@b{i}stakbaroo AAanh\q@u{a} ol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@cmxci{Faman a\q@i{\q@u{th}}lamu mimmani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban aw ka\q@u{thth}aba bi\q@u{a}y\q@u{a}tihi ol\q@u{a}ika yan\q@u{a}luhum na\q@u{s}eebuhum mina alkit\q@u{a}bi \q@u{h}att\q@u{a} i\q@u{tha} j\q@u{a}athum rusulun\q@u{a} yatawaffawnahum q\q@u{a}loo ayna m\q@u{a} kuntum tadAAoona min dooni All\q@u{a}hi q\q@u{a}loo \q@u{d}alloo AAann\q@u{a} washahidoo AAal\q@u{a} anfusihim annahum k\q@u{a}noo k\q@u{a}fireen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@cmxcii{Q\q@u{a}la odkhuloo fee omamin qad khalat min qablikum mina aljinni wa\q@b{a}linsi fee a\q@b{l}nn\q@u{a}ri kullam\q@u{a} dakhalat ommatun laAAanat okhtah\q@u{a} \q@u{h}att\q@u{a} i\q@u{tha} idd\q@u{a}rakoo feeh\q@u{a} jameeAAan q\q@u{a}lat okhr\q@u{a}hum liool\q@u{a}hum rabban\q@u{a} h\q@u{a}ol\q@u{a}i a\q@u{d}alloon\q@u{a} fa\q@u{a}tihim AAa\q@u{tha}ban \q@u{d}iAAfan mina a\q@b{l}nn\q@u{a}ri q\q@u{a}la likullin \q@u{d}iAAfun wal\q@u{a}kin l\q@u{a} taAAlamoon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@cmxciii{Waq\q@u{a}lat ool\q@u{a}hum liokhr\q@u{a}hum fam\q@u{a} k\q@u{a}na lakum AAalayn\q@u{a} min fa\q@u{d}lin fa\q@u{th}ooqoo alAAa\q@u{tha}ba bim\q@u{a} kuntum taksiboon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@cmxciv{Inna alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} wa\q@b{i}stakbaroo AAanh\q@u{a} l\q@u{a} tufatta\q@u{h}u lahum abw\q@u{a}bu a\q@b{l}ssam\q@u{a}i wal\q@u{a} yadkhuloona aljannata \q@u{h}att\q@u{a} yalija aljamalu fee sammi alkhiy\q@u{at}i waka\q@u{tha}lika najzee almujrimeen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@cmxcv{Lahum min jahannama mih\q@u{a}dun wamin fawqihim ghaw\q@u{a}shin waka\q@u{tha}lika najzee a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@cmxcvi{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti l\q@u{a} nukallifu nafsan ill\q@u{a} wusAAah\q@u{a} ol\q@u{a}ika a\q@u{s}\q@u{ha}bu aljannati hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@cmxcvii{WanazaAAn\q@u{a} m\q@u{a} fee \q@u{s}udoorihim min ghillin tajree min ta\q@u{h}tihimu alanh\q@u{a}ru waq\q@u{a}loo al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee had\q@u{a}n\q@u{a} lih\q@u{atha} wam\q@u{a} kunn\q@u{a} linahtadiya lawl\q@u{a} an had\q@u{a}n\q@u{a} All\q@u{a}hu laqad j\q@u{a}at rusulu rabbin\q@u{a} bi\q@b{a}l\q@u{h}aqqi wanoodoo an tilkumu aljannatu oorithtumooh\q@u{a} bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@cmxcviii{Wan\q@u{a}d\q@u{a} a\q@u{s}\q@u{ha}bu aljannati a\q@u{s}\q@u{ha}ba a\q@b{l}nn\q@u{a}ri an qad wajadn\q@u{a} m\q@u{a} waAAadan\q@u{a} rabbun\q@u{a} \q@u{h}aqqan fahal wajadtum m\q@u{a} waAAada rabbukum \q@u{h}aqqan q\q@u{a}loo naAAam faa\q@u{thth}ana mua\q@u{thth}inun baynahum an laAAnatu All\q@u{a}hi AAal\q@u{a} a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@cmxcix{Alla\q@u{th}eena ya\q@u{s}uddoona AAan sabeeli All\q@u{a}hi wayabghoonah\q@u{a} AAiwajan wahum bi\q@b{a}l\q@u{a}khirati k\q@u{a}firoon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@m{Wabaynahum\q@u{a} \q@u{h}ij\q@u{a}bun waAAal\q@u{a} alaAAr\q@u{a}fi rij\q@u{a}lun yaAArifoona kullan biseem\q@u{a}hum wan\q@u{a}daw a\q@u{s}\q@u{ha}ba aljannati an sal\q@u{a}mun AAalaykum lam yadkhulooh\q@u{a} wahum ya\q@u{t}maAAoon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mi{Wai\q@u{tha} \q@u{s}urifat ab\q@u{sa}ruhum tilq\q@u{a}a a\q@u{s}\q@u{ha}bi a\q@b{l}nn\q@u{a}ri q\q@u{a}loo rabban\q@u{a} l\q@u{a} tajAAaln\q@u{a} maAAa alqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mii{Wan\q@u{a}d\q@u{a} a\q@u{s}\q@u{ha}bu alaAAr\q@u{a}fi rij\q@u{a}lan yaAArifoonahum biseem\q@u{a}hum q\q@u{a}loo m\q@u{a} aghn\q@u{a} AAankum jamAAukum wam\q@u{a} kuntum tastakbiroon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@miii{Ah\q@u{a}ol\q@u{a}i alla\q@u{th}eena aqsamtum l\q@u{a} yan\q@u{a}luhumu All\q@u{a}hu bira\q@u{h}matin odkhuloo aljannata l\q@u{a} khawfun AAalaykum wal\q@u{a} antum ta\q@u{h}zanoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@miv{Wan\q@u{a}d\q@u{a} a\q@u{s}\q@u{ha}bu a\q@b{l}n\q@u{a}ri a\q@u{s}\q@u{ha}ba aljannati an afee\q@u{d}oo AAalayn\q@u{a} mina alm\q@u{a}i aw mimm\q@u{a} razaqakumu All\q@u{a}hu q\q@u{a}loo inna All\q@u{a}ha \q@u{h}arramahum\q@u{a} AAal\q@u{a} alk\q@u{a}fireen\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mv{Alla\q@u{th}eena ittakha\q@u{th}oo deenahum lahwan walaAAiban wagharrathumu al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} fa\q@b{a}lyawma nans\q@u{a}hum kam\q@u{a} nasoo liq\q@u{a}a yawmihim h\q@u{atha} wam\q@u{a} k\q@u{a}noo bi\q@u{a}y\q@u{a}tin\q@u{a} yaj\q@u{h}adoon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mvi{Walaqad jin\q@u{a}hum bikit\q@u{a}bin fa\q@u{ss}aln\q@u{a}hu AAal\q@u{a} AAilmin hudan wara\q@u{h}matan liqawmin yuminoon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mvii{Hal yan\q@i{\q@u{th}}uroona ill\q@u{a} taweelahu yawma yatee taweeluhu yaqoolu alla\q@u{th}eena nasoohu min qablu qad j\q@u{a}at rusulu rabbin\q@u{a} bi\q@b{a}l\q@u{h}aqqi fahal lan\q@u{a} min shufaAA\q@u{a}a fayashfaAAoo lan\q@u{a} aw nuraddu fanaAAmala ghayra alla\q@u{th}ee kunn\q@u{a} naAAmalu qad khasiroo anfusahum wa\q@u{d}alla AAanhum m\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mviii{Inna rabbakumu All\q@u{a}hu alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a fee sittati ayy\q@u{a}min thumma istaw\q@u{a} AAal\q@u{a} alAAarshi yughshee allayla a\q@b{l}nnah\q@u{a}ra ya\q@u{t}lubuhu \q@u{h}atheethan wa\q@b{al}shshamsa wa\q@b{a}lqamara wa\q@b{al}nnujooma musakhkhar\q@u{a}tin biamrihi al\q@u{a} lahu alkhalqu wa\q@b{a}lamru tab\q@u{a}raka All\q@u{a}hu rabbu alAA\q@u{a}lameen\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mix{OdAAoo rabbakum ta\q@u{d}arruAAan wakhufyatan innahu l\q@u{a} yu\q@u{h}ibbu almuAAtadeen\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mx{Wal\q@u{a} tufsidoo fee alar\q@u{d}i baAAda i\q@u{s}l\q@u{ah}ih\q@u{a} wa\q@b{o}dAAoohu khawfan wa\q@u{t}amaAAan inna ra\q@u{h}mata All\q@u{a}hi qareebun mina almu\q@u{h}sineen\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mxi{Wahuwa alla\q@u{th}ee yursilu a\q@b{l}rriy\q@u{ah}a bushran bayna yaday ra\q@u{h}matihi \q@u{h}att\q@u{a} i\q@u{tha} aqallat sa\q@u{ha}ban thiq\q@u{a}lan suqn\q@u{a}hu libaladin mayyitin faanzaln\q@u{a} bihi alm\q@u{a}a faakhrajn\q@u{a} bihi min kulli a\q@b{l}ththamar\q@u{a}ti ka\q@u{tha}lika nukhriju almawt\q@u{a} laAAallakum ta\q@u{th}akkaroon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mxii{Wa\q@b{a}lbaladu a\q@b{l}\q@u{tt}ayyibu yakhruju nab\q@u{a}tuhu bii\q@u{th}ni rabbihi wa\q@b{a}lla\q@u{th}ee khabutha l\q@u{a} yakhruju ill\q@u{a} nakidan ka\q@u{tha}lika nu\q@u{s}arrifu al\q@u{a}y\q@u{a}ti liqawmin yashkuroon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mxiii{Laqad arsaln\q@u{a} noo\q@u{h}an il\q@u{a} qawmihi faq\q@u{a}la y\q@u{a} qawmi oAAbudoo All\q@u{a}ha m\q@u{a} lakum min il\q@u{a}hin ghayruhu innee akh\q@u{a}fu AAalaykum AAa\q@u{tha}ba yawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mxiv{Q\q@u{a}la almalao min qawmihi inn\q@u{a} lanar\q@u{a}ka fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mxv{Q\q@u{a}la y\q@u{a} qawmi laysa bee \q@u{d}al\q@u{a}latun wal\q@u{a}kinnee rasoolun min rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mxvi{Oballighukum ris\q@u{a}l\q@u{a}ti rabbee waan\q@u{s}a\q@u{h}u lakum waaAAlamu mina All\q@u{a}hi m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mxvii{AwaAAajibtum an j\q@u{a}akum \q@u{th}ikrun min rabbikum AAal\q@u{a} rajulin minkum liyun\q@u{th}irakum walitattaqoo walaAAallakum tur\q@u{h}amoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mxviii{Faka\q@u{thth}aboohu faanjayn\q@u{a}hu wa\q@b{a}lla\q@u{th}eena maAAahu fee alfulki waaghraqn\q@u{a} alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} innahum k\q@u{a}noo qawman AAameen\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mxix{Wail\q@u{a} AA\q@u{a}din akh\q@u{a}hum hoodan q\q@u{a}la y\q@u{a} qawmi oAAbudoo All\q@u{a}ha m\q@u{a} lakum min il\q@u{a}hin ghayruhu afal\q@u{a} tattaqoon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mxx{Q\q@u{a}la almalao alla\q@u{th}eena kafaroo min qawmihi inn\q@u{a} lanar\q@u{a}ka fee saf\q@u{a}hatin wainn\q@u{a} lana\q@i{\q@u{th}}unnuka mina alk\q@u{ath}ibeen\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mxxi{Q\q@u{a}la y\q@u{a} qawmi laysa bee saf\q@u{a}hatun wal\q@u{a}kinnee rasoolun min rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mxxii{Oballighukum ris\q@u{a}l\q@u{a}ti rabbee waan\q@u{a} lakum n\q@u{as}i\q@u{h}un ameen\q@b{un}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mxxiii{AwaAAajibtum an j\q@u{a}akum \q@u{th}ikrun min rabbikum AAal\q@u{a} rajulin minkum liyun\q@u{th}irakum wa\q@b{o}\q@u{th}kuroo i\q@u{th} jaAAalakum khulaf\q@u{a}a min baAAdi qawmi noo\q@u{h}in waz\q@u{a}dakum fee alkhalqi bas\q@u{t}atan fa\q@b{o}\q@u{th}kuroo \q@u{a}l\q@u{a}a All\q@u{a}hi laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mxxiv{Q\q@u{a}loo ajitan\q@u{a} linaAAbuda All\q@u{a}ha wa\q@u{h}dahu wana\q@u{th}ara m\q@u{a} k\q@u{a}na yaAAbudu \q@u{a}b\q@u{a}on\q@u{a} fatin\q@u{a} bim\q@u{a} taAAidun\q@u{a} in kunta mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mxxv{Q\q@u{a}la qad waqaAAa AAalaykum min rabbikum rijsun wagha\q@u{d}abun atuj\q@u{a}diloonanee fee asm\q@u{a}in sammaytumooh\q@u{a} antum wa\q@u{a}b\q@u{a}okum m\q@u{a} nazzala All\q@u{a}hu bih\q@u{a} min sul\q@u{ta}nin fa\q@b{i}nta\q@i{\q@u{th}}iroo innee maAAakum mina almunta\q@i{\q@u{th}}ireen\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mxxvi{Faanjayn\q@u{a}hu wa\q@b{a}lla\q@u{th}eena maAAahu bira\q@u{h}matin minn\q@u{a} waqa\q@u{t}aAAn\q@u{a} d\q@u{a}bira alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} wam\q@u{a} k\q@u{a}noo mumineen\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mxxvii{Wail\q@u{a} thamooda akh\q@u{a}hum \q@u{sa}li\q@u{h}an q\q@u{a}la y\q@u{a} qawmi oAAbudoo All\q@u{a}ha m\q@u{a} lakum min il\q@u{a}hin ghayruhu qad j\q@u{a}atkum bayyinatun min rabbikum h\q@u{ath}ihi n\q@u{a}qatu All\q@u{a}hi lakum \q@u{a}yatan fa\q@u{th}arooh\q@u{a} takul fee ar\q@u{d}i All\q@u{a}hi wal\q@u{a} tamassooh\q@u{a} bisooin fayakhu\q@u{th}akum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mxxviii{Wa\q@b{o}\q@u{th}kuroo i\q@u{th} jaAAalakum khulaf\q@u{a}a min baAAdi AA\q@u{a}din wabawwaakum fee alar\q@u{d}i tattakhi\q@u{th}oona min suhoolih\q@u{a} qu\q@u{s}ooran watan\q@u{h}itoona aljib\q@u{a}la buyootan fa\q@b{o}\q@u{th}kuroo \q@u{a}l\q@u{a}a All\q@u{a}hi wal\q@u{a} taAAthaw fee alar\q@u{d}i mufsideen\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mxxix{Q\q@u{a}la almalao alla\q@u{th}eena istakbaroo min qawmihi lilla\q@u{th}eena istu\q@u{d}AAifoo liman \q@u{a}mana minhum ataAAlamoona anna \q@u{sa}li\q@u{h}an mursalun min rabbihi q\q@u{a}loo inn\q@u{a} bim\q@u{a} orsila bihi muminoon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mxxx{Q\q@u{a}la alla\q@u{th}eena istakbaroo inn\q@u{a} bi\q@b{a}lla\q@u{th}ee \q@u{a}mantum bihi k\q@u{a}firoon\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mxxxi{FaAAaqaroo a\q@b{l}nn\q@u{a}qata waAAataw AAan amri rabbihim waq\q@u{a}loo y\q@u{a} \q@u{sa}li\q@u{h}u itin\q@u{a} bim\q@u{a} taAAidun\q@u{a} in kunta mina almursaleen\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mxxxii{Faakha\q@u{th}athumu a\q@b{l}rrajfatu faa\q@u{s}ba\q@u{h}oo fee d\q@u{a}rihim j\q@u{a}thimeen\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mxxxiii{Fatawall\q@u{a} AAanhum waq\q@u{a}la y\q@u{a} qawmi laqad ablaghtukum ris\q@u{a}lata rabbee wana\q@u{s}a\q@u{h}tu lakum wal\q@u{a}kin l\q@u{a} tu\q@u{h}ibboona a\q@b{l}nn\q@u{as}i\q@u{h}een\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mxxxiv{Waloo\q@u{t}an i\q@u{th} q\q@u{a}la liqawmihi atatoona alf\q@u{ah}ishata m\q@u{a} sabaqakum bih\q@u{a} min a\q@u{h}adin mina alAA\q@u{a}lameen\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mxxxv{Innakum latatoona a\q@b{l}rrij\q@u{a}la shahwatan min dooni a\q@b{l}nnis\q@u{a}i bal antum qawmun musrifoon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mxxxvi{Wam\q@u{a} k\q@u{a}na jaw\q@u{a}ba qawmihi ill\q@u{a} an q\q@u{a}loo akhrijoohum min qaryatikum innahum on\q@u{a}sun yata\q@u{t}ahharoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mxxxvii{Faanjayn\q@u{a}hu waahlahu ill\q@u{a} imraatahu k\q@u{a}nat mina algh\q@u{a}bireen\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mxxxviii{Waam\q@u{t}arn\q@u{a} AAalayhim ma\q@u{t}aran fa\q@b{o}n\q@i{\q@u{th}}ur kayfa k\q@u{a}na AA\q@u{a}qibatu almujrimeen\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mxxxix{Wail\q@u{a} madyana akh\q@u{a}hum shuAAayban q\q@u{a}la y\q@u{a} qawmi oAAbudoo All\q@u{a}ha m\q@u{a} lakum min il\q@u{a}hin ghayruhu qad j\q@u{a}atkum bayyinatun min rabbikum faawfoo alkayla wa\q@b{a}lmeez\q@u{a}na wal\q@u{a} tabkhasoo a\q@b{l}nn\q@u{a}sa ashy\q@u{a}ahum wal\q@u{a} tufsidoo fee alar\q@u{d}i baAAda i\q@u{s}l\q@u{ah}ih\q@u{a} \q@u{tha}likum khayrun lakum in kuntum mumineen\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mxl{Wal\q@u{a} taqAAudoo bikulli \q@u{s}ir\q@u{at}in tooAAidoona wata\q@u{s}uddoona AAan sabeeli All\q@u{a}hi man \q@u{a}mana bihi watabghoonah\q@u{a} AAiwajan wa\q@b{o}\q@u{th}kuroo i\q@u{th} kuntum qaleelan fakaththarakum wa\q@b{o}n\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu almufsideen\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mxli{Wain k\q@u{a}na \q@u{ta}ifatun minkum \q@u{a}manoo bi\q@b{a}lla\q@u{th}ee orsiltu bihi wa\q@u{ta}ifatun lam yuminoo fa\q@b{i}\q@u{s}biroo \q@u{h}att\q@u{a} ya\q@u{h}kuma All\q@u{a}hu baynan\q@u{a} wahuwa khayru al\q@u{ha}kimeen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mxlii{Q\q@u{a}la almalao alla\q@u{th}eena istakbaroo min qawmihi lanukhrijannaka y\q@u{a} shuAAaybu wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo maAAaka min qaryatin\q@u{a} aw lataAAoodunna fee millatin\q@u{a} q\q@u{a}la awalaw kunn\q@u{a} k\q@u{a}riheen\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mxliii{Qadi iftarayn\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban in AAudn\q@u{a} fee millatikum baAAda i\q@u{th} najj\q@u{a}n\q@u{a} All\q@u{a}hu minh\q@u{a} wam\q@u{a} yakoonu lan\q@u{a} an naAAooda feeh\q@u{a} ill\q@u{a} an yash\q@u{a}a All\q@u{a}hu rabbun\q@u{a} wasiAAa rabbun\q@u{a} kulla shayin AAilman AAal\q@u{a} All\q@u{a}hi tawakkaln\q@u{a} rabban\q@u{a} ifta\q@u{h} baynan\q@u{a} wabayna qawmin\q@u{a} bi\q@b{a}l\q@u{h}aqqi waanta khayru alf\q@u{a}ti\q@u{h}een\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mxliv{Waq\q@u{a}la almalao alla\q@u{th}eena kafaroo min qawmihi laini ittabaAAtum shuAAayban innakum i\q@u{th}an lakh\q@u{a}siroon\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mxlv{Faakha\q@u{th}athumu a\q@b{l}rrajfatu faa\q@u{s}ba\q@u{h}oo fee d\q@u{a}rihim j\q@u{a}thimeen\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mxlvi{Alla\q@u{th}eena ka\q@u{thth}aboo shuAAayban kaan lam yaghnaw feeh\q@u{a} alla\q@u{th}eena ka\q@u{thth}aboo shuAAayban k\q@u{a}noo humu alkh\q@u{a}sireen\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mxlvii{Fatawall\q@u{a} AAanhum waq\q@u{a}la y\q@u{a} qawmi laqad ablaghtukum ris\q@u{a}l\q@u{a}ti rabbee wana\q@u{s}a\q@u{h}tu lakum fakayfa \q@u{a}s\q@u{a} AAal\q@u{a} qawmin k\q@u{a}fireen\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mxlviii{Wam\q@u{a} arsaln\q@u{a} fee qaryatin min nabiyyin ill\q@u{a} akha\q@u{th}n\q@u{a} ahlah\q@u{a} bi\q@b{a}lbas\q@u{a}i wa\q@b{al}\q@u{dd}arr\q@u{a}i laAAallahum ya\q@u{dd}arraAAoon\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mxlix{Thumma baddaln\q@u{a} mak\q@u{a}na a\q@b{l}ssayyiati al\q@u{h}asanata \q@u{h}att\q@u{a} AAafaw waq\q@u{a}loo qad massa \q@u{a}b\q@u{a}an\q@u{a} a\q@b{l}\q@u{dd}arr\q@u{a}o wa\q@b{al}ssarr\q@u{a}o faakha\q@u{th}n\q@u{a}hum baghtatan wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@ml{Walaw anna ahla alqur\q@u{a} \q@u{a}manoo wa\q@b{i}ttaqaw lafata\q@u{h}n\q@u{a} AAalayhim barak\q@u{a}tin mina a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i wal\q@u{a}kin ka\q@u{thth}aboo faakha\q@u{th}n\q@u{a}hum bim\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mli{Afaamina ahlu alqur\q@u{a} an yatiyahum basun\q@u{a} bay\q@u{a}tan wahum n\q@u{a}imoon\q@b{a}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mlii{Awa amina ahlu alqur\q@u{a} an yatiyahum basun\q@u{a} \q@u{d}u\q@u{h}an wahum yalAAaboon\q@b{a}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mliii{Afaaminoo makra All\q@u{a}hi fal\q@u{a} yamanu makra All\q@u{a}hi ill\q@u{a} alqawmu alkh\q@u{a}siroon\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mliv{Awalam yahdi lilla\q@u{th}eena yarithoona alar\q@u{d}a min baAAdi ahlih\q@u{a} an law nash\q@u{a}o a\q@u{s}abn\q@u{a}hum bi\q@u{th}unoobihim wana\q@u{t}baAAu AAal\q@u{a} quloobihim fahum l\q@u{a} yasmaAAoon\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mlv{Tilka alqur\q@u{a} naqu\q@u{ss}u AAalayka min anb\q@u{a}ih\q@u{a} walaqad j\q@u{a}athum rusuluhum bi\q@b{a}lbayyin\q@u{a}ti fam\q@u{a} k\q@u{a}noo liyuminoo bim\q@u{a} ka\q@u{thth}aboo min qablu ka\q@u{tha}lika ya\q@u{t}baAAu All\q@u{a}hu AAal\q@u{a} quloobi alk\q@u{a}fireen\q@b{a}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mlvi{Wam\q@u{a} wajadn\q@u{a} liaktharihim min AAahdin wain wajadn\q@u{a} aktharahum laf\q@u{a}siqeen\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mlvii{Thumma baAAathn\q@u{a} min baAAdihim moos\q@u{a} bi\q@u{a}y\q@u{a}tin\q@u{a} il\q@u{a} firAAawna wamalaihi fa\q@i{\q@u{th}}alamoo bih\q@u{a} fa\q@b{o}nu\q@i{\q@u{th}}ur kayfa k\q@u{a}na AA\q@u{a}qibatu almufsideen\q@b{a}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mlviii{Waq\q@u{a}la moos\q@u{a} y\q@u{a} firAAawnu innee rasoolun min rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mlix{\q@u{H}aqeequn AAal\q@u{a} an l\q@u{a} aqoola AAal\q@u{a} All\q@u{a}hi ill\q@u{a} al\q@u{h}aqqa qad jitukum bibayyinatin min rabbikum faarsil maAAiya banee isr\q@u{a}eel\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mlx{Q\q@u{a}la in kunta jita bi\q@u{a}yatin fati bih\q@u{a} in kunta mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mlxi{Faalq\q@u{a} AAa\q@u{sa}hu fai\q@u{tha} hiya thuAAb\q@u{a}nun mubeen\q@b{un}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mlxii{WanazaAAa yadahu fai\q@u{tha} hiya bay\q@u{da}o li\q@b{l}nn\q@u{a}\q@i{\q@u{th}}ireen\q@b{a}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mlxiii{Q\q@u{a}la almalao min qawmi firAAawna inna h\q@u{atha} las\q@u{ah}irun AAaleem\q@b{un}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mlxiv{Yureedu an yukhrijakum min ar\q@u{d}ikum fam\q@u{atha} tamuroon\q@b{a}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mlxv{Q\q@u{a}loo arjih waakh\q@u{a}hu waarsil fee almad\q@u{a}ini \q@u{ha}shireen\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mlxvi{Yatooka bikulli s\q@u{ah}irin AAaleem\q@b{in}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@mlxvii{Waj\q@u{a}a a\q@b{l}ssa\q@u{h}aratu firAAawna q\q@u{a}loo inna lan\q@u{a} laajran in kunn\q@u{a} na\q@u{h}nu algh\q@u{a}libeen\q@b{a}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@mlxviii{Q\q@u{a}la naAAam wainnakum lamina almuqarrabeen\q@b{a}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@mlxix{Q\q@u{a}loo y\q@u{a} moos\q@u{a} imm\q@u{a} an tulqiya waimm\q@u{a} an nakoona na\q@u{h}nu almulqeen\q@b{a}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@mlxx{Q\q@u{a}la alqoo falamm\q@u{a} alqaw sa\q@u{h}aroo aAAyuna a\q@b{l}nn\q@u{a}si wa\q@b{i}starhaboohum waj\q@u{a}oo bisi\q@u{h}rin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@mlxxi{Waaw\q@u{h}ayn\q@u{a} il\q@u{a} moos\q@u{a} an alqi AAa\q@u{sa}ka fai\q@u{tha} hiya talqafu m\q@u{a} yafikoon\q@b{a}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@mlxxii{FawaqaAAa al\q@u{h}aqqu waba\q@u{t}ala m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@mlxxiii{Faghuliboo hun\q@u{a}lika wa\q@b{i}nqalaboo \q@u{sa}ghireen\q@b{a}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@mlxxiv{Waolqiya a\q@b{l}ssa\q@u{h}aratu s\q@u{a}jideen\q@b{a}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@mlxxv{Q\q@u{a}loo \q@u{a}mann\q@u{a} birabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@mlxxvi{Rabbi moos\q@u{a} wah\q@u{a}roon\q@b{a}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@mlxxvii{Q\q@u{a}la firAAawnu \q@u{a}mantum bihi qabla an \q@u{ath}ana lakum inna h\q@u{atha} lamakrun makartumoohu fee almadeenati litukhrijoo minh\q@u{a} ahlah\q@u{a} fasawfa taAAlamoon\q@b{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@mlxxviii{Laoqa\q@u{t}iAAanna aydiyakum waarjulakum min khil\q@u{a}fin thumma lao\q@u{s}allibannakum ajmaAAeen\q@b{a}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@mlxxix{Q\q@u{a}loo inn\q@u{a} il\q@u{a} rabbin\q@u{a} munqaliboon\q@b{a}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@mlxxx{Wam\q@u{a} tanqimu minn\q@u{a} ill\q@u{a} an \q@u{a}mann\q@u{a} bi\q@u{a}y\q@u{a}ti rabbin\q@u{a} lamm\q@u{a} j\q@u{a}atn\q@u{a} rabban\q@u{a} afrigh AAalayn\q@u{a} \q@u{s}abran watawaffan\q@u{a} muslimeen\q@b{a}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@mlxxxi{Waq\q@u{a}la almalao min qawmi firAAawna ata\q@u{th}aru moos\q@u{a} waqawmahu liyufsidoo fee alar\q@u{d}i waya\q@u{th}araka wa\q@u{a}lihataka q\q@u{a}la sanuqattilu abn\q@u{a}ahum wanasta\q@u{h}yee nis\q@u{a}ahum wainn\q@u{a} fawqahum q\q@u{a}hiroon\q@b{a}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@mlxxxii{Q\q@u{a}la moos\q@u{a} liqawmihi istaAAeenoo bi\q@b{A}ll\q@u{a}hi wa\q@b{i}\q@u{s}biroo inna alar\q@u{d}a lill\q@u{a}hi yoorithuh\q@u{a} man yash\q@u{a}o min AAib\q@u{a}dihi wa\q@b{a}lAA\q@u{a}qibatu lilmuttaqeen\q@b{a}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@mlxxxiii{Q\q@u{a}loo oo\q@u{th}een\q@u{a} min qabli an tatiyan\q@u{a} wamin baAAdi m\q@u{a} jitan\q@u{a} q\q@u{a}la AAas\q@u{a} rabbukum an yuhlika AAaduwwakum wayastakhlifakum fee alar\q@u{d}i fayan\q@i{\q@u{th}}ura kayfa taAAmaloon\q@b{a}\qt@no{(129)}}
\qt@newcmd\qurantrans@lt@mlxxxiv{Walaqad akha\q@u{th}n\q@u{a} \q@u{a}la firAAawna bi\q@b{al}ssineena wanaq\q@u{s}in mina a\q@b{l}ththamar\q@u{a}ti laAAallahum ya\q@u{thth}akkaroon\q@b{a}\qt@no{(130)}}
\qt@newcmd\qurantrans@lt@mlxxxv{Fai\q@u{tha} j\q@u{a}athumu al\q@u{h}asanatu q\q@u{a}loo lan\q@u{a} h\q@u{ath}ihi wain tu\q@u{s}ibhum sayyiatun ya\q@u{tt}ayyaroo bimoos\q@u{a} waman maAAahu al\q@u{a} innam\q@u{a} \q@u{ta}iruhum AAinda All\q@u{a}hi wal\q@u{a}kinna aktharahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(131)}}
\qt@newcmd\qurantrans@lt@mlxxxvi{Waq\q@u{a}loo mahm\q@u{a} tatin\q@u{a} bihi min \q@u{a}yatin litas\q@u{h}aran\q@u{a} bih\q@u{a} fam\q@u{a} na\q@u{h}nu laka bimumineen\q@b{a}\qt@no{(132)}}
\qt@newcmd\qurantrans@lt@mlxxxvii{Faarsaln\q@u{a} AAalayhimu a\q@b{l}\q@u{tt}oof\q@u{a}na wa\q@b{a}ljar\q@u{a}da wa\q@b{a}lqummala wa\q@b{al}\q@u{dd}af\q@u{a}diAAa wa\q@b{al}ddama \q@u{a}y\q@u{a}tin mufa\q@u{ss}al\q@u{a}tin fa\q@b{i}stakbaroo wak\q@u{a}noo qawman mujrimeen\q@b{a}\qt@no{(133)}}
\qt@newcmd\qurantrans@lt@mlxxxviii{Walamm\q@u{a} waqaAAa AAalayhimu a\q@b{l}rrijzu q\q@u{a}loo y\q@u{a} moos\q@u{a} odAAu lan\q@u{a} rabbaka bim\q@u{a} AAahida AAindaka lain kashafta AAann\q@u{a} a\q@b{l}rrijza lanuminanna laka walanursilanna maAAaka banee isr\q@u{a}eel\q@b{a}\qt@no{(134)}}
\qt@newcmd\qurantrans@lt@mlxxxix{Falamm\q@u{a} kashafn\q@u{a} AAanhumu a\q@b{l}rrijza il\q@u{a} ajalin hum b\q@u{a}lighoohu i\q@u{tha} hum yankuthoon\q@b{a}\qt@no{(135)}}
\qt@newcmd\qurantrans@lt@mxc{Fa\q@b{i}ntaqamn\q@u{a} minhum faaghraqn\q@u{a}hum fee alyammi biannahum ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} wak\q@u{a}noo AAanh\q@u{a} gh\q@u{a}fileen\q@b{a}\qt@no{(136)}}
\qt@newcmd\qurantrans@lt@mxci{Waawrathn\q@u{a} alqawma alla\q@u{th}eena k\q@u{a}noo yusta\q@u{d}AAafoona mash\q@u{a}riqa alar\q@u{d}i wamagh\q@u{a}ribah\q@u{a} allatee b\q@u{a}rakn\q@u{a} feeh\q@u{a} watammat kalimatu rabbika al\q@u{h}usn\q@u{a} AAal\q@u{a} banee isr\q@u{a}eela bim\q@u{a} \q@u{s}abaroo wadammarn\q@u{a} m\q@u{a} k\q@u{a}na ya\q@u{s}naAAu firAAawnu waqawmuhu wam\q@u{a} k\q@u{a}noo yaAArishoon\q@b{a}\qt@no{(137)}}
\qt@newcmd\qurantrans@lt@mxcii{Waj\q@u{a}wazn\q@u{a} bibanee isr\q@u{a}eela alba\q@u{h}ra faataw AAal\q@u{a} qawmin yaAAkufoona AAal\q@u{a} a\q@u{s}n\q@u{a}min lahum q\q@u{a}loo y\q@u{a} moos\q@u{a} ijAAal lan\q@u{a} il\q@u{a}han kam\q@u{a} lahum \q@u{a}lihatun q\q@u{a}la innakum qawmun tajhaloon\q@b{a}\qt@no{(138)}}
\qt@newcmd\qurantrans@lt@mxciii{Inna h\q@u{a}ol\q@u{a}i mutabbarun m\q@u{a} hum feehi wab\q@u{at}ilun m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(139)}}
\qt@newcmd\qurantrans@lt@mxciv{Q\q@u{a}la aghayra All\q@u{a}hi abgheekum il\q@u{a}han wahuwa fa\q@u{dd}alakum AAal\q@u{a} alAA\q@u{a}lameen\q@b{a}\qt@no{(140)}}
\qt@newcmd\qurantrans@lt@mxcv{Wai\q@u{th} anjayn\q@u{a}kum min \q@u{a}li firAAawna yasoomoonakum sooa alAAa\q@u{tha}bi yuqattiloona abn\q@u{a}akum wayasta\q@u{h}yoona nis\q@u{a}akum wafee \q@u{tha}likum bal\q@u{a}on min rabbikum AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(141)}}
\qt@newcmd\qurantrans@lt@mxcvi{Waw\q@u{a}AAadn\q@u{a} moos\q@u{a} thal\q@u{a}theena laylatan waatmamn\q@u{a}h\q@u{a} biAAashrin fatamma meeq\q@u{a}tu rabbihi arbaAAeena laylatan waq\q@u{a}la moos\q@u{a} liakheehi h\q@u{a}roona okhlufnee fee qawmee waa\q@u{s}li\q@u{h} wal\q@u{a} tattabiAA sabeela almufsideen\q@b{a}\qt@no{(142)}}
\qt@newcmd\qurantrans@lt@mxcvii{Walamm\q@u{a} j\q@u{a}a moos\q@u{a} limeeq\q@u{a}tin\q@u{a} wakallamahu rabbuhu q\q@u{a}la rabbi arinee an\q@i{\q@u{th}}ur ilayka q\q@u{a}la lan tar\q@u{a}nee wal\q@u{a}kini on\q@i{\q@u{th}}ur il\q@u{a} aljabali faini istaqarra mak\q@u{a}nahu fasawfa tar\q@u{a}nee falamm\q@u{a} tajall\q@u{a} rabbuhu liljabali jaAAalahu dakkan wakharra moos\q@u{a} \q@u{s}aAAiqan falamm\q@u{a} af\q@u{a}qa q\q@u{a}la sub\q@u{ha}naka tubtu ilayka waan\q@u{a} awwalu almumineen\q@b{a}\qt@no{(143)}}
\qt@newcmd\qurantrans@lt@mxcviii{Q\q@u{a}la y\q@u{a} moos\q@u{a} innee i\q@u{st}afaytuka AAal\q@u{a} a\q@b{l}nn\q@u{a}si biris\q@u{a}l\q@u{a}tee wabikal\q@u{a}mee fakhu\q@u{th} m\q@u{a} \q@u{a}taytuka wakun mina a\q@b{l}shsh\q@u{a}kireen\q@b{a}\qt@no{(144)}}
\qt@newcmd\qurantrans@lt@mxcix{Wakatabn\q@u{a} lahu fee alalw\q@u{ah}i min kulli shayin mawAAi\q@i{\q@u{th}}atan wataf\q@u{s}eelan likulli shayin fakhu\q@u{th}h\q@u{a} biquwwatin wamur qawmaka yakhu\q@u{th}oo bia\q@u{h}sanih\q@u{a} saoreekum d\q@u{a}ra alf\q@u{a}siqeen\q@b{a}\qt@no{(145)}}
\qt@newcmd\qurantrans@lt@mc{Saa\q@u{s}rifu AAan \q@u{a}y\q@u{a}tiya alla\q@u{th}eena yatakabbaroona fee alar\q@u{d}i bighayri al\q@u{h}aqqi wain yaraw kulla \q@u{a}yatin l\q@u{a} yuminoo bih\q@u{a} wain yaraw sabeela a\q@b{l}rrushdi l\q@u{a} yattakhi\q@u{th}oohu sabeelan wain yaraw sabeela alghayyi yattakhi\q@u{th}oohu sabeelan \q@u{tha}lika biannahum ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} wak\q@u{a}noo AAanh\q@u{a} gh\q@u{a}fileen\q@b{a}\qt@no{(146)}}
\qt@newcmd\qurantrans@lt@mci{Wa\q@b{a}lla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} waliq\q@u{a}i al\q@u{a}khirati \q@u{h}abi\q@u{t}at aAAm\q@u{a}luhum hal yujzawna ill\q@u{a} m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(147)}}
\qt@newcmd\qurantrans@lt@mcii{Wa\q@b{i}ttakha\q@u{th}a qawmu moos\q@u{a} min baAAdihi min \q@u{h}uliyyihim AAijlan jasadan lahu khuw\q@u{a}run alam yaraw annahu l\q@u{a} yukallimuhum wal\q@u{a }yahdeehim sabeelan ittakha\q@u{th}oohu wak\q@u{a}noo \q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(148)}}
\qt@newcmd\qurantrans@lt@mciii{Walamm\q@u{a} suqi\q@u{t}a fee aydeehim waraaw annahum qad \q@u{d}alloo q\q@u{a}loo lain lam yar\q@u{h}amn\q@u{a} rabbun\q@u{a} wayaghfir lan\q@u{a} lanakoonanna mina alkh\q@u{a}sireen\q@b{a}\qt@no{(149)}}
\qt@newcmd\qurantrans@lt@mciv{Walamm\q@u{a} rajaAAa moos\q@u{a} il\q@u{a} qawmihi gha\q@u{d}b\q@u{a}na asifan q\q@u{a}la bisam\q@u{a} khalaftumoonee min baAAdee aAAajiltum amra rabbikum waalq\q@u{a }alalw\q@u{ah}a waakha\q@u{th}a birasi akheehi yajurruhu ilayhi q\q@u{a}la ibna omma inna alqawma ista\q@u{d}AAafoonee wak\q@u{a}doo yaqtuloonanee fal\q@u{a} tushmit biya alaAAd\q@u{a}a wal\q@u{a} tajAAalnee maAAa alqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(150)}}
\qt@newcmd\qurantrans@lt@mcv{Q\q@u{a}la rabbi ighfir lee waliakhee waadkhiln\q@u{a} fee ra\q@u{h}matika waanta ar\q@u{h}amu a\q@b{l}rr\q@u{ah}imeen\q@b{a}\qt@no{(151)}}
\qt@newcmd\qurantrans@lt@mcvi{Inna alla\q@u{th}eena ittakha\q@u{th}oo alAAijla sayan\q@u{a}luhum gha\q@u{d}abun min rabbihim wa\q@u{th}illatun fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} waka\q@u{tha}lika najzee almuftareen\q@b{a}\qt@no{(152)}}
\qt@newcmd\qurantrans@lt@mcvii{Wa\q@b{a}lla\q@u{th}eena AAamiloo a\q@b{l}ssayyi\q@u{a}ti thumma t\q@u{a}boo min baAAdih\q@u{a} wa\q@u{a}manoo inna rabbaka min baAAdih\q@u{a} laghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(153)}}
\qt@newcmd\qurantrans@lt@mcviii{Walamm\q@u{a} sakata AAan moos\q@u{a} algha\q@u{d}abu akha\q@u{th}a alalw\q@u{ah}a wafee nuskhatih\q@u{a} hudan wara\q@u{h}matun lilla\q@u{th}eena hum lirabbihim yarhaboon\q@b{a}\qt@no{(154)}}
\qt@newcmd\qurantrans@lt@mcix{Wa\q@b{i}kht\q@u{a}ra moos\q@u{a} qawmahu sabAAeena rajulan limeeq\q@u{a}tin\q@u{a} falamm\q@u{a} akha\q@u{th}athumu a\q@b{l}rrajfatu q\q@u{a}la rabbi law shita ahlaktahum min qablu waiyy\q@u{a}ya atuhlikun\q@u{a} bim\q@u{a} faAAala a\q@b{l}ssufah\q@u{a}o minn\q@u{a} in hiya ill\q@u{a} fitnatuka tu\q@u{d}illu bih\q@u{a} man tash\q@u{a}o watahdee man tash\q@u{a}o anta waliyyun\q@u{a} fa\q@b{i}ghfir lan\q@u{a} wa\q@b{i}r\q@u{h}amn\q@u{a} waanta khayru algh\q@u{a}fireen\q@b{a}\qt@no{(155)}}
\qt@newcmd\qurantrans@lt@mcx{Wa\q@b{o}ktub lan\q@u{a} fee h\q@u{ath}ihi a\q@b{l}dduny\q@u{a} \q@u{h}asanatan wafee al\q@u{a}khirati inn\q@u{a} hudn\q@u{a} ilayka q\q@u{a}la AAa\q@u{tha}bee o\q@u{s}eebu bihi man ash\q@u{a}o wara\q@u{h}matee wasiAAat kulla shayin fasaaktubuh\q@u{a} lilla\q@u{th}eena yattaqoona wayutoona a\q@b{l}zzak\q@u{a}ta wa\q@b{a}lla\q@u{th}eena hum bi\q@u{a}y\q@u{a}tin\q@u{a} yuminoon\q@b{a}\qt@no{(156)}}
\qt@newcmd\qurantrans@lt@mcxi{Alla\q@u{th}eena yattabiAAoona a\q@b{l}rrasoola a\q@b{l}nnabiyya alommiyya alla\q@u{th}ee yajidoonahu maktooban AAindahum fee a\q@b{l}ttawr\q@u{a}ti wa\q@b{a}linjeeli yamuruhum bi\q@b{a}lmaAAroofi wayanh\q@u{a}hum AAani almunkari wayu\q@u{h}illu lahumu a\q@b{l}\q@u{tt}ayyib\q@u{a}ti wayu\q@u{h}arrimu AAalayhimu alkhab\q@u{a}itha waya\q@u{d}aAAu AAanhum i\q@u{s}rahum wa\q@b{a}laghl\q@u{a}la allatee k\q@u{a}nat AAalayhim fa\q@b{a}lla\q@u{th}eena \q@u{a}manoo bihi waAAazzaroohu wana\q@u{s}aroohu wa\q@b{i}ttabaAAoo a\q@b{l}nnoora alla\q@u{th}ee onzila maAAahu ol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(157)}}
\qt@newcmd\qurantrans@lt@mcxii{Qul y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su innee rasoolu All\q@u{a}hi ilaykum jameeAAan alla\q@u{th}ee lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa yu\q@u{h}yee wayumeetu fa\q@u{a}minoo bi\q@b{A}ll\q@u{a}hi warasoolihi a\q@b{l}nnabiyyi alommiyyi alla\q@u{th}ee yuminu bi\q@b{A}ll\q@u{a}hi wakalim\q@u{a}tihi wa\q@b{i}ttabiAAoohu laAAallakum tahtadoon\q@b{a}\qt@no{(158)}}
\qt@newcmd\qurantrans@lt@mcxiii{Wamin qawmi moos\q@u{a} ommatun yahdoona bi\q@b{a}l\q@u{h}aqqi wabihi yaAAdiloon\q@b{a}\qt@no{(159)}}
\qt@newcmd\qurantrans@lt@mcxiv{Waqa\q@u{tt}aAAn\q@u{a}humu ithnatay AAashrata asb\q@u{at}an omaman waaw\q@u{h}ayn\q@u{a} il\q@u{a} moos\q@u{a} i\q@u{th}i istasq\q@u{a}hu qawmuhu ani i\q@u{d}rib biAAa\q@u{sa}ka al\q@u{h}ajara fa\q@b{i}nbajasat minhu ithnat\q@u{a} AAashrata AAaynan qad AAalima kullu on\q@u{a}sin mashrabahum wa\q@i{\q@u{th}}allaln\q@u{a} AAalayhimu algham\q@u{a}ma waanzaln\q@u{a} AAalayhimu almanna wa\q@b{al}ssalw\q@u{a} kuloo min \q@u{t}ayyib\q@u{a}ti m\q@u{a} razaqn\q@u{a}kum wam\q@u{a} \q@i{\q@u{th}}alamoon\q@u{a} wal\q@u{a}kin k\q@u{a}noo anfusahum ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(160)}}
\qt@newcmd\qurantrans@lt@mcxv{Wai\q@u{th} qeela lahumu oskunoo h\q@u{ath}ihi alqaryata wakuloo minh\q@u{a} \q@u{h}aythu shitum waqooloo \q@u{h}i\q@u{tt}atun wa\q@b{o}dkhuloo alb\q@u{a}ba sujjadan naghfir lakum kha\q@u{t}ee\q@u{a}tikum sanazeedu almu\q@u{h}sineen\q@b{a}\qt@no{(161)}}
\qt@newcmd\qurantrans@lt@mcxvi{Fabaddala alla\q@u{th}eena \q@i{\q@u{th}}alamoo minhum qawlan ghayra alla\q@u{th}ee qeela lahum faarsaln\q@u{a} AAalayhim rijzan mina a\q@b{l}ssam\q@u{a}i bim\q@u{a} k\q@u{a}noo ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(162)}}
\qt@newcmd\qurantrans@lt@mcxvii{Wa\q@b{i}salhum AAani alqaryati allatee k\q@u{a}nat \q@u{had}irata alba\q@u{h}ri i\q@u{th} yaAAdoona fee a\q@b{l}ssabti i\q@u{th} tateehim \q@u{h}eet\q@u{a}nuhum yawma sabtihim shurraAAan wayawma l\q@u{a} yasbitoona l\q@u{a} tateehim ka\q@u{tha}lika nabloohum bim\q@u{a} k\q@u{a}noo yafsuqoon\q@b{a}\qt@no{(163)}}
\qt@newcmd\qurantrans@lt@mcxviii{Wai\q@u{th} q\q@u{a}lat ommatun minhum lima taAAi\q@i{\q@u{th}}oona qawman All\q@u{a}hu muhlikuhum aw muAAa\q@u{thth}ibuhum AAa\q@u{tha}ban shadeedan q\q@u{a}loo maAA\q@u{th}iratan il\q@u{a} rabbikum walaAAallahum yattaqoon\q@b{a}\qt@no{(164)}}
\qt@newcmd\qurantrans@lt@mcxix{Falamm\q@u{a} nasoo m\q@u{a} \q@u{th}ukkiroo bihi anjayn\q@u{a} alla\q@u{th}eena yanhawna AAani a\q@b{l}ssooi waakha\q@u{th}n\q@u{a} alla\q@u{th}eena \q@i{\q@u{th}}alamoo biAAa\q@u{tha}bin baeesin bim\q@u{a} k\q@u{a}noo yafsuqoon\q@b{a}\qt@no{(165)}}
\qt@newcmd\qurantrans@lt@mcxx{Falamm\q@u{a} AAataw AAan m\q@u{a} nuhoo AAanhu quln\q@u{a} lahum koonoo qiradatan kh\q@u{a}sieen\q@b{a}\qt@no{(166)}}
\qt@newcmd\qurantrans@lt@mcxxi{Wai\q@u{th} taa\q@u{thth}ana rabbuka layabAAathanna AAalayhim il\q@u{a} yawmi alqiy\q@u{a}mati man yasoomuhum sooa alAAa\q@u{tha}bi inna rabbaka lasareeAAu alAAiq\q@u{a}bi wainnahu laghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(167)}}
\qt@newcmd\qurantrans@lt@mcxxii{Waqa\q@u{tt}aAAn\q@u{a}hum fee alar\q@u{d}i omaman minhumu a\q@b{l}\q@u{ssa}li\q@u{h}oona waminhum doona \q@u{tha}lika wabalawn\q@u{a}hum bi\q@b{a}l\q@u{h}asan\q@u{a}ti wa\q@b{al}ssayyi\q@u{a}ti laAAallahum yarjiAAoon\q@b{a}\qt@no{(168)}}
\qt@newcmd\qurantrans@lt@mcxxiii{Fakhalafa min baAAdihim khalfun warithoo alkit\q@u{a}ba yakhu\q@u{th}oona AAara\q@u{d}a h\q@u{atha} aladn\q@u{a} wayaqooloona sayughfaru lan\q@u{a} wain yatihim AAara\q@u{d}un mithluhu yakhu\q@u{th}oohu alam yukha\q@u{th} AAalayhim meeth\q@u{a}qu alkit\q@u{a}bi an l\q@u{a} yaqooloo AAal\q@u{a} All\q@u{a}hi ill\q@u{a} al\q@u{h}aqqa wadarasoo m\q@u{a} feehi wa\q@b{al}dd\q@u{a}ru al\q@u{a}khiratu khayrun lilla\q@u{th}eena yattaqoona afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(169)}}
\qt@newcmd\qurantrans@lt@mcxxiv{Wa\q@b{a}lla\q@u{th}eena yumassikoona bi\q@b{a}lkit\q@u{a}bi waaq\q@u{a}moo a\q@b{l}\q@u{ss}al\q@u{a}ta inn\q@u{a} l\q@u{a} nu\q@u{d}eeAAu ajra almu\q@u{s}li\q@u{h}een\q@b{a}\qt@no{(170)}}
\qt@newcmd\qurantrans@lt@mcxxv{Wai\q@u{th} nataqn\q@u{a} aljabala fawqahum kaannahu \q@i{\q@u{th}}ullatun wa\q@i{\q@u{th}}annoo annahu w\q@u{a}qiAAun bihim khu\q@u{th}oo m\q@u{a} \q@u{a}tayn\q@u{a}kum biquwwatin wa\q@b{o}\q@u{th}kuroo m\q@u{a} feehi laAAallakum tattaqoon\q@b{a}\qt@no{(171)}}
\qt@newcmd\qurantrans@lt@mcxxvi{Wai\q@u{th} akha\q@u{th}a rabbuka min banee \q@u{a}dama min \q@i{\q@u{th}}uhoorihim \q@u{th}urriyyatahum waashhadahum AAal\q@u{a} anfusihim alastu birabbikum q\q@u{a}loo bal\q@u{a} shahidn\q@u{a} an taqooloo yawma alqiy\q@u{a}mati inn\q@u{a} kunn\q@u{a} AAan h\q@u{atha} gh\q@u{a}fileen\q@b{a}\qt@no{(172)}}
\qt@newcmd\qurantrans@lt@mcxxvii{Aw taqooloo innam\q@u{a} ashraka \q@u{a}b\q@u{a}on\q@u{a} min qablu wakunn\q@u{a} \q@u{th}urriyyatan min baAAdihim afatuhlikun\q@u{a} bim\q@u{a} faAAala almub\q@u{t}iloon\q@b{a}\qt@no{(173)}}
\qt@newcmd\qurantrans@lt@mcxxviii{Waka\q@u{tha}lika nufa\q@u{ss}ilu al\q@u{a}y\q@u{a}ti walaAAallahum yarjiAAoon\q@b{a}\qt@no{(174)}}
\qt@newcmd\qurantrans@lt@mcxxix{Wa\q@b{o}tlu AAalayhim nabaa alla\q@u{th}ee \q@u{a}tayn\q@u{a}hu \q@u{a}y\q@u{a}tin\q@u{a} fa\q@b{i}nsalakha minh\q@u{a} faatbaAAahu a\q@b{l}shshay\q@u{ta}nu fak\q@u{a}na mina algh\q@u{a}ween\q@b{a}\qt@no{(175)}}
\qt@newcmd\qurantrans@lt@mcxxx{Walaw shin\q@u{a} larafaAAn\q@u{a}hu bih\q@u{a} wal\q@u{a}kinnahu akhlada il\q@u{a} alar\q@u{d}i wa\q@b{i}ttabaAAa haw\q@u{a}hu famathaluhu kamathali alkalbi in ta\q@u{h}mil AAalayhi yalhath aw tatrukhu yalhath \q@u{tha}lika mathalu alqawmi alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} fa\q@b{o}q\q@u{s}u\q@u{s}i alqa\q@u{s}a\q@u{s}a laAAallahum yatafakkaroon\q@b{a}\qt@no{(176)}}
\qt@newcmd\qurantrans@lt@mcxxxi{S\q@u{a}a mathalan alqawmu alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} waanfusahum k\q@u{a}noo ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(177)}}
\qt@newcmd\qurantrans@lt@mcxxxii{Man yahdi All\q@u{a}hu fahuwa almuhtadee waman yu\q@u{d}lil faol\q@u{a}ika humu alkh\q@u{a}siroon\q@b{a}\qt@no{(178)}}
\qt@newcmd\qurantrans@lt@mcxxxiii{Walaqad \q@u{th}aran\q@u{a} lijahannama katheeran mina aljinni wa\q@b{a}linsi lahum quloobun l\q@u{a} yafqahoona bih\q@u{a} walahum aAAyunun l\q@u{a} yub\q@u{s}iroona bih\q@u{a} walahum \q@u{atha}nun l\q@u{a} yasmaAAoona bih\q@u{a} ol\q@u{a}ika ka\q@b{a}lanAA\q@u{a}mi bal hum a\q@u{d}allu ol\q@u{a}ika humu algh\q@u{a}filoon\q@b{a}\qt@no{(179)}}
\qt@newcmd\qurantrans@lt@mcxxxiv{Walill\q@u{a}hi alasm\q@u{a}o al\q@u{h}usn\q@u{a} fa\q@b{o}dAAoohu bih\q@u{a} wa\q@u{th}aroo alla\q@u{th}eena yul\q@u{h}idoona fee asm\q@u{a}ihi sayujzawna m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(180)}}
\qt@newcmd\qurantrans@lt@mcxxxv{Wamimman khalaqn\q@u{a} ommatun yahdoona bi\q@b{a}l\q@u{h}aqqi wabihi yaAAdiloon\q@b{a}\qt@no{(181)}}
\qt@newcmd\qurantrans@lt@mcxxxvi{Wa\q@b{a}lla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} sanastadrijuhum min \q@u{h}aythu l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(182)}}
\qt@newcmd\qurantrans@lt@mcxxxvii{Waomlee lahum inna kaydee mateen\q@b{un}\qt@no{(183)}}
\qt@newcmd\qurantrans@lt@mcxxxviii{Awalam yatafakkaroo m\q@u{a} bi\q@u{sah}ibihim min jinnatin in huwa ill\q@u{a} na\q@u{th}eerun mubeen\q@b{un}\qt@no{(184)}}
\qt@newcmd\qurantrans@lt@mcxxxix{Awalam yan\q@i{\q@u{th}}uroo fee malakooti a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} khalaqa All\q@u{a}hu min shayin waan AAas\q@u{a} an yakoona qadi iqtaraba ajaluhum fabiayyi \q@u{h}adeethin baAAdahu yuminoon\q@b{a}\qt@no{(185)}}
\qt@newcmd\qurantrans@lt@mcxl{Man yu\q@u{d}lili All\q@u{a}hu fal\q@u{a} h\q@u{a}diya lahu waya\q@u{th}aruhum fee \q@u{t}ughy\q@u{a}nihim yaAAmahoon\q@b{a}\qt@no{(186)}}
\qt@newcmd\qurantrans@lt@mcxli{Yasaloonaka AAani a\q@b{l}ss\q@u{a}AAati ayy\q@u{a}na murs\q@u{a}h\q@u{a} qul innam\q@u{a} AAilmuh\q@u{a} AAinda rabbee l\q@u{a} yujalleeh\q@u{a} liwaqtih\q@u{a} ill\q@u{a} huwa thaqulat fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i l\q@u{a} tateekum ill\q@u{a} baghtatan yasaloonaka kaannaka \q@u{h}afiyyun AAanh\q@u{a} qul innam\q@u{a} AAilmuh\q@u{a} AAinda All\q@u{a}hi wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(187)}}
\qt@newcmd\qurantrans@lt@mcxlii{Qul l\q@u{a} amliku linafsee nafAAan wal\q@u{a} \q@u{d}arran ill\q@u{a} m\q@u{a} sh\q@u{a}a All\q@u{a}hu walaw kuntu aAAlamu alghayba la\q@b{i}stakthartu mina alkhayri wam\q@u{a} massaniya a\q@b{l}ssooo in an\q@u{a} ill\q@u{a} na\q@u{th}eerun wabasheerun liqawmin yuminoon\q@b{a}\qt@no{(188)}}
\qt@newcmd\qurantrans@lt@mcxliii{Huwa alla\q@u{th}ee khalaqakum min nafsin w\q@u{ah}idatin wajaAAala minh\q@u{a} zawjah\q@u{a} liyaskuna ilayh\q@u{a} falamm\q@u{a} taghashsh\q@u{a}h\q@u{a} \q@u{h}amalat \q@u{h}amlan khafeefan famarrat bihi falamm\q@u{a} athqalat daAAaw\q@u{a} All\q@u{a}ha rabbahum\q@u{a} lain \q@u{a}taytan\q@u{a} \q@u{sa}li\q@u{h}an lanakoonanna mina a\q@b{l}shsh\q@u{a}kireen\q@b{a}\qt@no{(189)}}
\qt@newcmd\qurantrans@lt@mcxliv{Falamm\q@u{a} \q@u{a}t\q@u{a}hum\q@u{a} \q@u{sa}li\q@u{h}an jaAAal\q@u{a} lahu shurak\q@u{a}a feem\q@u{a} \q@u{a}t\q@u{a}hum\q@u{a} fataAA\q@u{a}l\q@u{a} All\q@u{a}hu AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(190)}}
\qt@newcmd\qurantrans@lt@mcxlv{Ayushrikoona m\q@u{a} l\q@u{a} yakhluqu shayan wahum yukhlaqoon\q@b{a}\qt@no{(191)}}
\qt@newcmd\qurantrans@lt@mcxlvi{Wal\q@u{a} yasta\q@u{t}eeAAoona lahum na\q@u{s}ran wal\q@u{a} anfusahum yan\q@u{s}uroon\q@b{a}\qt@no{(192)}}
\qt@newcmd\qurantrans@lt@mcxlvii{Wain tadAAoohum il\q@u{a} alhud\q@u{a} l\q@u{a} yattabiAAookum saw\q@u{a}on AAalaykum adaAAawtumoohum am antum \q@u{sa}mitoon\q@b{a}\qt@no{(193)}}
\qt@newcmd\qurantrans@lt@mcxlviii{Inna alla\q@u{th}eena tadAAoona min dooni All\q@u{a}hi AAib\q@u{a}dun amth\q@u{a}lukum fa\q@b{o}dAAoohum falyastajeeboo lakum in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(194)}}
\qt@newcmd\qurantrans@lt@mcxlix{Alahum arjulun yamshoona bih\q@u{a} am lahum aydin yab\q@u{t}ishoona bih\q@u{a} am lahum aAAyunun yub\q@u{s}iroona bih\q@u{a} am lahum \q@u{atha}nun yasmaAAoona bih\q@u{a} quli odAAoo shurak\q@u{a}akum thumma keedooni fal\q@u{a} tun\q@i{\q@u{th}}iroon\q@b{i}\qt@no{(195)}}
\qt@newcmd\qurantrans@lt@mcl{Inna waliyyiya All\q@u{a}hu alla\q@u{th}ee nazzala alkit\q@u{a}ba wahuwa yatawall\q@u{a} a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(196)}}
\qt@newcmd\qurantrans@lt@mcli{Wa\q@b{a}lla\q@u{th}eena tadAAoona min doonihi l\q@u{a} yasta\q@u{t}eeAAoona na\q@u{s}rakum wal\q@u{a} anfusahum yan\q@u{s}uroon\q@b{a}\qt@no{(197)}}
\qt@newcmd\qurantrans@lt@mclii{Wain tadAAoohum il\q@u{a} alhud\q@u{a} l\q@u{a} yasmaAAoo watar\q@u{a}hum yan\q@i{\q@u{th}}uroona ilayka wahum l\q@u{a} yub\q@u{s}iroon\q@b{a}\qt@no{(198)}}
\qt@newcmd\qurantrans@lt@mcliii{Khu\q@u{th}i alAAafwa wamur bi\q@b{a}lAAurfi waaAAri\q@u{d} AAani alj\q@u{a}hileen\q@b{a}\qt@no{(199)}}
\qt@newcmd\qurantrans@lt@mcliv{Waimm\q@u{a} yanzaghannaka mina a\q@b{l}shshay\q@u{ta}ni nazghun fa\q@b{i}staAAi\q@u{th} bi\q@b{A}ll\q@u{a}hi innahu sameeAAun AAaleem\q@b{un}\qt@no{(200)}}
\qt@newcmd\qurantrans@lt@mclv{Inna alla\q@u{th}eena ittaqaw i\q@u{tha} massahum \q@u{ta}ifun mina a\q@b{l}shshay\q@u{ta}ni ta\q@u{th}akkaroo fai\q@u{tha} hum mub\q@u{s}iroon\q@b{a}\qt@no{(201)}}
\qt@newcmd\qurantrans@lt@mclvi{Waikhw\q@u{a}nuhum yamuddoonahum fee alghayyi thumma l\q@u{a} yuq\q@u{s}iroon\q@b{a}\qt@no{(202)}}
\qt@newcmd\qurantrans@lt@mclvii{Wai\q@u{tha} lam tatihim bi\q@u{a}yatin q\q@u{a}loo lawl\q@u{a} ijtabaytah\q@u{a} qul innam\q@u{a} attabiAAu m\q@u{a} yoo\q@u{ha} ilayya min rabbee h\q@u{atha} ba\q@u{sa}iru min rabbikum wahudan wara\q@u{h}matun liqawmin yuminoon\q@b{a}\qt@no{(203)}}
\qt@newcmd\qurantrans@lt@mclviii{Wai\q@u{tha} quria alqur\q@u{a}nu fa\q@b{i}stamiAAoo lahu waan\q@u{s}itoo laAAallakum tur\q@u{h}amoon\q@b{a}\qt@no{(204)}}
\qt@newcmd\qurantrans@lt@mclix{Wa\q@b{o}\q@u{th}kur rabbaka fee nafsika ta\q@u{d}arruAAan wakheefatan wadoona aljahri mina alqawli bi\q@b{a}lghuduwwi wa\q@b{a}l\q@u{asa}li wal\q@u{a} takun mina algh\q@u{a}fileen\q@b{a}\qt@no{(205)}}
\qt@newcmd\qurantrans@lt@mclx{Inna alla\q@u{th}eena AAinda rabbika l\q@u{a} yastakbiroona AAan AAib\q@u{a}datihi wayusabbi\q@u{h}oonahu walahu yasjudoon\q@b{a}\qt@no{(206)}}
\qt@newcmd\qurantrans@lt@mclxi{\basmalahlt Yasaloonaka AAani alanf\q@u{a}li quli alanf\q@u{a}lu lill\q@u{a}hi wa\q@b{al}rrasooli fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{s}li\q@u{h}oo \q@u{tha}ta baynikum waa\q@u{t}eeAAoo All\q@u{a}ha warasoolahu in kuntum mumineen\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mclxii{Innam\q@u{a} almuminoona alla\q@u{th}eena i\q@u{tha} \q@u{th}ukira All\q@u{a}hu wajilat quloobuhum wai\q@u{tha} tuliyat AAalayhim \q@u{a}y\q@u{a}tuhu z\q@u{a}dathum eem\q@u{a}nan waAAal\q@u{a} rabbihim yatawakkaloon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mclxiii{Alla\q@u{th}eena yuqeemoona a\q@b{l}\q@u{ss}al\q@u{a}ta wamimm\q@u{a} razaqn\q@u{a}hum yunfiqoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mclxiv{Ol\q@u{a}ika humu almuminoona \q@u{h}aqqan lahum daraj\q@u{a}tun AAinda rabbihim wamaghfiratun warizqun kareem\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mclxv{Kam\q@u{a} akhrajaka rabbuka min baytika bi\q@b{a}l\q@u{h}aqqi wainna fareeqan mina almumineena lak\q@u{a}rihoon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mclxvi{Yuj\q@u{a}diloonaka fee al\q@u{h}aqqi baAAdam\q@u{a} tabayyana kaannam\q@u{a} yus\q@u{a}qoona il\q@u{a} almawti wahum yan\q@i{\q@u{th}}uroon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mclxvii{Wai\q@u{th} yaAAidukumu All\q@u{a}hu i\q@u{h}d\q@u{a} a\q@b{l}\q@u{tta}ifatayni annah\q@u{a} lakum watawaddoona anna ghayra \q@u{tha}ti a\q@b{l}shshawkati takoonu lakum wayureedu All\q@u{a}hu an yu\q@u{h}iqqa al\q@u{h}aqqa bikalim\q@u{a}tihi wayaq\q@u{t}aAAa d\q@u{a}bira alk\q@u{a}fireen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mclxviii{Liyu\q@u{h}iqqa al\q@u{h}aqqa wayub\q@u{t}ila alb\q@u{at}ila walaw kariha almujrimoon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mclxix{I\q@u{th} tastagheethoona rabbakum fa\q@b{i}staj\q@u{a}ba lakum annee mumiddukum bialfin mina almal\q@u{a}ikati murdifeen\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mclxx{Wam\q@u{a} jaAAalahu All\q@u{a}hu ill\q@u{a} bushr\q@u{a} walita\q@u{t}mainna bihi quloobukum wam\q@u{a} a\q@b{l}nna\q@u{s}ru ill\q@u{a} min AAindi All\q@u{a}hi inna All\q@u{a}ha AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mclxxi{I\q@u{th} yughashsheekumu a\q@b{l}nnuAA\q@u{a}sa amanatan minhu wayunazzilu AAalaykum mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an liyu\q@u{t}ahhirakum bihi wayu\q@u{th}hiba AAankum rijza a\q@b{l}shshay\q@u{ta}ni waliyarbi\q@u{t}a AAal\q@u{a} quloobikum wayuthabbita bihi alaqd\q@u{a}m\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mclxxii{I\q@u{th} yoo\q@u{h}ee rabbuka il\q@u{a} almal\q@u{a}ikati annee maAAakum fathabbitoo alla\q@u{th}eena \q@u{a}manoo saolqee fee quloobi alla\q@u{th}eena kafaroo a\q@b{l}rruAAba fa\q@b{i}\q@u{d}riboo fawqa alaAAn\q@u{a}qi wa\q@b{i}\q@u{d}riboo minhum kulla ban\q@u{a}n\q@b{in}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mclxxiii{\q@u{Tha}lika biannahum sh\q@u{a}qqoo All\q@u{a}ha warasoolahu waman yush\q@u{a}qiqi All\q@u{a}ha warasoolahu fainna All\q@u{a}ha shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mclxxiv{\q@u{Tha}likum fa\q@u{th}ooqoohu waanna lilk\q@u{a}fireena AAa\q@u{tha}ba a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mclxxv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} laqeetumu alla\q@u{th}eena kafaroo za\q@u{h}fan fal\q@u{a} tuwalloohumu aladb\q@u{a}r\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mclxxvi{Waman yuwallihim yawmai\q@u{th}in duburahu ill\q@u{a} muta\q@u{h}arrifan liqit\q@u{a}lin aw muta\q@u{h}ayyizan il\q@u{a} fiatin faqad b\q@u{a}a bigha\q@u{d}abin mina All\q@u{a}hi wamaw\q@u{a}hu jahannamu wabisa alma\q@u{s}eer\q@b{u}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mclxxvii{Falam taqtuloohum wal\q@u{a}kinna All\q@u{a}ha qatalahum wam\q@u{a} ramayta i\q@u{th} ramayta wal\q@u{a}kinna All\q@u{a}ha ram\q@u{a} waliyubliya almumineena minhu bal\q@u{a}an \q@u{h}asanan inna All\q@u{a}ha sameeAAun AAaleem\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mclxxviii{\q@u{Tha}likum waanna All\q@u{a}ha moohinu kaydi alk\q@u{a}fireen\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mclxxix{In tastafti\q@u{h}oo faqad j\q@u{a}akumu alfat\q@u{h}u wain tantahoo fahuwa khayrun lakum wain taAAoodoo naAAud walan tughniya AAankum fiatukum shayan walaw kathurat waanna All\q@u{a}ha maAAa almumineen\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mclxxx{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo a\q@u{t}eeAAoo All\q@u{a}ha warasoolahu wal\q@u{a} tawallaw AAanhu waantum tasmaAAoon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mclxxxi{Wal\q@u{a} takoonoo ka\q@b{a}lla\q@u{th}eena q\q@u{a}loo samiAAn\q@u{a} wahum l\q@u{a} yasmaAAoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mclxxxii{Inna sharra a\q@b{l}ddaw\q@u{a}bbi AAinda All\q@u{a}hi a\q@b{l}\q@u{ss}ummu albukmu alla\q@u{th}eena l\q@u{a} yaAAqiloon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mclxxxiii{Walaw AAalima All\q@u{a}hu feehim khayran laasmaAAahum walaw asmaAAahum latawallaw wahum muAAri\q@u{d}oon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mclxxxiv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo istajeeboo lill\q@u{a}hi wali\q@b{l}rrasooli i\q@u{tha} daAA\q@u{a}kum lim\q@u{a} yu\q@u{h}yeekum wa\q@b{i}AAlamoo anna All\q@u{a}ha ya\q@u{h}oolu bayna almari waqalbihi waannahu ilayhi tu\q@u{h}sharoon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mclxxxv{Wa\q@b{i}ttaqoo fitnatan l\q@u{a} tu\q@u{s}eebanna alla\q@u{th}eena \q@i{\q@u{th}}alamoo minkum kh\q@u{ass}atan wa\q@b{i}AAlamoo anna All\q@u{a}ha shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mclxxxvi{Wa\q@b{o}\q@u{th}kuroo i\q@u{th} antum qaleelun musta\q@u{d}AAafoona fee alar\q@u{d}i takh\q@u{a}foona an yatakha\q@u{tt}afakumu a\q@b{l}nn\q@u{a}su fa\q@u{a}w\q@u{a}kum waayyadakum bina\q@u{s}rihi warazaqakum mina a\q@b{l}\q@u{tt}ayyib\q@u{a}ti laAAallakum tashkuroon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mclxxxvii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} takhoonoo All\q@u{a}ha wa\q@b{al}rrasoola watakhoonoo am\q@u{a}n\q@u{a}tikum waantum taAAlamoon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mclxxxviii{Wa\q@b{i}AAlamoo annam\q@u{a} amw\q@u{a}lukum waawl\q@u{a}dukum fitnatun waanna All\q@u{a}ha AAindahu ajrun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mclxxxix{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}m\q@u{a}noo in tattaqoo All\q@u{a}ha yajAAal lakum furq\q@u{a}nan wayukaffir AAankum sayyi\q@u{a}tikum wayaghfir lakum wa\q@b{A}ll\q@u{a}hu \q@u{th}oo alfa\q@u{d}li alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mcxc{Wai\q@u{th} yamkuru bika alla\q@u{th}eena kafaroo liyuthbitooka aw yaqtulooka aw yukhrijooka wayamkuroona wayamkuru All\q@u{a}hu wa\q@b{A}ll\q@u{a}hu khayru alm\q@u{a}kireen\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mcxci{Wai\q@u{tha} tutl\q@u{a} AAalayhim \q@u{a}y\q@u{a}tun\q@u{a} q\q@u{a}loo qad samiAAn\q@u{a} law nash\q@u{a}o laquln\q@u{a} mithla h\q@u{atha} in h\q@u{atha} ill\q@u{a} as\q@u{at}eeru alawwaleen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mcxcii{Wai\q@u{th} q\q@u{a}loo all\q@u{a}humma in k\q@u{a}na h\q@u{atha} huwa al\q@u{h}aqqa min AAindika faam\q@u{t}ir AAalayn\q@u{a} \q@u{h}ij\q@u{a}ratan mina a\q@b{l}ssam\q@u{a}i awi itin\q@u{a} biAAa\q@u{tha}bin aleem\q@b{in}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mcxciii{Wam\q@u{a} k\q@u{a}na All\q@u{a}hu liyuAAa\q@u{thth}ibahum waanta feehim wam\q@u{a} k\q@u{a}na All\q@u{a}hu muAAa\q@u{thth}ibahum wahum yastaghfiroon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mcxciv{Wam\q@u{a} lahum all\q@u{a} yuAAa\q@u{thth}ibahumu All\q@u{a}hu wahum ya\q@u{s}uddoona AAani almasjidi al\q@u{h}ar\q@u{a}mi wam\q@u{a} k\q@u{a}noo awliy\q@u{a}ahu in awliy\q@u{a}ohu ill\q@u{a} almuttaqoona wal\q@u{a}kinna aktharahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mcxcv{Wam\q@u{a} k\q@u{a}na \q@u{s}al\q@u{a}tuhum AAinda albayti ill\q@u{a} muk\q@u{a}an wata\q@u{s}diyatan fa\q@u{th}ooqoo alAAa\q@u{tha}ba bim\q@u{a} kuntum takfuroon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mcxcvi{Inna alla\q@u{th}eena kafaroo yunfiqoona amw\q@u{a}lahum liya\q@u{s}uddoo AAan sabeeli All\q@u{a}hi fasayunfiqoonah\q@u{a} thumma takoonu AAalayhim \q@u{h}asratan thumma yughlaboona wa\q@b{a}lla\q@u{th}eena kafaroo il\q@u{a} jahannama yu\q@u{h}sharoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mcxcvii{Liyameeza All\q@u{a}hu alkhabeetha mina a\q@b{l}\q@u{tt}ayyibi wayajAAala alkhabeetha baAA\q@u{d}ahu AAal\q@u{a} baAA\q@u{d}in fayarkumahu jameeAAan fayajAAalahu fee jahannama ol\q@u{a}ika humu alkh\q@u{a}siroon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mcxcviii{Qul lilla\q@u{th}eena kafaroo in yantahoo yughfar lahum m\q@u{a} qad salafa wain yaAAoodoo faqad ma\q@u{d}at sunnatu alawwaleen\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mcxcix{Waq\q@u{a}tiloohum \q@u{h}att\q@u{a} l\q@u{a} takoona fitnatun wayakoona a\q@b{l}ddeenu kulluhu lill\q@u{a}hi faini intahaw fainna All\q@u{a}ha bim\q@u{a} yaAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mcc{Wain tawallaw fa\q@b{i}AAlamoo anna All\q@u{a}ha mawl\q@u{a}kum niAAma almawl\q@u{a} waniAAma a\q@b{l}nna\q@u{s}eer\q@b{u}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mcci{Wa\q@b{i}AAlamoo annam\q@u{a} ghanimtum min shayin faanna lill\q@u{a}hi khumusahu wali\q@b{l}rrasooli wali\q@u{th}ee alqurb\q@u{a} wa\q@b{a}lyat\q@u{a}m\q@u{a} wa\q@b{a}lmas\q@u{a}keeni wa\q@b{i}bni a\q@b{l}ssabeeli in kuntum \q@u{a}mantum bi\q@b{A}ll\q@u{a}hi wam\q@u{a} anzaln\q@u{a} AAal\q@u{a} AAabdin\q@u{a} yawma alfurq\q@u{a}ni yawma iltaq\q@u{a} aljamAA\q@u{a}ni wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mccii{I\q@u{th} antum bi\q@b{a}lAAudwati a\q@b{l}dduny\q@u{a} wahum bi\q@b{a}lAAudwati alqu\q@u{s}w\q@u{a} wa\q@b{al}rrakbu asfala minkum walaw taw\q@u{a}AAadtum la\q@b{i}khtalaftum fee almeeAA\q@u{a}di wal\q@u{a}kin liyaq\q@u{d}iya All\q@u{a}hu amran k\q@u{a}na mafAAoolan liyahlika man halaka AAan bayyinatin waya\q@u{h}y\q@u{a} man \q@u{h}ayya AAan bayyinatin wainna All\q@u{a}ha lasameeAAun AAaleem\q@b{un}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mcciii{I\q@u{th} yureekahumu All\q@u{a}hu fee man\q@u{a}mika qaleelan walaw ar\q@u{a}kahum katheeran lafashiltum walatan\q@u{a}zaAAtum fee alamri wal\q@u{a}kinna All\q@u{a}ha sallama innahu AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mcciv{Wai\q@u{th} yureekumoohum i\q@u{th}i iltaqaytum fee aAAyunikum qaleelan wayuqallilukum fee aAAyunihim liyaq\q@u{d}iya All\q@u{a}hu amran k\q@u{a}na mafAAoolan wail\q@u{a} All\q@u{a}hi turjaAAu alomoor\q@b{u}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mccv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} laqeetum fiatan fa\q@b{o}thbutoo wa\q@b{o}\q@u{th}kuroo All\q@u{a}ha katheeran laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mccvi{Waa\q@u{t}eeAAoo All\q@u{a}ha warasoolahu wal\q@u{a} tan\q@u{a}zaAAoo fatafshaloo wata\q@u{th}haba ree\q@u{h}ukum wa\q@b{i}\q@u{s}biroo inna All\q@u{a}ha maAAa a\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mccvii{Wal\q@u{a} takoonoo ka\q@b{a}lla\q@u{th}eena kharajoo min diy\q@u{a}rihim ba\q@u{t}aran wari\q@u{a}a a\q@b{l}nn\q@u{a}si waya\q@u{s}uddoona AAan sabeeli All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu bim\q@u{a} yaAAmaloona mu\q@u{h}ee\q@u{t}\q@b{un}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mccviii{Wai\q@u{th} zayyana lahumu a\q@b{l}shshay\q@u{ta}nu aAAm\q@u{a}lahum waq\q@u{a}la l\q@u{a} gh\q@u{a}liba lakumu alyawma mina a\q@b{l}nn\q@u{a}si wainnee j\q@u{a}run lakum falamm\q@u{a} tar\q@u{a}ati alfiat\q@u{a}ni naka\q@u{s}a AAal\q@u{a} AAaqibayhi waq\q@u{a}la innee bareeon minkum innee ar\q@u{a} m\q@u{a} l\q@u{a} tarawna innee akh\q@u{a}fu All\q@u{a}ha wa\q@b{A}ll\q@u{a}hu shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mccix{I\q@u{th} yaqoolu almun\q@u{a}fiqoona wa\q@b{a}lla\q@u{th}eena fee quloobihim mara\q@u{d}un gharra h\q@u{a}ol\q@u{a}i deenuhum waman yatawakkal AAal\q@u{a} All\q@u{a}hi fainna All\q@u{a}ha AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mccx{Walaw tar\q@u{a} i\q@u{th} yatawaff\q@u{a} alla\q@u{th}eena kafaroo almal\q@u{a}ikatu ya\q@u{d}riboona wujoohahum waadb\q@u{a}rahum wa\q@u{th}ooqoo AAa\q@u{tha}ba al\q@u{h}areeq\q@b{i}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mccxi{\q@u{Tha}lika bim\q@u{a} qaddamat aydeekum waanna All\q@u{a}ha laysa bi\q@i{\q@u{th}}all\q@u{a}min lilAAabeed\q@b{i}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mccxii{Kadabi \q@u{a}li firAAawna wa\q@b{a}lla\q@u{th}eena min qablihim kafaroo bi\q@u{a}y\q@u{a}ti All\q@u{a}hi faakha\q@u{th}ahumu All\q@u{a}hu bi\q@u{th}unoobihim inna All\q@u{a}ha qawiyyun shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mccxiii{\q@u{Tha}lika bianna All\q@u{a}ha lam yaku mughayyiran niAAmatan anAAamah\q@u{a} AAal\q@u{a} qawmin \q@u{h}att\q@u{a} yughayyiroo m\q@u{a} bianfusihim waanna All\q@u{a}ha sameeAAun AAaleem\q@b{un}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mccxiv{Kadabi \q@u{a}li firAAawna wa\q@b{a}lla\q@u{th}eena min qablihim ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}ti rabbihim faahlakn\q@u{a}hum bi\q@u{th}unoobihim waaghraqn\q@u{a} \q@u{a}la firAAawna wakullun k\q@u{a}noo \q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mccxv{Inna sharra a\q@b{l}ddaw\q@u{a}bbi AAinda All\q@u{a}hi alla\q@u{th}eena kafaroo fahum l\q@u{a} yuminoon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mccxvi{Alla\q@u{th}eena AA\q@u{a}hadta minhum thumma yanqu\q@u{d}oona AAahdahum fee kulli marratin wahum l\q@u{a} yattaqoon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mccxvii{Faimm\q@u{a} tathqafannahum fee al\q@u{h}arbi fasharrid bihim man khalfahum laAAallahum ya\q@u{thth}akkaroon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mccxviii{Waimm\q@u{a} takh\q@u{a}fanna min qawmin khiy\q@u{a}natan fa\q@b{i}nbi\q@u{th} ilayhim AAal\q@u{a} sawain inna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu alkh\q@u{a}ineen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mccxix{Wal\q@u{a} ya\q@u{h}sabanna alla\q@u{th}eena kafaroo sabaqoo innahum l\q@u{a} yuAAjizoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mccxx{WaaAAiddoo lahum m\q@u{a} ista\q@u{t}aAAtum min quwwatin wamin rib\q@u{at}i alkhayli turhiboona bihi AAaduwwa All\q@u{a}hi waAAaduwwakum wa\q@u{a}khareena min doonihim l\q@u{a} taAAlamoonahumu All\q@u{a}hu yaAAlamuhum wam\q@u{a} tunfiqoo min shayin fee sabeeli All\q@u{a}hi yuwaffa ilaykum waantum l\q@u{a} tu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mccxxi{Wain jana\q@u{h}oo li\q@b{l}ssalmi fa\q@b{i}jna\q@u{h} lah\q@u{a} watawakkal AAal\q@u{a} All\q@u{a}hi innahu huwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mccxxii{Wain yureedoo an yakhdaAAooka fainna \q@u{h}asbaka All\q@u{a}hu huwa alla\q@u{th}ee ayyadaka bina\q@u{s}rihi wabi\q@b{a}lmumineen\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mccxxiii{Waallafa bayna quloobihim law anfaqta m\q@u{a} fee alar\q@u{d}i jameeAAan m\q@u{a} allafta bayna quloobihim wal\q@u{a}kinna All\q@u{a}ha allafa baynahum innahu AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mccxxiv{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu \q@u{h}asbuka All\q@u{a}hu wamani ittabaAAaka mina almumineen\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mccxxv{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu \q@u{h}arri\q@u{d}i almumineena AAal\q@u{a} alqit\q@u{a}li in yakun minkum AAishroona \q@u{sa}biroona yaghliboo miatayni wain yakun minkum miatun yaghliboo alfan mina alla\q@u{th}eena kafaroo biannahum qawmun l\q@u{a} yafqahoon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mccxxvi{Al\q@u{a}na khaffafa All\q@u{a}hu AAankum waAAalima anna feekum \q@u{d}aAAfan fain yakun minkum miatun \q@u{sa}biratun yaghliboo miatayni wain yakun minkum alfun yaghliboo alfayni bii\q@u{th}ni All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu maAAa a\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mccxxvii{M\q@u{a} k\q@u{a}na linabiyyin an yakoona lahu asr\q@u{a} \q@u{h}att\q@u{a} yuthkhina fee alar\q@u{d}i tureedoona AAara\q@u{d}a a\q@b{l}dduny\q@u{a} wa\q@b{A}ll\q@u{a}hu yureedu al\q@u{a}khirata wa\q@b{A}ll\q@u{a}hu AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mccxxviii{Lawl\q@u{a} kit\q@u{a}bun mina All\q@u{a}hi sabaqa lamassakum feem\q@u{a} akha\q@u{th}tum AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mccxxix{Fakuloo mimm\q@u{a} ghanimtum \q@u{h}al\q@u{a}lan \q@u{t}ayyiban wa\q@b{i}ttaqoo All\q@u{a}ha inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mccxxx{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu qul liman fee aydeekum mina alasr\q@u{a} in yaAAlami All\q@u{a}hu fee quloobikum khayran yutikum khayran mimm\q@u{a} okhi\q@u{th}a minkum wayaghfir lakum wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mccxxxi{Wain yureedoo khiy\q@u{a}nataka faqad kh\q@u{a}noo All\q@u{a}ha min qablu faamkana minhum wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mccxxxii{Inna alla\q@u{th}eena \q@u{a}manoo wah\q@u{a}jaroo waj\q@u{a}hadoo biamw\q@u{a}lihim waanfusihim fee sabeeli All\q@u{a}hi wa\q@b{a}lla\q@u{th}eena \q@u{a}waw wana\q@u{s}aroo ol\q@u{a}ika baAA\q@u{d}uhum awliy\q@u{a}o baAA\q@u{d}in wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo walam yuh\q@u{a}jiroo m\q@u{a} lakum min wal\q@u{a}yatihim min shayin \q@u{h}att\q@u{a} yuh\q@u{a}jiroo waini istan\q@u{s}arookum fee a\q@b{l}ddeeni faAAalaykumu a\q@b{l}nna\q@u{s}ru ill\q@u{a} AAal\q@u{a} qawmin baynakum wabaynahum meeth\q@u{a}qun wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mccxxxiii{Wa\q@b{a}lla\q@u{th}eena kafaroo baAA\q@u{d}uhum awliy\q@u{a}o baAA\q@u{d}in ill\q@u{a} tafAAaloohu takun fitnatun fee alar\q@u{d}i wafas\q@u{a}dun kabeer\q@b{un}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mccxxxiv{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo wah\q@u{a}jaroo waj\q@u{a}hadoo fee sabeeli All\q@u{a}hi wa\q@b{a}lla\q@u{th}eena \q@u{a}waw wana\q@u{s}aroo ol\q@u{a}ika humu almuminoona \q@u{h}aqqan lahum maghfiratun warizqun kareem\q@b{un}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mccxxxv{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo min baAAdu wah\q@u{a}jaroo waj\q@u{a}hadoo maAAakum faol\q@u{a}ika minkum waoloo alar\q@u{ha}mi baAA\q@u{d}uhum awl\q@u{a} bibaAA\q@u{d}in fee kit\q@u{a}bi All\q@u{a}hi inna All\q@u{a}ha bikulli shayin AAaleem\q@b{un}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mccxxxvi{\basmalahlt Bar\q@u{a}atun mina All\q@u{a}hi warasoolihi il\q@u{a} alla\q@u{th}eena AA\q@u{a}hadtum mina almushrikeen\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mccxxxvii{Fasee\q@u{h}oo fee alar\q@u{d}i arbaAAata ashhurin wa\q@b{i}AAlamoo annakum ghayru muAAjizee All\q@u{a}hi waanna All\q@u{a}ha mukhzee alk\q@u{a}fireen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mccxxxviii{Waa\q@u{tha}nun mina All\q@u{a}hi warasoolihi il\q@u{a} a\q@b{l}nn\q@u{a}si yawma al\q@u{h}ajji alakbari anna All\q@u{a}ha bareeon mina almushrikeena warasooluhu fain tubtum fahuwa khayrun lakum wain tawallaytum fa\q@b{i}AAlamoo annakum ghayru muAAjizee All\q@u{a}hi wabashshiri alla\q@u{th}eena kafaroo biAAa\q@u{tha}bin aleem\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mccxxxix{Ill\q@u{a} alla\q@u{th}eena AA\q@u{a}hadtum mina almushrikeena thumma lam yanqu\q@u{s}ookum shayan walam yu\q@i{\q@u{th}}\q@u{a}hiroo AAalaykum a\q@u{h}adan faatimmoo ilayhim AAahdahum il\q@u{a} muddatihim inna All\q@u{a}ha yu\q@u{h}ibbu almuttaqeen\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mccxl{Fai\q@u{tha} insalakha alashhuru al\q@u{h}urumu fa\q@b{o}qtuloo almushrikeena \q@u{h}aythu wajadtumoohum wakhu\q@u{th}oohum wa\q@b{o}\q@u{hs}uroohum wa\q@b{o}qAAudoo lahum kulla mar\q@u{s}adin fain t\q@u{a}boo waaq\q@u{a}moo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}tawoo a\q@b{l}zzak\q@u{a}ta fakhalloo sabeelahum inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mccxli{Wain a\q@u{h}adun mina almushrikeena istaj\q@u{a}raka faajirhu \q@u{h}att\q@u{a} yasmaAAa kal\q@u{a}ma All\q@u{a}hi thumma ablighhu mamanahu \q@u{tha}lika biannahum qawmun l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mccxlii{Kayfa yakoonu lilmushrikeena AAahdun AAinda All\q@u{a}hi waAAinda rasoolihi ill\q@u{a} alla\q@u{th}eena AA\q@u{a}hadtum AAinda almasjidi al\q@u{h}ar\q@u{a}mi fam\q@u{a} istaq\q@u{a}moo lakum fa\q@b{i}staqeemoo lahum inna All\q@u{a}ha yu\q@u{h}ibbu almuttaqeen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mccxliii{Kayfa wain ya\q@i{\q@u{th}}haroo AAalaykum l\q@u{a} yarquboo feekum illan wal\q@u{a} \q@u{th}immatan yur\q@u{d}oonakum biafw\q@u{a}hihim watab\q@u{a} quloobuhum waaktharuhum f\q@u{a}siqoon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mccxliv{Ishtaraw bi\q@u{a}y\q@u{a}ti All\q@u{a}hi thamanan qaleelan fa\q@u{s}addoo AAan sabeelihi innahum s\q@u{a}a m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mccxlv{L\q@u{a} yarquboona fee muminin illan wal\q@u{a} \q@u{th}immatan waol\q@u{a}ika humu almuAAtadoon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mccxlvi{Fain t\q@u{a}boo waaq\q@u{a}moo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}tawoo a\q@b{l}zzak\q@u{a}ta faikhw\q@u{a}nukum fee a\q@b{l}ddeeni wanufa\q@u{ss}ilu al\q@u{a}y\q@u{a}ti liqawmin yaAAlamoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mccxlvii{Wain nakathoo aym\q@u{a}nahum min baAAdi AAahdihim wa\q@u{t}aAAanoo fee deenikum faq\q@u{a}tiloo aimmata alkufri innahum l\q@u{a} aym\q@u{a}na lahum laAAallahum yantahoon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mccxlviii{Al\q@u{a} tuq\q@u{a}tiloona qawman nakathoo aym\q@u{a}nahum wahammoo biikhr\q@u{a}ji a\q@b{l}rrasooli wahum badaookum awwala marratin atakhshawnahum fa\q@b{A}ll\q@u{a}hu a\q@u{h}aqqu an takhshawhu in kuntum mumineen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mccxlix{Q\q@u{a}tiloohum yuAAa\q@u{thth}ibhumu All\q@u{a}hu biaydeekum wayukhzihim wayan\q@u{s}urkum AAalayhim wayashfi \q@u{s}udoora qawmin mumineen\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mccl{Wayu\q@u{th}hib ghay\q@i{\q@u{th}}a quloobihim wayatoobu All\q@u{a}hu AAal\q@u{a} man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mccli{Am \q@u{h}asibtum an tutrakoo walamm\q@u{a} yaAAlami All\q@u{a}hu alla\q@u{th}eena j\q@u{a}hadoo minkum walam yattakhi\q@u{th}oo min dooni All\q@u{a}hi wal\q@u{a} rasoolihi wal\q@u{a} almumineena waleejatan wa\q@b{A}ll\q@u{a}hu khabeerun bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mcclii{M\q@u{a} k\q@u{a}na lilmushrikeena an yaAAmuroo mas\q@u{a}jida All\q@u{a}hi sh\q@u{a}hideena AAal\q@u{a} anfusihim bi\q@b{a}lkufri ol\q@u{a}ika \q@u{h}abi\q@u{t}at aAAm\q@u{a}luhum wafee a\q@b{l}nn\q@u{a}ri hum kh\q@u{a}lidoon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mccliii{Innam\q@u{a} yaAAmuru mas\q@u{a}jida All\q@u{a}hi man \q@u{a}mana bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri waaq\q@u{a}ma a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}t\q@u{a} a\q@b{l}zzak\q@u{a}ta walam yakhsha ill\q@u{a} All\q@u{a}ha faAAas\q@u{a} ol\q@u{a}ika an yakoonoo mina almuhtadeen\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mccliv{AjaAAaltum siq\q@u{a}yata al\q@u{ha}jji waAAim\q@u{a}rata almasjidi al\q@u{h}ar\q@u{a}mi kaman \q@u{a}mana bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri waj\q@u{a}hada fee sabeeli All\q@u{a}hi l\q@u{a} yastawoona AAinda All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mcclv{Alla\q@u{th}eena \q@u{a}manoo wah\q@u{a}jaroo waj\q@u{a}hadoo fee sabeeli All\q@u{a}hi biamw\q@u{a}lihim waanfusihim aAA\q@i{\q@u{th}}amu darajatan AAinda All\q@u{a}hi waol\q@u{a}ika humu alf\q@u{a}izoon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mcclvi{Yubashshiruhum rabbuhum bira\q@u{h}matin minhu wari\q@u{d}w\q@u{a}nin wajann\q@u{a}tin lahum feeh\q@u{a} naAAeemun muqeem\q@b{un}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mcclvii{Kh\q@u{a}lideena feeh\q@u{a} abadan inna All\q@u{a}ha AAindahu ajrun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mcclviii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tattakhi\q@u{th}oo \q@u{a}b\q@u{a}akum waikhw\q@u{a}nakum awliy\q@u{a}a ini ista\q@u{h}abboo alkufra AAal\q@u{a} aleem\q@u{a}ni waman yatawallahum minkum faol\q@u{a}ika humu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mcclix{Qul in k\q@u{a}na \q@u{a}b\q@u{a}okum waabn\q@u{a}okum waikhw\q@u{a}nukum waazw\q@u{a}jukum waAAasheeratukum waamw\q@u{a}lun iqtaraftumooh\q@u{a} watij\q@u{a}ratun takhshawna kas\q@u{a}dah\q@u{a} wamas\q@u{a}kinu tar\q@u{d}awnah\q@u{a} a\q@u{h}abba ilaykum mina All\q@u{a}hi warasoolihi wajih\q@u{a}din fee sabeelihi fatarabba\q@u{s}oo \q@u{h}att\q@u{a} yatiya All\q@u{a}hu biamrihi wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma alf\q@u{a}siqeen\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mcclx{Laqad na\q@u{s}arakumu All\q@u{a}hu fee maw\q@u{at}ina katheeratin wayawma \q@u{h}unaynin i\q@u{th} aAAjabatkum kathratukum falam tughni AAankum shayan wa\q@u{da}qat AAalaykumu alar\q@u{d}u bim\q@u{a} ra\q@u{h}ubat thumma wallaytum mudbireen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mcclxi{Thumma anzala All\q@u{a}hu sakeenatahu AAal\q@u{a} rasoolihi waAAal\q@u{a} almumineena waanzala junoodan lam tarawh\q@u{a} waAAa\q@u{thth}aba alla\q@u{th}eena kafaroo wa\q@u{tha}lika jaz\q@u{a}o alk\q@u{a}fireen\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mcclxii{Thumma yatoobu All\q@u{a}hu min baAAdi \q@u{tha}lika AAal\q@u{a} man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mcclxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo innam\q@u{a} almushrikoona najasun fal\q@u{a} yaqraboo almasjida al\q@u{h}ar\q@u{a}ma baAAda AA\q@u{a}mihim h\q@u{atha} wain khiftum AAaylatan fasawfa yughneekumu All\q@u{a}hu min fa\q@u{d}lihi in sh\q@u{a}a inna All\q@u{a}ha AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mcclxiv{Q\q@u{a}tiloo alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{A}ll\q@u{a}hi wal\q@u{a} bi\q@b{a}lyawmi al\q@u{a}khiri wal\q@u{a} yu\q@u{h}arrimoona m\q@u{a} \q@u{h}arrama All\q@u{a}hu warasooluhu wal\q@u{a} yadeenoona deena al\q@u{h}aqqi mina alla\q@u{th}eena ootoo alkit\q@u{a}ba \q@u{h}att\q@u{a} yuAA\q@u{t}oo aljizyata AAan yadin wahum \q@u{sa}ghiroon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mcclxv{Waq\q@u{a}lati alyahoodu AAuzayrun ibnu All\q@u{a}hi waq\q@u{a}lati a\q@b{l}nna\q@u{sa}r\q@u{a} almasee\q@u{h}u ibnu All\q@u{a}hi \q@u{tha}lika qawluhum biafw\q@u{a}hihim yu\q@u{da}hioona qawla alla\q@u{th}eena kafaroo min qablu q\q@u{a}talahumu All\q@u{a}hu ann\q@u{a} yufakoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mcclxvi{Ittakha\q@u{th}oo a\q@u{h}b\q@u{a}rahum waruhb\q@u{a}nahum arb\q@u{a}ban min dooni All\q@u{a}hi wa\q@b{a}lmasee\q@u{h}a ibna maryama wam\q@u{a} omiroo ill\q@u{a} liyaAAbudoo il\q@u{a}han w\q@u{ah}idan l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa sub\q@u{ha}nahu AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mcclxvii{Yureedoona an yu\q@u{t}fioo noora All\q@u{a}hi biafw\q@u{a}hihim wayab\q@u{a} All\q@u{a}hu ill\q@u{a} an yutimma noorahu walaw kariha alk\q@u{a}firoon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mcclxviii{Huwa alla\q@u{th}ee arsala rasoolahu bi\q@b{a}lhud\q@u{a} wadeeni al\q@u{h}aqqi liyu\q@i{\q@u{th}}hirahu AAal\q@u{a} a\q@b{l}ddeeni kullihi walaw kariha almushrikoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mcclxix{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo inna katheeran mina ala\q@u{h}b\q@u{a}ri wa\q@b{al}rruhb\q@u{a}ni layakuloona amw\q@u{a}la a\q@b{l}nn\q@u{a}si bi\q@b{a}lb\q@u{at}ili waya\q@u{s}uddoona AAan sabeeli All\q@u{a}hi wa\q@b{a}lla\q@u{th}eena yaknizoona a\q@b{l}\q@u{thth}ahaba wa\q@b{a}lfi\q@u{dd}ata wal\q@u{a} yunfiqoonah\q@u{a} fee sabeeli All\q@u{a}hi fabashshirhum biAAa\q@u{tha}bin aleem\q@b{in}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mcclxx{Yawma yu\q@u{h}m\q@u{a} AAalayh\q@u{a} fee n\q@u{a}ri jahannama fatukw\q@u{a} bih\q@u{a} jib\q@u{a}huhum wajunoobuhum wa\q@i{\q@u{th}}uhooruhum h\q@u{atha} m\q@u{a} kanaztum lianfusikum fa\q@u{th}ooqoo m\q@u{a} kuntum taknizoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mcclxxi{Inna AAiddata a\q@b{l}shshuhoori AAinda All\q@u{a}hi ithn\q@u{a} AAashara shahran fee kit\q@u{a}bi All\q@u{a}hi yawma khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a minh\q@u{a} arbaAAatun \q@u{h}urumun \q@u{tha}lika a\q@b{l}ddeenu alqayyimu fal\q@u{a} ta\q@i{\q@u{th}}limoo feehinna anfusakum waq\q@u{a}tiloo almushrikeena k\q@u{a}ffatan kam\q@u{a} yuq\q@u{a}tiloonakum k\q@u{a}ffatan wa\q@b{i}AAlamoo anna All\q@u{a}ha maAAa almuttaqeen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mcclxxii{Innam\q@u{a} a\q@b{l}nnaseeo ziy\q@u{a}datun fee alkufri yu\q@u{d}allu bihi alla\q@u{th}eena kafaroo yu\q@u{h}illoonahu AA\q@u{a}man wayu\q@u{h}arrimoonahu AA\q@u{a}man liyuw\q@u{at}ioo AAiddata m\q@u{a} \q@u{h}arrama All\q@u{a}hu fayu\q@u{h}illoo m\q@u{a} \q@u{h}arrama All\q@u{a}hu zuyyina lahum sooo aAAm\q@u{a}lihim wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma alk\q@u{a}fireen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mcclxxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo m\q@u{a} lakum i\q@u{tha} qeela lakumu infiroo fee sabeeli All\q@u{a}hi ithth\q@u{a}qaltum il\q@u{a} alar\q@u{d}i ara\q@u{d}eetum bi\q@b{a}l\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} mina al\q@u{a}khirati fam\q@u{a} mat\q@u{a}AAu al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} fee al\q@u{a}khirati ill\q@u{a} qaleel\q@b{un}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mcclxxiv{Ill\q@u{a} tanfiroo yuAAa\q@u{thth}ibkum AAa\q@u{tha}ban aleeman wayastabdil qawman ghayrakum wal\q@u{a} ta\q@u{d}urroohu shayan wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mcclxxv{Ill\q@u{a} tan\q@u{s}uroohu faqad na\q@u{s}arahu All\q@u{a}hu i\q@u{th} akhrajahu alla\q@u{th}eena kafaroo th\q@u{a}niya ithnayni i\q@u{th} hum\q@u{a} fee algh\q@u{a}ri i\q@u{th} yaqoolu li\q@u{sah}ibihi l\q@u{a} ta\q@u{h}zan inna All\q@u{a}ha maAAan\q@u{a} faanzala All\q@u{a}hu sakeenatahu AAalayhi waayyadahu bijunoodin lam tarawh\q@u{a} wajaAAala kalimata alla\q@u{th}eena kafaroo a\q@b{l}ssufl\q@u{a} wakalimatu All\q@u{a}hi hiya alAAuly\q@u{a} wa\q@b{A}ll\q@u{a}hu AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mcclxxvi{Infiroo khif\q@u{a}fan wathiq\q@u{a}lan waj\q@u{a}hidoo biamw\q@u{a}likum waanfusikum fee sabeeli All\q@u{a}hi \q@u{tha}likum khayrun lakum in kuntum taAAlamoon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mcclxxvii{Law k\q@u{a}na AAara\q@u{d}an qareeban wasafaran q\q@u{as}idan la\q@b{i}ttabaAAooka wal\q@u{a}kin baAAudat AAalayhimu a\q@b{l}shshuqqatu wasaya\q@u{h}lifoona bi\q@b{A}ll\q@u{a}hi lawi ista\q@u{t}aAAn\q@u{a} lakharajn\q@u{a} maAAakum yuhlikoona anfusahum wa\q@b{A}ll\q@u{a}hu yaAAlamu innahum lak\q@u{ath}iboon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mcclxxviii{AAaf\q@u{a} All\q@u{a}hu AAanka lima a\q@u{th}inta lahum \q@u{h}att\q@u{a} yatabayyana laka alla\q@u{th}eena \q@u{s}adaqoo wataAAlama alk\q@u{ath}ibeen\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mcclxxix{L\q@u{a} yasta\q@u{th}inuka alla\q@u{th}eena yuminoona bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri an yuj\q@u{a}hidoo biamw\q@u{a}lihim waanfusihim wa\q@b{A}ll\q@u{a}hu AAaleemun bi\q@b{a}lmuttaqeen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mcclxxx{Innam\q@u{a} yasta\q@u{th}inuka alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri wa\q@b{i}rt\q@u{a}bat quloobuhum fahum fee raybihim yataraddadoon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mcclxxxi{Walaw ar\q@u{a}doo alkhurooja laaAAaddoo lahu AAuddatan wal\q@u{a}kin kariha All\q@u{a}hu inbiAA\q@u{a}thahum fathabba\q@u{t}ahum waqeela oqAAudoo maAAa alq\q@u{a}AAideen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mcclxxxii{Law kharajoo feekum m\q@u{a} z\q@u{a}dookum ill\q@u{a} khab\q@u{a}lan walaaw\q@u{d}aAAoo khil\q@u{a}lakum yabghoonakumu alfitnata wafeekum samm\q@u{a}AAoona lahum wa\q@b{A}ll\q@u{a}hu AAaleemun bi\q@b{al}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mcclxxxiii{Laqadi ibtaghawoo alfitnata min qablu waqallaboo laka alomoora \q@u{h}att\q@u{a} j\q@u{a}a al\q@u{h}aqqu wa\q@i{\q@u{th}}ahara amru All\q@u{a}hi wahum k\q@u{a}rihoon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mcclxxxiv{Waminhum man yaqoolu i\q@u{th}an lee wal\q@u{a} taftinnee al\q@u{a} fee alfitnati saqa\q@u{t}oo wainna jahannama lamu\q@u{h}ee\q@u{t}atun bi\q@b{a}lk\q@u{a}fireen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mcclxxxv{In tu\q@u{s}ibka \q@u{h}asanatun tasuhum wain tu\q@u{s}ibka mu\q@u{s}eebatun yaqooloo qad akha\q@u{th}n\q@u{a} amran\q@u{a} min qablu wayatawallaw wahum fari\q@u{h}oon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mcclxxxvi{Qul lan yu\q@u{s}eeban\q@u{a} ill\q@u{a} m\q@u{a} kataba All\q@u{a}hu lan\q@u{a} huwa mawl\q@u{a}n\q@u{a} waAAal\q@u{a} All\q@u{a}hi falyatawakkali almuminoon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mcclxxxvii{Qul hal tarabba\q@u{s}oona bin\q@u{a} ill\q@u{a} i\q@u{h}d\q@u{a} al\q@u{h}usnayayni wana\q@u{h}nu natarabba\q@u{s}u bikum an yu\q@u{s}eebakumu All\q@u{a}hu biAAa\q@u{tha}bin min AAindihi aw biaydeen\q@u{a} fatarabba\q@u{s}oo inn\q@u{a} maAAakum mutarabbi\q@u{s}oon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mcclxxxviii{Qul anfiqoo \q@u{t}awAAan aw karhan lan yutaqabbala minkum innakum kuntum qawman f\q@u{a}siqeen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mcclxxxix{Wam\q@u{a} manaAAahum an tuqbala minhum nafaq\q@u{a}tuhum ill\q@u{a} annahum kafaroo bi\q@b{A}ll\q@u{a}hi wabirasoolihi wal\q@u{a} yatoona a\q@b{l}\q@u{ss}al\q@u{a}ta ill\q@u{a} wahum kus\q@u{a}l\q@u{a} wal\q@u{a} yunfiqoona ill\q@u{a} wahum k\q@u{a}rihoon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mccxc{Fal\q@u{a} tuAAjibka amw\q@u{a}luhum wal\q@u{a} awl\q@u{a}duhum innam\q@u{a} yureedu All\q@u{a}hu liyuAAa\q@u{thth}ibahum bih\q@u{a} fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} watazhaqa anfusuhum wahum k\q@u{a}firoon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mccxci{Waya\q@u{h}lifoona bi\q@b{A}ll\q@u{a}hi innahum laminkum wam\q@u{a} hum minkum wal\q@u{a}kinnahum qawmun yafraqoon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mccxcii{Law yajidoona maljaan aw magh\q@u{a}r\q@u{a}tin aw muddakhalan lawallaw ilayhi wahum yajma\q@u{h}oon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mccxciii{Waminhum man yalmizuka fee a\q@b{l}\q@u{ss}adaq\q@u{a}ti fain oAA\q@u{t}oo minh\q@u{a} ra\q@u{d}oo wain lam yuAA\q@u{t}aw minh\q@u{a} i\q@u{tha} hum yaskha\q@u{t}oon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mccxciv{Walaw annahum ra\q@u{d}oo m\q@u{a} \q@u{a}t\q@u{a}humu All\q@u{a}hu warasooluhu waq\q@u{a}loo \q@u{h}asbun\q@u{a} All\q@u{a}hu sayuteen\q@u{a} All\q@u{a}hu min fa\q@u{d}lihi warasooluhu inn\q@u{a} il\q@u{a} All\q@u{a}hi r\q@u{a}ghiboon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mccxcv{Innam\q@u{a} a\q@b{l}\q@u{ss}adaq\q@u{a}tu lilfuqar\q@u{a}i wa\q@b{a}lmas\q@u{a}keeni wa\q@b{a}lAA\q@u{a}mileena AAalayh\q@u{a} wa\q@b{a}lmuallafati quloobuhum wafee a\q@b{l}rriq\q@u{a}bi wa\q@b{a}lgh\q@u{a}rimeena wafee sabeeli All\q@u{a}hi wa\q@b{i}bni a\q@b{l}ssabeeli faree\q@u{d}atan mina All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeemun\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mccxcvi{Waminhumu alla\q@u{th}eena yu\q@u{th}oona a\q@b{l}nnabiyya wayaqooloona huwa o\q@u{th}unun qul o\q@u{th}unu khayrin lakum yuminu bi\q@b{A}ll\q@u{a}hi wayuminu lilmumineena wara\q@u{h}matun lilla\q@u{th}eena \q@u{a}manoo minkum wa\q@b{a}lla\q@u{th}eena yu\q@u{th}oona rasoola All\q@u{a}hi lahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mccxcvii{Ya\q@u{h}lifoona bi\q@b{A}ll\q@u{a}hi lakum liyur\q@u{d}ookum wa\q@b{A}ll\q@u{a}hu warasooluhu a\q@u{h}aqqu an yur\q@u{d}oohu in k\q@u{a}noo mumineen\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mccxcviii{Alam yaAAlamoo annahu man yu\q@u{ha}didi All\q@u{a}ha warasoolahu faanna lahu n\q@u{a}ra jahannama kh\q@u{a}lidan feeh\q@u{a} \q@u{tha}lika alkhizyu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mccxcix{Ya\q@u{hth}aru almun\q@u{a}fiqoona an tunazzala AAalayhim sooratun tunabbiohum bim\q@u{a} fee quloobihim quli istahzioo inna All\q@u{a}ha mukhrijun m\q@u{a} ta\q@u{hth}aroon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mccc{Walain saaltahum layaqoolunna innam\q@u{a} kunn\q@u{a} nakhoo\q@u{d}u wanalAAabu qul abi\q@b{A}ll\q@u{a}hi wa\q@u{a}y\q@u{a}tihi warasoolihi kuntum tastahzioon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mccci{L\q@u{a} taAAta\q@u{th}iroo qad kafartum baAAda eem\q@u{a}nikum in naAAfu AAan \q@u{ta}ifatin minkum nuAAa\q@u{thth}ib \q@u{ta}ifatan biannahum k\q@u{a}noo mujrimeen\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mcccii{Almun\q@u{a}fiqoona wa\q@b{a}lmun\q@u{a}fiq\q@u{a}tu baAA\q@u{d}uhum min baAA\q@u{d}in yamuroona bi\q@b{a}lmunkari wayanhawna AAani almaAAroofi wayaqbi\q@u{d}oona aydiyahum nasoo All\q@u{a}ha fanasiyahum inna almun\q@u{a}fiqeena humu alf\q@u{a}siqoon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mccciii{WaAAada All\q@u{a}hu almun\q@u{a}fiqeena wa\q@b{a}lmun\q@u{a}fiq\q@u{a}ti wa\q@b{a}lkuff\q@u{a}ra n\q@u{a}ra jahannama kh\q@u{a}lideena feeh\q@u{a} hiya \q@u{h}asbuhum walaAAanahumu All\q@u{a}hu walahum AAa\q@u{tha}bun muqeem\q@b{un}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mccciv{Ka\q@b{a}lla\q@u{th}eena min qablikum k\q@u{a}noo ashadda minkum quwwatan waakthara amw\q@u{a}lan waawl\q@u{a}dan fa\q@b{i}stamtaAAoo bikhal\q@u{a}qihim fa\q@b{i}stamtaAAtum bikhal\q@u{a}qikum kam\q@u{a} istamtaAAa alla\q@u{th}eena min qablikum bikhal\q@u{a}qihim wakhu\q@u{d}tum ka\q@b{a}lla\q@u{th}ee kh\q@u{ad}oo ol\q@u{a}ika \q@u{h}abi\q@u{t}at aAAm\q@u{a}luhum fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati waol\q@u{a}ika humu alkh\q@u{a}siroon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mcccv{Alam yatihim nabao alla\q@u{th}eena min qablihim qawmi noo\q@u{h}in waAA\q@u{a}din wathamooda waqawmi ibr\q@u{a}heema waa\q@u{s}\q@u{ha}bi madyana wa\q@b{a}lmutafik\q@u{a}ti atathum rusuluhum bi\q@b{a}lbayyin\q@u{a}ti fam\q@u{a} k\q@u{a}na All\q@u{a}hu liya\q@i{\q@u{th}}limahum wal\q@u{a}kin k\q@u{a}noo anfusahum ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mcccvi{Wa\q@b{a}lmuminoona wa\q@b{a}lmumin\q@u{a}tu baAA\q@u{d}uhum awliy\q@u{a}o baAA\q@u{d}in yamuroona bi\q@b{a}lmaAAroofi wayanhawna AAani almunkari wayuqeemoona a\q@b{l}\q@u{ss}al\q@u{a}ta wayutoona a\q@b{l}zzak\q@u{a}ta wayu\q@u{t}eeAAoona All\q@u{a}ha warasoolahu ol\q@u{a}ika sayar\q@u{h}amuhumu All\q@u{a}hu inna All\q@u{a}ha AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mcccvii{WaAAada All\q@u{a}hu almumineena wa\q@b{a}lmumin\q@u{a}ti jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} wamas\q@u{a}kina \q@u{t}ayyibatan fee jann\q@u{a}ti AAadnin wari\q@u{d}w\q@u{a}nun mina All\q@u{a}hi akbaru \q@u{tha}lika huwa alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mcccviii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu j\q@u{a}hidi alkuff\q@u{a}ra wa\q@b{a}lmun\q@u{a}fiqeena wa\q@b{o}ghlu\q@i{\q@u{th}} AAalayhim wamaw\q@u{a}hum jahannamu wabisa alma\q@u{s}eer\q@b{u}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mcccix{Ya\q@u{h}lifoona bi\q@b{A}ll\q@u{a}hi m\q@u{a} q\q@u{a}loo walaqad q\q@u{a}loo kalimata alkufri wakafaroo baAAda isl\q@u{a}mihim wahammoo bim\q@u{a} lam yan\q@u{a}loo wam\q@u{a} naqamoo ill\q@u{a} an aghn\q@u{a}humu All\q@u{a}hu warasooluhu min fa\q@u{d}lihi fain yatooboo yaku khayran lahum wain yatawallaw yuAAa\q@u{thth}ibhumu All\q@u{a}hu AAa\q@u{tha}ban aleeman fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati wam\q@u{a} lahum fee alar\q@u{d}i min waliyyin wal\q@u{a} na\q@u{s}eer\q@b{in}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mcccx{Waminhum man AA\q@u{a}hada All\q@u{a}ha lain \q@u{a}t\q@u{a}n\q@u{a} min fa\q@u{d}lihi lana\q@u{ss}addaqanna walanakoonanna mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mcccxi{Falamm\q@u{a} \q@u{a}t\q@u{a}hum min fa\q@u{d}lihi bakhiloo bihi watawallaw wahum muAAri\q@u{d}oon\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mcccxii{FaaAAqabahum nif\q@u{a}qan fee quloobihim il\q@u{a} yawmi yalqawnahu bim\q@u{a} akhlafoo All\q@u{a}ha m\q@u{a} waAAadoohu wabim\q@u{a} k\q@u{a}noo yak\q@u{th}iboon\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mcccxiii{Alam yaAAlamoo anna All\q@u{a}ha yaAAlamu sirrahum wanajw\q@u{a}hum waanna All\q@u{a}ha AAall\q@u{a}mu alghuyoob\q@b{i}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mcccxiv{Alla\q@u{th}eena yalmizoona almu\q@u{tt}awwiAAeena mina almumineena fee a\q@b{l}\q@u{ss}adaq\q@u{a}ti wa\q@b{a}lla\q@u{th}eena l\q@u{a} yajidoona ill\q@u{a} juhdahum fayaskharoona minhum sakhira All\q@u{a}hu minhum walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mcccxv{Istaghfir lahum aw l\q@u{a} tastaghfir lahum in tastaghfir lahum sabAAeena marratan falan yaghfira All\q@u{a}hu lahum \q@u{tha}lika biannahum kafaroo bi\q@b{A}ll\q@u{a}hi warasoolihi wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma alf\q@u{a}siqeen\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mcccxvi{Fari\q@u{h}a almukhallafoona bimaqAAadihim khil\q@u{a}fa rasooli All\q@u{a}hi wakarihoo an yuj\q@u{a}hidoo biamw\q@u{a}lihim waanfusihim fee sabeeli All\q@u{a}hi waq\q@u{a}loo l\q@u{a} tanfiroo fee al\q@u{h}arri qul n\q@u{a}ru jahannama ashaddu \q@u{h}arran law k\q@u{a}noo yafqahoon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mcccxvii{Falya\q@u{dh}akoo qaleelan walyabkoo katheeran jaz\q@u{a}an bim\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mcccxviii{Fain rajaAAaka All\q@u{a}hu il\q@u{a} \q@u{ta}ifatin minhum fa\q@b{i}sta\q@u{th}anooka lilkhurooji faqul lan takhrujoo maAAiya abadan walan tuq\q@u{a}tiloo maAAiya AAaduwwan innakum ra\q@u{d}eetum bi\q@b{a}lquAAoodi awwala marratin fa\q@b{o}qAAudoo maAAa alkh\q@u{a}lifeen\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mcccxix{Wal\q@u{a} tu\q@u{s}alli AAal\q@u{a} a\q@u{h}adin minhum m\q@u{a}ta abadan wal\q@u{a} taqum AAal\q@u{a} qabrihi innahum kafaroo bi\q@b{A}ll\q@u{a}hi warasoolihi wam\q@u{a}too wahum f\q@u{a}siqoon\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mcccxx{Wal\q@u{a} tuAAjibka amw\q@u{a}luhum waawl\q@u{a}duhum innam\q@u{a} yureedu All\q@u{a}hu an yuAAa\q@u{thth}ibahum bih\q@u{a} fee a\q@b{l}dduny\q@u{a} watazhaqa anfusuhum wahum k\q@u{a}firoon\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mcccxxi{Wai\q@u{tha} onzilat sooratun an \q@u{a}minoo bi\q@b{A}ll\q@u{a}hi waj\q@u{a}hidoo maAAa rasoolihi ista\q@u{th}anaka oloo a\q@b{l}\q@u{tt}awli minhum waq\q@u{a}loo \q@u{th}arn\q@u{a} nakun maAAa alq\q@u{a}AAideen\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mcccxxii{Ra\q@u{d}oo bian yakoonoo maAAa alkhaw\q@u{a}lifi wa\q@u{t}ubiAAa AAal\q@u{a} quloobihim fahum l\q@u{a} yafqahoon\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mcccxxiii{L\q@u{a}kini a\q@b{l}rrasoolu wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo maAAahu j\q@u{a}hadoo biamw\q@u{a}lihim waanfusihim waol\q@u{a}ika lahumu alkhayr\q@u{a}tu waol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mcccxxiv{aAAadda All\q@u{a}hu lahum jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} \q@u{tha}lika alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mcccxxv{Waj\q@u{a}a almuAAa\q@u{thth}iroona mina alaAAr\q@u{a}bi liyu\q@u{th}ana lahum waqaAAada alla\q@u{th}eena ka\q@u{th}aboo All\q@u{a}ha warasoolahu sayu\q@u{s}eebu alla\q@u{th}eena kafaroo minhum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mcccxxvi{Laysa AAal\q@u{a} a\q@b{l}\q@u{dd}uAAaf\q@u{a}i wal\q@u{a} AAal\q@u{a} almar\q@u{da} wal\q@u{a} AAal\q@u{a} alla\q@u{th}eena l\q@u{a} yajidoona m\q@u{a} yunfiqoona \q@u{h}arajun i\q@u{tha} na\q@u{s}a\q@u{h}oo lill\q@u{a}hi warasoolihi m\q@u{a} AAal\q@u{a} almu\q@u{h}sineena min sabeelin wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mcccxxvii{Wal\q@u{a} AAal\q@u{a} alla\q@u{th}eena i\q@u{tha} m\q@u{a} atawka lita\q@u{h}milahum qulta l\q@u{a} ajidu m\q@u{a} a\q@u{h}milukum AAalayhi tawallaw waaAAyunuhum tafee\q@u{d}u mina a\q@b{l}ddamAAi \q@u{h}azanan all\q@u{a} yajidoo m\q@u{a} yunfiqoon\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mcccxxviii{Innam\q@u{a} a\q@b{l}ssabeelu AAal\q@u{a} alla\q@u{th}eena yasta\q@u{th}inoonaka wahum aghniy\q@u{a}o ra\q@u{d}oo bian yakoonoo maAAa alkhaw\q@u{a}lifi wa\q@u{t}abaAAa All\q@u{a}hu AAal\q@u{a} quloobihim fahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mcccxxix{YaAAta\q@u{th}iroona ilaykum i\q@u{tha} rajaAAtum ilayhim qul l\q@u{a} taAAta\q@u{th}iroo lan numina lakum qad nabbaan\q@u{a} All\q@u{a}hu min akhb\q@u{a}rikum wasayar\q@u{a} All\q@u{a}hu AAamalakum warasooluhu thumma turaddoona il\q@u{a} AA\q@u{a}limi alghaybi wa\q@b{al}shshah\q@u{a}dati fayunabbiokum bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mcccxxx{Saya\q@u{h}lifoona bi\q@b{A}ll\q@u{a}hi lakum i\q@u{tha} inqalabtum ilayhim lituAAri\q@u{d}oo AAanhum faaAAri\q@u{d}oo AAanhum innahum rijsun wamaw\q@u{a}hum jahannamu jaz\q@u{a}an bim\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mcccxxxi{Ya\q@u{h}lifoona lakum litar\q@u{d}aw AAanhum fain tar\q@u{d}aw AAanhum fainna All\q@u{a}ha l\q@u{a} yar\q@u{da} AAani alqawmi alf\q@u{a}siqeen\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mcccxxxii{AlaAAr\q@u{a}bu ashaddu kufran wanif\q@u{a}qan waajdaru all\q@u{a} yaAAlamoo \q@u{h}udooda m\q@u{a} anzala All\q@u{a}hu AAal\q@u{a} rasoolihi wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mcccxxxiii{Wamina alaAAr\q@u{a}bi man yattakhi\q@u{th}u m\q@u{a} yunfiqu maghraman wayatarabba\q@u{s}u bikumu a\q@b{l}ddaw\q@u{a}ira AAalayhim d\q@u{a}iratu a\q@b{l}ssawi wa\q@b{A}ll\q@u{a}hu sameeAAun AAaleem\q@b{un}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mcccxxxiv{Wamina alaAAr\q@u{a}bi man yuminu bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri wayattakhi\q@u{th}u m\q@u{a} yunfiqu qurub\q@u{a}tin AAinda All\q@u{a}hi wa\q@u{s}alaw\q@u{a}ti a\q@b{l}rrasooli al\q@u{a} innah\q@u{a} qurbatun lahum sayudkhiluhumu All\q@u{a}hu fee ra\q@u{h}matihi inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mcccxxxv{Wa\q@b{al}ss\q@u{a}biqoona alawwaloona mina almuh\q@u{a}jireena wa\q@b{a}lan\q@u{sa}ri wa\q@b{a}lla\q@u{th}eena ittabaAAoohum bii\q@u{h}s\q@u{a}nin ra\q@u{d}iya All\q@u{a}hu AAanhum wara\q@u{d}oo AAanhu waaAAadda lahum jann\q@u{a}tin tajree ta\q@u{h}tah\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} abadan \q@u{tha}lika alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mcccxxxvi{Wamimman \q@u{h}awlakum mina alaAAr\q@u{a}bi mun\q@u{a}fiqoona wamin ahli almadeenati maradoo AAal\q@u{a} a\q@b{l}nnif\q@u{a}qi l\q@u{a} taAAlamuhum na\q@u{h}nu naAAlamuhum sanuAAa\q@u{thth}ibuhum marratayni thumma yuraddoona il\q@u{a} AAa\q@u{tha}bin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mcccxxxvii{Wa\q@u{a}kharoona iAAtarafoo bi\q@u{th}unoobihim khala\q@u{t}oo AAamalan \q@u{sa}li\q@u{h}an wa\q@u{a}khara sayyian AAas\q@u{a} All\q@u{a}hu an yatooba AAalayhim inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mcccxxxviii{Khu\q@u{th} min amw\q@u{a}lihim \q@u{s}adaqatan tu\q@u{t}ahhiruhum watuzakkeehim bih\q@u{a} wa\q@u{s}alli AAalayhim inna \q@u{s}al\q@u{a}taka sakanun lahum wa\q@b{A}ll\q@u{a}hu sameeAAun AAaleem\q@b{un}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mcccxxxix{Alam yaAAlamoo anna All\q@u{a}ha huwa yaqbalu a\q@b{l}ttawbata AAan AAib\q@u{a}dihi wayakhu\q@u{th}u a\q@b{l}\q@u{ss}adaq\q@u{a}ti waanna All\q@u{a}ha huwa a\q@b{l}ttaww\q@u{a}bu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mcccxl{Waquli iAAmaloo fasayar\q@u{a} All\q@u{a}hu AAamalakum warasooluhu wa\q@b{a}lmuminoona wasaturaddoona il\q@u{a} AA\q@u{a}limi alghaybi wa\q@b{al}shshah\q@u{a}dati fayunabbiokum bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mcccxli{Wa\q@u{a}kharoona murjawna liamri All\q@u{a}hi imm\q@u{a} yuAAa\q@u{thth}ibuhum waimm\q@u{a} yatoobu AAalayhim wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mcccxlii{Wa\q@b{a}lla\q@u{th}eena ittakha\q@u{th}oo masjidan \q@u{d}ir\q@u{a}ran wakufran watafreeqan bayna almumineena wair\q@u{sa}dan liman \q@u{ha}raba All\q@u{a}ha warasoolahu min qablu walaya\q@u{h}lifunna in aradn\q@u{a} ill\q@u{a} al\q@u{h}usn\q@u{a} wa\q@b{A}ll\q@u{a}hu yashhadu innahum lak\q@u{ath}iboon\q@b{a}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mcccxliii{L\q@u{a} taqum feehi abadan lamasjidun ossisa AAal\q@u{a} a\q@b{l}ttaqw\q@u{a} min awwali yawmin a\q@u{h}aqqu an taqooma feehi feehi rij\q@u{a}lun yu\q@u{h}ibboona an yata\q@u{t}ahharoo wa\q@b{A}ll\q@u{a}hu yu\q@u{h}ibbu almu\q@u{tt}ahhireen\q@b{a}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mcccxliv{Afaman assasa buny\q@u{a}nahu AAal\q@u{a} taqw\q@u{a} mina All\q@u{a}hi wari\q@u{d}w\q@u{a}nin khayrun am man assasa buny\q@u{a}nahu AAal\q@u{a} shaf\q@u{a} jurufin h\q@u{a}rin fa\q@b{i}nh\q@u{a}ra bihi fee n\q@u{a}ri jahannama wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mcccxlv{L\q@u{a} yaz\q@u{a}lu buny\q@u{a}nuhumu alla\q@u{th}ee banaw reebatan fee quloobihim ill\q@u{a} an taqa\q@u{tt}aAAa quloobuhum wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mcccxlvi{Inna All\q@u{a}ha ishtar\q@u{a} mina almumineena anfusahum waamw\q@u{a}lahum bianna lahumu aljannata yuq\q@u{a}tiloona fee sabeeli All\q@u{a}hi fayaqtuloona wayuqtaloona waAAdan AAalayhi \q@u{h}aqqan fee a\q@b{l}ttawr\q@u{a}ti wa\q@b{a}linjeeli wa\q@b{a}lqur\q@u{a}ni waman awf\q@u{a} biAAahdihi mina All\q@u{a}hi fa\q@b{i}stabshiroo bibayAAikumu alla\q@u{th}ee b\q@u{a}yaAAtum bihi wa\q@u{tha}lika huwa alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mcccxlvii{A\q@b{l}tt\q@u{a}iboona alAA\q@u{a}bidoona al\q@u{ha}midoona a\q@b{l}ss\q@u{a}i\q@u{h}oona a\q@b{l}rr\q@u{a}kiAAoona a\q@b{l}ss\q@u{a}jidoona al\q@u{a}miroona bi\q@b{a}lmaAAroofi wa\q@b{al}nn\q@u{a}hoona AAani almunkari wa\q@b{a}l\q@u{ha}fi\q@i{\q@u{th}}oona li\q@u{h}udoodi All\q@u{a}hi wabashshiri almumineen\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@mcccxlviii{M\q@u{a} k\q@u{a}na li\q@b{l}nnabiyyi wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo an yastaghfiroo lilmushrikeena walaw k\q@u{a}noo olee qurb\q@u{a} min baAAdi m\q@u{a} tabayyana lahum annahum a\q@u{s}\q@u{ha}bu alja\q@u{h}eem\q@b{i}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@mcccxlix{Wam\q@u{a} k\q@u{a}na istighf\q@u{a}ru ibr\q@u{a}heema liabeehi ill\q@u{a} AAan mawAAidatin waAAadah\q@u{a} iyy\q@u{a}hu falamm\q@u{a} tabayyana lahu annahu AAaduwwun lill\q@u{a}hi tabarraa minhu inna ibr\q@u{a}heema laaww\q@u{a}hun \q@u{h}aleem\q@b{un}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@mcccl{Wam\q@u{a} k\q@u{a}na All\q@u{a}hu liyu\q@u{d}illa qawman baAAda i\q@u{th} had\q@u{a}hum \q@u{h}att\q@u{a} yubayyina lahum m\q@u{a} yattaqoona inna All\q@u{a}ha bikulli shayin AAaleem\q@b{un}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@mcccli{Inna All\q@u{a}ha lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i yu\q@u{h}yee wayumeetu wam\q@u{a} lakum min dooni All\q@u{a}hi min waliyyin wal\q@u{a} na\q@u{s}eer\q@b{in}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@mccclii{Laqad t\q@u{a}ba All\q@u{a}hu AAal\q@u{a} a\q@b{l}nnabiyyi wa\q@b{a}lmuh\q@u{a}jireena wa\q@b{a}lan\q@u{sa}ri alla\q@u{th}eena ittabaAAoohu fee s\q@u{a}AAati alAAusrati min baAAdi m\q@u{a} k\q@u{a}da yazeeghu quloobu fareeqin minhum thumma t\q@u{a}ba AAalayhim innahu bihim raoofun ra\q@u{h}eem\q@b{un}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@mcccliii{WaAAal\q@u{a} a\q@b{l}ththal\q@u{a}thati alla\q@u{th}eena khullifoo \q@u{h}att\q@u{a} i\q@u{tha} \q@u{da}qat AAalayhimu alar\q@u{d}u bim\q@u{a} ra\q@u{h}ubat wa\q@u{da}qat AAalayhim anfusuhum wa\q@i{\q@u{th}}annoo an l\q@u{a} maljaa mina All\q@u{a}hi ill\q@u{a} ilayhi thumma t\q@u{a}ba AAalayhim liyatooboo inna All\q@u{a}ha huwa a\q@b{l}ttaww\q@u{a}bu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@mcccliv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo ittaqoo All\q@u{a}ha wakoonoo maAAa a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@mccclv{M\q@u{a} k\q@u{a}na liahli almadeenati waman \q@u{h}awlahum mina alaAAr\q@u{a}bi an yatakhallafoo AAan rasooli All\q@u{a}hi wal\q@u{a} yarghaboo bianfusihim AAan nafsihi \q@u{tha}lika biannahum l\q@u{a} yu\q@u{s}eebuhum \q@i{\q@u{th}}amaon wal\q@u{a} na\q@u{s}abun wal\q@u{a} makhma\q@u{s}atun fee sabeeli All\q@u{a}hi wal\q@u{a} ya\q@u{t}aoona maw\q@u{t}ian yaghee\q@i{\q@u{th}}u alkuff\q@u{a}ra wal\q@u{a} yan\q@u{a}loona min AAaduwwin naylan ill\q@u{a} kutiba lahum bihi AAamalun \q@u{sa}li\q@u{h}un inna All\q@u{a}ha l\q@u{a} yu\q@u{d}eeAAu ajra almu\q@u{h}sineen\q@b{a}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@mccclvi{Wal\q@u{a} yunfiqoona nafaqatan \q@u{s}agheeratan wal\q@u{a} kabeeratan wal\q@u{a} yaq\q@u{t}aAAoona w\q@u{a}diyan ill\q@u{a} kutiba lahum liyajziyahumu All\q@u{a}hu a\q@u{h}sana m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@mccclvii{Wam\q@u{a} k\q@u{a}na almuminoona liyanfiroo k\q@u{a}ffatan falawl\q@u{a} nafara min kulli firqatin minhum \q@u{ta}ifatun liyatafaqqahoo fee a\q@b{l}ddeeni waliyun\q@u{th}iroo qawmahum i\q@u{tha} rajaAAoo ilayhim laAAallahum ya\q@u{hth}aroon\q@b{a}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@mccclviii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo q\q@u{a}tiloo alla\q@u{th}eena yaloonakum mina alkuff\q@u{a}ri walyajidoo feekum ghil\q@i{\q@u{th}}atan wa\q@b{i}AAlamoo anna All\q@u{a}ha maAAa almuttaqeen\q@b{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@mccclix{Wai\q@u{tha} m\q@u{a} onzilat sooratun faminhum man yaqoolu ayyukum z\q@u{a}dathu h\q@u{ath}ihi eem\q@u{a}nan faamm\q@u{a} alla\q@u{th}eena \q@u{a}manoo faz\q@u{a}dathum eem\q@u{a}nan wahum yastabshiroon\q@b{a}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@mccclx{Waamm\q@u{a} alla\q@u{th}eena fee quloobihim mara\q@u{d}un faz\q@u{a}dathum rijsan il\q@u{a} rijsihim wam\q@u{a}too wahum k\q@u{a}firoon\q@b{a}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@mccclxi{Awal\q@u{a} yarawna annahum yuftanoona fee kulli AA\q@u{a}min marratan aw marratayni thumma l\q@u{a} yatooboona wal\q@u{a} hum ya\q@u{thth}akkaroon\q@b{a}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@mccclxii{Wai\q@u{tha} m\q@u{a} onzilat sooratun na\q@i{\q@u{th}}ara baAA\q@u{d}uhum il\q@u{a} baAA\q@u{d}in hal yar\q@u{a}kum min a\q@u{h}adin thumma in\q@u{s}arafoo \q@u{s}arafa All\q@u{a}hu quloobahum biannahum qawmun l\q@u{a} yafqahoon\q@b{a}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@mccclxiii{Laqad j\q@u{a}akum rasoolun min anfusikum AAazeezun AAalayhi m\q@u{a }AAanittum \q@u{h}aree\q@u{s}un AAalaykum bi\q@b{a}lmumineena raoofun ra\q@u{h}eem\q@b{un}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@mccclxiv{Fain tawallaw faqul \q@u{h}asbiya All\q@u{a}hu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa AAalayhi tawakkaltu wahuwa rabbu alAAarshi alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(129)}}
\qt@newcmd\qurantrans@lt@mccclxv{\basmalahlt Alifl\q@u{a}mr\q@u{a} tilka \q@u{a}y\q@u{a}tu alkit\q@u{a}bi al\q@u{h}akeem\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mccclxvi{Ak\q@u{a}na li\q@b{l}nn\q@u{a}si AAajaban an aw\q@u{h}ayn\q@u{a} il\q@u{a} rajulin minhum an an\q@u{th}iri a\q@b{l}nn\q@u{a}sa wabashshiri alla\q@u{th}eena \q@u{a}manoo anna lahum qadama \q@u{s}idqin AAinda rabbihim q\q@u{a}la alk\q@u{a}firoona inna h\q@u{atha} las\q@u{ah}irun mubeen\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mccclxvii{Inna rabbakumu All\q@u{a}hu alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a fee sittati ayy\q@u{a}min thumma istaw\q@u{a} AAal\q@u{a} alAAarshi yudabbiru alamra m\q@u{a} min shafeeAAin ill\q@u{a} min baAAdi i\q@u{th}nihi \q@u{tha}likumu All\q@u{a}hu rabbukum fa\q@b{o}AAbudoohu afal\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mccclxviii{Ilayhi marjiAAukum jameeAAan waAAda All\q@u{a}hi \q@u{h}aqqan innahu yabdao alkhalqa thumma yuAAeeduhu liyajziya alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti bi\q@b{a}lqis\q@u{t}i wa\q@b{a}lla\q@u{th}eena kafaroo lahum shar\q@u{a}bun min \q@u{h}ameemin waAAa\q@u{tha}bun aleemun bim\q@u{a} k\q@u{a}noo yakfuroon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mccclxix{Huwa alla\q@u{th}ee jaAAala a\q@b{l}shshamsa \q@u{d}iy\q@u{a}an wa\q@b{a}lqamara nooran waqaddarahu man\q@u{a}zila litaAAlamoo AAadada a\q@b{l}ssineena wa\q@b{a}l\q@u{h}is\q@u{a}ba m\q@u{a} khalaqa All\q@u{a}hu \q@u{tha}lika ill\q@u{a} bi\q@b{a}l\q@u{h}aqqi yufa\q@u{ss}ilu al\q@u{a}y\q@u{a}ti liqawmin yaAAlamoon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mccclxx{Inna fee ikhtil\q@u{a}fi allayli wa\q@b{al}nnah\q@u{a}ri wam\q@u{a} khalaqa All\q@u{a}hu fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i la\q@u{a}y\q@u{a}tin liqawmin yattaqoon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mccclxxi{Inna alla\q@u{th}eena l\q@u{a} yarjoona liq\q@u{a}an\q@u{a} wara\q@u{d}oo bi\q@b{a}l\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wa\q@b{i}\q@u{t}maannoo bih\q@u{a} wa\q@b{a}lla\q@u{th}eena hum AAan \q@u{a}y\q@u{a}tin\q@u{a} gh\q@u{a}filoon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mccclxxii{Ol\q@u{a}ika maw\q@u{a}humu a\q@b{l}nn\q@u{a}ru bim\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mccclxxiii{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti yahdeehim rabbuhum bieem\q@u{a}nihim tajree min ta\q@u{h}tihimu alanh\q@u{a}ru fee jann\q@u{a}ti a\q@b{l}nnaAAeem\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mccclxxiv{DaAAw\q@u{a}hum feeh\q@u{a} sub\q@u{ha}naka all\q@u{a}humma wata\q@u{h}iyyatuhum feeh\q@u{a} sal\q@u{a}mun wa\q@u{a}khiru daAAw\q@u{a}hum ani al\q@u{h}amdu lill\q@u{a}hi rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mccclxxv{Walaw yuAAajjilu All\q@u{a}hu li\q@b{l}nn\q@u{a}si a\q@b{l}shsharra istiAAj\q@u{a}lahum bi\q@b{a}lkhayri laqu\q@u{d}iya ilayhim ajaluhum fana\q@u{th}aru alla\q@u{th}eena l\q@u{a} yarjoona liq\q@u{a}an\q@u{a} fee \q@u{t}ughy\q@u{a}nihim yaAAmahoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mccclxxvi{Wai\q@u{tha} massa alins\q@u{a}na a\q@b{l}\q@u{dd}urru daAA\q@u{a}n\q@u{a} lijanbihi aw q\q@u{a}AAidan aw q\q@u{a}iman falamm\q@u{a} kashafn\q@u{a} AAanhu \q@u{d}urrahu marra kaan lam yadAAun\q@u{a} il\q@u{a} \q@u{d}urrin massahu ka\q@u{tha}lika zuyyina lilmusrifeena m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mccclxxvii{Walaqad ahlakn\q@u{a} alquroona min qablikum lamm\q@u{a} \q@i{\q@u{th}}alamoo waj\q@u{a}athum rusuluhum bi\q@b{a}lbayyin\q@u{a}ti wam\q@u{a} k\q@u{a}noo liyuminoo ka\q@u{tha}lika najzee alqawma almujrimeen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mccclxxviii{Thumma jaAAaln\q@u{a}kum khal\q@u{a}ifa fee alar\q@u{d}i min baAAdihim linan\q@i{\q@u{th}}ura kayfa taAAmaloon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mccclxxix{Wai\q@u{tha} tutl\q@u{a} AAalayhim \q@u{a}y\q@u{a}tun\q@u{a} bayyin\q@u{a}tin q\q@u{a}la alla\q@u{th}eena l\q@u{a} yarjoona liq\q@u{a}an\q@u{a} iti biqur\q@u{a}nin ghayri h\q@u{atha} aw baddilhu qul m\q@u{a} yakoonu lee an obaddilahu min tilq\q@u{a}i nafsee in attabiAAu ill\q@u{a} m\q@u{a} yoo\q@u{ha} ilayya innee akh\q@u{a}fu in AAa\q@u{s}aytu rabbee AAa\q@u{tha}ba yawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mccclxxx{Qul law sh\q@u{a}a All\q@u{a}hu m\q@u{a} talawtuhu AAalaykum wal\q@u{a} adr\q@u{a}kum bihi faqad labithtu feekum AAumuran min qablihi afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mccclxxxi{Faman a\q@i{\q@u{th}}lamu mimmani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban aw ka\q@u{thth}aba bi\q@u{a}y\q@u{a}tihi innahu l\q@u{a} yufli\q@u{h}u almujrimoon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mccclxxxii{WayaAAbudoona min dooni All\q@u{a}hi m\q@u{a} l\q@u{a} ya\q@u{d}urruhum wal\q@u{a} yanfaAAuhum wayaqooloona h\q@u{a}ol\q@u{a}i shufaAA\q@u{a}on\q@u{a} AAinda All\q@u{a}hi qul atunabbioona All\q@u{a}ha bim\q@u{a} l\q@u{a} yaAAlamu fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wal\q@u{a} fee alar\q@u{d}i sub\q@u{ha}nahu wataAA\q@u{a}l\q@u{a} AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mccclxxxiii{Wam\q@u{a} k\q@u{a}na a\q@b{l}nn\q@u{a}su ill\q@u{a} ommatan w\q@u{ah}idatan fa\q@b{i}khtalafoo walawl\q@u{a} kalimatun sabaqat min rabbika laqu\q@u{d}iya baynahum feem\q@u{a} feehi yakhtalifoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mccclxxxiv{Wayaqooloona lawl\q@u{a} onzila AAalayhi \q@u{a}yatun min rabbihi faqul innam\q@u{a} alghaybu lill\q@u{a}hi fa\q@b{i}nta\q@i{\q@u{th}}iroo innee maAAakum mina almunta\q@i{\q@u{th}}ireen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mccclxxxv{Wai\q@u{tha} a\q@u{th}aqn\q@u{a} a\q@b{l}nn\q@u{a}sa ra\q@u{h}matan min baAAdi \q@u{d}arr\q@u{a}a massathum i\q@u{tha} lahum makrun fee \q@u{a}y\q@u{a}tin\q@u{a} quli All\q@u{a}hu asraAAu makran inna rusulan\q@u{a} yaktuboona m\q@u{a} tamkuroon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mccclxxxvi{Huwa alla\q@u{th}ee yusayyirukum fee albarri wa\q@b{a}lba\q@u{h}ri \q@u{h}att\q@u{a} i\q@u{tha} kuntum fee alfulki wajarayna bihim biree\q@u{h}in \q@u{t}ayyibatin wafari\q@u{h}oo bih\q@u{a} j\q@u{a}ath\q@u{a} ree\q@u{h}un AA\q@u{as}ifun waj\q@u{a}ahumu almawju min kulli mak\q@u{a}nin wa\q@i{\q@u{th}}annoo annahum o\q@u{h}ee\q@u{t}a bihim daAAawoo All\q@u{a}ha mukhli\q@u{s}eena lahu a\q@b{l}ddeena lain anjaytan\q@u{a} min h\q@u{ath}ihi lanakoonanna mina a\q@b{l}shsh\q@u{a}kireen\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mccclxxxvii{Falamm\q@u{a} anj\q@u{a}hum i\q@u{tha} hum yabghoona fee alar\q@u{d}i bighayri al\q@u{h}aqqi y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su innam\q@u{a} baghyukum AAal\q@u{a} anfusikum mat\q@u{a}AAa al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} thumma ilayn\q@u{a} marjiAAukum fanunabbiokum bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mccclxxxviii{Innam\q@u{a} mathalu al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} kam\q@u{a}in anzaln\q@u{a}hu mina a\q@b{l}ssam\q@u{a}i fa\q@b{i}khtala\q@u{t}a bihi nab\q@u{a}tu alar\q@u{d}i mimm\q@u{a} yakulu a\q@b{l}nn\q@u{a}su wa\q@b{a}lanAA\q@u{a}mu \q@u{h}att\q@u{a} i\q@u{tha} akha\q@u{th}ati alar\q@u{d}u zukhrufah\q@u{a} wa\q@b{i}zzayyanat wa\q@i{\q@u{th}}anna ahluh\q@u{a} annahum q\q@u{a}diroona AAalayh\q@u{a} at\q@u{a}h\q@u{a} amrun\q@u{a} laylan aw nah\q@u{a}ran fajaAAaln\q@u{a}h\q@u{a} \q@u{h}a\q@u{s}eedan kaan lam taghna bi\q@b{a}lamsi ka\q@u{tha}lika nufa\q@u{ss}ilu al\q@u{a}y\q@u{a}ti liqawmin yatafakkaroon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mccclxxxix{Wa\q@b{A}ll\q@u{a}hu yadAAoo il\q@u{a} d\q@u{a}ri a\q@b{l}ssal\q@u{a}mi wayahdee man yash\q@u{a}o il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mcccxc{Lilla\q@u{th}eena a\q@u{h}sanoo al\q@u{h}usn\q@u{a} waziy\q@u{a}datun wal\q@u{a} yarhaqu wujoohahum qatarun wal\q@u{a} \q@u{th}illatun ol\q@u{a}ika a\q@u{s}\q@u{ha}bu aljannati hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mcccxci{Wa\q@b{a}lla\q@u{th}eena kasaboo a\q@b{l}ssayyi\q@u{a}ti jaz\q@u{a}o sayyiatin bimithlih\q@u{a} watarhaquhum \q@u{th}illatun m\q@u{a} lahum mina All\q@u{a}hi min AA\q@u{as}imin kaannam\q@u{a} oghshiyat wujoohuhum qi\q@u{t}aAAan mina allayli mu\q@i{\q@u{th}}liman ol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mcccxcii{Wayawma na\q@u{h}shuruhum jameeAAan thumma naqoolu lilla\q@u{th}eena ashrakoo mak\q@u{a}nakum antum washurak\q@u{a}okum fazayyaln\q@u{a} baynahum waq\q@u{a}la shurak\q@u{a}ohum m\q@u{a} kuntum iyy\q@u{a}n\q@u{a} taAAbudoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mcccxciii{Fakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi shaheedan baynan\q@u{a} wabaynakum in kunn\q@u{a} AAan AAib\q@u{a}datikum lagh\q@u{a}fileen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mcccxciv{Hun\q@u{a}lika tabloo kullu nafsin m\q@u{a} aslafat waruddoo il\q@u{a} All\q@u{a}hi mawl\q@u{a}humu al\q@u{h}aqqi wa\q@u{d}alla AAanhum m\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mcccxcv{Qul man yarzuqukum mina a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i amman yamliku a\q@b{l}ssamAAa wa\q@b{a}lab\q@u{sa}ra waman yukhriju al\q@u{h}ayya mina almayyiti wayukhriju almayyita mina al\q@u{h}ayyi waman yudabbiru alamra fasayaqooloona All\q@u{a}hu faqul afal\q@u{a} tattaqoon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mcccxcvi{Fa\q@u{tha}likumu All\q@u{a}hu rabbukumu al\q@u{h}aqqu fam\q@u{atha} baAAda al\q@u{h}aqqi ill\q@u{a} a\q@b{l}\q@u{dd}al\q@u{a}lu faann\q@u{a} tu\q@u{s}rafoon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mcccxcvii{Ka\q@u{tha}lika \q@u{h}aqqat kalimatu rabbika AAal\q@u{a} alla\q@u{th}eena fasaqoo annahum l\q@u{a} yuminoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mcccxcviii{Qul hal min shurak\q@u{a}ikum man yabdao alkhalqa thumma yuAAeeduhu quli All\q@u{a}hu yabdao alkhalqa thumma yuAAeeduhu faann\q@u{a} tufakoon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mcccxcix{Qul hal min shurak\q@u{a}ikum man yahdee il\q@u{a} al\q@u{h}aqqi quli All\q@u{a}hu yahdee lil\q@u{h}aqqi afaman yahdee il\q@u{a} al\q@u{h}aqqi a\q@u{h}aqqu an yuttabaAAa amman l\q@u{a} yahiddee ill\q@u{a} an yuhd\q@u{a} fam\q@u{a} lakum kayfa ta\q@u{h}kumoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mcd{Wam\q@u{a} yattabiAAu aktharuhum ill\q@u{a} \q@i{\q@u{th}}annan inna a\q@b{l}\q@i{\q@u{thth}}anna l\q@u{a} yughnee mina al\q@u{h}aqqi shayan inna All\q@u{a}ha AAaleemun bim\q@u{a} yafAAaloon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mcdi{Wam\q@u{a} k\q@u{a}na h\q@u{atha} alqur\q@u{a}nu an yuftar\q@u{a} min dooni All\q@u{a}hi wal\q@u{a}kin ta\q@u{s}deeqa alla\q@u{th}ee bayna yadayhi wataf\q@u{s}eela alkit\q@u{a}bi l\q@u{a} rayba feehi min rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mcdii{Am yaqooloona iftar\q@u{a}hu qul fatoo bisooratin mithlihi wa\q@b{o}dAAoo mani ista\q@u{t}aAAtum min dooni All\q@u{a}hi in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mcdiii{Bal ka\q@u{thth}aboo bim\q@u{a} lam yu\q@u{h}ee\q@u{t}oo biAAilmihi walamm\q@u{a} yatihim taweeluhu ka\q@u{tha}lika ka\q@u{thth}aba alla\q@u{th}eena min qablihim fa\q@b{o}n\q@i{\q@u{th}}ur kayfa k\q@u{a}na AA\q@u{a}qibatu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mcdiv{Waminhum man yuminu bihi waminhum man l\q@u{a} yuminu bihi warabbuka aAAlamu bi\q@b{a}lmufsideen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mcdv{Wain ka\q@u{thth}abooka faqul lee AAamalee walakum AAamalukum antum bareeoona mimm\q@u{a} aAAmalu waan\q@u{a} bareeon mimm\q@u{a} taAAmaloon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mcdvi{Waminhum man yastamiAAoona ilayka afaanta tusmiAAu a\q@b{l}\q@u{ss}umma walaw k\q@u{a}noo l\q@u{a} yaAAqiloon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mcdvii{Waminhum man yan\q@i{\q@u{th}}uru ilayka afaanta tahdee alAAumya walaw k\q@u{a}noo l\q@u{a} yub\q@u{s}iroon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mcdviii{Inna All\q@u{a}ha l\q@u{a} ya\q@i{\q@u{th}}limu a\q@b{l}nn\q@u{a}sa shayan wal\q@u{a}kinna a\q@b{l}nn\q@u{a}sa anfusahum ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mcdix{Wayawma ya\q@u{h}shuruhum kaan lam yalbathoo ill\q@u{a} s\q@u{a}AAatan mina a\q@b{l}nnah\q@u{a}ri yataAA\q@u{a}rafoona baynahum qad khasira alla\q@u{th}eena ka\q@u{thth}aboo biliq\q@u{a}i All\q@u{a}hi wam\q@u{a} k\q@u{a}noo muhtadeen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mcdx{Waimm\q@u{a} nuriyannaka baAA\q@u{d}a alla\q@u{th}ee naAAiduhum aw natawaffayannaka failayn\q@u{a} marjiAAuhum thumma All\q@u{a}hu shaheedun AAal\q@u{a} m\q@u{a} yafAAaloon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mcdxi{Walikulli ommatin rasoolun fai\q@u{tha} j\q@u{a}a rasooluhum qu\q@u{d}iya baynahum bi\q@b{a}lqis\q@u{t}i wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mcdxii{Wayaqooloona mat\q@u{a} h\q@u{atha} alwaAAdu in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mcdxiii{Qul l\q@u{a} amliku linafsee \q@u{d}arran wal\q@u{a} nafAAan ill\q@u{a} m\q@u{a} sh\q@u{a}a All\q@u{a}hu likulli ommatin ajalun i\q@u{tha} j\q@u{a}a ajaluhum fal\q@u{a} yastakhiroona s\q@u{a}AAatan wal\q@u{a} yastaqdimoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mcdxiv{Qul araaytum in at\q@u{a}kum AAa\q@u{tha}buhu bay\q@u{a}tan aw nah\q@u{a}ran m\q@u{atha} yastaAAjilu minhu almujrimoon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mcdxv{Athumma i\q@u{tha} m\q@u{a} waqaAAa \q@u{a}mantum bihi \q@u{a}l\q@u{a}na waqad kuntum bihi tastaAAjiloon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mcdxvi{Thumma qeela lilla\q@u{th}eena \q@i{\q@u{th}}alamoo \q@u{th}ooqoo AAa\q@u{tha}ba alkhuldi hal tujzawna ill\q@u{a} bim\q@u{a} kuntum taksiboon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mcdxvii{Wayastanbioonaka a\q@u{h}aqqun huwa qul ee warabbee innahu la\q@u{h}aqqun wam\q@u{a} antum bimuAAjizeen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mcdxviii{Walaw anna likulli nafsin \q@i{\q@u{th}}alamat m\q@u{a} fee alar\q@u{d}i la\q@b{i}ftadat bihi waasarroo a\q@b{l}nnad\q@u{a}mata lamm\q@u{a} raawoo alAAa\q@u{tha}ba waqu\q@u{d}iya baynahum bi\q@b{a}lqis\q@u{t}i wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mcdxix{Al\q@u{a} inna lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i al\q@u{a} inna waAAda All\q@u{a}hi \q@u{h}aqqun wal\q@u{a}kinna aktharahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mcdxx{Huwa yu\q@u{h}yee wayumeetu wailayhi turjaAAoon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mcdxxi{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su qad j\q@u{a}atkum mawAAi\q@i{\q@u{th}}atun min rabbikum washif\q@u{a}on lim\q@u{a} fee a\q@b{l}\q@u{ss}udoori wahudan wara\q@u{h}matun lilmumineen\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mcdxxii{Qul bifa\q@u{d}li All\q@u{a}hi wabira\q@u{h}matihi fabi\q@u{tha}lika falyafra\q@u{h}oo huwa khayrun mimm\q@u{a} yajmaAAoon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mcdxxiii{Qul araaytum m\q@u{a} anzala All\q@u{a}hu lakum min rizqin fajaAAaltum minhu \q@u{h}ar\q@u{a}man wa\q@u{h}al\q@u{a}lan qul \q@u{a}ll\q@u{a}hu a\q@u{th}ina lakum am AAal\q@u{a} All\q@u{a}hi taftaroon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mcdxxiv{Wam\q@u{a} \q@i{\q@u{th}}annu alla\q@u{th}eena yaftaroona AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba yawma alqiy\q@u{a}mati inna All\q@u{a}ha la\q@u{th}oo fa\q@u{d}lin AAal\q@u{a} a\q@b{l}nn\q@u{a}si wal\q@u{a}kinna aktharahum l\q@u{a} yashkuroon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mcdxxv{Wam\q@u{a} takoonu fee shanin wam\q@u{a} tatloo minhu min qur\q@u{a}nin wal\q@u{a} taAAmaloona min AAamalin ill\q@u{a} kunn\q@u{a} AAalaykum shuhoodan i\q@u{th} tufee\q@u{d}oona feehi wam\q@u{a} yaAAzubu AAan rabbika min mithq\q@u{a}li \q@u{th}arratin fee alar\q@u{d}i wal\q@u{a} fee a\q@b{l}ssam\q@u{a}i wal\q@u{a} a\q@u{s}ghara min \q@u{tha}lika wal\q@u{a} akbara ill\q@u{a} fee kit\q@u{a}bin mubeen\q@b{un}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mcdxxvi{Al\q@u{a} inna awliy\q@u{a}a All\q@u{a}hi l\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mcdxxvii{Alla\q@u{th}eena \q@u{a}manoo wak\q@u{a}noo yattaqoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mcdxxviii{Lahumu albushr\q@u{a} fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wafee al\q@u{a}khirati l\q@u{a} tabdeela likalim\q@u{a}ti All\q@u{a}hi \q@u{tha}lika huwa alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mcdxxix{Wal\q@u{a} ya\q@u{h}zunka qawluhum inna alAAizzata lill\q@u{a}hi jameeAAan huwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mcdxxx{Al\q@u{a} inna lill\q@u{a}hi man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti waman fee alar\q@u{d}i wam\q@u{a} yattabiAAu alla\q@u{th}eena yadAAoona min dooni All\q@u{a}hi shurak\q@u{a}a in yattabiAAoona ill\q@u{a} a\q@b{l}\q@i{\q@u{thth}}anna wain hum ill\q@u{a} yakhru\q@u{s}oon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mcdxxxi{Huwa alla\q@u{th}ee jaAAala lakumu allayla litaskunoo feehi wa\q@b{al}nnah\q@u{a}ra mub\q@u{s}iran inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yasmaAAoon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mcdxxxii{Q\q@u{a}loo ittakha\q@u{th}a All\q@u{a}hu waladan sub\q@u{ha}nahu huwa alghaniyyu lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i in AAindakum min sul\q@u{ta}nin bih\q@u{atha} ataqooloona AAal\q@u{a} All\q@u{a}hi m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mcdxxxiii{Qul inna alla\q@u{th}eena yaftaroona AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba l\q@u{a} yufli\q@u{h}oon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mcdxxxiv{Mat\q@u{a}AAun fee a\q@b{l}dduny\q@u{a} thumma ilayn\q@u{a} marjiAAuhum thumma nu\q@u{th}eequhumu alAAa\q@u{tha}ba a\q@b{l}shshadeeda bim\q@u{a} k\q@u{a}noo yakfuroon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mcdxxxv{Wa\q@b{o}tlu AAalayhim nabaa noo\q@u{h}in i\q@u{th} q\q@u{a}la liqawmihi y\q@u{a} qawmi in k\q@u{a}na kabura AAalaykum maq\q@u{a}mee wata\q@u{th}keeree bi\q@u{a}y\q@u{a}ti All\q@u{a}hi faAAal\q@u{a} All\q@u{a}hi tawakkaltu faajmiAAoo amrakum washurak\q@u{a}akum thumma l\q@u{a} yakun amrukum AAalaykum ghummatan thumma iq\q@u{d}oo ilayya wal\q@u{a} tun\q@i{\q@u{th}}iroon\q@b{i}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mcdxxxvi{Fain tawallaytum fam\q@u{a} saaltukum min ajrin in ajriya ill\q@u{a} AAal\q@u{a} All\q@u{a}hi waomirtu an akoona mina almuslimeen\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mcdxxxvii{Faka\q@u{thth}aboohu fanajjayn\q@u{a}hu waman maAAahu fee alfulki wajaAAaln\q@u{a}hum khal\q@u{a}ifa waaghraqn\q@u{a} alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} fa\q@b{o}n\q@i{\q@u{th}}ur kayfa k\q@u{a}na AA\q@u{a}qibatu almun\q@u{th}areen\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mcdxxxviii{Thumma baAAathn\q@u{a} min baAAdihi rusulan il\q@u{a} qawmihim faj\q@u{a}oohum bi\q@b{a}lbayyin\q@u{a}ti fam\q@u{a} k\q@u{a}noo liyuminoo bim\q@u{a} ka\q@u{thth}aboo bihi min qablu ka\q@u{tha}lika na\q@u{t}baAAu AAal\q@u{a} quloobi almuAAtadeen\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mcdxxxix{Thumma baAAathn\q@u{a} min baAAdihim moos\q@u{a} wah\q@u{a}roona il\q@u{a} firAAawna wamalaihi bi\q@u{a}y\q@u{a}tin\q@u{a} fa\q@b{i}stakbaroo wak\q@u{a}noo qawman mujrimeen\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mcdxl{Falamm\q@u{a} j\q@u{a}ahumu al\q@u{h}aqqu min AAindin\q@u{a} q\q@u{a}loo inna h\q@u{atha} lasi\q@u{h}run mubeen\q@b{un}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mcdxli{Q\q@u{a}la moos\q@u{a} ataqooloona lil\q@u{h}aqqi lamm\q@u{a} j\q@u{a}akum asi\q@u{h}run h\q@u{atha} wal\q@u{a} yufli\q@u{h}u a\q@b{l}ss\q@u{ah}iroon\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mcdxlii{Q\q@u{a}loo ajitan\q@u{a} litalfitan\q@u{a} AAamm\q@u{a} wajadn\q@u{a} AAalayhi \q@u{a}b\q@u{a}an\q@u{a} watakoona lakum\q@u{a} alkibriy\q@u{a}o fee alar\q@u{d}i wam\q@u{a} na\q@u{h}nu lakum\q@u{a} bimumineen\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mcdxliii{Waq\q@u{a}la firAAawnu itoonee bikulli s\q@u{ah}irin AAaleem\q@b{in}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mcdxliv{Falamm\q@u{a} j\q@u{a}a a\q@b{l}ssa\q@u{h}aratu q\q@u{a}la lahum moos\q@u{a} alqoo m\q@u{a} antum mulqoon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mcdxlv{Falamm\q@u{a} alqaw q\q@u{a}la moos\q@u{a} m\q@u{a} jitum bihi a\q@b{l}ssi\q@u{h}ru inna All\q@u{a}ha sayub\q@u{t}iluhu inna All\q@u{a}ha l\q@u{a} yu\q@u{s}li\q@u{h}u AAamala almufsideen\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mcdxlvi{Wayu\q@u{h}iqqu All\q@u{a}hu al\q@u{h}aqqa bikalim\q@u{a}tihi walaw kariha almujrimoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mcdxlvii{Fam\q@u{a} \q@u{a}mana limoos\q@u{a} ill\q@u{a} \q@u{th}urriyyatun min qawmihi AAal\q@u{a} khawfin min firAAawna wamalaihim an yaftinahum wainna firAAawna laAA\q@u{a}lin fee alar\q@u{d}i wainnahu lamina almusrifeen\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mcdxlviii{Waq\q@u{a}la moos\q@u{a} y\q@u{a} qawmi in kuntum \q@u{a}mantum bi\q@b{A}ll\q@u{a}hi faAAalayhi tawakkaloo in kuntum muslimeen\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mcdxlix{Faq\q@u{a}loo AAal\q@u{a} All\q@u{a}hi tawakkaln\q@u{a} rabban\q@u{a} l\q@u{a} tajAAaln\q@u{a} fitnatan lilqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mcdl{Wanajjin\q@u{a} bira\q@u{h}matika mina alqawmi alk\q@u{a}fireen\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mcdli{Waaw\q@u{h}ayn\q@u{a} il\q@u{a} moos\q@u{a} waakheehi an tabawwa\q@u{a} liqawmikum\q@u{a} bimi\q@u{s}ra buyootan wa\q@b{i}jAAaloo buyootakum qiblatan waaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wabashshiri almumineen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mcdlii{Waq\q@u{a}la moos\q@u{a} rabban\q@u{a} innaka \q@u{a}tayta firAAawna wamalaahu zeenatan waamw\q@u{a}lan fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} rabban\q@u{a} liyu\q@u{d}illoo AAan sabeelika rabban\q@u{a} i\q@u{t}mis AAal\q@u{a} amw\q@u{a}lihim wa\q@b{o}shdud AAal\q@u{a} quloobihim fal\q@u{a} yuminoo \q@u{h}att\q@u{a} yarawoo alAAa\q@u{tha}ba alaleem\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mcdliii{Q\q@u{a}la qad ojeebat daAAwatukum\q@u{a} fa\q@b{i}staqeem\q@u{a} wal\q@u{a} tattabiAA\q@u{a}nni sabeela alla\q@u{th}eena l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mcdliv{Waj\q@u{a}wazn\q@u{a} bibanee isr\q@u{a}eela alba\q@u{h}ra faatbaAAahum firAAawnu wajunooduhu baghyan waAAadwan \q@u{h}att\q@u{a} i\q@u{tha} adrakahu algharaqu q\q@u{a}la \q@u{a}mantu annahu l\q@u{a} il\q@u{a}ha ill\q@u{a} alla\q@u{th}ee \q@u{a}manat bihi banoo isr\q@u{a}eela waan\q@u{a} mina almuslimeen\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mcdlv{\q@u{A}l\q@u{a}na waqad AAa\q@u{s}ayta qablu wakunta mina almufsideen\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mcdlvi{Fa\q@b{a}lyawma nunajjeeka bibadanika litakoona liman khalfaka \q@u{a}yatan wainna katheeran mina a\q@b{l}nn\q@u{a}si AAan \q@u{a}y\q@u{a}tin\q@u{a} lagh\q@u{a}filoon\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mcdlvii{Walaqad bawwan\q@u{a} banee isr\q@u{a}eela mubawwaa \q@u{s}idqin warazaqn\q@u{a}hum mina a\q@b{l}\q@u{tt}ayyib\q@u{a}ti fam\q@u{a} ikhtalafoo \q@u{h}att\q@u{a} j\q@u{a}ahumu alAAilmu inna rabbaka yaq\q@u{d}ee baynahum yawma alqiy\q@u{a}mati feem\q@u{a} k\q@u{a}noo feehi yakhtalifoon\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mcdlviii{Fain kunta fee shakkin mimm\q@u{a} anzalnn\q@u{a} ilayka fa\q@b{i}sali alla\q@u{th}eena yaqraoona alkit\q@u{a}ba min qablika laqad j\q@u{a}aka al\q@u{h}aqqu min rabbika fal\q@u{a} takoonanna mina almumtareen\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mcdlix{Wal\q@u{a} takoonanna mina alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}ti All\q@u{a}hi fatakoona mina alkh\q@u{a}sireen\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mcdlx{Inna alla\q@u{th}eena \q@u{h}aqqat AAalayhim kalimatu rabbika l\q@u{a} yuminoon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mcdlxi{Walaw j\q@u{a}athum kullu \q@u{a}yatin \q@u{h}att\q@u{a} yarawoo alAAa\q@u{tha}ba alaleem\q@b{a}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mcdlxii{Falawl\q@u{a} k\q@u{a}nat qaryatun \q@u{a}manat fanafaAAah\q@u{a} eem\q@u{a}nuh\q@u{a} ill\q@u{a} qawma yoonusa lamm\q@u{a} \q@u{a}manoo kashafn\q@u{a} AAanhum AAa\q@u{tha}ba alkhizyi fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wamattaAAn\q@u{a}hum il\q@u{a} \q@u{h}een\q@b{in}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mcdlxiii{Walaw sh\q@u{a}a rabbuka la\q@u{a}mana man fee alar\q@u{d}i kulluhum jameeAAan afaanta tukrihu a\q@b{l}nn\q@u{a}sa \q@u{h}att\q@u{a} yakoonoo mumineen\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mcdlxiv{Wam\q@u{a} k\q@u{a}na linafsin an tumina ill\q@u{a} bii\q@u{th}ni All\q@u{a}hi wayajAAalu a\q@b{l}rrijsa AAal\q@u{a} alla\q@u{th}eena l\q@u{a} yaAAqiloon\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mcdlxv{Quli on\q@i{\q@u{th}}uroo m\q@u{atha} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} tughnee al\q@u{a}y\q@u{a}tu wa\q@b{al}nnu\q@u{th}uru AAan qawmin l\q@u{a} yuminoon\q@b{a}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mcdlxvi{Fahal yanta\q@i{\q@u{th}}iroona ill\q@u{a} mithla ayy\q@u{a}mi alla\q@u{th}eena khalaw min qablihim qul fa\q@b{i}nta\q@i{\q@u{th}}iroo innee maAAakum mina almunta\q@i{\q@u{th}}ireen\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mcdlxvii{Thumma nunajjee rusulan\q@u{a} wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo ka\q@u{tha}lika \q@u{h}aqqan AAalayn\q@u{a} nunjee almumineen\q@b{a}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mcdlxviii{Qul y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su in kuntum fee shakkin min deenee fal\q@u{a} aAAbudu alla\q@u{th}eena taAAbudoona min dooni All\q@u{a}hi wal\q@u{a}kin aAAbudu All\q@u{a}ha alla\q@u{th}ee yatawaff\q@u{a}kum waomirtu an akoona mina almumineen\q@b{a}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mcdlxix{Waan aqim wajhaka li\q@b{l}ddeeni \q@u{h}aneefan wal\q@u{a} takoonanna mina almushrikeen\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mcdlxx{Wal\q@u{a} tadAAu min dooni All\q@u{a}hi m\q@u{a} l\q@u{a} yanfaAAuka wal\q@u{a} ya\q@u{d}urruka fain faAAalta fainnaka i\q@u{th}an mina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mcdlxxi{Wain yamsaska All\q@u{a}hu bi\q@u{d}urrin fal\q@u{a} k\q@u{a}shifa lahu ill\q@u{a} huwa wain yuridka bikhayrin fal\q@u{a} r\q@u{a}dda lifa\q@u{d}lihi yu\q@u{s}eebu bihi man yash\q@u{a}o min AAib\q@u{a}dihi wahuwa alghafooru a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mcdlxxii{Qul y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su qad j\q@u{a}akumu al\q@u{h}aqqu min rabbikum famani ihtad\q@u{a} fainnam\q@u{a} yahtadee linafsihi waman \q@u{d}alla fainnam\q@u{a} ya\q@u{d}illu AAalayh\q@u{a} wam\q@u{a} an\q@u{a} AAalaykum biwakeel\q@b{in}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mcdlxxiii{Wa\q@b{i}ttabiAA m\q@u{a} yoo\q@u{ha} ilayka wa\q@b{i}\q@u{s}bir \q@u{h}att\q@u{a} ya\q@u{h}kuma All\q@u{a}hu wahuwa khayru al\q@u{ha}kimeen\q@b{a}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mcdlxxiv{\basmalahlt Alifl\q@u{a}mr\q@u{a} kit\q@u{a}bun o\q@u{h}kimat \q@u{a}y\q@u{a}tuhu thumma fu\q@u{ss}ilat min ladun \q@u{h}akeemin khabeer\q@b{in}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mcdlxxv{All\q@u{a} taAAbudoo ill\q@u{a} All\q@u{a}ha innanee lakum minhu na\q@u{th}eerun wabasheer\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mcdlxxvi{Waani istaghfiroo rabbakum thumma tooboo ilayhi yumattiAAkum mat\q@u{a}AAan \q@u{h}asanan il\q@u{a} ajalin musamman wayuti kulla \q@u{th}ee fa\q@u{d}lin fa\q@u{d}lahu wain tawallaw fainee akh\q@u{a}fu AAalaykum AAa\q@u{tha}ba yawmin kabeer\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mcdlxxvii{Il\q@u{a} All\q@u{a}hi marjiAAukum wahuwa AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mcdlxxviii{Al\q@u{a} innahum yathnoona \q@u{s}udoorahum liyastakhfoo minhu al\q@u{a} \q@u{h}eena yastaghshoona thiy\q@u{a}bahum yaAAlamu m\q@u{a} yusirroona wam\q@u{a} yuAAlinoona innahu AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mcdlxxix{Wam\q@u{a} min d\q@u{a}bbatin fee alar\q@u{d}i ill\q@u{a} AAal\q@u{a} All\q@u{a}hi rizquh\q@u{a} wayaAAlamu mustaqarrah\q@u{a} wamustawdaAAah\q@u{a} kullun fee kit\q@u{a}bin mubeen\q@b{in}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mcdlxxx{Wahuwa alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a fee sittati ayy\q@u{a}min wak\q@u{a}na AAarshuhu AAal\q@u{a} alm\q@u{a}i liyabluwakum ayyukum a\q@u{h}sanu AAamalan walain qulta innakum mabAAoothoona min baAAdi almawti layaqoolanna alla\q@u{th}eena kafaroo in h\q@u{atha} ill\q@u{a} si\q@u{h}run mubeen\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mcdlxxxi{Walain akhkharn\q@u{a} AAanhumu alAAa\q@u{tha}ba il\q@u{a} ommatin maAAdoodatin layaqoolunna m\q@u{a} ya\q@u{h}bisuhu al\q@u{a} yawma yateehim laysa ma\q@u{s}roofan AAanhum wa\q@u{ha}qa bihim m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mcdlxxxii{Walain a\q@u{th}aqn\q@u{a} alins\q@u{a}na minn\q@u{a} ra\q@u{h}matan thumma nazaAAn\q@u{a}h\q@u{a} minhu innahu layaoosun kafoor\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mcdlxxxiii{Walain a\q@u{th}aqn\q@u{a}hu naAAm\q@u{a}a baAAda \q@u{d}arr\q@u{a}a massathu layaqoolanna \q@u{th}ahaba a\q@b{l}ssayyi\q@u{a}tu AAannee innahu lafari\q@u{h}un fakhoor\q@b{un}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mcdlxxxiv{Ill\q@u{a} alla\q@u{th}eena \q@u{s}abaroo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti ol\q@u{a}ika lahum maghfiratun waajrun kabeer\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mcdlxxxv{FalaAAallaka t\q@u{a}rikun baAA\q@u{d}a m\q@u{a} yoo\q@u{ha} ilayka wa\q@u{da}iqun bihi \q@u{s}adruka an yaqooloo lawl\q@u{a} onzila AAalayhi kanzun aw j\q@u{a}a maAAahu malakun innam\q@u{a} anta na\q@u{th}eerun wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin wakeel\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mcdlxxxvi{Am yaqooloona iftar\q@u{a}hu qul fatoo biAAashri suwarin mithlihi muftaray\q@u{a}tin wa\q@b{o}dAAoo mani ista\q@u{t}aAAtum min dooni All\q@u{a}hi in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mcdlxxxvii{Fai llam yastajeeboo lakum fa\q@b{i}AAlamoo annam\q@u{a} onzila biAAilmi All\q@u{a}hi waan l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa fahal antum muslimoon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mcdlxxxviii{Man k\q@u{a}na yureedu al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a} wazeenatah\q@u{a} nuwaffi ilayhim aAAm\q@u{a}lahum feeh\q@u{a} wahum feeh\q@u{a} l\q@u{a} yubkhasoon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mcdlxxxix{Ol\q@u{a}ika alla\q@u{th}eena laysa lahum fee al\q@u{a}khirati ill\q@u{a} a\q@b{l}nn\q@u{a}ru wa\q@u{h}abi\q@u{t}a m\q@u{a} \q@u{s}anaAAoo feeh\q@u{a} wab\q@u{at}ilun m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mcdxc{Afaman k\q@u{a}na AAal\q@u{a} bayyinatin min rabbihi wayatloohu sh\q@u{a}hidun minhu wamin qablihi kit\q@u{a}bu moos\q@u{a} im\q@u{a}man wara\q@u{h}matan ol\q@u{a}ika yuminoona bihi waman yakfur bihi mina ala\q@u{h}z\q@u{a}bi fa\q@b{al}nn\q@u{a}ru mawAAiduhu fal\q@u{a} taku fee miryatin minhu innahu al\q@u{h}aqqu min rabbika wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yuminoon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mcdxci{Waman a\q@i{\q@u{th}}lamu mimmani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban ol\q@u{a}ika yuAAra\q@u{d}oona AAal\q@u{a} rabbihim wayaqoolu alashh\q@u{a}du h\q@u{a}ol\q@u{a}i alla\q@u{th}eena ka\q@u{th}aboo AAal\q@u{a} rabbihim al\q@u{a} laAAnatu All\q@u{a}hi AAal\q@u{a} a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mcdxcii{Alla\q@u{th}eena ya\q@u{s}uddoona AAan sabeeli All\q@u{a}hi wayabghoonah\q@u{a} AAiwajan wahum bi\q@b{a}l\q@u{a}khirati hum k\q@u{a}firoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mcdxciii{Ol\q@u{a}ika lam yakoonoo muAAjizeena fee alar\q@u{d}i wam\q@u{a} k\q@u{a}na lahum min dooni All\q@u{a}hi min awliy\q@u{a}a yu\q@u{da}AAafu lahumu alAAa\q@u{tha}bu m\q@u{a} k\q@u{a}noo yasta\q@u{t}eeAAoona a\q@b{l}ssamAAa wam\q@u{a} k\q@u{a}noo yub\q@u{s}iroon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mcdxciv{Ol\q@u{a}ika alla\q@u{th}eena khasiroo anfusahum wa\q@u{d}alla AAanhum m\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mcdxcv{L\q@u{a} jarama annahum fee al\q@u{a}khirati humu alakhsaroon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mcdxcvi{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{sa}li\q@u{ha}ti waakhbatoo il\q@u{a} rabbihim ol\q@u{a}ika a\q@u{s}\q@u{ha}bu aljannati hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mcdxcvii{Mathalu alfareeqayni ka\q@b{a}l\q@b{}aAAm\q@u{a} wa\q@b{a}la\q@u{s}ammi wa\q@b{a}lba\q@u{s}eeri wa\q@b{al}ssameeAAi hal yastawiy\q@u{a}ni mathalan afal\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mcdxcviii{Walaqad arsaln\q@u{a} noo\q@u{h}an il\q@u{a} qawmihi innee lakum na\q@u{th}eerun mubeen\q@b{un}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mcdxcix{An l\q@u{a} taAAbudoo ill\q@u{a} All\q@u{a}ha innee akh\q@u{a}fu AAalaykum AAa\q@u{tha}ba yawmin aleem\q@b{in}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@md{Faq\q@u{a}la almalao alla\q@u{th}eena kafaroo min qawmihi m\q@u{a} nar\q@u{a}ka ill\q@u{a} basharan mithlan\q@u{a} wam\q@u{a} nar\q@u{a}ka ittabaAAaka ill\q@u{a} alla\q@u{th}eena hum ar\q@u{ath}ilun\q@u{a} b\q@u{a}diya a\q@b{l}rrayi wam\q@u{a} nar\q@u{a} lakum AAalayn\q@u{a} min fa\q@u{d}lin bal na\q@i{\q@u{th}}unnukum k\q@u{ath}ibeen\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mdi{Q\q@u{a}la y\q@u{a} qawmi araaytum in kuntu AAal\q@u{a} bayyinatin min rabbee wa\q@u{a}t\q@u{a}nee ra\q@u{h}matan min AAindihi faAAummiyat AAalaykum anulzimukumooh\q@u{a} waantum lah\q@u{a} k\q@u{a}rihoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mdii{Way\q@u{a} qawmi l\q@u{a} asalukum AAalayhi m\q@u{a}lan in ajriya ill\q@u{a} AAal\q@u{a} All\q@u{a}hi wam\q@u{a} an\q@u{a} bi\q@u{ta}ridi alla\q@u{th}eena \q@u{a}manoo innahum mul\q@u{a}qoo rabbihim wal\q@u{a}kinnee ar\q@u{a}kum qawman tajhaloon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mdiii{Way\q@u{a} qawmi man yan\q@u{s}urunee mina All\q@u{a}hi in \q@u{t}aradtuhum afal\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mdiv{Wal\q@u{a} aqoolu lakum AAindee khaz\q@u{a}inu All\q@u{a}hi wal\q@u{a} aAAlamu alghayba wal\q@u{a} aqoolu innee malakun wal\q@u{a} aqoolu lilla\q@u{th}eena tazdaree aAAyunukum lan yutiyahumu All\q@u{a}hu khayran All\q@u{a}hu aAAlamu bim\q@u{a} fee anfusihim innee i\q@u{th}an lamina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mdv{Q\q@u{a}loo y\q@u{a} noo\q@u{h}u qad j\q@u{a}daltan\q@u{a} faaktharta jid\q@u{a}lan\q@u{a} fatin\q@u{a} bim\q@u{a} taAAidun\q@u{a} in kunta mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mdvi{Q\q@u{a}la innam\q@u{a} yateekum bihi All\q@u{a}hu in sh\q@u{a}a wam\q@u{a} antum bimuAAjizeen\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mdvii{Wal\q@u{a} yanfaAAukum nu\q@u{sh}ee in aradtu an an\q@u{s}a\q@u{h}a lakum in k\q@u{a}na All\q@u{a}hu yureedu an yughwiyakum huwa rabbukum wailayhi turjaAAoon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mdviii{Am yaqooloona iftar\q@u{a}hu qul ini iftaraytuhu faAAalayya ijr\q@u{a}mee waan\q@u{a} bareeon mimm\q@u{a} tujrimoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mdix{Waoo\q@u{h}iya il\q@u{a} noo\q@u{h}in annahu lan yumina min qawmika ill\q@u{a} man qad \q@u{a}mana fal\q@u{a} tabtais bim\q@u{a} k\q@u{a}noo yafAAaloon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mdx{Wa\q@b{i}\q@u{s}naAAi alfulka biaAAyunin\q@u{a} wawa\q@u{h}yin\q@u{a} wal\q@u{a} tukh\q@u{at}ibnee fee alla\q@u{th}eena \q@i{\q@u{th}}alamoo innahum mughraqoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mdxi{Waya\q@u{s}naAAu alfulka wakullam\q@u{a} marra AAalayhi malaon min qawmihi sakhiroo minhu q\q@u{a}la in taskharoo minn\q@u{a} fainn\q@u{a} naskharu minkum kam\q@u{a} taskharoon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mdxii{Fasawfa taAAlamoona man yateehi AAa\q@u{tha}bun yukhzeehi waya\q@u{h}illu AAalayhi AAa\q@u{tha}bun muqeem\q@b{un}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mdxiii{\q@u{H}att\q@u{a} i\q@u{tha} j\q@u{a}a amrun\q@u{a} waf\q@u{a}ra a\q@b{l}ttannooru quln\q@u{a} i\q@u{h}mil feeh\q@u{a} min kullin zawjayni ithnayni waahlaka ill\q@u{a} man sabaqa AAalayhi alqawlu waman \q@u{a}mana wam\q@u{a} \q@u{a}mana maAAahu ill\q@u{a} qaleel\q@b{un}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mdxiv{Waq\q@u{a}la irkaboo feeh\q@u{a} bismi All\q@u{a}hi majr\q@u{a}h\q@u{a} wamurs\q@u{a}h\q@u{a} inna rabbee laghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mdxv{Wahiya tajree bihim fee mawjin ka\q@b{a}ljib\q@u{a}li wan\q@u{a}d\q@u{a} noo\q@u{h}unu ibnahu wak\q@u{a}na fee maAAzilin y\q@u{a} bunayya irkab maAAan\q@u{a} wal\q@u{a} takun maAAa alk\q@u{a}fireen\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mdxvi{Q\q@u{a}la sa\q@u{a}wee il\q@u{a} jabalin yaAA\q@u{s}imunee mina alm\q@u{a}i q\q@u{a}la l\q@u{a} AA\q@u{as}ima alyawma min amri All\q@u{a}hi ill\q@u{a} man ra\q@u{h}ima wa\q@u{ha}la baynahum\q@u{a} almawju fak\q@u{a}na mina almughraqeen\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mdxvii{Waqeela y\q@u{a} ar\q@u{d}u iblaAAee m\q@u{a}aki way\q@u{a} sam\q@u{a}o aqliAAee waghee\q@u{d}a alm\q@u{a}o waqu\q@u{d}iya alamru wa\q@b{i}stawat AAal\q@u{a} aljoodiyyi waqeela buAAdan lilqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mdxviii{Wan\q@u{a}d\q@u{a} noo\q@u{h}un rabbahu faq\q@u{a}la rabbi inna ibnee min ahlee wainna waAAdaka al\q@u{h}aqqu waanta a\q@u{h}kamu al\q@u{ha}kimeen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mdxix{Q\q@u{a}la y\q@u{a} noo\q@u{h}u innahu laysa min ahlika innahu AAamalun ghayru \q@u{sa}li\q@u{h}in fal\q@u{a} tasalni m\q@u{a} laysa laka bihi AAilmun innee aAAi\q@i{\q@u{th}}uka an takoona mina alj\q@u{a}hileen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mdxx{Q\q@u{a}la rabbi innee aAAoo\q@u{th}u bika an asalaka m\q@u{a} laysa lee bihi AAilmun waill\q@u{a} taghfir lee watar\q@u{h}amnee akun mina alkh\q@u{a}sireen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mdxxi{Qeela y\q@u{a} noo\q@u{h}u ihbi\q@u{t} bisal\q@u{a}min minn\q@u{a} wabarak\q@u{a}tin AAalayka waAAal\q@u{a} omamin mimman maAAaka waomamun sanumattiAAuhum thumma yamassuhum minn\q@u{a} AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mdxxii{Tilka min anb\q@u{a}i alghaybi noo\q@u{h}eeh\q@u{a} ilayka m\q@u{a} kunta taAAlamuh\q@u{a} anta wal\q@u{a} qawmuka min qabli h\q@u{atha} fa\q@b{i}\q@u{s}bir inna alAA\q@u{a}qibata lilmuttaqeen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mdxxiii{Wail\q@u{a} AA\q@u{a}din akh\q@u{a}hum hoodan q\q@u{a}la y\q@u{a} qawmi oAAbudoo All\q@u{a}ha m\q@u{a} lakum min il\q@u{a}hin ghayruhu in antum ill\q@u{a} muftaroon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mdxxiv{Y\q@u{a} qawmi l\q@u{a} asalukum AAalayhi ajran in ajriya ill\q@u{a} AAal\q@u{a} alla\q@u{th}ee fa\q@u{t}aranee afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mdxxv{Way\q@u{a} qawmi istaghfiroo rabbakum thumma tooboo ilayhi yursili a\q@b{l}ssam\q@u{a}a AAalaykum midr\q@u{a}ran wayazidkum quwwatan il\q@u{a} quwwatikum wal\q@u{a} tatawallaw mujrimeen\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mdxxvi{Q\q@u{a}loo y\q@u{a} hoodu m\q@u{a} jitan\q@u{a} bibayyinatin wam\q@u{a} na\q@u{h}nu bit\q@u{a}rikee \q@u{a}lihatin\q@u{a} AAan qawlika wam\q@u{a} na\q@u{h}nu laka bimumineen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mdxxvii{In naqoolu ill\q@u{a} iAAtar\q@u{a}ka baAA\q@u{d}u \q@u{a}lihatin\q@u{a} bisooin q\q@u{a}la innee oshhidu All\q@u{a}ha wa\q@b{i}shhadoo annee bareeon mimm\q@u{a} tushrikoon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mdxxviii{Min doonihi fakeedoonee jameeAAan thumma l\q@u{a} tun\q@i{\q@u{th}}iroon\q@b{i}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mdxxix{Innee tawakkaltu AAal\q@u{a} All\q@u{a}hi rabbee warabbikum m\q@u{a} min d\q@u{a}bbatin ill\q@u{a} huwa \q@u{a}khi\q@u{th}un bin\q@u{as}iyatih\q@u{a} inna rabbee AAal\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mdxxx{Fain tawallaw faqad ablaghtukum m\q@u{a} orsiltu bihi ilaykum wayastakhlifu rabbee qawman ghayrakum wal\q@u{a} ta\q@u{d}urroonahu shayan inna rabbee AAal\q@u{a} kulli shayin \q@u{h}afee\q@i{\q@u{th}}\q@b{un}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mdxxxi{Walamm\q@u{a} j\q@u{a}a amrun\q@u{a} najjayn\q@u{a} hoodan wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo maAAahu bira\q@u{h}matin minn\q@u{a} wanajjayn\q@u{a}hum min AAa\q@u{tha}bin ghalee\q@i{\q@u{th}}\q@b{in}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mdxxxii{Watilka AA\q@u{a}dun ja\q@u{h}adoo bi\q@u{a}y\q@u{a}ti rabbihim waAAa\q@u{s}aw rusulahu wa\q@b{i}ttabaAAoo amra kulli jabb\q@u{a}rin AAaneed\q@b{in}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mdxxxiii{WaotbiAAoo fee h\q@u{ath}ihi a\q@b{l}dduny\q@u{a} laAAnatan wayawma alqiy\q@u{a}mati al\q@u{a} inna AA\q@u{a}dan kafaroo rabbahum al\q@u{a} buAAdan liAA\q@u{a}din qawmi hood\q@b{in}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mdxxxiv{Wail\q@u{a} thamooda akh\q@u{a}hum \q@u{sa}li\q@u{h}an q\q@u{a}la y\q@u{a} qawmi oAAbudoo All\q@u{a}ha m\q@u{a} lakum min il\q@u{a}hin ghayruhu huwa anshaakum mina alar\q@u{d}i wa\q@b{i}staAAmarakum feeh\q@u{a} fa\q@b{i}staghfiroohu thumma tooboo ilayhi inna rabbee qareebun mujeeb\q@b{un}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mdxxxv{Q\q@u{a}loo y\q@u{a} \q@u{sa}li\q@u{h}u qad kunta feen\q@u{a} marjuwwan qabla h\q@u{atha} atanh\q@u{a}n\q@u{a} an naAAbuda m\q@u{a} yaAAbudu \q@u{a}b\q@u{a}on\q@u{a} wainnan\q@u{a} lafee shakkin mimm\q@u{a} tadAAoon\q@u{a} ilayhi mureeb\q@b{un}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mdxxxvi{Q\q@u{a}la y\q@u{a} qawmi araaytum in kuntu AAal\q@u{a} bayyinatin min rabbee wa\q@u{a}t\q@u{a}nee minhu ra\q@u{h}matan faman yan\q@u{s}urunee mina All\q@u{a}hi in AAa\q@u{s}aytuhu fam\q@u{a} tazeedoonanee ghayra takhseer\q@b{in}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mdxxxvii{Way\q@u{a} qawmi h\q@u{ath}ihi n\q@u{a}qatu All\q@u{a}hi lakum \q@u{a}yatan fa\q@u{th}arooh\q@u{a} takul fee ar\q@u{d}i All\q@u{a}hi wal\q@u{a} tamassooh\q@u{a} bisooin fayakhu\q@u{th}akum AAa\q@u{tha}bun qareeb\q@b{un}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mdxxxviii{FaAAaqarooh\q@u{a} faq\q@u{a}la tamattaAAoo fee d\q@u{a}rikum thal\q@u{a}thata ayy\q@u{a}min \q@u{tha}lika waAAdun ghayru mak\q@u{th}oob\q@b{in}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mdxxxix{Falamm\q@u{a} j\q@u{a}a amrun\q@u{a} najjayn\q@u{a} \q@u{sa}li\q@u{h}an wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo maAAahu bira\q@u{h}matin minn\q@u{a} wamin khizyi yawmii\q@u{th}in inna rabbaka huwa alqawiyyu alAAazeez\q@b{u}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mdxl{Waakha\q@u{th}a alla\q@u{th}eena \q@i{\q@u{th}}alamoo a\q@b{l}\q@u{ss}ay\q@u{h}atu faa\q@u{s}ba\q@u{h}oo fee diy\q@u{a}rihim j\q@u{a}thimeen\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mdxli{Kaan lam yaghnaw feeh\q@u{a} al\q@u{a} inna thamooda kafaroo rabbahum al\q@u{a} buAAdan lithamood\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mdxlii{Walaqad j\q@u{a}at rusulun\q@u{a} ibr\q@u{a}heema bi\q@b{a}lbushr\q@u{a} q\q@u{a}loo sal\q@u{a}man q\q@u{a}la sal\q@u{a}mun fam\q@u{a} labitha an j\q@u{a}a biAAijlin \q@u{h}anee\q@u{th}\q@b{in}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mdxliii{Falamm\q@u{a} ra\q@u{a} aydiyahum l\q@u{a} ta\q@u{s}ilu ilayhi nakirahum waawjasa minhum kheefatan q\q@u{a}loo l\q@u{a} takhaf inn\q@u{a} orsiln\q@u{a} il\q@u{a} qawmi loo\q@u{t}\q@b{in}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mdxliv{Wa\q@b{i}mraatuhu q\q@u{a}imatun fa\q@u{d}a\q@u{h}ikat fabashsharn\q@u{a}h\q@u{a} biis\q@u{ha}qa wamin war\q@u{a}i is\q@u{ha}qa yaAAqoob\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mdxlv{Q\q@u{a}lat y\q@u{a} waylat\q@u{a} aalidu waan\q@u{a} AAajoozun wah\q@u{atha} baAAlee shaykhan inna h\q@u{atha} lashayon AAajeeb\q@b{un}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mdxlvi{Q\q@u{a}loo ataAAjabeena min amri All\q@u{a}hi ra\q@u{h}matu All\q@u{a}hi wabarak\q@u{a}tuhu AAalaykum ahla albayti innahu \q@u{h}ameedun majeed\q@b{un}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mdxlvii{Falamm\q@u{a} \q@u{th}ahaba AAan ibr\q@u{a}heema a\q@b{l}rrawAAu waj\q@u{a}athu albushr\q@u{a }yuj\q@u{a}dilun\q@u{a} fee qawmi loo\q@u{t}\q@b{in}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mdxlviii{Inna ibr\q@u{a}heema la\q@u{h}aleemun aww\q@u{a}hun muneeb\q@b{un}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mdxlix{Y\q@u{a} ibr\q@u{a}heemu aAAri\q@u{d} AAan h\q@u{atha} innahu qad j\q@u{a}a amru rabbika wainnahum \q@u{a}teehim AAa\q@u{tha}bun ghayru mardood\q@b{in}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mdl{Walamm\q@u{a} j\q@u{a}at rusulun\q@u{a} loo\q@u{t}an seea bihim wa\q@u{da}qa bihim \q@u{th}arAAan waq\q@u{a}la h\q@u{atha} yawmun AAa\q@u{s}eeb\q@b{un}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mdli{Waj\q@u{a}ahu qawmuhu yuhraAAoona ilayhi wamin qablu k\q@u{a}noo yaAAmaloona a\q@b{l}ssayyi\q@u{a}ti q\q@u{a}la y\q@u{a} qawmi h\q@u{a}ol\q@u{a}i ban\q@u{a}tee hunna a\q@u{t}haru lakum fa\q@b{i}ttaqoo All\q@u{a}ha wal\q@u{a} tukhzooni fee \q@u{d}ayfee alaysa minkum rajulun rasheed\q@b{un}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mdlii{Q\q@u{a}loo laqad AAalimta m\q@u{a} lan\q@u{a} fee ban\q@u{a}tika min \q@u{h}aqqin wainnaka lataAAlamu m\q@u{a} nureed\q@b{u}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mdliii{Q\q@u{a}la law anna lee bikum quwwatan aw \q@u{a}wee il\q@u{a} ruknin shadeed\q@b{in}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mdliv{Q\q@u{a}loo y\q@u{a} loo\q@u{t}u inn\q@u{a} rusulu rabbika lan ya\q@u{s}iloo ilayka faasri biahlika biqi\q@u{t}AAin mina allayli wal\q@u{a} yaltafit minkum a\q@u{h}adun ill\q@u{a} imraataka innahu mu\q@u{s}eebuh\q@u{a} m\q@u{a} a\q@u{sa}bahum inna mawAAidahumu a\q@b{l}\q@u{ss}ub\q@u{h}u alaysa a\q@b{l}\q@u{ss}ub\q@u{h}u biqareeb\q@b{in}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mdlv{Falamm\q@u{a} j\q@u{a}a amrun\q@u{a} jaAAaln\q@u{a} AA\q@u{a}liyah\q@u{a} s\q@u{a}filah\q@u{a} waam\q@u{t}arn\q@u{a} AAalayh\q@u{a} \q@u{h}ij\q@u{a}ratan min sijjeelin man\q@u{d}ood\q@b{in}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mdlvi{Musawwamatan AAinda rabbika wam\q@u{a} hiya mina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena bibaAAeed\q@b{in}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mdlvii{Wail\q@u{a} madyana akh\q@u{a}hum shuAAayban q\q@u{a}la y\q@u{a} qawmi oAAbudoo All\q@u{a}ha m\q@u{a} lakum min il\q@u{a}hin ghayruhu wal\q@u{a} tanqu\q@u{s}oo almiky\q@u{a}la wa\q@b{a}lmeez\q@u{a}na innee ar\q@u{a}kum bikhayrin wainnee akh\q@u{a}fu AAalaykum AAa\q@u{tha}ba yawmin mu\q@u{h}ee\q@u{t}\q@b{in}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mdlviii{Way\q@u{a} qawmi awfoo almiky\q@u{a}la wa\q@b{a}lmeez\q@u{a}na bi\q@b{a}lqis\q@u{t}i wal\q@u{a} tabkhasoo a\q@b{l}nn\q@u{a}sa ashy\q@u{a}ahum wal\q@u{a} taAAthaw fee alar\q@u{d}i mufsideen\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mdlix{Baqiyyatu All\q@u{a}hi khayrun lakum in kuntum mumineena wam\q@u{a} an\q@u{a} AAalaykum bi\q@u{h}afee\q@i{\q@u{th}}\q@b{in}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mdlx{Q\q@u{a}loo y\q@u{a} shuAAaybu a\q@u{s}al\q@u{a}tuka tamuruka an natruka m\q@u{a} yaAAbudu \q@u{a}b\q@u{a}on\q@u{a} aw an nafAAala fee amw\q@u{a}lin\q@u{a} m\q@u{a} nash\q@u{a}o innaka laanta al\q@u{h}aleemu a\q@b{l}rrasheed\q@b{u}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mdlxi{Q\q@u{a}la y\q@u{a} qawmi araaytum in kuntu AAal\q@u{a} bayyinatin min rabbee warazaqanee minhu rizqan \q@u{h}asanan wam\q@u{a} oreedu an okh\q@u{a}lifakum il\q@u{a} m\q@u{a} anh\q@u{a}kum AAanhu in oreedu ill\q@u{a} ali\q@u{s}l\q@u{ah}a m\q@u{a} ista\q@u{t}aAAtu wam\q@u{a} tawfeeqee ill\q@u{a} bi\q@b{A}ll\q@u{a}hi AAalayhi tawakkaltu wailayhi oneeb\q@b{u}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mdlxii{Way\q@u{a} qawmi l\q@u{a} yajrimannakum shiq\q@u{a}qee an yu\q@u{s}eebakum mithlu m\q@u{a} a\q@u{sa}ba qawma noo\q@u{h}in aw qawma hoodin aw qawma \q@u{sa}li\q@u{h}in wam\q@u{a} qawmu loo\q@u{t}in minkum bibaAAeed\q@b{in}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mdlxiii{Wa\q@b{i}staghfiroo rabbakum thumma tooboo ilayhi inna rabbee ra\q@u{h}eemun wadood\q@b{un}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mdlxiv{Q\q@u{a}loo y\q@u{a} shuAAaybu m\q@u{a} nafqahu katheeran mimm\q@u{a} taqoolu wainn\q@u{a} lanar\q@u{a}ka feen\q@u{a} \q@u{d}aAAeefan walawl\q@u{a} rah\q@u{t}uka larajamn\q@u{a}ka wam\q@u{a} anta AAalayn\q@u{a} biAAazeez\q@b{in}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mdlxv{Q\q@u{a}la y\q@u{a} qawmi arah\q@u{t}ee aAAazzu AAalaykum mina All\q@u{a}hi wa\q@b{i}ttakha\q@u{th}tumoohu war\q@u{a}akum \q@i{\q@u{th}}ihriyyan inna rabbee bim\q@u{a} taAAmaloona mu\q@u{h}ee\q@u{t}\q@b{un}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mdlxvi{Way\q@u{a} qawmi iAAmaloo AAal\q@u{a} mak\q@u{a}natikum innee AA\q@u{a}milun sawfa taAAlamoona man yateehi AAa\q@u{tha}bun yukhzeehi waman huwa k\q@u{ath}ibun wa\q@b{i}rtaqiboo inne maAAakum raqeeb\q@b{un}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mdlxvii{Walamm\q@u{a} j\q@u{a}a amrun\q@u{a} najjayn\q@u{a} shuAAayban wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo maAAahu bira\q@u{h}matin minn\q@u{a} waakha\q@u{th}ati alla\q@u{th}eena \q@i{\q@u{th}}alamoo a\q@b{l}\q@u{ss}ay\q@u{h}atu faa\q@u{s}ba\q@u{h}oo fee diy\q@u{a}rihim j\q@u{a}thimeen\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mdlxviii{Kaan lam yaghnaw feeh\q@u{a} al\q@u{a} buAAdan limadyana kam\q@u{a} baAAidat thamood\q@b{u}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mdlxix{Walaqad arsaln\q@u{a} moos\q@u{a} bi\q@u{a}y\q@u{a}tin\q@u{a} wasul\q@u{ta}nin mubeen\q@b{in}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mdlxx{Il\q@u{a} firAAawna wamalaihi fa\q@b{i}ttabaAAoo amra firAAawna wam\q@u{a} amru firAAawna birasheed\q@b{in}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mdlxxi{Yaqdumu qawmahu yawma alqiy\q@u{a}mati faawradahumu a\q@b{l}nn\q@u{a}ra wabisa alwirdu almawrood\q@b{u}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mdlxxii{WaotbiAAoo fee h\q@u{ath}ihi laAAnatan wayawma alqiy\q@u{a}mati bisa a\q@b{l}rrifdu almarfood\q@b{u}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mdlxxiii{\q@u{Tha}lika min anb\q@u{a}i alqur\q@u{a} naqu\q@u{ss}uhu AAalayka minh\q@u{a} q\q@u{a}imun wa\q@u{h}a\q@u{s}eed\q@b{un}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mdlxxiv{Wam\q@u{a} \q@i{\q@u{th}}alamn\q@u{a}hum wal\q@u{a}kin \q@i{\q@u{th}}alamoo anfusahum fam\q@u{a} aghnat AAanhum \q@u{a}lihatuhumu allatee yadAAoona min dooni All\q@u{a}hi min shayin lamm\q@u{a} j\q@u{a}a amru rabbika wam\q@u{a} z\q@u{a}doohum ghayra tatbeeb\q@b{in}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mdlxxv{Waka\q@u{tha}lika akh\q@u{th}u rabbika i\q@u{tha} akha\q@u{th}a alqur\q@u{a} wahiya \q@i{\q@u{th}}\q@u{a}limatun inna akh\q@u{th}ahu aleemun shadeed\q@b{un}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mdlxxvi{Inna fee \q@u{tha}lika la\q@u{a}yatan liman kh\q@u{a}fa AAa\q@u{tha}ba al\q@u{a}khirati \q@u{tha}lika yawmun majmooAAun lahu a\q@b{l}nn\q@u{a}su wa\q@u{tha}lika yawmun mashhoodun\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mdlxxvii{Wam\q@u{a} nuakhkhiruhu ill\q@u{a} liajalin maAAdood\q@b{in}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mdlxxviii{Yawma yati l\q@u{a} takallamu nafsun ill\q@u{a} bii\q@u{th}nihi faminhum shaqiyyun wasaAAeed\q@b{in}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mdlxxix{Faamm\q@u{a} alla\q@u{th}eena shaqoo fafee a\q@b{l}nn\q@u{a}ri lahum feeh\q@u{a} zafeerun washaheeq\q@b{un}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mdlxxx{Kh\q@u{a}lideena feeh\q@u{a} m\q@u{a} d\q@u{a}mati a\q@b{l}ssam\q@u{a}w\q@u{a}tu wa\q@b{a}lar\q@u{d}u ill\q@u{a} m\q@u{a} sh\q@u{a}a rabbuka inna rabbaka faAAAA\q@u{a}lun lim\q@u{a} yureed\q@b{u}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mdlxxxi{Waamm\q@u{a} alla\q@u{th}eena suAAidoo fafee aljannati kh\q@u{a}lideena feeh\q@u{a} m\q@u{a} d\q@u{a}mati a\q@b{l}ssam\q@u{a}w\q@u{a}tu wa\q@b{a}lar\q@u{d}u ill\q@u{a} m\q@u{a} sh\q@u{a}a rabbuka AAa\q@u{ta}an ghayra maj\q@u{th}oo\q@u{th}\q@b{in}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mdlxxxii{Fal\q@u{a} taku fee miryatin mimm\q@u{a} yaAAbudu h\q@u{a}ol\q@u{a}i m\q@u{a} yaAAbudoona ill\q@u{a} kam\q@u{a} yaAAbudu \q@u{a}b\q@u{a}ohum min qablu wainn\q@u{a} lamuwaffoohum na\q@u{s}eebahum ghayra manqoo\q@u{s}\q@b{in}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mdlxxxiii{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba fa\q@b{i}khtulifa feehi walawl\q@u{a} kalimatun sabaqat min rabbika laqu\q@u{d}iya baynahum wainnahum lafee shakkin minhu mureeb\q@b{un}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mdlxxxiv{Wainna kullan lamm\q@u{a} layuwaffiyannahum rabbuka aAAm\q@u{a}lahum innahu bim\q@u{a} yaAAmaloona khabeer\q@b{un}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mdlxxxv{Fa\q@b{i}staqim kam\q@u{a} omirta waman t\q@u{a}ba maAAaka wal\q@u{a} ta\q@u{t}ghaw innahu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@mdlxxxvi{Wal\q@u{a} tarkanoo il\q@u{a} alla\q@u{th}eena \q@i{\q@u{th}}alamoo fatamassakumu a\q@b{l}nn\q@u{a}ru wam\q@u{a} lakum min dooni All\q@u{a}hi min awliy\q@u{a}a thumma l\q@u{a} tun\q@u{s}aroon\q@b{a}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@mdlxxxvii{Waaqimi a\q@b{l}\q@u{ss}al\q@u{a}ta \q@u{t}arafayi a\q@b{l}nnah\q@u{a}ri wazulafan mina allayli inna al\q@u{h}asan\q@u{a}ti yu\q@u{th}hibna a\q@b{l}ssayyi\q@u{a}ti \q@u{tha}lika \q@u{th}ikr\q@u{a} li\q@b{l}\q@u{ththa}kireen\q@b{a}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@mdlxxxviii{Wa\q@b{i}\q@u{s}bir fainna All\q@u{a}ha l\q@u{a} yu\q@u{d}eeAAu ajra almu\q@u{h}sineen\q@b{a}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@mdlxxxix{Falawl\q@u{a} k\q@u{a}na mina alqurooni min qablikum oloo baqiyyatin yanhawna AAani alfas\q@u{a}di fee alar\q@u{d}i ill\q@u{a} qaleelan mimman anjayn\q@u{a} minhum wa\q@b{i}ttabaAAa alla\q@u{th}eena \q@i{\q@u{th}}alamoo m\q@u{a} otrifoo feehi wak\q@u{a}noo mujrimeen\q@b{a}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@mdxc{Wam\q@u{a} k\q@u{a}na rabbuka liyuhlika alqur\q@u{a} bi\q@i{\q@u{th}}ulmin waahluh\q@u{a} mu\q@u{s}li\q@u{h}oon\q@b{a}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@mdxci{Walaw sh\q@u{a}a rabbuka lajaAAala a\q@b{l}nn\q@u{a}sa ommatan w\q@u{ah}idatan wal\q@u{a} yaz\q@u{a}loona mukhtalifeen\q@b{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@mdxcii{Ill\q@u{a} man ra\q@u{h}ima rabbuka wali\q@u{tha}lika khalaqahum watammat kalimatu rabbika laamlaanna jahannama mina aljinnati wa\q@b{al}nn\q@u{a}si ajmaAAeen\q@b{a}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@mdxciii{Wakullan naqu\q@u{ss}u AAalayka min anb\q@u{a}i a\q@b{l}rrusuli m\q@u{a} nuthabbitu bihi fu\q@u{a}daka waj\q@u{a}aka fee h\q@u{ath}ihi al\q@u{h}aqqu wamawAAi\q@i{\q@u{th}}atun wa\q@u{th}ikr\q@u{a} lilmumineen\q@b{a}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@mdxciv{Waqul lilla\q@u{th}eena l\q@u{a} yuminoona iAAmaloo AAal\q@u{a} mak\q@u{a}natikum inn\q@u{a} AA\q@u{a}miloon\q@b{a}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@mdxcv{Wa\q@b{i}nta\q@i{\q@u{th}}iroo inn\q@u{a} munta\q@i{\q@u{th}}iroon\q@b{a}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@mdxcvi{Walill\q@u{a}hi ghaybu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wailayhi yurjaAAu alamru kulluhu fa\q@b{o}AAbudhu watawakkal AAalayhi wam\q@u{a} rabbuka bigh\q@u{a}filin AAamm\q@u{a} taAAmaloon\q@b{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@mdxcvii{\basmalahlt Alifl\q@u{a}mr\q@u{a} tilka \q@u{a}y\q@u{a}tu alkit\q@u{a}bi almubeen\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mdxcviii{Inn\q@u{a} anzaln\q@u{a}hu qur\q@u{a}nan AAarabiyyan laAAallakum taAAqiloon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mdxcix{Na\q@u{h}nu naqu\q@u{ss}u AAalayka a\q@u{h}sana alqa\q@u{s}a\q@u{s}i bim\q@u{a} aw\q@u{h}ayn\q@u{a} ilayka h\q@u{atha} alqur\q@u{a}na wain kunta min qablihi lamina algh\q@u{a}fileen\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mdc{I\q@u{th} q\q@u{a}la yoosufu liabeehi y\q@u{a} abati innee raaytu a\q@u{h}ada AAashara kawkaban wa\q@b{al}shshamsa wa\q@b{a}lqamara raaytuhum lee s\q@u{a}jideen\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mdci{Q\q@u{a}la y\q@u{a} bunayya l\q@u{a} taq\q@u{s}u\q@u{s} ruy\q@u{a}ka AAal\q@u{a} ikhwatika fayakeedoo laka kaydan inna a\q@b{l}shshay\q@u{ta}na lilins\q@u{a}ni AAaduwwun mubeen\q@b{un}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mdcii{Waka\q@u{tha}lika yajtabeeka rabbuka wayuAAallimuka min taweeli ala\q@u{ha}deethi wayutimmu niAAmatahu AAalayka waAAal\q@u{a} \q@u{a}li yaAAqooba kam\q@u{a} atammah\q@u{a} AAal\q@u{a} abawayka min qablu ibr\q@u{a}heema wais\q@u{ha}qa inna rabbaka AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mdciii{Laqad k\q@u{a}na fee yoosufa waikhwatihi \q@u{a}y\q@u{a}tun li\q@b{l}ss\q@u{a}ileen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mdciv{I\q@u{th} q\q@u{a}loo layoosufu waakhoohu a\q@u{h}abbu il\q@u{a} abeen\q@u{a} minn\q@u{a} wana\q@u{h}nu AAu\q@u{s}batun inna ab\q@u{a}n\q@u{a} lafee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mdcv{Oqtuloo yoosufa awi i\q@u{t}ra\q@u{h}oohu ar\q@u{d}an yakhlu lakum wajhu abeekum watakoonoo min baAAdihi qawman \q@u{sa}li\q@u{h}een\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mdcvi{Q\q@u{a}la q\q@u{a}ilun minhum l\q@u{a} taqtuloo yoosufa waalqoohu fee ghay\q@u{a}bati aljubbi yaltaqi\q@u{t}hu baAA\q@u{d}u a\q@b{l}ssayy\q@u{a}rati in kuntum f\q@u{a}AAileen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mdcvii{Q\q@u{a}loo y\q@u{a} ab\q@u{a}n\q@u{a} m\q@u{a} laka l\q@u{a} tamann\q@u{a} AAal\q@u{a} yoosufa wainn\q@u{a} lahu lan\q@u{as}i\q@u{h}oon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mdcviii{Arsilhu maAAan\q@u{a} ghadan yartaAA wayalAAab wainn\q@u{a} lahu la\q@u{ha}fi\q@i{\q@u{th}}oon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mdcix{Q\q@u{a}la innee laya\q@u{h}zununee an tha\q@u{th}haboo bihi waakh\q@u{a}fu an yakulahu a\q@b{l}\q@u{thth}ibu waantum AAanhu gh\q@u{a}filoon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mdcx{Q\q@u{a}loo lain akalahu a\q@b{l}\q@u{thth}ibu wana\q@u{h}nu AAu\q@u{s}batun inn\q@u{a} i\q@u{th}an lakh\q@u{a}siroon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mdcxi{Falamm\q@u{a} \q@u{th}ahaboo bihi waajmaAAoo an yajAAaloohu fee ghay\q@u{a}bati aljubbi waaw\q@u{h}ayn\q@u{a} ilayhi latunabiannahum biamrihim h\q@u{atha} wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mdcxii{Waj\q@u{a}oo ab\q@u{a}hum AAish\q@u{a}an yabkoon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mdcxiii{Q\q@u{a}loo y\q@u{a} ab\q@u{a}n\q@u{a} inn\q@u{a} \q@u{th}ahabn\q@u{a} nastabiqu watarakn\q@u{a} yoosufa AAinda mat\q@u{a}AAin\q@u{a} faakalahu a\q@b{l}\q@u{thth}ibu wam\q@u{a} anta bimuminin lan\q@u{a} walaw kunn\q@u{a} \q@u{sa}diqeen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mdcxiv{Waj\q@u{a}oo AAal\q@u{a} qamee\q@u{s}ihi bidamin ka\q@u{th}ibin q\q@u{a}la bal sawwalat lakum anfusukum amran fa\q@u{s}abrun jameelun wa\q@b{A}ll\q@u{a}hu almustaAA\q@u{a}nu AAal\q@u{a} m\q@u{a} ta\q@u{s}ifoon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mdcxv{Waj\q@u{a}at sayy\q@u{a}ratun faarsaloo w\q@u{a}ridahum faadl\q@u{a} dalwahu q\q@u{a}la y\q@u{a} bushr\q@u{a} h\q@u{atha} ghul\q@u{a}mun waasarroohu bi\q@u{da}AAatan wa\q@b{A}ll\q@u{a}hu AAaleemun bim\q@u{a} yaAAmaloon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mdcxvi{Washarawhu bithamanin bakhsin dar\q@u{a}hima maAAdoodatin wak\q@u{a}noo feehi mina a\q@b{l}zz\q@u{a}hideen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mdcxvii{Waq\q@u{a}la alla\q@u{th}ee ishtar\q@u{a}hu min mi\q@u{s}ra li\q@b{i}mraatihi akrimee mathw\q@u{a}hu AAas\q@u{a} an yanfaAAan\q@u{a} aw nattakhi\q@u{th}ahu waladan waka\q@u{tha}lika makkann\q@u{a} liyoosufa fee alar\q@u{d}i walinuAAallimahu min taweeli ala\q@u{ha}deethi wa\q@b{A}ll\q@u{a}hu gh\q@u{a}libun AAal\q@u{a} amrihi wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mdcxviii{Walamm\q@u{a} balagha ashuddahu \q@u{a}tayn\q@u{a}hu \q@u{h}ukman waAAilman waka\q@u{tha}lika najzee almu\q@u{h}sineen\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mdcxix{War\q@u{a}wadathu allatee huwa fee baytih\q@u{a} AAan nafsihi waghallaqati alabw\q@u{a}ba waq\q@u{a}lat hayta laka q\q@u{a}la maAA\q@u{ath}a All\q@u{a}hi innahu rabbee a\q@u{h}sana mathw\q@u{a}ya innahu l\q@u{a} yufli\q@u{h}u a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mdcxx{Walaqad hammat bihi wahamma bih\q@u{a} lawl\q@u{a} an ra\q@u{a} burh\q@u{a}na rabbihi ka\q@u{tha}lika lina\q@u{s}rifa AAanhu a\q@b{l}ssooa wa\q@b{a}lfa\q@u{h}sh\q@u{a}a innahu min AAib\q@u{a}din\q@u{a} almukhla\q@u{s}een\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mdcxxi{Wa\q@b{i}stabaq\q@u{a} alb\q@u{a}ba waqaddat qamee\q@u{s}ahu min duburin waalfay\q@u{a} sayyidah\q@u{a} lad\q@u{a} alb\q@u{a}bi q\q@u{a}lat m\q@u{a} jaz\q@u{a}o man ar\q@u{a}da biahlika sooan ill\q@u{a} an yusjana aw AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mdcxxii{Q\q@u{a}la hiya r\q@u{a}wadatnee AAan nafsee washahida sh\q@u{a}hidun min ahlih\q@u{a} in k\q@u{a}na qamee\q@u{s}uhu qudda min qubulin fa\q@u{s}adaqat wahuwa mina alk\q@u{ath}ibeen\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mdcxxiii{Wain k\q@u{a}na qamee\q@u{s}uhu qudda min duburin faka\q@u{th}abat wahuwa mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mdcxxiv{Falamm\q@u{a} ra\q@u{a} qamee\q@u{s}ahu qudda min duburin q\q@u{a}la innahu min kaydikunna inna kaydakunna AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mdcxxv{Yoosufu aAAri\q@u{d} AAan h\q@u{atha} wa\q@b{i}staghfiree li\q@u{th}anbiki innaki kunti mina alkh\q@u{at}ieen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mdcxxvi{Waq\q@u{a}la niswatun fee almadeenati imraatu alAAazeezi tur\q@u{a}widu fat\q@u{a}h\q@u{a} AAan nafsihi qad shaghafah\q@u{a} \q@u{h}ubban inn\q@u{a} lanar\q@u{a}h\q@u{a} fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mdcxxvii{Falamm\q@u{a} samiAAat bimakrihinna arsalat ilayhinna waaAAtadat lahunna muttakaan wa\q@u{a}tat kulla w\q@u{ah}idatin minhunna sikkeenan waq\q@u{a}lati okhruj AAalayhinna falamm\q@u{a} raaynahu akbarnahu waqa\q@u{tt}aAAna aydiyahunna waqulna \q@u{ha}sha lill\q@u{a}hi m\q@u{a} h\q@u{atha} basharan in h\q@u{atha} ill\q@u{a} malakun kareem\q@b{un}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mdcxxviii{Q\q@u{a}lat fa\q@u{tha}likunna alla\q@u{th}ee lumtunnanee feehi walaqad r\q@u{a}wadtuhu AAan nafsihi fa\q@b{i}stAA\q@u{s}ama walain lam yafAAal m\q@u{a} \q@u{a}muruhu layusjananna walayakoonan mina a\q@b{l}\q@u{ssa}ghireen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mdcxxix{Q\q@u{a}la rabbi a\q@b{l}ssijnu a\q@u{h}abbu ilayya mimm\q@u{a} yadAAoonanee ilayhi waill\q@u{a} ta\q@u{s}rif AAannee kaydahunna a\q@u{s}bu ilayhinna waakun mina alj\q@u{a}hileen\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mdcxxx{Fa\q@b{i}staj\q@u{a}ba lahu rabbuhu fa\q@u{s}arafa AAanhu kaydahunna innahu huwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mdcxxxi{Thumma bad\q@u{a} lahum min baAAdi m\q@u{a} raawoo al\q@u{a}y\q@u{a}ti layasjununnahu \q@u{h}att\q@u{a} \q@u{h}een\q@b{in}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mdcxxxii{Wadakhala maAAahu a\q@b{l}ssijna fatay\q@u{a}ni q\q@u{a}la a\q@u{h}aduhum\q@u{a} innee ar\q@u{a}nee aAA\q@u{s}iru khamran waq\q@u{a}la al\q@u{a}kharu innee ar\q@u{a}nee a\q@u{h}milu fawqa rasee khubzan takulu a\q@b{l}\q@u{tt}ayru minhu nabbin\q@u{a} bitaweelihi inn\q@u{a} nar\q@u{a}ka mina almu\q@u{h}sineen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mdcxxxiii{Q\q@u{a}la l\q@u{a} yateekum\q@u{a} \q@u{t}aAA\q@u{a}mun turzaq\q@u{a}nihi ill\q@u{a} nabbatukum\q@u{a} bitaweelihi qabla an yatiyakum\q@u{a} \q@u{tha}likum\q@u{a} mimm\q@u{a} AAallamanee rabbee innee taraktu millata qawmin l\q@u{a} yuminoona bi\q@b{A}ll\q@u{a}hi wahum bi\q@b{a}l\q@u{a}khirati hum k\q@u{a}firoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mdcxxxiv{Wa\q@b{i}ttabaAAtu millata \q@u{a}b\q@u{a}ee ibr\q@u{a}heema wais\q@u{ha}qa wayaAAqooba m\q@u{a} k\q@u{a}na lan\q@u{a} an nushrika bi\q@b{A}ll\q@u{a}hi min shayin \q@u{tha}lika min fa\q@u{d}li All\q@u{a}hi AAalayn\q@u{a} waAAal\q@u{a} a\q@b{l}nn\q@u{a}si wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yashkuroon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mdcxxxv{Y\q@u{a} \q@u{sah}ibayi a\q@b{l}ssijni aarb\q@u{a}bun mutafarriqoona khayrun ami All\q@u{a}hu alw\q@u{ah}idu alqahh\q@u{a}r\q@b{u}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mdcxxxvi{M\q@u{a} taAAbudoona min doonihi ill\q@u{a} asm\q@u{a}an sammaytumooh\q@u{a} antum wa\q@u{a}b\q@u{a}okum m\q@u{a} anzala All\q@u{a}hu bih\q@u{a} min sul\q@u{ta}nin ini al\q@u{h}ukmu ill\q@u{a} lill\q@u{a}hi amara all\q@u{a} taAAbudoo ill\q@u{a} iyy\q@u{a}hu \q@u{tha}lika a\q@b{l}ddeenu alqayyimu wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mdcxxxvii{Y\q@u{a} \q@u{sah}ibayi a\q@b{l}ssijni amm\q@u{a} a\q@u{h}adukum\q@u{a} fayasqee rabbahu khamran waamm\q@u{a} al\q@u{a}kharu fayu\q@u{s}labu fatakulu a\q@b{l}\q@u{tt}ayru min rasihi qu\q@u{d}iya alamru alla\q@u{th}ee feehi tastaftiy\q@u{a}n\q@b{i}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mdcxxxviii{Waq\q@u{a}la lilla\q@u{th}ee \q@i{\q@u{th}}anna annahu n\q@u{a}jin minhum\q@u{a} o\q@u{th}kurnee AAinda rabbika faans\q@u{a}hu a\q@b{l}shshay\q@u{ta}nu \q@u{th}ikra rabbihi falabitha fee a\q@b{l}ssijni bi\q@u{d}AAa sineen\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mdcxxxix{Waq\q@u{a}la almaliku innee ar\q@u{a} sabAAa baqar\q@u{a}tin sim\q@u{a}nin yakuluhunna sabAAun AAij\q@u{a}fun wasabAAa sunbul\q@u{a}tin khu\q@u{d}rin waokhara y\q@u{a}bis\q@u{a}tin y\q@u{a} ayyuh\q@u{a} almalao aftoonee fee ruy\q@u{a}ya in kuntum li\q@b{l}rruy\q@u{a} taAAburoon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mdcxl{Q\q@u{a}loo a\q@u{d}gh\q@u{a}thu a\q@u{h}l\q@u{a}min wam\q@u{a} na\q@u{h}nu bitaweeli ala\q@u{h}l\q@u{a}mi biAA\q@u{a}limeen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mdcxli{Waq\q@u{a}la alla\q@u{th}ee naj\q@u{a} minhum\q@u{a} wa\q@b{i}ddakara baAAda ommatin an\q@u{a} onabbiokum bitaweelihi faarsiloon\q@b{i}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mdcxlii{Yoosufu ayyuh\q@u{a} a\q@b{l}\q@u{ss}iddeequ aftin\q@u{a} fee sabAAi baqar\q@u{a}tin sim\q@u{a}nin yakuluhunna sabAAun AAij\q@u{a}fun wasabAAi sunbul\q@u{a}tin khu\q@u{d}rin waokhara y\q@u{a}bis\q@u{a}tin laAAallee arjiAAu il\q@u{a} a\q@b{l}nn\q@u{a}si laAAallahum yaAAlamoon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mdcxliii{Q\q@u{a}la tazraAAoona sabAAa sineena daaban fam\q@u{a} \q@u{h}a\q@u{s}adtum fa\q@u{th}aroohu fee sunbulihi ill\q@u{a} qaleelan mimm\q@u{a} takuloon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mdcxliv{Thumma yatee min baAAdi \q@u{tha}lika sabAAun shid\q@u{a}dun yakulna m\q@u{a} qaddamtum lahunna ill\q@u{a} qaleelan mimm\q@u{a} tu\q@u{hs}inoon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mdcxlv{Thumma yatee min baAAdi \q@u{tha}lika AA\q@u{a}mun feehi yugh\q@u{a}thu a\q@b{l}nn\q@u{a}su wafeehi yaAA\q@u{s}iroon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mdcxlvi{Waq\q@u{a}la almaliku itoonee bihi falamm\q@u{a} j\q@u{a}ahu a\q@b{l}rrasoolu q\q@u{a}la irjiAA il\q@u{a} rabbika fa\q@b{i}salhu m\q@u{a} b\q@u{a}lu a\q@b{l}nniswati all\q@u{a}tee qa\q@u{tt}aAAna aydiyahunna inna rabbee bikaydihinna AAaleem\q@b{un}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mdcxlvii{Q\q@u{a}la m\q@u{a} kha\q@u{t}bukunna i\q@u{th} r\q@u{a}wadtunna yoosufa AAan nafsihi qulna \q@u{ha}sha lill\q@u{a}hi m\q@u{a} AAalimn\q@u{a} AAalayhi min sooin q\q@u{a}lati imraatu alAAazeezi al\q@u{a}na \q@u{h}a\q@u{sh}a\q@u{s}a al\q@u{h}aqqu an\q@u{a} r\q@u{a}wadtuhu AAan nafsihi wainnahu lamina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mdcxlviii{\q@u{Tha}lika liyaAAlama annee lam akhunhu bi\q@b{a}lghaybi waanna All\q@u{a}ha l\q@u{a} yahdee kayda alkh\q@u{a}ineen\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mdcxlix{Wam\q@u{a} obarrio nafsee inna a\q@b{l}nnafsa laamm\q@u{a}ratun bi\q@b{al}ssooi ill\q@u{a} m\q@u{a} ra\q@u{h}ima rabbee inna rabbee ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mdcl{Waq\q@u{a}la almaliku itoonee bihi astakhli\q@u{s}hu linafsee falamm\q@u{a} kallamahu q\q@u{a}la innaka alyawma ladayn\q@u{a} makeenun ameen\q@b{un}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mdcli{Q\q@u{a}la ijAAalnee AAal\q@u{a} khaz\q@u{a}ini alar\q@u{d}i innee \q@u{h}afee\q@i{\q@u{th}}un AAaleem\q@b{un}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mdclii{Waka\q@u{tha}lika makann\q@u{a} liyoosufa fee alar\q@u{d}i yatabawwao minh\q@u{a} \q@u{h}aythu yash\q@u{a}o nu\q@u{s}eebu bira\q@u{h}matin\q@u{a} man nash\q@u{a}o wal\q@u{a} nu\q@u{d}eeAAu ajra almu\q@u{h}sineen\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mdcliii{Walaajru al\q@u{a}khirati khayrun lilla\q@u{th}eena \q@u{a}manoo wak\q@u{a}noo yattaqoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mdcliv{Waj\q@u{a}a ikhwatu yoosufa fadakhaloo AAalayhi faAAarafahum wahum lahu munkiroon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mdclv{Walamm\q@u{a} jahhazahum bijah\q@u{a}zihim q\q@u{a}la itoonee biakhin lakum min abeekum al\q@u{a} tarawna annee oofee alkayla waan\q@u{a} khayru almunzileen\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mdclvi{Fain lam tatoonee bihi fal\q@u{a} kayla lakum AAindee wal\q@u{a} taqraboon\q@b{i}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mdclvii{Q\q@u{a}loo sanur\q@u{a}widu AAanhu ab\q@u{a}hu wainn\q@u{a} laf\q@u{a}AAiloon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mdclviii{Waq\q@u{a}la lifity\q@u{a}nihi ijAAaloo bi\q@u{da}AAatahum fee ri\q@u{ha}lihim laAAallahum yaAArifoonah\q@u{a} i\q@u{tha} inqalaboo il\q@u{a} ahlihim laAAallahum yarjiAAoon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mdclix{Falamm\q@u{a} rajaAAoo il\q@u{a} abeehim q\q@u{a}loo y\q@u{a} ab\q@u{a}n\q@u{a} muniAAa minn\q@u{a} alkaylu faarsil maAAan\q@u{a} akh\q@u{a}n\q@u{a} naktal wainn\q@u{a} lahu la\q@u{ha}fi\q@i{\q@u{th}}oon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mdclx{Q\q@u{a}la hal \q@u{a}manukum AAalayhi ill\q@u{a} kam\q@u{a} amintukum AAal\q@u{a} akheehi min qablu fa\q@b{A}ll\q@u{a}hu khayrun \q@u{ha}fi\q@i{\q@u{th}}an wahuwa ar\q@u{h}amu a\q@b{l}rr\q@u{ah}imeen\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mdclxi{Walamm\q@u{a} fata\q@u{h}oo mat\q@u{a}AAahum wajadoo bi\q@u{da}AAatahum ruddat ilayhim q\q@u{a}loo y\q@u{a} ab\q@u{a}n\q@u{a} m\q@u{a} nabghee h\q@u{ath}ihi bi\q@u{da}AAatun\q@u{a} ruddat ilayn\q@u{a} wanameeru ahlan\q@u{a} wana\q@u{h}fa\q@i{\q@u{th}}u akh\q@u{a}n\q@u{a} wanazd\q@u{a}du kayla baAAeerin \q@u{tha}lika kaylun yaseer\q@b{un}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mdclxii{Q\q@u{a}la lan orsilahu maAAakum \q@u{h}att\q@u{a} tutooni mawthiqan mina All\q@u{a}hi latatunnanee bihi ill\q@u{a} an yu\q@u{hat}a bikum falamm\q@u{a} \q@u{a}tawhu mawthiqahum q\q@u{a}la All\q@u{a}hu AAal\q@u{a} m\q@u{a} naqoolu wakeel\q@b{un}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mdclxiii{Waq\q@u{a}la y\q@u{a} baniyya l\q@u{a} tadkhuloo min b\q@u{a}bin w\q@u{ah}idin wa\q@b{o}dkhuloo min abw\q@u{a}bin mutafarriqatin wam\q@u{a} oghnee AAankum mina All\q@u{a}hi min shayin ini al\q@u{h}ukmu ill\q@u{a} lill\q@u{a}hi AAalayhi tawakkaltu waAAalayhi falyatawakkali almutawakkiloon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mdclxiv{Walamm\q@u{a} dakhaloo min \q@u{h}aythu amarahum aboohum m\q@u{a} k\q@u{a}na yughnee AAanhum mina All\q@u{a}hi min shayin ill\q@u{a} \q@u{ha}jatan fee nafsi yaAAqooba qa\q@u{da}h\q@u{a} wainnahu la\q@u{th}oo AAilmin lim\q@u{a} AAallamn\q@u{a}hu wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mdclxv{Walamm\q@u{a} dakhaloo AAal\q@u{a} yoosufa \q@u{a}w\q@u{a} ilayhi akh\q@u{a}hu q\q@u{a}la innee an\q@u{a} akhooka fal\q@u{a} tabtais bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mdclxvi{Falamm\q@u{a} jahhazahum bijah\q@u{a}zihim jaAAala a\q@b{l}ssiq\q@u{a}yata fee ra\q@u{h}li akheehi thumma a\q@u{thth}ana mua\q@u{thth}inun ayyatuh\q@u{a} alAAeeru innakum las\q@u{a}riqoon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mdclxvii{Q\q@u{a}loo waaqbaloo AAalayhim m\q@u{atha} tafqidoon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mdclxviii{Q\q@u{a}loo nafqidu \q@u{s}uw\q@u{a}AAa almaliki waliman j\q@u{a}a bihi \q@u{h}imlu baAAeerin waan\q@u{a} bihi zaAAeem\q@b{un}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mdclxix{Q\q@u{a}loo ta\q@b{A}ll\q@u{a}hi laqad AAalimtum m\q@u{a} jin\q@u{a} linufsida fee alar\q@u{d}i wam\q@u{a} kunn\q@u{a} s\q@u{a}riqeen\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mdclxx{Q\q@u{a}loo fam\q@u{a} jaz\q@u{a}ohu in kuntum k\q@u{ath}ibeen\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mdclxxi{Q\q@u{a}loo jaz\q@u{a}ohu man wujida fee ra\q@u{h}lihi fahuwa jaz\q@u{a}ohu ka\q@u{tha}lika najzee a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mdclxxii{Fabadaa biawAAiyatihim qabla wiAA\q@u{a}i akheehi thumma istakhrajah\q@u{a} min wiAA\q@u{a}i akheehi ka\q@u{tha}lika kidn\q@u{a} liyoosufa m\q@u{a} k\q@u{a}na liyakhu\q@u{th}a akh\q@u{a}hu fee deeni almaliki ill\q@u{a} an yash\q@u{a}a All\q@u{a}hu narfaAAu daraj\q@u{a}tin man nash\q@u{a}o wafawqa kulli \q@u{th}ee AAilmin AAaleem\q@b{un}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mdclxxiii{Q\q@u{a}loo in yasriq faqad saraqa akhun lahu min qablu faasarrah\q@u{a} yoosufu fee nafsihi walam yubdih\q@u{a} lahum q\q@u{a}la antum sharrun mak\q@u{a}nan wa\q@b{A}ll\q@u{a}hu aAAlamu bim\q@u{a} ta\q@u{s}ifoon\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mdclxxiv{Q\q@u{a}loo y\q@u{a} ayyuh\q@u{a} alAAazeezu inna lahu aban shaykhan kabeeran fakhu\q@u{th} a\q@u{h}adan\q@u{a} mak\q@u{a}nahu inn\q@u{a} nar\q@u{a}ka mina almu\q@u{h}sineen\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mdclxxv{Q\q@u{a}la maAA\q@u{ath}a All\q@u{a}hi an nakhu\q@u{th}a ill\q@u{a} man wajadn\q@u{a} mat\q@u{a}AAan\q@u{a} AAindahu inn\q@u{a} i\q@u{th}an la\q@i{\q@u{th}}\q@u{a}limoon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mdclxxvi{Falamm\q@u{a} istayasoo minhu khala\q@u{s}oo najiyyan q\q@u{a}la kabeeruhum alam taAAlamoo anna ab\q@u{a}kum qad akha\q@u{th}a AAalaykum mawthiqan mina All\q@u{a}hi wamin qablu m\q@u{a} farra\q@u{t}tum fee yoosufa falan abra\q@u{h}a alar\q@u{d}a \q@u{h}att\q@u{a} ya\q@u{th}ana lee abee aw ya\q@u{h}kuma All\q@u{a}hu lee wahuwa khayru al\q@u{ha}kimeen\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mdclxxvii{IrjiAAoo il\q@u{a} abeekum faqooloo y\q@u{a} ab\q@u{a}n\q@u{a} inna ibnaka saraqa wam\q@u{a} shahidn\q@u{a} ill\q@u{a} bim\q@u{a} AAalimn\q@u{a} wam\q@u{a} kunn\q@u{a} lilghaybi \q@u{ha}fi\q@i{\q@u{th}}een\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mdclxxviii{Wa\q@b{i}sali alqaryata allatee kunn\q@u{a} feeh\q@u{a} wa\q@b{a}lAAeera allatee aqbaln\q@u{a} feeh\q@u{a} wainn\q@u{a} la\q@u{sa}diqoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mdclxxix{Q\q@u{a}la bal sawwalat lakum anfusukum amran fa\q@u{s}abrun jameelun AAas\q@u{a} All\q@u{a}hu an yatiyanee bihim jameeAAan innahu huwa alAAaleemu al\q@u{h}akeem\q@b{u}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mdclxxx{Watawall\q@u{a} AAanhum waq\q@u{a}la y\q@u{a} asaf\q@u{a} AAal\q@u{a} yoosufa wa\q@b{i}bya\q@u{dd}at AAayn\q@u{a}hu mina al\q@u{h}uzni fahuwa ka\q@i{\q@u{th}}eem\q@b{un}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mdclxxxi{Q\q@u{a}loo ta\q@b{A}ll\q@u{a}hi taftao ta\q@u{th}kuru yoosufa \q@u{h}att\q@u{a} takoona \q@u{h}ara\q@u{d}an aw takoona mina alh\q@u{a}likeen\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mdclxxxii{Q\q@u{a}la innam\q@u{a} ashkoo baththee wa\q@u{h}uznee il\q@u{a} All\q@u{a}hi waaAAlamu mina All\q@u{a}hi m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mdclxxxiii{Y\q@u{a} baniyya i\q@u{th}haboo fata\q@u{h}assasoo min yoosufa waakheehi wal\q@u{a} tayasoo min raw\q@u{h}i All\q@u{a}hi innahu l\q@u{a} yayasu min raw\q@u{h}i All\q@u{a}hi ill\q@u{a} alqawmu alk\q@u{a}firoon\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mdclxxxiv{Falamm\q@u{a} dakhaloo AAalayhi q\q@u{a}loo y\q@u{a} ayyuh\q@u{a} alAAazeezu massan\q@u{a} waahlan\q@u{a} a\q@b{l}\q@u{dd}urru wajin\q@u{a} bibi\q@u{da}AAatin muzj\q@u{a}tin faawfi lan\q@u{a} alkayla wata\q@u{s}addaq AAalayn\q@u{a} inna All\q@u{a}ha yajzee almuta\q@u{s}addiqeen\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mdclxxxv{Q\q@u{a}la hal AAalimtum m\q@u{a} faAAaltum biyoosufa waakheehi i\q@u{th} antum j\q@u{a}hiloon\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mdclxxxvi{Q\q@u{a}loo ainnaka laanta yoosufa q\q@u{a}la an\q@u{a} yoosufu wah\q@u{atha} akhee qad manna All\q@u{a}hu AAalayn\q@u{a} innahu man yattaqi waya\q@u{s}bir fainna All\q@u{a}ha l\q@u{a} yu\q@u{d}eeAAu ajra almu\q@u{h}sineen\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mdclxxxvii{Q\q@u{a}loo ta\q@b{A}ll\q@u{a}hi laqad \q@u{a}tharaka All\q@u{a}hu AAalayn\q@u{a} wain kunn\q@u{a} lakh\q@u{at}ieen\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mdclxxxviii{Q\q@u{a}la l\q@u{a} tathreeba AAalaykumu alyawma yaghfiru All\q@u{a}hu lakum wahuwa ar\q@u{h}amu a\q@b{l}rr\q@u{ah}imeen\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mdclxxxix{I\q@u{th}haboo biqamee\q@u{s}ee h\q@u{atha} faalqoohu AAal\q@u{a} wajhi abee yati ba\q@u{s}eeran watoonee biahlikum ajmaAAeen\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mdcxc{Walamm\q@u{a} fa\q@u{s}alati alAAeeru q\q@u{a}la aboohum innee laajidu ree\q@u{h}a yoosufa lawl\q@u{a} an tufannidoon\q@b{i}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mdcxci{Q\q@u{a}loo ta\q@b{A}ll\q@u{a}hi innaka lafee \q@u{d}al\q@u{a}lika alqadeem\q@b{i}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mdcxcii{Falamm\q@u{a} an j\q@u{a}a albasheeru alq\q@u{a}hu AAal\q@u{a} wajhihi fa\q@b{i}rtadda ba\q@u{s}eeran q\q@u{a}la alam aqul lakum innee aAAlamu mina All\q@u{a}hi m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mdcxciii{Q\q@u{a}loo y\q@u{a} ab\q@u{a}n\q@u{a} istaghfir lan\q@u{a} \q@u{th}unooban\q@u{a} inn\q@u{a} kunn\q@u{a} kh\q@u{at}ieen\q@b{a}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mdcxciv{Q\q@u{a}la sawfa astaghfiru lakum rabbee innahu huwa alghafooru a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mdcxcv{Falamm\q@u{a} dakhaloo AAal\q@u{a} yoosufa \q@u{a}w\q@u{a} ilayhi abawayhi waq\q@u{a}la odkhuloo mi\q@u{s}ra in sh\q@u{a}a All\q@u{a}hu \q@u{a}mineen\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mdcxcvi{WarafaAAa abawayhi AAal\q@u{a} alAAarshi wakharroo lahu sujjadan waq\q@u{a}la y\q@u{a} abati h\q@u{atha} taweelu ruy\q@u{a}ya min qablu qad jaAAalah\q@u{a} rabbee \q@u{h}aqqan waqad a\q@u{h}sana bee i\q@u{th} akhrajanee mina a\q@b{l}ssijni waj\q@u{a}a bikum mina albadwi min baAAdi an nazagha a\q@b{l}shshay\q@u{ta}nu baynee wabayna ikhwatee inna rabbee la\q@u{t}eefun lim\q@u{a} yash\q@u{a}o innahu huwa alAAaleemu al\q@u{h}akeem\q@b{u}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mdcxcvii{Rabbi qad \q@u{a}taytanee mina almulki waAAallamtanee min taweeli ala\q@u{ha}deethi f\q@u{at}ira a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i anta waliyyee fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati tawaffanee musliman waal\q@u{h}iqnee bi\q@b{al}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mdcxcviii{\q@u{Tha}lika min anb\q@u{a}i alghaybi noo\q@u{h}eehi ilayka wam\q@u{a} kunta ladayhim i\q@u{th} ajmaAAoo amrahum wahum yamkuroon\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mdcxcix{Wam\q@u{a} aktharu a\q@b{l}nn\q@u{a}si walaw \q@u{h}ara\q@u{s}ta bimumineen\q@b{a}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mdcc{Wam\q@u{a} tasaluhum AAalayhi min ajrin in huwa ill\q@u{a} \q@u{th}ikrun lilAA\q@u{a}lameen\q@b{a}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mdcci{Wakaayyin min \q@u{a}yatin fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i yamurroona AAalayh\q@u{a} wahum AAanh\q@u{a} muAAri\q@u{d}oon\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mdccii{Wam\q@u{a} yuminu aktharuhum bi\q@b{A}ll\q@u{a}hi ill\q@u{a} wahum mushrikoon\q@b{a}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mdcciii{Afaaminoo an tatiyahum gh\q@u{a}shiyatun min AAa\q@u{tha}bi All\q@u{a}hi aw tatiyahumu a\q@b{l}ss\q@u{a}AAatu baghtatan wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mdcciv{Qul h\q@u{ath}ihi sabeelee adAAoo il\q@u{a} All\q@u{a}hi AAal\q@u{a} ba\q@u{s}eeratin an\q@u{a} wamani ittabaAAanee wasub\q@u{ha}na All\q@u{a}hi wam\q@u{a} an\q@u{a} mina almushrikeen\q@b{a}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mdccv{Wam\q@u{a} arsaln\q@u{a} min qablika ill\q@u{a} rij\q@u{a}lan noo\q@u{h}ee ilayhim min ahli alqur\q@u{a} afalam yaseeroo fee alar\q@u{d}i fayan\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu alla\q@u{th}eena min qablihim walad\q@u{a}ru al\q@u{a}khirati khayrun lilla\q@u{th}eena ittaqaw afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mdccvi{\q@u{H}att\q@u{a} i\q@u{tha} istayasa a\q@b{l}rrusulu wa\q@i{\q@u{th}}annoo annahum qad ku\q@u{th}iboo j\q@u{a}ahum na\q@u{s}run\q@u{a} fanujjiya man nash\q@u{a}o wal\q@u{a} yuraddu basun\q@u{a} AAani alqawmi almujrimeen\q@b{a}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mdccvii{Laqad k\q@u{a}na fee qa\q@u{s}a\q@u{s}ihim AAibratun liolee alalb\q@u{a}bi m\q@u{a} k\q@u{a}na \q@u{h}adeethan yuftar\q@u{a} wal\q@u{a}kin ta\q@u{s}deeqa alla\q@u{th}ee bayna yadayhi wataf\q@u{s}eela kulli shayin wahudan wara\q@u{h}matan liqawmin yuminoon\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mdccviii{\basmalahlt Alifl\q@u{a}mmeemr\q@u{a} tilka \q@u{a}y\q@u{a}tu alkit\q@u{a}bi wa\q@b{a}lla\q@u{th}ee onzila ilayka min rabbika al\q@u{h}aqqu wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yuminoon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mdccix{All\q@u{a}hu alla\q@u{th}ee rafaAAa a\q@b{l}ssam\q@u{a}w\q@u{a}ti bighayri AAamadin tarawnah\q@u{a} thumma istaw\q@u{a} AAal\q@u{a} alAAarshi wasakhkhara a\q@b{l}shshamsa wa\q@b{a}lqamara kullun yajree liajalin musamman yudabbiru alamra yufa\q@u{ss}ilu al\q@u{a}y\q@u{a}ti laAAallakum biliq\q@u{a}i rabbikum tooqinoon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mdccx{Wahuwa alla\q@u{th}ee madda alar\q@u{d}a wajaAAala feeh\q@u{a} raw\q@u{a}siya waanh\q@u{a}ran wamin kulli a\q@b{l}ththamar\q@u{a}ti jaAAala feeh\q@u{a} zawjayni ithnayni yughshee allayla a\q@b{l}nnah\q@u{a}ra inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yatafakkaroon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mdccxi{Wafee alar\q@u{d}i qi\q@u{t}aAAun mutaj\q@u{a}wir\q@u{a}tun wajann\q@u{a}tun min aAAn\q@u{a}bin wazarAAun wanakheelun \q@u{s}inw\q@u{a}nun waghayru \q@u{s}inw\q@u{a}nin yusq\q@u{a} bim\q@u{a}in w\q@u{ah}idin wanufa\q@u{dd}ilu baAA\q@u{d}ah\q@u{a} AAal\q@u{a} baAA\q@u{d}in fee alokuli inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yaAAqiloon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mdccxii{Wain taAAjab faAAajabun qawluhum ai\q@u{tha} kunn\q@u{a} tur\q@u{a}ban ainn\q@u{a} lafee khalqin jadeedin ol\q@u{a}ika alla\q@u{th}eena kafaroo birabbihim waol\q@u{a}ika alaghl\q@u{a}lu fee aAAn\q@u{a}qihim waol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mdccxiii{WayastaAAjiloonaka bi\q@b{al}ssayyiati qabla al\q@u{h}asanati waqad khalat min qablihimu almathul\q@u{a}tu wainna rabbaka la\q@u{th}oo maghfiratin li\q@b{l}nn\q@u{a}si AAal\q@u{a} \q@i{\q@u{th}}ulmihim wainna rabbaka lashadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mdccxiv{Wayaqoolu alla\q@u{th}eena kafaroo lawl\q@u{a} onzila AAalayhi \q@u{a}yatun min rabbihi innam\q@u{a} anta mun\q@u{th}irun walikulli qawmin h\q@u{a}d\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mdccxv{All\q@u{a}hu yaAAlamu m\q@u{a} ta\q@u{h}milu kullu onth\q@u{a} wam\q@u{a} taghee\q@u{d}u alar\q@u{ha}mu wam\q@u{a} tazd\q@u{a}du wakullu shayin AAindahu bimiqd\q@u{a}r\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mdccxvi{AA\q@u{a}limu alghaybi wa\q@b{al}shshah\q@u{a}dati alkabeeru almutaAA\q@u{a}l\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mdccxvii{Saw\q@u{a}on minkum man asarra alqawla waman jahara bihi waman huwa mustakhfin bi\q@b{a}llayli was\q@u{a}ribun bi\q@b{al}nnah\q@u{a}r\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mdccxviii{Lahu muAAaqqib\q@u{a}tun min bayni yadayhi wamin khalfihi ya\q@u{h}fa\q@i{\q@u{th}}oonahu min amri All\q@u{a}hi inna All\q@u{a}ha l\q@u{a} yughayyiru m\q@u{a} biqawmin \q@u{h}att\q@u{a} yughayyiroo m\q@u{a} bianfusihim wai\q@u{tha} ar\q@u{a}da All\q@u{a}hu biqawmin sooan fal\q@u{a} maradda lahu wam\q@u{a} lahum min doonihi min w\q@u{a}l\q@b{in}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mdccxix{Huwa alla\q@u{th}ee yureekumu albarqa khawfan wa\q@u{t}amaAAan wayunshio a\q@b{l}ssa\q@u{ha}ba a\q@b{l}ththiq\q@u{a}l\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mdccxx{Wayusabbi\q@u{h}u a\q@b{l}rraAAdu bi\q@u{h}amdihi wa\q@b{a}lmal\q@u{a}ikatu min kheefatihi wayursilu a\q@b{l}\q@u{ss}aw\q@u{a}AAiqa fayu\q@u{s}eebu bih\q@u{a} man yash\q@u{a}o wahum yuj\q@u{a}diloona fee All\q@u{a}hi wahuwa shadeedu almi\q@u{ha}l\q@b{i}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mdccxxi{Lahu daAAwatu al\q@u{h}aqqi wa\q@b{a}lla\q@u{th}eena yadAAoona min doonihi l\q@u{a} yastajeeboona lahum bishayin ill\q@u{a} kab\q@u{a}si\q@u{t}i kaffayhi il\q@u{a} alm\q@u{a}i liyablugha f\q@u{a}hu wam\q@u{a} huwa bib\q@u{a}lighihi wam\q@u{a} duAA\q@u{a}o alk\q@u{a}fireena ill\q@u{a} fee \q@u{d}al\q@u{a}l\q@b{in}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mdccxxii{Walill\q@u{a}hi yasjudu man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i \q@u{t}awAAan wakarhan wa\q@i{\q@u{th}}il\q@u{a}luhum bi\q@b{a}lghuduwwi wa\q@b{a}l\q@u{asa}l\q@b{i}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mdccxxiii{Qul man rabbu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i quli All\q@u{a}hu qul afa\q@b{i}ttakha\q@u{th}tum min doonihi awliy\q@u{a}a l\q@u{a} yamlikoona lianfusihim nafAAan wal\q@u{a} \q@u{d}arran qul hal yastawee alaAAm\q@u{a} wa\q@b{a}lba\q@u{s}eeru am hal tastawee a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}tu wa\q@b{al}nnooru am jaAAaloo lill\q@u{a}hi shurak\q@u{a}a khalaqoo kakhalqihi fatash\q@u{a}baha alkhalqu AAalayhim quli All\q@u{a}hu kh\q@u{a}liqu kulli shayin wahuwa alw\q@u{ah}idu alqahh\q@u{a}r\q@b{u}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mdccxxiv{Anzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an fas\q@u{a}lat awdiyatun biqadarih\q@u{a} fa\q@b{i}\q@u{h}tamala a\q@b{l}ssaylu zabadan r\q@u{a}biyan wamimm\q@u{a} yooqidoona AAalayhi fee a\q@b{l}nn\q@u{a}ri ibtigh\q@u{a}a \q@u{h}ilyatin aw mat\q@u{a}AAin zabadun mithluhu ka\q@u{tha}lika ya\q@u{d}ribu All\q@u{a}hu al\q@u{h}aqqa wa\q@b{a}lb\q@u{at}ila faamm\q@u{a} a\q@b{l}zzabadu faya\q@u{th}habu juf\q@u{a}an waamm\q@u{a} m\q@u{a} yanfaAAu a\q@b{l}nn\q@u{a}sa fayamkuthu fee alar\q@u{d}i ka\q@u{tha}lika ya\q@u{d}ribu All\q@u{a}hu alamth\q@u{a}l\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mdccxxv{Lilla\q@u{th}eena istaj\q@u{a}boo lirabbihimu al\q@u{h}usn\q@u{a} wa\q@b{a}lla\q@u{th}eena lam yastajeeboo lahu law anna lahum m\q@u{a} fee alar\q@u{d}i jameeAAan wamithlahu maAAahu la\q@b{i}ftadaw bihi ol\q@u{a}ika lahum sooo al\q@u{h}is\q@u{a}bi wamaw\q@u{a}hum jahannamu wabisa almih\q@u{a}d\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mdccxxvi{Afaman yaAAlamu annam\q@u{a} onzila ilayka min rabbika al\q@u{h}aqqu kaman huwa aAAm\q@u{a} innam\q@u{a} yata\q@u{th}akkaru oloo alalb\q@u{a}b\q@b{i}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mdccxxvii{Alla\q@u{th}eena yoofoona biAAahdi All\q@u{a}hi wal\q@u{a} yanqu\q@u{d}oona almeeth\q@u{a}q\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mdccxxviii{Wa\q@b{a}lla\q@u{th}eena ya\q@u{s}iloona m\q@u{a} amara All\q@u{a}hu bihi an yoo\q@u{s}ala wayakhshawna rabbahum wayakh\q@u{a}foona sooa al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mdccxxix{Wa\q@b{a}lla\q@u{th}eena \q@u{s}abaroo ibtigh\q@u{a}a wajhi rabbihim waaq\q@u{a}moo a\q@b{l}\q@u{ss}al\q@u{a}ta waanfaqoo mimm\q@u{a} razaqn\q@u{a}hum sirran waAAal\q@u{a}niyatan wayadraoona bi\q@b{a}l\q@u{h}asanati a\q@b{l}ssayyiata ol\q@u{a}ika lahum AAuqb\q@u{a} a\q@b{l}dd\q@u{a}r\q@b{i}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mdccxxx{Jann\q@u{a}tu AAadnin yadkhuloonah\q@u{a} waman \q@u{s}ala\q@u{h}a min \q@u{a}b\q@u{a}ihim waazw\q@u{a}jihim wa\q@u{th}urriyy\q@u{a}tihim wa\q@b{a}lmal\q@u{a}ikatu yadkhuloona AAalayhim min kulli b\q@u{a}b\q@b{in}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mdccxxxi{Sal\q@u{a}mun AAalaykum bim\q@u{a} \q@u{s}abartum faniAAma AAuqb\q@u{a} a\q@b{l}dd\q@u{a}r\q@b{i}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mdccxxxii{Wa\q@b{a}lla\q@u{th}eena yanqu\q@u{d}oona AAahda All\q@u{a}hi min baAAdi meeth\q@u{a}qihi wayaq\q@u{t}aAAoona m\q@u{a} amara All\q@u{a}hu bihi an yoo\q@u{s}ala wayufsidoona fee alar\q@u{d}i ol\q@u{a}ika lahumu allaAAnatu walahum sooo a\q@b{l}dd\q@u{a}r\q@b{i}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mdccxxxiii{All\q@u{a}hu yabsu\q@u{t}u a\q@b{l}rrizqa liman yash\q@u{a}o wayaqdiru wafari\q@u{h}oo bi\q@b{a}l\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wam\q@u{a} al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} fee al\q@u{a}khirati ill\q@u{a} mat\q@u{a}AA\q@b{un}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mdccxxxiv{Wayaqoolu alla\q@u{th}eena kafaroo lawl\q@u{a} onzila AAalayhi \q@u{a}yatun min rabbihi qul inna All\q@u{a}ha yu\q@u{d}illu man yash\q@u{a}o wayahdee ilayhi man an\q@u{a}b\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mdccxxxv{Alla\q@u{th}eena \q@u{a}manoo wata\q@u{t}mainnu quloobuhum bi\q@u{th}ikri All\q@u{a}hi al\q@u{a} bi\q@u{th}ikri All\q@u{a}hi ta\q@u{t}mainnu alquloob\q@b{u}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mdccxxxvi{Alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti \q@u{t}oob\q@u{a} lahum wa\q@u{h}usnu ma\q@u{a}b\q@b{in}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mdccxxxvii{Ka\q@u{tha}lika arsaln\q@u{a}ka fee ommatin qad khalat min qablih\q@u{a} omamun litatluwa AAalayhimu alla\q@u{th}ee aw\q@u{h}ayn\q@u{a} ilayka wahum yakfuroona bi\q@b{al}rra\q@u{h}m\q@u{a}ni qul huwa rabbee l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa AAalayhi tawakkaltu wailayhi mat\q@u{a}b\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mdccxxxviii{Walaw anna qur\q@u{a}nan suyyirat bihi aljib\q@u{a}lu aw qu\q@u{tt}iAAat bihi alar\q@u{d}u aw kullima bihi almawt\q@u{a} bal lill\q@u{a}hi alamru jameeAAan afalam yayasi alla\q@u{th}eena \q@u{a}manoo an law yash\q@u{a}o All\q@u{a}hu lahad\q@u{a} a\q@b{l}nn\q@u{a}sa jameeAAan wal\q@u{a} yaz\q@u{a}lu alla\q@u{th}eena kafaroo tu\q@u{s}eebuhum bim\q@u{a} \q@u{s}anaAAoo q\q@u{a}riAAatun aw ta\q@u{h}ullu qareeban min d\q@u{a}rihim \q@u{h}att\q@u{a} yatiya waAAdu All\q@u{a}hi inna All\q@u{a}ha l\q@u{a} yukhlifu almeeAA\q@u{a}d\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mdccxxxix{Walaqadi istuhzia birusulin min qablika faamlaytu lilla\q@u{th}eena kafaroo thumma akha\q@u{th}tuhum fakayfa k\q@u{a}na AAiq\q@u{a}b\q@b{i}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mdccxl{Afaman huwa q\q@u{a}imun AAal\q@u{a} kulli nafsin bim\q@u{a} kasabat wajaAAaloo lill\q@u{a}hi shurak\q@u{a}a qul sammoohum am tunabbioonahu bim\q@u{a} l\q@u{a} yaAAlamu fee alar\q@u{d}i am bi\q@i{\q@u{th}}\q@u{a}hirin mina alqawli bal zuyyina lilla\q@u{th}eena kafaroo makruhum wa\q@u{s}uddoo AAani a\q@b{l}ssabeeli waman yu\q@u{d}lili All\q@u{a}hu fam\q@u{a} lahu min h\q@u{a}d\q@b{in}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mdccxli{Lahum AAa\q@u{tha}bun fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} walaAAa\q@u{tha}bu al\q@u{a}khirati ashaqqu wam\q@u{a} lahum mina All\q@u{a}hi min w\q@u{a}q\q@b{in}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mdccxlii{Mathalu aljannati allatee wuAAida almuttaqoona tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru okuluh\q@u{a} d\q@u{a}imun wa\q@i{\q@u{th}}illuh\q@u{a} tilka AAuqb\q@u{a} alla\q@u{th}eena ittaqaw waAAuqb\q@u{a} alk\q@u{a}fireena a\q@b{l}nn\q@u{a}r\q@b{u}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mdccxliii{Wa\q@b{a}lla\q@u{th}eena \q@u{a}tayn\q@u{a}humu alkit\q@u{a}ba yafra\q@u{h}oona bim\q@u{a} onzila ilayka wamina ala\q@u{h}z\q@u{a}bi man yunkiru baAA\q@u{d}ahu qul innam\q@u{a} omirtu an aAAbuda All\q@u{a}ha wal\q@u{a} oshrika bihi ilayhi adAAoo wailayhi ma\q@u{a}b\q@b{i}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mdccxliv{Waka\q@u{tha}lika anzaln\q@u{a}hu \q@u{h}ukman AAarabiyyan walaini ittabaAAta ahw\q@u{a}ahum baAAda m\q@u{a} j\q@u{a}aka mina alAAilmi m\q@u{a} laka mina All\q@u{a}hi min waliyyin wal\q@u{a} w\q@u{a}q\q@b{in}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mdccxlv{Walaqad arsaln\q@u{a} rusulan min qablika wajaAAaln\q@u{a} lahum azw\q@u{a}jan wa\q@u{th}urriyyatan wam\q@u{a} k\q@u{a}na lirasoolin an yatiya bi\q@u{a}yatin ill\q@u{a} bii\q@u{th}ni All\q@u{a}hi likulli ajalin kit\q@u{a}b\q@b{un}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mdccxlvi{Yam\q@u{h}oo All\q@u{a}hu m\q@u{a} yash\q@u{a}o wayuthbitu waAAindahu ommu alkit\q@u{a}b\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mdccxlvii{Wain m\q@u{a} nuriyannaka baAA\q@u{d}a alla\q@u{th}ee naAAiduhum aw natawaffayannaka fainnam\q@u{a} AAalayka albal\q@u{a}ghu waAAalayn\q@u{a} al\q@u{h}is\q@u{a}b\q@b{u}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mdccxlviii{Awalam yaraw ann\q@u{a} natee alar\q@u{d}a nanqu\q@u{s}uh\q@u{a} min a\q@u{t}r\q@u{a}fih\q@u{a} wa\q@b{A}ll\q@u{a}hu ya\q@u{h}kumu l\q@u{a} muAAaqqiba li\q@u{h}ukmihi wahuwa sareeAAu al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mdccxlix{Waqad makara alla\q@u{th}eena min qablihim falill\q@u{a}hi almakru jameeAAan yaAAlamu m\q@u{a} taksibu kullu nafsin wasayaAAlamu alkuff\q@u{a}ru liman AAuqb\q@u{a} a\q@b{l}dd\q@u{a}r\q@b{i}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mdccl{Wayaqoolu alla\q@u{th}eena kafaroo lasta mursalan qul kaf\q@u{a} bi\q@b{A}ll\q@u{a}hi shaheedan baynee wabaynakum waman AAindahu AAilmu alkit\q@u{a}b\q@b{i}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mdccli{\basmalahlt Alifl\q@u{a}mr\q@u{a} kit\q@u{a}bun anzaln\q@u{a}hu ilayka litukhrija a\q@b{l}nn\q@u{a}sa mina a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti il\q@u{a} a\q@b{l}nnoori bii\q@u{th}ni rabbihim il\q@u{a} \q@u{s}ir\q@u{at}i alAAazeezi al\q@u{h}ameed\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mdcclii{All\q@u{a}hi alla\q@u{th}ee lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wawaylun lilk\q@u{a}fireena min AAa\q@u{tha}bin shadeed\q@b{in}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mdccliii{Alla\q@u{th}eena yasta\q@u{h}ibboona al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a} AAal\q@u{a} al\q@u{a}khirati waya\q@u{s}uddoona AAan sabeeli All\q@u{a}hi wayabghoonah\q@u{a} AAiwajan ol\q@u{a}ika fee \q@u{d}al\q@u{a}lin baAAeed\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mdccliv{Wam\q@u{a} arsaln\q@u{a} min rasoolin ill\q@u{a} bilis\q@u{a}ni qawmihi liyubayyina lahum fayu\q@u{d}illu All\q@u{a}hu man yash\q@u{a}o wayahdee man yash\q@u{a}o wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mdcclv{Walaqad arsaln\q@u{a} moos\q@u{a} bi\q@u{a}y\q@u{a}tin\q@u{a} an akhrij qawmaka mina a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti il\q@u{a} a\q@b{l}nnoori wa\q@u{th}akkirhum biayy\q@u{a}mi All\q@u{a}hi inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin likulli \q@u{s}abb\q@u{a}rin shakoor\q@b{in}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mdcclvi{Wai\q@u{th} q\q@u{a}la moos\q@u{a} liqawmihi o\q@u{th}kuroo niAAmata All\q@u{a}hi AAalaykum i\q@u{th} anj\q@u{a}kum min \q@u{a}li firAAawna yasoomoonakum sooa alAAa\q@u{tha}bi wayu\q@u{th}abbi\q@u{h}oona abn\q@u{a}akum wayasta\q@u{h}yoona nis\q@u{a}akum wafee \q@u{tha}likum bal\q@u{a}on min rabbikum AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mdcclvii{Wai\q@u{th} taa\q@u{thth}ana rabbukum lain shakartum laazeedannakum walain kafartum inna AAa\q@u{tha}bee lashadeed\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mdcclviii{Waq\q@u{a}la moos\q@u{a} in takfuroo antum waman fee alar\q@u{d}i jameeAAan fainna All\q@u{a}ha laghaniyyun \q@u{h}ameed\q@b{un}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mdcclix{Alam yatikum nabao alla\q@u{th}eena min qablikum qawmi noo\q@u{h}in waAA\q@u{a}din wathamooda wa\q@b{a}lla\q@u{th}eena min baAAdihim l\q@u{a} yaAAlamuhum ill\q@u{a} All\q@u{a}hu j\q@u{a}athum rusuluhum bi\q@b{a}lbayyin\q@u{a}ti faraddoo aydiyahum fee afw\q@u{a}hihim waq\q@u{a}loo inn\q@u{a} kafarn\q@u{a} bim\q@u{a} orsiltum bihi wainn\q@u{a} lafee shakkin mimm\q@u{a} tadAAoonan\q@u{a} ilayhi mureeb\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mdcclx{Q\q@u{a}lat rusuluhum afee All\q@u{a}hi shakkun f\q@u{at}iri a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i yadAAookum liyaghfira lakum min \q@u{th}unoobikum wayuakhkhirakum il\q@u{a} ajalin musamman q\q@u{a}loo in antum ill\q@u{a} basharun mithlun\q@u{a} tureedoona an ta\q@u{s}uddoon\q@u{a} AAamm\q@u{a} k\q@u{a}na yaAAbudu \q@u{a}b\q@u{a}on\q@u{a} fatoon\q@u{a} bisul\q@u{ta}nin mubeen\q@b{in}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mdcclxi{Q\q@u{a}lat lahum rusuluhum in na\q@u{h}nu ill\q@u{a} basharun mithlukum wal\q@u{a}kinna All\q@u{a}ha yamunnu AAal\q@u{a} man yash\q@u{a}o min AAib\q@u{a}dihi wam\q@u{a} k\q@u{a}na lan\q@u{a} an natiyakum bisul\q@u{ta}nin ill\q@u{a} bii\q@u{th}ni All\q@u{a}hi waAAal\q@u{a} All\q@u{a}hi falyatawakkali almuminoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mdcclxii{Wam\q@u{a} lan\q@u{a} all\q@u{a} natawakkala AAal\q@u{a} All\q@u{a}hi waqad had\q@u{a}n\q@u{a} subulan\q@u{a} walana\q@u{s}biranna AAal\q@u{a} m\q@u{a} \q@u{ath}aytumoon\q@u{a} waAAal\q@u{a} All\q@u{a}hi falyatawakkali almutawakkiloon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mdcclxiii{Waq\q@u{a}la alla\q@u{th}eena kafaroo lirusulihim lanukhrijannakum min ar\q@u{d}in\q@u{a} aw lataAAoodunna fee millatin\q@u{a} faaw\q@u{ha} ilayhim rabbuhum lanuhlikanna a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mdcclxiv{Walanuskinannakumu alar\q@u{d}a min baAAdihim \q@u{tha}lika liman kh\q@u{a}fa maq\q@u{a}mee wakh\q@u{a}fa waAAeed\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mdcclxv{Wa\q@b{i}stafta\q@u{h}oo wakh\q@u{a}ba kullu jabb\q@u{a}rin AAaneed\q@b{in}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mdcclxvi{Min war\q@u{a}ihi jahannamu wayusq\q@u{a} min m\q@u{a}in \q@u{s}adeed\q@b{in}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mdcclxvii{YatajarraAAuhu wal\q@u{a} yak\q@u{a}du yuseeghuhu wayateehi almawtu min kulli mak\q@u{a}nin wam\q@u{a} huwa bimayyitin wamin war\q@u{a}ihi AAa\q@u{tha}bun ghalee\q@i{\q@u{th}}\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mdcclxviii{Mathalu alla\q@u{th}eena kafaroo birabbihim aAAm\q@u{a}luhum karam\q@u{a}din ishtaddat bihi a\q@b{l}rree\q@u{h}u fee yawmin AA\q@u{as}ifin l\q@u{a} yaqdiroona mimm\q@u{a} kasaboo AAal\q@u{a} shayin \q@u{tha}lika huwa a\q@b{l}\q@u{dd}al\q@u{a}lu albaAAeed\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mdcclxix{Alam tara anna All\q@u{a}ha khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a bi\q@b{a}l\q@u{h}aqqi in yasha yu\q@u{th}hibkum wayati bikhalqin jadeed\q@b{in}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mdcclxx{Wam\q@u{a} \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi biAAazeez\q@b{in}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mdcclxxi{Wabarazoo lill\q@u{a}hi jameeAAan faq\q@u{a}la a\q@b{l}\q@u{dd}uAAaf\q@u{a}o lilla\q@u{th}eena istakbaroo inn\q@u{a} kunn\q@u{a} lakum tabaAAan fahal antum mughnoona AAann\q@u{a} min AAa\q@u{tha}bi All\q@u{a}hi min shayin q\q@u{a}loo law had\q@u{a}n\q@u{a} All\q@u{a}hu lahadayn\q@u{a}kum saw\q@u{a}on AAalayn\q@u{a} ajaziAAn\q@u{a} am \q@u{s}abarn\q@u{a} m\q@u{a} lan\q@u{a} min ma\q@u{h}ee\q@u{s}\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mdcclxxii{Waq\q@u{a}la a\q@b{l}shshay\q@u{ta}nu lamm\q@u{a} qu\q@u{d}iya alamru inna All\q@u{a}ha waAAadakum waAAda al\q@u{h}aqqi wawaAAadtukum faakhlaftukum wam\q@u{a} k\q@u{a}na liya AAalaykum min sul\q@u{ta}nin ill\q@u{a} an daAAawtukum fa\q@b{i}stajabtum lee fal\q@u{a} taloomoonee waloomoo anfusakum m\q@u{a} an\q@u{a} bimu\q@u{s}rikhikum wam\q@u{a} antum bimu\q@u{s}rikhiyya innee kafartu bim\q@u{a} ashraktumooni min qablu inna a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena lahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mdcclxxiii{Waodkhila alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} bii\q@u{th}ni rabbihim ta\q@u{h}iyyatuhum feeh\q@u{a} sal\q@u{a}m\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mdcclxxiv{Alam tara kayfa \q@u{d}araba All\q@u{a}hu mathalan kalimatan \q@u{t}ayyibatan kashajaratin \q@u{t}ayyibatin a\q@u{s}luh\q@u{a} th\q@u{a}bitun wafarAAuh\q@u{a} fee a\q@b{l}ssam\q@u{a}\q@b{i}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mdcclxxv{Tutee okulah\q@u{a} kulla \q@u{h}eenin bii\q@u{th}ni rabbih\q@u{a} waya\q@u{d}ribu All\q@u{a}hu alamth\q@u{a}la li\q@b{l}nn\q@u{a}si laAAallahum yata\q@u{th}akkaroon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mdcclxxvi{Wamathalu kalimatin khabeethatin kashajaratin khabeethatin ijtuththat min fawqi alar\q@u{d}i m\q@u{a} lah\q@u{a} min qar\q@u{a}r\q@b{in}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mdcclxxvii{Yuthabbitu All\q@u{a}hu alla\q@u{th}eena \q@u{a}manoo bi\q@b{a}lqawli a\q@b{l}thth\q@u{a}biti fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wafee al\q@u{a}khirati wayu\q@u{d}illu All\q@u{a}hu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena wayafAAalu All\q@u{a}hu m\q@u{a} yash\q@u{a}\q@b{o}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mdcclxxviii{Alam tara il\q@u{a} alla\q@u{th}eena baddaloo niAAmata All\q@u{a}hi kufran waa\q@u{h}alloo qawmahum d\q@u{a}ra albaw\q@u{a}r\q@b{i}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mdcclxxix{Jahannama ya\q@u{s}lawnah\q@u{a} wabisa alqar\q@u{a}r\q@b{u}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mdcclxxx{WajaAAaloo lill\q@u{a}hi and\q@u{a}dan liyu\q@u{d}illoo AAan sabeelihi qul tamattaAAoo fainna ma\q@u{s}eerakum il\q@u{a} a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mdcclxxxi{Qul liAAib\q@u{a}diya alla\q@u{th}eena \q@u{a}manoo yuqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wayunfiqoo mimm\q@u{a} razaqn\q@u{a}hum sirran waAAal\q@u{a}niyatan min qabli an yatiya yawmun l\q@u{a} bayAAun feehi wal\q@u{a} khil\q@u{a}l\q@b{un}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mdcclxxxii{All\q@u{a}hu alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a waanzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faakhraja bihi mina a\q@b{l}ththamar\q@u{a}ti rizqan lakum wasakhkhara lakumu alfulka litajriya fee alba\q@u{h}ri biamrihi wasakhkhara lakumu alanh\q@u{a}r\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mdcclxxxiii{Wasakhkhara lakumu a\q@b{l}shshamsa wa\q@b{a}lqamara d\q@u{a}ibayni wasakhkhara lakumu allayla wa\q@b{al}nnah\q@u{a}r\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mdcclxxxiv{Wa\q@u{a}t\q@u{a}kum min kulli m\q@u{a} saaltumoohu wain taAAuddoo niAAmata All\q@u{a}hi l\q@u{a} tu\q@u{hs}ooh\q@u{a} inna alins\q@u{a}na la\q@i{\q@u{th}}aloomun kaff\q@u{a}r\q@b{un}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mdcclxxxv{Wai\q@u{th} q\q@u{a}la ibr\q@u{a}heemu rabbi ijAAal h\q@u{atha} albalada \q@u{a}minan wa\q@b{o}jnubnee wabaniyya an naAAbuda ala\q@u{s}n\q@u{a}m\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mdcclxxxvi{Rabbi innahunna a\q@u{d}lalna katheeran mina a\q@b{l}nn\q@u{a}si faman tabiAAanee fainnahu minnee waman AAa\q@u{sa}nee fainnaka ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mdcclxxxvii{Rabban\q@u{a} innee askantu min \q@u{th}urriyyatee biw\q@u{a}din ghayri \q@u{th}ee zarAAin AAinda baytika almu\q@u{h}arrami rabban\q@u{a} liyuqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta fa\q@b{i}jAAal afidatan mina a\q@b{l}nn\q@u{a}si tahwee ilayhim wa\q@b{o}rzuqhum mina a\q@b{l}ththamar\q@u{a}ti laAAallahum yashkuroon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mdcclxxxviii{Rabban\q@u{a} innaka taAAlamu m\q@u{a} nukhfee wam\q@u{a} nuAAlinu wam\q@u{a} yakhf\q@u{a} AAal\q@u{a} All\q@u{a}hi min shayin fee alar\q@u{d}i wal\q@u{a} fee a\q@b{l}ssam\q@u{a}\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mdcclxxxix{Al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee wahaba lee AAal\q@u{a} alkibari ism\q@u{a}AAeela wais\q@u{ha}qa inna rabbee lasameeAAu a\q@b{l}dduAA\q@u{a}\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mdccxc{Rabbi ijAAalnee muqeema a\q@b{l}\q@u{ss}al\q@u{a}ti wamin \q@u{th}urriyyatee rabban\q@u{a} wtaqabbal duAA\q@u{a}\q@b{i}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mdccxci{Rabban\q@u{a} ighfir lee waliw\q@u{a}lidayya walilmumineena yawma yaqoomu al\q@u{h}is\q@u{a}b\q@b{u}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mdccxcii{Wal\q@u{a} ta\q@u{h}sabanna All\q@u{a}ha gh\q@u{a}filan AAamm\q@u{a} yaAAmalu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoona innam\q@u{a} yuakhkhiruhum liyawmin tashkha\q@u{s}u feehi alab\q@u{sa}r\q@b{u}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mdccxciii{Muh\q@u{t}iAAeena muqniAAee ruoosihim l\q@u{a} yartaddu ilayhim \q@u{t}arfuhum waafidatuhum haw\q@u{a}\q@b{on}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mdccxciv{Waan\q@u{th}iri a\q@b{l}nn\q@u{a}sa yawma yateehimu alAAa\q@u{tha}bu fayaqoolu alla\q@u{th}eena \q@i{\q@u{th}}alamoo rabban\q@u{a} akhkhirn\q@u{a} il\q@u{a} ajalin qareebin nujib daAAwataka wanattabiAAi a\q@b{l}rrusula awalam takoonoo aqsamtum min qablu m\q@u{a} lakum min zaw\q@u{a}l\q@b{in}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mdccxcv{Wasakantum fee mas\q@u{a}kini alla\q@u{th}eena \q@i{\q@u{th}}alamoo anfusahum watabayyana lakum kayfa faAAaln\q@u{a} bihim wa\q@u{d}arabn\q@u{a} lakumu alamth\q@u{a}l\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mdccxcvi{Waqad makaroo makrahum waAAinda All\q@u{a}hi makruhum wain k\q@u{a}na makruhum litazoola minhu aljib\q@u{a}l\q@b{u}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mdccxcvii{Fal\q@u{a} ta\q@u{h}sabanna All\q@u{a}ha mukhlifa waAAdihi rusulahu inna All\q@u{a}ha AAazeezun \q@u{th}oo intiq\q@u{a}m\q@b{in}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mdccxcviii{Yawma tubaddalu alar\q@u{d}u ghayra alar\q@u{d}i wa\q@b{al}ssam\q@u{a}w\q@u{a}tu wabarazoo lill\q@u{a}hi alw\q@u{ah}idi alqahh\q@u{a}r\q@b{i}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mdccxcix{Watar\q@u{a} almujrimeena yawmai\q@u{th}in muqarraneena fee ala\q@u{s}f\q@u{a}d\q@b{i}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mdccc{Sar\q@u{a}beeluhum min qa\q@u{t}r\q@u{a}nin wataghsh\q@u{a} wujoohahumu a\q@b{l}nn\q@u{a}r\q@b{u}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mdccci{Liyajziya All\q@u{a}hu kulla nafsin m\q@u{a} kasabat inna All\q@u{a}ha sareeAAu al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mdcccii{H\q@u{atha} bal\q@u{a}ghun li\q@b{l}nn\q@u{a}si waliyun\q@u{th}aroo bihi waliyaAAlamoo annam\q@u{a} huwa il\q@u{a}hun w\q@u{ah}idun waliya\q@u{thth}akkara oloo alalb\q@u{a}b\q@b{i}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mdccciii{\basmalahlt Alifl\q@u{a}mr\q@u{a} tilka \q@u{a}y\q@u{a}tu alkit\q@u{a}bi waqur\q@u{a}nin mubeen\q@b{in}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mdccciv{Rubam\q@u{a} yawaddu alla\q@u{th}eena kafaroo law k\q@u{a}noo muslimeen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mdcccv{\q@u{Th}arhum yakuloo wayatamattaAAoo wayulhihimu alamalu fasawfa yaAAlamoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mdcccvi{Wam\q@u{a} ahlakn\q@u{a} min qaryatin ill\q@u{a} walah\q@u{a} kit\q@u{a}bun maAAloom\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mdcccvii{M\q@u{a} tasbiqu min ommatin ajalah\q@u{a} wam\q@u{a} yastakhiroon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mdcccviii{Waq\q@u{a}loo y\q@u{a} ayyuh\q@u{a} alla\q@u{th}ee nuzzila AAalayhi a\q@b{l}\q@u{thth}ikru innaka lamajnoon\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mdcccix{Law m\q@u{a} tateen\q@u{a} bi\q@b{a}lmal\q@u{a}ikati in kunta mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mdcccx{M\q@u{a} nunazzilu almal\q@u{a}ikata ill\q@u{a} bi\q@b{a}l\q@u{h}aqqi wam\q@u{a} k\q@u{a}noo i\q@u{th}an mun\q@i{\q@u{th}}areen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mdcccxi{Inn\q@u{a} na\q@u{h}nu nazzaln\q@u{a} a\q@b{l}\q@u{thth}ikra wainn\q@u{a} lahu la\q@u{ha}fi\q@i{\q@u{th}}oon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mdcccxii{Walaqad arsaln\q@u{a} min qablika fee shiyaAAi alawwaleen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mdcccxiii{Wam\q@u{a} yateehim min rasoolin ill\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mdcccxiv{Ka\q@u{tha}lika naslukuhu fee quloobi almujrimeen\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mdcccxv{L\q@u{a} yuminoona bihi waqad khalat sunnatu alawwaleen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mdcccxvi{Walaw fata\q@u{h}n\q@u{a} AAalayhim b\q@u{a}ban mina a\q@b{l}ssam\q@u{a}i fa\q@i{\q@u{th}}alloo feehi yaAArujoon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mdcccxvii{Laq\q@u{a}loo innam\q@u{a} sukkirat ab\q@u{sa}run\q@u{a} bal na\q@u{h}nu qawmun mas\q@u{h}ooroon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mdcccxviii{Walaqad jaAAaln\q@u{a} fee a\q@b{l}ssam\q@u{a}i buroojan wazayyann\q@u{a}h\q@u{a} li\q@b{l}nn\q@u{a}\q@i{\q@u{th}}ireen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mdcccxix{Wa\q@u{h}afi\q@i{\q@u{th}}n\q@u{a}h\q@u{a} min kulli shay\q@u{ta}nin rajeem\q@b{in}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mdcccxx{Ill\q@u{a} mani istaraqa a\q@b{l}ssamAAa faatbaAAahu shih\q@u{a}bun mubeen\q@b{un}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mdcccxxi{Wa\q@b{a}lar\q@u{d}a madadn\q@u{a}h\q@u{a} waalqayn\q@u{a} feeh\q@u{a} raw\q@u{a}siya waanbatn\q@u{a} feeh\q@u{a} min kulli shayin mawzoon\q@b{in}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mdcccxxii{WajaAAaln\q@u{a} lakum feeh\q@u{a} maAA\q@u{a}yisha waman lastum lahu bir\q@u{a}ziqeen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mdcccxxiii{Wain min shayin ill\q@u{a} AAindan\q@u{a} khaz\q@u{a}inuhu wam\q@u{a} nunazziluhu ill\q@u{a} biqadarin maAAloom\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mdcccxxiv{Waarsaln\q@u{a} a\q@b{l}rriy\q@u{ah}a law\q@u{a}qi\q@u{h}a faanzaln\q@u{a} mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faasqayn\q@u{a}kumoohu wam\q@u{a} antum lahu bikh\q@u{a}zineen\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mdcccxxv{Wainn\q@u{a} lana\q@u{h}nu nu\q@u{h}yee wanumeetu wana\q@u{h}nu alw\q@u{a}rithoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mdcccxxvi{Walaqad AAalimn\q@u{a} almustaqdimeena minkum walaqad AAalimn\q@u{a} almustakhireen\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mdcccxxvii{Wainna rabbaka huwa ya\q@u{h}shuruhum innahu \q@u{h}akeemun AAaleem\q@b{un}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mdcccxxviii{Walaqad khalaqn\q@u{a} alins\q@u{a}na min \q@u{s}al\q@u{sa}lin min \q@u{h}amain masnoon\q@b{in}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mdcccxxix{Wa\q@b{a}lj\q@u{a}nna khalaqn\q@u{a}hu min qablu min n\q@u{a}ri a\q@b{l}ssamoom\q@b{i}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mdcccxxx{Wai\q@u{th} q\q@u{a}la rabbuka lilmal\q@u{a}ikati innee kh\q@u{a}liqun basharan min \q@u{s}al\q@u{sa}lin min \q@u{h}amain masnoon\q@b{in}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mdcccxxxi{Fai\q@u{tha} sawwaytuhu wanafakhtu feehi min roo\q@u{h}ee faqaAAoo lahu s\q@u{a}jideen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mdcccxxxii{Fasajada almal\q@u{a}ikatu kulluhum ajmaAAoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mdcccxxxiii{Ill\q@u{a} ibleesa ab\q@u{a} an yakoona maAAa a\q@b{l}ss\q@u{a}jideen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mdcccxxxiv{Q\q@u{a}la y\q@u{a} ibleesu m\q@u{a} laka all\q@u{a} takoona maAAa a\q@b{l}ss\q@u{a}jideen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mdcccxxxv{Q\q@u{a}la lam akun liasjuda libasharin khalaqtahu min \q@u{s}al\q@u{sa}lin min \q@u{h}amain masnoon\q@b{in}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mdcccxxxvi{Q\q@u{a}la fa\q@b{o}khruj minh\q@u{a} fainnaka rajeem\q@b{un}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mdcccxxxvii{Wainna AAalayka allaAAnata il\q@u{a} yawmi a\q@b{l}ddeen\q@b{i}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mdcccxxxviii{Q\q@u{a}la rabbi faan\q@i{\q@u{th}}irnee il\q@u{a} yawmi yubAAathoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mdcccxxxix{Q\q@u{a}la fainnaka mina almun\q@i{\q@u{th}}areen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mdcccxl{Il\q@u{a} yawmi alwaqti almaAAloom\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mdcccxli{Q\q@u{a}la rabbi bim\q@u{a} aghwaytanee laozayyinanna lahum fee alar\q@u{d}i walaoghwiyannahum ajmaAAeen\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mdcccxlii{Ill\q@u{a} AAib\q@u{a}daka minhumu almukhla\q@u{s}een\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mdcccxliii{Q\q@u{a}la h\q@u{atha} \q@u{s}ir\q@u{at}un AAalayya mustaqeem\q@b{un}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mdcccxliv{Inna AAib\q@u{a}dee laysa laka AAalayhim sul\q@u{ta}nun ill\q@u{a} mani ittabaAAaka mina algh\q@u{a}ween\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mdcccxlv{Wainna jahannama lamawAAiduhum ajmaAAeen\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mdcccxlvi{Lah\q@u{a} sabAAatu abw\q@u{a}bin likulli b\q@u{a}bin minhum juzon maqsoom\q@b{un}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mdcccxlvii{Inna almuttaqeena fee jann\q@u{a}tin waAAuyoon\q@b{in}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mdcccxlviii{Odkhulooh\q@u{a} bisal\q@u{a}min \q@u{a}mineen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mdcccxlix{WanazaAAn\q@u{a} m\q@u{a} fee \q@u{s}udoorihim min ghillin ikhw\q@u{a}nan AAal\q@u{a} sururin mutaq\q@u{a}bileen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mdcccl{L\q@u{a} yamassuhum feeh\q@u{a} na\q@u{s}abun wam\q@u{a} hum minh\q@u{a} bimukhrajeen\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mdcccli{Nabbi AAib\q@u{a}dee annee an\q@u{a} alghafooru a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mdccclii{Wa anna AAa\q@u{tha}bee huwa alAAa\q@u{tha}bu alaleem\q@b{u}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mdcccliii{Wanabbihum AAan \q@u{d}ayfi ibr\q@u{a}heem\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mdcccliv{I\q@u{th} dakhaloo AAalayhi faq\q@u{a}loo sal\q@u{a}man q\q@u{a}la inn\q@u{a} minkum wajiloon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mdccclv{Q\q@u{a}loo l\q@u{a} tawjal inn\q@u{a} nubashshiruka bighul\q@u{a}min AAaleem\q@b{in}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mdccclvi{Q\q@u{a}la abashshartumoonee AAal\q@u{a} an massaniya alkibaru fabima tubashshiroon\q@b{i}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mdccclvii{Q\q@u{a}loo bashsharn\q@u{a}ka bi\q@b{a}l\q@u{h}aqqi fal\q@u{a} takun mina alq\q@u{a}ni\q@u{t}een\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mdccclviii{Q\q@u{a}la waman yaqna\q@u{t}u min ra\q@u{h}mati rabbihi ill\q@u{a} a\q@b{l}\q@u{dda}lloon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mdccclix{Q\q@u{a}la fam\q@u{a} kha\q@u{t}bukum ayyuh\q@u{a} almursaloon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mdccclx{Q\q@u{a}loo inn\q@u{a} orsiln\q@u{a} il\q@u{a} qawmin mujrimeen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mdccclxi{Ill\q@u{a} \q@u{a}la loo\q@u{t}in inn\q@u{a} lamunajjoohum ajmaAAeen\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mdccclxii{Ill\q@u{a} imraatahu qaddarn\q@u{a} innah\q@u{a} lamina algh\q@u{a}bireen\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mdccclxiii{Falamm\q@u{a} j\q@u{a}a \q@u{a}la loo\q@u{t}in almursaloon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mdccclxiv{Q\q@u{a}la innakum qawmun munkaroon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mdccclxv{Q\q@u{a}loo bal jin\q@u{a}ka bim\q@u{a} k\q@u{a}noo feehi yamtaroon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mdccclxvi{Waatayn\q@u{a}ka bi\q@b{a}l\q@u{h}aqqi wainn\q@u{a} la\q@u{sa}diqoon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mdccclxvii{Faasri biahlika biqi\q@u{t}AAin mina allayli wa\q@b{i}ttabiAA adb\q@u{a}rahum wal\q@u{a} yaltafit minkum a\q@u{h}adun wa\q@b{i}m\q@u{d}oo \q@u{h}aythu tumaroon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mdccclxviii{Waqa\q@u{d}ayn\q@u{a} ilayhi \q@u{tha}lika alamra anna d\q@u{a}bira h\q@u{a}ol\q@u{a}i maq\q@u{t}ooAAun mu\q@u{s}bi\q@u{h}een\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mdccclxix{Waj\q@u{a}a ahlu almadeenati yastabshiroon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mdccclxx{Q\q@u{a}la inna h\q@u{a}ol\q@u{a}i \q@u{d}ayfee fal\q@u{a} taf\q@u{d}a\q@u{h}oon\q@b{i}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mdccclxxi{Wa\q@b{i}ttaqoo All\q@u{a}ha wal\q@u{a} tukhzoon\q@b{i}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mdccclxxii{Q\q@u{a}loo awalam nanhaka AAani alAA\q@u{a}lameen\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mdccclxxiii{Q\q@u{a}la h\q@u{a}ol\q@u{a}i ban\q@u{a}tee in kuntum f\q@u{a}AAileen\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mdccclxxiv{LaAAamruka innahum lafee sakratihim yaAAmahoona\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mdccclxxv{Faakha\q@u{th}athumu a\q@b{l}\q@u{ss}ay\q@u{h}atu mushriqeen\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mdccclxxvi{FajaAAaln\q@u{a} AA\q@u{a}liyah\q@u{a} s\q@u{a}filah\q@u{a} waam\q@u{t}arn\q@u{a} AAalayhim \q@u{h}ij\q@u{a}ratan min sijjeel\q@b{in}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mdccclxxvii{Inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin lilmutawassimeen\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mdccclxxviii{Wainnah\q@u{a} labisabeelin muqeem\q@b{in}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mdccclxxix{Inna fee \q@u{tha}lika la\q@u{a}yatan lilmumineen\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mdccclxxx{Wain k\q@u{a}na a\q@u{s}\q@u{ha}bu alaykati la\q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mdccclxxxi{Fa\q@b{i}ntaqamn\q@u{a} minhum wainnahum\q@u{a} labiim\q@u{a}min mubeen\q@b{in}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mdccclxxxii{Walaqad ka\q@u{thth}aba a\q@u{s}\q@u{ha}bu al\q@u{h}ijri almursaleen\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mdccclxxxiii{Wa\q@u{a}tayn\q@u{a}hum \q@u{a}y\q@u{a}tin\q@u{a} fak\q@u{a}noo AAanh\q@u{a} muAAri\q@u{d}een\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mdccclxxxiv{Wak\q@u{a}noo yan\q@u{h}itoona mina aljib\q@u{a}li buyootan \q@u{a}mineen\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mdccclxxxv{Faakha\q@u{th}athumu a\q@b{l}\q@u{ss}ay\q@u{h}atu mu\q@u{s}bi\q@u{h}een\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mdccclxxxvi{Fam\q@u{a} aghn\q@u{a} AAanhum m\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mdccclxxxvii{Wam\q@u{a} khalaqn\q@u{a} a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wam\q@u{a} baynahum\q@u{a} ill\q@u{a} bi\q@b{a}l\q@u{h}aqqi wainna a\q@b{l}ss\q@u{a}AAata la\q@u{a}tiyatun fa\q@b{i}\q@u{s}fa\q@u{h}i a\q@b{l}\q@u{ss}af\q@u{h}a aljameel\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mdccclxxxviii{Inna rabbaka huwa alkhall\q@u{a}qu alAAaleem\q@b{u}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mdccclxxxix{Walaqad \q@u{a}tayn\q@u{a}ka sabAAan mina almath\q@u{a}nee wa\q@b{a}lqur\q@u{a}na alAAa\q@i{\q@u{th}}eem\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mdcccxc{L\q@u{a} tamuddanna AAaynayka il\q@u{a} m\q@u{a} mattaAAn\q@u{a} bihi azw\q@u{a}jan minhum wal\q@u{a} ta\q@u{h}zan AAalayhim wa\q@b{i}khfi\q@u{d} jan\q@u{ah}aka lilmumineen\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mdcccxci{Waqul innee an\q@u{a} a\q@b{l}nna\q@u{th}eeru almubeen\q@b{u}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mdcccxcii{Kam\q@u{a} anzaln\q@u{a} AAal\q@u{a} almuqtasimeen\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mdcccxciii{Alla\q@u{th}eena jaAAaloo alqur\q@u{a}na AAi\q@u{d}een\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mdcccxciv{Fawarabbika lanasalannahum ajmaAAeen\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mdcccxcv{AAamm\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mdcccxcvi{Fa\q@b{i}\q@u{s}daAA bim\q@u{a} tumaru waaAAri\q@u{d} AAani almushrikeen\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mdcccxcvii{Inn\q@u{a} kafayn\q@u{a}ka almustahzieen\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mdcccxcviii{Alla\q@u{th}eena yajAAaloona maAAa All\q@u{a}hi il\q@u{a}han \q@u{a}khara fasawfa yaAAlamoon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mdcccxcix{Walaqad naAAlamu annaka ya\q@u{d}eequ \q@u{s}adruka bim\q@u{a} yaqooloon\q@b{a}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mcm{Fasabbi\q@u{h} bi\q@u{h}amdi rabbika wakun mina a\q@b{l}ss\q@u{a}jideen\q@b{a}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mcmi{Wa\q@b{o}AAbud rabbaka \q@u{h}att\q@u{a} yatiyaka alyaqeen\q@b{u}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mcmii{\basmalahlt At\q@u{a} amru All\q@u{a}hi fal\q@u{a} tastaAAjiloohu sub\q@u{ha}nahu wataAA\q@u{a}l\q@u{a} AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mcmiii{Yunazzilu almal\q@u{a}ikata bi\q@b{al}rroo\q@u{h}i min amrihi AAal\q@u{a} man yash\q@u{a}o min AAib\q@u{a}dihi an an\q@u{th}iroo annahu l\q@u{a} il\q@u{a}ha ill\q@u{a} an\q@u{a} fa\q@b{i}ttaqoon\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mcmiv{Khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a bi\q@b{a}l\q@u{h}aqqi taAA\q@u{a}l\q@u{a} AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mcmv{Khalaqa alins\q@u{a}na min nu\q@u{t}fatin fai\q@u{tha} huwa kha\q@u{s}eemun mubeen\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mcmvi{Wa\q@b{a}lanAA\q@u{a}ma khalaqah\q@u{a} lakum feeh\q@u{a} difon waman\q@u{a}fiAAu waminh\q@u{a} takuloon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mcmvii{Walakum feeh\q@u{a} jam\q@u{a}lun \q@u{h}eena turee\q@u{h}oona wa\q@u{h}eena tasra\q@u{h}oon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mcmviii{Wata\q@u{h}milu athq\q@u{a}lakum il\q@u{a} baladin lam takoonoo b\q@u{a}ligheehi ill\q@u{a} bishiqqi alanfusi inna rabbakum laraoofun ra\q@u{h}eem\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mcmix{Wa\q@b{a}lkhayla wa\q@b{a}lbigh\q@u{a}la wa\q@b{a}l\q@u{h}ameera litarkabooh\q@u{a} wazeenatan wayakhluqu m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mcmx{WaAAal\q@u{a} All\q@u{a}hi qa\q@u{s}du a\q@b{l}ssabeeli waminh\q@u{a} j\q@u{a}irun walaw sh\q@u{a}a lahad\q@u{a}kum ajmaAAeen\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mcmxi{Huwa alla\q@u{th}ee anzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an lakum minhu shar\q@u{a}bun waminhu shajarun feehi tuseemoon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mcmxii{Yunbitu lakum bihi a\q@b{l}zzarAAa wa\q@b{al}zzaytoona wa\q@b{al}nnakheela wa\q@b{a}laAAn\q@u{a}ba wamin kulli a\q@b{l}ththamar\q@u{a}ti inna fee \q@u{tha}lika la\q@u{a}yatan liqawmin yatafakkaroon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mcmxiii{Wasakhkhara lakumu allayla wa\q@b{al}nnah\q@u{a}ra wa\q@b{al}shshamsa wa\q@b{a}lqamara wa\q@b{al}nnujoomu musakhkhar\q@u{a}tun biamrihi inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yaAAqiloon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mcmxiv{Wam\q@u{a} \q@u{th}araa lakum fee alar\q@u{d}i mukhtalifan alw\q@u{a}nuhu inna fee \q@u{tha}lika la\q@u{a}yatan liqawmin ya\q@u{thth}akkaroon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mcmxv{Wahuwa alla\q@u{th}ee sakhkhara alba\q@u{h}ra litakuloo minhu la\q@u{h}man \q@u{t}ariyyan watastakhrijoo minhu \q@u{h}ilyatan talbasoonah\q@u{a} watar\q@u{a} alfulka maw\q@u{a}khira feehi walitabtaghoo min fa\q@u{d}lihi walaAAallakum tashkuroon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mcmxvi{Waalq\q@u{a} fee alar\q@u{d}i raw\q@u{a}siya an tameeda bikum waanh\q@u{a}ran wasubulan laAAallakum tahtadoon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mcmxvii{WaAAal\q@u{a}m\q@u{a}tin wabi\q@b{al}nnajmi hum yahtadoon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mcmxviii{Afaman yakhluqu kaman l\q@u{a} yakhluqu afal\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mcmxix{Wain taAAuddoo niAAmata All\q@u{a}hi l\q@u{a} tu\q@u{hs}ooh\q@u{a} inna All\q@u{a}ha laghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mcmxx{Wa\q@b{A}ll\q@u{a}hu yaAAlamu m\q@u{a} tusirroona wam\q@u{a} tuAAlinoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mcmxxi{Wa\q@b{a}lla\q@u{th}eena yadAAoona min dooni All\q@u{a}hi l\q@u{a} yakhluqoona shayan wahum yukhlaqoon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mcmxxii{Amw\q@u{a}tun ghayru a\q@u{h}y\q@u{a}in wam\q@u{a} yashAAuroona ayy\q@u{a}na yubAAathoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mcmxxiii{Il\q@u{a}hukum il\q@u{a}hun w\q@u{ah}idun fa\q@b{a}lla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati quloobuhum munkiratun wahum mustakbiroon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mcmxxiv{L\q@u{a} jarama anna All\q@u{a}ha yaAAlamu m\q@u{a} yusirroona wam\q@u{a} yuAAlinoona innahu l\q@u{a} yu\q@u{h}ibbu almustakbireen\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mcmxxv{Wai\q@u{tha} qeela lahum m\q@u{atha} anzala rabbukum q\q@u{a}loo as\q@u{at}eeru alawwaleen\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mcmxxvi{Liya\q@u{h}miloo awz\q@u{a}rahum k\q@u{a}milatan yawma alqiy\q@u{a}mati wamin awz\q@u{a}ri alla\q@u{th}eena yu\q@u{d}illoonahum bighayri AAilmin al\q@u{a} s\q@u{a}a m\q@u{a} yaziroon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mcmxxvii{Qad makara alla\q@u{th}eena min qablihim faat\q@u{a} All\q@u{a}hu buny\q@u{a}nahum mina alqaw\q@u{a}AAidi fakharra AAalayhimu a\q@b{l}ssaqfu min fawqihim waat\q@u{a}humu alAAa\q@u{tha}bu min \q@u{h}aythu l\q@u{a} yashAAuroon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mcmxxviii{Thumma yawma alqiy\q@u{a}mati yukhzeehim wayaqoolu ayna shurak\q@u{a}iya alla\q@u{th}eena kuntum tush\q@u{a}qqoona feehim q\q@u{a}la alla\q@u{th}eena ootoo alAAilma inna alkhizya alyawma wa\q@b{al}ssooa AAal\q@u{a} alk\q@u{a}fireen\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mcmxxix{Alla\q@u{th}eena tatawaff\q@u{a}humu almal\q@u{a}ikatu \q@i{\q@u{th}}\q@u{a}limee anfusihim faalqawoo a\q@b{l}ssalama m\q@u{a} kunn\q@u{a} naAAmalu min sooin bal\q@u{a} inna All\q@u{a}ha AAaleemun bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mcmxxx{Fa\q@b{o}dkhuloo abw\q@u{a}ba jahannama kh\q@u{a}lideena feeh\q@u{a} falabisa mathw\q@u{a} almutakabbireen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mcmxxxi{Waqeela lilla\q@u{th}eena ittaqaw m\q@u{atha} anzala rabbukum q\q@u{a}loo khayran lilla\q@u{th}eena a\q@u{h}sanoo fee h\q@u{ath}ihi a\q@b{l}dduny\q@u{a} \q@u{h}asanatun walad\q@u{a}ru al\q@u{a}khirati khayrun walaniAAma d\q@u{a}ru almuttaqeen\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mcmxxxii{Jann\q@u{a}tu AAadnin yadkhuloonah\q@u{a} tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru lahum feeh\q@u{a} m\q@u{a} yash\q@u{a}oona ka\q@u{tha}lika yajzee All\q@u{a}hu almuttaqeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mcmxxxiii{Alla\q@u{th}eena tatawaff\q@u{a}humu almal\q@u{a}ikatu \q@u{t}ayyibeena yaqooloona sal\q@u{a}mun AAalaykumu odkhuloo aljannata bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mcmxxxiv{Hal yan\q@i{\q@u{th}}uroona ill\q@u{a} an tatiyahumu almal\q@u{a}ikatu aw yatiya amru rabbika ka\q@u{tha}lika faAAala alla\q@u{th}eena min qablihim wam\q@u{a} \q@i{\q@u{th}}alamahumu All\q@u{a}hu wal\q@u{a}kin k\q@u{a}noo anfusahum ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mcmxxxv{Faa\q@u{sa}bahum sayyi\q@u{a}tu m\q@u{a} AAamiloo wa\q@u{ha}qa bihim m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mcmxxxvi{Waq\q@u{a}la alla\q@u{th}eena ashrakoo law sh\q@u{a}a All\q@u{a}hu m\q@u{a} AAabadn\q@u{a} min doonihi min shayin na\q@u{h}nu wal\q@u{a} \q@u{a}b\q@u{a}on\q@u{a} wal\q@u{a} \q@u{h}arramn\q@u{a} min doonihi min shayin ka\q@u{tha}lika faAAala alla\q@u{th}eena min qablihim fahal AAal\q@u{a} a\q@b{l}rrusuli ill\q@u{a} albal\q@u{a}ghu almubeen\q@b{u}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mcmxxxvii{Walaqad baAAathn\q@u{a} fee kulli ommatin rasoolan ani oAAbudoo All\q@u{a}ha wa\q@b{i}jtaniboo a\q@b{l}\q@u{tta}ghoota faminhum man had\q@u{a} All\q@u{a}hu waminhum man \q@u{h}aqqat AAalayhi a\q@b{l}\q@u{dd}al\q@u{a}latu faseeroo fee alar\q@u{d}i fa\q@b{o}n\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu almuka\q@u{thth}ibeen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mcmxxxviii{In ta\q@u{h}ri\q@u{s} AAal\q@u{a} hud\q@u{a}hum fainna All\q@u{a}ha l\q@u{a} yahdee man yu\q@u{d}illu wam\q@u{a} lahum min n\q@u{as}ireen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mcmxxxix{Waaqsamoo bi\q@b{A}ll\q@u{a}hi jahda aym\q@u{a}nihim l\q@u{a} yabAAathu All\q@u{a}hu man yamootu bal\q@u{a} waAAdan AAalayhi \q@u{h}aqqan wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mcmxl{Liyubayyina lahumu alla\q@u{th}ee yakhtalifoona feehi waliyaAAlama alla\q@u{th}eena kafaroo annahum k\q@u{a}noo k\q@u{ath}ibeen\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mcmxli{Innam\q@u{a} qawlun\q@u{a} lishayin i\q@u{tha} aradn\q@u{a}hu an naqoola lahu kun fayakoon\q@b{u}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mcmxlii{Wa\q@b{a}lla\q@u{th}eena h\q@u{a}jaroo fee All\q@u{a}hi min baAAdi m\q@u{a} \q@i{\q@u{th}}ulimoo lanubawwiannahum fee a\q@b{l}dduny\q@u{a} \q@u{h}asanatan walaajru al\q@u{a}khirati akbaru law k\q@u{a}noo yaAAlamoon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mcmxliii{Alla\q@u{th}eena \q@u{s}abaroo waAAal\q@u{a} rabbihim yatawakkaloon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mcmxliv{Wam\q@u{a} arsaln\q@u{a} min qablika ill\q@u{a} rij\q@u{a}lan noo\q@u{h}ee ilayhim fa\q@b{i}saloo ahla a\q@b{l}\q@u{thth}ikri in kuntum l\q@u{a} taAAlamoon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mcmxlv{Bi\q@b{a}lbayyin\q@u{a}ti wa\q@b{al}zzuburi waanzaln\q@u{a} ilayka a\q@b{l}\q@u{thth}ikra litubayyina li\q@b{l}nn\q@u{a}si m\q@u{a} nuzzila ilayhim walaAAallahum yatafakkaroon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mcmxlvi{Afaamina alla\q@u{th}eena makaroo a\q@b{l}ssayyi\q@u{a}ti an yakhsifa All\q@u{a}hu bihimu alar\q@u{d}a aw yatiyahumu alAAa\q@u{tha}bu min \q@u{h}aythu l\q@u{a} yashAAuroon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mcmxlvii{Aw yakhu\q@u{th}ahum fee taqallubihim fam\q@u{a} hum bimuAAjizeen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mcmxlviii{Aw yakhu\q@u{th}ahum AAal\q@u{a} takhawwufin fainna rabbakum laraoofun ra\q@u{h}eem\q@b{un}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mcmxlix{Awa lam yaraw il\q@u{a} m\q@u{a} khalaqa All\q@u{a}hu min shayin yatafayyao \q@i{\q@u{th}}il\q@u{a}luhu AAani alyameeni wa\q@b{al}shsham\q@u{a}ili sujjadan lill\q@u{a}hi wahum d\q@u{a}khiroon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mcml{Walill\q@u{a}hi yasjudu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i min d\q@u{a}bbatin wa\q@b{a}lmal\q@u{a}ikatu wahum l\q@u{a} yastakbiroon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mcmli{Yakh\q@u{a}foona rabbahum min fawqihim wayafAAaloona m\q@u{a} yumaroon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mcmlii{Waq\q@u{a}la All\q@u{a}hu l\q@u{a} tattakhi\q@u{th}oo il\q@u{a}hayni ithnayni innam\q@u{a} huwa il\q@u{a}hun w\q@u{ah}idun faiyy\q@u{a}ya fa\q@b{i}rhaboon\q@b{i}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mcmliii{Walahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i walahu a\q@b{l}ddeenu w\q@u{as}iban afaghayra All\q@u{a}hi tattaqoon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mcmliv{Wam\q@u{a} bikum min niAAmatin famina All\q@u{a}hi thumma i\q@u{tha} massakumu a\q@b{l}\q@u{dd}urru failayhi tajaroon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mcmlv{Thumma i\q@u{tha} kashafa a\q@b{l}\q@u{dd}urra AAankum i\q@u{tha} fareequn minkum birabbihim yushrikoon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mcmlvi{Liyakfuroo bim\q@u{a} \q@u{a}tayn\q@u{a}hum fatamattaAAoo fasawfa taAAlamoon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mcmlvii{WayajAAaloona lim\q@u{a} l\q@u{a} yaAAlamoona na\q@u{s}eeban mimm\q@u{a} razaqn\q@u{a}hum ta\q@b{A}ll\q@u{a}hi latusalunna AAamm\q@u{a} kuntum taftaroon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mcmlviii{WayajAAaloona lill\q@u{a}hi alban\q@u{a}ti sub\q@u{ha}nahu walahum m\q@u{a} yashtahoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mcmlix{Wai\q@u{tha} bushshira a\q@u{h}aduhum bi\q@b{a}lonth\q@u{a} \q@i{\q@u{th}}alla wajhuhu muswaddan wahuwa ka\q@i{\q@u{th}}eem\q@b{un}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mcmlx{Yataw\q@u{a}r\q@u{a} mina alqawmi min sooi m\q@u{a} bushshira bihi ayumsikuhu AAal\q@u{a} hoonin am yadussuhu fee a\q@b{l}ttur\q@u{a}bi al\q@u{a} s\q@u{a}a m\q@u{a} ya\q@u{h}kumoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mcmlxi{Lilla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati mathalu a\q@b{l}ssawi walill\q@u{a}hi almathalu alaAAl\q@u{a} wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mcmlxii{Walaw yu\q@u{a}khi\q@u{th}u All\q@u{a}hu a\q@b{l}nn\q@u{a}sa bi\q@i{\q@u{th}}ulmihim m\q@u{a} taraka AAalayh\q@u{a} min d\q@u{a}bbatin wal\q@u{a}kin yuakhkhiruhum il\q@u{a} ajalin musamman fai\q@u{tha} j\q@u{a}a ajaluhum l\q@u{a} yastakhiroona s\q@u{a}AAatan wal\q@u{a} yastaqdimoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mcmlxiii{WayajAAaloona lill\q@u{a}hi m\q@u{a} yakrahoona wata\q@u{s}ifu alsinatuhumu alka\q@u{th}iba anna lahumu al\q@u{h}usn\q@u{a} l\q@u{a} jarama anna lahumu a\q@b{l}nn\q@u{a}ra waannahum mufra\q@u{t}oon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mcmlxiv{Ta\q@b{A}ll\q@u{a}hi laqad arsaln\q@u{a} il\q@u{a} omamin min qablika fazayyana lahumu a\q@b{l}shshay\q@u{ta}nu aAAm\q@u{a}lahum fahuwa waliyyuhumu alyawma walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mcmlxv{Wam\q@u{a} anzaln\q@u{a} AAalayka alkit\q@u{a}ba ill\q@u{a} litubayyina lahumu alla\q@u{th}ee ikhtalafoo feehi wahudan wara\q@u{h}matan liqawmin yuminoon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mcmlxvi{Wa\q@b{A}ll\q@u{a}hu anzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faa\q@u{h}y\q@u{a} bihi alar\q@u{d}a baAAda mawtih\q@u{a} inna fee \q@u{tha}lika la\q@u{a}yatan liqawmin yasmaAAoon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mcmlxvii{Wainna lakum fee alanAA\q@u{a}mi laAAibratan nusqeekum mimm\q@u{a} fee bu\q@u{t}oonihi min bayni farthin wadamin labanan kh\q@u{a}li\q@u{s}an s\q@u{a}ighan li\q@b{l}shsh\q@u{a}ribeen\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mcmlxviii{Wamin thamar\q@u{a}ti a\q@b{l}nnakheeli wa\q@b{a}laAAn\q@u{a}bi tattakhi\q@u{th}oona minhu sakaran warizqan \q@u{h}asanan inna fee \q@u{tha}lika la\q@u{a}yatan liqawmin yaAAqiloon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mcmlxix{Waaw\q@u{ha} rabbuka il\q@u{a} a\q@b{l}nna\q@u{h}li ani ittakhi\q@u{th}ee mina aljib\q@u{a}li buyootan wamina a\q@b{l}shshajari wamimm\q@u{a} yaAArishoon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mcmlxx{Thumma kulee min kulli a\q@b{l}ththamar\q@u{a}ti fa\q@b{o}slukee subula rabbiki \q@u{th}ululan yakhruju min bu\q@u{t}oonih\q@u{a} shar\q@u{a}bun mukhtalifun alw\q@u{a}nuhu feehi shif\q@u{a}on li\q@b{l}nn\q@u{a}si inna fee \q@u{tha}lika la\q@u{a}yatan liqawmin yatafakkaroon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mcmlxxi{Wa\q@b{A}ll\q@u{a}hu khalaqakum thumma yatawaff\q@u{a}kum waminkum man yuraddu il\q@u{a} ar\q@u{th}ali alAAumuri likay l\q@u{a} yaAAlama baAAda AAilmin shayan inna All\q@u{a}ha AAaleemun qadeer\q@b{un}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mcmlxxii{Wa\q@b{A}ll\q@u{a}hu fa\q@u{dd}ala baAA\q@u{d}akum AAal\q@u{a} baAA\q@u{d}in fee a\q@b{l}rrizqi fam\q@u{a} alla\q@u{th}eena fu\q@u{dd}iloo bir\q@u{a}ddee rizqihim AAal\q@u{a} m\q@u{a} malakat aym\q@u{a}nuhum fahum feehi saw\q@u{a}on afabiniAAmati All\q@u{a}hi yaj\q@u{h}adoon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mcmlxxiii{Wa\q@b{A}ll\q@u{a}hu jaAAala lakum min anfusikum azw\q@u{a}jan wajaAAala lakum min azw\q@u{a}jikum baneena wa\q@u{h}afadatan warazaqakum mina a\q@b{l}\q@u{tt}ayyib\q@u{a}ti afabi\q@b{a}lb\q@u{at}ili yuminoona wabiniAAmati All\q@u{a}hi hum yakfuroon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mcmlxxiv{WayaAAbudoona min dooni All\q@u{a}hi m\q@u{a} l\q@u{a} yamliku lahum rizqan mina a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i shayan wal\q@u{a} yasta\q@u{t}eeAAoon\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mcmlxxv{Fal\q@u{a} ta\q@u{d}riboo lill\q@u{a}hi alamth\q@u{a}la inna All\q@u{a}ha yaAAlamu waantum l\q@u{a} taAAlamoon\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mcmlxxvi{\q@u{D}araba All\q@u{a}hu mathalan AAabdan mamlookan l\q@u{a} yaqdiru AAal\q@u{a} shayin waman razaqn\q@u{a}hu minn\q@u{a} rizqan \q@u{h}asanan fahuwa yunfiqu minhu sirran wajahran hal yastawoona al\q@u{h}amdu lill\q@u{a}hi bal aktharuhum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mcmlxxvii{Wa\q@u{d}araba All\q@u{a}hu mathalan rajulayni a\q@u{h}aduhum\q@u{a} abkamu l\q@u{a} yaqdiru AAal\q@u{a} shayin wahuwa kallun AAal\q@u{a} mawl\q@u{a}hu aynam\q@u{a} yuwajjihhu l\q@u{a} yati bikhayrin hal yastawee huwa waman yamuru bi\q@b{a}lAAadli wahuwa AAal\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mcmlxxviii{Walill\q@u{a}hi ghaybu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} amru a\q@b{l}ss\q@u{a}AAati ill\q@u{a} kalam\q@u{h}i alba\q@u{s}ari aw huwa aqrabu inna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mcmlxxix{Wa\q@b{A}ll\q@u{a}hu akhrajakum min bu\q@u{t}ooni ommah\q@u{a}tikum l\q@u{a} taAAlamoona shayan wajaAAala lakumu a\q@b{l}ssamAAa wa\q@b{a}lab\q@u{sa}ra wa\q@b{a}lafidata laAAallakum tashkuroon\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mcmlxxx{Alam yaraw il\q@u{a} a\q@b{l}\q@u{tt}ayri musakhkhar\q@u{a}tin fee jawwi a\q@b{l}ssam\q@u{a}i m\q@u{a} yumsikuhunna ill\q@u{a} All\q@u{a}hu inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yuminoon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mcmlxxxi{Wa\q@b{A}ll\q@u{a}hu jaAAala lakum min buyootikum sakanan wajaAAala lakum min juloodi alanAA\q@u{a}mi buyootan tastakhiffoonah\q@u{a} yawma \q@i{\q@u{th}}aAAnikum wayawma iq\q@u{a}matikum wamin a\q@u{s}w\q@u{a}fih\q@u{a} waawb\q@u{a}rih\q@u{a} waashAA\q@u{a}rih\q@u{a} ath\q@u{a}than wamat\q@u{a}AAan il\q@u{a} \q@u{h}een\q@b{in}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mcmlxxxii{Wa\q@b{A}ll\q@u{a}hu jaAAala lakum mimm\q@u{a} khalaqa \q@i{\q@u{th}}il\q@u{a}lan wajaAAala lakum mina aljib\q@u{a}li akn\q@u{a}nan wajaAAala lakum sar\q@u{a}beela taqeekumu al\q@u{h}arra wasar\q@u{a}beela taqeekum basakum ka\q@u{tha}lika yutimmu niAAmatahu AAalaykum laAAallakum tuslimoon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mcmlxxxiii{Fain tawallaw fainnam\q@u{a} AAalayka albal\q@u{a}ghu almubeen\q@b{u}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mcmlxxxiv{YaAArifoona niAAmata All\q@u{a}hi thumma yunkiroonah\q@u{a} waaktharuhumu alk\q@u{a}firoon\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mcmlxxxv{Wayawma nabAAathu min kulli ommatin shaheedan thumma l\q@u{a} yu\q@u{th}anu lilla\q@u{th}eena kafaroo wal\q@u{a} hum yustaAAtaboon\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mcmlxxxvi{Wai\q@u{tha} ra\q@u{a} alla\q@u{th}eena \q@i{\q@u{th}}alamoo alAAa\q@u{tha}ba fal\q@u{a} yukhaffafu AAanhum wal\q@u{a} hum yun\q@i{\q@u{th}}aroon\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mcmlxxxvii{Wai\q@u{tha} ra\q@u{a} alla\q@u{th}eena ashrakoo shurak\q@u{a}ahum q\q@u{a}loo rabban\q@u{a} h\q@u{a}ol\q@u{a}i shurak\q@u{a}on\q@u{a} alla\q@u{th}eena kunn\q@u{a} nadAAoo min doonika faalqaw ilayhimu alqawla innakum lak\q@u{ath}iboon\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mcmlxxxviii{Waalqaw il\q@u{a} All\q@u{a}hi yawmai\q@u{th}in a\q@b{l}ssalama wa\q@u{d}alla AAanhum m\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mcmlxxxix{Alla\q@u{th}eena kafaroo wa\q@u{s}addoo AAan sabeeli All\q@u{a}hi zidn\q@u{a}hum AAa\q@u{tha}ban fawqa alAAa\q@u{tha}bi bim\q@u{a} k\q@u{a}noo yufsidoon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mcmxc{Wayawma nabAAathu fee kulli ommatin shaheedan AAalayhim min anfusihim wajin\q@u{a} bika shaheedan AAal\q@u{a} h\q@u{a}ol\q@u{a}i wanazzaln\q@u{a} AAalayka alkit\q@u{a}ba tiby\q@u{a}nan likulli shayin wahudan wara\q@u{h}matan wabushr\q@u{a} lilmuslimeen\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mcmxci{Inna All\q@u{a}ha yamuru bi\q@b{a}lAAadli wa\q@b{a}li\q@u{h}s\q@u{a}ni waeet\q@u{a}i \q@u{th}ee alqurb\q@u{a} wayanh\q@u{a} AAani alfa\q@u{h}sh\q@u{a}i wa\q@b{a}lmunkari wa\q@b{a}lbaghyi yaAAi\q@i{\q@u{th}}ukum laAAallakum ta\q@u{th}akkaroon\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mcmxcii{Waawfoo biAAahdi All\q@u{a}hi i\q@u{tha} AA\q@u{a}hadtum wal\q@u{a} tanqu\q@u{d}oo alaym\q@u{a}na baAAda tawkeedih\q@u{a} waqad jaAAaltumu All\q@u{a}ha AAalaykum kafeelan inna All\q@u{a}ha yaAAlamu m\q@u{a} tafAAaloon\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mcmxciii{Wal\q@u{a} takoonoo ka\q@b{a}llatee naqa\q@u{d}at ghazlah\q@u{a} min baAAdi quwwatin ank\q@u{a}than tattakhi\q@u{th}oona aym\q@u{a}nakum dakhalan baynakum an takoona ommatun hiya arb\q@u{a} min ommatin innam\q@u{a} yablookumu All\q@u{a}hu bihi walayubayyinanna lakum yawma alqiy\q@u{a}mati m\q@u{a} kuntum feehi takhtalifoon\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mcmxciv{Walaw sh\q@u{a}a All\q@u{a}hu lajaAAalakum ommatan w\q@u{ah}idatan wal\q@u{a}kin yu\q@u{d}illu man yash\q@u{a}o wayahdee man yash\q@u{a}o walatusalunna AAamm\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mcmxcv{Wal\q@u{a} tattakhi\q@u{th}oo aym\q@u{a}nakum dakhalan baynakum fatazilla qadamun baAAda thubootih\q@u{a} wata\q@u{th}ooqoo a\q@b{l}ssooa bim\q@u{a} \q@u{s}adadtum AAan sabeeli All\q@u{a}hi walakum AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mcmxcvi{Wal\q@u{a} tashtaroo biAAahdi All\q@u{a}hi thamanan qaleelan innam\q@u{a} AAinda All\q@u{a}hi huwa khayrun lakum in kuntum taAAlamoon\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mcmxcvii{M\q@u{a} AAindakum yanfadu wam\q@u{a} AAinda All\q@u{a}hi b\q@u{a}qin walanajziyanna alla\q@u{th}eena \q@u{s}abaroo ajrahum bia\q@u{h}sani m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mcmxcviii{Man AAamila \q@u{sa}li\q@u{h}an min \q@u{th}akarin aw onth\q@u{a} wahuwa muminun falanu\q@u{h}yiyannahu \q@u{h}ay\q@u{a}tan \q@u{t}ayyibatan walanajziyannahum ajrahum bia\q@u{h}sani m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mcmxcix{Fai\q@u{tha} qarata alqur\q@u{a}na fa\q@b{i}staAAi\q@u{th} bi\q@b{A}ll\q@u{a}hi mina a\q@b{l}shshay\q@u{ta}ni a\q@b{l}rrajeem\q@b{i}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mm{Innahu laysa lahu sul\q@u{ta}nun AAal\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAal\q@u{a} rabbihim yatawakkaloon\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mmi{Innam\q@u{a} sul\q@u{ta}nuhu AAal\q@u{a} alla\q@u{th}eena yatawallawnahu wa\q@b{a}lla\q@u{th}eena hum bihi mushrikoon\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mmii{Wai\q@u{tha} baddaln\q@u{a} \q@u{a}yatan mak\q@u{a}na \q@u{a}yatin wa\q@b{A}ll\q@u{a}hu aAAlamu bim\q@u{a} yunazzilu q\q@u{a}loo innam\q@u{a} anta muftarin bal aktharuhum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mmiii{Qul nazzalahu roo\q@u{h}u alqudusi min rabbika bi\q@b{a}l\q@u{h}aqqi liyuthabbita alla\q@u{th}eena \q@u{a}manoo wahudan wabushr\q@u{a} lilmuslimeen\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mmiv{Walaqad naAAlamu annahum yaqooloona innam\q@u{a} yuAAallimuhu basharun lis\q@u{a}nu alla\q@u{th}ee yul\q@u{h}idoona ilayhi aAAjamiyyun wah\q@u{atha} lis\q@u{a}nun AAarabiyyun mubeen\q@b{un}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mmv{Inna alla\q@u{th}eena l\q@u{a} yuminoona bi\q@u{a}y\q@u{a}ti All\q@u{a}hi l\q@u{a} yahdeehimu All\q@u{a}hu walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mmvi{Innam\q@u{a} yaftaree alka\q@u{th}iba alla\q@u{th}eena l\q@u{a} yuminoona bi\q@u{a}y\q@u{a}ti All\q@u{a}hi waol\q@u{a}ika humu alk\q@u{ath}iboon\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mmvii{Man kafara bi\q@b{A}ll\q@u{a}hi min baAAdi eem\q@u{a}nihi ill\q@u{a} man okriha waqalbuhu mu\q@u{t}mainnun bi\q@b{a}leem\q@u{a}ni wal\q@u{a}kin man shara\q@u{h}a bi\q@b{a}lkufri \q@u{s}adran faAAalayhim gha\q@u{d}abun mina All\q@u{a}hi walahum AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mmviii{\q@u{Tha}lika biannahumu ista\q@u{h}abboo al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a} AAal\q@u{a} al\q@u{a}khirati waanna All\q@u{a}ha l\q@u{a} yahdee alqawma alk\q@u{a}fireen\q@b{a}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mmix{Ol\q@u{a}ika alla\q@u{th}eena \q@u{t}abaAAa All\q@u{a}hu AAal\q@u{a} quloobihim wasamAAihim waab\q@u{sa}rihim waol\q@u{a}ika humu algh\q@u{a}filoon\q@b{a}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mmx{L\q@u{a} jarama annahum fee al\q@u{a}khirati humu alkh\q@u{a}siroon\q@b{a}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mmxi{Thumma inna rabbaka lilla\q@u{th}eena h\q@u{a}jaroo min baAAdi m\q@u{a} futinoo thumma j\q@u{a}hadoo wa\q@u{s}abaroo inna rabbaka min baAAdih\q@u{a} laghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mmxii{Yawma tatee kullu nafsin tuj\q@u{a}dilu AAan nafsih\q@u{a} watuwaff\q@u{a} kullu nafsin m\q@u{a} AAamilat wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mmxiii{Wa\q@u{d}araba All\q@u{a}hu mathalan qaryatan k\q@u{a}nat \q@u{a}minatan mu\q@u{t}mainnatan yateeh\q@u{a} rizquh\q@u{a} raghadan min kulli mak\q@u{a}nin fakafarat bianAAumi All\q@u{a}hi faa\q@u{tha}qah\q@u{a} All\q@u{a}hu lib\q@u{a}sa aljooAAi wa\q@b{a}lkhawfi bim\q@u{a} k\q@u{a}noo ya\q@u{s}naAAoon\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@mmxiv{Walaqad j\q@u{a}ahum rasoolun minhum faka\q@u{thth}aboohu faakha\q@u{th}ahumu alAAa\q@u{tha}bu wahum \q@i{\q@u{th}}\q@u{a}limoon\q@b{a}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@mmxv{Fakuloo mimm\q@u{a} razaqakumu All\q@u{a}hu \q@u{h}al\q@u{a}lan \q@u{t}ayyiban wa\q@b{o}shkuroo niAAmata All\q@u{a}hi in kuntum iyy\q@u{a}hu taAAbudoon\q@b{a}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@mmxvi{Innam\q@u{a} \q@u{h}arrama AAalaykumu almaytata wa\q@b{al}ddama wala\q@u{h}ma alkhinzeeri wam\q@u{a} ohilla lighayri All\q@u{a}hi bihi famani i\q@u{dt}urra ghayra b\q@u{a}ghin wal\q@u{a} AA\q@u{a}din fainna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@mmxvii{Wal\q@u{a} taqooloo lim\q@u{a} ta\q@u{s}ifu alsinatukumu alka\q@u{th}iba h\q@u{atha} \q@u{h}al\q@u{a}lun wah\q@u{atha} \q@u{h}ar\q@u{a}mun litaftaroo AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba inna alla\q@u{th}eena yaftaroona AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba l\q@u{a} yufli\q@u{h}oon\q@b{a}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@mmxviii{Mat\q@u{a}AAun qaleelun walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@mmxix{WaAAal\q@u{a} alla\q@u{th}eena h\q@u{a}doo \q@u{h}arramn\q@u{a} m\q@u{a} qa\q@u{s}a\q@u{s}n\q@u{a} AAalayka min qablu wam\q@u{a} \q@i{\q@u{th}}alamn\q@u{a}hum wal\q@u{a}kin k\q@u{a}noo anfusahum ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@mmxx{Thumma inna rabbaka lilla\q@u{th}eena AAamiloo a\q@b{l}ssooa bijah\q@u{a}latin thumma t\q@u{a}boo min baAAdi \q@u{tha}lika waa\q@u{s}la\q@u{h}oo inna rabbaka min baAAdih\q@u{a} laghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@mmxxi{Inna ibr\q@u{a}heema k\q@u{a}na ommatan q\q@u{a}nitan lill\q@u{a}hi \q@u{h}aneefan walam yaku mina almushrikeen\q@b{a}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@mmxxii{Sh\q@u{a}kiran lianAAumihi ijtab\q@u{a}hu wahad\q@u{a}hu il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@mmxxiii{Wa\q@u{a}tayn\q@u{a}hu fee a\q@b{l}dduny\q@u{a} \q@u{h}asanatan wainnahu fee al\q@u{a}khirati lamina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@mmxxiv{Thumma aw\q@u{h}ayn\q@u{a} ilayka ani ittabiAA millata ibr\q@u{a}heema \q@u{h}aneefan wam\q@u{a} k\q@u{a}na mina almushrikeen\q@b{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@mmxxv{Innam\q@u{a} juAAila a\q@b{l}ssabtu AAal\q@u{a} alla\q@u{th}eena ikhtalafoo feehi wainna rabbaka laya\q@u{h}kumu baynahum yawma alqiy\q@u{a}mati feem\q@u{a} k\q@u{a}noo feehi yakhtalifoon\q@b{a}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@mmxxvi{OdAAu il\q@u{a} sabeeli rabbika bi\q@b{a}l\q@u{h}ikmati wa\q@b{a}lmawAAi\q@i{\q@u{th}}ati al\q@u{h}asanati waj\q@u{a}dilhum bi\q@b{a}llatee hiya a\q@u{h}sanu inna rabbaka huwa aAAlamu biman \q@u{d}alla AAan sabeelihi wahuwa aAAlamu bi\q@b{a}lmuhtadeen\q@b{a}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@mmxxvii{Wain AA\q@u{a}qabtum faAA\q@u{a}qiboo bimithli m\q@u{a} AAooqibtum bihi walain \q@u{s}abartum lahuwa khayrun li\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@mmxxviii{Wa\q@b{i}\q@u{s}bir wam\q@u{a} \q@u{s}abruka ill\q@u{a} bi\q@b{A}ll\q@u{a}hi wal\q@u{a} ta\q@u{h}zan AAalayhim wal\q@u{a} taku fee \q@u{d}ayqin mimm\q@u{a} yamkuroon\q@b{a}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@mmxxix{Inna All\q@u{a}ha maAAa alla\q@u{th}eena ittaqaw wa\q@b{a}lla\q@u{th}eena hum mu\q@u{h}sinoon\q@b{a}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@mmxxx{\basmalahlt Sub\q@u{ha}na alla\q@u{th}ee asr\q@u{a} biAAabdihi laylan mina almasjidi al\q@u{h}ar\q@u{a}mi il\q@u{a} almasjidi alaq\q@u{sa} alla\q@u{th}ee b\q@u{a}rakn\q@u{a} \q@u{h}awlahu linuriyahu min \q@u{a}y\q@u{a}tin\q@u{a} innahu huwa a\q@b{l}ssameeAAu alba\q@u{s}eer\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmxxxi{Wa\q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba wajaAAaln\q@u{a}hu hudan libanee isr\q@u{a}eela all\q@u{a} tattakhi\q@u{th}oo min doonee wakeel\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmxxxii{\q@u{Th}urriyyata man \q@u{h}amaln\q@u{a} maAAa noo\q@u{h}in innahu k\q@u{a}na AAabdan shakoor\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmxxxiii{Waqa\q@u{d}ayn\q@u{a} il\q@u{a} banee isr\q@u{a}eela fee alkit\q@u{a}bi latufsidunna fee alar\q@u{d}i marratayni walataAAlunna AAuluwwan kabeer\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmxxxiv{Fai\q@u{tha} j\q@u{a}a waAAdu ool\q@u{a}hum\q@u{a} baAAathn\q@u{a} AAalaykum AAib\q@u{a}dan lan\q@u{a} olee basin shadeedin faj\q@u{a}soo khil\q@u{a}la a\q@b{l}ddiy\q@u{a}ri wak\q@u{a}na waAAdan mafAAool\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmxxxv{Thumma radadn\q@u{a} lakumu alkarrata AAalayhim waamdadn\q@u{a}kum biamw\q@u{a}lin wabaneena wajaAAaln\q@u{a}kum akthara nafeer\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmxxxvi{In a\q@u{h}santum a\q@u{h}santum lianfusikum wain asatum falah\q@u{a} fai\q@u{tha} j\q@u{a}a waAAdu al\q@u{a}khirati liyasoooo wujoohakum waliyadkhuloo almasjida kam\q@u{a} dakhaloohu awwala marratin waliyutabbiroo m\q@u{a} AAalaw tatbeer\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmxxxvii{AAas\q@u{a} rabbukum an yar\q@u{h}amakum wain AAudtum AAudn\q@u{a} wajaAAaln\q@u{a} jahannama lilk\q@u{a}fireena \q@u{h}a\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmxxxviii{Inna h\q@u{atha} alqur\q@u{a}na yahdee lillatee hiya aqwamu wayubashshiru almumineena alla\q@u{th}eena yaAAmaloona a\q@b{l}\q@u{ssa}li\q@u{ha}ti anna lahum ajran kabeer\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmxxxix{Waanna alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati aAAtadn\q@u{a} lahum AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmxl{WayadAAu alins\q@u{a}nu bi\q@b{al}shsharri duAA\q@u{a}ahu bi\q@b{a}lkhayri wak\q@u{a}na alins\q@u{a}nu AAajool\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmxli{WajaAAaln\q@u{a} allayla wa\q@b{al}nnah\q@u{a}ra \q@u{a}yatayni fama\q@u{h}awn\q@u{a} \q@u{a}yata allayli wajaAAaln\q@u{a} \q@u{a}yata a\q@b{l}nnah\q@u{a}ri mub\q@u{s}iratan litabtaghoo fa\q@u{d}lan min rabbikum walitaAAlamoo AAadada a\q@b{l}ssineena wa\q@b{a}l\q@u{h}is\q@u{a}ba wakulla shayin fa\q@u{ss}aln\q@u{a}hu taf\q@u{s}eel\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmxlii{Wakulla ins\q@u{a}nin alzamn\q@u{a}hu \q@u{ta}irahu fee AAunuqihi wanukhriju lahu yawma alqiy\q@u{a}mati kit\q@u{a}ban yalq\q@u{a}hu manshoor\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmxliii{Iqra kit\q@u{a}baka kaf\q@u{a} binafsika alyawma AAalayka \q@u{h}aseeb\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmxliv{Mani ihtad\q@u{a} fainnam\q@u{a} yahtadee linafsihi waman \q@u{d}alla fainnam\q@u{a} ya\q@u{d}illu AAalayh\q@u{a} wal\q@u{a} taziru w\q@u{a}ziratun wizra okhr\q@u{a} wam\q@u{a} kunn\q@u{a} muAAa\q@u{thth}ibeena \q@u{h}att\q@u{a} nabAAatha rasool\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmxlv{Wai\q@u{tha} aradn\q@u{a} an nuhlika qaryatan amarn\q@u{a} mutrafeeh\q@u{a} fafasaqoo feeh\q@u{a} fa\q@u{h}aqqa AAalayh\q@u{a} alqawlu fadammarn\q@u{a}h\q@u{a} tadmeer\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmxlvi{Wakam ahlakn\q@u{a} mina alqurooni min baAAdi noo\q@u{h}in wakaf\q@u{a} birabbika bi\q@u{th}unoobi AAib\q@u{a}dihi khabeeran ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmxlvii{Man k\q@u{a}na yureedu alAA\q@u{a}jilata AAajjaln\q@u{a} lahu feeh\q@u{a} m\q@u{a} nash\q@u{a}o liman nureedu thumma jaAAaln\q@u{a} lahu jahannama ya\q@u{s}l\q@u{a}h\q@u{a} ma\q@u{th}mooman mad\q@u{h}oor\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmxlviii{Waman ar\q@u{a}da al\q@u{a}khirata wasaAA\q@u{a} lah\q@u{a} saAAyah\q@u{a} wahuwa muminun faol\q@u{a}ika k\q@u{a}na saAAyuhum mashkoor\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmxlix{Kullan numiddu h\q@u{a}ol\q@u{a}i wah\q@u{a}ol\q@u{a}i min AAa\q@u{ta}i rabbika wam\q@u{a} k\q@u{a}na AAa\q@u{ta}o rabbika ma\q@u{h}\q@i{\q@u{th}}oor\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mml{On\q@i{\q@u{th}}ur kayfa fa\q@u{dd}aln\q@u{a} baAA\q@u{d}ahum AAal\q@u{a} baAA\q@u{d}in walal\q@u{a}khiratu akbaru daraj\q@u{a}tin waakbaru taf\q@u{d}eel\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmli{L\q@u{a} tajAAal maAAa All\q@u{a}hi il\q@u{a}han \q@u{a}khara fataqAAuda ma\q@u{th}mooman makh\q@u{th}ool\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmlii{Waqa\q@u{da} rabbuka all\q@u{a} taAAbudoo ill\q@u{a} iyy\q@u{a}hu wabi\q@b{a}lw\q@u{a}lidayni i\q@u{h}s\q@u{a}nan imm\q@u{a} yablughanna AAindaka alkibara a\q@u{h}aduhum\q@u{a} aw kil\q@u{a}hum\q@u{a} fal\q@u{a} taqul lahum\q@u{a} offin wal\q@u{a} tanharhum\q@u{a} waqul lahum\q@u{a} qawlan kareem\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmliii{Wa\q@b{i}khfi\q@u{d} lahum\q@u{a} jan\q@u{ah}a a\q@b{l}\q@u{thth}ulli mina a\q@b{l}rra\q@u{h}mati waqul rabbi ir\q@u{h}amhum\q@u{a} kam\q@u{a} rabbay\q@u{a}nee \q@u{s}agheer\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmliv{Rabbukum aAAlamu bim\q@u{a} fee nufoosikum in takoonoo \q@u{sa}li\q@u{h}eena fainnahu k\q@u{a}na lilaww\q@u{a}beena ghafoor\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmlv{Wa\q@u{a}ti \q@u{tha} alqurb\q@u{a} \q@u{h}aqqahu wa\q@b{a}lmiskeena wa\q@b{i}bna a\q@b{l}ssabeeli wal\q@u{a} tuba\q@u{thth}ir tab\q@u{th}eer\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmlvi{Inna almuba\q@u{thth}ireena k\q@u{a}noo ikhw\q@u{a}na a\q@b{l}shshay\q@u{at}eeni wak\q@u{a}na a\q@b{l}shshay\q@u{ta}nu lirabbihi kafoor\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmlvii{Waimm\q@u{a} tuAAri\q@u{d}anna AAanhumu ibtigh\q@u{a}a ra\q@u{h}matin min rabbika tarjooh\q@u{a} faqul lahum qawlan maysoor\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmlviii{Wal\q@u{a} tajAAal yadaka maghloolatan il\q@u{a} AAunuqika wal\q@u{a} tabsu\q@u{t}h\q@u{a} kulla albas\q@u{t}i fataqAAuda malooman ma\q@u{h}soor\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmlix{Inna rabbaka yabsu\q@u{t}u a\q@b{l}rrizqa liman yash\q@u{a}o wayaqdiru innahu k\q@u{a}na biAAib\q@u{a}dihi khabeeran ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmlx{Wal\q@u{a} taqtuloo awl\q@u{a}dakum khashyata iml\q@u{a}qin na\q@u{h}nu narzuquhum waiyy\q@u{a}kum inna qatlahum k\q@u{a}na khi\q@u{t}an kabeer\q@u{a}\q@b{n}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmlxi{Wal\q@u{a} taqraboo a\q@b{l}zzin\q@u{a} innahu k\q@u{a}na f\q@u{ah}ishatan was\q@u{a}a sabeel\q@u{a}\q@b{n}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmlxii{Wal\q@u{a} taqtuloo a\q@b{l}nnafsa allatee \q@u{h}arrama All\q@u{a}hu ill\q@u{a} bi\q@b{a}l\q@u{h}aqqi waman qutila ma\q@i{\q@u{th}}looman faqad jaAAaln\q@u{a} liwaliyyihi sul\q@u{ta}nan fal\q@u{a} yusrif fee alqatli innahu k\q@u{a}na man\q@u{s}oor\q@u{a}\q@b{n}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmlxiii{Wal\q@u{a} taqraboo m\q@u{a}la alyateemi ill\q@u{a} bi\q@b{a}llatee hiya a\q@u{h}sanu \q@u{h}att\q@u{a} yablugha ashuddahu waawfoo bi\q@b{a}lAAahdi inna alAAahda k\q@u{a}na masool\q@u{a}\q@b{n}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmlxiv{Waawfoo alkayla i\q@u{tha} kiltum wazinoo bi\q@b{a}lqis\q@u{ta}si almustaqeemi \q@u{tha}lika khayrun waa\q@u{h}sanu taweel\q@u{a}\q@b{n}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmlxv{Wal\q@u{a} taqfu m\q@u{a} laysa laka bihi AAilmun inna a\q@b{l}ssamAAa wa\q@b{a}lba\q@u{s}ara wa\q@b{a}lfu\q@u{a}da kullu ol\q@u{a}ika k\q@u{a}na AAanhu masool\q@u{a}\q@b{n}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmlxvi{Wal\q@u{a} tamshi fee alar\q@u{d}i mara\q@u{h}an innaka lan takhriqa alar\q@u{d}a walan tablugha aljib\q@u{a}la \q@u{t}ool\q@u{a}\q@b{n}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmlxvii{Kullu \q@u{tha}lika k\q@u{a}na sayyiohu AAinda rabbika makrooh\q@u{a}\q@b{n}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmlxviii{\q@u{Tha}lika mimm\q@u{a} aw\q@u{ha} ilayka rabbuka mina al\q@u{h}ikmati wal\q@u{a} tajAAal maAAa All\q@u{a}hi il\q@u{a}han \q@u{a}khara fatulq\q@u{a} fee jahannama malooman mad\q@u{h}oor\q@u{a}\q@b{n}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmlxix{Afaa\q@u{s}f\q@u{a}kum rabbukum bi\q@b{a}lbaneena wa\q@b{i}ttakha\q@u{th}a mina almal\q@u{a}ikati in\q@u{a}than innakum lataqooloona qawlan AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmlxx{Walaqad \q@u{s}arrafn\q@u{a} fee h\q@u{atha} alqur\q@u{a}ni liya\q@u{thth}akkaroo wam\q@u{a} yazeeduhum ill\q@u{a} nufoor\q@u{a}\q@b{n}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmlxxi{Qul law k\q@u{a}na maAAahu \q@u{a}lihatun kam\q@u{a} yaqooloona i\q@u{th}an la\q@b{i}btaghaw il\q@u{a} \q@u{th}ee alAAarshi sabeel\q@u{a}\q@b{n}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmlxxii{Sub\q@u{ha}nahu wataAA\q@u{a}l\q@u{a} AAamm\q@u{a} yaqooloona AAuluwwan kabeer\q@u{a}\q@b{n}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmlxxiii{Tusabbi\q@u{h}u lahu a\q@b{l}ssam\q@u{a}w\q@u{a}tu a\q@b{l}ssabAAu wa\q@b{a}lar\q@u{d}u waman feehinna wain min shayin ill\q@u{a} yusabbi\q@u{h}u bi\q@u{h}amdihi wal\q@u{a}kin l\q@u{a} tafqahoona tasbee\q@u{h}ahum innahu k\q@u{a}na \q@u{h}aleeman ghafoor\q@u{a}\q@b{n}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmlxxiv{Wai\q@u{tha} qarata alqur\q@u{a}na jaAAaln\q@u{a} baynaka wabayna alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati \q@u{h}ij\q@u{a}ban mastoor\q@u{a}\q@b{n}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmlxxv{WajaAAaln\q@u{a} AAal\q@u{a} quloobihim akinnatan an yafqahoohu wafee \q@u{atha}nihim waqran wai\q@u{tha} \q@u{th}akarta rabbaka fee alqur\q@u{a}ni wa\q@u{h}dahu wallaw AAal\q@u{a} adb\q@u{a}rihim nufoor\q@u{a}\q@b{n}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmlxxvi{Na\q@u{h}nu aAAlamu bim\q@u{a} yastamiAAoona bihi i\q@u{th} yastamiAAoona ilayka wai\q@u{th} hum najw\q@u{a} i\q@u{th} yaqoolu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoona in tattabiAAoona ill\q@u{a} rajulan mas\q@u{h}oor\q@u{a}\q@b{n}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmlxxvii{On\q@i{\q@u{th}}ur kayfa \q@u{d}araboo laka alamth\q@u{a}la fa\q@u{d}alloo fal\q@u{a} yasta\q@u{t}eeAAoona sabeel\q@u{a}\q@b{n}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmlxxviii{Waq\q@u{a}loo ai\q@u{tha} kunn\q@u{a} AAi\q@i{\q@u{th}}\q@u{a}man waruf\q@u{a}tan ainn\q@u{a} lamabAAoothoona khalqan jadeed\q@u{a}\q@b{n}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmlxxix{Qul koonoo \q@u{h}ij\q@u{a}ratan aw \q@u{h}adeed\q@u{a}\q@b{n}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmlxxx{Aw khalqan mimm\q@u{a} yakburu fee \q@u{s}udoorikum fasayaqooloona man yuAAeedun\q@u{a} quli alla\q@u{th}ee fa\q@u{t}arakum awwala marratin fasayunghi\q@u{d}oona ilayka ruoosahum wayaqooloona mat\q@u{a} huwa qul AAas\q@u{a} an yakoona qareeb\q@u{a}\q@b{n}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmlxxxi{Yawma yadAAookum fatastajeeboona bi\q@u{h}amdihi wata\q@i{\q@u{th}}unnoona in labithtum ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmlxxxii{Waqul liAAib\q@u{a}dee yaqooloo allatee hiya a\q@u{h}sanu inna a\q@b{l}shshay\q@u{ta}na yanzaghu baynahum inna a\q@b{l}shshay\q@u{ta}na k\q@u{a}na lilins\q@u{a}ni AAaduwwan mubeen\q@u{a}\q@b{n}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmlxxxiii{Rabbukum aAAlamu bikum in yasha yar\q@u{h}amkum aw in yasha yuAAa\q@u{thth}ibkum wam\q@u{a} arsaln\q@u{a}ka AAalayhim wakeel\q@u{a}\q@b{n}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmlxxxiv{Warabbuka aAAlamu biman fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i walaqad fa\q@u{dd}aln\q@u{a} baAA\q@u{d}a a\q@b{l}nnabiyyeena AAal\q@u{a} baAA\q@u{d}in wa\q@u{a}tayn\q@u{a} d\q@u{a}wooda zaboor\q@u{a}\q@b{n}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmlxxxv{Quli odAAu alla\q@u{th}eena zaAAamtum min doonihi fal\q@u{a} yamlikoona kashfa a\q@b{l}\q@u{dd}urri AAankum wal\q@u{a} ta\q@u{h}weel\q@u{a}\q@b{n}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmlxxxvi{Ol\q@u{a}ika alla\q@u{th}eena yadAAoona yabtaghoona il\q@u{a} rabbihimu alwaseelata ayyuhum aqrabu wayarjoona ra\q@u{h}matahu wayakh\q@u{a}foona AAa\q@u{tha}bahu inna AAa\q@u{tha}ba rabbika k\q@u{a}na ma\q@u{hth}oor\q@u{a}\q@b{n}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmlxxxvii{Wain min qaryatin ill\q@u{a} na\q@u{h}nu muhlikooh\q@u{a} qabla yawmi alqiy\q@u{a}mati aw muAAa\q@u{thth}ibooh\q@u{a} AAa\q@u{tha}ban shadeedan k\q@u{a}na \q@u{tha}lika fee alkit\q@u{a}bi mas\q@u{t}oor\q@u{a}\q@b{n}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmlxxxviii{Wam\q@u{a} manaAAan\q@u{a} an nursila bi\q@b{a}l\q@u{a}y\q@u{a}ti ill\q@u{a} an ka\q@u{thth}aba bih\q@u{a} alawwaloona wa\q@u{a}tayn\q@u{a} thamooda a\q@b{l}nn\q@u{a}qata mub\q@u{s}iratan fa\q@i{\q@u{th}}alamoo bih\q@u{a} wam\q@u{a} nursilu bi\q@b{a}l\q@u{a}y\q@u{a}ti ill\q@u{a} takhweef\q@u{a}\q@b{n}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmlxxxix{Wai\q@u{th} quln\q@u{a} laka inna rabbaka a\q@u{hat}a bi\q@b{al}nn\q@u{a}si wam\q@u{a} jaAAaln\q@u{a} a\q@b{l}rruy\q@u{a} allatee arayn\q@u{a}ka ill\q@u{a} fitnatan li\q@b{l}nn\q@u{a}si wa\q@b{al}shshajarata almalAAoonata fee alqur\q@u{a}ni wanukhawwifuhum fam\q@u{a} yazeeduhum ill\q@u{a} \q@u{t}ughy\q@u{a}nan kabeer\q@u{a}\q@b{n}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmxc{Wai\q@u{th} quln\q@u{a} lilmal\q@u{a}ikati osjudoo li\q@u{a}dama fasajadoo ill\q@u{a} ibleesa q\q@u{a}la aasjudu liman khalaqta \q@u{t}een\q@u{a}\q@b{n}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmxci{Q\q@u{a}la araaytaka h\q@u{atha} alla\q@u{th}ee karramta AAalayya lain akhkhartani il\q@u{a} yawmi alqiy\q@u{a}mati laa\q@u{h}tanikanna \q@u{th}urriyyatahu ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmxcii{Q\q@u{a}la i\q@u{th}hab faman tabiAAaka minhum fainna jahannama jaz\q@u{a}okum jaz\q@u{a}an mawfoor\q@u{a}\q@b{n}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmxciii{Wa\q@b{i}stafziz mani ista\q@u{t}aAAta minhum bi\q@u{s}awtika waajlib AAalayhim bikhaylika warajlika wash\q@u{a}rikhum fee alamw\q@u{a}li wa\q@b{a}lawl\q@u{a}di waAAidhum wam\q@u{a} yaAAiduhumu a\q@b{l}shshay\q@u{ta}nu ill\q@u{a} ghuroor\q@u{a}\q@b{n}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmxciv{Inna AAib\q@u{a}dee laysa laka AAalayhim sul\q@u{ta}nun wakaf\q@u{a} birabbika wakeel\q@u{a}\q@b{n}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmxcv{Rabbukumu alla\q@u{th}ee yuzjee lakumu alfulka fee alba\q@u{h}ri litabtaghoo min fa\q@u{d}lihi innahu k\q@u{a}na bikum ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmxcvi{Wai\q@u{tha} massakumu a\q@b{l}\q@u{dd}urru fee alba\q@u{h}ri \q@u{d}alla man tadAAoona ill\q@u{a} iyy\q@u{a}hu falamm\q@u{a} najj\q@u{a}kum il\q@u{a} albarri aAAra\q@u{d}tum wak\q@u{a}na alins\q@u{a}nu kafoor\q@u{a}\q@b{n}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmxcvii{Afaamintum an yakhsifa bikum j\q@u{a}niba albarri aw yursila AAalaykum \q@u{has}iban thumma l\q@u{a} tajidoo lakum wakeel\q@u{a}\q@b{n}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmxcviii{Am amintum an yuAAeedakum feehi t\q@u{a}ratan okhr\q@u{a} fayursila AAalaykum q\q@u{as}ifan mina a\q@b{l}rree\q@u{h}i fayughriqakum bim\q@u{a} kafartum thumma l\q@u{a} tajidoo lakum AAalayn\q@u{a} bihi tabeeAA\q@u{a}\q@b{n}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmxcix{Walaqad karramn\q@u{a} banee \q@u{a}dama wa\q@u{h}amaln\q@u{a}hum fee albarri wa\q@b{a}lba\q@u{h}ri warazaqn\q@u{a}hum mina a\q@b{l}\q@u{tt}ayyib\q@u{a}ti wafa\q@u{dd}aln\q@u{a}hum AAal\q@u{a} katheerin mimman khalaqn\q@u{a} taf\q@u{d}eel\q@u{a}\q@b{n}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmc{Yawma nadAAoo kulla on\q@u{a}sin biim\q@u{a}mihim faman ootiya kit\q@u{a}bahu biyameenihi faol\q@u{a}ika yaqraoona kit\q@u{a}bahum wal\q@u{a} yu\q@i{\q@u{th}}lamoona fateel\q@u{a}\q@b{n}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmci{Waman k\q@u{a}na fee h\q@u{ath}ihi aAAm\q@u{a} fahuwa fee al\q@u{a}khirati aAAm\q@u{a} waa\q@u{d}allu sabeel\q@u{a}\q@b{n}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmcii{Wain k\q@u{a}doo layaftinoonaka AAani alla\q@u{th}ee aw\q@u{h}ayn\q@u{a} ilayka litaftariya AAalayn\q@u{a} ghayrahu wai\q@u{th}an la\q@b{i}ttakha\q@u{th}ooka khaleel\q@u{a}\q@b{n}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmciii{Walawl\q@u{a} an thabbatn\q@u{a}ka laqad kidta tarkanu ilayhim shayan qaleel\q@u{a}\q@b{n}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmciv{I\q@u{th}an laa\q@u{th}aqn\q@u{a}ka \q@u{d}iAAfa al\q@u{h}ay\q@u{a}ti wa\q@u{d}iAAfa almam\q@u{a}ti thumma l\q@u{a} tajidu laka AAalayn\q@u{a} na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmcv{Wain k\q@u{a}doo layastafizzoonaka mina alar\q@u{d}i liyukhrijooka minh\q@u{a} wai\q@u{th}an l\q@u{a} yalbathoona khil\q@u{a}faka ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmcvi{Sunnata man qad arsaln\q@u{a} qablaka min rusulin\q@u{a} wal\q@u{a} tajidu lisunnatin\q@u{a} ta\q@u{h}weel\q@u{a}\q@b{n}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmcvii{Aqimi a\q@b{l}\q@u{ss}al\q@u{a}ta lidulooki a\q@b{l}shshamsi il\q@u{a} ghasaqi allayli waqur\q@u{a}na alfajri inna qur\q@u{a}na alfajri k\q@u{a}na mashhood\q@u{a}\q@b{n}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmcviii{Wamina allayli fatahajjad bihi n\q@u{a}filatan laka AAas\q@u{a} an yabAAathaka rabbuka maq\q@u{a}man ma\q@u{h}mood\q@u{a}\q@b{n}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmcix{Waqul rabbi adkhilnee mudkhala \q@u{s}idqin waakhrijnee mukhraja \q@u{s}idqin wa\q@b{i}jAAal lee min ladunka sul\q@u{ta}nan na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmcx{Waqul j\q@u{a}a al\q@u{h}aqqu wazahaqa alb\q@u{at}ilu inna alb\q@u{at}ila k\q@u{a}na zahooq\q@u{a}\q@b{n}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmcxi{Wanunazzilu mina alqur\q@u{a}ni m\q@u{a} huwa shif\q@u{a}on wara\q@u{h}matun lilmumineena wal\q@u{a} yazeedu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena ill\q@u{a} khas\q@u{a}r\q@u{a}\q@b{n}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmcxii{Wai\q@u{tha} anAAamn\q@u{a} AAal\q@u{a} alins\q@u{a}ni aAAra\q@u{d}a wana\q@u{a} bij\q@u{a}nibihi wai\q@u{tha} massahu a\q@b{l}shsharru k\q@u{a}na yaoos\q@u{a}\q@b{n}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmcxiii{Qul kullun yaAAmalu AAal\q@u{a} sh\q@u{a}kilatihi farabbukum aAAlamu biman huwa ahd\q@u{a} sabeel\q@u{a}\q@b{n}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmcxiv{Wayasaloonaka AAani a\q@b{l}rroo\q@u{h}i quli a\q@b{l}rroo\q@u{h}u min amri rabbee wam\q@u{a} ooteetum mina alAAilmi ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmcxv{Walain shin\q@u{a} lana\q@u{th}habanna bi\q@b{a}lla\q@u{th}ee aw\q@u{h}ayn\q@u{a} ilayka thumma l\q@u{a} tajidu laka bihi AAalayn\q@u{a} wakeel\q@u{a}\q@b{n}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmcxvi{Ill\q@u{a} ra\q@u{h}matan min rabbika inna fa\q@u{d}lahu k\q@u{a}na AAalayka kabeer\q@u{a}\q@b{n}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmcxvii{Qul laini ijtamaAAati alinsu wa\q@b{a}ljinnu AAal\q@u{a} an yatoo bimithli h\q@u{atha} alqur\q@u{a}ni l\q@u{a} yatoona bimithlihi walaw k\q@u{a}na baAA\q@u{d}uhum libaAA\q@u{d}in \q@i{\q@u{th}}aheer\q@u{a}\q@b{n}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmcxviii{Walaqad \q@u{s}arrafn\q@u{a} li\q@b{l}nn\q@u{a}si fee h\q@u{atha} alqur\q@u{a}ni min kulli mathalin faab\q@u{a} aktharu a\q@b{l}nn\q@u{a}si ill\q@u{a} kufoor\q@u{a}\q@b{n}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmcxix{Waq\q@u{a}loo lan numina laka \q@u{h}att\q@u{a} tafjura lan\q@u{a} mina alar\q@u{d}i yanbooAA\q@u{a}\q@b{n}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmcxx{Aw takoona laka jannatun min nakheelin waAAinabin fatufajjira alanh\q@u{a}ra khil\q@u{a}lah\q@u{a} tafjeer\q@u{a}\q@b{n}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmcxxi{Aw tusqi\q@u{t}a a\q@b{l}ssam\q@u{a}a kam\q@u{a} zaAAamta AAalayn\q@u{a} kisafan aw tatiya bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lmal\q@u{a}ikati qabeel\q@u{a}\q@b{n}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmcxxii{Aw yakoona laka baytun min zukhrufin aw tarq\q@u{a} fee a\q@b{l}ssam\q@u{a}i walan numina liruqiyyika \q@u{h}att\q@u{a} tunazzila AAalayn\q@u{a} kit\q@u{a}ban naqraohu qul sub\q@u{ha}na rabbee hal kuntu ill\q@u{a} basharan rasool\q@u{a}\q@b{n}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmcxxiii{Wam\q@u{a} manaAAa a\q@b{l}nn\q@u{a}sa an yuminoo i\q@u{th} j\q@u{a}ahumu alhud\q@u{a} ill\q@u{a} an q\q@u{a}loo abaAAatha All\q@u{a}hu basharan rasool\q@u{a}\q@b{n}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mmcxxiv{Qul law k\q@u{a}na fee alar\q@u{d}i mal\q@u{a}ikatun yamshoona mu\q@u{t}mainneena lanazzaln\q@u{a} AAalayhim mina a\q@b{l}ssam\q@u{a}i malakan rasool\q@u{a}\q@b{n}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mmcxxv{Qul kaf\q@u{a} bi\q@b{A}ll\q@u{a}hi shaheedan baynee wabaynakum innahu k\q@u{a}na biAAib\q@u{a}dihi khabeeran ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mmcxxvi{Waman yahdi All\q@u{a}hu fahuwa almuhtadi waman yu\q@u{d}lil falan tajida lahum awliy\q@u{a}a min doonihi wana\q@u{h}shuruhum yawma alqiy\q@u{a}mati AAal\q@u{a} wujoohihim AAumyan wabukman wa\q@u{s}umman maw\q@u{a}hum jahannamu kullam\q@u{a} khabat zidn\q@u{a}hum saAAeer\q@u{a}\q@b{n}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mmcxxvii{\q@u{Tha}lika jaz\q@u{a}ohum biannahum kafaroo bi\q@u{a}y\q@u{a}tin\q@u{a} waq\q@u{a}loo ai\q@u{tha} kunn\q@u{a} AAi\q@i{\q@u{th}}\q@u{a}man waruf\q@u{a}tan ainn\q@u{a} lamabAAoothoona khalqan jadeed\q@u{a}\q@b{n}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mmcxxviii{Awalam yaraw anna All\q@u{a}ha alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a q\q@u{a}dirun AAal\q@u{a} an yakhluqa mithlahum wajaAAala lahum ajalan l\q@u{a} rayba feehi faab\q@u{a} a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoona ill\q@u{a} kufoor\q@u{a}\q@b{n}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mmcxxix{Qul law antum tamlikoona khaz\q@u{a}ina ra\q@u{h}mati rabbee i\q@u{th}an laamsaktum khashyata alinf\q@u{a}qi wak\q@u{a}na alins\q@u{a}nu qatoor\q@u{a}\q@b{n}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mmcxxx{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} tisAAa \q@u{a}y\q@u{a}tin bayyin\q@u{a}tin fa\q@b{i}sal banee isr\q@u{a}eela i\q@u{th} j\q@u{a}ahum faq\q@u{a}la lahu firAAawnu innee laa\q@i{\q@u{th}}unnuka y\q@u{a} moos\q@u{a} mas\q@u{h}oor\q@u{a}\q@b{n}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mmcxxxi{Q\q@u{a}la laqad AAalimta m\q@u{a} anzala h\q@u{a}ol\q@u{a}i ill\q@u{a} rabbu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i ba\q@u{sa}ira wainnee laa\q@i{\q@u{th}}unnuka y\q@u{a} firAAawnu mathboor\q@u{a}\q@b{n}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mmcxxxii{Faar\q@u{a}da an yastafizzahum mina alar\q@u{d}i faaghraqn\q@u{a}hu waman maAAahu jameeAA\q@u{a}\q@b{n}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mmcxxxiii{Waquln\q@u{a} min baAAdihi libanee isr\q@u{a}eela oskunoo alar\q@u{d}a fai\q@u{tha} j\q@u{a}a waAAdu al\q@u{a}khirati jin\q@u{a} bikum lafeef\q@u{a}\q@b{n}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mmcxxxiv{Wabi\q@b{a}l\q@u{h}aqqi anzaln\q@u{a}hu wabi\q@b{a}l\q@u{h}aqqi nazala wam\q@u{a} arsaln\q@u{a}ka ill\q@u{a} mubashshiran wana\q@u{th}eer\q@u{a}\q@b{n}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mmcxxxv{Waqur\q@u{a}nan faraqn\q@u{a}hu litaqraahu AAal\q@u{a} a\q@b{l}nn\q@u{a}si AAal\q@u{a} mukthin wanazzaln\q@u{a}hu tanzeel\q@u{a}\q@b{n}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mmcxxxvi{Qul \q@u{a}minoo bihi aw l\q@u{a} tuminoo inna alla\q@u{th}eena ootoo alAAilma min qablihi i\q@u{tha} yutl\q@u{a} AAalayhim yakhirroona lila\q@u{th}q\q@u{a}ni sujjad\q@u{a}\q@b{n}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mmcxxxvii{Wayaqooloona sub\q@u{ha}na rabbin\q@u{a} in k\q@u{a}na waAAdu rabbin\q@u{a} lamafAAool\q@u{a}\q@b{n}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mmcxxxviii{Wayakhirroona lila\q@u{th}q\q@u{a}ni yabkoona wayazeeduhum khushooAA\q@u{a}\q@b{n}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mmcxxxix{Quli odAAoo All\q@u{a}ha awi odAAoo a\q@b{l}rra\q@u{h}m\q@u{a}na ayyan m\q@u{a} tadAAoo falahu alasm\q@u{a}o al\q@u{h}usn\q@u{a} wal\q@u{a} tajhar bi\q@u{s}al\q@u{a}tika wal\q@u{a} tukh\q@u{a}fit bih\q@u{a} wa\q@b{i}btaghi bayna \q@u{tha}lika sabeel\q@u{a}\q@b{n}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mmcxl{Waquli al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee lam yattakhi\q@u{th} waladan walam yakun lahu shareekun fee almulki walam yakun lahu waliyyun mina a\q@b{l}\q@u{thth}ulli wakabbirhu takbeer\q@u{a}\q@b{n}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mmcxli{\basmalahlt Al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee anzala AAal\q@u{a} AAabdihi alkit\q@u{a}ba walam yajAAal lahu AAiwaj\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmcxlii{Qayyiman liyun\q@u{th}ira basan shadeedan min ladunhu wayubashshira almumineena alla\q@u{th}eena yaAAmaloona a\q@b{l}\q@u{ssa}li\q@u{ha}ti anna lahum ajran \q@u{h}asan\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmcxliii{M\q@u{a}kitheena feehi abad\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmcxliv{Wayun\q@u{th}ira alla\q@u{th}eena q\q@u{a}loo ittakha\q@u{th}a All\q@u{a}hu walad\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmcxlv{M\q@u{a} lahum bihi min AAilmin wal\q@u{a} li\q@u{a}b\q@u{a}ihim kaburat kalimatan takhruju min afw\q@u{a}hihim in yaqooloona ill\q@u{a} ka\q@u{th}ib\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmcxlvi{FalaAAallaka b\q@u{a}khiAAun nafsaka AAal\q@u{a} \q@u{a}th\q@u{a}rihim in lam yuminoo bih\q@u{atha} al\q@u{h}adeethi asaf\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmcxlvii{Inn\q@u{a} jaAAaln\q@u{a} m\q@u{a} AAal\q@u{a} alar\q@u{d}i zeenatan lah\q@u{a} linabluwahum ayyuhum a\q@u{h}sanu AAamal\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmcxlviii{Wainn\q@u{a} laj\q@u{a}AAiloona m\q@u{a} AAalayh\q@u{a} \q@u{s}aAAeedan juruz\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmcxlix{Am \q@u{h}asibta anna a\q@u{s}\q@u{ha}ba alkahfi wa\q@b{al}rraqeemi k\q@u{a}noo min \q@u{a}y\q@u{a}tin\q@u{a} AAajab\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmcl{I\q@u{th} aw\q@u{a} alfityatu il\q@u{a} alkahfi faq\q@u{a}loo rabban\q@u{a} \q@u{a}tin\q@u{a} min ladunka ra\q@u{h}matan wahayyi lan\q@u{a} min amrin\q@u{a} rashad\q@u{a}\q@b{n}\q@u{}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmcli{Fa\q@u{d}arabn\q@u{a} AAal\q@u{a} \q@u{atha}nihim fee alkahfi sineena AAadad\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmclii{Thumma baAAathn\q@u{a}hum linaAAlama ayyu al\q@u{h}izbayni a\q@u{hsa} lim\q@u{a} labithoo amad\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmcliii{Na\q@u{h}nu naqu\q@u{ss}u AAalayka nabaahum bi\q@b{a}l\q@u{h}aqqi innahum fityatun \q@u{a}manoo birabbihim wazidn\q@u{a}hum hud\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmcliv{Waraba\q@u{t}n\q@u{a} AAal\q@u{a} quloobihim i\q@u{th} q\q@u{a}moo faq\q@u{a}loo rabbun\q@u{a} rabbu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i lan nadAAuwa min doonihi il\q@u{a}han laqad quln\q@u{a} i\q@u{th}an sha\q@u{t}a\q@u{ta}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmclv{H\q@u{a}ol\q@u{a}i qawmun\q@u{a} ittakha\q@u{th}oo min doonihi \q@u{a}lihatan lawl\q@u{a} yatoona AAalayhim bisul\q@u{ta}nin bayyinin faman a\q@i{\q@u{th}}lamu mimmani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}ib\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmclvi{Wai\q@u{th}i iAAtazaltumoohum wam\q@u{a} yaAAbudoona ill\q@u{a} All\q@u{a}ha fawoo il\q@u{a} alkahfi yanshur lakum rabbukum min ra\q@u{h}matihi wayuhayyi lakum min amrikum mirfaq\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmclvii{Watar\q@u{a} a\q@b{l}shshamsa i\q@u{tha} \q@u{t}alaAAat taz\q@u{a}waru AAan kahfihim \q@u{tha}ta alyameeni wai\q@u{tha} gharabat taqri\q@u{d}uhum \q@u{tha}ta a\q@b{l}shshim\q@u{a}li wahum fee fajwatin minhu \q@u{tha}lika min \q@u{a}y\q@u{a}ti All\q@u{a}hi man yahdi All\q@u{a}hu fahuwa almuhtadi waman yu\q@u{d}lil falan tajida lahu waliyyan murshid\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmclviii{Wata\q@u{h}sabuhum ayq\q@u{a}\q@i{\q@u{th}}an wahum ruqoodun wanuqallibuhum \q@u{tha}ta alyameeni wa\q@u{tha}ta a\q@b{l}shshim\q@u{a}li wakalbuhum b\q@u{a}si\q@u{t}un \q@u{th}ir\q@u{a}AAayhi bi\q@b{a}lwa\q@u{s}eedi lawi i\q@u{tt}alaAAta AAalayhim lawallayta minhum fir\q@u{a}ran walamulita minhum ruAAb\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmclix{Waka\q@u{tha}lika baAAathn\q@u{a}hum liyatas\q@u{a}aloo baynahum q\q@u{a}la q\q@u{a}ilun minhum kam labithtum q\q@u{a}loo labithn\q@u{a} yawman aw baAA\q@u{d}a yawmin q\q@u{a}loo rabbukum aAAlamu bim\q@u{a} labithtum fa\q@b{i}bAAathoo a\q@u{h}adakum biwariqikum h\q@u{ath}ihi il\q@u{a} almadeenati falyan\q@i{\q@u{th}}ur ayyuh\q@u{a} azk\q@u{a} \q@u{t}aAA\q@u{a}man falyatikum birizqin minhu walyatala\q@u{tt}af wal\q@u{a} yushAAiranna bikum a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmclx{Innahum in ya\q@i{\q@u{th}}haroo AAalaykum yarjumookum aw yuAAeedookum fee millatihim walan tufli\q@u{h}oo i\q@u{th}an abad\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmclxi{Waka\q@u{tha}lika aAAtharn\q@u{a} AAalayhim liyaAAlamoo anna waAAda All\q@u{a}hi \q@u{h}aqqun waanna a\q@b{l}s\q@u{a}AAata l\q@u{a} rayba feeh\q@u{a} i\q@u{th} yatan\q@u{a}zaAAoona baynahum amrahum faq\q@u{a}loo ibnoo AAalayhim buny\q@u{a}nan rabbuhum aAAlamu bihim q\q@u{a}la alla\q@u{th}eena ghalaboo AAal\q@u{a} amrihim lanattakhi\q@u{th}anna AAalayhim masjid\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmclxii{Sayaqooloona thal\q@u{a}thatun r\q@u{a}biAAuhum kalbuhum wayaqooloona khamsatun s\q@u{a}disuhum kalbuhum rajman bi\q@b{a}lghaybi wayaqooloona sabAAatun wath\q@u{a}minuhum kalbuhum qul rabbee aAAlamu biAAiddatihim m\q@u{a} yaAAlamuhum ill\q@u{a} qaleelun fal\q@u{a} tum\q@u{a}ri feehim ill\q@u{a} mir\q@u{a}an \q@i{\q@u{th}}\q@u{a}hiran wal\q@u{a} tastafti feehim minhum a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmclxiii{Wal\q@u{a} taqoolanna lishayin innee f\q@u{a}AAilun \q@u{tha}lika ghad\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmclxiv{Ill\q@u{a} an yash\q@u{a}a All\q@u{a}hu wa\q@b{o}\q@u{th}kur rabbaka i\q@u{tha} naseeta waqul AAas\q@u{a} an yahdiyani rabbee liaqraba min h\q@u{atha} rashad\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmclxv{Walabithoo fee kahfihim thal\q@u{a}tha miatin sineena wa\q@b{i}zd\q@u{a}doo tisAA\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmclxvi{Quli All\q@u{a}hu aAAlamu bim\q@u{a} labithoo lahu ghaybu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i ab\q@u{s}ir bihi waasmiAA m\q@u{a} lahum min doonihi min waliyyin wal\q@u{a} yushriku fee \q@u{h}ukmihi a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmclxvii{Wa\q@b{o}tlu m\q@u{a} oo\q@u{h}iya ilayka min kit\q@u{a}bi rabbika l\q@u{a} mubaddila likalim\q@u{a}tihi walan tajida min doonihi multa\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmclxviii{Wa\q@b{i}\q@u{s}bir nafsaka maAAa alla\q@u{th}eena yadAAoona rabbahum bi\q@b{a}lghad\q@u{a}ti wa\q@b{a}lAAashiyyi yureedoona wajhahu wal\q@u{a} taAAdu AAayn\q@u{a}ka AAanhum tureedu zeenata al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wal\q@u{a} tu\q@u{t}iAA man aghfaln\q@u{a} qalbahu AAan \q@u{th}ikrin\q@u{a} wa\q@b{i}ttabaAAa haw\q@u{a}hu wak\q@u{a}na amruhu furu\q@u{ta}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmclxix{Waquli al\q@u{h}aqqu min rabbikum faman sh\q@u{a}a falyumin waman sh\q@u{a}a falyakfur inn\q@u{a} aAAtadn\q@u{a} li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena n\q@u{a}ran a\q@u{hat}a bihim sur\q@u{a}diquh\q@u{a} wain yastagheethoo yugh\q@u{a}thoo bim\q@u{a}in ka\q@b{a}lmuhli yashwee alwujooha bisa a\q@b{l}shshar\q@u{a}bu was\q@u{a}at murtafaq\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmclxx{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti inn\q@u{a} l\q@u{a} nu\q@u{d}eeAAu ajra man a\q@u{h}sana AAamal\q@u{a}\q@b{n}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmclxxi{Ol\q@u{a}ika lahum jann\q@u{a}tu AAadnin tajree min ta\q@u{h}tihimu alanh\q@u{a}ru yu\q@u{h}allawna feeh\q@u{a} min as\q@u{a}wira min \q@u{th}ahabin way\q@b{a}lbasoona thiy\q@u{a}ban khu\q@u{d}ran min sundusin waistabraqin muttakieena feeh\q@u{a} AAal\q@u{a} alar\q@u{a}iki niAAma a\q@b{l}ththaw\q@u{a}bu wa\q@u{h}asunat murtafaq\q@u{a}\q@b{n}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmclxxii{Wa\q@b{i}\q@u{d}rib lahum mathalan rajulayni jaAAaln\q@u{a} lia\q@u{h}adihim\q@u{a} jannatayni min aAAn\q@u{a}bin wa\q@u{h}afafn\q@u{a}hum\q@u{a} binakhlin wajaAAaln\q@u{a} baynahum\q@u{a} zarAA\q@u{a}\q@b{n}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmclxxiii{Kilt\q@u{a} aljannatayni \q@u{a}tat okulah\q@u{a} walam ta\q@i{\q@u{th}}lim minhu shayan wafajjarn\q@u{a} khil\q@u{a}lahum\q@u{a} nahar\q@u{a}\q@b{n}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmclxxiv{Wak\q@u{a}na lahu thamarun faq\q@u{a}la li\q@u{sah}ibihi wahuwa yu\q@u{ha}wiruhu an\q@u{a} aktharu minka m\q@u{a}lan waaAAazzu nafar\q@u{a}\q@b{n}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmclxxv{Wadakhala jannatahu wahuwa \q@i{\q@u{th}}\q@u{a}limun linafsihi q\q@u{a}la m\q@u{a} a\q@i{\q@u{th}}unnu an tabeeda h\q@u{ath}ihi abad\q@u{a}\q@b{n}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmclxxvi{Wam\q@u{a} a\q@i{\q@u{th}}unnu a\q@b{l}ss\q@u{a}AAata q\q@u{a}imatan walain rudidtu il\q@u{a} rabbee laajidanna khayran minh\q@u{a} munqalab\q@u{a}\q@b{n}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmclxxvii{Q\q@u{a}la lahu \q@u{sah}ibuhu wahuwa yu\q@u{ha}wiruhu akafarta bi\q@b{a}lla\q@u{th}ee khalaqaka min tur\q@u{a}bin thumma min nu\q@u{t}fatin thumma saww\q@u{a}ka rajul\q@u{a}\q@b{n}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmclxxviii{L\q@u{a}kinna huwa All\q@u{a}hu rabbee wal\q@u{a} oshriku birabbee a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmclxxix{Walawl\q@u{a} i\q@u{th} dakhalta jannataka qulta m\q@u{a} sh\q@u{a}a All\q@u{a}hu l\q@u{a} quwwata ill\q@u{a} bi\q@b{A}ll\q@u{a}hi in tarani an\q@u{a} aqalla minka m\q@u{a}lan wawalad\q@u{a}\q@b{n}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmclxxx{FaAAas\q@u{a} rabbee an yutiyani khayran min jannatika wayursila AAalayh\q@u{a} \q@u{h}usb\q@u{a}nan mina a\q@b{l}ssam\q@u{a}i fatu\q@u{s}bi\q@u{h}a \q@u{s}aAAeedan zalaq\q@u{a}\q@b{n}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmclxxxi{Aw yu\q@u{s}bi\q@u{h}a m\q@u{a}oh\q@u{a} ghawran falan tasta\q@u{t}eeAAa lahu \q@u{t}alab\q@u{a}\q@b{n}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmclxxxii{Wao\q@u{h}ee\q@u{t}a bithamarihi faa\q@u{s}ba\q@u{h}a yuqallibu kaffayhi AAal\q@u{a} m\q@u{a} anfaqa feeh\q@u{a} wahiya kh\q@u{a}wiyatun AAal\q@u{a} AAurooshih\q@u{a} wayaqoolu y\q@u{a} laytanee lam oshrik birabbee a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmclxxxiii{Walam takun lahu fiatun yan\q@u{s}uroonahu min dooni All\q@u{a}hi wam\q@u{a} k\q@u{a}na munta\q@u{s}ir\q@u{a}\q@b{n}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmclxxxiv{Hun\q@u{a}lika alwal\q@u{a}yatu lill\q@u{a}hi al\q@u{h}aqqi huwa khayrun thaw\q@u{a}ban wakhayrun AAuqb\q@u{a}\q@b{n}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmclxxxv{Wa\q@b{i}\q@u{d}rib lahum mathala al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} kam\q@u{a}in anzaln\q@u{a}hu mina a\q@b{l}ssam\q@u{a}i fa\q@b{i}khtala\q@u{t}a bihi nab\q@u{a}tu alar\q@u{d}i faa\q@u{s}ba\q@u{h}a hasheeman ta\q@u{th}roohu a\q@b{l}rriy\q@u{ah}u wak\q@u{a}na All\q@u{a}hu AAal\q@u{a} kulli shayin muqtadir\q@u{a}\q@b{n}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmclxxxvi{Alm\q@u{a}lu wa\q@b{a}lbanoona zeenatu al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wa\q@b{a}lb\q@u{a}qiy\q@u{a}tu a\q@b{l}\q@u{ssa}li\q@u{ha}tu khayrun AAinda rabbika thaw\q@u{a}ban wakhayrun amal\q@u{a}\q@b{n}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmclxxxvii{Wayawma nusayyiru aljib\q@u{a}la watar\q@u{a} alar\q@u{d}a b\q@u{a}rizatan wa\q@u{h}asharn\q@u{a}hum falam nugh\q@u{a}dir minhum a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmclxxxviii{WaAAuri\q@u{d}oo AAal\q@u{a} rabbika \q@u{s}affan laqad jitumoon\q@u{a} kam\q@u{a} khalaqn\q@u{a}kum awwala marratin bal zaAAamtum allan najAAala lakum mawAAid\q@u{a}\q@b{n}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmclxxxix{Wawu\q@u{d}iAAa alkit\q@u{a}bu fatar\q@u{a} almujrimeena mushfiqeena mimm\q@u{a} feehi wayaqooloona y\q@u{a} waylatan\q@u{a} m\q@u{a} lih\q@u{atha} alkit\q@u{a}bi l\q@u{a} yugh\q@u{a}diru \q@u{s}agheeratan wal\q@u{a} kabeeratan ill\q@u{a} a\q@u{hsa}h\q@u{a} wawajadoo m\q@u{a} AAamiloo \q@u{had}iran wal\q@u{a} ya\q@i{\q@u{th}}limu rabbuka a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmcxc{Wai\q@u{th} quln\q@u{a} lilmal\q@u{a}ikati osjudoo li\q@u{a}dama fasajadoo ill\q@u{a} ibleesa k\q@u{a}na mina aljinni fafasaqa AAan amri rabbihi afatattakhi\q@u{th}oonahu wa\q@u{th}urriyyatahu awliy\q@u{a}a min doonee wahum lakum AAaduwwun bisa li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena badal\q@u{a}\q@b{n}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmcxci{M\q@u{a} ashhadtuhum khalqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wal\q@u{a} khalqa anfusihim wam\q@u{a} kuntu muttakhi\q@u{th}a almu\q@u{d}illeena AAa\q@u{d}ud\q@u{a}\q@b{n}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmcxcii{Wayawma yaqoolu n\q@u{a}doo shurak\q@u{a}iya alla\q@u{th}eena zaAAamtum fadaAAawhum falam yastajeeboo lahum wajaAAaln\q@u{a} baynahum mawbiq\q@u{a}\q@b{n}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmcxciii{Wara\q@u{a} almujrimoona a\q@b{l}nn\q@u{a}ra fa\q@i{\q@u{th}}annoo annahum muw\q@u{a}qiAAooh\q@u{a} walam yajidoo AAanh\q@u{a} ma\q@u{s}rif\q@u{a}\q@b{n}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmcxciv{Walaqad \q@u{s}arrafn\q@u{a} fee h\q@u{atha} alqur\q@u{a}ni li\q@b{l}nn\q@u{a}si min kulli mathalin wak\q@u{a}na alins\q@u{a}nu akthara shayin jadal\q@u{a}\q@b{n}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmcxcv{Wam\q@u{a} manaAAa a\q@b{l}nn\q@u{a}sa an yuminoo i\q@u{th} j\q@u{a}ahumu alhud\q@u{a} wayastaghfiroo rabbahum ill\q@u{a} an tatiyahum sunnatu alawwaleena aw yatiyahumu alAAa\q@u{tha}bu qubul\q@u{a}\q@b{n}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmcxcvi{Wam\q@u{a} nursilu almursaleena ill\q@u{a} mubashshireena wamun\q@u{th}ireena wayuj\q@u{a}dilu alla\q@u{th}eena kafaroo bi\q@b{a}lb\q@u{at}ili liyud\q@u{h}i\q@u{d}oo bihi al\q@u{h}aqqa wa\q@b{i}ttakha\q@u{th}oo \q@u{a}y\q@u{a}tee wam\q@u{a} on\q@u{th}iroo huzuw\q@u{a}\q@b{n}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmcxcvii{Waman a\q@i{\q@u{th}}lamu mimman \q@u{th}ukkira bi\q@u{a}y\q@u{a}ti rabbihi faaAAra\q@u{d}a AAanh\q@u{a} wanasiya m\q@u{a} qaddamat yad\q@u{a}hu inn\q@u{a} jaAAaln\q@u{a} AAal\q@u{a} quloobihim akinnatan an yafqahoohu wafee \q@u{atha}nihim waqran wain tadAAuhum il\q@u{a} alhud\q@u{a} falan yahtadoo i\q@u{th}an abad\q@u{a}\q@b{n}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmcxcviii{Warabbuka alghafooru \q@u{th}oo a\q@b{l}rra\q@u{h}mati law yu\q@u{a}khi\q@u{th}uhum bim\q@u{a} kasaboo laAAajjala lahumu alAAa\q@u{tha}ba bal lahum mawAAidun lan yajidoo min doonihi mawil\q@u{a}\q@b{n}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmcxcix{Watilka alqur\q@u{a} ahlakn\q@u{a}hum lamm\q@u{a} \q@i{\q@u{th}}alamoo wajaAAaln\q@u{a} limahlikihim mawAAid\q@u{a}\q@b{n}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmcc{Wai\q@u{th} q\q@u{a}la moos\q@u{a} lifat\q@u{a}hu l\q@u{a} abra\q@u{h}u \q@u{h}att\q@u{a} ablugha majmaAAa alba\q@u{h}rayni aw am\q@u{d}iya \q@u{h}uqub\q@u{a}\q@b{n}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmcci{Falamm\q@u{a} balagh\q@u{a} majmaAAa baynihim\q@u{a} nasiy\q@u{a} \q@u{h}ootahum\q@u{a} fa\q@b{i}ttakha\q@u{th}a sabeelahu fee alba\q@u{h}ri sarab\q@u{a}\q@b{n}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmccii{Falamm\q@u{a} j\q@u{a}waz\q@u{a} q\q@u{a}la lifat\q@u{a}hu \q@u{a}tin\q@u{a} ghad\q@u{a}an\q@u{a} laqad laqeen\q@u{a} min safarin\q@u{a} h\q@u{atha} na\q@u{s}ab\q@u{a}\q@b{n}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmcciii{Q\q@u{a}la araayta i\q@u{th} awayn\q@u{a} il\q@u{a} a\q@b{l}\q@u{ss}akhrati fainnee naseetu al\q@u{h}oota wam\q@u{a} ans\q@u{a}neehu ill\q@u{a} a\q@b{l}shshay\q@u{ta}nu an a\q@u{th}kurahu wa\q@b{i}ttakha\q@u{th}a sabeelahu fee alba\q@u{h}ri AAajab\q@u{a}\q@b{n}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmcciv{Q\q@u{a}la \q@u{tha}lika m\q@u{a} kunn\q@u{a} nabghi fa\q@b{i}rtadd\q@u{a} AAal\q@u{a} \q@u{a}th\q@u{a}rihim\q@u{a} qa\q@u{s}a\q@u{sa}\q@b{n}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmccv{Fawajad\q@u{a} AAabdan min AAib\q@u{a}din\q@u{a} \q@u{a}tayn\q@u{a}hu ra\q@u{h}matan min AAindin\q@u{a} waAAallamn\q@u{a}hu min ladunn\q@u{a} AAilm\q@u{a}\q@b{n}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmccvi{Q\q@u{a}la lahu moos\q@u{a} hal attabiAAuka AAal\q@u{a} an tuAAallimani mimm\q@u{a} AAullimta rushd\q@u{a}\q@b{n}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmccvii{Q\q@u{a}la innaka lan tasta\q@u{t}eeAAa maAAiya \q@u{s}abr\q@u{a}\q@b{n}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmccviii{Wakayfa ta\q@u{s}biru AAal\q@u{a} m\q@u{a} lam tu\q@u{h}i\q@u{t} bihi khubr\q@u{a}\q@b{n}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmccix{Q\q@u{a}la satajidunee in sh\q@u{a}a All\q@u{a}hu \q@u{sa}biran wal\q@u{a} aAA\q@u{s}ee laka amr\q@u{a}\q@b{n}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmccx{Q\q@u{a}la faini ittabaAAtanee fal\q@u{a} tasalnee AAan shayin \q@u{h}att\q@u{a} o\q@u{h}ditha laka minhu \q@u{th}ikr\q@u{a}\q@b{n}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmccxi{Fa\q@b{i}n\q@u{t}alaq\q@u{a} \q@u{h}att\q@u{a} i\q@u{tha} rakib\q@u{a} fee a\q@b{l}ssafeenati kharaqah\q@u{a} q\q@u{a}la akharaqtah\q@u{a} litughriqa ahlah\q@u{a} laqad jita shayan imr\q@u{a}\q@b{n}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmccxii{Q\q@u{a}la alam aqul innaka lan tasta\q@u{t}eeAAa maAAiya \q@u{s}abr\q@u{a}\q@b{n}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmccxiii{Q\q@u{a}la l\q@u{a} tu\q@u{a}khi\q@u{th}nee bim\q@u{a} naseetu wal\q@u{a} turhiqnee min amree AAusr\q@u{a}\q@b{n}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmccxiv{Fa\q@b{i}n\q@u{t}alaq\q@u{a} \q@u{h}att\q@u{a} i\q@u{tha} laqiy\q@u{a} ghul\q@u{a}man faqatalahu q\q@u{a}la aqatalta nafsan zakiyyatan bighayri nafsin laqad jita shayan nukr\q@u{a}\q@b{n}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmccxv{Q\q@u{a}la alam aqul laka innaka lan tasta\q@u{t}eeAAa maAAiya \q@u{s}abr\q@u{a}\q@b{n}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmccxvi{Q\q@u{a}la in saaltuka AAan shayin baAAdah\q@u{a} fal\q@u{a} tu\q@u{sah}ibnee qad balaghta min ladunnee AAu\q@u{th}r\q@u{a}\q@b{n}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmccxvii{Fa\q@b{i}n\q@u{t}alaq\q@u{a} \q@u{h}att\q@u{a} i\q@u{tha} atay\q@u{a} ahla qaryatin ista\q@u{t}AAam\q@u{a} ahlah\q@u{a} faabaw an yu\q@u{d}ayyifoohum\q@u{a} fawajad\q@u{a} feeh\q@u{a} jid\q@u{a}ran yureedu an yanqa\q@u{dd}a faaq\q@u{a}mahu q\q@u{a}la law shita la\q@b{i}ttakha\q@u{th}ta AAalayhi ajr\q@u{a}\q@b{n}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmccxviii{Q\q@u{a}la h\q@u{atha} fir\q@u{a}qu baynee wabaynika saonabbioka bitaweeli m\q@u{a} lam tasta\q@u{t}iAA AAalayhi \q@u{s}abr\q@u{a}\q@b{n}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmccxix{Amm\q@u{a} a\q@b{l}ssafeenatu fak\q@u{a}nat limas\q@u{a}keena yaAAmaloona fee alba\q@u{h}ri faaradtu an aAAeebah\q@u{a} wak\q@u{a}na war\q@u{a}ahum malikun yakhu\q@u{th}u kulla safeenatin gha\q@u{s}b\q@u{a}\q@b{n}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmccxx{Waamm\q@u{a} alghul\q@u{a}mu fak\q@u{a}na abaw\q@u{a}hu muminayni fakhasheen\q@u{a} an yurhiqahum\q@u{a} \q@u{t}ughy\q@u{a}nan wakufr\q@u{a}\q@b{n}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmccxxi{Faaradn\q@u{a} an yubdilahum\q@u{a} rabbuhum\q@u{a} khayran minhu zak\q@u{a}tan waaqraba ru\q@u{h}m\q@u{a}\q@b{n}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmccxxii{Waamm\q@u{a} aljid\q@u{a}ru fak\q@u{a}na lighul\q@u{a}mayni yateemayni fee almadeenati wak\q@u{a}na ta\q@u{h}tahu kanzun lahum\q@u{a} wak\q@u{a}na aboohum\q@u{a} \q@u{sa}li\q@u{h}an faar\q@u{a}da rabbuka an yablugh\q@u{a} ashuddahum\q@u{a} wayastakhrij\q@u{a} kanzahum\q@u{a} ra\q@u{h}matan min rabbika wam\q@u{a} faAAaltuhu AAan amree \q@u{tha}lika taweelu m\q@u{a} lam tas\q@u{t}iAA AAalayhi \q@u{s}abr\q@u{a}\q@b{n}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmccxxiii{Wayasaloonaka AAan \q@u{th}ee alqarnayni qul saatloo AAalaykum minhu \q@u{th}ikr\q@u{a}\q@b{n}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmccxxiv{Inn\q@u{a} makkann\q@u{a} lahu fee alar\q@u{d}i wa\q@u{a}tayn\q@u{a}hu min kulli shayin sabab\q@u{a}\q@b{n}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmccxxv{FaatbaAAa sabab\q@u{a}\q@b{n}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmccxxvi{\q@u{H}att\q@u{a} i\q@u{tha} balagha maghriba a\q@b{l}shshamsi wajadah\q@u{a} taghrubu fee AAaynin \q@u{h}amiatin wawajada AAindah\q@u{a} qawman quln\q@u{a} y\q@u{a} \q@u{tha} alqarnayni imm\q@u{a} an tuAAa\q@u{thth}iba waimm\q@u{a} an tattakhi\q@u{th}a feehim \q@u{h}usn\q@u{a}\q@b{n}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmccxxvii{Q\q@u{a}la amm\q@u{a} man \q@i{\q@u{th}}alama fasawfa nuAAa\q@u{thth}ibuhu thumma yuraddu il\q@u{a} rabbihi fayuAAa\q@u{thth}ibuhu AAa\q@u{tha}ban nukr\q@u{a}\q@b{n}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmccxxviii{Waamm\q@u{a} man \q@u{a}mana waAAamila \q@u{sa}li\q@u{h}an falahu jaz\q@u{a}an al\q@u{h}usn\q@u{a} wasanaqoolu lahu min amrin\q@u{a} yusr\q@u{a}\q@b{n}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmccxxix{Thumma atbaAAa sabab\q@u{a}\q@b{n}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmccxxx{\q@u{H}att\q@u{a} i\q@u{tha} balagha ma\q@u{t}liAAa a\q@b{l}shshamsi wajadah\q@u{a} ta\q@u{t}luAAu AAal\q@u{a} qawmin lam najAAal lahum min doonih\q@u{a} sitr\q@u{a}\q@b{n}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmccxxxi{Ka\q@u{tha}lika waqad a\q@u{h}a\q@u{t}n\q@u{a} bim\q@u{a} ladayhi khubr\q@u{a}\q@b{n}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmccxxxii{Thumma atbaAAa sabab\q@u{a}\q@b{n}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmccxxxiii{\q@u{H}att\q@u{a} i\q@u{tha} balagha bayna a\q@b{l}ssaddayni wajada min doonihim\q@u{a} qawman l\q@u{a} yak\q@u{a}doona yafqahoona qawl\q@u{a}\q@b{n}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmccxxxiv{Q\q@u{a}loo y\q@u{a} \q@u{tha} alqarnayni inna yajooja wamajooja mufsidoona fee alar\q@u{d}i fahal najAAalu laka kharjan AAal\q@u{a} an tajAAala baynan\q@u{a} wabaynahum sadd\q@u{a}\q@b{n}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mmccxxxv{Q\q@u{a}la m\q@u{a} makkannee feehi rabbee khayrun faaAAeenoonee biquwwatin ajAAal baynakum wabaynahum radm\q@u{a}\q@b{n}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mmccxxxvi{\q@u{A}toonee zubara al\q@u{h}adeedi \q@u{h}att\q@u{a} i\q@u{tha} s\q@u{a}w\q@u{a} bayna a\q@b{l}\q@u{s}adafayni q\q@u{a}la onfukhoo \q@u{h}att\q@u{a} i\q@u{tha} jaAAalahu n\q@u{a}ran q\q@u{a}la \q@u{a}toonee ofrigh AAalayhi qi\q@u{t}r\q@u{a}\q@b{n}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mmccxxxvii{Fam\q@u{a} is\q@u{ta}AAoo an ya\q@i{\q@u{th}}haroohu wam\q@u{a} ista\q@u{ta}AAoo lahu naqb\q@u{a}\q@b{n}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mmccxxxviii{Q\q@u{a}la h\q@u{atha} ra\q@u{h}matun min rabbee fai\q@u{tha} j\q@u{a}a waAAdu rabbee jaAAalahu dakk\q@u{a}a wak\q@u{a}na waAAdu rabbee \q@u{h}aqq\q@u{a}\q@b{n}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mmccxxxix{Watarakn\q@u{a} baAA\q@u{d}ahum yawmai\q@u{th}in yamooju fee baAA\q@u{d}in wanufikha fee a\q@b{l}\q@u{ss}oori fajamaAAn\q@u{a}hum jamAA\q@u{a}\q@b{n}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mmccxl{WaAAara\q@u{d}n\q@u{a} jahannama yawmai\q@u{th}in lilk\q@u{a}fireena AAar\q@u{da}\q@b{n}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mmccxli{Alla\q@u{th}eena k\q@u{a}nat aAAyunuhum fee ghi\q@u{ta}in AAan \q@u{th}ikree wak\q@u{a}noo l\q@u{a} yasta\q@u{t}eeAAoona samAA\q@u{a}\q@b{n}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mmccxlii{Afa\q@u{h}asiba alla\q@u{th}eena kafaroo an yattakhi\q@u{th}oo AAib\q@u{a}dee min doonee awliy\q@u{a}a inn\q@u{a} aAAtadn\q@u{a} jahannama lilk\q@u{a}fireena nuzul\q@u{a}\q@b{n}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mmccxliii{Qul hal nunabbiokum bi\q@b{a}lakhsareena aAAm\q@u{a}l\q@u{a}\q@b{n}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mmccxliv{Alla\q@u{th}eena \q@u{d}alla saAAyuhum fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wahum ya\q@u{h}saboona annahum yu\q@u{h}sinoona \q@u{s}unAA\q@u{a}\q@b{n}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mmccxlv{Ol\q@u{a}ika alla\q@u{th}eena kafaroo bi\q@u{a}y\q@u{a}ti rabbihim waliq\q@u{a}ihi fa\q@u{h}abi\q@u{t}at aAAm\q@u{a}luhum fal\q@u{a} nuqeemu lahum yawma alqiy\q@u{a}mati wazn\q@u{a}\q@b{n}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mmccxlvi{\q@u{Tha}lika jaz\q@u{a}ohum jahannamu bim\q@u{a} kafaroo wa\q@b{i}ttakha\q@u{th}oo \q@u{a}y\q@u{a}tee warusulee huzuw\q@u{a}\q@b{n}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mmccxlvii{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti k\q@u{a}nat lahum jann\q@u{a}tu alfirdawsi nuzul\q@u{a}\q@b{n}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mmccxlviii{Kh\q@u{a}lideena feeh\q@u{a} l\q@u{a} yabghoona AAanh\q@u{a} \q@u{h}iwal\q@u{a}\q@b{n}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mmccxlix{Qul law k\q@u{a}na alba\q@u{h}ru mid\q@u{a}dan likalim\q@u{a}ti rabbee lanafida alba\q@u{h}ru qabla an tanfada kalim\q@u{a}tu rabbee walaw jin\q@u{a} bimithlihi madad\q@u{a}\q@b{n}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mmccl{Qul innam\q@u{a} an\q@u{a} basharun mithlukum yoo\q@u{ha} ilayya annam\q@u{a} il\q@u{a}hukum il\q@u{a}hun w\q@u{ah}idun faman k\q@u{a}na yarjoo liq\q@u{a}a rabbihi falyaAAmal AAamalan \q@u{sa}li\q@u{h}an wal\q@u{a} yushrik biAAib\q@u{a}dati rabbihi a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mmccli{\basmalahlt K\q@u{a}fh\q@u{a}y\q@u{a}AAayn\q@u{sa}d\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmcclii{\q@u{Th}ikru ra\q@u{h}mati rabbika AAabdahu zakariyy\q@u{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmccliii{I\q@u{th} n\q@u{a}d\q@u{a} rabbahu nid\q@u{a}an khafiyy\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmccliv{Q\q@u{a}la rabbi innee wahana alAAa\q@i{\q@u{th}}mu minnee wa\q@b{i}shtaAAala a\q@b{l}rrasu shayban walam akun biduAA\q@u{a}ika rabbi shaqiyy\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmcclv{Wainnee khiftu almaw\q@u{a}liya min war\q@u{a}ee wak\q@u{a}nati imraatee AA\q@u{a}qiran fahab lee min ladunka waliyy\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmcclvi{Yarithunee wayarithu min \q@u{a}li yaAAqooba wa\q@b{i}jAAalhu rabbi ra\q@u{d}iyy\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmcclvii{Y\q@u{a} zakariyy\q@u{a} inn\q@u{a} nubashshiruka bighul\q@u{a}min ismuhu ya\q@u{h}y\q@u{a} lam najAAal lahu min qablu samiyy\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmcclviii{Q\q@u{a}la rabbi ann\q@u{a} yakoonu lee ghul\q@u{a}mun wak\q@u{a}nati imraatee AA\q@u{a}qiran waqad balaghtu mina alkibari AAitiyy\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmcclix{Q\q@u{a}la ka\q@u{tha}lika q\q@u{a}la rabbuka huwa AAalayya hayyinun waqad khalaqtuka min qablu walam taku shay\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmcclx{Q\q@u{a}la rabbi ijAAal lee \q@u{a}yatan q\q@u{a}la \q@u{a}yatuka all\q@u{a} tukallima a\q@b{l}nn\q@u{a}sa thal\q@u{a}tha lay\q@u{a}lin sawiyy\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmcclxi{Fakharaja AAal\q@u{a} qawmihi mina almi\q@u{h}r\q@u{a}bi faaw\q@u{ha} ilayhim an sabbi\q@u{h}oo bukratan waAAashiyy\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmcclxii{Y\q@u{a} ya\q@u{h}y\q@u{a} khu\q@u{th}i alkit\q@u{a}ba biquwwatin wa\q@u{a}tayn\q@u{a}hu al\q@u{h}ukma \q@u{s}abiyy\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmcclxiii{Wa\q@u{h}an\q@u{a}nan min ladunn\q@u{a} wazak\q@u{a}tan wak\q@u{a}na taqiyy\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmcclxiv{Wabarran biw\q@u{a}lidayhi walam yakun jabb\q@u{a}ran AAa\q@u{s}iyy\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmcclxv{Wasal\q@u{a}mun AAalayhi yawma wulida wayawma yamootu wayawma yubAAathu \q@u{h}ayy\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmcclxvi{Wa\q@b{o}\q@u{th}kur fee alkit\q@u{a}bi maryama i\q@u{th}i intaba\q@u{th}at min ahlih\q@u{a} mak\q@u{a}nan sharqiyy\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmcclxvii{Fa\q@b{i}ttakha\q@u{th}at min doonihim \q@u{h}ij\q@u{a}ban faarsaln\q@u{a} ilayh\q@u{a} roo\q@u{h}an\q@u{a} fatamaththala lah\q@u{a} basharan sawiyy\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmcclxviii{Q\q@u{a}lat innee aAAoo\q@u{th}u bi\q@b{al}rra\q@u{h}m\q@u{a}ni minka in kunta taqiyy\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmcclxix{Q\q@u{a}la innam\q@u{a} an\q@u{a} rasoolu rabbiki liahaba laki ghul\q@u{a}man zakiyy\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmcclxx{Q\q@u{a}lat ann\q@u{a} yakoonu lee ghul\q@u{a}mun walam yamsasnee basharun walam aku baghiyy\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmcclxxi{Q\q@u{a}la ka\q@u{tha}liki q\q@u{a}la rabbuki huwa AAalayya hayyinun walinajAAalahu \q@u{a}yatan li\q@b{l}nn\q@u{a}si wara\q@u{h}matan minn\q@u{a} wak\q@u{a}na amran maq\q@u{d}iyy\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmcclxxii{Fa\q@u{h}amalathu fa\q@b{i}ntaba\q@u{th}at bihi mak\q@u{a}nan qa\q@u{s}iyy\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmcclxxiii{Faaj\q@u{a}ah\q@u{a} almakh\q@u{ad}u il\q@u{a} ji\q@u{th}AAi a\q@b{l}nnakhlati q\q@u{a}lat y\q@u{a} laytanee mittu qabla h\q@u{atha} wakuntu nasyan mansiyy\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmcclxxiv{Fan\q@u{a}d\q@u{a}h\q@u{a} min ta\q@u{h}tih\q@u{a} all\q@u{a} ta\q@u{h}zanee qad jaAAala rabbuki ta\q@u{h}taki sariyy\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmcclxxv{Wahuzzee ilayki biji\q@u{th}AAi a\q@b{l}nnakhlati tus\q@u{a}qi\q@u{t} AAalayki ru\q@u{t}aban janiyy\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmcclxxvi{Fakulee wa\q@b{i}shrabee waqarree AAaynan faimm\q@u{a} tarayinna mina albashari a\q@u{h}adan faqoolee innee na\q@u{th}artu li\q@b{l}rra\q@u{h}m\q@u{a}ni \q@u{s}awman falan okallima alyawma insiyy\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmcclxxvii{Faatat bihi qawmah\q@u{a} ta\q@u{h}miluhu q\q@u{a}loo y\q@u{a} maryamu laqad jiti shayan fariyy\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmcclxxviii{Y\q@u{a} okhta h\q@u{a}roona m\q@u{a} k\q@u{a}na abooki imraa sawin wam\q@u{a} k\q@u{a}nat ommuki baghiyy\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmcclxxix{Faash\q@u{a}rat ilayhi q\q@u{a}loo kayfa nukallimu man k\q@u{a}na fee almahdi \q@u{s}abiyy\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmcclxxx{Q\q@u{a}la innee AAabdu All\q@u{a}hi \q@u{a}t\q@u{a}niya alkit\q@u{a}ba wajaAAalanee nabiyy\q@u{a}\q@b{n}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmcclxxxi{WajaAAalanee mub\q@u{a}rakan ayna m\q@u{a} kuntu waaw\q@u{sa}nee bi\q@b{al}\q@u{ss}al\q@u{a}ti wa\q@b{al}zzak\q@u{a}ti m\q@u{a} dumtu \q@u{h}ayy\q@u{a}\q@b{n}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmcclxxxii{Wabarran biw\q@u{a}lidatee walam yajAAalnee jabb\q@u{a}ran shaqiyy\q@u{a}\q@b{n}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmcclxxxiii{Wa\q@b{al}ssal\q@u{a}mu AAalayya yawma wulidtu wayawma amootu wayawma obAAathu \q@u{h}ayy\q@u{a}\q@b{n}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmcclxxxiv{\q@u{Tha}lika AAees\q@u{a} ibnu maryama qawla al\q@u{h}aqqi alla\q@u{th}ee feehi yamtaroon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmcclxxxv{M\q@u{a} k\q@u{a}na lill\q@u{a}hi an yattakhi\q@u{th}a min waladin sub\q@u{ha}nahu i\q@u{tha} qa\q@u{da} amran fainnam\q@u{a} yaqoolu lahu kun fayakoon\q@b{u}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmcclxxxvi{Wainna All\q@u{a}ha rabbee warabbukum fa\q@b{o}AAbudoohu h\q@u{atha} \q@u{s}ir\q@u{at}un mustaqeem\q@b{un}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmcclxxxvii{Fa\q@b{i}khtalafa ala\q@u{h}z\q@u{a}bu min baynihim fawaylun lilla\q@u{th}eena kafaroo min mashhadi yawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmcclxxxviii{AsmiAA bihim waab\q@u{s}ir yawma yatoonan\q@u{a} l\q@u{a}kini a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoona alyawma fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmcclxxxix{Waan\q@u{th}irhum yawma al\q@u{h}asrati i\q@u{th} qu\q@u{d}iya alamru wahum fee ghaflatin wahum l\q@u{a} yuminoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmccxc{Inn\q@u{a} na\q@u{h}nu narithu alar\q@u{d}a waman AAalayh\q@u{a} wailayn\q@u{a} yurjaAAoon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmccxci{Wa\q@b{o}\q@u{th}kur fee alkit\q@u{a}bi ibr\q@u{a}heema innahu k\q@u{a}na \q@u{s}iddeeqan nabiyy\q@u{a}\q@b{n}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmccxcii{I\q@u{th} q\q@u{a}la liabeehi y\q@u{a} abati lima taAAbudu m\q@u{a} l\q@u{a} yasmaAAu wal\q@u{a} yub\q@u{s}iru wal\q@u{a} yughnee AAanka shay\q@u{a}\q@b{n}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmccxciii{Y\q@u{a} abati innee qad j\q@u{a}anee mina alAAilmi m\q@u{a} lam yatika fa\q@b{i}ttabiAAnee ahdika \q@u{s}ir\q@u{at}an sawiyy\q@u{a}\q@b{n}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmccxciv{Y\q@u{a} abati l\q@u{a} taAAbudi a\q@b{l}shshay\q@u{ta}na inna a\q@b{l}shshay\q@u{ta}na k\q@u{a}na li\q@b{l}rra\q@u{h}m\q@u{a}ni AAa\q@u{s}iyy\q@u{a}\q@b{n}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmccxcv{Y\q@u{a} abati innee akh\q@u{a}fu an yamassaka AAa\q@u{tha}bun mina a\q@b{l}rra\q@u{h}m\q@u{a}ni fatakoona li\q@b{l}shshya\q@u{ta}ni waliyy\q@u{a}\q@b{n}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmccxcvi{Q\q@u{a}la ar\q@u{a}ghibun anta AAan \q@u{a}lihatee y\q@u{a} ibr\q@u{a}heemu lain lam tantahi laarjumannaka wa\q@b{o}hjurnee maliyy\q@u{a}\q@b{n}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmccxcvii{Q\q@u{a}la sal\q@u{a}mun AAalayka saastaghfiru laka rabbee innahu k\q@u{a}na bee \q@u{h}afiyy\q@u{a}\q@b{n}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmccxcviii{WaaAAtazilukum wam\q@u{a} tadAAoona min dooni All\q@u{a}hi waadAAoo rabbee AAas\q@u{a} all\q@u{a} akoona biduAA\q@u{a}i rabbee shaqiyy\q@u{a}\q@b{n}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmccxcix{Falamm\q@u{a} iAAtazalahum wam\q@u{a} yaAAbudoona min dooni All\q@u{a}hi wahabn\q@u{a} lahu is\q@u{ha}qa wayaAAqooba wakullan jaAAaln\q@u{a} nabiyy\q@u{a}\q@b{n}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmccc{Wawahabn\q@u{a} lahum min ra\q@u{h}matin\q@u{a} wajaAAaln\q@u{a} lahum lis\q@u{a}na \q@u{s}idqin AAaliyy\q@u{a}\q@b{n}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmccci{Wa\q@b{o}\q@u{th}kur fee alkit\q@u{a}bi moos\q@u{a} innahu k\q@u{a}na mukhla\q@u{s}an wak\q@u{a}na rasoolan nabiyy\q@u{a}\q@b{n}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmcccii{Wan\q@u{a}dayn\q@u{a}hu min j\q@u{a}nibi a\q@b{l}\q@u{tt}oori alaymani waqarrabn\q@u{a}hu najiyy\q@u{a}\q@b{n}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmccciii{Wawahabn\q@u{a} lahu min ra\q@u{h}matin\q@u{a} akh\q@u{a}hu h\q@u{a}roona nabiyy\q@u{a}\q@b{n}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmccciv{Wa\q@b{o}\q@u{th}kur fee alkit\q@u{a}bi ism\q@u{a}AAeela innahu k\q@u{a}na \q@u{sa}diqa alwaAAdi wak\q@u{a}na rasoolan nabiyy\q@u{a}\q@b{n}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmcccv{Wak\q@u{a}na yamuru ahlahu bi\q@b{al}\q@u{ss}al\q@u{a}ti wa\q@b{al}zzak\q@u{a}ti wak\q@u{a}na AAinda rabbihi mar\q@u{d}iyy\q@u{a}\q@b{n}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmcccvi{Wa\q@b{o}\q@u{th}kur fee alkit\q@u{a}bi idreesa innahu k\q@u{a}na \q@u{s}iddeeqan nabiyy\q@u{a}\q@b{n}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmcccvii{WarafaAAn\q@u{a}hu mak\q@u{a}nan AAaliyy\q@u{a}\q@b{n}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmcccviii{Ol\q@u{a}ika alla\q@u{th}eena anAAama All\q@u{a}hu AAalayhim mina a\q@b{l}nnabiyyeena min \q@u{th}urriyyati \q@u{a}dama wamimman \q@u{h}amaln\q@u{a} maAAa noo\q@u{h}in wamin \q@u{th}urriyyati ibr\q@u{a}heema waisr\q@u{a}eela wamimman hadayn\q@u{a} wa\q@b{i}jtabayn\q@u{a} i\q@u{tha} tutl\q@u{a} AAalayhim \q@u{a}y\q@u{a}tu a\q@b{l}rra\q@u{h}m\q@u{a}ni kharroo sujjadan wabukiyy\q@u{a}\q@b{n}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmcccix{Fakhalafa min baAAdihim khalfun a\q@u{da}AAoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@b{i}ttabaAAoo a\q@b{l}shshahaw\q@u{a}ti fasawfa yalqawna ghayy\q@u{a}\q@b{n}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmcccx{Ill\q@u{a} man t\q@u{a}ba wa\q@u{a}mana waAAamila \q@u{sa}li\q@u{h}an faol\q@u{a}ika yadkhuloona aljannata wal\q@u{a} yu\q@i{\q@u{th}}lamoona shay\q@u{a}\q@b{n}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmcccxi{Jann\q@u{a}ti AAadnin allatee waAAada a\q@b{l}rra\q@u{h}m\q@u{a}nu AAib\q@u{a}dahu bi\q@b{al}ghaybi innahu k\q@u{a}na waAAduhu matiyy\q@u{a}\q@b{n}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmcccxii{L\q@u{a} yasmaAAoona feeh\q@u{a} laghwan ill\q@u{a} sal\q@u{a}man walahum rizquhum feeh\q@u{a} bukratan waAAashiyy\q@u{a}\q@b{n}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmcccxiii{Tilka aljannatu allatee noorithu min AAib\q@u{a}din\q@u{a} man k\q@u{a}na taqiyy\q@u{a}\q@b{n}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmcccxiv{Wam\q@u{a} natanazzalu ill\q@u{a} biamri rabbika lahu m\q@u{a} bayna aydeen\q@u{a} wam\q@u{a }khalfan\q@u{a} wam\q@u{a} bayna \q@u{tha}lika wam\q@u{a} k\q@u{a}na rabbuka nasiyy\q@u{a}\q@b{n}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmcccxv{Rabbu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} fa\q@b{o}AAbudhu wa\q@b{i}\q@u{st}abir liAAib\q@u{a}datihi hal taAAlamu lahu samiyy\q@u{a}\q@b{n}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmcccxvi{Wayaqoolu alins\q@u{a}nu ai\q@u{tha} m\q@u{a} mittu lasawfa okhraju \q@u{h}ayy\q@u{a}\q@b{n}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmcccxvii{Awal\q@u{a} ya\q@u{th}kuru alins\q@u{a}nu ann\q@u{a} khalaqn\q@u{a}hu min qablu walam yaku shay\q@u{a}\q@b{n}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmcccxviii{Fawarabbika lana\q@u{h}shurannahum wa\q@b{al}shshay\q@u{at}eena thumma lanu\q@u{hd}irannahum \q@u{h}awla jahannama jithiyy\q@u{a}\q@b{n}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmcccxix{Thumma lananziAAanna min kulli sheeAAatin ayyuhum ashaddu AAal\q@u{a} a\q@b{l}rra\q@u{h}m\q@u{a}ni AAitiyy\q@u{a}\q@b{n}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmcccxx{Thumma lana\q@u{h}nu aAAlamu bi\q@b{a}lla\q@u{th}eena hum awl\q@u{a} bih\q@u{a} \q@u{s}iliyy\q@u{a}\q@b{n}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmcccxxi{Wain minkum ill\q@u{a} w\q@u{a}riduh\q@u{a} k\q@u{a}na AAal\q@u{a} rabbika \q@u{h}atman maq\q@u{d}iyy\q@u{a}\q@b{n}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmcccxxii{Thumma nunajjee alla\q@u{th}eena ittaqaw wana\q@u{th}aru a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena feeh\q@u{a} jithiyy\q@u{a}\q@b{n}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmcccxxiii{Wai\q@u{tha} tutl\q@u{a} AAalayhim \q@u{a}y\q@u{a}tun\q@u{a} bayyin\q@u{a}tin q\q@u{a}la alla\q@u{th}eena kafaroo lilla\q@u{th}eena \q@u{a}manoo ayyu alfareeqayni khayrun maq\q@u{a}man waa\q@u{h}sanu nadiyy\q@u{a}\q@b{n}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmcccxxiv{Wakam ahlakn\q@u{a} qablahum min qarnin hum a\q@u{h}sanu ath\q@u{a}than wariy\q@u{a}\q@b{n}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmcccxxv{Qul man k\q@u{a}na fee a\q@b{l}\q@u{dd}al\q@u{a}lati falyamdud lahu a\q@b{l}rra\q@u{h}m\q@u{a}nu maddan \q@u{h}att\q@u{a} i\q@u{tha} raaw m\q@u{a} yooAAadoona imm\q@u{a} alAAa\q@u{tha}ba waimm\q@u{a} a\q@b{l}ss\q@u{a}AAata fasayaAAlamoona man huwa sharrun mak\q@u{a}nan waa\q@u{d}AAafu jund\q@u{a}\q@b{n}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmcccxxvi{Wayazeedu All\q@u{a}hu alla\q@u{th}eena ihtadaw hudan wa\q@b{a}lb\q@u{a}qiy\q@u{a}tu a\q@b{l}\q@u{ssa}li\q@u{ha}tu khayrun AAinda rabbika thaw\q@u{a}ban wakhayrun maradd\q@u{a}\q@b{n}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmcccxxvii{Afaraayta alla\q@u{th}ee kafara bi\q@u{a}y\q@u{a}tin\q@u{a} waq\q@u{a}la laootayanna m\q@u{a}lan wawalad\q@u{a}\q@b{n}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmcccxxviii{A\q@u{tt}alaAAa alghayba ami ittakha\q@u{th}a AAinda a\q@b{l}rra\q@u{h}m\q@u{a}ni AAahd\q@u{a}\q@b{n}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmcccxxix{Kall\q@u{a} sanaktubu m\q@u{a} yaqoolu wanamuddu lahu mina alAAa\q@u{tha}bi madd\q@u{a}\q@b{n}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmcccxxx{Wanarithuhu m\q@u{a} yaqoolu wayateen\q@u{a} fard\q@u{a}\q@b{n}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmcccxxxi{Wa\q@b{i}ttakha\q@u{th}oo min dooni All\q@u{a}hi \q@u{a}lihatan liyakoonoo lahum AAizz\q@u{a}\q@b{n}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmcccxxxii{Kall\q@u{a} sayakfuroona biAAib\q@u{a}datihim wayakoonoona AAalayhim \q@u{d}idd\q@u{a}\q@b{n}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmcccxxxiii{Alam tara ann\q@u{a} arsaln\q@u{a} a\q@b{l}shshay\q@u{at}eena AAal\q@u{a} alk\q@u{a}fireena taozzuhum azz\q@u{a}\q@b{n}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmcccxxxiv{Fal\q@u{a} taAAjal AAalayhim innam\q@u{a} naAAuddu lahum AAadd\q@u{a}\q@b{n}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmcccxxxv{Yawma na\q@u{h}shuru almuttaqeena il\q@u{a} a\q@b{l}rra\q@u{h}m\q@u{a}ni wafd\q@u{a}\q@b{n}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmcccxxxvi{Wanasooqu almujrimeena il\q@u{a} jahannama wird\q@u{a}\q@b{n}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmcccxxxvii{L\q@u{a} yamlikoona a\q@b{l}shshaf\q@u{a}AAata ill\q@u{a} mani ittakha\q@u{th}a AAinda a\q@b{l}rra\q@u{h}m\q@u{a}ni AAahd\q@u{a}\q@b{n}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmcccxxxviii{Waq\q@u{a}loo ittakha\q@u{th}a a\q@b{l}rra\q@u{h}m\q@u{a}nu walad\q@u{a}\q@b{n}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmcccxxxix{Laqad jitum shayan idd\q@u{a}\q@b{n}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmcccxl{Tak\q@u{a}du a\q@b{l}ssam\q@u{a}w\q@u{a}tu yatafa\q@u{tt}arna minhu watanshaqqu alar\q@u{d}u watakhirru aljib\q@u{a}lu hadd\q@u{a}\q@b{n}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmcccxli{An daAAaw li\q@b{l}rra\q@u{h}m\q@u{a}ni walad\q@u{a}\q@b{n}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmcccxlii{Wam\q@u{a} yanbaghee li\q@b{l}rra\q@u{h}m\q@u{a}ni an yattakhi\q@u{th}a walad\q@u{a}\q@b{n}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmcccxliii{In kullu man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i ill\q@u{a} \q@u{a}tee a\q@b{l}rra\q@u{h}m\q@u{a}ni AAabd\q@u{a}\q@b{n}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmcccxliv{Laqad a\q@u{hsa}hum waAAaddahum AAadd\q@u{a}\q@b{n}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mmcccxlv{Wakulluhum \q@u{a}teehi yawma alqiy\q@u{a}mati fard\q@u{a}\q@b{n}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mmcccxlvi{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti sayajAAalu lahumu a\q@b{l}rra\q@u{h}m\q@u{a}nu wudd\q@u{a}\q@b{n}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mmcccxlvii{Fainnam\q@u{a} yassarn\q@u{a}hu bilis\q@u{a}nika litubashshira bihi almuttaqeena watun\q@u{th}ira bihi qawman ludd\q@u{a}\q@b{n}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mmcccxlviii{Wakam ahlakn\q@u{a} qablahum min qarnin hal tu\q@u{h}issu minhum min a\q@u{h}adin aw tasmaAAu lahum rikz\q@u{a}\q@b{n}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mmcccxlix{\basmalahlt \q@u{Ta}h\q@u{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmcccl{M\q@u{a} anzaln\q@u{a} AAalayka alqur\q@u{a}na litashq\q@u{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmcccli{Ill\q@u{a} ta\q@u{th}kiratan liman yakhsh\q@u{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmccclii{Tanzeelan mimman khalaqa alar\q@u{d}a wa\q@b{al}ssam\q@u{a}w\q@u{a}ti alAAul\q@u{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmcccliii{A\q@b{l}rra\q@u{h}m\q@u{a}nu AAal\q@u{a} alAAarshi istaw\q@u{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmcccliv{Lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wam\q@u{a} baynahum\q@u{a} wam\q@u{a} ta\q@u{h}ta a\q@b{l}ththar\q@u{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmccclv{Wain tajhar bi\q@b{a}lqawli fainnahu yaAAlamu a\q@b{l}ssirra waakhf\q@u{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmccclvi{All\q@u{a}hu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa lahu alasm\q@u{a}o al\q@u{h}usn\q@u{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmccclvii{Wahal at\q@u{a}ka \q@u{h}adeethu moos\q@u{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmccclviii{I\q@u{th} ra\q@u{a} n\q@u{a}ran faq\q@u{a}la liahlihi omkuthoo innee \q@u{a}nastu n\q@u{a}ran laAAallee \q@u{a}teekum minh\q@u{a} biqabasin aw ajidu AAal\q@u{a} a\q@b{l}nn\q@u{a}ri hud\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmccclix{Falamm\q@u{a} at\q@u{a}h\q@u{a} noodiya y\q@u{a} moos\q@u{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmccclx{Innee an\q@u{a} rabbuka fa\q@b{i}khlaAA naAAlayka innaka bi\q@b{a}lw\q@u{a}di almuqaddasi \q@u{t}uw\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmccclxi{Waan\q@u{a} ikhtartuka fa\q@b{i}stamiAA lim\q@u{a} yoo\q@u{ha}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmccclxii{Innanee an\q@u{a} All\q@u{a}hu l\q@u{a} il\q@u{a}ha ill\q@u{a} an\q@u{a} fa\q@b{o}AAbudnee waaqimi a\q@b{l}\q@u{ss}al\q@u{a}ta li\q@u{th}ikree\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmccclxiii{Inna a\q@b{l}ss\q@u{a}AAata \q@u{a}tiyatun ak\q@u{a}du okhfeeh\q@u{a} litujz\q@u{a} kullu nafsin bim\q@u{a} tasAA\q@u{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmccclxiv{Fal\q@u{a} ya\q@u{s}uddannaka AAanh\q@u{a} man l\q@u{a} yuminu bih\q@u{a} wa\q@b{i}ttabaAAa haw\q@u{a}hu fatard\q@u{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmccclxv{Wam\q@u{a} tilka biyameenika y\q@u{a} moos\q@u{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmccclxvi{Q\q@u{a}la hiya AAa\q@u{sa}ya atawakkao AAalayh\q@u{a} waahushshu bih\q@u{a} AAal\q@u{a} ghanamee waliya feeh\q@u{a} ma\q@u{a}ribu okhr\q@u{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmccclxvii{Q\q@u{a}la alqih\q@u{a} y\q@u{a} moos\q@u{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmccclxviii{Faalq\q@u{a}h\q@u{a} fai\q@u{tha} hiya \q@u{h}ayyatun tasAA\q@u{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmccclxix{Q\q@u{a}la khu\q@u{th}h\q@u{a} wal\q@u{a} takhaf sanuAAeeduh\q@u{a} seeratah\q@u{a} alool\q@u{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmccclxx{Wa\q@b{o}\q@u{d}mum yadaka il\q@u{a} jan\q@u{ah}ika takhruj bay\q@u{da}a min ghayri sooin \q@u{a}yatan okhr\q@u{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmccclxxi{Linuriyaka min \q@u{a}y\q@u{a}tin\q@u{a} alkubr\q@u{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmccclxxii{I\q@u{th}hab il\q@u{a} firAAawna innahu \q@u{t}agh\q@u{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmccclxxiii{Q\q@u{a}la rabbi ishra\q@u{h} lee \q@u{s}adree\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmccclxxiv{Wayassir lee amree\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmccclxxv{Wa\q@b{o}\q@u{h}lul AAuqdatan min lis\q@u{a}nee\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmccclxxvi{Yafqahoo qawlee\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmccclxxvii{Wa\q@b{i}jAAal lee wazeeran min ahlee\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmccclxxviii{H\q@u{a}roona akhee\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmccclxxix{Oshdud bihi azree\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmccclxxx{Waashrikhu fee amree\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmccclxxxi{Kay nusabbi\q@u{h}aka katheer\q@u{a}\q@b{n}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmccclxxxii{Wana\q@u{th}kuraka katheer\q@u{a}\q@b{n}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmccclxxxiii{Innaka kunta bin\q@u{a} ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmccclxxxiv{Q\q@u{a}la qad ooteeta sulaka y\q@u{a} moos\q@u{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmccclxxxv{Walaqad manann\q@u{a} AAalayka marratan okhr\q@u{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmccclxxxvi{I\q@u{th} aw\q@u{h}ayn\q@u{a} il\q@u{a} ommika m\q@u{a} yoo\q@u{ha}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmccclxxxvii{Ani iq\q@u{th}ifeehi fee a\q@b{l}tt\q@u{a}booti fa\q@b{i}q\q@u{th}ifeehi fee alyammi falyulqihi alyammu bi\q@b{al}ss\q@u{ah}ili yakhu\q@u{th}hu AAaduwwun lee waAAaduwwun lahu waalqaytu AAalayka ma\q@u{h}abbatan minnee walitu\q@u{s}naAAa AAal\q@u{a} AAaynee\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmccclxxxviii{I\q@u{th} tamshee okhtuka fataqoolu hal adullukum AAal\q@u{a} man yakfuluhu farajaAAn\q@u{a}ka il\q@u{a} ommika kay taqarra AAaynuh\q@u{a} wal\q@u{a} ta\q@u{h}zana waqatalta nafsan fanajjayn\q@u{a}ka mina alghammi wafatann\q@u{a}ka futoonan falabithta sineena fee ahli madyana thumma jita AAal\q@u{a} qadarin y\q@u{a} moos\q@u{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmccclxxxix{Wa\q@b{i}\q@u{st}anaAAtuka linafsee\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmcccxc{I\q@u{th}hab anta waakhooka bi\q@u{a}y\q@u{a}tee wal\q@u{a} taniy\q@u{a} fee \q@u{th}ikree\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmcccxci{I\q@u{th}hab\q@u{a} il\q@u{a} firAAawna innahu \q@u{t}agh\q@u{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmcccxcii{Faqool\q@u{a} lahu qawlan layyinan laAAallahu yata\q@u{th}akkaru aw yakhsh\q@u{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmcccxciii{Q\q@u{a}l\q@u{a} rabban\q@u{a} innan\q@u{a} nakh\q@u{a}fu an yafru\q@u{t}a AAalayn\q@u{a} aw an ya\q@u{t}gh\q@u{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmcccxciv{Q\q@u{a}la l\q@u{a} takh\q@u{a}f\q@u{a} innanee maAAakum\q@u{a} asmaAAu waar\q@u{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmcccxcv{Fatiy\q@u{a}hu faqool\q@u{a} inn\q@u{a} rasool\q@u{a} rabbika faarsil maAAan\q@u{a} banee isr\q@u{a}eela wal\q@u{a} tuAAa\q@u{thth}ibhum qad jin\q@u{a}ka bi\q@u{a}yatin min rabbika wa\q@b{al}ssal\q@u{a}mu AAal\q@u{a} mani ittabaAAa alhud\q@u{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmcccxcvi{Inn\q@u{a} qad oo\q@u{h}iya ilayn\q@u{a} anna alAAa\q@u{tha}ba AAal\q@u{a} man ka\q@u{thth}aba watawall\q@u{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmcccxcvii{Q\q@u{a}la faman rabbukum\q@u{a} y\q@u{a} moos\q@u{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmcccxcviii{Q\q@u{a}la rabbun\q@u{a} alla\q@u{th}ee aAA\q@u{ta} kulla shayin khalqahu thumma had\q@u{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmcccxcix{Q\q@u{a}la fam\q@u{a} b\q@u{a}lu alqurooni alool\q@u{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmcd{Q\q@u{a}la AAilmuh\q@u{a} AAinda rabbee fee kit\q@u{a}bin l\q@u{a} ya\q@u{d}illu rabbee wal\q@u{a} yans\q@u{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmcdi{Alla\q@u{th}ee jaAAala lakumu alar\q@u{d}a mahdan wasalaka lakum feeh\q@u{a} subulan waanzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faakhrajn\q@u{a} bihi azw\q@u{a}jan min nab\q@u{a}tin shatt\q@u{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmcdii{Kuloo wa\q@b{i}rAAaw anAA\q@u{a}makum inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liolee a\q@b{l}nnuh\q@u{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmcdiii{Minh\q@u{a} khalaqn\q@u{a}kum wafeeh\q@u{a} nuAAeedukum waminh\q@u{a} nukhrijukum t\q@u{a}ratan okhr\q@u{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmcdiv{Walaqad arayn\q@u{a}hu \q@u{a}y\q@u{a}tin\q@u{a} kullah\q@u{a} faka\q@u{thth}aba waab\q@u{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmcdv{Q\q@u{a}la ajitan\q@u{a} litukhrijan\q@u{a} min ar\q@u{d}in\q@u{a} bisi\q@u{h}rika y\q@u{a} moos\q@u{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmcdvi{Falanatiyannaka bisi\q@u{h}rin mithlihi fa\q@b{i}jAAal baynan\q@u{a} wabaynaka mawAAidan l\q@u{a} nukhlifuhu na\q@u{h}nu wal\q@u{a} anta mak\q@u{a}nan suw\q@u{a}\q@b{n}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmcdvii{Q\q@u{a}la mawAAidukum yawmu a\q@b{l}zzeenati waan yu\q@u{h}shara a\q@b{l}nn\q@u{a}su \q@u{d}u\q@u{ha}\q@b{n}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmcdviii{Fatawall\q@u{a} firAAawnu fajamaAAa kaydahu thumma at\q@u{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmcdix{Q\q@u{a}la lahum moos\q@u{a} waylakum l\q@u{a} taftaroo AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban fayus\q@u{h}itakum biAAa\q@u{tha}bin waqad kh\q@u{a}ba mani iftar\q@u{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmcdx{Fatan\q@u{a}zaAAoo amrahum baynahum waasarroo a\q@b{l}nnajw\q@u{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmcdxi{Q\q@u{a}loo in h\q@u{atha}ni las\q@u{ah}ir\q@u{a}ni yureed\q@u{a}ni an yukhrij\q@u{a}kum min ar\q@u{d}ikum bisi\q@u{h}rihim\q@u{a} waya\q@u{th}hab\q@u{a} bi\q@u{t}areeqatikumu almuthl\q@u{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmcdxii{FaajmiAAoo kaydakum thumma itoo \q@u{s}affan waqad afla\q@u{h}a alyawma mani istaAAl\q@u{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmcdxiii{Q\q@u{a}loo y\q@u{a} moos\q@u{a} imm\q@u{a} an tulqiya waimm\q@u{a} an nakoona awwala man alq\q@u{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmcdxiv{Q\q@u{a}la bal alqoo fai\q@u{tha} \q@u{h}ib\q@u{a}luhum waAAi\q@u{s}iyyuhum yukhayyalu ilayhi min si\q@u{h}rihim annah\q@u{a} tasAA\q@u{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmcdxv{Faawjasa fee nafsihi kheefatan moos\q@u{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmcdxvi{Quln\q@u{a} l\q@u{a} takhaf innaka anta alaAAl\q@u{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmcdxvii{Waalqi m\q@u{a} fee yameenika talqaf m\q@u{a} \q@u{s}anaAAoo innam\q@u{a} \q@u{s}anaAAoo kaydu s\q@u{ah}irin wal\q@u{a} yufli\q@u{h}u a\q@b{l}ss\q@u{ah}iru \q@u{h}aythu at\q@u{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmcdxviii{Faolqiya a\q@b{l}ssa\q@u{h}aratu sujjadan q\q@u{a}loo \q@u{a}mann\q@u{a} birabbi h\q@u{a}roona wamoos\q@u{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmcdxix{Q\q@u{a}la \q@u{a}mantum lahu qabla an \q@u{ath}ana lakum innahu lakabeerukumu alla\q@u{th}ee AAallamakumu a\q@b{l}ssi\q@u{h}ra falaoqa\q@u{tt}iAAanna aydiyakum waarjulakum min khil\q@u{a}fin walao\q@u{s}allibannakum fee ju\q@u{th}ooAAi a\q@b{l}nnakhli walataAAlamunna ayyun\q@u{a} ashaddu AAa\q@u{tha}ban waabq\q@u{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmcdxx{Q\q@u{a}loo lan nuthiraka AAal\q@u{a} m\q@u{a} j\q@u{a}an\q@u{a} mina albayyin\q@u{a}ti wa\q@b{a}lla\q@u{th}ee fa\q@u{t}aran\q@u{a} fa\q@b{i}q\q@u{d}i m\q@u{a} anta q\q@u{ad}in innam\q@u{a} taq\q@u{d}ee h\q@u{ath}ihi al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmcdxxi{Inn\q@u{a} \q@u{a}mann\q@u{a} birabbin\q@u{a} liyaghfira lan\q@u{a} kha\q@u{ta}y\q@u{a}n\q@u{a} wam\q@u{a} akrahtan\q@u{a} AAalayhi mina a\q@b{l}ssi\q@u{h}ri wa\q@b{A}ll\q@u{a}hu khayrun waabq\q@u{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmcdxxii{Innahu man yati rabbahu mujriman fainna lahu jahannama l\q@u{a} yamootu feeh\q@u{a} wal\q@u{a} ya\q@u{h}y\q@u{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmcdxxiii{Waman yatihi muminan qad AAamila a\q@b{l}\q@u{ssa}li\q@u{ha}ti faol\q@u{a}ika lahumu a\q@b{l}ddaraj\q@u{a}tu alAAul\q@u{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmcdxxiv{Jann\q@u{a}tu AA\q@u{a}dnin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} wa\q@u{tha}lika jaz\q@u{a}o man tazakk\q@u{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmcdxxv{Walaqad aw\q@u{h}ayn\q@u{a} il\q@u{a} moos\q@u{a} an asri biAAib\q@u{a}dee fa\q@b{i}\q@u{d}rib lahum \q@u{t}areeqan fee alba\q@u{h}ri yabasan l\q@u{a} takh\q@u{a}fu darakan wal\q@u{a} takhsh\q@u{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmcdxxvi{FaatbaAAahum firAAawnu bijunoodihi faghashiyahum mina alyammi m\q@u{a} ghashiyahum\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmcdxxvii{Waa\q@u{d}alla firAAawnu qawmahu wam\q@u{a} had\q@u{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmcdxxviii{Y\q@u{a} banee isr\q@u{a}eela qad anjayn\q@u{a}kum min AAaduwwikum waw\q@u{a}AAadn\q@u{a}kum j\q@u{a}niba a\q@b{l}\q@u{tt}oori alaymana wanazzaln\q@u{a} AAalaykumu almanna wa\q@b{al}ssalw\q@u{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmcdxxix{Kuloo min \q@u{t}ayyib\q@u{a}ti m\q@u{a} razaqn\q@u{a}kum wal\q@u{a} ta\q@u{t}ghaw feehi faya\q@u{h}illa AAalaykum gha\q@u{d}abee waman ya\q@u{h}lil AAalayhi gha\q@u{d}abee faqad haw\q@u{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmcdxxx{Wainnee laghaff\q@u{a}run liman t\q@u{a}ba wa\q@u{a}mana waAAamila \q@u{sa}li\q@u{h}an thumma ihtad\q@u{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmcdxxxi{Wam\q@u{a} aAAjalaka AAan qawmika y\q@u{a} moos\q@u{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmcdxxxii{Q\q@u{a}la hum ol\q@u{a}i AAal\q@u{a} atharee waAAajiltu ilayka rabbi litar\q@u{da}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmcdxxxiii{Q\q@u{a}la fainn\q@u{a} qad fatann\q@u{a} qawmaka min baAAdika waa\q@u{d}allahumu a\q@b{l}ss\q@u{a}miriy\q@b{yu}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmcdxxxiv{FarajaAAa moos\q@u{a} il\q@u{a} qawmihi gha\q@u{d}b\q@u{a}na asifan q\q@u{a}la y\q@u{a} qawmi alam yaAAidkum rabbukum waAAdan \q@u{h}asanan afa\q@u{ta}la AAalaykumu alAAahdu am aradtum an ya\q@u{h}illa AAalaykum gha\q@u{d}abun min rabbikum faakhlaftum mawAAidee\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmcdxxxv{Q\q@u{a}loo m\q@u{a} akhlafn\q@u{a} mawAAidaka bimalkin\q@u{a} wal\q@u{a}kinn\q@u{a} \q@u{h}ummiln\q@u{a} awz\q@u{a}ran min zeenati alqawmi faqa\q@u{th}afn\q@u{a}h\q@u{a} faka\q@u{tha}lika alq\q@u{a} a\q@b{l}ss\q@u{a}miriy\q@b{yu}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmcdxxxvi{Faakhraja lahum AAijlan jasadan lahu khuw\q@u{a}run faq\q@u{a}loo h\q@u{atha} il\q@u{a}hukum wail\q@u{a}hu moos\q@u{a} fanasiy\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmcdxxxvii{Afal\q@u{a} yarawna all\q@u{a} yarjiAAu ilayhim qawlan wal\q@u{a} yamliku lahum \q@u{d}arran wal\q@u{a} nafAA\q@u{a}\q@b{n}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmcdxxxviii{Walaqad q\q@u{a}la lahum h\q@u{a}roonu min qablu y\q@u{a} qawmi innam\q@u{a} futintum bihi wainna rabbakumu a\q@b{l}rra\q@u{h}m\q@u{a}nu fa\q@b{i}ttabiAAoonee waa\q@u{t}eeAAoo amree\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmcdxxxix{Q\q@u{a}loo lan nabra\q@u{h}a AAalayhi AA\q@u{a}kifeena \q@u{h}att\q@u{a} yarjiAAa ilayn\q@u{a} moos\q@u{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmcdxl{Q\q@u{a}la y\q@u{a} h\q@u{a}roonu m\q@u{a} manaAAaka i\q@u{th} raaytahum \q@u{d}alloo\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmcdxli{All\q@u{a} tattabiAAani afaAAa\q@u{s}ayta amree\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmcdxlii{Q\q@u{a}la ya bna omma l\q@u{a} takhu\q@u{th} bili\q@u{h}yatee wal\q@u{a} birasee innee khasheetu an taqoola farraqta bayna banee isr\q@u{a}eela walam tarqub qawlee\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mmcdxliii{Q\q@u{a}la fam\q@u{a} kha\q@u{t}buka y\q@u{a} s\q@u{a}miriy\q@b{yu}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mmcdxliv{Q\q@u{a}la ba\q@u{s}urtu bim\q@u{a} lam yab\q@u{s}uroo bihi faqaba\q@u{d}tu qab\q@u{d}atan min athari a\q@b{l}rrasooli fanaba\q@u{th}tuh\q@u{a} waka\q@u{tha}lika sawwalat lee nafsee\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mmcdxlv{Q\q@u{a}la fa\q@b{i}\q@u{th}hab fainna laka fee al\q@u{h}ay\q@u{a}ti an taqoola l\q@u{a} mis\q@u{a}sa wainna laka mawAAidan lan tukhlafahu wa\q@b{o}n\q@i{\q@u{th}}ur il\q@u{a} il\q@u{a}hika alla\q@u{th}ee \q@i{\q@u{th}}alta AAalayhi AA\q@u{a}kifan lanu\q@u{h}arriqannahu thumma lanansifannahu fee alyammi nasf\q@u{a}\q@b{n}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mmcdxlvi{Innam\q@u{a} il\q@u{a}hukumu All\q@u{a}hu alla\q@u{th}ee l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa wasiAAa kulla shayin AAilm\q@u{a}\q@b{n}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mmcdxlvii{Ka\q@u{tha}lika naqu\q@u{ss}u AAalayka min anb\q@u{a}i m\q@u{a} qad sabaqa waqad \q@u{a}tayn\q@u{a}ka min ladunn\q@u{a} thikra\q@b{n}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mmcdxlviii{Man aAAra\q@u{d}a AAanhu fainnahu ya\q@u{h}milu yawma alqiy\q@u{a}mati wizr\q@u{a}\q@b{n}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mmcdxlix{Kh\q@u{a}lideena feehi was\q@u{a}a lahum yawma alqiy\q@u{a}mati \q@u{h}iml\q@u{a}\q@b{n}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mmcdl{Yawma yunfakhu fee a\q@b{l}\q@u{ss}oori wana\q@u{h}shuru almujrimeena yawmai\q@u{th}in zurq\q@u{a}\q@b{n}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mmcdli{Yatakh\q@u{a}fatoona baynahum in labithtum ill\q@u{a} AAashr\q@u{a}\q@b{n}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mmcdlii{Na\q@u{h}nu aAAlamu bim\q@u{a} yaqooloona i\q@u{th} yaqoolu amthaluhum \q@u{t}areeqatan in labithtum ill\q@u{a} yawm\q@u{a}\q@b{n}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mmcdliii{Wayasaloonaka AAani aljib\q@u{a}li faqul yansifuh\q@u{a} rabbee nasf\q@u{a}\q@b{n}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mmcdliv{Faya\q@u{th}aruh\q@u{a} q\q@u{a}AAan \q@u{s}af\q@u{s}af\q@u{a}\q@b{n}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mmcdlv{L\q@u{a} tar\q@u{a} feeh\q@u{a} AAiwajan wal\q@u{a} amt\q@u{a}\q@b{n}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mmcdlvi{Yawmai\q@u{th}in yattabiAAoona a\q@b{l}dd\q@u{a}AAiya l\q@u{a} AAiwaja lahu wakhashaAAati ala\q@u{s}w\q@u{a}tu li\q@b{l}rra\q@u{h}m\q@u{a}ni fal\q@u{a} tasmaAAu ill\q@u{a} hams\q@u{a}\q@b{n}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mmcdlvii{Yawmai\q@u{th}in l\q@u{a} tanfaAAu a\q@b{l}shshaf\q@u{a}AAatu ill\q@u{a} man a\q@u{th}ina lahu a\q@b{l}rra\q@u{h}m\q@u{a}nu wara\q@u{d}iya lahu qawl\q@u{a}\q@b{n}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mmcdlviii{YaAAlamu m\q@u{a} bayna aydeehim wam\q@u{a} khalfahum wal\q@u{a} yu\q@u{h}ee\q@u{t}oona bihi AAilm\q@u{a}\q@b{n}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mmcdlix{WaAAanati alwujoohu lil\q@u{h}ayyi alqayyoomi waqad kh\q@u{a}ba man \q@u{h}amala \q@i{\q@u{th}}ulm\q@u{a}\q@b{n}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mmcdlx{Waman yaAAmal mina a\q@b{l}\q@u{ssa}li\q@u{ha}ti wahuwa muminun fal\q@u{a} yakh\q@u{a}fu \q@i{\q@u{th}}ulman wal\q@u{a} ha\q@u{d}m\q@u{a}\q@b{n}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@mmcdlxi{Waka\q@u{tha}lika anzaln\q@u{a}hu qur\q@u{a}nan AAarabiyyan wa\q@u{s}arrafn\q@u{a} feehi mina alwaAAeedi laAAallahum yattaqoona aw yu\q@u{h}dithu lahum \q@u{th}ikr\q@u{a}\q@b{n}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@mmcdlxii{FataAA\q@u{a}l\q@u{a} All\q@u{a}hu almaliku al\q@u{h}aqqu wal\q@u{a} taAAjal bi\q@b{a}lqur\q@u{a}ni min qabli an yuq\q@u{da} ilayka wa\q@u{h}yuhu waqul rabbi zidnee AAilm\q@u{a}\q@b{n}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@mmcdlxiii{Walaqad AAahidn\q@u{a} il\q@u{a} \q@u{a}dama min qablu fanasiya walam najid lahu AAazm\q@u{a}\q@b{n}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@mmcdlxiv{Wai\q@u{th} quln\q@u{a} lilmal\q@u{a}ikati osjudoo li\q@u{a}dama fasajadoo ill\q@u{a} ibleesa ab\q@u{a}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@mmcdlxv{Faquln\q@u{a} y\q@u{a} \q@u{a}damu inna h\q@u{atha} AAaduwwun laka walizawjika fal\q@u{a} yukhrijannakum\q@u{a} mina aljannati fatashq\q@u{a}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@mmcdlxvi{Inna laka all\q@u{a} tajooAAa feeh\q@u{a} wal\q@u{a} taAAr\q@u{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@mmcdlxvii{Waannaka l\q@u{a} ta\q@i{\q@u{th}}mao feeh\q@u{a} wal\q@u{a} ta\q@u{dha}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@mmcdlxviii{Fawaswasa ilayhi a\q@b{l}shshay\q@u{ta}nu q\q@u{a}la y\q@u{a} \q@u{a}damu hal adulluka AAal\q@u{a} shajarati alkhuldi wamulkin l\q@u{a} yabl\q@u{a}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@mmcdlxix{Faakal\q@u{a} minh\q@u{a} fabadat lahum\q@u{a} saw\q@u{a}tuhum\q@u{a} wa\q@u{t}afiq\q@u{a} yakh\q@u{s}if\q@u{a}ni AAalayhim\q@u{a} min waraqi aljannati waAAa\q@u{sa} \q@u{a}damu rabbahu faghaw\q@u{a}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@mmcdlxx{Thumma ijtab\q@u{a}hu rabbuhu fat\q@u{a}ba AAalayhi wahad\q@u{a}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@mmcdlxxi{Q\q@u{a}la ihbi\q@u{ta} minh\q@u{a} jameeAAan baAA\q@u{d}ukum libaAA\q@u{d}in AAaduwwun faimm\q@u{a} yatiyannakum minnee hudan famani ittabaAAa hud\q@u{a}ya fal\q@u{a} ya\q@u{d}illu wal\q@u{a} yashq\q@u{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@mmcdlxxii{Waman aAAra\q@u{d}a AAan \q@u{th}ikree fainna lahu maAAeeshatan \q@u{d}ank\q@u{a}\q@b{n} wana\q@u{h}shuruhu yawma alqiy\q@u{a}mati aAAm\q@u{a}\q@b{n}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@mmcdlxxiii{Q\q@u{a}la rabbi lima \q@u{h}ashartanee aAAm\q@u{a} waqad kuntu ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@mmcdlxxiv{Q\q@u{a}la ka\q@u{tha}lika atatka \q@u{a}y\q@u{a}tun\q@u{a} fanaseetah\q@u{a} waka\q@u{tha}lika alyawma tuns\q@u{a}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@mmcdlxxv{Waka\q@u{tha}lika najzee man asrafa walam yumin bi\q@u{a}y\q@u{a}ti rabbihi walaAAa\q@u{tha}bu al\q@u{a}khirati ashaddu waabq\q@u{a}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@mmcdlxxvi{Afalam yahdi lahum kam ahlakn\q@u{a} qablahum mina alqurooni yamshoona fee mas\q@u{a}kinihim inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liolee a\q@b{l}nnuh\q@u{a}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@mmcdlxxvii{Walawl\q@u{a} kalimatun sabaqat min rabbika lak\q@u{a}na liz\q@u{a}man waajalun musamm\q@u{a}\q@b{n}\qt@no{(129)}}
\qt@newcmd\qurantrans@lt@mmcdlxxviii{Fa\q@b{i}\q@u{s}bir AAal\q@u{a} m\q@u{a} yaqooloona wasabbi\q@u{h} bi\q@u{h}amdi rabbika qabla \q@u{t}ulooAAi a\q@b{l}shshamsi waqabla ghuroobih\q@u{a} wamin \q@u{a}n\q@u{a}i allayli fasabbi\q@u{h} waa\q@u{t}r\q@u{a}fa a\q@b{l}nnah\q@u{a}ri laAAallaka tar\q@u{da}\qt@no{(130)}}
\qt@newcmd\qurantrans@lt@mmcdlxxix{Wal\q@u{a} tamuddanna AAaynayka il\q@u{a} m\q@u{a} mattaAAn\q@u{a} bihi azw\q@u{a}jan minhum zahrata al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} linaftinahum feehi warizqu rabbika khayrun waabq\q@u{a}\qt@no{(131)}}
\qt@newcmd\qurantrans@lt@mmcdlxxx{Wamur ahlaka bi\q@b{al}\q@u{ss}al\q@u{a}ti wa\q@b{i}\q@u{st}abir AAalayh\q@u{a} l\q@u{a} nasaluka rizqan na\q@u{h}nu narzuquka wa\q@b{a}lAA\q@u{a}qibatu li\q@b{l}ttaqw\q@u{a}\qt@no{(132)}}
\qt@newcmd\qurantrans@lt@mmcdlxxxi{Waq\q@u{a}loo lawl\q@u{a} yateen\q@u{a} bi\q@u{a}yatin min rabbihi awalam tatihim bayyinatu m\q@u{a} fee a\q@b{l}\q@u{ss}u\q@u{h}ufi alool\q@u{a}\qt@no{(133)}}
\qt@newcmd\qurantrans@lt@mmcdlxxxii{Walaw ann\q@u{a} ahlakn\q@u{a}hum biAAa\q@u{tha}bin min qablihi laq\q@u{a}loo rabban\q@u{a} lawl\q@u{a} arsalta ilayn\q@u{a} rasoolan fanattabiAAa \q@u{a}y\q@u{a}tika min qabli an na\q@u{th}illa wanakhz\q@u{a}\qt@no{(134)}}
\qt@newcmd\qurantrans@lt@mmcdlxxxiii{Qul kullun mutarabbi\q@u{s}un fatarabba\q@u{s}oo fasataAAlamoona man a\q@u{s}\q@u{ha}bu a\q@b{l}\q@u{ss}ir\q@u{at}i a\q@b{l}ssawiyyi wamani ihtad\q@u{a}\qt@no{(135)}}
\qt@newcmd\qurantrans@lt@mmcdlxxxiv{\basmalahlt Iqtaraba li\q@b{l}nn\q@u{a}si \q@u{h}is\q@u{a}buhum wahum fee ghaflatin muAAri\q@u{d}oon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmcdlxxxv{M\q@u{a} yateehim min \q@u{th}ikrin min rabbihim mu\q@u{h}dathin ill\q@u{a} istamaAAoohu wahum yalAAaboon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmcdlxxxvi{L\q@u{a}hiyatan quloobuhum waasarroo a\q@b{l}nnajw\q@u{a} alla\q@u{th}eena \q@i{\q@u{th}}alamoo hal h\q@u{atha} ill\q@u{a} basharun mithlukum afatatoona a\q@b{l}ssi\q@u{h}ra waantum tub\q@u{s}iroon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmcdlxxxvii{Q\q@u{a}la rabbee yaAAlamu alqawla fee a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i wahuwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmcdlxxxviii{Bal q\q@u{a}loo a\q@u{d}gh\q@u{a}thu a\q@u{h}l\q@u{a}min bali iftar\q@u{a}hu bal huwa sh\q@u{a}AAirun falyatin\q@u{a} bi\q@u{a}yatin kam\q@u{a} orsila alawwaloon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmcdlxxxix{M\q@u{a} \q@u{a}manat qablahum min qaryatin ahlakn\q@u{a}h\q@u{a} afahum yuminoon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmcdxc{Wam\q@u{a} arsaln\q@u{a} qablaka ill\q@u{a} rij\q@u{a}lan noo\q@u{h}ee ilayhim fa\q@b{i}saloo ahla a\q@b{l}\q@u{thth}ikri in kuntum l\q@u{a} taAAlamoon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmcdxci{Wam\q@u{a} jaAAaln\q@u{a}hum jasadan l\q@u{a} yakuloona a\q@b{l}\q@u{tt}aAA\q@u{a}ma wam\q@u{a} k\q@u{a}noo kh\q@u{a}lideen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmcdxcii{Thumma \q@u{s}adaqn\q@u{a}humu alwaAAda faanjayn\q@u{a}hum waman nash\q@u{a}o waahlakn\q@u{a} almusrifeen\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmcdxciii{Laqad anzaln\q@u{a} ilaykum kit\q@u{a}ban feehi \q@u{th}ikrukum afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmcdxciv{Wakam qa\q@u{s}amn\q@u{a} min qaryatin k\q@u{a}nat \q@i{\q@u{th}}\q@u{a}limatan waanshan\q@u{a} baAAdah\q@u{a} qawman \q@u{a}khareen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmcdxcv{Falamm\q@u{a} a\q@u{h}assoo basan\q@u{a} i\q@u{tha} hum minh\q@u{a} yarku\q@u{d}oon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmcdxcvi{L\q@u{a} tarku\q@u{d}oo wa\q@b{i}rjiAAoo il\q@u{a} m\q@u{a} otriftum feehi wamas\q@u{a}kinikum laAAallakum tusaloon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmcdxcvii{Q\q@u{a}loo y\q@u{a} waylan\q@u{a} inn\q@u{a} kunn\q@u{a} \q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmcdxcviii{Fam\q@u{a} z\q@u{a}lat tilka daAAw\q@u{a}hum \q@u{h}att\q@u{a} jaAAaln\q@u{a}hum \q@u{h}a\q@u{s}eedan kh\q@u{a}mideen\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmcdxcix{Wam\q@u{a} khalaqn\q@u{a} a\q@b{l}ssam\q@u{a}a wa\q@b{a}lar\q@u{d}a wam\q@u{a} baynahum\q@u{a} l\q@u{a}AAibeen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmd{Law aradn\q@u{a} an nattakhi\q@u{th}a lahwan la\q@b{i}ttakha\q@u{th}n\q@u{a}hu min ladunn\q@u{a} in kunn\q@u{a} f\q@u{a}AAileen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmdi{Bal naq\q@u{th}ifu bi\q@b{a}l\q@u{h}aqqi AAal\q@u{a} alb\q@u{at}ili fayadmaghuhu fai\q@u{tha} huwa z\q@u{a}hiqun walakumu alwaylu mimm\q@u{a} ta\q@u{s}ifoon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmdii{Walahu man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i waman AAindahu l\q@u{a} yastakbiroona AAan AAib\q@u{a}datihi wal\q@u{a} yasta\q@u{h}siroon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmdiii{Yusabbi\q@u{h}oona allayla wa\q@b{al}nnah\q@u{a}ra l\q@u{a} yafturoon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmdiv{Ami ittakha\q@u{th}oo \q@u{a}lihatan mina alar\q@u{d}i hum yunshiroon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmdv{Law k\q@u{a}na feehim\q@u{a} \q@u{a}lihatun ill\q@u{a} All\q@u{a}hu lafasadat\q@u{a} fasub\q@u{ha}na All\q@u{a}hi rabbi alAAarshi AAamm\q@u{a} ya\q@u{s}ifoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmdvi{L\q@u{a} yusalu AAamm\q@u{a} yafAAalu wahum yusaloon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmdvii{Ami ittakha\q@u{th}oo min doonihi \q@u{a}lihatan qul h\q@u{a}too burh\q@u{a}nakum h\q@u{atha} \q@u{th}ikru man maAAiya wa\q@u{th}ikru man qablee bal aktharuhum l\q@u{a} yaAAlamoona al\q@u{h}aqqa fahum muAAri\q@u{d}oon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmdviii{Wam\q@u{a} arsaln\q@u{a} min qablika min rasoolin ill\q@u{a} noo\q@u{h}ee ilayhi annahu l\q@u{a} il\q@u{a}ha ill\q@u{a} an\q@u{a} fa\q@b{o}AAbudoon\q@b{i}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmdix{Waq\q@u{a}loo ittakha\q@u{th}a a\q@b{l}rra\q@u{h}m\q@u{a}nu waladan sub\q@u{ha}nahu bal AAib\q@u{a}dun mukramoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmdx{L\q@u{a} yasbiqoonahu bi\q@b{a}lqawli wahum biamrihi yaAAmaloon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmdxi{YaAAlamu m\q@u{a} bayna aydeehim wam\q@u{a} khalfahum wal\q@u{a} yashfaAAoona ill\q@u{a} limani irta\q@u{da} wahum min khashyatihi mushfiqoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmdxii{Waman yaqul minhum innee il\q@u{a}hun min doonihi fa\q@u{tha}lika najzeehi jahannama ka\q@u{tha}lika najzee a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmdxiii{Awalam yar\q@u{a} alla\q@u{th}eena kafaroo anna a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a k\q@u{a}nat\q@u{a} ratqan fafataqn\q@u{a}hum\q@u{a} wajaAAaln\q@u{a} mina alm\q@u{a}i kulla shayin \q@u{h}ayyin afal\q@u{a} yuminoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmdxiv{WajaAAaln\q@u{a} fee alar\q@u{d}i raw\q@u{a}siya an tameeda bihim wajaAAaln\q@u{a} feeh\q@u{a }fij\q@u{a}jan subulan laAAallahum yahtadoon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmdxv{WajaAAaln\q@u{a} a\q@b{l}ssam\q@u{a}a saqfan ma\q@u{h}foo\q@i{\q@u{th}}an wahum AAan \q@u{a}y\q@u{a}tih\q@u{a} muAAri\q@u{d}oon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmdxvi{Wahuwa alla\q@u{th}ee khalaqa allayla wa\q@b{al}nnah\q@u{a}ra wa\q@b{al}shshamsa wa\q@b{a}lqamara kullun fee falakin yasba\q@u{h}oon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmdxvii{Wam\q@u{a} jaAAaln\q@u{a} libasharin min qablika alkhulda afain mitta fahumu alkh\q@u{a}lidoon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmdxviii{Kullu nafsin \q@u{tha}iqatu almawti wanablookum bi\q@b{al}shsharri wa\q@b{a}lkhayri fitnatan wailayn\q@u{a} turjaAAoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmdxix{Wai\q@u{tha} ra\q@u{a}ka alla\q@u{th}eena kafaroo in yattakhi\q@u{th}oonaka ill\q@u{a} huzuwan ah\q@u{atha} alla\q@u{th}ee ya\q@u{th}kuru \q@u{a}lihatakum wahum bi\q@u{th}ikri a\q@b{l}rra\q@u{h}m\q@u{a}ni hum k\q@u{a}firoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmdxx{Khuliqa alins\q@u{a}nu min AAajalin saoreekum \q@u{a}y\q@u{a}tee fal\q@u{a} tastaAAjiloon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmdxxi{Wayaqooloona mat\q@u{a} h\q@u{atha} alwaAAdu in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmdxxii{Law yaAAlamu alla\q@u{th}eena kafaroo \q@u{h}eena l\q@u{a} yakuffoona AAan wujoohihimu a\q@b{l}nn\q@u{a}ra wal\q@u{a} AAan \q@i{\q@u{th}}uhoorihim wal\q@u{a} hum yun\q@u{s}aroon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmdxxiii{Bal tateehim baghtatan fatabhatuhum fal\q@u{a} yasta\q@u{t}eeAAoona raddah\q@u{a} wal\q@u{a} hum yun\q@i{\q@u{th}}aroon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmdxxiv{Walaqadi istuhzia birusulin min qablika fa\q@u{ha}qa bi\q@b{a}lla\q@u{th}eena sakhiroo minhum m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmdxxv{Qul man yaklaokum bi\q@b{a}llayli wa\q@b{al}nnah\q@u{a}ri mina a\q@b{l}rra\q@u{h}m\q@u{a}ni bal hum AAan \q@u{th}ikri rabbihim muAAri\q@u{d}oon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmdxxvi{Am lahum \q@u{a}lihatun tamnaAAuhum min doonin\q@u{a} l\q@u{a} yasta\q@u{t}eeAAoona na\q@u{s}ra anfusihim wal\q@u{a} hum minn\q@u{a} yu\q@u{sh}aboon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmdxxvii{Bal mattaAAn\q@u{a} h\q@u{a}ol\q@u{a}i wa\q@u{a}b\q@u{a}ahum \q@u{h}att\q@u{a} \q@u{ta}la AAalayhimu alAAumuru afal\q@u{a} yarawna ann\q@u{a} natee alar\q@u{d}a nanqu\q@u{s}uh\q@u{a} min a\q@u{t}r\q@u{a}fih\q@u{a} afahumu algh\q@u{a}liboon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmdxxviii{Qul innam\q@u{a} on\q@u{th}irukum bi\q@b{a}lwa\q@u{h}yi wal\q@u{a} yasmaAAu a\q@b{l}\q@u{ss}ummu a\q@b{l}dduAA\q@u{a}a i\q@u{tha} m\q@u{a} yun\q@u{th}aroon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmdxxix{Walain massathum naf\q@u{h}atun min AAa\q@u{tha}bi rabbika layaqoolunna y\q@u{a }waylan\q@u{a} inn\q@u{a} kunn\q@u{a} \q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmdxxx{Wana\q@u{d}aAAu almaw\q@u{a}zeena alqis\q@u{t}a liyawmi alqiy\q@u{a}mati fal\q@u{a} tu\q@i{\q@u{th}}lamu nafsun shayan wain k\q@u{a}na mithq\q@u{a}la \q@u{h}abbatin min khardalin atayn\q@u{a} bih\q@u{a} wakaf\q@u{a} bin\q@u{a} \q@u{ha}sibeen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmdxxxi{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} wah\q@u{a}roona alfurq\q@u{a}na wa\q@u{d}iy\q@u{a}an wa\q@u{th}ikran lilmuttaqeen\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmdxxxii{Alla\q@u{th}eena yakhshawna rabbahum bi\q@b{a}lghaybi wahum mina a\q@b{l}ss\q@u{a}AAati mushfiqoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmdxxxiii{Wah\q@u{atha} \q@u{th}ikrun mub\q@u{a}rakun anzaln\q@u{a}hu afaantum lahu munkiroon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmdxxxiv{Walaqad \q@u{a}tayn\q@u{a} ibr\q@u{a}heema rushdahu min qablu wakunn\q@u{a} bihi AA\q@u{a}limeen\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmdxxxv{I\q@u{th} q\q@u{a}la liabeehi waqawmihi m\q@u{a} h\q@u{ath}ihi a\q@b{l}ttam\q@u{a}theelu allatee antum lah\q@u{a} AA\q@u{a}kifoon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmdxxxvi{Q\q@u{a}loo wajadn\q@u{a} \q@u{a}b\q@u{a}an\q@u{a} lah\q@u{a} AA\q@u{a}bideen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmdxxxvii{Q\q@u{a}la laqad kuntum antum wa\q@u{a}b\q@u{a}okum fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmdxxxviii{Q\q@u{a}loo ajitan\q@u{a} bi\q@b{a}l\q@u{h}aqqi am anta mina all\q@u{a}AAibeen\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmdxxxix{Q\q@u{a}la bal rabbukum rabbu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i alla\q@u{th}ee fa\q@u{t}arahunna waan\q@u{a} AAal\q@u{a} \q@u{tha}likum mina a\q@b{l}shsh\q@u{a}hideen\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmdxl{Wata\q@b{A}ll\q@u{a}hi laakeedanna a\q@u{s}n\q@u{a}makum baAAda an tuwalloo mudbireen\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmdxli{FajaAAalahum ju\q@u{thath}an ill\q@u{a} kabeeran lahum laAAallahum ilayhi yarjiAAoon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmdxlii{Q\q@u{a}loo man faAAala h\q@u{atha} bi\q@u{a}lihatin\q@u{a} innahu lamina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmdxliii{Q\q@u{a}loo samiAAn\q@u{a} fatan ya\q@u{th}kuruhum yuq\q@u{a}lu lahu ibr\q@u{a}heem\q@b{u}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmdxliv{Q\q@u{a}loo fatoo bihi AAal\q@u{a} aAAyuni a\q@b{l}nn\q@u{a}si laAAallahum yashhadoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmdxlv{Q\q@u{a}loo aanta faAAalta h\q@u{atha} bi\q@u{a}lihatin\q@u{a} y\q@u{a} ibr\q@u{a}heem\q@b{u}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmdxlvi{Q\q@u{a}la bal faAAalahu kabeeruhum h\q@u{atha} fa\q@b{i}saloohum in k\q@u{a}noo yan\q@u{t}iqoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmdxlvii{FarajaAAoo il\q@u{a} anfusihim faq\q@u{a}loo innakum antumu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmdxlviii{Thumma nukisoo AAal\q@u{a} ruoosihim laqad AAalimta m\q@u{a} h\q@u{a}ol\q@u{a}i yan\q@u{t}iqoon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmdxlix{Q\q@u{a}la afataAAbudoona min dooni All\q@u{a}hi m\q@u{a} l\q@u{a} yanfaAAukum shayan wal\q@u{a} ya\q@u{d}urrukum\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmdl{Offin lakum walim\q@u{a} taAAbudoona min dooni All\q@u{a}hi afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmdli{Q\q@u{a}loo \q@u{h}arriqoohu wa\q@b{o}n\q@u{s}uroo \q@u{a}lihatakum in kuntum f\q@u{a}AAileen\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmdlii{Quln\q@u{a} y\q@u{a} n\q@u{a}ru koonee bardan wasal\q@u{a}man AAal\q@u{a} ibr\q@u{a}heem\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmdliii{Waar\q@u{a}doo bihi kaydan fajaAAaln\q@u{a}humu alakhsareen\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmdliv{Wanajjayn\q@u{a}hu waloo\q@u{t}an il\q@u{a} alar\q@u{d}i allatee b\q@u{a}rakn\q@u{a} feeh\q@u{a} lilAA\q@u{a}lameen\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmdlv{Wawahabn\q@u{a} lahu is\q@u{ha}qa wayaAAqooba n\q@u{a}filatan wakullan jaAAaln\q@u{a} \q@u{sa}li\q@u{h}een\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmdlvi{WajaAAaln\q@u{a}hum aimmatan yahdoona biamrin\q@u{a} waaw\q@u{h}ayn\q@u{a} ilayhim fiAAla alkhayr\q@u{a}ti waiq\q@u{a}ma a\q@b{l}\q@u{ss}al\q@u{a}ti waeet\q@u{a}a a\q@b{l}zzak\q@u{a}ti wak\q@u{a}noo lan\q@u{a} AA\q@u{a}bideen\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmdlvii{Waloo\q@u{t}an \q@u{a}tayn\q@u{a}hu \q@u{h}ukman waAAilman wanajjayn\q@u{a}hu mina alqaryati allatee k\q@u{a}nat taAAmalu alkhab\q@u{a}itha innahum k\q@u{a}noo qawma sawin f\q@u{a}siqeen\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmdlviii{Waadkhaln\q@u{a}hu fee ra\q@u{h}matin\q@u{a} innahu mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmdlix{Wanoo\q@u{h}an i\q@u{th} n\q@u{a}d\q@u{a} min qablu fa\q@b{i}stajabn\q@u{a} lahu fanajjayn\q@u{a}hu waahlahu mina alkarbi alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmdlx{Wana\q@u{s}arn\q@u{a}hu mina alqawmi alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} innahum k\q@u{a}noo qawma sawin faaghraqn\q@u{a}hum ajmaAAeen\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmdlxi{Wad\q@u{a}wooda wasulaym\q@u{a}na i\q@u{th} ya\q@u{h}kum\q@u{a}ni fee al\q@u{h}arthi i\q@u{th} nafashat feehi ghanamu alqawmi wakunn\q@u{a} li\q@u{h}ukmihim sh\q@u{a}hideen\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmdlxii{Fafahhamn\q@u{a}h\q@u{a} sulaym\q@u{a}na wakullan \q@u{a}tayn\q@u{a} \q@u{h}ukman waAAilman wasakhkharn\q@u{a} maAAa d\q@u{a}wooda aljib\q@u{a}la yusabbi\q@u{h}na wa\q@b{al}\q@u{tt}ayra wakunn\q@u{a} f\q@u{a}AAileen\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmdlxiii{WaAAallamn\q@u{a}hu \q@u{s}anAAata laboosin lakum litu\q@u{hs}inakum min basikum fahal antum sh\q@u{a}kiroon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmdlxiv{Walisulaym\q@u{a}na a\q@b{l}rree\q@u{h}a AA\q@u{as}ifatan tajree biamrihi il\q@u{a} alar\q@u{d}i allatee b\q@u{a}rakn\q@u{a} feeh\q@u{a} wakunn\q@u{a} bikulli shayin AA\q@u{a}limeen\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmdlxv{Wamina a\q@b{l}shshay\q@u{at}eeni man yaghoo\q@u{s}oona lahu wayaAAmaloona AAamalan doona \q@u{tha}lika wakunn\q@u{a} lahum \q@u{ha}fi\q@i{\q@u{th}}een\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmdlxvi{Waayyooba i\q@u{th} n\q@u{a}d\q@u{a} rabbahu annee massaniya a\q@b{l}\q@u{dd}urru waanta ar\q@u{h}amu a\q@b{l}rr\q@u{ah}imeen\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmdlxvii{Fa\q@b{i}stajabn\q@u{a} lahu fakashafn\q@u{a} m\q@u{a} bihi min \q@u{d}urrin wa\q@u{a}tayn\q@u{a}hu ahlahu wamithlahum maAAahum ra\q@u{h}matan min AAindin\q@u{a} wa\q@u{th}ikr\q@u{a} lilAA\q@u{a}bideen\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmdlxviii{Waism\q@u{a}AAeela waidreesa wa\q@u{tha} alkifli kullun mina a\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmdlxix{Waadkhaln\q@u{a}hum fee ra\q@u{h}matin\q@u{a} innahum mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmdlxx{Wa\q@u{tha} a\q@b{l}nnooni i\q@u{th} \q@u{th}ahaba mugh\q@u{ad}iban fa\q@i{\q@u{th}}anna an lan naqdira AAalayhi fan\q@u{a}d\q@u{a} fee a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti an l\q@u{a} il\q@u{a}ha ill\q@u{a} anta sub\q@u{ha}naka innee kuntu mina a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmdlxxi{Fa\q@b{i}stajabn\q@u{a} lahu wanajjayn\q@u{a}hu mina alghammi waka\q@u{tha}lika nunjee almumineen\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmdlxxii{Wazakariyy\q@u{a} i\q@u{th} n\q@u{a}d\q@u{a} rabbahu rabbi l\q@u{a} ta\q@u{th}arnee fardan waanta khayru alw\q@u{a}ritheen\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmdlxxiii{Fa\q@b{i}stajabn\q@u{a} lahu wawahabn\q@u{a} lahu ya\q@u{h}y\q@u{a} waa\q@u{s}la\q@u{h}n\q@u{a} lahu zawjahu innahum k\q@u{a}noo yus\q@u{a}riAAoona fee alkhayr\q@u{a}ti wayadAAoonan\q@u{a} raghaban warahaban wak\q@u{a}noo lan\q@u{a} kh\q@u{a}shiAAeen\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmdlxxiv{Wa\q@b{a}llatee a\q@u{hs}anat farjah\q@u{a} fanafakhn\q@u{a} feeh\q@u{a} min roo\q@u{h}in\q@u{a} wajaAAaln\q@u{a}h\q@u{a} wa\q@b{i}bnah\q@u{a} \q@u{a}yatan lilAA\q@u{a}lameen\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmdlxxv{Inna h\q@u{ath}ihi ommatukum ommatan w\q@u{ah}idatan waan\q@u{a} rabbukum faoAAbudoon\q@b{i}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmdlxxvi{Wataqa\q@u{tt}aAAoo amrahum baynahum kullun ilayn\q@u{a} r\q@u{a}jiAAoon\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmdlxxvii{Faman yaAAmal mina a\q@b{l}\q@u{ssa}li\q@u{ha}ti wahuwa muminun fal\q@u{a} kufr\q@u{a}na lisaAAyihi wainn\q@u{a} lahu k\q@u{a}tiboon\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mmdlxxviii{Wa\q@u{h}ar\q@u{a}mun AAal\q@u{a} qaryatin ahlakn\q@u{a}h\q@u{a} annahum l\q@u{a} yarjiAAoon\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mmdlxxix{\q@u{H}att\q@u{a} i\q@u{tha} futi\q@u{h}at yajooju wamajooju wahum min kulli \q@u{h}adabin yansiloon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mmdlxxx{Wa\q@b{i}qtaraba alwaAAdu al\q@u{h}aqqu fai\q@u{tha} hiya sh\q@u{a}khi\q@u{s}atun ab\q@u{sa}ru alla\q@u{th}eena kafaroo y\q@u{a} waylan\q@u{a} qad kunn\q@u{a} fee ghaflatin min h\q@u{atha} bal kunn\q@u{a} \q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mmdlxxxi{Innakum wam\q@u{a} taAAbudoona min dooni All\q@u{a}hi \q@u{h}a\q@u{s}abu jahannama antum lah\q@u{a} w\q@u{a}ridoon\q@b{a}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mmdlxxxii{Law k\q@u{a}na h\q@u{a}ol\q@u{a}i \q@u{a}lihatan m\q@u{a} waradooh\q@u{a} wakullun feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mmdlxxxiii{Lahum feeh\q@u{a} zafeerun wahum feeh\q@u{a} l\q@u{a} yasmaAAoon\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mmdlxxxiv{Inna alla\q@u{th}eena sabaqat lahum minn\q@u{a} al\q@u{h}usn\q@u{a} ol\q@u{a}ika AAanh\q@u{a }mubAAadoon\q@b{a}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mmdlxxxv{L\q@u{a} yasmaAAoona \q@u{h}aseesah\q@u{a} wahum fee m\q@u{a} ishtahat anfusuhum kh\q@u{a}lidoon\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mmdlxxxvi{L\q@u{a} ya\q@u{h}zunuhumu alfazaAAu alakbaru watatalaqq\q@u{a}humu almal\q@u{a}ikatu h\q@u{atha} yawmukumu alla\q@u{th}ee kuntum tooAAadoon\q@b{a}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mmdlxxxvii{Yawma na\q@u{t}wee a\q@b{l}ssam\q@u{a}a ka\q@u{t}ayyi a\q@b{l}ssijlli lilkutubi kam\q@u{a} badan\q@u{a} awwala khalqin nuAAeeduhu waAAdan AAalayn\q@u{a} inn\q@u{a} kunn\q@u{a} f\q@u{a}AAileen\q@b{a}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mmdlxxxviii{Walaqad katabn\q@u{a} fee a\q@b{l}zzaboori min baAAdi a\q@b{l}\q@u{thth}ikri anna alar\q@u{d}a yarithuh\q@u{a} AAib\q@u{a}diya a\q@b{l}\q@u{ssa}li\q@u{h}oon\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mmdlxxxix{Inna fee h\q@u{atha} labal\q@u{a}ghan liqawmin AA\q@u{a}bideen\q@b{a}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mmdxc{Wam\q@u{a} arsaln\q@u{a}ka ill\q@u{a} ra\q@u{h}matan lilAA\q@u{a}lameen\q@b{a}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mmdxci{Qul innam\q@u{a} yoo\q@u{ha} ilayya annam\q@u{a} il\q@u{a}hukum il\q@u{a}hun w\q@u{ah}idun fahal antum muslimoon\q@b{a}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mmdxcii{Fain tawallaw faqul \q@u{ath}antukum AAal\q@u{a} saw\q@u{a}in wain adree aqareebun am baAAeedun m\q@u{a} tooAAadoon\q@b{a}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mmdxciii{Innahu yaAAlamu aljahra mina alqawli wayaAAlamu m\q@u{a} taktumoon\q@b{a}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mmdxciv{Wain adree laAAallahu fitnatun lakum wamat\q@u{a}AAun il\q@u{a} \q@u{h}een\q@b{in}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mmdxcv{Q\q@u{a}la rabbi o\q@u{h}kum bi\q@b{a}l\q@u{h}aqqi warabbun\q@u{a} a\q@b{l}rra\q@u{h}m\q@u{a}nu almustaAA\q@u{a}nu AAal\q@u{a} m\q@u{a} ta\q@u{s}ifoon\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@mmdxcvi{\basmalahlt Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su ittaqoo rabbakum inna zalzalata a\q@b{l}ss\q@u{a}AAati shayon AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmdxcvii{Yawma tarawnah\q@u{a} ta\q@u{th}halu kullu mur\q@u{d}iAAatin AAamm\q@u{a} ar\q@u{d}aAAat wata\q@u{d}aAAu kullu \q@u{tha}ti \q@u{h}amlin \q@u{h}amlah\q@u{a} watar\q@u{a} a\q@b{l}nn\q@u{a}sa suk\q@u{a}r\q@u{a} wam\q@u{a} hum bisuk\q@u{a}r\q@u{a} wal\q@u{a}kinna AAa\q@u{tha}ba All\q@u{a}hi shadeed\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmdxcviii{Wamina a\q@b{l}nn\q@u{a}si man yuj\q@u{a}dilu fee All\q@u{a}hi bighayri AAilmin wayattabiAAu kulla shay\q@u{ta}nin mareed\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmdxcix{Kutiba AAalayhi annahu man tawall\q@u{a}hu faannahu yu\q@u{d}illuhu wayahdeehi il\q@u{a} AAa\q@u{tha}bi a\q@b{l}ssaAAeer\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmdc{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su in kuntum fee raybin mina albaAAthi fainn\q@u{a} khalaqn\q@u{a}kum min tur\q@u{a}bin thumma min nu\q@u{t}fatin thumma min AAalaqatin thumma min mu\q@u{d}ghatin mukhallaqatin waghayri mukhallaqatin linubayyina lakum wanuqirru fee alar\q@u{ha}mi m\q@u{a} nash\q@u{a}o il\q@u{a} ajalin musamman thumma nukhrijukum \q@u{t}iflan thumma litablughoo ashuddakum waminkum man yutawaff\q@u{a} waminkum man yuraddu il\q@u{a} ar\q@u{th}ali alAAumuri likayl\q@u{a} yaAAlama min baAAdi AAilmin shayan watar\q@u{a} alar\q@u{d}a h\q@u{a}midatan fai\q@u{tha} anzaln\q@u{a} AAalayh\q@u{a} alm\q@u{a}a ihtazzat warabat waanbatat min kulli zawjin baheej\q@b{in}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmdci{\q@u{Tha}lika bianna All\q@u{a}ha huwa al\q@u{h}aqqu waannahu yu\q@u{h}yee almawt\q@u{a} waannahu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmdcii{Waanna a\q@b{l}ss\q@u{a}AAata \q@u{a}tiyatun l\q@u{a} rayba feeh\q@u{a} waanna All\q@u{a}ha yabAAathu man fee alquboor\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmdciii{Wamina a\q@b{l}nn\q@u{a}si man yuj\q@u{a}dilu fee All\q@u{a}hi bighayri AAilmin wal\q@u{a} hudan wal\q@u{a} kit\q@u{a}bin muneer\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmdciv{Th\q@u{a}niya AAi\q@u{t}fihi liyu\q@u{d}illa AAan sabeeli All\q@u{a}hi lahu fee a\q@b{l}dduny\q@u{a} khizyun wanu\q@u{th}eequhu yawma alqiy\q@u{a}mati AAa\q@u{tha}ba al\q@u{h}areeq\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmdcv{\q@u{Tha}lika bim\q@u{a} qaddamat yad\q@u{a}ka waanna All\q@u{a}ha laysa bi\q@i{\q@u{th}}all\q@u{a}min lilAAabeed\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmdcvi{Wamina a\q@b{l}nn\q@u{a}si man yaAAbudu All\q@u{a}ha AAal\q@u{a} \q@u{h}arfin fain a\q@u{sa}bahu khayrun i\q@u{t}maanna bihi wain a\q@u{sa}bathu fitnatun inqalaba AAal\q@u{a} wajhihi khasira a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirata \q@u{tha}lika huwa alkhusr\q@u{a}nu almubeen\q@b{u}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmdcvii{YadAAoo min dooni All\q@u{a}hi m\q@u{a} l\q@u{a} ya\q@u{d}urruhu wam\q@u{a} l\q@u{a} yanfaAAuhu \q@u{tha}lika huwa a\q@b{l}\q@u{dd}al\q@u{a}lu albaAAeed\q@b{u}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmdcviii{YadAAoo laman \q@u{d}arruhu aqrabu min nafAAihi labisa almawl\q@u{a} walabisa alAAasheer\q@b{u}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmdcix{Inna All\q@u{a}ha yudkhilu alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru inna All\q@u{a}ha yafAAalu m\q@u{a} yureed\q@b{u}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmdcx{Man k\q@u{a}na ya\q@i{\q@u{th}}unnu an lan yan\q@u{s}urahu All\q@u{a}hu fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati falyamdud bisababin il\q@u{a} a\q@b{l}ssam\q@u{a}i thumma liyaq\q@u{t}aAA falyan\q@i{\q@u{th}}ur hal yu\q@u{th}hibanna kayduhu m\q@u{a} yaghee\q@i{\q@u{th}}\q@b{u}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmdcxi{Waka\q@u{tha}lika anzaln\q@u{a}hu \q@u{a}y\q@u{a}tin bayyin\q@u{a}tin waanna All\q@u{a}ha yahdee man yureed\q@b{u}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmdcxii{Inna alla\q@u{th}eena \q@u{a}manoo wa\q@b{a}lla\q@u{th}eena h\q@u{a}doo wa\q@b{al}\q@u{ssa}bieena wa\q@b{al}nna\q@u{sa}r\q@u{a} wa\q@b{a}lmajoosa wa\q@b{a}lla\q@u{th}eena ashrakoo inna All\q@u{a}ha yaf\q@u{s}ilu baynahum yawma alqiy\q@u{a}mati inna All\q@u{a}ha AAal\q@u{a} kulli shayin shaheed\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmdcxiii{Alam tara anna All\q@u{a}ha yasjudu lahu man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti waman fee alar\q@u{d}i wa\q@b{al}shshamsu wa\q@b{a}lqamaru wa\q@b{al}nnujoomu wa\q@b{a}ljib\q@u{a}lu wa\q@b{al}shshajaru wa\q@b{al}ddaw\q@u{a}bbu wakatheerun mina a\q@b{l}nn\q@u{a}si wakatheerun \q@u{h}aqqa AAalayhi alAAa\q@u{tha}bu waman yuhini All\q@u{a}hu fam\q@u{a} lahu min mukrimin inna All\q@u{a}ha yafAAalu m\q@u{a} yash\q@u{a}\q@b{o}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmdcxiv{H\q@u{atha}ni kha\q@u{s}m\q@u{a}ni ikhta\q@u{s}amoo fee rabbihim fa\q@b{a}lla\q@u{th}eena kafaroo qu\q@u{tt}iAAat lahum thiy\q@u{a}bun min n\q@u{a}rin yu\q@u{s}abbu min fawqi ruoosihimu al\q@u{h}ameem\q@b{u}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmdcxv{Yu\q@u{s}haru bihi m\q@u{a} fee bu\q@u{t}oonihim wa\q@b{a}ljulood\q@b{u}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmdcxvi{Walahum maq\q@u{a}miAAu min \q@u{h}adeed\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmdcxvii{Kullam\q@u{a} ar\q@u{a}doo an yakhrujoo minh\q@u{a} min ghammin oAAeedoo feeh\q@u{a} wa\q@u{th}ooqoo AAa\q@u{tha}ba al\q@u{h}areeq\q@b{i}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmdcxviii{Inna All\q@u{a}ha yudkhilu alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru yu\q@u{h}allawna feeh\q@u{a} min as\q@u{a}wira min \q@u{th}ahabin waluluan walib\q@u{a}suhum feeh\q@u{a} \q@u{h}areer\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmdcxix{Wahudoo il\q@u{a} a\q@b{l}\q@u{tt}ayyibi mina alqawli wahudoo il\q@u{a} \q@u{s}ir\q@u{at}i al\q@u{h}ameed\q@b{i}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmdcxx{Inna alla\q@u{th}eena kafaroo waya\q@u{s}uddoona AAan sabeeli All\q@u{a}hi wa\q@b{a}lmasjidi al\q@u{h}ar\q@u{a}mi alla\q@u{th}ee jaAAaln\q@u{a}hu li\q@b{l}nn\q@u{a}si saw\q@u{a}an alAA\q@u{a}kifu feehi wa\q@b{a}lb\q@u{a}di waman yurid feehi biil\q@u{ha}din bi\q@i{\q@u{th}}ulmin nu\q@u{th}iqhu min AAa\q@u{tha}bin aleem\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmdcxxi{Wai\q@u{th} bawwan\q@u{a} liibr\q@u{a}heema mak\q@u{a}na albayti an l\q@u{a} tushrik bee shayan wa\q@u{t}ahhir baytiya li\q@b{l}\q@u{tta}ifeena wa\q@b{a}lq\q@u{a}imeena wa\q@b{al}rrukkaAAi a\q@b{l}ssujood\q@b{i}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmdcxxii{Waa\q@u{thth}in fee a\q@b{l}nn\q@u{a}si bi\q@b{a}l\q@u{h}ajji yatooka rij\q@u{a}lan waAAal\q@u{a} kulli \q@u{da}mirin yateena min kulli fajjin AAameeq\q@b{in}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmdcxxiii{Liyashhadoo man\q@u{a}fiAAa lahum waya\q@u{th}kuroo isma All\q@u{a}hi fee ayy\q@u{a}min maAAloom\q@u{a}tin AAal\q@u{a} m\q@u{a} razaqahum min baheemati alanAA\q@u{a}mi fakuloo minh\q@u{a} waa\q@u{t}AAimoo alb\q@u{a}isa alfaqeer\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmdcxxiv{Thumma lyaq\q@u{d}oo tafathahum walyoofoo nu\q@u{th}oorahum walya\q@u{tt}awwafoo bi\q@b{a}lbayti alAAateeq\q@b{i}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmdcxxv{\q@u{Tha}lika waman yuAAa\q@i{\q@u{thth}}im \q@u{h}urum\q@u{a}ti All\q@u{a}hi fahuwa khayrun lahu AAinda rabbihi wao\q@u{h}illat lakumu alanAA\q@u{a}mu ill\q@u{a} m\q@u{a} yutl\q@u{a} AAalaykum fa\q@b{i}jtaniboo a\q@b{l}rrijsa mina alawth\q@u{a}ni wa\q@b{i}jtaniboo qawla a\q@b{l}zzoor\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmdcxxvi{\q@u{H}unaf\q@u{a}a lill\q@u{a}hi ghayra mushrikeena bihi waman yushrik bi\q@b{A}ll\q@u{a}hi fakaannam\q@u{a} kharra mina a\q@b{l}ssam\q@u{a}i fatakh\q@u{t}afuhu a\q@b{l}\q@u{tt}ayru aw tahwee bihi a\q@b{l}rree\q@u{h}u fee mak\q@u{a}nin sa\q@u{h}eeq\q@b{in}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmdcxxvii{\q@u{Tha}lika waman yuAAa\q@i{\q@u{thth}}im shaAA\q@u{a}ira All\q@u{a}hi fainnah\q@u{a} min taqw\q@u{a} alquloob\q@b{i}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmdcxxviii{Lakum feeh\q@u{a} man\q@u{a}fiAAu il\q@u{a} ajalin musamman thumma ma\q@u{h}illuh\q@u{a} il\q@u{a} albayti alAAateeq\q@b{i}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmdcxxix{Walikulli ommatin jaAAaln\q@u{a} mansakan liya\q@u{th}kuroo isma All\q@u{a}hi AAal\q@u{a} m\q@u{a} razaqahum min baheemati alanAA\q@u{a}mi fail\q@u{a}hukum il\q@u{a}hun w\q@u{ah}idun falahu aslimoo wabashshiri almukhbiteen\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmdcxxx{Alla\q@u{th}eena i\q@u{tha} \q@u{th}ukira All\q@u{a}hu wajilat quloobuhum wa\q@b{al}\q@u{ssa}bireena AAal\q@u{a} m\q@u{a} a\q@u{sa}bahum wa\q@b{a}lmuqeemee a\q@b{l}\q@u{ss}al\q@u{a}ti wamimm\q@u{a} razaqn\q@u{a}hum yunfiqoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmdcxxxi{Wa\q@b{a}lbudna jaAAaln\q@u{a}h\q@u{a} lakum min shaAA\q@u{a}iri All\q@u{a}hi lakum feeh\q@u{a} khayrun fa\q@b{o}\q@u{th}kuroo isma All\q@u{a}hi AAalayh\q@u{a} \q@u{s}aw\q@u{a}ffa fai\q@u{tha} wajabat junoobuh\q@u{a} fakuloo minh\q@u{a} waa\q@u{t}AAimoo alq\q@u{a}niAAa wa\q@b{a}lmuAAtarra ka\q@u{tha}lika sakhkharn\q@u{a}h\q@u{a} lakum laAAallakum tashkuroon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmdcxxxii{Lan yan\q@u{a}la All\q@u{a}ha lu\q@u{h}oomuh\q@u{a} wal\q@u{a} dim\q@u{a}oh\q@u{a} wal\q@u{a}kin yan\q@u{a}luhu a\q@b{l}ttaqw\q@u{a} minkum ka\q@u{tha}lika sakhkharah\q@u{a} lakum litukabbiroo All\q@u{a}ha AAal\q@u{a} m\q@u{a} had\q@u{a}kum wabashshiri almu\q@u{h}sineen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmdcxxxiii{Inna All\q@u{a}ha yud\q@u{a}fiAAu AAani alla\q@u{th}eena \q@u{a}manoo inna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu kulla khaww\q@u{a}nin kafoor\q@b{in}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmdcxxxiv{O\q@u{th}ina lilla\q@u{th}eena yuq\q@u{a}taloona biannahum \q@i{\q@u{th}}ulimoo wainna All\q@u{a}ha AAal\q@u{a} na\q@u{s}rihim laqadeer\q@b{un}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmdcxxxv{Alla\q@u{th}eena okhrijoo min diy\q@u{a}rihim bighayri \q@u{h}aqqin ill\q@u{a} an yaqooloo rabbun\q@u{a} All\q@u{a}hu walawl\q@u{a} dafAAu All\q@u{a}hi a\q@b{l}nn\q@u{a}sa baAA\q@u{d}ahum bibaAA\q@u{d}in lahuddimat \q@u{s}aw\q@u{a}miAAu wabiyaAAun wa\q@u{s}alaw\q@u{a}tun wamas\q@u{a}jidu yu\q@u{th}karu feeh\q@u{a} ismu All\q@u{a}hi katheeran walayan\q@u{s}uranna All\q@u{a}hu man yan\q@u{s}uruhu inna All\q@u{a}ha laqawiyyun AAazeez\q@b{un}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmdcxxxvi{Alla\q@u{th}eena in makkann\q@u{a}hum fee alar\q@u{d}i aq\q@u{a}moo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}tawoo a\q@b{l}zzak\q@u{a}ta waamaroo bi\q@b{a}lmaAAroofi wanahaw AAani almunkari walill\q@u{a}hi AA\q@u{a}qibatu alomoor\q@b{i}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmdcxxxvii{Wain yuka\q@u{thth}ibooka faqad ka\q@u{thth}abat qablahum qawmu noo\q@u{h}in waAA\q@u{a}dun wathamood\q@b{u}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmdcxxxviii{Waqawmu ibr\q@u{a}heema waqawmu loo\q@u{t}\q@b{in}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmdcxxxix{Waa\q@u{s}\q@u{ha}bu madyana waku\q@u{thth}iba moos\q@u{a} faamlaytu lilk\q@u{a}fireena thumma akha\q@u{th}tuhum fakayfa k\q@u{a}na nakeer\q@b{i}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmdcxl{Fakaayyin min qaryatin ahlakn\q@u{a}h\q@u{a} wahiya \q@i{\q@u{th}}\q@u{a}limatun fahiya kh\q@u{a}wiyatun AAal\q@u{a} AAurooshih\q@u{a} wabirin muAAa\q@u{tt}alatin waqa\q@u{s}rin masheed\q@b{in}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmdcxli{Afalam yaseeroo fee alar\q@u{d}i fatakoona lahum quloobun yaAAqiloona bih\q@u{a} aw \q@u{atha}nun yasmaAAoona bih\q@u{a} fainnah\q@u{a} l\q@u{a} taAAm\q@u{a} alab\q@u{sa}ru wal\q@u{a}kin taAAm\q@u{a} alquloobu allatee fee a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmdcxlii{WayastaAAjiloonaka bi\q@b{a}lAAa\q@u{tha}bi walan yukhlifa All\q@u{a}hu waAAdahu wainna yawman AAinda rabbika kaalfi sanatin mimm\q@u{a} taAAuddoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmdcxliii{Wakaayyin min qaryatin amlaytu lah\q@u{a} wahiya \q@i{\q@u{th}}\q@u{a}limatun thumma akha\q@u{th}tuh\q@u{a} wailayya alma\q@u{s}eer\q@b{u}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmdcxliv{Qul y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su innam\q@u{a} an\q@u{a} lakum na\q@u{th}eerun mubeen\q@b{un}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmdcxlv{Fa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lahum maghfiratun warizqun kareem\q@b{un}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmdcxlvi{Wa\q@b{a}lla\q@u{th}eena saAAaw fee \q@u{a}y\q@u{a}tin\q@u{a} muAA\q@u{a}jizeena ol\q@u{a}ika a\q@u{s}\q@u{ha}bu alja\q@u{h}eem\q@b{i}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmdcxlvii{Wam\q@u{a} arsaln\q@u{a} min qablika min rasoolin wal\q@u{a} nabiyyin ill\q@u{a} i\q@u{tha} tamann\q@u{a} alq\q@u{a} a\q@b{l}shshay\q@u{ta}nu fee omniyyatihi fayansakhu All\q@u{a}hu m\q@u{a} yulqee a\q@b{l}shshay\q@u{ta}nu thumma yu\q@u{h}kimu All\q@u{a}hu \q@u{a}y\q@u{a}tihi wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmdcxlviii{LiyajAAala m\q@u{a} yulqee a\q@b{l}shshay\q@u{ta}nu fitnatan lilla\q@u{th}eena fee quloobihim mara\q@u{d}un wa\q@b{a}lq\q@u{a}siyati quloobuhum wainna a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena lafee shiq\q@u{a}qin baAAeed\q@b{in}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmdcxlix{WaliyaAAlama alla\q@u{th}eena ootoo alAAilma annahu al\q@u{h}aqqu min rabbika fayuminoo bihi fatukhbita lahu quloobuhum wainna All\q@u{a}ha lah\q@u{a}di alla\q@u{th}eena \q@u{a}manoo il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmdcl{Wal\q@u{a} yaz\q@u{a}lu alla\q@u{th}eena kafaroo fee miryatin minhu \q@u{h}att\q@u{a} tatiyahumu a\q@b{l}ss\q@u{a}AAatu baghtatan aw yatiyahum AAa\q@u{tha}bu yawmin AAaqeem\q@b{in}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmdcli{Almulku yawmai\q@u{th}in lill\q@u{a}hi ya\q@u{h}kumu baynahum fa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti fee jann\q@u{a}ti a\q@b{l}nnaAAeem\q@b{i}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmdclii{Wa\q@b{a}lla\q@u{th}eena kafaroo waka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} faol\q@u{a}ika lahum AAa\q@u{tha}bun muheen\q@b{un}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmdcliii{Wa\q@b{a}lla\q@u{th}eena h\q@u{a}jaroo fee sabeeli All\q@u{a}hi thumma qutiloo aw m\q@u{a}too layarzuqannahumu All\q@u{a}hu rizqan \q@u{h}asanan wainna All\q@u{a}ha lahuwa khayru a\q@b{l}rr\q@u{a}ziqeen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmdcliv{Layudkhilannahum mudkhalan yar\q@u{d}awnahu wainna All\q@u{a}ha laAAaleemun \q@u{h}aleem\q@b{un}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmdclv{\q@u{Tha}lika waman AA\q@u{a}qaba bimithli m\q@u{a} AAooqiba bihi thumma bughiya AAalayhi layan\q@u{s}urannahu All\q@u{a}hu inna All\q@u{a}ha laAAafuwwun ghafoor\q@b{un}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmdclvi{\q@u{Tha}lika bianna All\q@u{a}ha yooliju allayla fee a\q@b{l}nnah\q@u{a}ri wayooliju a\q@b{l}nnah\q@u{a}ra fee allayli waanna All\q@u{a}ha sameeAAun ba\q@u{s}eer\q@b{un}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmdclvii{\q@u{Tha}lika bianna All\q@u{a}ha huwa al\q@u{h}aqqu waanna m\q@u{a} yadAAoona min doonihi huwa alb\q@u{at}ilu waanna All\q@u{a}ha huwa alAAaliyyu alkabeer\q@b{u}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmdclviii{Alam tara anna All\q@u{a}ha anzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an fatu\q@u{s}bi\q@u{h}u alar\q@u{d}u mukh\q@u{d}arratan inna All\q@u{a}ha la\q@u{t}eefun khabeer\q@b{un}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmdclix{Lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wainna All\q@u{a}ha lahuwa alghaniyyu al\q@u{h}ameed\q@b{u}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmdclx{Alam tara anna All\q@u{a}ha sakhkhara lakum m\q@u{a} fee alar\q@u{d}i wa\q@b{a}lfulka tajree fee alba\q@u{h}ri biamrihi wayumsiku a\q@b{l}ssam\q@u{a}a an taqaAAa AAal\q@u{a} alar\q@u{d}i ill\q@u{a} bii\q@u{th}nihi inna All\q@u{a}ha bi\q@b{al}nn\q@u{a}si laraoofun ra\q@u{h}eem\q@b{un}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmdclxi{Wahuwa alla\q@u{th}ee a\q@u{h}y\q@u{a}kum thumma yumeetukum thumma yu\q@u{h}yeekum inna alins\q@u{a}na lakafoor\q@b{un}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmdclxii{Likulli ommatin jaAAaln\q@u{a} mansakan hum n\q@u{a}sikoohu fal\q@u{a} yun\q@u{a}ziAAunnaka fee alamri wa\q@b{o}dAAu il\q@u{a} rabbika innaka laAAal\q@u{a} hudan mustaqeem\q@b{in}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmdclxiii{Wain j\q@u{a}dalooka faquli All\q@u{a}hu aAAlamu bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmdclxiv{All\q@u{a}hu ya\q@u{h}kumu baynakum yawma alqiy\q@u{a}mati feem\q@u{a} kuntum feehi takhtalifoon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmdclxv{Alam taAAlam anna All\q@u{a}ha yaAAlamu m\q@u{a} fee a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i inna \q@u{tha}lika fee kit\q@u{a}bin inna \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi yaseer\q@b{un}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmdclxvi{WayaAAbudoona min dooni All\q@u{a}hi m\q@u{a} lam yunazzil bihi sul\q@u{ta}nan wam\q@u{a} laysa lahum bihi AAilmun wam\q@u{a} li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena min na\q@u{s}eer\q@b{in}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmdclxvii{Wai\q@u{tha} tutl\q@u{a} AAalayhim \q@u{a}y\q@u{a}tun\q@u{a} bayyin\q@u{a}tin taAArifu fee wujoohi alla\q@u{th}eena kafaroo almunkara yak\q@u{a}doona yas\q@u{t}oona bi\q@b{a}lla\q@u{th}eena yatloona AAalayhim \q@u{a}y\q@u{a}tin\q@u{a} qul afaonabbiokum bisharrin min \q@u{tha}likum a\q@b{l}nn\q@u{a}ru waAAadah\q@u{a} All\q@u{a}hu alla\q@u{th}eena kafaroo wabisa alma\q@u{s}eer\q@b{u}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmdclxviii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su \q@u{d}uriba mathalun fa\q@b{i}stamiAAoo lahu inna alla\q@u{th}eena tadAAoona min dooni All\q@u{a}hi lan yakhluqoo \q@u{th}ub\q@u{a}ban walawi ijtamaAAoo lahu wain yaslubuhumu a\q@b{l}\q@u{thth}ub\q@u{a}bu shayan l\q@u{a} yastanqi\q@u{th}oohu minhu \q@u{d}aAAufa a\q@b{l}\q@u{tta}libu wa\q@b{a}lma\q@u{t}loob\q@b{u}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmdclxix{M\q@u{a} qadaroo All\q@u{a}ha \q@u{h}aqqa qadrihi inna All\q@u{a}ha laqawiyyun AAazeez\q@b{un}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmdclxx{All\q@u{a}hu ya\q@u{st}afee mina almal\q@u{a}ikati rusulan wamina a\q@b{l}nn\q@u{a}si inna All\q@u{a}ha sameeAAun ba\q@u{s}eer\q@b{un}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmdclxxi{YaAAlamu m\q@u{a} bayna aydeehim wam\q@u{a} khalfahum wail\q@u{a} All\q@u{a}hi turjaAAu alomoor\q@b{u}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmdclxxii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo irkaAAoo wa\q@b{o}sjudoo wa\q@b{o}AAbudoo rabbakum wa\q@b{i}fAAaloo alkhayra laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmdclxxiii{Waj\q@u{a}hidoo fee All\q@u{a}hi \q@u{h}aqqa jih\q@u{a}dihi huwa ijtab\q@u{a}kum wam\q@u{a} jaAAala AAalaykum fee a\q@b{l}ddeeni min \q@u{h}arajin millata abeekum ibr\q@u{a}heema huwa samm\q@u{a}kumu almuslimeena min qablu wafee h\q@u{atha} liyakoona a\q@b{l}rrasoolu shaheedan AAalaykum watakoonoo shuhad\q@u{a}a AAal\q@u{a} a\q@b{l}nn\q@u{a}si faaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}too a\q@b{l}zzak\q@u{a}ta wa\q@b{i}AAta\q@u{s}imoo bi\q@b{A}ll\q@u{a}hi huwa mawl\q@u{a}kum faniAAma almawl\q@u{a} waniAAma a\q@b{l}nna\q@u{s}eer\q@b{u}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmdclxxiv{\basmalahlt Qad afla\q@u{h}a almuminoon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmdclxxv{Alla\q@u{th}eena hum fee \q@u{s}al\q@u{a}tihim kh\q@u{a}shiAAoon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmdclxxvi{Wa\q@b{a}lla\q@u{th}eena hum AAani allaghwi muAAri\q@u{d}oon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmdclxxvii{Wa\q@b{a}lla\q@u{th}eena hum li\q@b{l}zzak\q@u{a}ti f\q@u{a}AAiloon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmdclxxviii{Wa\q@b{a}lla\q@u{th}eena hum lifuroojihim \q@u{ha}fi\q@i{\q@u{th}}oon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmdclxxix{Ill\q@u{a} AAal\q@u{a} azw\q@u{a}jihim aw m\q@u{a} malakat aym\q@u{a}nuhum fainnahum ghayru maloomeen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmdclxxx{Famani ibtagh\q@u{a} war\q@u{a}a \q@u{tha}lika faol\q@u{a}ika humu alAA\q@u{a}doon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmdclxxxi{Wa\q@b{a}lla\q@u{th}eena hum liam\q@u{a}n\q@u{a}tihim waAAahdihim r\q@u{a}AAoon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmdclxxxii{Wa\q@b{a}lla\q@u{th}eena hum AAal\q@u{a} \q@u{s}alaw\q@u{a}tihim yu\q@u{ha}fi\q@i{\q@u{th}}oon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmdclxxxiii{Ol\q@u{a}ika humu alw\q@u{a}rithoon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmdclxxxiv{Alla\q@u{th}eena yarithoona alfirdawsa hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmdclxxxv{Walaqad khalaqn\q@u{a} alins\q@u{a}na min sul\q@u{a}latin min \q@u{t}een\q@b{in}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmdclxxxvi{Thumma jaAAaln\q@u{a}hu nu\q@u{t}fatan fee qar\q@u{a}rin makeen\q@b{in}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmdclxxxvii{Thumma khalaqn\q@u{a} a\q@b{l}nnu\q@u{t}fata AAalaqatan fakhalaqn\q@u{a} alAAalaqata mu\q@u{d}ghatan fakhalaqn\q@u{a} almu\q@u{d}ghata AAi\q@i{\q@u{th}}\q@u{a}man fakasawn\q@u{a} alAAi\q@i{\q@u{th}}\q@u{a}ma la\q@u{h}man thumma anshan\q@u{a}hu khalqan \q@u{a}khara fatab\q@u{a}raka All\q@u{a}hu a\q@u{h}sanu alkh\q@u{a}liqeen\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmdclxxxviii{Thumma innakum baAAda \q@u{tha}lika lamayyitoon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmdclxxxix{Thumma innakum yawma alqiy\q@u{a}mati tubAAathoon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmdcxc{Walaqad khalaqn\q@u{a} fawqakum sabAAa \q@u{t}ar\q@u{a}iqa wam\q@u{a} kunn\q@u{a} AAani alkhalqi gh\q@u{a}fileen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmdcxci{Waanzaln\q@u{a} mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an biqadarin faaskann\q@u{a}hu fee alar\q@u{d}i wainn\q@u{a} AAal\q@u{a} \q@u{th}ah\q@u{a}bin bihi laq\q@u{a}diroon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmdcxcii{Faanshan\q@u{a} lakum bihi jann\q@u{a}tin min nakheelin waaAAn\q@u{a}bin lakum feeh\q@u{a} faw\q@u{a}kihu katheeratun waminh\q@u{a} takuloon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmdcxciii{Washajaratan takhruju min \q@u{t}oori sayn\q@u{a}a tanbutu bi\q@b{al}dduhni wa\q@u{s}ibghin lil\q@u{a}kileen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmdcxciv{Wainna lakum fee alanAA\q@u{a}mi laAAibratan nusqeekum mimm\q@u{a} fee bu\q@u{t}oonih\q@u{a} walakum feeh\q@u{a} man\q@u{a}fiAAu katheeratun waminh\q@u{a} takuloon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmdcxcv{WaAAalayh\q@u{a} waAAal\q@u{a} alfulki tu\q@u{h}maloon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmdcxcvi{Walaqad arsaln\q@u{a} noo\q@u{h}an il\q@u{a} qawmihi faq\q@u{a}la y\q@u{a} qawmi oAAbudoo All\q@u{a}ha m\q@u{a} lakum min il\q@u{a}hin ghayruhu afal\q@u{a} tattaqoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmdcxcvii{Faq\q@u{a}la almalao alla\q@u{th}eena kafaroo min qawmihi m\q@u{a} h\q@u{atha} ill\q@u{a} basharun mithlukum yureedu an yatafa\q@u{dd}ala AAalaykum walaw sh\q@u{a}a All\q@u{a}hu laanzala mal\q@u{a}ikatan m\q@u{a} samiAAn\q@u{a} bih\q@u{atha} fee \q@u{a}b\q@u{a}in\q@u{a} alawwaleen\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmdcxcviii{In huwa ill\q@u{a} rajulun bihi jinnatun fatarabba\q@u{s}oo bihi \q@u{h}att\q@u{a} \q@u{h}een\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmdcxcix{Q\q@u{a}la rabbi on\q@u{s}urnee bim\q@u{a} ka\q@u{thth}aboon\q@b{i}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmdcc{Faaw\q@u{h}ayn\q@u{a} ilayhi ani i\q@u{s}naAAi alfulka biaAAyunin\q@u{a} wawa\q@u{h}yin\q@u{a} fai\q@u{tha} j\q@u{a}a amrun\q@u{a} waf\q@u{a}ra a\q@b{l}ttannooru fa\q@b{o}sluk feeh\q@u{a} min kullin zawjayni ithnayni waahlaka ill\q@u{a} man sabaqa AAalayhi alqawlu minhum wal\q@u{a} tukh\q@u{at}ibnee fee alla\q@u{th}eena \q@i{\q@u{th}}alamoo innahum mughraqoon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmdcci{Fai\q@u{tha} istawayta anta waman maAAaka AAal\q@u{a} alfulki faquli al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee najj\q@u{a}n\q@u{a} mina alqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmdccii{Waqul rabbi anzilnee munzalan mub\q@u{a}rakan waanta khayru almunzileen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmdcciii{Inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin wain kunn\q@u{a} lamubtaleen\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmdcciv{Thumma anshan\q@u{a} min baAAdihim qarnan \q@u{a}khareen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmdccv{Faarsaln\q@u{a} feehim rasoolan minhum ani oAAbudoo All\q@u{a}ha m\q@u{a} lakum min il\q@u{a}hin ghayruhu afal\q@u{a} tattaqoon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmdccvi{Waq\q@u{a}la almalao min qawmihi alla\q@u{th}eena kafaroo waka\q@u{thth}aboo biliq\q@u{a}i al\q@u{a}khirati waatrafn\q@u{a}hum fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} m\q@u{a} h\q@u{atha} ill\q@u{a} basharun mithlukum yakulu mimm\q@u{a} takuloona minhu wayashrabu mimm\q@u{a} tashraboon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmdccvii{Walain a\q@u{t}aAAtum basharan mithlakum innakum i\q@u{th}an lakh\q@u{a}siroon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmdccviii{AyaAAidukum annakum i\q@u{tha} mittum wakuntum tur\q@u{a}ban waAAi\q@i{\q@u{th}}\q@u{a}man annakum mukhrajoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmdccix{Hayh\q@u{a}ta hayh\q@u{a}ta lim\q@u{a} tooAAadoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmdccx{In hiya ill\q@u{a} \q@u{h}ay\q@u{a}tun\q@u{a} a\q@b{l}dduny\q@u{a} namootu wana\q@u{h}y\q@u{a} wam\q@u{a} na\q@u{h}nu bimabAAootheen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmdccxi{In huwa ill\q@u{a} rajulun iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban wam\q@u{a} na\q@u{h}nu lahu bimumineen\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmdccxii{Q\q@u{a}la rabbi on\q@u{s}urnee bim\q@u{a} ka\q@u{thth}aboon\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmdccxiii{Q\q@u{a}la AAamm\q@u{a} qaleelin layu\q@u{s}bi\q@u{h}unna n\q@u{a}dimeen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmdccxiv{Faakha\q@u{th}athumu a\q@b{l}\q@u{ss}ay\q@u{h}atu bi\q@b{a}l\q@u{h}aqqi fajaAAaln\q@u{a}hum ghuth\q@u{a}an fabuAAdan lilqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmdccxv{Thumma anshan\q@u{a} min baAAdihim quroonan \q@u{a}khareen\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmdccxvi{M\q@u{a} tasbiqu min ommatin ajalah\q@u{a} wam\q@u{a} yastakhiroon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmdccxvii{Thumma arsaln\q@u{a} rusulan\q@u{a} tatr\q@u{a} kulla m\q@u{a} j\q@u{a}a ommatan rasooluh\q@u{a} ka\q@u{thth}aboohu faatbaAAn\q@u{a} baAA\q@u{d}ahum baAA\q@u{d}an wajaAAaln\q@u{a}hum a\q@u{ha}deetha fabuAAdan liqawmin l\q@u{a} yuminoon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmdccxviii{Thumma arsaln\q@u{a} moos\q@u{a} waakh\q@u{a}hu h\q@u{a}roona bi\q@u{a}y\q@u{a}tin\q@u{a} wasul\q@u{ta}nin mubeen\q@b{in}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmdccxix{Il\q@u{a} firAAawna wamalaihi fa\q@b{i}stakbaroo wak\q@u{a}noo qawman AA\q@u{a}leen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmdccxx{Faq\q@u{a}loo anuminu libasharayni mithlin\q@u{a} waqawmuhum\q@u{a} lan\q@u{a} AA\q@u{a}bidoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmdccxxi{Faka\q@u{thth}aboohum\q@u{a} fak\q@u{a}noo mina almuhlakeen\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmdccxxii{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba laAAallahum yahtadoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmdccxxiii{WajaAAaln\q@u{a} ibna maryama waommahu \q@u{a}yatan wa\q@u{a}wayn\q@u{a}hum\q@u{a} il\q@u{a} rabwatin \q@u{tha}ti qar\q@u{a}rin wamaAAeen\q@b{in}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmdccxxiv{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}rrusulu kuloo mina a\q@b{l}\q@u{tt}ayyib\q@u{a}ti wa\q@b{i}AAmaloo \q@u{sa}li\q@u{h}an innee bim\q@u{a} taAAmaloona AAaleem\q@b{un}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmdccxxv{Wainna h\q@u{ath}ihi ommatukum ommatan w\q@u{ah}idatan waan\q@u{a} rabbukum fa\q@b{i}ttaqoon\q@b{i}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmdccxxvi{Fataqa\q@u{tt}aAAoo amrahum baynahum zuburan kullu \q@u{h}izbin bim\q@u{a} ladayhim fari\q@u{h}oon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmdccxxvii{Fa\q@u{th}arhum fee ghamratihim \q@u{h}att\q@u{a} \q@u{h}een\q@b{in}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmdccxxviii{Aya\q@u{h}saboona annam\q@u{a} numidduhum bihi min m\q@u{a}lin wabaneen\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmdccxxix{Nus\q@u{a}riAAu lahum fee alkhayr\q@u{a}ti bal l\q@u{a} yashAAuroon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmdccxxx{Inna alla\q@u{th}eena hum min khashyati rabbihim mushfiqoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmdccxxxi{Wa\q@b{a}lla\q@u{th}eena hum bi\q@u{a}y\q@u{a}ti rabbihim yuminoon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmdccxxxii{Wa\q@b{a}lla\q@u{th}eena hum birabbihim l\q@u{a} yushrikoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmdccxxxiii{Wa\q@b{a}lla\q@u{th}eena yutoona m\q@u{a} \q@u{a}taw waquloobuhum wajilatun annahum il\q@u{a} rabbihim r\q@u{a}jiAAoon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmdccxxxiv{Ol\q@u{a}ika yus\q@u{a}riAAoona fee alkhayr\q@u{a}ti wahum lah\q@u{a} s\q@u{a}biqoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmdccxxxv{Wal\q@u{a} nukallifu nafsan ill\q@u{a} wusAAah\q@u{a} waladayn\q@u{a} kit\q@u{a}bun yan\q@u{t}iqu bi\q@b{a}l\q@u{h}aqqi wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmdccxxxvi{Bal quloobuhum fee ghamratin min h\q@u{atha} walahum aAAm\q@u{a}lun min dooni \q@u{tha}lika hum lah\q@u{a} AA\q@u{a}miloon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmdccxxxvii{\q@u{H}att\q@u{a} i\q@u{tha} akha\q@u{th}n\q@u{a} mutrafeehim bi\q@b{a}lAAa\q@u{tha}bi i\q@u{tha} hum yajaroon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmdccxxxviii{L\q@u{a} tajaroo alyawma innakum minn\q@u{a} l\q@u{a} tun\q@u{s}aroon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmdccxxxix{Qad k\q@u{a}nat \q@u{a}y\q@u{a}tee tutl\q@u{a} AAalaykum fakuntum AAal\q@u{a} aAAq\q@u{a}bikum tanki\q@u{s}oon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmdccxl{Mustakbireena bihi s\q@u{a}miran tahjuroon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmdccxli{Afalam yaddabbaroo alqawla am j\q@u{a}ahum m\q@u{a} lam yati \q@u{a}b\q@u{a}ahumu alawwaleen\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmdccxlii{Am lam yaAArifoo rasoolahum fahum lahu munkiroon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmdccxliii{Am yaqooloona bihi jinnatun bal j\q@u{a}ahum bi\q@b{a}l\q@u{h}aqqi waaktharuhum lil\q@u{h}aqqi k\q@u{a}rihoon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmdccxliv{Walawi ittabaAAa al\q@u{h}aqqu ahw\q@u{a}ahum lafasadati a\q@b{l}ssam\q@u{a}w\q@u{a}tu wa\q@b{a}lar\q@u{d}u waman feehinna bal atayn\q@u{a}hum bi\q@u{th}ikrihim fahum AAan \q@u{th}ikrihim muAAri\q@u{d}oon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmdccxlv{Am tasaluhum kharjan fakhar\q@u{a}ju rabbika khayrun wahuwa khayru a\q@b{l}rr\q@u{a}ziqeen\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmdccxlvi{Wainnaka latadAAoohum il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmdccxlvii{Wainna alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati AAani a\q@b{l}\q@u{ss}ir\q@u{at}i lan\q@u{a}kiboon\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmdccxlviii{Walaw ra\q@u{h}imn\q@u{a}hum wakashafn\q@u{a} m\q@u{a} bihim min \q@u{d}urrin lalajjoo fee \q@u{t}ughy\q@u{a}nihim yaAAmahoon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmdccxlix{Walaqad akha\q@u{th}n\q@u{a}hum bi\q@b{a}lAAa\q@u{tha}bi fam\q@u{a} istak\q@u{a}noo lirabbihim wam\q@u{a} yata\q@u{d}arraAAoon\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmdccl{\q@u{H}att\q@u{a} i\q@u{tha} fata\q@u{h}n\q@u{a} AAalayhim b\q@u{a}ban \q@u{tha} AAa\q@u{tha}bin shadeedin i\q@u{tha} hum feehi mublisoon\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmdccli{Wahuwa alla\q@u{th}ee anshaa lakumu a\q@b{l}ssamAAa wa\q@b{a}lab\q@u{sa}ra wa\q@b{a}lafidata qaleelan m\q@u{a} tashkuroon\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmdcclii{Wahuwa alla\q@u{th}ee \q@u{th}araakum fee alar\q@u{d}i wailayhi tu\q@u{h}sharoon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmdccliii{Wahuwa alla\q@u{th}ee yu\q@u{h}yee wayumeetu walahu ikhtil\q@u{a}fu allayli wa\q@b{al}nnah\q@u{a}ri afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmdccliv{Bal q\q@u{a}loo mithla m\q@u{a} q\q@u{a}la alawwaloon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmdcclv{Q\q@u{a}loo ai\q@u{tha} mitn\q@u{a} wakunn\q@u{a} tur\q@u{a}ban waAAi\q@i{\q@u{th}}\q@u{a}man ainn\q@u{a} lamabAAoothoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmdcclvi{Laqad wuAAidn\q@u{a} na\q@u{h}nu wa\q@u{a}b\q@u{a}on\q@u{a} h\q@u{atha} min qablu in h\q@u{atha} ill\q@u{a} as\q@u{at}eeru alawwaleen\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmdcclvii{Qul limani alar\q@u{d}u waman feeh\q@u{a} in kuntum taAAlamoon\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmdcclviii{Sayaqooloona lill\q@u{a}hi qul afal\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmdcclix{Qul man rabbu a\q@b{l}ssam\q@u{a}w\q@u{a}ti a\q@b{l}ssabAAi warabbu alAAarshi alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmdcclx{Sayaqooloona lill\q@u{a}hi qul afal\q@u{a} tattaqoon\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmdcclxi{Qul man biyadihi malakootu kulli shayin wahuwa yujeeru wal\q@u{a} yuj\q@u{a}ru AAalayhi in kuntum taAAlamoon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmdcclxii{Sayaqooloona lill\q@u{a}hi qul faann\q@u{a} tus\q@u{h}aroon\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmdcclxiii{Bal atayn\q@u{a}hum bi\q@b{a}l\q@u{h}aqqi wainnahum lak\q@u{ath}iboon\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmdcclxiv{M\q@u{a} ittakha\q@u{th}a All\q@u{a}hu min waladin wam\q@u{a} k\q@u{a}na maAAahu min il\q@u{a}hin i\q@u{th}an la\q@u{th}ahaba kullu il\q@u{a}hin bim\q@u{a} khalaqa walaAAal\q@u{a} baAA\q@u{d}uhum AAal\q@u{a} baAA\q@u{d}in sub\q@u{ha}na All\q@u{a}hi AAamm\q@u{a} ya\q@u{s}ifoon\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmdcclxv{AA\q@u{a}limi alghaybi wa\q@b{al}shshah\q@u{a}dati fataAA\q@u{a}l\q@u{a} AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmdcclxvi{Qul rabbi imm\q@u{a} turiyannee m\q@u{a} yooAAadoon\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmdcclxvii{Rabbi fal\q@u{a} tajAAalnee fee alqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mmdcclxviii{Wainn\q@u{a} AAal\q@u{a} an nuriyaka m\q@u{a} naAAiduhum laq\q@u{a}diroon\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mmdcclxix{IdfaAA bi\q@b{a}llatee hiya a\q@u{h}sanu a\q@b{l}ssayyiata na\q@u{h}nu aAAlamu bim\q@u{a} ya\q@u{s}ifoon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mmdcclxx{Waqul rabbi aAAoo\q@u{th}u bika min hamaz\q@u{a}ti a\q@b{l}shshay\q@u{at}een\q@b{i}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mmdcclxxi{WaaAAoo\q@u{th}u bika rabbi an ya\q@u{hd}uroon\q@b{i}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mmdcclxxii{\q@u{H}att\q@u{a} i\q@u{tha} j\q@u{a}a a\q@u{h}adahumu almawtu q\q@u{a}la rabbi irjiAAoon\q@b{i}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mmdcclxxiii{LaAAallee aAAmalu \q@u{sa}li\q@u{h}an feem\q@u{a} taraktu kall\q@u{a} innah\q@u{a} kalimatun huwa q\q@u{a}iluh\q@u{a} wamin war\q@u{a}ihim barzakhun il\q@u{a} yawmi yubAAathoon\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mmdcclxxiv{Fai\q@u{tha} nufikha fee a\q@b{l}\q@u{ss}oori fal\q@u{a} ans\q@u{a}ba baynahum yawmai\q@u{th}in wal\q@u{a} yatas\q@u{a}aloon\q@b{a}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mmdcclxxv{Faman thaqulat maw\q@u{a}zeenuhu faol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mmdcclxxvi{Waman khaffat maw\q@u{a}zeenuhu faol\q@u{a}ika alla\q@u{th}eena khasiroo anfusahum fee jahannama kh\q@u{a}lidoon\q@b{a}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mmdcclxxvii{Talfa\q@u{h}u wujoohahumu a\q@b{l}nn\q@u{a}ru wahum feeh\q@u{a} k\q@u{a}li\q@u{h}oon\q@b{a}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mmdcclxxviii{Alam takun \q@u{a}y\q@u{a}tee tutl\q@u{a} AAalaykum fakuntum bih\q@u{a} tuka\q@u{thth}iboon\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mmdcclxxix{Q\q@u{a}loo rabban\q@u{a} ghalabat AAalayn\q@u{a} shiqwatun\q@u{a} wakunn\q@u{a} qawman \q@u{da}lleen\q@b{a}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mmdcclxxx{Rabban\q@u{a} akhrijn\q@u{a} minh\q@u{a} fain AAudn\q@u{a} fainn\q@u{a} \q@i{\q@u{th}}\q@u{a}limoon\q@b{a}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mmdcclxxxi{Q\q@u{a}la ikhsaoo feeh\q@u{a} wal\q@u{a} tukallimoon\q@b{i}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mmdcclxxxii{Innahu k\q@u{a}na fareequn min AAib\q@u{a}dee yaqooloona rabban\q@u{a} \q@u{a}mann\q@u{a} fa\q@b{i}ghfir lan\q@u{a} wa\q@b{i}r\q@u{h}amn\q@u{a} waanta khayru a\q@b{l}rr\q@u{ah}imeen\q@b{a}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mmdcclxxxiii{Fa\q@b{i}ttakha\q@u{th}tumoohum sikhriyyan \q@u{h}att\q@u{a} ansawkum \q@u{th}ikree wakuntum minhum ta\q@u{dh}akoon\q@b{a}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mmdcclxxxiv{Innee jazaytuhumu alyawma bim\q@u{a} \q@u{s}abaroo annahum humu alf\q@u{a}izoon\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mmdcclxxxv{Q\q@u{a}la kam labithtum fee alar\q@u{d}i AAadada sineen\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@mmdcclxxxvi{Q\q@u{a}loo labithn\q@u{a} yawman aw baAA\q@u{d}a yawmin fa\q@b{i}sali alAA\q@u{a}ddeen\q@b{a}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@mmdcclxxxvii{Q\q@u{a}la in labithtum ill\q@u{a} qaleelan law annakum kuntum taAAlamoon\q@b{a}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@mmdcclxxxviii{Afa\q@u{h}asibtum annam\q@u{a} khalaqn\q@u{a}kum AAabathan waannakum ilayn\q@u{a} l\q@u{a} turjaAAoon\q@b{a}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@mmdcclxxxix{FataAA\q@u{a}l\q@u{a} All\q@u{a}hu almaliku al\q@u{h}aqqu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa rabbu alAAarshi alkareem\q@b{i}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@mmdccxc{Waman yadAAu maAAa All\q@u{a}hi il\q@u{a}han \q@u{a}khara l\q@u{a} burh\q@u{a}na lahu bihi fainnam\q@u{a} \q@u{h}is\q@u{a}buhu AAinda rabbihi innahu l\q@u{a} yufli\q@u{h}u alk\q@u{a}firoon\q@b{a}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@mmdccxci{Waqul rabbi ighfir wa\q@b{i}r\q@u{h}am waanta khayru a\q@b{l}rr\q@u{ah}imeen\q@b{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@mmdccxcii{\basmalahlt Sooratun anzaln\q@u{a}h\q@u{a} wafara\q@u{d}n\q@u{a}h\q@u{a} waanzaln\q@u{a} feeh\q@u{a} \q@u{a}y\q@u{a}tin bayyin\q@u{a}tin laAAallakum ta\q@u{th}akkaroon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmdccxciii{A\q@b{l}zz\q@u{a}niyatu wa\q@b{al}zz\q@u{a}nee fa\q@b{i}jlidoo kulla w\q@u{ah}idin minhum\q@u{a} miata jaldatin wal\q@u{a} takhu\q@u{th}kum bihim\q@u{a} rafatun fee deeni All\q@u{a}hi in kuntum tuminoona bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri walyashhad AAa\q@u{tha}bahum\q@u{a} \q@u{ta}ifatun mina almumineen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmdccxciv{A\q@b{l}zz\q@u{a}nee l\q@u{a} yanki\q@u{h}u ill\q@u{a} z\q@u{a}niyatan aw mushrikatan wa\q@b{al}zz\q@u{a}niyatu l\q@u{a} yanki\q@u{h}uh\q@u{a} ill\q@u{a} z\q@u{a}nin aw mushrikun wa\q@u{h}urrima \q@u{tha}lika AAal\q@u{a} almumineen\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmdccxcv{Wa\q@b{a}lla\q@u{th}eena yarmoona almu\q@u{hs}an\q@u{a}ti thumma lam yatoo biarbaAAati shuhad\q@u{a}a fa\q@b{i}jlidoohum tham\q@u{a}neena jaldatan wal\q@u{a} taqbaloo lahum shah\q@u{a}datan abadan waol\q@u{a}ika humu alf\q@u{a}siqoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmdccxcvi{Ill\q@u{a} alla\q@u{th}eena t\q@u{a}boo min baAAdi \q@u{tha}lika waa\q@u{s}la\q@u{h}oo fainna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmdccxcvii{Wa\q@b{a}lla\q@u{th}eena yarmoona azw\q@u{a}jahum walam yakun lahum shuhad\q@u{a}o ill\q@u{a} anfusuhum fashah\q@u{a}datu a\q@u{h}adihim arbaAAu shah\q@u{a}d\q@u{a}tin bi\q@b{A}ll\q@u{a}hi innahu lamina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmdccxcviii{Wa\q@b{a}lkh\q@u{a}misatu anna laAAnata All\q@u{a}hi AAalayhi in k\q@u{a}na mina alk\q@u{ath}ibeen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmdccxcix{Wayadrao AAanh\q@u{a} alAAa\q@u{tha}ba an tashhada arbaAAa shah\q@u{a}d\q@u{a}tin bi\q@b{A}ll\q@u{a}hi innahu lamina alk\q@u{ath}ibeen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmdccc{Wa\q@b{a}lkh\q@u{a}misata anna gha\q@u{d}aba All\q@u{a}hi AAalayh\q@u{a} in k\q@u{a}na mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmdccci{Walawl\q@u{a} fa\q@u{d}lu All\q@u{a}hi AAalaykum wara\q@u{h}matuhu waanna All\q@u{a}ha taww\q@u{a}bun \q@u{h}akeem\q@b{un}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmdcccii{Inna alla\q@u{th}eena j\q@u{a}oo bi\q@b{a}lifki AAu\q@u{s}batun minkum l\q@u{a} ta\q@u{h}saboohu sharran lakum bal huwa khayrun lakum likulli imriin minhum m\q@u{a} iktasaba mina alithmi wa\q@b{a}lla\q@u{th}ee tawall\q@u{a} kibrahu minhum lahu AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmdccciii{Lawl\q@u{a} i\q@u{th} samiAAtumoohu \q@i{\q@u{th}}anna almuminoona wa\q@b{a}lmumin\q@u{a}tu bianfusihim khayran waq\q@u{a}loo h\q@u{atha} ifkun mubeen\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmdccciv{Lawl\q@u{a} j\q@u{a}oo AAalayhi biarbaAAati shuhad\q@u{a}a fai\q@u{th} lam yatoo bi\q@b{al}shshuhad\q@u{a}i faol\q@u{a}ika AAinda All\q@u{a}hi humu alk\q@u{ath}iboon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmdcccv{Walawl\q@u{a} fa\q@u{d}lu All\q@u{a}hi AAalaykum wara\q@u{h}matuhu fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati lamassakum fee m\q@u{a} afa\q@u{d}tum feehi AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmdcccvi{I\q@u{th} talaqqawnahu bialsinatikum wataqooloona biafw\q@u{a}hikum m\q@u{a} laysa lakum bihi AAilmun wata\q@u{h}saboonahu hayyinan wahuwa AAinda All\q@u{a}hi AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmdcccvii{Walawl\q@u{a} i\q@u{th} samiAAtumoohu qultum m\q@u{a} yakoonu lan\q@u{a} an natakallama bih\q@u{atha} sub\q@u{ha}naka h\q@u{atha} buht\q@u{a}nun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmdcccviii{YaAAi\q@i{\q@u{th}}ukumu All\q@u{a}hu an taAAoodoo limithlihi abadan in kuntum mumineen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmdcccix{Wayubayyinu All\q@u{a}hu lakumu al\q@u{a}y\q@u{a}ti wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmdcccx{Inna alla\q@u{th}eena yu\q@u{h}ibboona an tasheeAAa alf\q@u{ah}ishatu fee alla\q@u{th}eena \q@u{a}manoo lahum AAa\q@u{tha}bun aleemun fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati wa\q@b{A}ll\q@u{a}hu yaAAlamu waantum l\q@u{a} taAAlamoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmdcccxi{Walawl\q@u{a} fa\q@u{d}lu All\q@u{a}hi AAalaykum wara\q@u{h}matuhu waanna All\q@u{a}ha raoofun ra\q@u{h}eem\q@b{un}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmdcccxii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tattabiAAoo khu\q@u{t}uw\q@u{a}ti a\q@b{l}shshay\q@u{ta}ni waman yattabiAA khu\q@u{t}uw\q@u{a}ti a\q@b{l}shshay\q@u{ta}ni fainnahu yamuru bi\q@b{a}lfa\q@u{h}sh\q@u{a}i wa\q@b{a}lmunkari walawl\q@u{a} fa\q@u{d}lu All\q@u{a}hi AAalaykum wara\q@u{h}matuhu m\q@u{a} zak\q@u{a} minkum min a\q@u{h}adin abadan wal\q@u{a}kinna All\q@u{a}ha yuzakkee man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu sameeAAun AAaleem\q@b{un}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmdcccxiii{Wal\q@u{a} yatali oloo alfa\q@u{d}li minkum wa\q@b{al}ssaAAati an yutoo olee alqurb\q@u{a} wa\q@b{a}lmas\q@u{a}keena wa\q@b{a}lmuh\q@u{a}jireena fee sabeeli All\q@u{a}hi walyaAAfoo walya\q@u{s}fa\q@u{h}oo al\q@u{a} tu\q@u{h}ibboona an yaghfira All\q@u{a}hu lakum wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmdcccxiv{Inna alla\q@u{th}eena yarmoona almu\q@u{hs}an\q@u{a}ti algh\q@u{a}fil\q@u{a}ti almumin\q@u{a}ti luAAinoo fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati walahum AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmdcccxv{Yawma tashhadu AAalayhim alsinatuhum waaydeehim waarjuluhum bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmdcccxvi{Yawmai\q@u{th}in yuwaffeehimu All\q@u{a}hu deenahumu al\q@u{h}aqqa wayaAAlamoona anna All\q@u{a}ha huwa al\q@u{h}aqqu almubeen\q@b{u}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmdcccxvii{Alkhabeeth\q@u{a}tu lilkhabeetheena wa\q@b{a}lkhabeethoona lilkhabeeth\q@u{a}ti wa\q@b{al}\q@u{tt}ayyib\q@u{a}tu li\q@b{l}\q@u{tt}ayyibeena wa\q@b{al}\q@u{tt}ayyiboona li\q@b{l}\q@u{tt}ayyib\q@u{a}ti ol\q@u{a}ika mubarraoona mimm\q@u{a} yaqooloona lahum maghfiratun warizqun kareem\q@b{un}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmdcccxviii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tadkhuloo buyootan ghayra buyootikum \q@u{h}att\q@u{a} tastanisoo watusallimoo AAal\q@u{a} ahlih\q@u{a} \q@u{tha}likum khayrun lakum laAAallakum ta\q@u{th}akkaroon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmdcccxix{Fain lam tajidoo feeh\q@u{a} a\q@u{h}adan fal\q@u{a} tadkhulooh\q@u{a} \q@u{h}att\q@u{a} yu\q@u{th}ana lakum wain qeela lakumu irjiAAoo fa\q@b{i}rjiAAoo huwa azk\q@u{a} lakum wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona AAaleem\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmdcccxx{Laysa AAalaykum jun\q@u{ah}un an tadkhuloo buyootan ghayra maskoonatin feeh\q@u{a} mat\q@u{a}AAun lakum wa\q@b{A}ll\q@u{a}hu yaAAlamu m\q@u{a} tubdoona wam\q@u{a} taktumoon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmdcccxxi{Qul lilmumineena yaghu\q@u{dd}oo min ab\q@u{sa}rihum waya\q@u{h}fa\q@i{\q@u{th}}oo furoojahum \q@u{tha}lika azk\q@u{a} lahum inna All\q@u{a}ha khabeerun bim\q@u{a} ya\q@u{s}naAAoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmdcccxxii{Waqul lilmumin\q@u{a}ti yagh\q@u{d}u\q@u{d}na min ab\q@u{sa}rihinna waya\q@u{h}fa\q@i{\q@u{th}}na furoojahunna wal\q@u{a} yubdeena zeenatahunna ill\q@u{a} m\q@u{a} \q@i{\q@u{th}}ahara minh\q@u{a} walya\q@u{d}ribna bikhumurihinna AAal\q@u{a} juyoobihinna wal\q@u{a} yubdeena zeenatahunna ill\q@u{a} libuAAoolatihinna aw \q@u{a}b\q@u{a}ihinna aw \q@u{a}b\q@u{a}i buAAoolatihinna aw abn\q@u{a}ihinna aw abn\q@u{a}i buAAoolatihinna aw ikhw\q@u{a}nihinna aw banee ikhw\q@u{a}nihinna aw banee akhaw\q@u{a}tihinna aw nis\q@u{a}ihinna aw m\q@u{a} malakat aym\q@u{a}nuhunna awi a\q@b{l}tt\q@u{a}biAAeena ghayri olee alirbati mina a\q@b{l}rrij\q@u{a}li awi a\q@b{l}\q@u{tt}ifli alla\q@u{th}eena lam ya\q@i{\q@u{th}}haroo AAal\q@u{a} AAawr\q@u{a}ti a\q@b{l}nnis\q@u{a}i wal\q@u{a} ya\q@u{d}ribna biarjulihinna liyuAAlama m\q@u{a} yukhfeena min zeenatihinna watooboo il\q@u{a} All\q@u{a}hi jameeAAan ayyuh\q@u{a} almuminoona laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmdcccxxiii{Waanki\q@u{h}oo alay\q@u{a}m\q@u{a} minkum wa\q@b{al}\q@u{ssa}li\q@u{h}eena min AAib\q@u{a}dikum waim\q@u{a}ikum in yakoonoo fuqar\q@u{a}a yughnihimu All\q@u{a}hu min fa\q@u{d}lihi wa\q@b{A}ll\q@u{a}hu w\q@u{a}siAAun AAaleem\q@b{un}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmdcccxxiv{WalyastaAAfifi alla\q@u{th}eena l\q@u{a} yajidoona nik\q@u{ah}an \q@u{h}att\q@u{a} yughniyahumu All\q@u{a}hu min fa\q@u{d}lihi wa\q@b{a}lla\q@u{th}eena yabtaghoona alkit\q@u{a}ba mimm\q@u{a} malakat aym\q@u{a}nukum fak\q@u{a}tiboohum in AAalimtum feehim khayran wa\q@u{a}toohum min m\q@u{a}li All\q@u{a}hi alla\q@u{th}ee \q@u{a}t\q@u{a}kum wal\q@u{a} tukrihoo fatay\q@u{a}tikum AAal\q@u{a} albigh\q@u{a}i in aradna ta\q@u{h}a\q@u{ss}unan litabtaghoo AAara\q@u{d}a al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} waman yukrihhunna fainna All\q@u{a}ha min baAAdi ikr\q@u{a}hihinna ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmdcccxxv{Walaqad anzaln\q@u{a} ilaykum \q@u{a}y\q@u{a}tin mubayyin\q@u{a}tin wamathalan mina alla\q@u{th}eena khalaw min qablikum wamawAAi\q@i{\q@u{th}}atan lilmuttaqeen\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmdcccxxvi{All\q@u{a}hu nooru a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i mathalu noorihi kamishk\q@u{a}tin feeh\q@u{a} mi\q@u{s}b\q@u{ah}un almi\q@u{s}b\q@u{ah}u fee zuj\q@u{a}jatin a\q@b{l}zzuj\q@u{a}jatu kaannah\q@u{a} kawkabun durriyyun yooqadu min shajaratin mub\q@u{a}rakatin zaytoonatin l\q@u{a} sharqiyyatin wal\q@u{a} gharbiyyatin yak\q@u{a}du zaytuh\q@u{a} yu\q@u{d}eeo walaw lam tamsashu n\q@u{a}run noorun AAal\q@u{a} noorin yahdee All\q@u{a}hu linoorihi man yash\q@u{a}o waya\q@u{d}ribu All\q@u{a}hu alamth\q@u{a}la li\q@b{l}nn\q@u{a}si wa\q@b{A}ll\q@u{a}hu bikulli shayin AAaleem\q@b{un}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmdcccxxvii{Fee buyootin a\q@u{th}ina All\q@u{a}hu an turfaAAa wayu\q@u{th}kara feeh\q@u{a} ismuhu yusabbi\q@u{h}u lahu feeh\q@u{a} bi\q@b{a}lghuduwwi wa\q@b{a}l\q@u{asa}l\q@b{i}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmdcccxxviii{Rij\q@u{a}lun l\q@u{a} tulheehim tij\q@u{a}ratun wal\q@u{a} bayAAun AAan \q@u{th}ikri All\q@u{a}hi waiq\q@u{a}mi a\q@b{l}\q@u{ss}al\q@u{a}ti waeet\q@u{a}i a\q@b{l}zzak\q@u{a}ti yakh\q@u{a}foona yawman tataqallabu feehi alquloobu wa\q@b{a}lab\q@u{sa}r\q@b{u}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmdcccxxix{Liyajziyahumu All\q@u{a}hu a\q@u{h}sana m\q@u{a} AAamiloo wayazeedahum min fa\q@u{d}lihi wa\q@b{A}ll\q@u{a}hu yarzuqu man yash\q@u{a}o bighayri \q@u{h}is\q@u{a}b\q@b{in}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmdcccxxx{Wa\q@b{a}lla\q@u{th}eena kafaroo aAAm\q@u{a}luhum kasar\q@u{a}bin biqeeAAatin ya\q@u{h}sabuhu a\q@b{l}\q@i{\q@u{thth}}am\q@u{a}nu m\q@u{a}an \q@u{h}att\q@u{a} i\q@u{tha} j\q@u{a}ahu lam yajidhu shayan wawajada All\q@u{a}ha AAindahu fawaff\q@u{a}hu \q@u{h}is\q@u{a}bahu wa\q@b{A}ll\q@u{a}hu sareeAAu al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmdcccxxxi{Aw ka\q@i{\q@u{th}}ulum\q@u{a}tin fee ba\q@u{h}rin lujjiyyin yaghsh\q@u{a}hu mawjun min fawqihi mawjun min fawqihi sa\q@u{ha}bun \q@i{\q@u{th}}ulum\q@u{a}tun baAA\q@u{d}uh\q@u{a} fawqa baAA\q@u{d}in i\q@u{tha} akhraja yadahu lam yakad yar\q@u{a}h\q@u{a} waman lam yajAAali All\q@u{a}hu lahu nooran fam\q@u{a} lahu min noor\q@b{in}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmdcccxxxii{Alam tara anna All\q@u{a}ha yusabbi\q@u{h}u lahu man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{al}\q@u{tt}ayru \q@u{sa}ff\q@u{a}tin kullun qad AAalima \q@u{s}al\q@u{a}tahu watasbee\q@u{h}ahu wa\q@b{A}ll\q@u{a}hu AAaleemun bim\q@u{a} yafAAaloon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmdcccxxxiii{Walill\q@u{a}hi mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wail\q@u{a} All\q@u{a}hi alma\q@u{s}eer\q@b{u}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmdcccxxxiv{Alam tara anna All\q@u{a}ha yuzjee sa\q@u{ha}ban thumma yuallifu baynahu thumma yajAAaluhu ruk\q@u{a}man fatar\q@u{a} alwadqa yakhruju min khil\q@u{a}lihi wayunazzilu mina a\q@b{l}ssam\q@u{a}i min jib\q@u{a}lin feeh\q@u{a} min baradin fayu\q@u{s}eebu bihi man yash\q@u{a}o waya\q@u{s}rifuhu AAan man yash\q@u{a}o yak\q@u{a}du san\q@u{a} barqihi ya\q@u{th}habu bi\q@b{a}lab\q@u{sa}r\q@b{i}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmdcccxxxv{Yuqallibu All\q@u{a}hu allayla wa\q@b{al}nnah\q@u{a}ra inna fee \q@u{tha}lika laAAibratan liolee alab\q@u{sa}r\q@b{i}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmdcccxxxvi{Wa\q@b{A}ll\q@u{a}hu khalaqa kulla d\q@u{a}bbatin min m\q@u{a}in faminhum man yamshee AAal\q@u{a} ba\q@u{t}nihi waminhum man yamshee AAal\q@u{a} rijlayni waminhum man yamshee AAal\q@u{a} arbaAAin yakhluqu All\q@u{a}hu m\q@u{a} yash\q@u{a}o inna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmdcccxxxvii{Laqad anzaln\q@u{a} \q@u{a}y\q@u{a}tin mubayyin\q@u{a}tin wa\q@b{A}ll\q@u{a}hu yahdee man yash\q@u{a}o il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmdcccxxxviii{Wayaqooloona \q@u{a}mann\q@u{a} bi\q@b{A}ll\q@u{a}hi wabi\q@b{al}rrasooli waa\q@u{t}aAAn\q@u{a} thumma yatawall\q@u{a} fareequn minhum min baAAdi \q@u{tha}lika wam\q@u{a} ol\q@u{a}ika bi\q@b{a}lmumineen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmdcccxxxix{Wai\q@u{tha} duAAoo il\q@u{a} All\q@u{a}hi warasoolihi liya\q@u{h}kuma baynahum i\q@u{tha} fareequn minhum muAAri\q@u{d}oon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmdcccxl{Wain yakun lahumu al\q@u{h}aqqu yatoo ilayhi mu\q@u{th}AAineen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmdcccxli{Afee quloobihim mara\q@u{d}un ami irt\q@u{a}boo am yakh\q@u{a}foona an ya\q@u{h}eefa All\q@u{a}hu AAalayhim warasooluhu bal ol\q@u{a}ika humu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmdcccxlii{Innam\q@u{a} k\q@u{a}na qawla almumineena i\q@u{tha} duAAoo il\q@u{a} All\q@u{a}hi warasoolihi liya\q@u{h}kuma baynahum an yaqooloo samiAAn\q@u{a} waa\q@u{t}aAAn\q@u{a} waol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmdcccxliii{Waman yu\q@u{t}iAAi All\q@u{a}ha warasoolahu wayakhsha All\q@u{a}ha wayattaqhi faol\q@u{a}ika humu alf\q@u{a}izoon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmdcccxliv{Waaqsamoo bi\q@b{A}ll\q@u{a}hi jahda aym\q@u{a}nihim lain amartahum layakhrujunna qul l\q@u{a} tuqsimoo \q@u{ta}AAatun maAAroofatun inna All\q@u{a}ha khabeerun bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmdcccxlv{Qul a\q@u{t}eeAAoo All\q@u{a}ha waa\q@u{t}eeAAoo a\q@b{l}rrasoola fain tawallaw fainnam\q@u{a} AAalayhi m\q@u{a} \q@u{h}ummila waAAalaykum m\q@u{a} \q@u{h}ummiltum wain tu\q@u{t}eeAAoohu tahtadoo wam\q@u{a} AAal\q@u{a} a\q@b{l}rrasooli ill\q@u{a} albal\q@u{a}ghu almubeen\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmdcccxlvi{WaAAada All\q@u{a}hu alla\q@u{th}eena \q@u{a}manoo minkum waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti layastakhlifannahum fee alar\q@u{d}i kam\q@u{a} istakhlafa alla\q@u{th}eena min qablihim walayumakkinanna lahum deenahumu alla\q@u{th}ee irta\q@u{da} lahum walayubaddilannahum min baAAdi khawfihim amnan yaAAbudoonanee l\q@u{a} yushrikoona bee shayan waman kafara baAAda \q@u{tha}lika faol\q@u{a}ika humu alf\q@u{a}siqoon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmdcccxlvii{Waaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}too a\q@b{l}zzak\q@u{a}ta waa\q@u{t}eeAAoo a\q@b{l}rrasoola laAAallakum tur\q@u{h}amoon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmdcccxlviii{L\q@u{a} ta\q@u{h}sabanna alla\q@u{th}eena kafaroo muAAjizeena fee alar\q@u{d}i wamaw\q@u{a}humu a\q@b{l}nn\q@u{a}ru walabisa alma\q@u{s}eer\q@b{u}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmdcccxlix{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo liyasta\q@u{th}inkumu alla\q@u{th}eena malakat aym\q@u{a}nukum wa\q@b{a}lla\q@u{th}eena lam yablughoo al\q@u{h}uluma minkum thal\q@u{a}tha marr\q@u{a}tin min qabli \q@u{s}al\q@u{a}ti alfajri wa\q@u{h}eena ta\q@u{d}aAAoona thiy\q@u{a}bakum mina a\q@b{l}\q@i{\q@u{thth}}aheerati wamin baAAdi \q@u{s}al\q@u{a}ti alAAish\q@u{a}i thal\q@u{a}thu AAawr\q@u{a}tin lakum laysa AAalaykum wal\q@u{a} AAalayhim jun\q@u{ah}un baAAdahunna \q@u{t}aww\q@u{a}foona AAalaykum baAA\q@u{d}ukum AAal\q@u{a} baAA\q@u{d}in ka\q@u{tha}lika yubayyinu All\q@u{a}hu lakumu al\q@u{a}y\q@u{a}ti wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmdcccl{Wai\q@u{tha} balagha ala\q@u{t}f\q@u{a}lu minkumu al\q@u{h}uluma falyasta\q@u{th}inoo kam\q@u{a} ista\q@u{th}ana alla\q@u{th}eena min qablihim ka\q@u{tha}lika yubayyinu All\q@u{a}hu lakum \q@u{a}y\q@u{a}tihi wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmdcccli{Wa\q@b{a}lqaw\q@u{a}AAidu mina a\q@b{l}nnis\q@u{a}i all\q@u{a}tee l\q@u{a} yarjoona nik\q@u{ah}an falaysa AAalayhinna jun\q@u{ah}un an ya\q@u{d}aAAna thiy\q@u{a}bahunna ghayra mutabarrij\q@u{a}tin bizeenatin waan yastaAAfifna khayrun lahunna wa\q@b{A}ll\q@u{a}hu sameeAAun AAaleem\q@b{un}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmdccclii{Laysa AAal\q@u{a} alaAAm\q@u{a} \q@u{h}arajun wal\q@u{a} AAal\q@u{a} alaAAraji \q@u{h}arajun wal\q@u{a} AAal\q@u{a} almaree\q@u{d}i \q@u{h}arajun wal\q@u{a} AAal\q@u{a} anfusikum an takuloo min buyootikum aw buyooti \q@u{a}b\q@u{a}ikum aw buyooti ommah\q@u{a}tikum aw buyooti ikhw\q@u{a}nikum aw buyooti akhaw\q@u{a}tikum aw buyooti aAAm\q@u{a}mikum aw buyooti AAamm\q@u{a}tikum aw buyooti akhw\q@u{a}likum aw buyooti kh\q@u{a}l\q@u{a}tikum aw m\q@u{a} malaktum maf\q@u{a}ti\q@u{h}ahu aw \q@u{s}adeeqikum laysa AAalaykum jun\q@u{ah}un an takuloo jameeAAan aw asht\q@u{a}tan fai\q@u{tha} dakhaltum buyootan fasallimoo AAal\q@u{a} anfusikum ta\q@u{h}iyyatan min AAindi All\q@u{a}hi mub\q@u{a}rakatan \q@u{t}ayyibatan ka\q@u{tha}lika yubayyinu All\q@u{a}hu lakumu al\q@u{a}y\q@u{a}ti laAAallakum taAAqiloon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmdcccliii{Innam\q@u{a} almuminoona alla\q@u{th}eena \q@u{a}manoo bi\q@b{A}ll\q@u{a}hi warasoolihi wai\q@u{tha} k\q@u{a}noo maAAahu AAal\q@u{a} amrin j\q@u{a}miAAin lam ya\q@u{th}haboo \q@u{h}att\q@u{a} yasta\q@u{th}inoohu inna alla\q@u{th}eena yasta\q@u{th}inoonaka ol\q@u{a}ika alla\q@u{th}eena yuminoona bi\q@b{A}ll\q@u{a}hi warasoolihi fai\q@u{tha} ista\q@u{th}anooka libaAA\q@u{d}i shanihim fa\q@u{th}an liman shita minhum wa\q@b{i}staghfir lahumu All\q@u{a}ha inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmdcccliv{L\q@u{a} tajAAaloo duAA\q@u{a}a a\q@b{l}rrasooli baynakum kaduAA\q@u{a}i baAA\q@u{d}ikum baAA\q@u{d}an qad yaAAlamu All\q@u{a}hu alla\q@u{th}eena yatasallaloona minkum liw\q@u{ath}an falya\q@u{hth}ari alla\q@u{th}eena yukh\q@u{a}lifoona AAan amrihi an tu\q@u{s}eebahum fitnatun aw yu\q@u{s}eebahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmdccclv{Al\q@u{a} inna lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i qad yaAAlamu m\q@u{a} antum AAalayhi wayawma yurjaAAoona ilayhi fayunabbiohum bim\q@u{a} AAamiloo wa\q@b{A}ll\q@u{a}hu bikulli shayin AAaleem\q@b{un}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmdccclvi{\basmalahlt Tab\q@u{a}raka alla\q@u{th}ee nazzala alfurq\q@u{a}na AAal\q@u{a} AAabdihi liyakoona lilAA\q@u{a}lameena na\q@u{th}eer\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmdccclvii{Alla\q@u{th}ee lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i walam yattakhi\q@u{th} waladan walam yakun lahu shareekun fee almulki wakhalaqa kulla shayin faqaddarahu taqdeer\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmdccclviii{Wa\q@b{i}ttakha\q@u{th}oo min doonihi \q@u{a}lihatan l\q@u{a} yakhluqoona shayan wahum yukhlaqoona wal\q@u{a} yamlikoona lianfusihim \q@u{d}arran wal\q@u{a} nafAAan wal\q@u{a} yamlikoona mawtan wal\q@u{a} \q@u{h}ay\q@u{a}tan wal\q@u{a} nushoor\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmdccclix{Waq\q@u{a}la alla\q@u{th}eena kafaroo in h\q@u{atha} ill\q@u{a} ifkun iftar\q@u{a}hu waaAA\q@u{a}nahu AAalayhi qawmun \q@u{a}kharoona faqad j\q@u{a}oo \q@i{\q@u{th}}ulman wazoor\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmdccclx{Waq\q@u{a}loo as\q@u{at}eeru alawwaleena iktatabah\q@u{a} fahiya tuml\q@u{a} AAalayhi bukratan waa\q@u{s}eel\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmdccclxi{Qul anzalahu alla\q@u{th}ee yaAAlamu a\q@b{l}ssirra fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i innahu k\q@u{a}na ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmdccclxii{Waq\q@u{a}loo m\q@u{a}li h\q@u{atha} a\q@b{l}rrasooli yakulu a\q@b{l}\q@u{tt}aAA\q@u{a}ma wayamshee fee alasw\q@u{a}qi lawl\q@u{a} onzila ilayhi malakun fayakoona maAAahu na\q@u{th}eer\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmdccclxiii{Aw yulq\q@u{a} ilayhi kanzun aw takoonu lahu jannatun yakulu minh\q@u{a} waq\q@u{a}la a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoona in tattabiAAoona ill\q@u{a} rajulan mas\q@u{h}oor\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmdccclxiv{On\q@i{\q@u{th}}ur kayfa \q@u{d}araboo laka alamth\q@u{a}la fa\q@u{d}alloo fal\q@u{a} yasta\q@u{t}eeAAoona sabeel\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmdccclxv{Tab\q@u{a}raka alla\q@u{th}ee in sh\q@u{a}a jaAAala laka khayran min \q@u{tha}lika jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru wayajAAal laka qu\q@u{s}oor\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmdccclxvi{Bal ka\q@u{thth}aboo bi\q@b{al}ss\q@u{a}AAati waaAAtadn\q@u{a} liman ka\q@u{thth}aba bi\q@b{al}ss\q@u{a}AAati saAAeer\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmdccclxvii{I\q@u{tha} raathum min mak\q@u{a}nin baAAeedin samiAAoo lah\q@u{a} taghayyu\q@i{\q@u{th}}an wazafeer\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmdccclxviii{Wai\q@u{tha} olqoo minh\q@u{a} mak\q@u{a}nan \q@u{d}ayyiqan muqarraneena daAAaw hun\q@u{a}lika thuboor\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmdccclxix{L\q@u{a} tadAAoo alyawma thubooran w\q@u{ah}idan wa\q@b{o}dAAoo thubooran katheer\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmdccclxx{Qul a\q@u{tha}lika khayrun am jannatu alkhuldi allatee wuAAida almuttaqoona k\q@u{a}nat lahum jaz\q@u{a}an wama\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmdccclxxi{Lahum feeh\q@u{a} m\q@u{a} yash\q@u{a}oona kh\q@u{a}lideena k\q@u{a}na AAal\q@u{a} rabbika waAAdan masool\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmdccclxxii{Wayawma ya\q@u{h}shuruhum wam\q@u{a} yaAAbudoona min dooni All\q@u{a}hi fayaqoolu aantum a\q@u{d}laltum AAib\q@u{a}dee h\q@u{a}ol\q@u{a}i am hum \q@u{d}alloo a\q@b{l}ssabeel\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmdccclxxiii{Q\q@u{a}loo sub\q@u{ha}naka m\q@u{a} k\q@u{a}na yanbaghee lan\q@u{a} an nattakhi\q@u{th}a min doonika min awliy\q@u{a}a wal\q@u{a}kin mattaAAtahum wa\q@u{a}b\q@u{a}ahum \q@u{h}att\q@u{a} nasoo a\q@b{l}\q@u{thth}ikra wak\q@u{a}noo qawman boor\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmdccclxxiv{Faqad ka\q@u{thth}abookum bim\q@u{a} taqooloona fam\q@u{a} tasta\q@u{t}eeAAoona \q@u{s}arfan wal\q@u{a} na\q@u{s}ran waman ya\q@i{\q@u{th}}lim minkum nu\q@u{th}iqhu AAa\q@u{tha}ban kabeer\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmdccclxxv{Wam\q@u{a} arsaln\q@u{a} qablaka mina almursaleena ill\q@u{a} innahum layakuloona a\q@b{l}\q@u{tt}aAA\q@u{a}ma wayamshoona fee alasw\q@u{a}qi wajaAAaln\q@u{a} baAA\q@u{d}akum libaAA\q@u{d}in fitnatan ata\q@u{s}biroona wak\q@u{a}na rabbuka ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmdccclxxvi{Waq\q@u{a}la alla\q@u{th}eena l\q@u{a} yarjoona liq\q@u{a}an\q@u{a} lawl\q@u{a} onzila AAalayn\q@u{a} almal\q@u{a}ikatu aw nar\q@u{a} rabban\q@u{a} laqadi istakbaroo fee anfusihim waAAataw AAutuwwan kabeer\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmdccclxxvii{Yawma yarawna almal\q@u{a}ikata l\q@u{a} bushr\q@u{a} yawmai\q@u{th}in lilmujrimeena wayaqooloona \q@u{h}ijran ma\q@u{h}joor\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmdccclxxviii{Waqadimn\q@u{a} il\q@u{a} m\q@u{a} AAamiloo min AAamalin fajaAAaln\q@u{a}hu hab\q@u{a}an manthoor\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmdccclxxix{A\q@u{s}\q@u{ha}bu aljannati yawmai\q@u{th}in khayrun mustaqarran waa\q@u{h}sanu maqeel\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmdccclxxx{Wayawma tashaqqaqu a\q@b{l}ssam\q@u{a}o bi\q@b{a}lgham\q@u{a}mi wanuzzila almal\q@u{a}ikatu tanzeel\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmdccclxxxi{Almulku yawmai\q@u{th}in al\q@u{h}aqqu li\q@b{l}rra\q@u{h}m\q@u{a}ni wak\q@u{a}na yawman AAal\q@u{a} alk\q@u{a}fireena AAaseer\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmdccclxxxii{Wayawma yaAAa\q@u{dd}u a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limu AAal\q@u{a} yadayhi yaqoolu y\q@u{a} laytanee ittakha\q@u{th}tu maAAa a\q@b{l}rrasooli sabeel\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmdccclxxxiii{Y\q@u{a} waylat\q@u{a} laytanee lam attakhi\q@u{th} ful\q@u{a}nan khaleel\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmdccclxxxiv{Laqad a\q@u{d}allanee AAani a\q@b{l}\q@u{thth}ikri baAAda i\q@u{th} j\q@u{a}anee wak\q@u{a}na a\q@b{l}shshay\q@u{ta}nu lilins\q@u{a}ni kha\q@u{th}ool\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmdccclxxxv{Waq\q@u{a}la a\q@b{l}rrasoolu y\q@u{a} rabbi inna qawmee ittakha\q@u{th}oo h\q@u{atha} alqur\q@u{a}na mahjoor\q@u{a}\q@b{n}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmdccclxxxvi{Waka\q@u{tha}lika jaAAaln\q@u{a} likulli nabiyyin AAaduwwan mina almujrimeena wakaf\q@u{a} birabbika h\q@u{a}diyan wana\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmdccclxxxvii{Waq\q@u{a}la alla\q@u{th}eena kafaroo lawl\q@u{a} nuzzila AAalayhi alqur\q@u{a}nu jumlatan w\q@u{ah}idatan ka\q@u{tha}lika linuthabbita bihi fu\q@u{a}daka warattaln\q@u{a}hu tarteel\q@u{a}\q@b{n}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmdccclxxxviii{Wal\q@u{a} yatoonaka bimathalin ill\q@u{a} jin\q@u{a}ka bi\q@b{a}l\q@u{h}aqqi waa\q@u{h}sana tafseer\q@u{a}\q@b{n}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmdccclxxxix{Alla\q@u{th}eena yu\q@u{h}sharoona AAal\q@u{a} wujoohihim il\q@u{a} jahannama ol\q@u{a}ika sharrun mak\q@u{a}nan waa\q@u{d}allu sabeel\q@u{a}\q@b{n}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmdcccxc{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba wajaAAaln\q@u{a} maAAahu akh\q@u{a}hu h\q@u{a}roona wazeer\q@u{a}\q@b{n}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmdcccxci{Faquln\q@u{a} i\q@u{th}hab\q@u{a} il\q@u{a} alqawmi alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} fadammarn\q@u{a}hum tadmeer\q@u{a}\q@b{n}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmdcccxcii{Waqawma noo\q@u{h}in lamm\q@u{a} ka\q@u{thth}aboo a\q@b{l}rrusula aghraqn\q@u{a}hum wajaAAaln\q@u{a}hum li\q@b{l}nn\q@u{a}si \q@u{a}yatan waaAAtadn\q@u{a} li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmdcccxciii{WaAA\q@u{a}dan wathamooda waa\q@u{s}\q@u{ha}ba a\q@b{l}rrassi waquroonan bayna \q@u{tha}lika katheer\q@u{a}\q@b{n}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmdcccxciv{Wakullan \q@u{d}arabn\q@u{a} lahu alamth\q@u{a}la wakullan tabbarn\q@u{a} tatbeer\q@u{a}\q@b{n}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmdcccxcv{Walaqad ataw AAal\q@u{a} alqaryati allatee om\q@u{t}irat ma\q@u{t}ara a\q@b{l}ssawi afalam yakoonoo yarawnah\q@u{a} bal k\q@u{a}noo l\q@u{a} yarjoona nushoor\q@u{a}\q@b{n}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmdcccxcvi{Wai\q@u{tha} raawka in yattakhi\q@u{th}oonaka ill\q@u{a} huzuwan ah\q@u{atha} alla\q@u{th}ee baAAatha All\q@u{a}hu rasool\q@u{a}\q@b{n}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmdcccxcvii{In k\q@u{a}da layu\q@u{d}illun\q@u{a} AAan \q@u{a}lihatin\q@u{a} lawl\q@u{a} an \q@u{s}abarn\q@u{a} AAalayh\q@u{a }wasawfa yaAAlamoona \q@u{h}eena yarawna alAAa\q@u{tha}ba man a\q@u{d}allu sabeel\q@u{a}\q@b{n}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmdcccxcviii{Araayta mani ittakha\q@u{th}a il\q@u{a}hahu haw\q@u{a}hu afaanta takoonu AAalayhi wakeel\q@u{a}\q@b{n}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmdcccxcix{Am ta\q@u{h}sabu anna aktharahum yasmaAAoona aw yaAAqiloona in hum ill\q@u{a} ka\q@b{a}lanAA\q@u{a}mi bal hum a\q@u{d}allu sabeel\q@u{a}\q@b{n}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmcm{Alam tara il\q@u{a} rabbika kayfa madda a\q@b{l}\q@i{\q@u{thth}}illa walaw sh\q@u{a}a lajaAAalahu s\q@u{a}kinan thumma jaAAaln\q@u{a} a\q@b{l}shshamsa AAalayhi daleel\q@u{a}\q@b{n}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmcmi{Thumma qaba\q@u{d}n\q@u{a}hu ilayn\q@u{a} qab\q@u{d}an yaseer\q@u{a}\q@b{n}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmcmii{Wahuwa alla\q@u{th}ee jaAAala lakumu allayla lib\q@u{a}san wa\q@b{al}nnawma sub\q@u{a}tan wajaAAala a\q@b{l}nnah\q@u{a}ra nushoor\q@u{a}\q@b{n}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmcmiii{Wahuwa alla\q@u{th}ee arsala a\q@b{l}rriy\q@u{ah}a bushran bayna yaday ra\q@u{h}matihi waanzaln\q@u{a} mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an \q@u{t}ahoor\q@u{a}\q@b{n}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmcmiv{Linu\q@u{h}yiya bihi baldatan maytan wanusqiyahu mimm\q@u{a} khalaqn\q@u{a} anAA\q@u{a}man waan\q@u{a}siyya katheer\q@u{a}\q@b{n}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmcmv{Walaqad \q@u{s}arrafn\q@u{a}hu baynahum liya\q@u{thth}akkaroo faab\q@u{a} aktharu a\q@b{l}nn\q@u{a}si ill\q@u{a} kufoor\q@u{a}\q@b{n}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmcmvi{Walaw shin\q@u{a} labaAAathn\q@u{a} fee kulli qaryatin na\q@u{th}eer\q@u{a}\q@b{n}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmcmvii{Fal\q@u{a} tu\q@u{t}iAAi alk\q@u{a}fireena waj\q@u{a}hidhum bihi jih\q@u{a}dan kabeer\q@u{a}\q@b{n}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmcmviii{Wahuwa alla\q@u{th}ee maraja alba\q@u{h}rayni h\q@u{atha} AAa\q@u{th}bun fur\q@u{a}tun wah\q@u{atha} mil\q@u{h}un oj\q@u{a}jun wajaAAala baynahum\q@u{a} barzakhan wa\q@u{h}ijran ma\q@u{h}joor\q@u{a}\q@b{n}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmcmix{Wahuwa alla\q@u{th}ee khalaqa mina alm\q@u{a}i basharan fajaAAalahu nasaban wa\q@u{s}ihran wak\q@u{a}na rabbuka qadeer\q@u{a}\q@b{n}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmcmx{WayaAAbudoona min dooni All\q@u{a}hi m\q@u{a} l\q@u{a} yanfaAAuhum wal\q@u{a} ya\q@u{d}urruhum wak\q@u{a}na alk\q@u{a}firu AAal\q@u{a} rabbihi \q@i{\q@u{th}}aheer\q@u{a}\q@b{n}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmcmxi{Wam\q@u{a} arsaln\q@u{a}ka ill\q@u{a} mubashshiran wana\q@u{th}eer\q@u{a}\q@b{n}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmcmxii{Qul m\q@u{a} asalukum AAalayhi min ajrin ill\q@u{a} man sh\q@u{a}a an yattakhi\q@u{th}a il\q@u{a} rabbihi sabeel\q@u{a}\q@b{n}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmcmxiii{Watawakkal AAal\q@u{a} al\q@u{h}ayyi alla\q@u{th}ee l\q@u{a} yamootu wasabbi\q@u{h} bi\q@u{h}amdihi wakaf\q@u{a} bihi bi\q@u{th}unoobi AAib\q@u{a}dihi khabeer\q@u{a}\q@b{n}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmcmxiv{Alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wam\q@u{a} baynahum\q@u{a} fee sittati ayy\q@u{a}min thumma istaw\q@u{a} AAal\q@u{a} alAAarshi a\q@b{l}rra\q@u{h}m\q@u{a}nu fa\q@b{i}sal bihi khabeer\q@u{a}\q@b{n}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmcmxv{Wai\q@u{tha} qeela lahumu osjudoo li\q@b{l}rra\q@u{h}m\q@u{a}ni q\q@u{a}loo wam\q@u{a} a\q@b{l}rra\q@u{h}m\q@u{a}nu anasjudu lim\q@u{a} tamurun\q@u{a} waz\q@u{a}dahum nufoor\q@u{a}\q@b{n}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmcmxvi{Tab\q@u{a}raka alla\q@u{th}ee jaAAala fee a\q@b{l}ssam\q@u{a}i buroojan wajaAAala feeh\q@u{a} sir\q@u{a}jan waqamaran muneer\q@u{a}\q@b{n}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmcmxvii{Wahuwa alla\q@u{th}ee jaAAala allayla wa\q@b{al}nnah\q@u{a}ra khilfatan liman ar\q@u{a}da an ya\q@u{thth}akkara aw ar\q@u{a}da shukoor\q@u{a}\q@b{n}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmcmxviii{WaAAib\q@u{a}du a\q@b{l}rra\q@u{h}m\q@u{a}ni alla\q@u{th}eena yamshoona AAal\q@u{a} alar\q@u{d}i hawnan wai\q@u{tha} kh\q@u{at}abahumu alj\q@u{a}hiloona q\q@u{a}loo sal\q@u{a}m\q@u{a}\q@b{n}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmcmxix{Wa\q@b{a}lla\q@u{th}eena yabeetoona lirabbihim sujjadan waqiy\q@u{a}m\q@u{a}\q@b{n}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmcmxx{Wa\q@b{a}lla\q@u{th}eena yaqooloona rabban\q@u{a} i\q@u{s}rif AAann\q@u{a} AAa\q@u{tha}ba jahannama inna AAa\q@u{tha}bah\q@u{a} k\q@u{a}na ghar\q@u{a}m\q@u{a}\q@b{n}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmcmxxi{Innah\q@u{a} s\q@u{a}at mustaqarran wamuq\q@u{a}m\q@u{a}\q@b{n}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmcmxxii{Wa\q@b{a}lla\q@u{th}eena i\q@u{tha} anfaqoo lam yusrifoo walam yaqturoo wak\q@u{a}na bayna \q@u{tha}lika qaw\q@u{a}m\q@u{a}\q@b{n}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmcmxxiii{Wa\q@b{a}lla\q@u{th}eena l\q@u{a} yadAAoona maAA\q@u{a} All\q@u{a}hi il\q@u{a}han \q@u{a}khara wal\q@u{a} yaqtuloona a\q@b{l}nnafsa allatee \q@u{h}arrama All\q@u{a}hu ill\q@u{a} bi\q@b{a}l\q@u{h}aqqi wal\q@u{a} yaznoona waman yafAAal \q@u{tha}lika yalqa ath\q@u{a}m\q@u{a}\q@b{n}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmcmxxiv{Yu\q@u{da}AAaf lahu alAAa\q@u{tha}bu yawma alqiy\q@u{a}mati wayakhlud feehi muh\q@u{a}n\q@u{a}\q@b{n}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmcmxxv{Ill\q@u{a} man t\q@u{a}ba wa\q@u{a}mana waAAamila AAamalan \q@u{sa}li\q@u{h}an faol\q@u{a}ika yubaddilu All\q@u{a}hu sayyi\q@u{a}tihim \q@u{h}asan\q@u{a}tin wak\q@u{a}na All\q@u{a}hu ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmcmxxvi{Waman t\q@u{a}ba waAAamila \q@u{sa}li\q@u{h}an fainnahu yatoobu il\q@u{a} All\q@u{a}hi mat\q@u{a}b\q@u{a}\q@b{n}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmcmxxvii{Wa\q@b{a}lla\q@u{th}eena l\q@u{a} yashhadoona a\q@b{l}zzoora wai\q@u{tha} marroo bi\q@b{a}llaghwi marroo kir\q@u{a}m\q@u{a}\q@b{n}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmcmxxviii{Wa\q@b{a}lla\q@u{th}eena i\q@u{tha} \q@u{th}ukkiroo bi\q@u{a}y\q@u{a}ti rabbihim lam yakhirroo AAalayh\q@u{a} \q@u{s}umman waAAumy\q@u{a}n\q@u{a}\q@b{n}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmcmxxix{Wa\q@b{a}lla\q@u{th}eena yaqooloona rabban\q@u{a} hab lan\q@u{a} min azw\q@u{a}jin\q@u{a} wa\q@u{th}urriyy\q@u{a}tin\q@u{a} qurrata aAAyunin wa\q@b{i}jAAaln\q@u{a} lilmuttaqeena im\q@u{a}m\q@u{a}\q@b{n}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmcmxxx{Ol\q@u{a}ika yujzawna alghurfata bim\q@u{a} \q@u{s}abaroo wayulaqqawna feeh\q@u{a} ta\q@u{h}iyyatan wasal\q@u{a}m\q@u{a}\q@b{n}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmcmxxxi{Kh\q@u{a}lideena feeh\q@u{a} \q@u{h}asunat mustaqarran wamuq\q@u{a}m\q@u{a}\q@b{n}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmcmxxxii{Qul m\q@u{a} yaAAbao bikum rabbee lawl\q@u{a} duAA\q@u{a}okum faqad ka\q@u{thth}abtum fasawfa yakoonu liz\q@u{a}m\q@u{a}\q@b{n}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmcmxxxiii{\basmalahlt \q@u{Ta}seenmeem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmcmxxxiv{Tilka \q@u{a}y\q@u{a}tu alkit\q@u{a}bi almubeen\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmcmxxxv{LaAAallaka b\q@u{a}khiAAun nafsaka all\q@u{a} yakoonoo mumineen\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmcmxxxvi{In nasha nunazzil AAalayhim mina a\q@b{l}ssam\q@u{a}i \q@u{a}yatan fa\q@i{\q@u{th}}allat aAAn\q@u{a}quhum lah\q@u{a} kh\q@u{ad}iAAeen\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmcmxxxvii{Wam\q@u{a} yateehim min \q@u{th}ikrin mina a\q@b{l}rra\q@u{h}m\q@u{a}ni mu\q@u{h}dathin ill\q@u{a} k\q@u{a}noo AAanhu muAAri\q@u{d}een\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmcmxxxviii{Faqad ka\q@u{thth}aboo fasayateehim anb\q@u{a}o m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmcmxxxix{Awalam yaraw il\q@u{a} alar\q@u{d}i kam anbatn\q@u{a} feeh\q@u{a} min kulli zawjin kareem\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmcmxl{Inna fee \q@u{tha}lika la\q@u{a}yatan wam\q@u{a} k\q@u{a}na aktharuhum mumineen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmcmxli{Wainna rabbaka lahuwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmcmxlii{Wai\q@u{th} n\q@u{a}d\q@u{a} rabbuka moos\q@u{a} ani iti alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmcmxliii{Qawma firAAawna al\q@u{a} yattaqoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmcmxliv{Q\q@u{a}la rabbi innee akh\q@u{a}fu an yuka\q@u{thth}iboon\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmcmxlv{Waya\q@u{d}eequ \q@u{s}adree wal\q@u{a} yan\q@u{t}aliqu lis\q@u{a}nee faarsil il\q@u{a} h\q@u{a}roon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmcmxlvi{Walahum AAalayya \q@u{th}anbun faakh\q@u{a}fu an yaqtuloon\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmcmxlvii{Q\q@u{a}la kall\q@u{a} fa\q@b{i}\q@u{th}hab\q@u{a} bi\q@u{a}y\q@u{a}tin\q@u{a} inn\q@u{a} maAAakum mustamiAAoon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmcmxlviii{Fatiy\q@u{a} firAAawna faqool\q@u{a} inn\q@u{a} rasoolu rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmcmxlix{An arsil maAAan\q@u{a} banee isr\q@u{a}eel\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmcml{Q\q@u{a}la alam nurabbika feen\q@u{a} waleedan walabithta feen\q@u{a} min AAumurika sineen\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmcmli{WafaAAalta faAAlataka allatee faAAalta waanta mina alk\q@u{a}fireen\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmcmlii{Q\q@u{a}la faAAaltuh\q@u{a} i\q@u{th}an waan\q@u{a} mina a\q@b{l}\q@u{dda}lleen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmcmliii{Fafarartu minkum lamm\q@u{a} khiftukum fawahaba lee rabbee \q@u{h}ukman wajaAAalanee mina almursaleen\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmcmliv{Watilka niAAmatun tamunnuh\q@u{a} AAalayya an AAabbadta banee isr\q@u{a}eel\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmcmlv{Q\q@u{a}la firAAawnu wam\q@u{a} rabbu alAA\q@u{a}lameen\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmcmlvi{Q\q@u{a}la rabbu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} in kuntum mooqineen\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmcmlvii{Q\q@u{a}la liman \q@u{h}awlahu al\q@u{a} tastamiAAoon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmcmlviii{Q\q@u{a}la rabbukum warabbu \q@u{a}b\q@u{a}ikumu alawwaleen\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmcmlix{Q\q@u{a}la inna rasoolakumu alla\q@u{th}ee orsila ilaykum lamajnoon\q@b{un}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmcmlx{Q\q@u{a}la rabbu almashriqi wa\q@b{a}lmaghribi wam\q@u{a} baynahum\q@u{a} in kuntum taAAqiloon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmcmlxi{Q\q@u{a}la laini ittakha\q@u{th}ta il\q@u{a}han ghayree laajAAalannaka mina almasjooneen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmcmlxii{Q\q@u{a}la awalaw jituka bishayin mubeen\q@b{in}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmcmlxiii{Q\q@u{a}la fati bihi in kunta mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmcmlxiv{Faalq\q@u{a} AAa\q@u{sa}hu fai\q@u{tha} hiya thuAAb\q@u{a}nun mubeen\q@b{un}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmcmlxv{WanazaAAa yadahu fai\q@u{tha} hiya bay\q@u{da}o li\q@b{l}nn\q@u{a}\q@i{\q@u{th}}ireen\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmcmlxvi{Q\q@u{a}la lilmalai \q@u{h}awlahu inna h\q@u{atha} las\q@u{ah}irun AAaleem\q@b{un}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmcmlxvii{Yureedu an yukhrijakum min ar\q@u{d}ikum bisi\q@u{h}rihi fam\q@u{atha} tamuroon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmcmlxviii{Q\q@u{a}loo arjih waakh\q@u{a}hu wa\q@b{i}bAAath fee almad\q@u{a}ini \q@u{ha}shireen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmcmlxix{Yatooka bikulli sa\q@u{hha}rin AAaleem\q@b{in}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmcmlxx{FajumiAAa a\q@b{l}ssa\q@u{h}aratu limeeq\q@u{a}ti yawmin maAAloom\q@b{in}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmcmlxxi{Waqeela li\q@b{l}nn\q@u{a}si hal antum mujtamiAAoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmcmlxxii{LaAAallan\q@u{a} nattabiAAu a\q@b{l}ssa\q@u{h}arata in k\q@u{a}noo humu algh\q@u{a}libeen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmcmlxxiii{Falamm\q@u{a} j\q@u{a}a a\q@b{l}ssa\q@u{h}aratu q\q@u{a}loo lifirAAawna ainna lan\q@u{a} laajran in kunn\q@u{a} na\q@u{h}nu algh\q@u{a}libeen\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmcmlxxiv{Q\q@u{a}la naAAam wainnakum i\q@u{th}an lamina almuqarrabeen\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmcmlxxv{Q\q@u{a}la lahum moos\q@u{a} alqoo m\q@u{a} antum mulqoon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmcmlxxvi{Faalqaw \q@u{h}ib\q@u{a}lahum waAAi\q@u{s}iyyahum waq\q@u{a}loo biAAizzati firAAawna inn\q@u{a} lana\q@u{h}nu algh\q@u{a}liboon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmcmlxxvii{Faalq\q@u{a} moos\q@u{a} AAa\q@u{sa}hu fai\q@u{tha} hiya talqafu m\q@u{a} yafikoon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmcmlxxviii{Faolqiya a\q@b{l}ssa\q@u{h}aratu s\q@u{a}jideen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmcmlxxix{Q\q@u{a}loo \q@u{a}mann\q@u{a} birabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmcmlxxx{Rabbi moos\q@u{a} wah\q@u{a}roon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmcmlxxxi{Q\q@u{a}la \q@u{a}mantum lahu qabla an \q@u{ath}ana lakum innahu lakabeerukumu alla\q@u{th}ee AAallamakumu a\q@b{l}ssi\q@u{h}ra falasawfa taAAlamoona laoqa\q@u{tt}iAAanna aydiyakum waarjulakum min khil\q@u{a}fin walao\q@u{s}allibannakum ajmaAAeen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmcmlxxxii{Q\q@u{a}loo l\q@u{a} \q@u{d}ayra inn\q@u{a} il\q@u{a} rabbin\q@u{a} munqaliboon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmcmlxxxiii{Inn\q@u{a} na\q@u{t}maAAu an yaghfira lan\q@u{a} rabbun\q@u{a} kha\q@u{ta}y\q@u{a}n\q@u{a} an kunn\q@u{a} awwala almumineen\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmcmlxxxiv{Waaw\q@u{h}ayn\q@u{a} il\q@u{a} moos\q@u{a} an asri biAAib\q@u{a}dee innakum muttabaAAoon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmcmlxxxv{Faarsala firAAawnu fee almad\q@u{a}ini \q@u{ha}shireen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmcmlxxxvi{Inna h\q@u{a}ol\q@u{a}i lashir\q@u{th}imatun qaleeloon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmcmlxxxvii{Wainnahum lan\q@u{a} lagh\q@u{a}i\q@i{\q@u{th}}oon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmcmlxxxviii{Wainn\q@u{a} lajameeAAun \q@u{hath}iroon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmcmlxxxix{Faakhrajn\q@u{a}hum min jann\q@u{a}tin waAAuyoon\q@b{in}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmcmxc{Wakunoozin wamaq\q@u{a}min kareem\q@b{in}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmcmxci{Ka\q@u{tha}lika waawrathn\q@u{a}h\q@u{a} banee isr\q@u{a}eel\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmcmxcii{FaatbaAAoohum mushriqeen\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmcmxciii{Falamm\q@u{a} tar\q@u{a}a aljamAA\q@u{a}ni q\q@u{a}la a\q@u{s}\q@u{ha}bu moos\q@u{a} inn\q@u{a} lamudrakoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmcmxciv{Q\q@u{a}la kall\q@u{a} inna maAAiya rabbee sayahdeen\q@b{i}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmcmxcv{Faaw\q@u{h}ayn\q@u{a} il\q@u{a} moos\q@u{a} ani i\q@u{d}rib biAAa\q@u{sa}ka alba\q@u{h}ra fa\q@b{i}nfalaqa fak\q@u{a}na kullu firqin ka\q@b{al}\q@u{tt}awdi alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmcmxcvi{Waazlafn\q@u{a} thamma al\q@u{a}khareen\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmcmxcvii{Waanjayn\q@u{a} moos\q@u{a} waman maAAahu ajmaAAeen\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmcmxcviii{Thumma aghraqn\q@u{a} al\q@u{a}khareen\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmcmxcix{Inna fee \q@u{tha}lika la\q@u{a}yatan wam\q@u{a} k\q@u{a}na aktharuhum mumineen\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmm{Wainna rabbaka lahuwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmi{Wa\q@b{o}tlu AAalayhim nabaa ibr\q@u{a}heem\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmii{I\q@u{th} q\q@u{a}la liabeehi waqawmihi m\q@u{a} taAAbudoon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmiii{Q\q@u{a}loo naAAbudu a\q@u{s}n\q@u{a}man fana\q@i{\q@u{th}}allu lah\q@u{a} AA\q@u{a}kifeen\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmiv{Q\q@u{a}la hal yasmaAAoonakum i\q@u{th} tadAAoon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmv{Aw yanfaAAoonakum aw ya\q@u{d}urroon\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmvi{Q\q@u{a}loo bal wajadn\q@u{a} \q@u{a}b\q@u{a}an\q@u{a} ka\q@u{tha}lika yafAAaloon\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmvii{Q\q@u{a}la afaraaytum m\q@u{a} kuntum taAAbudoon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmviii{Antum wa\q@u{a}b\q@u{a}okumu alaqdamoon\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmix{Fainnahum AAaduwwun lee ill\q@u{a} rabba alAA\q@u{a}lameen\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmx{Alla\q@u{th}ee khalaqanee fahuwa yahdeen\q@b{i}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmxi{Wa\q@b{a}lla\q@u{th}ee huwa yu\q@u{t}AAimunee wayasqeen\q@b{i}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmmxii{Wai\q@u{tha} mari\q@u{d}tu fahuwa yashfeen\q@b{i}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmmxiii{Wa\q@b{a}lla\q@u{th}ee yumeetunee thumma yu\q@u{h}yeen\q@b{i}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmmxiv{Wa\q@b{a}lla\q@u{th}ee a\q@u{t}maAAu an yaghfira lee kha\q@u{t}eeatee yawma a\q@b{l}ddeen\q@b{i}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmmxv{Rabbi hab lee \q@u{h}ukman waal\q@u{h}iqnee bi\q@b{al}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmmxvi{Wa\q@b{i}jAAal lee lis\q@u{a}na \q@u{s}idqin fee al\q@u{a}khireen\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmmxvii{Wa\q@b{i}jAAalnee min warathati jannati a\q@b{l}nnaAAeem\q@b{i}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmmxviii{Wa\q@b{i}ghfir liabee innahu k\q@u{a}na mina a\q@b{l}\q@u{dda}lleen\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmmxix{Wal\q@u{a} tukhzinee yawma yubAAathoon\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmmxx{Yawma l\q@u{a} yanfaAAu m\q@u{a}lun wal\q@u{a} banoon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmmxxi{Ill\q@u{a} man at\q@u{a} All\q@u{a}ha biqalbin saleem\q@b{in}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmmxxii{Waozlifati aljannatu lilmuttaqeen\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmmxxiii{Waburrizati alja\q@u{h}eemu lilgh\q@u{a}ween\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmmxxiv{Waqeela lahum ayna m\q@u{a} kuntum taAAbudoon\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmmxxv{Min dooni All\q@u{a}hi hal yan\q@u{s}uroonakum aw yanta\q@u{s}iroon\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmmxxvi{Fakubkiboo feeh\q@u{a} hum wa\q@b{a}lgh\q@u{a}woon\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mmmxxvii{Wajunoodu ibleesa ajmaAAoon\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mmmxxviii{Q\q@u{a}loo wahum feeh\q@u{a} yakhta\q@u{s}imoon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mmmxxix{Ta\q@b{A}ll\q@u{a}hi in kunn\q@u{a} lafee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mmmxxx{I\q@u{th} nusawweekum birabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mmmxxxi{Wam\q@u{a} a\q@u{d}allan\q@u{a} ill\q@u{a} almujrimoon\q@b{a}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mmmxxxii{Fam\q@u{a} lan\q@u{a} min sh\q@u{a}fiAAeen\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mmmxxxiii{Wal\q@u{a} \q@u{s}adeeqin \q@u{h}ameem\q@b{in}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mmmxxxiv{Falaw anna lan\q@u{a} karratan fanakoona mina almumineen\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mmmxxxv{Inna fee \q@u{tha}lika la\q@u{a}yatan wam\q@u{a} k\q@u{a}na aktharuhum mumineen\q@b{a}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mmmxxxvi{Wainna rabbaka lahuwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mmmxxxvii{Ka\q@u{thth}abat qawmu noo\q@u{h}in almursaleen\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mmmxxxviii{I\q@u{th} q\q@u{a}la lahum akhoohum noo\q@u{h}un al\q@u{a} tattaqoon\q@b{a}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mmmxxxix{Innee lakum rasoolun ameen\q@b{un}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mmmxl{Fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mmmxli{Wam\q@u{a} asalukum AAalayhi min ajrin in ajriya ill\q@u{a} AAal\q@u{a} rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mmmxlii{Fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mmmxliii{Q\q@u{a}loo anuminu laka wa\q@b{i}ttabaAAaka alar\q@u{th}aloon\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mmmxliv{Q\q@u{a}la wam\q@u{a} AAilmee bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@mmmxlv{In \q@u{h}is\q@u{a}buhum ill\q@u{a} AAal\q@u{a} rabbee law tashAAuroon\q@b{a}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@mmmxlvi{Wam\q@u{a} an\q@u{a} bi\q@u{ta}ridi almumineen\q@b{a}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@mmmxlvii{In an\q@u{a} ill\q@u{a} na\q@u{th}eerun mubeen\q@b{un}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@mmmxlviii{Q\q@u{a}loo lain lam tantahi y\q@u{a} noo\q@u{h}u latakoonanna mina almarjoomeen\q@b{a}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@mmmxlix{Q\q@u{a}la rabbi inna qawmee ka\q@u{thth}aboon\q@b{i}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@mmml{Fa\q@b{i}fta\q@u{h} baynee wabaynahum fat\q@u{h}an wanajjinee waman maAAiya mina almumineen\q@b{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@mmmli{Faanjayn\q@u{a}hu waman maAAahu fee alfulki almashhoon\q@b{i}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@mmmlii{Thumma aghraqn\q@u{a} baAAdu alb\q@u{a}qeen\q@b{a}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@mmmliii{Inna fee \q@u{tha}lika la\q@u{a}yatan wam\q@u{a} k\q@u{a}na aktharuhum mumineen\q@b{a}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@mmmliv{Wainna rabbaka lahuwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@mmmlv{Ka\q@u{thth}abat AA\q@u{a}dun almursaleen\q@b{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@mmmlvi{I\q@u{th} q\q@u{a}la lahum akhoohum hoodun al\q@u{a} tattaqoon\q@b{a}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@mmmlvii{Innee lakum rasoolun ameen\q@b{un}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@mmmlviii{Fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@mmmlix{Wam\q@u{a} asalukum AAalayhi min ajrin in ajriya ill\q@u{a} AAal\q@u{a} rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@mmmlx{Atabnoona bikulli reeAAin \q@u{a}yatan taAAbathoon\q@b{a}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@mmmlxi{Watattakhi\q@u{th}oona ma\q@u{sa}niAAa laAAallakum takhludoon\q@b{a}\qt@no{(129)}}
\qt@newcmd\qurantrans@lt@mmmlxii{Wai\q@u{tha} ba\q@u{t}ashtum ba\q@u{t}ashtum jabb\q@u{a}reen\q@b{a}\qt@no{(130)}}
\qt@newcmd\qurantrans@lt@mmmlxiii{Fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(131)}}
\qt@newcmd\qurantrans@lt@mmmlxiv{Wa\q@b{i}ttaqoo alla\q@u{th}ee amaddakum bim\q@u{a} taAAlamoon\q@b{a}\qt@no{(132)}}
\qt@newcmd\qurantrans@lt@mmmlxv{Amaddakum bianAA\q@u{a}min wabaneen\q@b{a}\qt@no{(133)}}
\qt@newcmd\qurantrans@lt@mmmlxvi{Wajann\q@u{a}tin waAAuyoon\q@b{in}\qt@no{(134)}}
\qt@newcmd\qurantrans@lt@mmmlxvii{Innee akh\q@u{a}fu AAalaykum AAa\q@u{tha}ba yawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(135)}}
\qt@newcmd\qurantrans@lt@mmmlxviii{Q\q@u{a}loo saw\q@u{a}on AAalayn\q@u{a} awaAAa\q@i{\q@u{th}}ta am lam takun mina alw\q@u{a}AAi\q@i{\q@u{th}}een\q@b{a}\qt@no{(136)}}
\qt@newcmd\qurantrans@lt@mmmlxix{In h\q@u{atha} ill\q@u{a} khuluqu alawwaleen\q@b{a}\qt@no{(137)}}
\qt@newcmd\qurantrans@lt@mmmlxx{Wam\q@u{a} na\q@u{h}nu bimuAAa\q@u{thth}abeen\q@b{a}\qt@no{(138)}}
\qt@newcmd\qurantrans@lt@mmmlxxi{Faka\q@u{thth}aboohu faahlakn\q@u{a}hum inna fee \q@u{tha}lika la\q@u{a}yatan wam\q@u{a} k\q@u{a}na aktharuhum mumineen\q@b{a}\qt@no{(139)}}
\qt@newcmd\qurantrans@lt@mmmlxxii{Wainna rabbaka lahuwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(140)}}
\qt@newcmd\qurantrans@lt@mmmlxxiii{Ka\q@u{thth}abat thamoodu almursaleen\q@b{a}\qt@no{(141)}}
\qt@newcmd\qurantrans@lt@mmmlxxiv{I\q@u{th} q\q@u{a}la lahum akhoohum \q@u{sa}li\q@u{h}un al\q@u{a} tattaqoon\q@b{a}\qt@no{(142)}}
\qt@newcmd\qurantrans@lt@mmmlxxv{Innee lakum rasoolun ameen\q@b{un}\qt@no{(143)}}
\qt@newcmd\qurantrans@lt@mmmlxxvi{Fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(144)}}
\qt@newcmd\qurantrans@lt@mmmlxxvii{Wam\q@u{a} asalukum AAalayhi min ajrin in ajriya ill\q@u{a} AAal\q@u{a} rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(145)}}
\qt@newcmd\qurantrans@lt@mmmlxxviii{Atutrakoona fee m\q@u{a} h\q@u{a}hun\q@u{a} \q@u{a}mineen\q@b{a}\qt@no{(146)}}
\qt@newcmd\qurantrans@lt@mmmlxxix{Fee jann\q@u{a}tin waAAuyoon\q@b{in}\qt@no{(147)}}
\qt@newcmd\qurantrans@lt@mmmlxxx{WazurooAAin wanakhlin \q@u{t}alAAuh\q@u{a} ha\q@u{d}eem\q@b{un}\qt@no{(148)}}
\qt@newcmd\qurantrans@lt@mmmlxxxi{Watan\q@u{h}itoona mina aljib\q@u{a}li buyootan f\q@u{a}riheen\q@b{a}\qt@no{(149)}}
\qt@newcmd\qurantrans@lt@mmmlxxxii{Fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(150)}}
\qt@newcmd\qurantrans@lt@mmmlxxxiii{Wal\q@u{a} tu\q@u{t}eeAAoo amra almusrifeen\q@b{a}\qt@no{(151)}}
\qt@newcmd\qurantrans@lt@mmmlxxxiv{Alla\q@u{th}eena yufsidoona fee alar\q@u{d}i wal\q@u{a} yu\q@u{s}li\q@u{h}oon\q@b{a}\qt@no{(152)}}
\qt@newcmd\qurantrans@lt@mmmlxxxv{Q\q@u{a}loo innam\q@u{a} anta mina almusa\q@u{hh}areen\q@b{a}\qt@no{(153)}}
\qt@newcmd\qurantrans@lt@mmmlxxxvi{M\q@u{a} anta ill\q@u{a} basharun mithlun\q@u{a} fati bi\q@u{a}yatin in kunta mina a\q@b{l}\q@u{ssa}diqeena\qt@no{(154)}}
\qt@newcmd\qurantrans@lt@mmmlxxxvii{Q\q@u{a}la h\q@u{ath}ihi n\q@u{a}qatun lah\q@u{a} shirbun walakum shirbu yawmin maAAloom\q@b{in}\qt@no{(155)}}
\qt@newcmd\qurantrans@lt@mmmlxxxviii{Wal\q@u{a} tamassooh\q@u{a} bisooin fayakhu\q@u{th}akum AAa\q@u{tha}bu yawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(156)}}
\qt@newcmd\qurantrans@lt@mmmlxxxix{FaAAaqarooh\q@u{a} faa\q@u{s}ba\q@u{h}oo n\q@u{a}dimeen\q@b{a}\qt@no{(157)}}
\qt@newcmd\qurantrans@lt@mmmxc{Faakha\q@u{th}ahumu alAAa\q@u{tha}bu inna fee \q@u{tha}lika la\q@u{a}yatan wam\q@u{a} k\q@u{a}na aktharuhum mumineen\q@b{a}\qt@no{(158)}}
\qt@newcmd\qurantrans@lt@mmmxci{Wainna rabbaka lahuwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(159)}}
\qt@newcmd\qurantrans@lt@mmmxcii{Ka\q@u{thth}abat qawmu loo\q@u{t}in almursaleen\q@b{a}\qt@no{(160)}}
\qt@newcmd\qurantrans@lt@mmmxciii{I\q@u{th} q\q@u{a}la lahum akhoohum loo\q@u{t}un al\q@u{a} tattaqoon\q@b{a}\qt@no{(161)}}
\qt@newcmd\qurantrans@lt@mmmxciv{Innee lakum rasoolun ameen\q@b{un}\qt@no{(162)}}
\qt@newcmd\qurantrans@lt@mmmxcv{Fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(163)}}
\qt@newcmd\qurantrans@lt@mmmxcvi{Wam\q@u{a} asalukum AAalayhi min ajrin in ajriya ill\q@u{a} AAal\q@u{a} rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(164)}}
\qt@newcmd\qurantrans@lt@mmmxcvii{Atatoona a\q@b{l}\q@u{thth}ukr\q@u{a}na mina alAA\q@u{a}lameen\q@b{a}\qt@no{(165)}}
\qt@newcmd\qurantrans@lt@mmmxcviii{Wata\q@u{th}aroona m\q@u{a} khalaqa lakum rabbukum min azw\q@u{a}jikum bal antum qawmun AA\q@u{a}doon\q@b{a}\qt@no{(166)}}
\qt@newcmd\qurantrans@lt@mmmxcix{Q\q@u{a}loo lain lam tantahi y\q@u{a} loo\q@u{t}u latakoonanna mina almukhrajeen\q@b{a}\qt@no{(167)}}
\qt@newcmd\qurantrans@lt@mmmc{Q\q@u{a}la innee liAAamalikum mina alq\q@u{a}leen\q@b{a}\qt@no{(168)}}
\qt@newcmd\qurantrans@lt@mmmci{Rabbi najjinee waahlee mimm\q@u{a} yaAAmaloon\q@b{a}\qt@no{(169)}}
\qt@newcmd\qurantrans@lt@mmmcii{Fanajjayn\q@u{a}hu waahlahu ajmaAAeen\q@b{a}\qt@no{(170)}}
\qt@newcmd\qurantrans@lt@mmmciii{Ill\q@u{a} AAajoozan fee algh\q@u{a}bireen\q@b{a}\qt@no{(171)}}
\qt@newcmd\qurantrans@lt@mmmciv{Thumma dammarn\q@u{a} al\q@u{a}khareen\q@b{a}\qt@no{(172)}}
\qt@newcmd\qurantrans@lt@mmmcv{Waam\q@u{t}arn\q@u{a} AAalayhim ma\q@u{t}aran fas\q@u{a}a ma\q@u{t}aru almun\q@u{th}areen\q@b{a}\qt@no{(173)}}
\qt@newcmd\qurantrans@lt@mmmcvi{Inna fee \q@u{tha}lika la\q@u{a}yatan wam\q@u{a} k\q@u{a}na aktharuhum mumineen\q@b{a}\qt@no{(174)}}
\qt@newcmd\qurantrans@lt@mmmcvii{Wainna rabbaka lahuwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(175)}}
\qt@newcmd\qurantrans@lt@mmmcviii{Ka\q@u{thth}aba a\q@u{s}\q@u{ha}bu alaykati almursaleen\q@b{a}\qt@no{(176)}}
\qt@newcmd\qurantrans@lt@mmmcix{I\q@u{th} q\q@u{a}la lahum shuAAaybun al\q@u{a} tattaqoon\q@b{a}\qt@no{(177)}}
\qt@newcmd\qurantrans@lt@mmmcx{Innee lakum rasoolun ameen\q@b{un}\qt@no{(178)}}
\qt@newcmd\qurantrans@lt@mmmcxi{Fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(179)}}
\qt@newcmd\qurantrans@lt@mmmcxii{Wam\q@u{a} asalukum AAalayhi min ajrin in ajriya ill\q@u{a} AAal\q@u{a} rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(180)}}
\qt@newcmd\qurantrans@lt@mmmcxiii{Awfoo alkayla wal\q@u{a} takoonoo mina almukhsireen\q@b{a}\qt@no{(181)}}
\qt@newcmd\qurantrans@lt@mmmcxiv{Wazinoo bi\q@b{a}lqis\q@u{ta}si almustaqeem\q@b{i}\qt@no{(182)}}
\qt@newcmd\qurantrans@lt@mmmcxv{Wal\q@u{a} tabkhasoo a\q@b{l}nn\q@u{a}sa ashy\q@u{a}ahum wal\q@u{a} taAAthaw fee alar\q@u{d}i mufsideen\q@b{a}\qt@no{(183)}}
\qt@newcmd\qurantrans@lt@mmmcxvi{Wa\q@b{i}ttaqoo alla\q@u{th}ee khalaqakum wa\q@b{a}ljibillata alawwaleen\q@b{a}\qt@no{(184)}}
\qt@newcmd\qurantrans@lt@mmmcxvii{Q\q@u{a}loo innam\q@u{a} anta mina almusa\q@u{hh}areen\q@b{a}\qt@no{(185)}}
\qt@newcmd\qurantrans@lt@mmmcxviii{Wam\q@u{a} anta ill\q@u{a} basharun mithlun\q@u{a} wain na\q@i{\q@u{th}}unnuka lamina alk\q@u{ath}ibeen\q@b{a}\qt@no{(186)}}
\qt@newcmd\qurantrans@lt@mmmcxix{Faasqi\q@u{t} AAalayn\q@u{a} kisafan mina a\q@b{l}ssam\q@u{a}i in kunta mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(187)}}
\qt@newcmd\qurantrans@lt@mmmcxx{Q\q@u{a}la rabbee aAAlamu bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(188)}}
\qt@newcmd\qurantrans@lt@mmmcxxi{Faka\q@u{thth}aboohu faakha\q@u{th}ahum AAa\q@u{tha}bu yawmi a\q@b{l}\q@i{\q@u{thth}}ullati innahu k\q@u{a}na AAa\q@u{tha}ba yawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(189)}}
\qt@newcmd\qurantrans@lt@mmmcxxii{Inna fee \q@u{tha}lika la\q@u{a}yatan wam\q@u{a} k\q@u{a}na aktharuhum mumineen\q@b{a}\qt@no{(190)}}
\qt@newcmd\qurantrans@lt@mmmcxxiii{Wainna rabbaka lahuwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(191)}}
\qt@newcmd\qurantrans@lt@mmmcxxiv{Wainnahu latanzeelu rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(192)}}
\qt@newcmd\qurantrans@lt@mmmcxxv{Nazala bihi a\q@b{l}rroo\q@u{h}u alameen\q@b{u}\qt@no{(193)}}
\qt@newcmd\qurantrans@lt@mmmcxxvi{AAal\q@u{a} qalbika litakoona mina almun\q@u{th}ireen\q@b{a}\qt@no{(194)}}
\qt@newcmd\qurantrans@lt@mmmcxxvii{Bilis\q@u{a}nin AAarabiyyin mubeen\q@b{in}\qt@no{(195)}}
\qt@newcmd\qurantrans@lt@mmmcxxviii{Wainnahu lafee zuburi alawwaleen\q@b{a}\qt@no{(196)}}
\qt@newcmd\qurantrans@lt@mmmcxxix{Awalam yakun lahum \q@u{a}yatan an yaAAlamahu AAulam\q@u{a}o banee isr\q@u{a}eel\q@b{a}\qt@no{(197)}}
\qt@newcmd\qurantrans@lt@mmmcxxx{Walaw nazzaln\q@u{a}hu AAal\q@u{a} baAA\q@u{d}i alaAAjameen\q@b{a}\qt@no{(198)}}
\qt@newcmd\qurantrans@lt@mmmcxxxi{Faqaraahu AAalayhim m\q@u{a} k\q@u{a}noo bihi mumineen\q@b{a}\qt@no{(199)}}
\qt@newcmd\qurantrans@lt@mmmcxxxii{Ka\q@u{tha}lika salakn\q@u{a}hu fee quloobi almujrimeen\q@b{a}\qt@no{(200)}}
\qt@newcmd\qurantrans@lt@mmmcxxxiii{L\q@u{a} yuminoona bihi \q@u{h}att\q@u{a} yarawoo alAAa\q@u{tha}ba alaleem\q@b{a}\qt@no{(201)}}
\qt@newcmd\qurantrans@lt@mmmcxxxiv{Fayatiyahum baghtatan wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(202)}}
\qt@newcmd\qurantrans@lt@mmmcxxxv{Fayaqooloo hal na\q@u{h}nu mun\q@i{\q@u{th}}aroon\q@b{a}\qt@no{(203)}}
\qt@newcmd\qurantrans@lt@mmmcxxxvi{AfabiAAa\q@u{tha}bin\q@u{a} yastaAAjiloon\q@b{a}\qt@no{(204)}}
\qt@newcmd\qurantrans@lt@mmmcxxxvii{Afaraayta in mattaAAn\q@u{a}hum sineen\q@b{a}\qt@no{(205)}}
\qt@newcmd\qurantrans@lt@mmmcxxxviii{Thumma j\q@u{a}ahum m\q@u{a} k\q@u{a}noo yooAAadoon\q@b{a}\qt@no{(206)}}
\qt@newcmd\qurantrans@lt@mmmcxxxix{M\q@u{a} aghn\q@u{a} AAanhum m\q@u{a} k\q@u{a}noo yumattaAAoon\q@b{a}\qt@no{(207)}}
\qt@newcmd\qurantrans@lt@mmmcxl{Wam\q@u{a} ahlakn\q@u{a} min qaryatin ill\q@u{a} lah\q@u{a} mun\q@u{th}iroon\q@b{a}\qt@no{(208)}}
\qt@newcmd\qurantrans@lt@mmmcxli{\q@u{Th}ikr\q@u{a} wam\q@u{a} kunn\q@u{a} \q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(209)}}
\qt@newcmd\qurantrans@lt@mmmcxlii{Wam\q@u{a} tanazzalat bihi a\q@b{l}shshay\q@u{at}een\q@b{u}\qt@no{(210)}}
\qt@newcmd\qurantrans@lt@mmmcxliii{Wam\q@u{a} yanbaghee lahum wam\q@u{a} yasta\q@u{t}eeAAoon\q@b{a}\qt@no{(211)}}
\qt@newcmd\qurantrans@lt@mmmcxliv{Innahum AAani a\q@b{l}ssamAAi lamaAAzooloona\qt@no{(212)}}
\qt@newcmd\qurantrans@lt@mmmcxlv{Fal\q@u{a} tadAAu maAAa All\q@u{a}hi il\q@u{a}han \q@u{a}khara fatakoona mina almuAAa\q@u{thth}abeen\q@b{a}\qt@no{(213)}}
\qt@newcmd\qurantrans@lt@mmmcxlvi{Waan\q@u{th}ir AAasheerataka alaqrabeen\q@b{a}\qt@no{(214)}}
\qt@newcmd\qurantrans@lt@mmmcxlvii{Wa\q@b{i}khfi\q@u{d} jan\q@u{ah}aka limani ittabaAAaka mina almumineen\q@b{a}\qt@no{(215)}}
\qt@newcmd\qurantrans@lt@mmmcxlviii{Fain AAa\q@u{s}awka faqul innee bareeon mimm\q@u{a} taAAmaloon\q@b{a}\qt@no{(216)}}
\qt@newcmd\qurantrans@lt@mmmcxlix{Watawakkal AAal\q@u{a} alAAazeezi a\q@b{l}rra\q@u{h}eem\q@b{i}\qt@no{(217)}}
\qt@newcmd\qurantrans@lt@mmmcl{Alla\q@u{th}ee yar\q@u{a}ka \q@u{h}eena taqoom\q@b{u}\qt@no{(218)}}
\qt@newcmd\qurantrans@lt@mmmcli{Wataqallubaka fee a\q@b{l}ss\q@u{a}jideen\q@b{a}\qt@no{(219)}}
\qt@newcmd\qurantrans@lt@mmmclii{Innahu huwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(220)}}
\qt@newcmd\qurantrans@lt@mmmcliii{Hal onabbiokum AAal\q@u{a} man tanazzalu a\q@b{l}shshay\q@u{at}een\q@b{u}\qt@no{(221)}}
\qt@newcmd\qurantrans@lt@mmmcliv{Tanazzalu AAal\q@u{a} kulli aff\q@u{a}kin atheem\q@b{in}\qt@no{(222)}}
\qt@newcmd\qurantrans@lt@mmmclv{Yulqoona a\q@b{l}ssamAAa waaktharuhum k\q@u{ath}iboon\q@b{a}\qt@no{(223)}}
\qt@newcmd\qurantrans@lt@mmmclvi{Wa\q@b{al}shshuAAar\q@u{a}o yattabiAAuhumu algh\q@u{a}woon\q@b{a}\qt@no{(224)}}
\qt@newcmd\qurantrans@lt@mmmclvii{Alam tara annahum fee kulli w\q@u{a}din yaheemoon\q@b{a}\qt@no{(225)}}
\qt@newcmd\qurantrans@lt@mmmclviii{Waannahum yaqooloona m\q@u{a} l\q@u{a} yafAAaloon\q@b{a}\qt@no{(226)}}
\qt@newcmd\qurantrans@lt@mmmclix{Ill\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti wa\q@u{th}akaroo All\q@u{a}ha katheeran wa\q@b{i}nta\q@u{s}aroo min baAAdi m\q@u{a} \q@i{\q@u{th}}ulimoo wasayaAAlamu alla\q@u{th}eena \q@i{\q@u{th}}alamoo ayya munqalabin yanqaliboon\q@b{a}\qt@no{(227)}}
\qt@newcmd\qurantrans@lt@mmmclx{\basmalahlt \q@u{Ta}seen tilka \q@u{a}y\q@u{a}tu alqur\q@u{a}ni wakit\q@u{a}bin mubeen\q@b{in}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmclxi{Hudan wabushr\q@u{a} lilmumineen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmclxii{Alla\q@u{th}eena yuqeemoona a\q@b{l}\q@u{ss}al\q@u{a}ta wayutoona a\q@b{l}zzak\q@u{a}ta wahum bi\q@b{a}l\q@u{a}khirati hum yooqinoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmclxiii{Inna alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati zayyann\q@u{a} lahum aAAm\q@u{a}lahum fahum yaAAmahoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmclxiv{Ol\q@u{a}ika alla\q@u{th}eena lahum sooo alAAa\q@u{tha}bi wahum fee al\q@u{a}khirati humu alakhsaroon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmclxv{Wainnaka latulaqq\q@u{a} alqur\q@u{a}na min ladun \q@u{h}akeemin AAaleem\q@b{in}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmclxvi{I\q@u{th} q\q@u{a}la moos\q@u{a} liahlihi innee \q@u{a}nastu n\q@u{a}ran sa\q@u{a}teekum minh\q@u{a} bikhabarin aw \q@u{a}teekum bishih\q@u{a}bin qabasin laAAallakum ta\q@u{st}aloon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmclxvii{Falamm\q@u{a} j\q@u{a}ah\q@u{a} noodiya an boorika man fee a\q@b{l}nn\q@u{a}ri waman \q@u{h}awlah\q@u{a} wasub\q@u{ha}na All\q@u{a}hi rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmclxviii{Y\q@u{a} moos\q@u{a} innahu an\q@u{a} All\q@u{a}hu alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmclxix{Waalqi AAa\q@u{sa}ka falamm\q@u{a} ra\q@u{a}h\q@u{a} tahtazzu kaannah\q@u{a} j\q@u{a}nnun wall\q@u{a} mudbiran walam yuAAaqqib y\q@u{a} moos\q@u{a} l\q@u{a} takhaf innee l\q@u{a} yakh\q@u{a}fu ladayya almursaloon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmclxx{Ill\q@u{a} man \q@i{\q@u{th}}alama thumma baddala \q@u{h}usnan baAAda sooin fainnee ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmclxxi{Waadkhil yadaka fee jaybika takhruj bay\q@u{da}a min ghayri sooin fee tisAAi \q@u{a}y\q@u{a}tin il\q@u{a} firAAawna waqawmihi innahum k\q@u{a}noo qawman f\q@u{a}siqeen\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmclxxii{Falamm\q@u{a} j\q@u{a}athum \q@u{a}y\q@u{a}tun\q@u{a} mub\q@u{s}iratan q\q@u{a}loo h\q@u{atha} si\q@u{h}run mubeen\q@b{un}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmclxxiii{Waja\q@u{h}adoo bih\q@u{a} wa\q@b{i}stayqanath\q@u{a} anfusuhum \q@i{\q@u{th}}ulman waAAuluwwan fa\q@b{o}n\q@i{\q@u{th}}ur kayfa k\q@u{a}na AA\q@u{a}qibatu almufsideen\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmclxxiv{Walaqad \q@u{a}tayn\q@u{a} d\q@u{a}wooda wasulaym\q@u{a}na AAilman waq\q@u{a}l\q@u{a} al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee fa\q@u{dd}alan\q@u{a} AAal\q@u{a} katheerin min AAib\q@u{a}dihi almumineen\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmclxxv{Wawaritha sulaym\q@u{a}nu d\q@u{a}wooda waq\q@u{a}la y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su AAullimn\q@u{a} man\q@u{t}iqa a\q@b{l}\q@u{tt}ayri waooteen\q@u{a} min kulli shayin inna h\q@u{atha} lahuwa alfa\q@u{d}lu almubeen\q@b{u}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmclxxvi{Wa\q@u{h}ushira lisulaym\q@u{a}na junooduhu mina aljinni wa\q@b{a}linsi wa\q@b{al}\q@u{tt}ayri fahum yoozaAAoon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmclxxvii{\q@u{H}att\q@u{a} i\q@u{tha} ataw AAal\q@u{a} w\q@u{a}di a\q@b{l}nnamli q\q@u{a}lat namlatun y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnamlu odkhuloo mas\q@u{a}kinakum l\q@u{a} ya\q@u{ht}imannakum sulaym\q@u{a}nu wajunooduhu wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmclxxviii{Fatabassama \q@u{dah}ikan min qawlih\q@u{a} waq\q@u{a}la rabbi awziAAnee an ashkura niAAmataka allatee anAAamta AAalayya waAAal\q@u{a} w\q@u{a}lidayya waan aAAmala \q@u{sa}li\q@u{h}an tar\q@u{da}hu waadkhilnee bira\q@u{h}matika fee AAib\q@u{a}dika a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmclxxix{Watafaqqada a\q@b{l}\q@u{tt}ayra faq\q@u{a}la m\q@u{a} liya l\q@u{a} ar\q@u{a} alhudhuda am k\q@u{a}na mina algh\q@u{a}ibeen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmclxxx{LaoAAa\q@u{thth}ibannahu AAa\q@u{tha}ban shadeedan aw laa\q@u{th}ba\q@u{h}annahu aw layatiyannee bisul\q@u{ta}nin mubeen\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmclxxxi{Famakatha ghayra baAAeedin faq\q@u{a}la a\q@u{hat}tu bim\q@u{a} lam tu\q@u{h}i\q@u{t} bihi wajituka min sabain binabain yaqeen\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmclxxxii{Innee wajadtu imraatan tamlikuhum waootiyat min kulli shayin walah\q@u{a} AAarshun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmclxxxiii{Wajadtuh\q@u{a} waqawmah\q@u{a} yasjudoona li\q@b{l}shshamsi min dooni All\q@u{a}hi wazayyana lahumu a\q@b{l}shshay\q@u{ta}nu aAAm\q@u{a}lahum fa\q@u{s}addahum AAani a\q@b{l}ssabeeli fahum l\q@u{a} yahtadoon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmclxxxiv{All\q@u{a} yasjudoo lill\q@u{a}hi alla\q@u{th}ee yukhriju alkhabaa fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wayaAAlamu m\q@u{a} tukhfoona wam\q@u{a} tuAAlinoon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmclxxxv{All\q@u{a}hu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa rabbu alAAarshi alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmclxxxvi{Q\q@u{a}la sanan\q@i{\q@u{th}}uru a\q@u{s}adaqta am kunta mina alk\q@u{ath}ibeen\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmclxxxvii{I\q@u{th}hab bikit\q@u{a}bee h\q@u{atha} faalqih ilayhim thumma tawalla AAanhum fa\q@b{o}n\q@i{\q@u{th}}ur m\q@u{atha} yarjiAAoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmclxxxviii{Q\q@u{a}lat y\q@u{a} ayyuh\q@u{a} almalao innee olqiya ilayya kit\q@u{a}bun kareem\q@b{un}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmclxxxix{Innahu min sulaym\q@u{a}na wainnahu bismi All\q@u{a}hi a\q@b{l}rra\q@u{h}m\q@u{a}ni a\q@b{l}rra\q@u{h}eem\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmcxc{All\q@u{a} taAAloo AAalayya watoonee muslimeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmcxci{Q\q@u{a}lat y\q@u{a} ayyuh\q@u{a} almalao aftoonee fee amree m\q@u{a} kuntu q\q@u{at}iAAatan amran \q@u{h}att\q@u{a} tashhadoon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmcxcii{Q\q@u{a}loo na\q@u{h}nu oloo quwwatin waoloo basin shadeedin wa\q@b{a}lamru ilayki fa\q@b{o}n\q@i{\q@u{th}}uree m\q@u{atha} tamureen\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmcxciii{Q\q@u{a}lat inna almulooka i\q@u{tha} dakhaloo qaryatan afsadooh\q@u{a} wajaAAaloo aAAizzata ahlih\q@u{a} a\q@u{th}illatan waka\q@u{tha}lika yafAAaloon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmcxciv{Wainnee mursilatun ilayhim bihadiyyatin fan\q@u{a}\q@i{\q@u{th}}iratun bima yarjiAAu almursaloon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmcxcv{Falamm\q@u{a} j\q@u{a}a sulaym\q@u{a}na q\q@u{a}la atumiddoonani bim\q@u{a}lin fam\q@u{a} \q@u{a}t\q@u{a}niya All\q@u{a}hu khayrun mimm\q@u{a} \q@u{a}t\q@u{a}kum bal antum bihadiyyatikum tafra\q@u{h}oon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmcxcvi{IrjiAA ilayhim falanatiyannahum bijunoodin l\q@u{a} qibala lahum bih\q@u{a} walanukhrijannahum minh\q@u{a} a\q@u{th}illatan wahum \q@u{sa}ghiroon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmcxcvii{Q\q@u{a}la y\q@u{a} ayyuh\q@u{a} almalao ayyukum yateenee biAAarshih\q@u{a} qabla an yatoonee muslimeen\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmcxcviii{Q\q@u{a}la AAifreetun mina aljinni an\q@u{a} \q@u{a}teeka bihi qabla an taqooma min maq\q@u{a}mika wainne AAalayhi laqawiyyun ameen\q@b{un}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmcxcix{Q\q@u{a}la alla\q@u{th}ee AAindahu AAilmun mina alkit\q@u{a}bi an\q@u{a} \q@u{a}teeka bihi qabla an yartadda ilayka \q@u{t}arfuka falamm\q@u{a} ra\q@u{a}hu mustaqirran AAindahu q\q@u{a}la h\q@u{atha} min fa\q@u{d}li rabbee liyabluwanee aashkuru am akfuru waman shakara fainnam\q@u{a} yashkuru linafsihi waman kafara fainna rabbee ghaniyyun kareem\q@b{un}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmcc{Q\q@u{a}la nakkiroo lah\q@u{a} AAarshah\q@u{a} nan\q@i{\q@u{th}}ur atahtadee am takoonu mina alla\q@u{th}eena l\q@u{a} yahtadoon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmcci{Falamm\q@u{a} j\q@u{a}at qeela ah\q@u{a}ka\q@u{tha} AAarshuki q\q@u{a}lat kaannahu huwa waooteen\q@u{a} alAAilma min qablih\q@u{a} wakunn\q@u{a} muslimeen\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmccii{Wa\q@u{s}addah\q@u{a} m\q@u{a} k\q@u{a}nat taAAbudu min dooni All\q@u{a}hi innah\q@u{a} k\q@u{a}nat min qawmin k\q@u{a}fireen\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmcciii{Qeela lah\q@u{a} odkhulee a\q@b{l}\q@u{ss}ar\q@u{h}a falamm\q@u{a} raathu \q@u{h}asibathu lujjatan wakashafat AAan s\q@u{a}qayh\q@u{a} q\q@u{a}la innahu \q@u{s}ar\q@u{h}un mumarradun min qaw\q@u{a}reera q\q@u{a}lat rabbi innee \q@i{\q@u{th}}alamtu nafsee waaslamtu maAAa sulaym\q@u{a}na lill\q@u{a}hi rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmcciv{Walaqad arsaln\q@u{a} il\q@u{a} thamooda akh\q@u{a}hum \q@u{sa}li\q@u{h}an ani oAAbudoo All\q@u{a}ha fai\q@u{tha} hum fareeq\q@u{a}ni yakhta\q@u{s}imoon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmccv{Q\q@u{a}la y\q@u{a} qawmi lima tastaAAjiloona bi\q@b{al}ssayyiati qabla al\q@u{h}asanati lawl\q@u{a} tastaghfiroona All\q@u{a}ha laAAallakum tur\q@u{h}amoon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmccvi{Q\q@u{a}loo i\q@u{tt}ayyarn\q@u{a} bika wabiman maAAaka q\q@u{a}la \q@u{ta}irukum AAinda All\q@u{a}hi bal antum qawmun tuftanoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmccvii{Wak\q@u{a}na fee almadeenati tisAAatu rah\q@u{t}in yufsidoona fee alar\q@u{d}i wal\q@u{a} yu\q@u{s}li\q@u{h}oon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmccviii{Q\q@u{a}loo taq\q@u{a}samoo bi\q@b{A}ll\q@u{a}hi lanubayyitannahu waahlahu thumma lanaqoolanna liwaliyyihi m\q@u{a} shahidn\q@u{a} mahlika ahlihi wainn\q@u{a} la\q@u{sa}diqoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmccix{Wamakaroo makran wamakarn\q@u{a} makran wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmccx{Fa\q@b{o}n\q@i{\q@u{th}}ur kayfa k\q@u{a}na AA\q@u{a}qibatu makrihim ann\q@u{a} dammarn\q@u{a}hum waqawmahum ajmaAAeen\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmccxi{Fatilka buyootuhum kh\q@u{a}wiyatan bim\q@u{a} \q@i{\q@u{th}}alamoo inna fee \q@u{tha}lika la\q@u{a}yatan liqawmin yaAAlamoon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmccxii{Waanjayn\q@u{a} alla\q@u{th}eena \q@u{a}manoo wak\q@u{a}noo yattaqoon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmccxiii{Waloo\q@u{t}an i\q@u{th} q\q@u{a}la liqawmihi atatoona alf\q@u{ah}ishata waantum tub\q@u{s}iroon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmccxiv{Ainnakum latatoona a\q@b{l}rrij\q@u{a}la shahwatan min dooni a\q@b{l}nnis\q@u{a}i bal antum qawmun tajhaloon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmccxv{Fam\q@u{a} k\q@u{a}na jaw\q@u{a}ba qawmihi ill\q@u{a} an q\q@u{a}loo akhrijoo \q@u{a}la loo\q@u{t}in min qaryatikum innahum on\q@u{a}sun yata\q@u{t}ahharoon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmccxvi{Faanjayn\q@u{a}hu waahlahu ill\q@u{a} imraatahu qaddarn\q@u{a}h\q@u{a} mina algh\q@u{a}bireen\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmccxvii{Waam\q@u{t}arn\q@u{a} AAalayhim ma\q@u{t}aran fas\q@u{a}a ma\q@u{t}aru almun\q@u{th}areen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmccxviii{Quli al\q@u{h}amdu lill\q@u{a}hi wasal\q@u{a}mun AAal\q@u{a} AAib\q@u{a}dihi alla\q@u{th}eena i\q@u{st}af\q@u{a} \q@u{a}ll\q@u{a}hu khayrun amm\q@u{a} yushrikoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmccxix{Amman khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a waanzala lakum mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faanbatn\q@u{a} bihi \q@u{h}ad\q@u{a}iqa \q@u{tha}ta bahjatin m\q@u{a} k\q@u{a}na lakum an tunbitoo shajarah\q@u{a} ail\q@u{a}hun maAAa All\q@u{a}hi bal hum qawmun yaAAdiloon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmccxx{Amman jaAAala alar\q@u{d}a qar\q@u{a}ran wajaAAala khil\q@u{a}lah\q@u{a} anh\q@u{a}ran wajaAAala lah\q@u{a} raw\q@u{a}siya wajaAAala bayna alba\q@u{h}rayni \q@u{ha}jizan ail\q@u{a}hun maAAa All\q@u{a}hi bal aktharuhum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmccxxi{Amman yujeebu almu\q@u{dt}arra i\q@u{tha} daAA\q@u{a}hu wayakshifu a\q@b{l}ssooa wayajAAalukum khulaf\q@u{a}a alar\q@u{d}i ail\q@u{a}hun maAAa All\q@u{a}hi qaleelan m\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmccxxii{Amman yahdeekum fee \q@i{\q@u{th}}ulum\q@u{a}ti albarri wa\q@b{a}lba\q@u{h}ri waman yursilu a\q@b{l}rriy\q@u{ah}a bushran bayna yaday ra\q@u{h}matihi ail\q@u{a}hun maAAa All\q@u{a}hi taAA\q@u{a}l\q@u{a} All\q@u{a}hu AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmccxxiii{Amman yabdao alkhalqa thumma yuAAeeduhu waman yarzuqukum mina a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i ail\q@u{a}hun maAAa All\q@u{a}hi qul h\q@u{a}too burh\q@u{a}nakum in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmccxxiv{Qul l\q@u{a} yaAAlamu man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i alghayba ill\q@u{a} All\q@u{a}hu wam\q@u{a} yashAAuroona ayy\q@u{a}na yubAAathoon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmccxxv{Bali idd\q@u{a}raka AAilmuhum fee al\q@u{a}khirati bal hum fee shakkin minh\q@u{a} bal hum minh\q@u{a} AAamoon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmccxxvi{Waq\q@u{a}la alla\q@u{th}eena kafaroo ai\q@u{tha} kunn\q@u{a} tur\q@u{a}ban wa\q@u{a}b\q@u{a}on\q@u{a} ainn\q@u{a} lamukhrajoon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmccxxvii{Laqad wuAAidn\q@u{a} h\q@u{atha} na\q@u{h}nu wa\q@u{a}b\q@u{a}on\q@u{a} min qablu in h\q@u{atha} ill\q@u{a} as\q@u{at}eeru alawwaleen\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmccxxviii{Qul seeroo fee alar\q@u{d}i fa\q@b{o}n\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu almujrimeen\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmccxxix{Wal\q@u{a} ta\q@u{h}zan AAalayhim wal\q@u{a} takun fee \q@u{d}ayqin mimm\q@u{a} yamkuroon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmccxxx{Wayaqooloona mat\q@u{a} h\q@u{atha} alwaAAdu in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmccxxxi{Qul AAas\q@u{a} an yakoona radifa lakum baAA\q@u{d}u alla\q@u{th}ee tastaAAjiloon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmccxxxii{Wainna rabbaka la\q@u{th}oo fa\q@u{d}lin AAal\q@u{a} a\q@b{l}nn\q@u{a}si wal\q@u{a}kinna aktharahum l\q@u{a} yashkuroon\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmccxxxiii{Wainna rabbaka layaAAlamu m\q@u{a} tukinnu \q@u{s}udooruhum wam\q@u{a} yuAAlinoon\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmccxxxiv{Wam\q@u{a} min gh\q@u{a}ibatin fee a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i ill\q@u{a} fee kit\q@u{a}bin mubeen\q@b{in}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmccxxxv{Inna h\q@u{atha} alqur\q@u{a}na yaqu\q@u{ss}u AAal\q@u{a} banee isr\q@u{a}eela akthara alla\q@u{th}ee hum feehi yakhtalifoon\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmccxxxvi{Wainnahu lahudan wara\q@u{h}matun lilmumineen\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmccxxxvii{Inna rabbaka yaq\q@u{d}ee baynahum bi\q@u{h}ukmihi wahuwa alAAazeezu alAAaleem\q@b{u}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmccxxxviii{Fatawakkal AAal\q@u{a} All\q@u{a}hi innaka AAal\q@u{a} al\q@u{h}aqqi almubeen\q@b{i}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmmccxxxix{Innaka l\q@u{a} tusmiAAu almawt\q@u{a} wal\q@u{a} tusmiAAu a\q@b{l}\q@u{ss}umma a\q@b{l}dduAA\q@u{a}a i\q@u{tha} wallaw mudbireen\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmmccxl{Wam\q@u{a} anta bih\q@u{a}dee alAAumyi AAan \q@u{d}al\q@u{a}latihim in tusmiAAu ill\q@u{a} man yuminu bi\q@u{a}y\q@u{a}tin\q@u{a} fahum muslimoon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmmccxli{Wai\q@u{tha} waqaAAa alqawlu AAalayhim akhrajn\q@u{a} lahum d\q@u{a}bbatan mina alar\q@u{d}i tukallimuhum anna a\q@b{l}nn\q@u{a}sa k\q@u{a}noo bi\q@u{a}y\q@u{a}tin\q@u{a} l\q@u{a} yooqinoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmmccxlii{Wayawma na\q@u{h}shuru min kulli ommatin fawjan mimman yuka\q@u{thth}ibu bi\q@u{a}y\q@u{a}tin\q@u{a} fahum yoozaAAoon\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmmccxliii{\q@u{H}att\q@u{a} i\q@u{tha} j\q@u{a}oo q\q@u{a}la aka\q@u{thth}abtum bi\q@u{a}y\q@u{a}tee walam tu\q@u{h}ee\q@u{t}oo bih\q@u{a} AAilman amm\q@u{atha} kuntum taAAmaloon\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmmccxliv{WawaqaAAa alqawlu AAalayhim bim\q@u{a} \q@i{\q@u{th}}alamoo fahum l\q@u{a} yan\q@u{t}iqoon\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmmccxlv{Alam yaraw ann\q@u{a} jaAAaln\q@u{a} allayla liyaskunoo feehi wa\q@b{al}nnah\q@u{a}ra mub\q@u{s}iran inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yuminoon\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmmccxlvi{Wayawma yunfakhu fee a\q@b{l}\q@u{ss}oori fafaziAAa man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti waman fee alar\q@u{d}i ill\q@u{a} man sh\q@u{a}a All\q@u{a}hu wakullun atawhu d\q@u{a}khireen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmmccxlvii{Watar\q@u{a} aljib\q@u{a}la ta\q@u{h}sabuh\q@u{a} j\q@u{a}midatan wahiya tamurru marra a\q@b{l}ssa\q@u{ha}bi \q@u{s}unAAa All\q@u{a}hi alla\q@u{th}ee atqana kulla shayin innahu khabeerun bim\q@u{a} tafAAaloon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmmccxlviii{Man j\q@u{a}a bi\q@b{a}l\q@u{h}asanati falahu khayrun minh\q@u{a} wahum min fazaAAin yawmai\q@u{th}in \q@u{a}minoon\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmmccxlix{Waman j\q@u{a}a bi\q@b{al}ssayyiati fakubbat wujoohuhum fee a\q@b{l}nn\q@u{a}ri hal tujzawna ill\q@u{a} m\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmmccl{Innam\q@u{a} omirtu an aAAbuda rabba h\q@u{ath}ihi albaldati alla\q@u{th}ee \q@u{h}arramah\q@u{a} walahu kullu shayin waomirtu an akoona mina almuslimeen\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmmccli{Waan atluwa alqur\q@u{a}na famani ihtad\q@u{a} fainnam\q@u{a} yahtadee linafsihi waman \q@u{d}alla faqul innam\q@u{a} an\q@u{a} mina almun\q@u{th}ireen\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmmcclii{Waquli al\q@u{h}amdu lill\q@u{a}hi sayureekum \q@u{a}y\q@u{a}tihi fataAArifoonah\q@u{a} wam\q@u{a} rabbuka bigh\q@u{a}filin AAamm\q@u{a} taAAmaloon\q@b{a}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmmccliii{\basmalahlt \q@u{Ta}seenmeem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmccliv{Tilka \q@u{a}y\q@u{a}tu alkit\q@u{a}bi almubeen\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmcclv{Natloo AAalayka min nabai moos\q@u{a} wafirAAawna bi\q@b{a}l\q@u{h}aqqi liqawmin yuminoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmcclvi{Inna firAAawna AAal\q@u{a} fee alar\q@u{d}i wajaAAala ahlah\q@u{a} shiyaAAan yasta\q@u{d}AAifu \q@u{ta}ifatan minhum yu\q@u{th}abbi\q@u{h}u abn\q@u{a}ahum wayasta\q@u{h}yee nis\q@u{a}ahum innahu k\q@u{a}na mina almufsideen\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmcclvii{Wanureedu an namunna AAal\q@u{a} alla\q@u{th}eena istu\q@u{d}AAifoo fee alar\q@u{d}i wanajAAalahum aimmatan wanajAAalahumu alw\q@u{a}ritheen\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmcclviii{Wanumakkina lahum fee alar\q@u{d}i wanuriya firAAawna wah\q@u{a}m\q@u{a}na wajunoodahum\q@u{a} minhum m\q@u{a} k\q@u{a}noo ya\q@u{hth}aroon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmcclix{Waaw\q@u{h}ayn\q@u{a} il\q@u{a} ommi moos\q@u{a} an ar\q@u{d}iAAeehi fai\q@u{tha} khifti AAalayhi faalqeehi fee alyammi wal\q@u{a} takh\q@u{a}fee wal\q@u{a} ta\q@u{h}zanee inn\q@u{a} r\q@u{a}ddoohu ilayki waj\q@u{a}AAiloohu mina almursaleen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmcclx{Fa\q@b{i}ltaqa\q@u{t}ahu \q@u{a}lu firAAawna liyakoona lahum AAaduwwan wa\q@u{h}azanan inna firAAawna wah\q@u{a}m\q@u{a}na wajunoodahum\q@u{a} k\q@u{a}noo kh\q@u{at}ieen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmcclxi{Waq\q@u{a}lati imraatu firAAawna qurratu AAaynin lee walaka l\q@u{a} taqtuloohu AAas\q@u{a} an yanfaAAan\q@u{a} aw nattakhi\q@u{th}ahu waladan wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmcclxii{Waa\q@u{s}ba\q@u{h}a fu\q@u{a}du ommi moos\q@u{a} f\q@u{a}righan in k\q@u{a}dat latubdee bihi lawl\q@u{a} an raba\q@u{t}n\q@u{a} AAal\q@u{a} qalbih\q@u{a} litakoona mina almumineen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmcclxiii{Waq\q@u{a}lat liokhtihi qu\q@u{ss}eehi faba\q@u{s}urat bihi AAan junubin wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmcclxiv{Wa\q@u{h}arramn\q@u{a} AAalayhi almar\q@u{ad}iAAa min qablu faq\q@u{a}lat hal adullukum AAal\q@u{a} ahli baytin yakfuloonahu lakum wahum lahu n\q@u{as}i\q@u{h}oon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmcclxv{Faradadn\q@u{a}hu il\q@u{a} ommihi kay taqarra AAaynuh\q@u{a} wal\q@u{a} ta\q@u{h}zana walitaAAlama anna waAAda All\q@u{a}hi \q@u{h}aqqun wal\q@u{a}kinna aktharahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmcclxvi{Walamm\q@u{a} balagha ashuddahu wa\q@b{i}staw\q@u{a} \q@u{a}tayn\q@u{a}hu \q@u{h}ukman waAAilman waka\q@u{tha}lika najzee almu\q@u{h}sineen\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmcclxvii{Wadakhala almadeenata AAal\q@u{a} \q@u{h}eeni ghaflatin min ahlih\q@u{a} fawajada feeh\q@u{a} rajulayni yaqtatil\q@u{a}ni h\q@u{atha} min sheeAAatihi wah\q@u{atha} min AAaduwwihi fa\q@b{i}stagh\q@u{a}thahu alla\q@u{th}ee min sheeAAatihi AAal\q@u{a} alla\q@u{th}ee min AAaduwwihi fawakazahu moos\q@u{a} faqa\q@u{da} AAalayhi q\q@u{a}la h\q@u{atha} min AAamali a\q@b{l}shshay\q@u{ta}ni innahu AAaduwwun mu\q@u{d}illun mubeen\q@b{un}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmcclxviii{Q\q@u{a}la rabbi innee \q@i{\q@u{th}}alamtu nafsee fa\q@b{i}ghfir lee faghafara lahu innahu huwa alghafooru a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmcclxix{Q\q@u{a}la rabbi bim\q@u{a} anAAamta AAalayya falan akoona \q@i{\q@u{th}}aheeran lilmujrimeen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmcclxx{Faa\q@u{s}ba\q@u{h}a fee almadeenati kh\q@u{a}ifan yataraqqabu fai\q@u{tha} alla\q@u{th}ee istan\q@u{s}arahu bi\q@b{a}lamsi yasta\q@u{s}rikhuhu q\q@u{a}la lahu moos\q@u{a} innaka laghawiyyun mubeen\q@b{un}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmcclxxi{Falamm\q@u{a} an ar\q@u{a}da an yab\q@u{t}isha bi\q@b{a}lla\q@u{th}ee huwa AAaduwwun lahum\q@u{a} q\q@u{a}la y\q@u{a} moos\q@u{a} atureedu an taqtulanee kam\q@u{a} qatalta nafsan bi\q@b{a}lamsi in tureedu ill\q@u{a} an takoona jabb\q@u{a}ran fee alar\q@u{d}i wam\q@u{a} tureedu an takoona mina almu\q@u{s}li\q@u{h}een\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmcclxxii{Waj\q@u{a}a rajulun min aq\q@u{sa} almadeenati yasAA\q@u{a} q\q@u{a}la y\q@u{a} moos\q@u{a} inna almalaa yatamiroona bika liyaqtulooka fa\q@b{o}khruj innee laka mina a\q@b{l}nn\q@u{as}i\q@u{h}een\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmcclxxiii{Fakharaja minh\q@u{a} kh\q@u{a}ifan yataraqqabu q\q@u{a}la rabbi najjinee mina alqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmcclxxiv{Walamm\q@u{a} tawajjaha tilq\q@u{a}a madyana q\q@u{a}la AAas\q@u{a} rabbee an yahdiyanee saw\q@u{a}a a\q@b{l}ssabeel\q@b{i}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmcclxxv{Walamm\q@u{a} warada m\q@u{a}a madyana wajada AAalayhi ommatan mina a\q@b{l}nn\q@u{a}si yasqoona wawajada min doonihimu imraatayni ta\q@u{th}ood\q@u{a}ni q\q@u{a}la m\q@u{a} kha\q@u{t}bukum\q@u{a} q\q@u{a}lat\q@u{a} l\q@u{a} nasqee \q@u{h}att\q@u{a} yu\q@u{s}dira a\q@b{l}rriAA\q@u{a}o waaboon\q@u{a} shaykhun kabeer\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmcclxxvi{Fasaq\q@u{a} lahum\q@u{a} thumma tawall\q@u{a} il\q@u{a} a\q@b{l}\q@i{\q@u{thth}}illi faq\q@u{a}la rabbi innee lim\q@u{a} anzalta ilayya min khayrin faqeer\q@b{un}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmcclxxvii{Faj\q@u{a}athu i\q@u{h}d\q@u{a}hum\q@u{a} tamshee AAal\q@u{a} isti\q@u{h}y\q@u{a}in q\q@u{a}lat inna abee yadAAooka liyajziyaka ajra m\q@u{a} saqayta lan\q@u{a} falamm\q@u{a} j\q@u{a}ahu waqa\q@u{ss}a AAalayhi alqa\q@u{s}a\q@u{s}a q\q@u{a}la l\q@u{a} takhaf najawta mina alqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmcclxxviii{Q\q@u{a}lat i\q@u{h}d\q@u{a}hum\q@u{a} y\q@u{a} abati istajirhu inna khayra mani istajarta alqawiyyu alameen\q@b{u}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmcclxxix{Q\q@u{a}la innee oreedu an onki\q@u{h}aka i\q@u{h}d\q@u{a} ibnatayya h\q@u{a}tayni AAal\q@u{a} an tajuranee tham\q@u{a}niya \q@u{h}ijajin fain atmamta AAashran famin AAindika wam\q@u{a} oreedu an ashuqqa AAalayka satajidunee in sh\q@u{a}a All\q@u{a}hu mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmcclxxx{Q\q@u{a}la \q@u{tha}lika baynee wabaynaka ayyam\q@u{a} alajalayni qa\q@u{d}aytu fal\q@u{a} AAudw\q@u{a}na AAalayya wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} m\q@u{a} naqoolu wakeel\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmcclxxxi{Falamm\q@u{a} qa\q@u{da} moos\q@u{a}alajala was\q@u{a}ra biahlihi \q@u{a}nasa min j\q@u{a}nibi a\q@b{l}\q@u{tt}oori n\q@u{a}ran q\q@u{a}la liahlihi omkuthoo innee \q@u{a}nastu n\q@u{a}ran laAAallee \q@u{a}teekum minh\q@u{a} bikhabarin aw ja\q@u{th}watin mina a\q@b{l}nn\q@u{a}ri laAAallakum ta\q@u{st}aloon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmcclxxxii{Falamm\q@u{a} at\q@u{a}h\q@u{a} noodiya min sh\q@u{at}ii alw\q@u{a}di alaymani fee albuqAAati almub\q@u{a}rakati mina a\q@b{l}shshajarati an y\q@u{a} moos\q@u{a} innee an\q@u{a} All\q@u{a}hu rabbu alAA\q@u{a}lameen\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmcclxxxiii{Waan alqi AAa\q@u{sa}ka falamm\q@u{a} ra\q@u{a}h\q@u{a} tahtazzu kaannah\q@u{a} j\q@u{a}nnun wall\q@u{a} mudbiran walam yuAAaqqib y\q@u{a} moos\q@u{a} aqbil wal\q@u{a} takhaf innaka mina al\q@u{a}mineen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmcclxxxiv{Osluk yadaka fee jaybika takhruj bay\q@u{da}a min ghayri sooin wa\q@b{o}\q@u{d}mum ilayka jan\q@u{ah}aka mina a\q@b{l}rrahbi fa\q@u{tha}nika burh\q@u{a}n\q@u{a}ni min rabbika il\q@u{a} firAAawna wamalaihi innahum k\q@u{a}noo qawman f\q@u{a}siqeen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmcclxxxv{Q\q@u{a}la rabbi innee qataltu minhum nafsan faakh\q@u{a}fu an yaqtuloon\q@b{i}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmcclxxxvi{Waakhee h\q@u{a}roonu huwa af\q@u{s}a\q@u{h}u minnee lis\q@u{a}nan faarsilhu maAAiya ridan yu\q@u{s}addiqunee innee akh\q@u{a}fu an yuka\q@u{thth}iboon\q@b{i}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmcclxxxvii{Q\q@u{a}la sanashuddu AAa\q@u{d}udaka biakheeka wanajAAalu lakum\q@u{a} sul\q@u{ta}nan fal\q@u{a} ya\q@u{s}iloona ilaykum\q@u{a} bi\q@u{a}y\q@u{a}tin\q@u{a} antum\q@u{a} wamani ittabaAAakum\q@u{a} algh\q@u{a}liboon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmcclxxxviii{Falamm\q@u{a} j\q@u{a}ahum moos\q@u{a} bi\q@u{a}y\q@u{a}tin\q@u{a} bayyin\q@u{a}tin q\q@u{a}loo m\q@u{a} h\q@u{atha} ill\q@u{a} si\q@u{h}run muftaran wam\q@u{a} samiAAn\q@u{a} bih\q@u{atha} fee \q@u{a}b\q@u{a}in\q@u{a} alawwaleen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmcclxxxix{Waq\q@u{a}la moos\q@u{a} rabbee aAAlamu biman j\q@u{a}a bi\q@b{a}lhud\q@u{a} min AAindihi waman takoonu lahu AA\q@u{a}qibatu a\q@b{l}dd\q@u{a}ri innahu l\q@u{a} yufli\q@u{h}u a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmccxc{Waq\q@u{a}la firAAawnu y\q@u{a} ayyuh\q@u{a} almalao m\q@u{a} AAalimtu lakum min il\q@u{a}hin ghayree faawqid lee y\q@u{a} h\q@u{a}m\q@u{a}nu AAal\q@u{a} a\q@b{l}\q@u{tt}eeni fa\q@b{i}jAAal lee \q@u{s}ar\q@u{h}an laAAallee a\q@u{tt}aliAAu il\q@u{a} il\q@u{a}hi moos\q@u{a} wainnee laa\q@i{\q@u{th}}unnuhu mina alk\q@u{ath}ibeen\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmccxci{Wa\q@b{i}stakbara huwa wajunooduhu fee alar\q@u{d}i bighayri al\q@u{h}aqqi wa\q@i{\q@u{th}}annoo annahum ilayn\q@u{a} l\q@u{a} yurjaAAoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmccxcii{Faakha\q@u{th}n\q@u{a}hu wajunoodahu fanaba\q@u{th}n\q@u{a}hum fee alyammi fa\q@b{o}n\q@i{\q@u{th}}ur kayfa k\q@u{a}na AA\q@u{a}qibatu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmccxciii{WajaAAaln\q@u{a}hum aimmatan yadAAoona il\q@u{a} a\q@b{l}nn\q@u{a}ri wayawma alqiy\q@u{a}mati l\q@u{a} yun\q@u{s}aroon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmccxciv{WaatbaAAn\q@u{a}hum fee h\q@u{ath}ihi a\q@b{l}dduny\q@u{a} laAAnatan wayawma alqiy\q@u{a}mati hum mina almaqboo\q@u{h}een\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmccxcv{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba min baAAdi m\q@u{a} ahlakn\q@u{a} alquroona alool\q@u{a} ba\q@u{sa}ira li\q@b{l}nn\q@u{a}si wahudan wara\q@u{h}matan laAAallahum yata\q@u{th}akkaroon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmccxcvi{Wam\q@u{a} kunta bij\q@u{a}nibi algharbiyyi i\q@u{th} qa\q@u{d}ayn\q@u{a} il\q@u{a} moos\q@u{a} alamra wam\q@u{a} kunta mina a\q@b{l}shsh\q@u{a}hideen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmccxcvii{Wal\q@u{a}kinn\q@u{a} anshan\q@u{a} quroonan fata\q@u{ta}wala AAalayhimu alAAumuru wam\q@u{a} kunta th\q@u{a}wiyan fee ahli madyana tatloo AAalayhim \q@u{a}y\q@u{a}tin\q@u{a} wal\q@u{a}kinn\q@u{a} kunn\q@u{a} mursileen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmccxcviii{Wam\q@u{a} kunta bij\q@u{a}nibi a\q@b{l}\q@u{tt}oori i\q@u{th} n\q@u{a}dayn\q@u{a} wal\q@u{a}kin ra\q@u{h}matan min rabbika litun\q@u{th}ira qawman m\q@u{a} at\q@u{a}hum min na\q@u{th}eerin min qablika laAAallahum yata\q@u{th}akkaroon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmccxcix{Walawl\q@u{a} an tu\q@u{s}eebahum mu\q@u{s}eebatun bim\q@u{a} qaddamat aydeehim fayaqooloo rabban\q@u{a} lawl\q@u{a} arsalta ilayn\q@u{a} rasoolan fanattabiAAa \q@u{a}y\q@u{a}tika wanakoona mina almumineen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmccc{Falamm\q@u{a} j\q@u{a}ahumu al\q@u{h}aqqu min AAindin\q@u{a} q\q@u{a}loo lawl\q@u{a} ootiya mithla m\q@u{a} ootiya moos\q@u{a} awalam yakfuroo bim\q@u{a} ootiya moos\q@u{a} min qablu q\q@u{a}loo si\q@u{h}r\q@u{a}ni ta\q@i{\q@u{th}}\q@u{a}har\q@u{a} waq\q@u{a}loo inn\q@u{a} bikullin k\q@u{a}firoon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmccci{Qul fatoo bikit\q@u{a}bin min AAindi All\q@u{a}hi huwa ahd\q@u{a} minhum\q@u{a} attabiAAhu in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmcccii{Fain lam yastajeeboo laka fa\q@b{i}AAlam annam\q@u{a} yattabiAAoona ahw\q@u{a}ahum waman a\q@u{d}allu mimmani ittabaAAa haw\q@u{a}hu bighayri hudan mina All\q@u{a}hi inna All\q@u{a}ha l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmccciii{Walaqad wa\q@u{ss}aln\q@u{a} lahumu alqawla laAAallahum yata\q@u{th}akkaroon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmccciv{Alla\q@u{th}eena \q@u{a}tayn\q@u{a}humu alkit\q@u{a}ba min qablihi hum bihi yuminoon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmcccv{Wai\q@u{tha} yutl\q@u{a} AAalayhim q\q@u{a}loo \q@u{a}mann\q@u{a} bihi innahu al\q@u{h}aqqu min rabbin\q@u{a} inn\q@u{a} kunn\q@u{a} min qablihi muslimeen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmcccvi{Ol\q@u{a}ika yutawna ajrahum marratayni bim\q@u{a} \q@u{s}abaroo wayadraoona bi\q@b{a}l\q@u{h}asanati a\q@b{l}ssayyiata wamimm\q@u{a} razaqn\q@u{a}hum yunfiqoon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmcccvii{Wai\q@u{tha} samiAAoo allaghwa aAAra\q@u{d}oo AAanhu waq\q@u{a}loo lan\q@u{a} aAAm\q@u{a}lun\q@u{a} walakum aAAm\q@u{a}lukum sal\q@u{a}mun AAalaykum l\q@u{a} nabtaghee alj\q@u{a}hileen\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmcccviii{Innaka l\q@u{a} tahdee man a\q@u{h}babta wal\q@u{a}kinna All\q@u{a}ha yahdee man yash\q@u{a}o wahuwa aAAlamu bi\q@b{a}lmuhtadeen\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmcccix{Waq\q@u{a}loo in nattabiAAi alhud\q@u{a} maAAaka nutakha\q@u{tt}af min ar\q@u{d}in\q@u{a} awalam numakkin lahum \q@u{h}araman \q@u{a}minan yujb\q@u{a} ilayhi thamar\q@u{a}tu kulli shayin rizqan min ladunn\q@u{a} wal\q@u{a}kinna aktharahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmcccx{Wakam ahlakn\q@u{a} min qaryatin ba\q@u{t}irat maAAeeshatah\q@u{a} fatilka mas\q@u{a}kinuhum lam tuskan min baAAdihim ill\q@u{a} qaleelan wakunn\q@u{a} na\q@u{h}nu alw\q@u{a}ritheen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmcccxi{Wam\q@u{a} k\q@u{a}na rabbuka muhlika alqur\q@u{a} \q@u{h}att\q@u{a} yabAAatha fee ommih\q@u{a} rasoolan yatloo AAalayhim \q@u{a}y\q@u{a}tin\q@u{a} wam\q@u{a} kunn\q@u{a} muhlikee alqur\q@u{a} ill\q@u{a} waahluh\q@u{a} \q@i{\q@u{th}}\q@u{a}limoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmcccxii{Wam\q@u{a} ooteetum min shayin famat\q@u{a}AAu al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wazeenatuh\q@u{a} wam\q@u{a} AAinda All\q@u{a}hi khayrun waabq\q@u{a} afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmcccxiii{Afaman waAAadn\q@u{a}hu waAAdan \q@u{h}asanan fahuwa l\q@u{a}qeehi kaman mattaAAn\q@u{a}hu mat\q@u{a}AAa al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} thumma huwa yawma alqiy\q@u{a}mati mina almu\q@u{hd}areen\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmcccxiv{Wayawma yun\q@u{a}deehim fayaqoolu ayna shurak\q@u{a}iya alla\q@u{th}eena kuntum tazAAumoon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmcccxv{Q\q@u{a}la alla\q@u{th}eena \q@u{h}aqqa AAalayhimu alqawlu rabban\q@u{a} h\q@u{a}ol\q@u{a}i alla\q@u{th}eena aghwayn\q@u{a} aghwayn\q@u{a}hum kam\q@u{a} ghawayn\q@u{a} tabarran\q@u{a} ilayka m\q@u{a} k\q@u{a}noo iyy\q@u{a}n\q@u{a} yaAAbudoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmcccxvi{Waqeela odAAoo shurak\q@u{a}akum fadaAAawhum falam yastajeeboo lahum waraawoo alAAa\q@u{tha}ba law annahum k\q@u{a}noo yahtadoon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmcccxvii{Wayawma yun\q@u{a}deehim fayaqoolu m\q@u{atha} ajabtumu almursaleen\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmcccxviii{FaAAamiyat AAalayhimu alanb\q@u{a}o yawmai\q@u{th}in fahum l\q@u{a} yatas\q@u{a}aloon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmcccxix{Faamm\q@u{a} man t\q@u{a}ba wa\q@u{a}mana waAAamila \q@u{sa}li\q@u{h}an faAAas\q@u{a} an yakoona mina almufli\q@u{h}een\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmcccxx{Warabbuka yakhluqu m\q@u{a} yash\q@u{a}o wayakht\q@u{a}ru m\q@u{a} k\q@u{a}na lahumu alkhiyaratu sub\q@u{ha}na All\q@u{a}hi wataAA\q@u{a}l\q@u{a} AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmcccxxi{Warabbuka yaAAlamu m\q@u{a} tukinnu \q@u{s}udooruhum wam\q@u{a} yuAAlinoon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmcccxxii{Wahuwa All\q@u{a}hu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa lahu al\q@u{h}amdu fee alool\q@u{a} wa\q@b{a}l\q@u{a}khirati walahu al\q@u{h}ukmu wailayhi turjaAAoon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmcccxxiii{Qul araaytum in jaAAala All\q@u{a}hu AAalaykumu allayla sarmadan il\q@u{a} yawmi alqiy\q@u{a}mati man il\q@u{a}hun ghayru All\q@u{a}hi yateekum bi\q@u{d}iy\q@u{a}in afal\q@u{a} tasmaAAoon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmcccxxiv{Qul araaytum in jaAAala All\q@u{a}hu AAalaykumu a\q@b{l}nnah\q@u{a}ra sarmadan il\q@u{a} yawmi alqiy\q@u{a}mati man il\q@u{a}hun ghayru All\q@u{a}hi yateekum bilaylin taskunoona feehi afal\q@u{a} tub\q@u{s}iroon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmcccxxv{Wamin ra\q@u{h}matihi jaAAala lakumu allayla wa\q@b{al}nnah\q@u{a}ra litaskunoo feehi walitabtaghoo min fa\q@u{d}lihi walaAAallakum tashkuroon\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmcccxxvi{Wayawma yun\q@u{a}deehim fayaqoolu ayna shurak\q@u{a}iya alla\q@u{th}eena kuntum tazAAumoon\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmcccxxvii{WanazaAAn\q@u{a} min kulli ommatin shaheedan faquln\q@u{a} h\q@u{a}too burh\q@u{a}nakum faAAalimoo anna al\q@u{h}aqqa lill\q@u{a}hi wa\q@u{d}alla AAanhum m\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmcccxxviii{Inna q\q@u{a}roona k\q@u{a}na min qawmi moos\q@u{a} fabagh\q@u{a} AAalayhim wa\q@u{a}tayn\q@u{a}hu mina alkunoozi m\q@u{a} inna maf\q@u{a}ti\q@u{h}ahu latanooo bi\q@b{a}lAAu\q@u{s}bati olee alquwwati i\q@u{th} q\q@u{a}la lahu qawmuhu l\q@u{a} tafra\q@u{h} inna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu alfari\q@u{h}een\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmcccxxix{Wa\q@b{i}btaghi feem\q@u{a} \q@u{a}t\q@u{a}ka All\q@u{a}hu a\q@b{l}dd\q@u{a}ra al\q@u{a}khirata wal\q@u{a} tansa na\q@u{s}eebaka mina a\q@b{l}dduny\q@u{a} waa\q@u{h}sin kam\q@u{a} a\q@u{h}sana All\q@u{a}hu ilayka wal\q@u{a} tabghi alfas\q@u{a}da fee alar\q@u{d}i inna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu almufsideen\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmcccxxx{Q\q@u{a}la innam\q@u{a} ooteetuhu AAal\q@u{a} AAilmin AAindee awalam yaAAlam anna All\q@u{a}ha qad ahlaka min qablihi mina alqurooni man huwa ashaddu minhu quwwatan waaktharu jamAAan wal\q@u{a} yusalu AAan \q@u{th}unoobihimu almujrimoon\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmcccxxxi{Fakharaja AAal\q@u{a} qawmihi fee zeenatihi q\q@u{a}la alla\q@u{th}eena yureedoona al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a} y\q@u{a} layta lan\q@u{a} mithla m\q@u{a} ootiya q\q@u{a}roonu innahu la\q@u{th}oo \q@u{h}a\q@i{\q@u{thth}}in AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmmcccxxxii{Waq\q@u{a}la alla\q@u{th}eena ootoo alAAilma waylakum thaw\q@u{a}bu All\q@u{a}hi khayrun liman \q@u{a}mana waAAamila \q@u{sa}li\q@u{h}an wal\q@u{a} yulaqq\q@u{a}h\q@u{a} ill\q@u{a} a\q@b{l}\q@u{ssa}biroon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmmcccxxxiii{Fakhasafn\q@u{a} bihi wabid\q@u{a}rihi alar\q@u{d}a fam\q@u{a} k\q@u{a}na lahu min fiatin yan\q@u{s}uroonahu min dooni All\q@u{a}hi wam\q@u{a} k\q@u{a}na mina almunta\q@u{s}ireen\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmmcccxxxiv{Waa\q@u{s}ba\q@u{h}a alla\q@u{th}eena tamannaw mak\q@u{a}nahu bi\q@b{a}lamsi yaqooloona waykaanna All\q@u{a}ha yabsu\q@u{t}u a\q@b{l}rrizqa liman yash\q@u{a}o min AAib\q@u{a}dihi wayaqdiru lawl\q@u{a} an manna All\q@u{a}hu AAalayn\q@u{a} lakhasafa bin\q@u{a} waykaannahu l\q@u{a} yufli\q@u{h}u alk\q@u{a}firoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmmcccxxxv{Tilka a\q@b{l}dd\q@u{a}ru al\q@u{a}khiratu najAAaluh\q@u{a} lilla\q@u{th}eena l\q@u{a} yureedoona AAuluwwan fee alar\q@u{d}i wal\q@u{a} fas\q@u{a}dan wa\q@b{a}lAA\q@u{a}qibatu lilmuttaqeen\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmmcccxxxvi{Man j\q@u{a}a bi\q@b{a}l\q@u{h}asanati falahu khayrun minh\q@u{a} waman j\q@u{a}a bi\q@b{al}ssayyiati fal\q@u{a} yujz\q@u{a} alla\q@u{th}eena AAamiloo a\q@b{l}ssayyi\q@u{a}ti ill\q@u{a} m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmmcccxxxvii{Inna alla\q@u{th}ee fara\q@u{d}a AAalayka alqur\q@u{a}na lar\q@u{a}dduka il\q@u{a} maAA\q@u{a}din qul rabbee aAAlamu man j\q@u{a}a bi\q@b{a}lhud\q@u{a} waman huwa fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmmcccxxxviii{Wam\q@u{a} kunta tarjoo an yulq\q@u{a} ilayka alkit\q@u{a}bu ill\q@u{a} ra\q@u{h}matan min rabbika fal\q@u{a} takoonanna \q@i{\q@u{th}}aheeran lilk\q@u{a}fireen\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmmcccxxxix{Wal\q@u{a} ya\q@u{s}uddunnaka AAan \q@u{a}y\q@u{a}ti All\q@u{a}hi baAAda i\q@u{th} onzilat ilayka wa\q@b{o}dAAu il\q@u{a} rabbika wal\q@u{a} takoonanna mina almushrikeen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmmcccxl{Wal\q@u{a} tadAAu maAAa All\q@u{a}hi il\q@u{a}han \q@u{a}khara l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa kullu shayin h\q@u{a}likun ill\q@u{a} wajhahu lahu al\q@u{h}ukmu wailayhi turjaAAoon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmmcccxli{\basmalahlt Alifl\q@u{a}mmeem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmcccxlii{A\q@u{h}asiba a\q@b{l}nn\q@u{a}su an yutrakoo an yaqooloo \q@u{a}mann\q@u{a} wahum l\q@u{a} yuftanoon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmcccxliii{Walaqad fatann\q@u{a} alla\q@u{th}eena min qablihim falayaAAlamanna All\q@u{a}hu alla\q@u{th}eena \q@u{s}adaqoo walayaAAlamanna alk\q@u{ath}ibeen\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmcccxliv{Am \q@u{h}asiba alla\q@u{th}eena yaAAmaloona a\q@b{l}ssayyi\q@u{a}ti an yasbiqoon\q@u{a} s\q@u{a}a m\q@u{a} ya\q@u{h}kumoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmcccxlv{Man k\q@u{a}na yarjoo liq\q@u{a}a All\q@u{a}hi fainna ajala All\q@u{a}hi la\q@u{a}tin wahuwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmcccxlvi{Waman j\q@u{a}hada fainnam\q@u{a} yuj\q@u{a}hidu linafsihi inna All\q@u{a}ha laghaniyyun AAani alAA\q@u{a}lameen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmcccxlvii{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lanukaffiranna AAanhum sayyi\q@u{a}tihim walanajziyannahum a\q@u{h}sana alla\q@u{th}ee k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmcccxlviii{Wawa\q@u{ss}ayn\q@u{a} alins\q@u{a}na biw\q@u{a}lidayhi \q@u{h}usnan wain j\q@u{a}had\q@u{a}ka litushrika bee m\q@u{a} laysa laka bihi AAilmun fal\q@u{a} tu\q@u{t}iAAhum\q@u{a} ilayya marjiAAukum faonabbiokum bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmcccxlix{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lanudkhilannahum fee a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmcccl{Wamina a\q@b{l}nn\q@u{a}si man yaqoolu \q@u{a}mann\q@u{a} bi\q@b{A}ll\q@u{a}hi fai\q@u{tha} oo\q@u{th}iya fee All\q@u{a}hi jaAAala fitnata a\q@b{l}nn\q@u{a}si kaAAa\q@u{tha}bi All\q@u{a}hi walain j\q@u{a}a na\q@u{s}run min rabbika layaqoolunna inn\q@u{a} kunn\q@u{a} maAAakum awalaysa All\q@u{a}hu biaAAlama bim\q@u{a} fee \q@u{s}udoori alAA\q@u{a}lameen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmcccli{WalayaAAlamanna All\q@u{a}hu alla\q@u{th}eena \q@u{a}manoo walayaAAlamanna almun\q@u{a}fiqeen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmccclii{Waq\q@u{a}la alla\q@u{th}eena kafaroo lilla\q@u{th}eena \q@u{a}manoo ittabiAAoo sabeelan\q@u{a} walna\q@u{h}mil kha\q@u{ta}y\q@u{a}kum wam\q@u{a} hum bi\q@u{ha}mileena min kha\q@u{ta}y\q@u{a}hum min shayin innahum lak\q@u{ath}iboon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmcccliii{Walaya\q@u{h}milunna athq\q@u{a}lahum waathq\q@u{a}lan maAAa athq\q@u{a}lihim walayusalunna yawma alqiy\q@u{a}mati AAamm\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmcccliv{Walaqad arsaln\q@u{a} noo\q@u{h}an il\q@u{a} qawmihi falabitha feehim alfa sanatin ill\q@u{a} khamseena AA\q@u{a}man faakha\q@u{th}ahumu a\q@b{l}\q@u{tt}oof\q@u{a}nu wahum \q@i{\q@u{th}}\q@u{a}limoon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmccclv{Faanjayn\q@u{a}hu waa\q@u{s}\q@u{ha}ba a\q@b{l}ssafeenati wajaAAaln\q@u{a}h\q@u{a} \q@u{a}yatan lilAA\q@u{a}lameen\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmccclvi{Waibr\q@u{a}heema i\q@u{th} q\q@u{a}la liqawmihi oAAbudoo All\q@u{a}ha wa\q@b{i}ttaqoohu \q@u{tha}likum khayrun lakum in kuntum taAAlamoon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmccclvii{Innam\q@u{a} taAAbudoona min dooni All\q@u{a}hi awth\q@u{a}nan watakhluqoona ifkan inna alla\q@u{th}eena taAAbudoona min dooni All\q@u{a}hi l\q@u{a} yamlikoona lakum rizqan fa\q@b{i}btaghoo AAinda All\q@u{a}hi a\q@b{l}rrizqa wa\q@b{o}AAbudoohu wa\q@b{o}shkuroo lahu ilayhi turjaAAoon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmccclviii{Wain tuka\q@u{thth}iboo faqad ka\q@u{thth}aba omamun min qablikum wam\q@u{a} AAal\q@u{a} a\q@b{l}rrasooli ill\q@u{a} albal\q@u{a}ghu almubeen\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmccclix{Awalam yaraw kayfa yubdio All\q@u{a}hu alkhalqa thumma yuAAeeduhu inna \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi yaseer\q@b{un}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmccclx{Qul seeroo fee alar\q@u{d}i fa\q@b{o}n\q@i{\q@u{th}}uroo kayfa badaa alkhalqa thumma All\q@u{a}hu yunshio a\q@b{l}nnashata al\q@u{a}khirata inna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmccclxi{YuAAa\q@u{thth}ibu man yash\q@u{a}o wayar\q@u{h}amu man yash\q@u{a}o wailayhi tuqlaboon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmccclxii{Wam\q@u{a} antum bimuAAjizeena fee alar\q@u{d}i wal\q@u{a} fee a\q@b{l}ssam\q@u{a}i wam\q@u{a} lakum min dooni All\q@u{a}hi min waliyyin wal\q@u{a} na\q@u{s}eer\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmccclxiii{Wa\q@b{a}lla\q@u{th}eena kafaroo bi\q@u{a}y\q@u{a}ti All\q@u{a}hi waliq\q@u{a}ihi ol\q@u{a}ika yaisoo min ra\q@u{h}matee waol\q@u{a}ika lahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmccclxiv{Fam\q@u{a} k\q@u{a}na jaw\q@u{a}ba qawmihi ill\q@u{a} an q\q@u{a}loo oqtuloohu aw \q@u{h}arriqoohu faanj\q@u{a}hu All\q@u{a}hu mina a\q@b{l}nn\q@u{a}ri inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yuminoon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmccclxv{Waq\q@u{a}la innam\q@u{a} ittakha\q@u{th}tum min dooni All\q@u{a}hi awth\q@u{a}nan mawaddata baynikum fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} thumma yawma alqiy\q@u{a}mati yakfuru baAA\q@u{d}ukum bibaAA\q@u{d}in wayalAAanu baAA\q@u{d}ukum baAA\q@u{d}an wamaw\q@u{a}kumu a\q@b{l}nn\q@u{a}ru wam\q@u{a} lakum min n\q@u{as}ireen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmccclxvi{Fa\q@u{a}mana lahu loo\q@u{t}un waq\q@u{a}la innee muh\q@u{a}jirun il\q@u{a} rabbee innahu huwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmccclxvii{Wawahabn\q@u{a} lahu is\q@u{ha}qa wayaAAqooba wajaAAaln\q@u{a} fee \q@u{th}urriyyatihi a\q@b{l}nnubuwwata wa\q@b{a}lkit\q@u{a}ba wa\q@u{a}tayn\q@u{a}hu ajrahu fee a\q@b{l}dduny\q@u{a} wainnahu fee al\q@u{a}khirati lamina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmccclxviii{Waloo\q@u{t}an i\q@u{th} q\q@u{a}la liqawmihi innakum latatoona alf\q@u{ah}ishata m\q@u{a} sabaqakum bih\q@u{a} min a\q@u{h}adin mina alAA\q@u{a}lameen\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmccclxix{Ainnakum latatoona a\q@b{l}rrij\q@u{a}la wataq\q@u{t}aAAoona a\q@b{l}ssabeela watatoona fee n\q@u{a}deekumu almunkara fam\q@u{a} k\q@u{a}na jaw\q@u{a}ba qawmihi ill\q@u{a} an q\q@u{a}loo itin\q@u{a} biAAa\q@u{tha}bi All\q@u{a}hi in kunta mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmccclxx{Q\q@u{a}la rabbi on\q@u{s}urnee AAal\q@u{a} alqawmi almufsideen\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmccclxxi{Walamm\q@u{a} j\q@u{a}at rusulun\q@u{a} ibr\q@u{a}heema bi\q@b{a}lbushr\q@u{a} q\q@u{a}loo inn\q@u{a} muhlikoo ahli h\q@u{ath}ihi alqaryati inna ahlah\q@u{a} k\q@u{a}noo \q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmccclxxii{Q\q@u{a}la inna feeh\q@u{a} loo\q@u{t}an q\q@u{a}loo na\q@u{h}nu aAAlamu biman feeh\q@u{a} lanunajjiyannahu waahlahu ill\q@u{a} imraatahu k\q@u{a}nat mina algh\q@u{a}bireen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmccclxxiii{Walamm\q@u{a} an j\q@u{a}at rusulun\q@u{a} loo\q@u{t}an seea bihim wa\q@u{da}qa bihim \q@u{th}arAAan waq\q@u{a}loo l\q@u{a} takhaf wal\q@u{a} ta\q@u{h}zan inn\q@u{a} munajjooka waahlaka ill\q@u{a} imraataka k\q@u{a}nat mina algh\q@u{a}bireen\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmccclxxiv{Inn\q@u{a} munziloona AAal\q@u{a} ahli h\q@u{ath}ihi alqaryati rijzan mina a\q@b{l}ssam\q@u{a}i bim\q@u{a} k\q@u{a}noo yafsuqoon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmccclxxv{Walaqad tarakn\q@u{a} minh\q@u{a} \q@u{a}yatan bayyinatan liqawmin yaAAqiloon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmccclxxvi{Wail\q@u{a} madyana akh\q@u{a}hum shuAAayban faq\q@u{a}la y\q@u{a} qawmi oAAbudoo All\q@u{a}ha wa\q@b{o}rjoo alyawma al\q@u{a}khira wal\q@u{a} taAAthaw fee alar\q@u{d}i mufsideen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmccclxxvii{Faka\q@u{thth}aboohu faakha\q@u{th}athumu a\q@b{l}rrajfatu faa\q@u{s}ba\q@u{h}oo fee d\q@u{a}rihim j\q@u{a}thimeen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmccclxxviii{WaAA\q@u{a}dan wathamooda waqad tabayyana lakum min mas\q@u{a}kinihim wazayyana lahumu a\q@b{l}shshay\q@u{ta}nu aAAm\q@u{a}lahum fa\q@u{s}addahum AAani a\q@b{l}ssabeeli wak\q@u{a}noo mustab\q@u{s}ireen\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmccclxxix{Waq\q@u{a}roona wafirAAawna wah\q@u{a}m\q@u{a}na walaqad j\q@u{a}ahum moos\q@u{a} bi\q@b{a}lbayyin\q@u{a}ti fa\q@b{i}stakbaroo fee alar\q@u{d}i wam\q@u{a} k\q@u{a}noo s\q@u{a}biqeen\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmccclxxx{Fakullan akha\q@u{th}n\q@u{a} bi\q@u{th}anbihi faminhum man arsaln\q@u{a} AAalayhi \q@u{has}iban waminhum man akha\q@u{th}athu a\q@b{l}\q@u{ss}ay\q@u{h}atu waminhum man khasafn\q@u{a} bihi alar\q@u{d}a waminhum man aghraqn\q@u{a} wam\q@u{a} k\q@u{a}na All\q@u{a}hu liya\q@i{\q@u{th}}limahum wal\q@u{a}kin k\q@u{a}noo anfusahum ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmccclxxxi{Mathalu alla\q@u{th}eena ittakha\q@u{th}oo min dooni All\q@u{a}hi awliy\q@u{a}a kamathali alAAankabooti ittakha\q@u{th}at baytan wainna awhana albuyooti labaytu alAAankabooti law k\q@u{a}noo yaAAlamoon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmccclxxxii{Inna All\q@u{a}ha yaAAlamu m\q@u{a} yadAAoona min doonihi min shayin wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmccclxxxiii{Watilka alamth\q@u{a}lu na\q@u{d}ribuh\q@u{a} li\q@b{l}nn\q@u{a}si wam\q@u{a} yaAAqiluh\q@u{a} ill\q@u{a} alAA\q@u{a}limoon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmccclxxxiv{Khalaqa All\q@u{a}hu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a bi\q@b{a}l\q@u{h}aqqi inna fee \q@u{tha}lika la\q@u{a}yatan lilmumineen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmccclxxxv{Otlu m\q@u{a} oo\q@u{h}iya ilayka mina alkit\q@u{a}bi waaqimi a\q@b{l}\q@u{ss}al\q@u{a}ta inna a\q@b{l}\q@u{ss}al\q@u{a}ta tanh\q@u{a} AAani alfa\q@u{h}sh\q@u{a}i wa\q@b{a}lmunkari wala\q@u{th}ikru All\q@u{a}hi akbaru wa\q@b{A}ll\q@u{a}hu yaAAlamu m\q@u{a} ta\q@u{s}naAAoon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmccclxxxvi{Wal\q@u{a} tuj\q@u{a}diloo ahla alkit\q@u{a}bi ill\q@u{a} bi\q@b{a}llatee hiya a\q@u{h}sanu ill\q@u{a} alla\q@u{th}eena \q@i{\q@u{th}}alamoo minhum waqooloo \q@u{a}mann\q@u{a} bi\q@b{a}lla\q@u{th}ee onzila ilayn\q@u{a} waonzila ilaykum wail\q@u{a}hun\q@u{a} wail\q@u{a}hukum w\q@u{ah}idun wana\q@u{h}nu lahu muslimoon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmccclxxxvii{Waka\q@u{tha}lika anzaln\q@u{a} ilayka alkit\q@u{a}ba fa\q@b{a}lla\q@u{th}eena \q@u{a}tayn\q@u{a}humu alkit\q@u{a}ba yuminoona bihi wamin h\q@u{a}ol\q@u{a}i man yuminu bihi wam\q@u{a} yaj\q@u{h}adu bi\q@u{a}y\q@u{a}tin\q@u{a} ill\q@u{a} alk\q@u{a}firoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmccclxxxviii{Wam\q@u{a} kunta tatloo min qablihi min kit\q@u{a}bin wal\q@u{a} takhu\q@u{tt}uhu biyameenika i\q@u{th}an la\q@b{i}rt\q@u{a}ba almub\q@u{t}iloon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmccclxxxix{Bal huwa \q@u{a}y\q@u{a}tun bayyin\q@u{a}tun fee \q@u{s}udoori alla\q@u{th}eena ootoo alAAilma wam\q@u{a} yaj\q@u{h}adu bi\q@u{a}y\q@u{a}tin\q@u{a} ill\q@u{a} a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmcccxc{Waq\q@u{a}loo lawl\q@u{a} onzila AAalayhi \q@u{a}y\q@u{a}tun min rabbihi qul innam\q@u{a} al\q@u{a}y\q@u{a}tu AAinda All\q@u{a}hi wainnam\q@u{a} an\q@u{a} na\q@u{th}eerun mubeen\q@b{un}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmcccxci{Awalam yakfihim ann\q@u{a} anzaln\q@u{a} AAalayka alkit\q@u{a}ba yutl\q@u{a} AAalayhim inna fee \q@u{tha}lika lara\q@u{h}matan wa\q@u{th}ikr\q@u{a} liqawmin yuminoon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmcccxcii{Qul kaf\q@u{a} bi\q@b{A}ll\q@u{a}hi baynee wabaynakum shaheedan yaAAlamu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo bi\q@b{a}lb\q@u{at}ili wakafaroo bi\q@b{A}ll\q@u{a}hi ol\q@u{a}ika humu alkh\q@u{a}siroon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmcccxciii{WayastaAAjiloonaka bi\q@b{a}lAAa\q@u{tha}bi walawl\q@u{a} ajalun musamman laj\q@u{a}ahumu alAAa\q@u{tha}bu walayatiyannahum baghtatan wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmcccxciv{YastaAAjiloonaka bi\q@b{a}lAAa\q@u{tha}bi wainna jahannama lamu\q@u{h}ee\q@u{t}atun bi\q@b{a}lk\q@u{a}fireen\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmcccxcv{Yawma yaghsh\q@u{a}humu alAAa\q@u{tha}bu min fawqihim wamin ta\q@u{h}ti arjulihim wayaqoolu \q@u{th}ooqoo m\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmcccxcvi{Y\q@u{a} AAib\q@u{a}diya alla\q@u{th}eena \q@u{a}manoo inna ar\q@u{d}ee w\q@u{a}siAAatun faiyy\q@u{a}ya fa\q@b{o}AAbudoon\q@b{i}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmcccxcvii{Kullu nafsin \q@u{tha}iqatu almawti thumma ilayn\q@u{a} turjaAAoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmcccxcviii{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lanubawwiannahum mina aljannati ghurafan tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} niAAma ajru alAA\q@u{a}mileen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmcccxcix{Alla\q@u{th}eena \q@u{s}abaroo waAAal\q@u{a} rabbihim yatawakkaloon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmcd{Wakaayyin min d\q@u{a}bbatin l\q@u{a} ta\q@u{h}milu rizqah\q@u{a} All\q@u{a}hu yarzuquh\q@u{a} waiyy\q@u{a}kum wahuwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmcdi{Walain saaltahum man khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wasakhkhara a\q@b{l}shshamsa wa\q@b{a}lqamara layaqoolunna All\q@u{a}hu faann\q@u{a} yufakoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmcdii{All\q@u{a}hu yabsu\q@u{t}u a\q@b{l}rrizqa liman yash\q@u{a}o min AAib\q@u{a}dihi wayaqdiru lahu inna All\q@u{a}ha bikulli shayin AAaleem\q@b{un}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmcdiii{Walain saaltahum man nazzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faa\q@u{h}y\q@u{a} bihi alar\q@u{d}a min baAAdi mawtih\q@u{a} layaqoolunna All\q@u{a}hu quli al\q@u{h}amdu lill\q@u{a}hi bal aktharuhum l\q@u{a} yaAAqiloon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmcdiv{Wam\q@u{a} h\q@u{ath}ihi al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} ill\q@u{a} lahwun walaAAibun wainna a\q@b{l}dd\q@u{a}ra al\q@u{a}khirata lahiya al\q@u{h}ayaw\q@u{a}nu law k\q@u{a}noo yaAAlamoon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmcdv{Fai\q@u{tha} rakiboo fee alfulki daAAawoo All\q@u{a}ha mukhli\q@u{s}eena lahu a\q@b{l}ddeena falamm\q@u{a} najj\q@u{a}hum il\q@u{a} albarri i\q@u{tha} hum yushrikoon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmcdvi{Liyakfuroo bim\q@u{a} \q@u{a}tayn\q@u{a}hum waliyatamattaAAoo fasawfa yaAAlamoon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmcdvii{Awalam yaraw ann\q@u{a} jaAAaln\q@u{a} \q@u{h}araman \q@u{a}minan wayutakha\q@u{tt}afu a\q@b{l}nn\q@u{a}su min \q@u{h}awlihim afabi\q@b{a}lb\q@u{at}ili yuminoona wabiniAAmati All\q@u{a}hi yakfuroon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmcdviii{Waman a\q@i{\q@u{th}}lamu mimmani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban aw ka\q@u{thth}aba bi\q@b{a}l\q@u{h}aqqi lamm\q@u{a} j\q@u{a}ahu alaysa fee jahannama mathwan lilk\q@u{a}fireen\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmcdix{Wa\q@b{a}lla\q@u{th}eena j\q@u{a}hadoo feen\q@u{a} lanahdiyannahum subulan\q@u{a} wainna All\q@u{a}ha lamaAAa almu\q@u{h}sineen\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmcdx{\basmalahlt Alifl\q@u{a}mmeem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmcdxi{Ghulibati a\q@b{l}rroom\q@b{u}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmcdxii{Fee adn\q@u{a} alar\q@u{d}i wahum min baAAdi ghalabihim sayaghliboon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmcdxiii{Fee bi\q@u{d}AAi sineena lill\q@u{a}hi alamru min qablu wamin baAAdu wayawmai\q@u{th}in yafra\q@u{h}u almuminoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmcdxiv{Bina\q@u{s}ri All\q@u{a}hi yan\q@u{s}uru man yash\q@u{a}o wahuwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmcdxv{WaAAda All\q@u{a}hi l\q@u{a} yukhlifu All\q@u{a}hu waAAdahu wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmcdxvi{YaAAlamoona \q@i{\q@u{th}}\q@u{a}hiran mina al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wahum AAani al\q@u{a}khirati hum gh\q@u{a}filoon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmcdxvii{Awalam yatafakkaroo fee anfusihim m\q@u{a} khalaqa All\q@u{a}hu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wam\q@u{a} baynahum\q@u{a} ill\q@u{a} bi\q@b{a}l\q@u{h}aqqi waajalin musamman wainna katheeran mina a\q@b{l}nn\q@u{a}si biliq\q@u{a}i rabbihim lak\q@u{a}firoon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmcdxviii{Awalam yaseeroo fee alar\q@u{d}i fayan\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu alla\q@u{th}eena min qablihim k\q@u{a}noo ashadda minhum quwwatan waath\q@u{a}roo alar\q@u{d}a waAAamarooh\q@u{a} akthara mimm\q@u{a} AAamarooh\q@u{a} waj\q@u{a}athum rusuluhum bi\q@b{a}lbayyin\q@u{a}ti fam\q@u{a} k\q@u{a}na All\q@u{a}hu liya\q@i{\q@u{th}}limahum wal\q@u{a}kin k\q@u{a}noo anfusahum ya\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmcdxix{Thumma k\q@u{a}na AA\q@u{a}qibata alla\q@u{th}eena as\q@u{a}oo a\q@b{l}ssoo\q@u{a} an ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}ti All\q@u{a}hi wak\q@u{a}noo bih\q@u{a} yastahzioon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmcdxx{All\q@u{a}hu yabdao alkhalqa thumma yuAAeeduhu thumma ilayhi turjaAAoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmcdxxi{Wayawma taqoomu a\q@b{l}ss\q@u{a}AAatu yublisu almujrimoon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmcdxxii{Walam yakun lahum min shurak\q@u{a}ihim shufaAA\q@u{a}o wak\q@u{a}noo bishurak\q@u{a}ihim k\q@u{a}fireen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmcdxxiii{Wayawma taqoomu a\q@b{l}ss\q@u{a}AAatu yawmai\q@u{th}in yatafarraqoon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmcdxxiv{Faamm\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti fahum fee raw\q@u{d}atin yu\q@u{h}baroon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmcdxxv{Waamm\q@u{a} alla\q@u{th}eena kafaroo waka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} waliq\q@u{a}i al\q@u{a}khirati faol\q@u{a}ika fee alAAa\q@u{tha}bi mu\q@u{hd}aroon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmcdxxvi{Fasub\q@u{ha}na All\q@u{a}hi \q@u{h}eena tumsoona wa\q@u{h}eena tu\q@u{s}bi\q@u{h}oon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmcdxxvii{Walahu al\q@u{h}amdu fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i waAAashiyyan wa\q@u{h}eena tu\q@i{\q@u{th}}hiroon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmcdxxviii{Yukhriju al\q@u{h}ayya mina almayyiti wayukhriju almayyita mina al\q@u{h}ayyi wayu\q@u{h}yee alar\q@u{d}a baAAda mawtih\q@u{a} waka\q@u{tha}lika tukhrajoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmcdxxix{Wamin \q@u{a}y\q@u{a}tihi an khalaqakum min tur\q@u{a}bin thumma i\q@u{tha} antum basharun tantashiroon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmcdxxx{Wamin \q@u{a}y\q@u{a}tihi an khalaqa lakum min anfusikum azw\q@u{a}jan litaskunoo ilayh\q@u{a} wajaAAala baynakum mawaddatan wara\q@u{h}matan inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yatafakkaroon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmcdxxxi{Wamin \q@u{a}y\q@u{a}tihi khalqu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{i}khtil\q@u{a}fu alsinatikum waalw\q@u{a}nikum inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin lilAA\q@u{a}limeen\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmcdxxxii{Wamin \q@u{a}y\q@u{a}tihi man\q@u{a}mukum bi\q@b{a}llayli wa\q@b{al}nnah\q@u{a}ri wa\q@b{i}btigh\q@u{a}okum min fa\q@u{d}lihi inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yasmaAAoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmcdxxxiii{Wamin \q@u{a}y\q@u{a}tihi yureekumu albarqa khawfan wa\q@u{t}amaAAan wayunazzilu mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an fayu\q@u{h}yee bihi alar\q@u{d}a baAAda mawtih\q@u{a} inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yaAAqiloon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmcdxxxiv{Wamin \q@u{a}y\q@u{a}tihi an taqooma a\q@b{l}ssam\q@u{a}o wa\q@b{a}lar\q@u{d}u biamrihi thumma i\q@u{tha} daAA\q@u{a}kum daAAwatan mina alar\q@u{d}i i\q@u{tha} antum takhrujoon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmcdxxxv{Walahu man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i kullun lahu q\q@u{a}nitoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmcdxxxvi{Wahuwa alla\q@u{th}ee yabdao alkhalqa thumma yuAAeeduhu wahuwa ahwanu AAalayhi walahu almathalu alaAAl\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmcdxxxvii{\q@u{D}araba lakum mathalan min anfusikum hal lakum mi mm\q@u{a} malakat aym\q@u{a}nukum min shurak\q@u{a}a fee m\q@u{a} razaqn\q@u{a}kum faantum feehi saw\q@u{a}on takh\q@u{a}foonahum kakheefatikum anfusakum ka\q@u{tha}lika nufa\q@u{ss}ilu al\q@u{a}y\q@u{a}ti liqawmin yaAAqiloon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmcdxxxviii{Bali ittabaAAa alla\q@u{th}eena \q@i{\q@u{th}}alamoo ahw\q@u{a}ahum bighayri AAilmin faman yahdee man a\q@u{d}alla All\q@u{a}hu wam\q@u{a} lahum min n\q@u{as}ireen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmcdxxxix{Faaqim wajhaka li\q@b{l}ddeeni \q@u{h}aneefan fi\q@u{t}rata All\q@u{a}hi allatee fa\q@u{t}ara a\q@b{l}nn\q@u{a}sa AAalayh\q@u{a} l\q@u{a} tabdeela likhalqi All\q@u{a}hi \q@u{tha}lika a\q@b{l}ddeenu alqayyimu wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmcdxl{Muneebeena ilayhi wa\q@b{i}ttaqoohu waaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wal\q@u{a} takoonoo mina almushrikeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmcdxli{Mina alla\q@u{th}eena farraqoo deenahum wak\q@u{a}noo shiyaAAan kullu \q@u{h}izbin bim\q@u{a} ladayhim fari\q@u{h}oon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmcdxlii{Wai\q@u{tha} massa a\q@b{l}nn\q@u{a}sa \q@u{d}urrun daAAaw rabbahum muneebeena ilayhi thumma i\q@u{tha} a\q@u{tha}qahum minhu ra\q@u{h}matan i\q@u{tha} fareequn minhum birabbihim yushrikoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmcdxliii{Liyakfuroo bim\q@u{a} \q@u{a}tayn\q@u{a}hum fatamattaAAoo fasawfa taAAlamoon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmcdxliv{Am anzaln\q@u{a} AAalayhim sul\q@u{ta}nan fahuwa yatakallamu bim\q@u{a} k\q@u{a}noo bihi yushrikoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmcdxlv{Wa\q@b{i}\q@u{tha} a\q@u{th}aqn\q@u{a} a\q@b{l}nn\q@u{a}sa ra\q@u{h}matan fari\q@u{h}oo bih\q@u{a} wain tu\q@u{s}ibhum sayyiatun bim\q@u{a} qaddamat aydeehim i\q@u{tha} hum yaqna\q@u{t}oon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmcdxlvi{Awalam yaraw anna All\q@u{a}ha yabsu\q@u{t}u a\q@b{l}rrizqa liman yash\q@u{a}o wayaqdiru inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yuminoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmcdxlvii{Fa\q@u{a}ti \q@u{tha} alqurb\q@u{a} \q@u{h}aqqahu wa\q@b{a}lmiskeena wa\q@b{i}bna a\q@b{l}ssabeeli \q@u{tha}lika khayrun lilla\q@u{th}eena yureedoona wajha All\q@u{a}hi waol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmcdxlviii{Wam\q@u{a} \q@u{a}taytum min riban liyarbuwa fee amw\q@u{a}li a\q@b{l}nn\q@u{a}si fal\q@u{a} yarboo AAinda All\q@u{a}hi wam\q@u{a} \q@u{a}taytum min zak\q@u{a}tin tureedoona wajha All\q@u{a}hi faol\q@u{a}ika humu almu\q@u{d}AAifoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmcdxlix{All\q@u{a}hu alla\q@u{th}ee khalaqakum thumma razaqakum thumma yumeetukum thumma yu\q@u{h}yeekum hal min shurak\q@u{a}ikum man yafAAalu min \q@u{tha}likum min shayin sub\q@u{ha}nahu wataAA\q@u{a}l\q@u{a} AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmcdl{\q@i{\q@u{Th}}ahara alfas\q@u{a}du fee albarri wa\q@b{a}lba\q@u{h}ri bim\q@u{a} kasabat aydee a\q@b{l}nn\q@u{a}si liyu\q@u{th}eeqahum baAA\q@u{d}a alla\q@u{th}ee AAamiloo laAAallahum yarjiAAoon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmcdli{Qul seeroo fee alar\q@u{d}i fa\q@b{o}n\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu alla\q@u{th}eena min qablu k\q@u{a}na aktharuhum mushrikeen\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmcdlii{Faaqim wajhaka li\q@b{l}ddeeni alqayyimi min qabli an yatiya yawmun l\q@u{a} maradda lahu mina All\q@u{a}hi yawmai\q@u{th}in ya\q@u{ss}addaAAoon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmcdliii{Man kafara faAAalayhi kufruhu waman AAamila \q@u{sa}li\q@u{h}an falianfusihim yamhadoon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmcdliv{Liyajziya alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti min fa\q@u{d}lihi innahu l\q@u{a} yu\q@u{h}ibbu alk\q@u{a}fireen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmcdlv{Wamin \q@u{a}y\q@u{a}tihi an yursila a\q@b{l}rriy\q@u{ah}a mubashshir\q@u{a}tin waliyu\q@u{th}eeqakum min ra\q@u{h}matihi walitajriya alfulku biamrihi walitabtaghoo min fa\q@u{d}lihi walaAAallakum tashkuroon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmcdlvi{Walaqad arsaln\q@u{a} min qablika rusulan il\q@u{a} qawmihim faj\q@u{a}oohum bi\q@b{a}lbayyin\q@u{a}ti fa\q@b{i}ntaqamn\q@u{a} mina alla\q@u{th}eena ajramoo wak\q@u{a}na \q@u{h}aqqan AAalayn\q@u{a} na\q@u{s}ru almumineen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmcdlvii{All\q@u{a}hu alla\q@u{th}ee yursilu a\q@b{l}rriy\q@u{ah}a fatutheeru sa\q@u{ha}ban fayabsu\q@u{t}uhu fee a\q@b{l}ssam\q@u{a}i kayfa yash\q@u{a}o wayajAAaluhu kisafan fatar\q@u{a} alwadqa yakhruju min khil\q@u{a}lihi fai\q@u{tha} a\q@u{sa}ba bihi man yash\q@u{a}o min AAib\q@u{a}dihi i\q@u{tha} hum yastabshiroon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmcdlviii{Wain k\q@u{a}noo min qabli an yunazzala AAalayhim min qablihi lamubliseen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmcdlix{Fa\q@b{o}n\q@i{\q@u{th}}ur il\q@u{a} \q@u{a}th\q@u{a}ri ra\q@u{h}mati All\q@u{a}hi kayfa yu\q@u{h}yee alar\q@u{d}a baAAda mawtih\q@u{a} inna \q@u{tha}lika lamu\q@u{h}yee almawt\q@u{a} wahuwa AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmcdlx{Walain arsaln\q@u{a} ree\q@u{h}an faraawhu mu\q@u{s}farran la\q@i{\q@u{th}}alloo min baAAdihi yakfuroon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmcdlxi{Fainnaka l\q@u{a} tusmiAAu almawt\q@u{a} wal\q@u{a} tusmiAAu a\q@b{l}\q@u{ss}umma a\q@b{l}dduAA\q@u{a}a i\q@u{tha} wallaw mudbireen\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmcdlxii{Wam\q@u{a} anta bih\q@u{a}di alAAumyi AAan \q@u{d}al\q@u{a}latihim in tusmiAAu ill\q@u{a} man yuminu bi\q@u{a}y\q@u{a}tin\q@u{a} fahum muslimoon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmcdlxiii{All\q@u{a}hu alla\q@u{th}ee khalaqakum min \q@u{d}aAAfin thumma jaAAala min baAAdi \q@u{d}aAAfin quwwatan thumma jaAAala min baAAdi quwwatin \q@u{d}aAAfan washaybatan yakhluqu m\q@u{a} yash\q@u{a}o wahuwa alAAaleemu alqadeer\q@b{u}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmcdlxiv{Wayawma taqoomu a\q@b{l}ss\q@u{a}AAatu yuqsimu almujrimoona m\q@u{a} labithoo ghayra s\q@u{a}AAatin ka\q@u{tha}lika k\q@u{a}noo yufakoon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmcdlxv{Waq\q@u{a}la alla\q@u{th}eena ootoo alAAilma wa\q@b{a}leem\q@u{a}na laqad labithtum fee kit\q@u{a}bi All\q@u{a}hi il\q@u{a} yawmi albaAAthi fah\q@u{atha} yawmu albaAAthi wal\q@u{a}kinnakum kuntum l\q@u{a} taAAlamoon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmcdlxvi{Fayawmai\q@u{th}in l\q@u{a} yanfaAAu alla\q@u{th}eena \q@i{\q@u{th}}alamoo maAA\q@u{th}iratuhum wal\q@u{a} hum yustaAAtaboon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmcdlxvii{Walaqad \q@u{d}arabn\q@u{a} li\q@b{l}nn\q@u{a}si fee h\q@u{atha} alqur\q@u{a}ni min kulli mathalin walain jitahum bi\q@u{a}yatin layaqoolanna alla\q@u{th}eena kafaroo in antum ill\q@u{a} mub\q@u{t}iloon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmcdlxviii{Ka\q@u{tha}lika ya\q@u{t}baAAu All\q@u{a}hu AAal\q@u{a} quloobi alla\q@u{th}eena l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmcdlxix{Fa\q@b{i}\q@u{s}bir inna waAAda All\q@u{a}hi \q@u{h}aqqun wal\q@u{a} yastakhiffannaka alla\q@u{th}eena l\q@u{a} yooqinoon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmcdlxx{\basmalahlt Alifl\q@u{a}mmeem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxi{Tilka \q@u{a}y\q@u{a}tu alkit\q@u{a}bi al\q@u{h}akeem\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxii{Hudan wara\q@u{h}matan lilmu\q@u{h}sineen\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxiii{Alla\q@u{th}eena yuqeemoona a\q@b{l}\q@u{ss}al\q@u{a}ta wayutoona a\q@b{l}zzak\q@u{a}ta wahum bi\q@b{a}l\q@u{a}khirati hum yooqinoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxiv{Ol\q@u{a}ika AAal\q@u{a} hudan min rabbihim waol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxv{Wamina a\q@b{l}nn\q@u{a}si man yashtaree lahwa al\q@u{h}adeethi liyu\q@u{d}illa AAan sabeeli All\q@u{a}hi bighayri AAilmin wayattakhi\q@u{th}ah\q@u{a} huzuwan ol\q@u{a}ika lahum AAa\q@u{tha}bun muheen\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxvi{Wai\q@u{tha} tutl\q@u{a} AAalayhi \q@u{a}y\q@u{a}tun\q@u{a} wall\q@u{a} mustakbiran kaan lam yasmaAAh\q@u{a} kaanna fee o\q@u{th}unayhi waqran fabashshirhu biAAa\q@u{tha}bin aleem\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxvii{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lahum jann\q@u{a}tu a\q@b{l}nnaAAeem\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxviii{Kh\q@u{a}lideena feeh\q@u{a} waAAda All\q@u{a}hi \q@u{h}aqqan wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxix{Khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti bighayri AAamadin tarawnah\q@u{a} waalq\q@u{a} fee alar\q@u{d}i raw\q@u{a}siya an tameeda bikum wabaththa feeh\q@u{a} min kulli d\q@u{a}bbatin waanzaln\q@u{a} mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faanbatn\q@u{a} feeh\q@u{a} min kulli zawjin kareem\q@b{in}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxx{H\q@u{atha} khalqu All\q@u{a}hi faaroonee m\q@u{atha} khalaqa alla\q@u{th}eena min doonihi bali a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoona fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxxi{Walaqad \q@u{a}tayn\q@u{a} luqm\q@u{a}na al\q@u{h}ikmata ani oshkur lill\q@u{a}hi waman yashkur fainnam\q@u{a} yashkuru linafsihi waman kafara fainna All\q@u{a}ha ghaniyyun \q@u{h}ameed\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxxii{Wai\q@u{th} q\q@u{a}la luqm\q@u{a}nu li\q@b{i}bnihi wahuwa yaAAi\q@i{\q@u{th}}uhu y\q@u{a} bunayya l\q@u{a} tushrik bi\q@b{A}ll\q@u{a}hi inna a\q@b{l}shshirka la\q@i{\q@u{th}}ulmun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxxiii{Wawa\q@u{ss}ayn\q@u{a} alins\q@u{a}na biw\q@u{a}lidayhi \q@u{h}amalathu ommuhu wahnan AAal\q@u{a} wahnin wafi\q@u{sa}luhu fee AA\q@u{a}mayni ani oshkur lee waliw\q@u{a}lidayka ilayya alma\q@u{s}eer\q@b{u}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxxiv{Wain j\q@u{a}had\q@u{a}ka AAal\q@u{a} an tushrika bee m\q@u{a} laysa laka bihi AAilmun fal\q@u{a} tu\q@u{t}iAAhum\q@u{a} wa\q@u{sah}ibhum\q@u{a} fee a\q@b{l}dduny\q@u{a} maAAroofan wa\q@b{i}ttabiAA sabeela man an\q@u{a}ba ilayya thumma ilayya marjiAAukum faonabbiokum bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxxv{Y\q@u{a} bunayya innah\q@u{a} in taku mithq\q@u{a}la \q@u{h}abbatin min khardalin fatakun fee \q@u{s}akhratin aw fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti aw fee alar\q@u{d}i yati bih\q@u{a} All\q@u{a}hu inna All\q@u{a}ha la\q@u{t}eefun khabeer\q@b{un}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxxvi{Y\q@u{a} bunayya aqimi a\q@b{l}\q@u{ss}al\q@u{a}ta wamur bi\q@b{a}lmaAAroofi wa\q@b{i}nha AAani almunkari wa\q@b{i}\q@u{s}bir AAal\q@u{a} m\q@u{a} a\q@u{sa}baka inna \q@u{tha}lika min AAazmi alomoor\q@b{i}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxxvii{Wal\q@u{a} tu\q@u{s}aAAAAir khaddaka li\q@b{l}nn\q@u{a}si wal\q@u{a} tamshi fee alar\q@u{d}i mara\q@u{h}an inna All\q@u{a}ha l\q@u{a} yu\q@u{h}ibbu kulla mukht\q@u{a}lin fakhoor\q@b{in}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxxviii{Wa\q@b{i}q\q@u{s}id fee mashyika wa\q@b{o}gh\q@u{d}u\q@u{d} min \q@u{s}awtika inna ankara ala\q@u{s}w\q@u{a}ti la\q@u{s}awtu al\q@u{h}ameer\q@b{i}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmcdlxxxix{Alam taraw anna All\q@u{a}ha sakhkhara lakum m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i waasbagha AAalaykum niAAamahu \q@i{\q@u{th}}\q@u{a}hiratan wab\q@u{at}inatan wamina a\q@b{l}nn\q@u{a}si man yuj\q@u{a}dilu fee All\q@u{a}hi bighayri AAilmin wal\q@u{a} hudan wal\q@u{a} kit\q@u{a}bin muneer\q@b{in}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmcdxc{Wai\q@u{tha} qeela lahumu ittabiAAoo m\q@u{a} anzala All\q@u{a}hu q\q@u{a}loo bal nattabiAAu m\q@u{a} wajadn\q@u{a} AAalayhi \q@u{a}b\q@u{a}an\q@u{a} awalaw k\q@u{a}na a\q@b{l}shshay\q@u{ta}nu yadAAoohum il\q@u{a} AAa\q@u{tha}bi a\q@b{l}ssaAAeer\q@b{i}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmcdxci{Waman yuslim wajhahu il\q@u{a} All\q@u{a}hi wahuwa mu\q@u{h}sinun faqadi istamsaka bi\q@b{a}lAAurwati alwuthq\q@u{a} wail\q@u{a} All\q@u{a}hi AA\q@u{a}qibatu alomoor\q@b{i}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmcdxcii{Waman kafara fal\q@u{a} ya\q@u{h}zunka kufruhu ilayn\q@u{a} marjiAAuhum fanunabbiohum bim\q@u{a} AAamiloo inna All\q@u{a}ha AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmcdxciii{NumattiAAuhum qaleelan thumma na\q@u{dt}arruhum il\q@u{a} AAa\q@u{tha}bin ghalee\q@i{\q@u{th}}\q@b{in}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmcdxciv{Walain saaltahum man khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a layaqoolunna All\q@u{a}hu quli al\q@u{h}amdu lill\q@u{a}hi bal aktharuhum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmcdxcv{Lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i inna All\q@u{a}ha huwa alghaniyyu al\q@u{h}ameed\q@b{u}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmcdxcvi{Walaw annam\q@u{a} fee alar\q@u{d}i min shajaratin aql\q@u{a}mun wa\q@b{a}lba\q@u{h}ru yamudduhu min baAAdihi sabAAatu ab\q@u{h}urin m\q@u{a} nafidat kalim\q@u{a}tu All\q@u{a}hi inna All\q@u{a}ha AAazeezun \q@u{h}akeem\q@b{un}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmcdxcvii{M\q@u{a} khalqukum wal\q@u{a} baAAthukum ill\q@u{a} kanafsin w\q@u{ah}idatin inna All\q@u{a}ha sameeAAun ba\q@u{s}eer\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmcdxcviii{Alam tara anna All\q@u{a}ha yooliju allayla fee a\q@b{l}nnah\q@u{a}ri wayooliju a\q@b{l}nnah\q@u{a}ra fee allayli wasakhkhara a\q@b{l}shshamsa wa\q@b{a}lqamara kullun yajree il\q@u{a} ajalin musamman waanna All\q@u{a}ha bim\q@u{a} taAAmaloona khabeer\q@b{un}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmcdxcix{\q@u{Tha}lika bianna All\q@u{a}ha huwa al\q@u{h}aqqu waanna m\q@u{a} yadAAoona min doonihi alb\q@u{at}ilu waanna All\q@u{a}ha huwa alAAaliyyu alkabeer\q@b{u}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmd{Alam tara anna alfulka tajree fee alba\q@u{h}ri biniAAmati All\q@u{a}hi liyuriyakum min \q@u{a}y\q@u{a}tihi inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin likulli \q@u{s}abb\q@u{a}rin shakoor\q@b{in}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmdi{Wai\q@u{tha} ghashiyahum mawjun ka\q@b{al}\q@i{\q@u{thth}}ulali daAAawoo All\q@u{a}ha mukhli\q@u{s}eena lahu a\q@b{l}ddeena falamm\q@u{a} najj\q@u{a}hum il\q@u{a} albarri faminhum muqta\q@u{s}idun wam\q@u{a} yaj\q@u{h}adu bi\q@u{a}y\q@u{a}tin\q@u{a} ill\q@u{a} kullu khatt\q@u{a}rin kafoor\q@b{in}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmdii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su ittaqoo rabbakum wa\q@b{i}khshaw yawman l\q@u{a} yajzee w\q@u{a}lidun AAan waladihi wal\q@u{a} mawloodun huwa j\q@u{a}zin AAan w\q@u{a}lidihi shayan inna waAAda All\q@u{a}hi \q@u{h}aqqun fal\q@u{a} taghurrannakumu al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} wal\q@u{a} yaghurrannakum bi\q@b{A}ll\q@u{a}hi algharoor\q@b{u}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmdiii{Inna All\q@u{a}ha AAindahu AAilmu a\q@b{l}ss\q@u{a}AAati wayunazzilu alghaytha wayaAAlamu m\q@u{a} fee alar\q@u{ha}mi wam\q@u{a} tadree nafsun m\q@u{atha} taksibu ghadan wam\q@u{a} tadree nafsun biayyi ar\q@u{d}in tamootu inna All\q@u{a}ha AAaleemun khabeer\q@b{un}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmdiv{\basmalahlt Alifl\q@u{a}mmeem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmdv{Tanzeelu alkit\q@u{a}bi l\q@u{a} rayba feehi min rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmdvi{Am yaqooloona iftar\q@u{a}hu bal huwa al\q@u{h}aqqu min rabbika litun\q@u{th}ira qawman m\q@u{a} at\q@u{a}hum min na\q@u{th}eerin min qablika laAAallahum yahtadoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmdvii{All\q@u{a}hu alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wam\q@u{a} baynahum\q@u{a} fee sittati ayy\q@u{a}min thumma istaw\q@u{a} AAal\q@u{a} alAAarshi m\q@u{a} lakum min doonihi min waliyyin wal\q@u{a} shafeeAAin afal\q@u{a} tata\q@u{th}akkaroon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmdviii{Yudabbiru alamra mina a\q@b{l}ssam\q@u{a}i il\q@u{a} alar\q@u{d}i thumma yaAAruju ilayhi fee yawmin k\q@u{a}na miqd\q@u{a}ruhu alfa sanatin mimm\q@u{a} taAAuddoon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmdix{\q@u{Tha}lika AA\q@u{a}limu alghaybi wa\q@b{al}shshah\q@u{a}dati alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmdx{Alla\q@u{th}ee a\q@u{h}sana kulla shayin khalaqahu wabadaa khalqa alins\q@u{a}ni min \q@u{t}een\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmdxi{Thumma jaAAala naslahu min sul\q@u{a}latin min m\q@u{a}in maheen\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmdxii{Thumma saww\q@u{a}hu wanafakha feehi min roo\q@u{h}ihi wajaAAala lakumu a\q@b{l}ssamAAa wa\q@b{a}lab\q@u{sa}ra wa\q@b{a}lafidata qaleelan m\q@u{a} tashkuroon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmdxiii{Waq\q@u{a}loo ai\q@u{tha} \q@u{d}al\q@u{a}ln\q@u{a} fee alar\q@u{d}i ainn\q@u{a} lafee khalqin jadeedin bal hum biliq\q@u{a}i rabbihim k\q@u{a}firoon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmdxiv{Qul yatawaff\q@u{a}kum malaku almawti alla\q@u{th}ee wukkila bikum thumma il\q@u{a} rabbikum turjaAAoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmdxv{Walaw tar\q@u{a} i\q@u{th}i almujrimoona n\q@u{a}kisoo ruoosihim AAinda rabbihim rabban\q@u{a} ab\q@u{s}arn\q@u{a} wasamiAAn\q@u{a} faarjiAAn\q@u{a} naAAmal \q@u{sa}li\q@u{h}an inn\q@u{a} mooqinoon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmdxvi{Walaw shin\q@u{a} la\q@u{a}tayn\q@u{a} kulla nafsin hud\q@u{a}h\q@u{a} wal\q@u{a}kin \q@u{h}aqqa alqawlu minnee laamlaanna jahannama mina aljinnati wa\q@b{al}nn\q@u{a}si ajmaAAeen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmdxvii{Fa\q@u{th}ooqoo bim\q@u{a} naseetum liq\q@u{a}a yawmikum h\q@u{atha} inn\q@u{a} naseen\q@u{a}kum wa\q@u{th}ooqoo AAa\q@u{tha}ba alkhuldi bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmdxviii{Innam\q@u{a} yuminu bi\q@u{a}y\q@u{a}tin\q@u{a} alla\q@u{th}eena i\q@u{tha} \q@u{th}ukkiroo bih\q@u{a} kharroo sujjadan wasabba\q@u{h}oo bi\q@u{h}amdi rabbihim wahum l\q@u{a} yastakbiroon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmdxix{Tataj\q@u{a}f\q@u{a} junoobuhum AAani alma\q@u{da}jiAAi yadAAoona rabbahum khawfan wa\q@u{t}amaAAan wamimm\q@u{a} razaqn\q@u{a}hum yunfiqoon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmdxx{Fal\q@u{a} taAAlamu nafsun m\q@u{a} okhfiya lahum min qurrati aAAyunin jaz\q@u{a}an bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmdxxi{Afaman k\q@u{a}na muminan kaman k\q@u{a}na f\q@u{a}siqan l\q@u{a} yastawoon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmdxxii{Amm\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti falahum jann\q@u{a}tu almaw\q@u{a} nuzulan bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmdxxiii{Waamm\q@u{a} alla\q@u{th}eena fasaqoo famaw\q@u{a}humu a\q@b{l}nn\q@u{a}ru kullam\q@u{a} ar\q@u{a}doo an yakhrujoo minh\q@u{a} oAAeedoo feeh\q@u{a} waqeela lahum \q@u{th}ooqoo AAa\q@u{tha}ba a\q@b{l}nn\q@u{a}ri alla\q@u{th}ee kuntum bihi tuka\q@u{thth}iboon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmdxxiv{Walanu\q@u{th}eeqannahum mina alAAa\q@u{tha}bi aladn\q@u{a} doona alAAa\q@u{tha}bi alakbari laAAallahum yarjiAAoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmdxxv{Waman a\q@i{\q@u{th}}lamu mimman \q@u{th}ukkira bi\q@u{a}y\q@u{a}ti rabbihi thumma aAAra\q@u{d}a AAanh\q@u{a} inn\q@u{a} mina almujrimeena muntaqimoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmdxxvi{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba fal\q@u{a} takun fee miryatin min liq\q@u{a}ihi wajaAAaln\q@u{a}hu hudan libanee isr\q@u{a}eel\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmdxxvii{WajaAAaln\q@u{a} minhum aimmatan yahdoona biamrin\q@u{a} lamm\q@u{a} \q@u{s}abaroo wak\q@u{a}noo bi\q@u{a}y\q@u{a}tin\q@u{a} yooqinoon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmdxxviii{Inna rabbaka huwa yaf\q@u{s}ilu baynahum yawma alqiy\q@u{a}mati feem\q@u{a} k\q@u{a}noo feehi yakhtalifoon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmdxxix{Awalam yahdi lahum kam ahlakn\q@u{a} min qablihim mina alqurooni yamshoona fee mas\q@u{a}kinihim inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin afal\q@u{a} yasmaAAoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmdxxx{Awalam yaraw ann\q@u{a} nasooqu alm\q@u{a}a il\q@u{a} alar\q@u{d}i aljuruzi fanukhriju bihi zarAAan takulu minhu anAA\q@u{a}muhum waanfusuhum afal\q@u{a} yub\q@u{s}iroon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmdxxxi{Wayaqooloona mat\q@u{a} h\q@u{atha} alfat\q@u{h}u in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmdxxxii{Qul yawma alfat\q@u{h}i l\q@u{a} yanfaAAu alla\q@u{th}eena kafaroo eem\q@u{a}nuhum wal\q@u{a} hum yun\q@i{\q@u{th}}aroon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmdxxxiii{FaaAAri\q@u{d} AAanhum wa\q@b{i}nta\q@i{\q@u{th}}ir innahum munta\q@i{\q@u{th}}iroon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmdxxxiv{\basmalahlt Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu ittaqi All\q@u{a}ha wal\q@u{a} tu\q@u{t}iAAi alk\q@u{a}fireena wa\q@b{a}lmun\q@u{a}fiqeena inna All\q@u{a}ha k\q@u{a}na AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmdxxxv{Wa\q@b{i}ttabiAA m\q@u{a} yoo\q@u{ha} ilayka min rabbika inna All\q@u{a}ha k\q@u{a}na bim\q@u{a} taAAmaloona khabeer\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmdxxxvi{Watawakkal AAal\q@u{a} All\q@u{a}hi wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi wakeel\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmdxxxvii{M\q@u{a} jaAAala All\q@u{a}hu lirajulin min qalbayni fee jawfihi wam\q@u{a} jaAAala azw\q@u{a}jakumu all\q@u{a}ee tu\q@i{\q@u{th}}\q@u{a}hiroona minhunna ommah\q@u{a}tikum wam\q@u{a} jaAAala adAAiy\q@u{a}akum abn\q@u{a}akum \q@u{tha}likum qawlukum biafw\q@u{a}hikum wa\q@b{A}ll\q@u{a}hu yaqoolu al\q@u{h}aqqa wahuwa yahdee a\q@b{l}ssabeel\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmdxxxviii{OdAAoohum li\q@u{a}b\q@u{a}ihim huwa aqsa\q@u{t}u AAinda All\q@u{a}hi fain lam taAAlamoo \q@u{a}b\q@u{a}ahum faikhw\q@u{a}nukum fee a\q@b{l}ddeeni wamaw\q@u{a}leekum walaysa AAalaykum jun\q@u{ah}un feem\q@u{a} akh\q@u{t}atum bihi wal\q@u{a}kin m\q@u{a} taAAammadat quloobukum wak\q@u{a}na All\q@u{a}hu ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmdxxxix{A\q@b{l}nnabiyyu awl\q@u{a} bi\q@b{a}lmumineena min anfusihim waazw\q@u{a}juhu ommah\q@u{a}tuhum waoloo alar\q@u{ha}mi baAA\q@u{d}uhum awl\q@u{a} bibaAA\q@u{d}in fee kit\q@u{a}bi All\q@u{a}hi mina almumineena wa\q@b{a}lmuh\q@u{a}jireena ill\q@u{a} an tafAAaloo il\q@u{a} awliy\q@u{a}ikum maAAroofan k\q@u{a}na \q@u{tha}lika fee alkit\q@u{a}bi mas\q@u{t}oor\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmdxl{Wai\q@u{th} akha\q@u{th}n\q@u{a} mina a\q@b{l}nnabiyyeena meeth\q@u{a}qahum waminka wamin noo\q@u{h}in waibr\q@u{a}heema wamoos\q@u{a} waAAees\q@u{a} ibni maryama waakha\q@u{th}n\q@u{a} minhum meeth\q@u{a}qan ghalee\q@i{\q@u{th}}\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmdxli{Liyasala a\q@b{l}\q@u{ssa}diqeena AAan \q@u{s}idqihim waaAAadda lilk\q@u{a}fireena AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmdxlii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo o\q@u{th}kuroo niAAmata All\q@u{a}hi AAalaykum i\q@u{th} j\q@u{a}atkum junoodun faarsaln\q@u{a} AAalayhim ree\q@u{h}an wajunoodan lam tarawh\q@u{a} wak\q@u{a}na All\q@u{a}hu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmdxliii{I\q@u{th} j\q@u{a}ookum min fawqikum wamin asfala minkum wai\q@u{th} z\q@u{a}ghati alab\q@u{sa}ru wabalaghati alquloobu al\q@u{h}an\q@u{a}jira wata\q@i{\q@u{th}}unnoona bi\q@b{A}ll\q@u{a}hi a\q@b{l}\q@i{\q@u{thth}}unoon\q@u{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmdxliv{Hun\q@u{a}lika ibtuliya almuminoona wazulziloo zilz\q@u{a}lan shadeed\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmdxlv{Wai\q@u{th} yaqoolu almun\q@u{a}fiqoona wa\q@b{a}lla\q@u{th}eena fee quloobihim mara\q@u{d}un m\q@u{a} waAAadan\q@u{a} All\q@u{a}hu warasooluhu ill\q@u{a} ghuroor\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmdxlvi{Wai\q@u{th} q\q@u{a}lat \q@u{ta}ifatun minhum y\q@u{a} ahla yathriba l\q@u{a} muq\q@u{a}ma lakum fa\q@b{i}rjiAAoo wayasta\q@u{th}inu fareequn minhumu a\q@b{l}nnabiyya yaqooloona inna buyootan\q@u{a} AAawratun wam\q@u{a} hiya biAAawratin in yureedoona ill\q@u{a} fir\q@u{a}r\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmdxlvii{Walaw dukhilat AAalayhim min aq\q@u{ta}rih\q@u{a} thumma suiloo alfitnata la\q@u{a}tawh\q@u{a} wam\q@u{a} talabbathoo bih\q@u{a} ill\q@u{a} yaseer\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmdxlviii{Walaqad k\q@u{a}noo AA\q@u{a}hadoo All\q@u{a}ha min qablu l\q@u{a} yuwalloona aladb\q@u{a}ra wak\q@u{a}na AAahdu All\q@u{a}hi masool\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmdxlix{Qul lan yanfaAAakumu alfir\q@u{a}ru in farartum mina almawti awi alqatli wai\q@u{th}an l\q@u{a} tumattaAAoona ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmdl{Qul man \q@u{tha} alla\q@u{th}ee yaAA\q@u{s}imukum mina All\q@u{a}hi in ar\q@u{a}da bikum sooan aw ar\q@u{a}da bikum ra\q@u{h}matan wal\q@u{a} yajidoona lahum min dooni All\q@u{a}hi waliyyan wal\q@u{a} na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmdli{Qad yaAAlamu All\q@u{a}hu almuAAawwiqeena minkum wa\q@b{a}lq\q@u{a}ileena liikhw\q@u{a}nihim halumma ilayn\q@u{a} wal\q@u{a} yatoona albasa ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmdlii{Ashi\q@u{hh}atan AAalaykum fai\q@u{tha} j\q@u{a}a alkhawfu raaytahum yan\q@i{\q@u{th}}uroona ilayka tadooru aAAyunuhum ka\q@b{a}lla\q@u{th}ee yughsh\q@u{a} AAalayhi mina almawti fai\q@u{tha} \q@u{th}ahaba alkhawfu salaqookum bialsinatin \q@u{h}id\q@u{a}din ashi\q@u{hh}atan AAal\q@u{a} alkhayri ol\q@u{a}ika lam yuminoo faa\q@u{h}ba\q@u{t}a All\q@u{a}hu aAAm\q@u{a}lahum wak\q@u{a}na \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi yaseer\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmdliii{Ya\q@u{h}saboona ala\q@u{h}z\q@u{a}ba lam ya\q@u{th}haboo wain yati ala\q@u{h}z\q@u{a}bu yawaddoo law annahum b\q@u{a}doona fee alaAAr\q@u{a}bi yasaloona AAan anb\q@u{a}ikum walaw k\q@u{a}noo feekum m\q@u{a} q\q@u{a}taloo ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmdliv{Laqad k\q@u{a}na lakum fee rasooli All\q@u{a}hi oswatun \q@u{h}asanatun liman k\q@u{a}na yarjoo All\q@u{a}ha wa\q@b{a}lyawma al\q@u{a}khira wa\q@u{th}akara All\q@u{a}ha katheer\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmdlv{Walamm\q@u{a} ra\q@u{a} almuminoona ala\q@u{h}z\q@u{a}ba q\q@u{a}loo h\q@u{atha} m\q@u{a} waAAadan\q@u{a} All\q@u{a}hu warasooluhu wa\q@u{s}adaqa All\q@u{a}hu warasooluhu wam\q@u{a} z\q@u{a}dahum ill\q@u{a} eem\q@u{a}nan watasleem\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmdlvi{Mina almumineena rij\q@u{a}lun \q@u{s}adaqoo m\q@u{a} AA\q@u{a}hadoo All\q@u{a}ha AAalayhi faminhum man qa\q@u{da} na\q@u{h}bahu waminhum man yanta\q@i{\q@u{th}}iru wam\q@u{a} baddaloo tabdeel\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmdlvii{Liyajziya All\q@u{a}hu a\q@b{l}\q@u{ssa}diqeena bi\q@u{s}idqihim wayuAAa\q@u{thth}iba almun\q@u{a}fiqeena in sh\q@u{a}a aw yatooba AAalayhim inna All\q@u{a}ha k\q@u{a}na ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmdlviii{Waradda All\q@u{a}hu alla\q@u{th}eena kafaroo bighay\q@i{\q@u{th}}ihim lam yan\q@u{a}loo khayran wakaf\q@u{a} All\q@u{a}hu almumineena alqit\q@u{a}la wak\q@u{a}na All\q@u{a}hu qawiyyan AAazeez\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmdlix{Waanzala alla\q@u{th}eena \q@i{\q@u{th}}\q@u{a}haroohum min ahli alkit\q@u{a}bi min \q@u{s}ay\q@u{as}eehim waqa\q@u{th}afa fee quloobihimu a\q@b{l}rruAAba fareeqan taqtuloona watasiroona fareeq\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmdlx{Waawrathakum ar\q@u{d}ahum wadiy\q@u{a}rahum waamw\q@u{a}lahum waar\q@u{d}an lam ta\q@u{t}aooh\q@u{a} wak\q@u{a}na All\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmdlxi{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu qul liazw\q@u{a}jika in kuntunna turidna al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a} wazeenatah\q@u{a} fataAA\q@u{a}layna omattiAAkunna waosarri\q@u{h}kunna sar\q@u{ah}an jameel\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmdlxii{Wain kuntunna turidna All\q@u{a}ha warasoolahu wa\q@b{al}dd\q@u{a}ra al\q@u{a}khirata fainna All\q@u{a}ha aAAadda lilmu\q@u{h}sin\q@u{a}ti minkunna ajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmdlxiii{Y\q@u{a} nis\q@u{a}a a\q@b{l}nnabiyyi man yati minkunna bif\q@u{ah}ishatin mubayyinatin yu\q@u{da}AAaf lah\q@u{a} alAAa\q@u{tha}bu \q@u{d}iAAfayni wak\q@u{a}na \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi yaseer\q@u{a}\q@b{n}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmdlxiv{Waman yaqnut minkunna lill\q@u{a}hi warasoolihi wataAAmal \q@u{sa}li\q@u{h}an nutih\q@u{a} ajrah\q@u{a} marratayni waaAAtadn\q@u{a} lah\q@u{a} rizqan kareem\q@u{a}\q@b{n}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmdlxv{Y\q@u{a} nis\q@u{a}a a\q@b{l}nnabiyyi lastunna kaa\q@u{h}adin mina a\q@b{l}nnis\q@u{a}i ini ittaqaytunna fal\q@u{a} takh\q@u{d}aAAna bi\q@b{a}lqawli faya\q@u{t}maAAa alla\q@u{th}ee fee qalbihi mara\q@u{d}un waqulna qawlan maAAroof\q@u{a}\q@b{n}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmdlxvi{Waqarna fee buyootikunna wal\q@u{a} tabarrajna tabarruja alj\q@u{a}hiliyyati alool\q@u{a} waaqimna a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}teena a\q@b{l}zzak\q@u{a}ta waa\q@u{t}iAAna All\q@u{a}ha warasoolahu innam\q@u{a} yureedu All\q@u{a}hu liyu\q@u{th}hiba AAankumu a\q@b{l}rrijsa ahla albayti wayu\q@u{t}ahhirakum ta\q@u{t}heer\q@u{a}\q@b{n}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmdlxvii{Wa\q@b{o}\q@u{th}kurna m\q@u{a} yutl\q@u{a} fee buyootikunna min \q@u{a}y\q@u{a}ti All\q@u{a}hi wa\q@b{a}l\q@u{h}ikmati inna All\q@u{a}ha k\q@u{a}na la\q@u{t}eefan khabeer\q@u{a}\q@b{n}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmdlxviii{Inna almuslimeena wa\q@b{a}lmuslim\q@u{a}ti wa\q@b{a}lmumineena wa\q@b{a}lmumin\q@u{a}ti wa\q@b{a}lq\q@u{a}niteena wa\q@b{a}lq\q@u{a}nit\q@u{a}ti wa\q@b{al}\q@u{ssa}diqeena wa\q@b{al}\q@u{ssa}diq\q@u{a}ti wa\q@b{al}\q@u{ssa}bireena wa\q@b{al}\q@u{ssa}bir\q@u{a}ti wa\q@b{a}lkh\q@u{a}shiAAeena wa\q@b{a}lkh\q@u{a}shiAA\q@u{a}ti wa\q@b{a}lmuta\q@u{s}addiqeena wa\q@b{a}lmuta\q@u{s}addiq\q@u{a}ti wa\q@b{al}\q@u{ssa}imeena wa\q@b{al}\q@u{ssa}im\q@u{a}ti wa\q@b{a}l\q@u{ha}fi\q@i{\q@u{th}}eena furoojahum wa\q@b{a}l\q@u{ha}fi\q@i{\q@u{th}}\q@u{a}ti wa\q@b{al}\q@u{ththa}kireena All\q@u{a}ha katheeran wa\q@b{al}\q@u{ththa}kir\q@u{a}ti aAAadda All\q@u{a}hu lahum maghfiratan waajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmdlxix{Wam\q@u{a} k\q@u{a}na limuminin wal\q@u{a} muminatin i\q@u{tha} qa\q@u{da} All\q@u{a}hu warasooluhu amran an yakoona lahumu alkhiyaratu min amrihim waman yaAA\q@u{s}i All\q@u{a}ha warasoolahu faqad \q@u{d}alla \q@u{d}al\q@u{a}lan mubeen\q@u{a}\q@b{n}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmdlxx{Wai\q@u{th} taqoolu lilla\q@u{th}ee anAAama All\q@u{a}hu AAalayhi waanAAamta AAalayhi amsik AAalayka zawjaka wa\q@b{i}ttaqi All\q@u{a}ha watukhfee fee nafsika m\q@u{a} All\q@u{a}hu mubdeehi watakhsh\q@u{a} a\q@b{l}nn\q@u{a}sa wa\q@b{A}ll\q@u{a}hu a\q@u{h}aqqu an takhsh\q@u{a}hu falamm\q@u{a} qa\q@u{da} zaydun minh\q@u{a} wa\q@u{t}aran zawwajn\q@u{a}kah\q@u{a} likay l\q@u{a} yakoona AAal\q@u{a} almumineena \q@u{h}arajun fee azw\q@u{a}ji adAAiy\q@u{a}ihim i\q@u{tha} qa\q@u{d}aw minhunna wa\q@u{t}aran wak\q@u{a}na amru All\q@u{a}hi mafAAool\q@u{a}\q@b{n}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmdlxxi{M\q@u{a} k\q@u{a}na AAal\q@u{a} a\q@b{l}nnabiyyi min \q@u{h}arajin feem\q@u{a} fara\q@u{d}a All\q@u{a}hu lahu sunnata All\q@u{a}hi fee alla\q@u{th}eena khalaw min qablu wak\q@u{a}na amru All\q@u{a}hi qadaran maqdoor\q@u{a}\q@b{n}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmdlxxii{Alla\q@u{th}eena yuballighoona ris\q@u{a}l\q@u{a}ti All\q@u{a}hi wayakhshawnahu wal\q@u{a} yakhshawna a\q@u{h}adan ill\q@u{a} All\q@u{a}ha wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi \q@u{h}aseeb\q@u{a}\q@b{n}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmdlxxiii{M\q@u{a} k\q@u{a}na mu\q@u{h}ammadun ab\q@u{a} a\q@u{h}adin min rij\q@u{a}likum wal\q@u{a}kin rasoola All\q@u{a}hi wakh\q@u{a}tama a\q@b{l}nnabiyyeena wak\q@u{a}na All\q@u{a}hu bikulli shayin AAaleem\q@u{a}\q@b{n}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmdlxxiv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo o\q@u{th}kuroo All\q@u{a}ha \q@u{th}ikran katheer\q@u{a}\q@b{n}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmdlxxv{Wasabbi\q@u{h}oohu bukratan waa\q@u{s}eel\q@u{a}\q@b{n}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmdlxxvi{Huwa alla\q@u{th}ee yu\q@u{s}allee AAalaykum wamal\q@u{a}ikatuhu liyukhrijakum mina a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti il\q@u{a} a\q@b{l}nnoori wak\q@u{a}na bi\q@b{a}lmumineena ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmdlxxvii{Ta\q@u{h}iyyatuhum yawma yalqawnahu sal\q@u{a}mun waaAAadda lahum ajran kareem\q@u{a}\q@b{n}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmdlxxviii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu inn\q@u{a} arsaln\q@u{a}ka sh\q@u{a}hidan wamubashshiran wana\q@u{th}eer\q@u{a}\q@b{n}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmdlxxix{Wad\q@u{a}AAiyan il\q@u{a} All\q@u{a}hi bii\q@u{th}nihi wasir\q@u{a}jan muneer\q@u{a}\q@b{n}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmdlxxx{Wabashshiri almumineena bianna lahum mina All\q@u{a}hi fa\q@u{d}lan kabeer\q@u{a}\q@b{n}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmdlxxxi{Wal\q@u{a} tu\q@u{t}iAAi alk\q@u{a}fireena wa\q@b{a}lmun\q@u{a}fiqeena wadaAA a\q@u{tha}hum watawakkal AAal\q@u{a} All\q@u{a}hi wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi wakeel\q@u{a}\q@b{n}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmdlxxxii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} naka\q@u{h}tumu almumin\q@u{a}ti thumma \q@u{t}allaqtumoohunna min qabli an tamassoohunna fam\q@u{a} lakum AAalayhinna min AAiddatin taAAtaddoonah\q@u{a} famattiAAoohunna wasarri\q@u{h}oohunna sar\q@u{ah}an jameel\q@u{a}\q@b{n}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmdlxxxiii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu inn\q@u{a} a\q@u{h}laln\q@u{a} laka azw\q@u{a}jaka all\q@u{a}tee \q@u{a}tayta ojoorahunna wam\q@u{a} malakat yameenuka mimm\q@u{a} af\q@u{a}a All\q@u{a}hu AAalayka waban\q@u{a}ti AAammika waban\q@u{a}ti AAamm\q@u{a}tika waban\q@u{a}ti kh\q@u{a}lika waban\q@u{a}ti kh\q@u{a}l\q@u{a}tika all\q@u{a}tee h\q@u{a}jarna maAAaka wa\q@b{i}mraatan muminatan in wahabat nafsah\q@u{a} li\q@b{l}nnabiyyi in ar\q@u{a}da a\q@b{l}nnabiyyu an yastanki\q@u{h}ah\q@u{a} kh\q@u{a}li\q@u{s}atan laka min dooni almumineena qad AAalimn\q@u{a} m\q@u{a} fara\q@u{d}n\q@u{a} AAalayhim fee azw\q@u{a}jihim wam\q@u{a} malakat aym\q@u{a}nuhum likayl\q@u{a} yakoona AAalayka \q@u{h}arajun wak\q@u{a}na All\q@u{a}hu ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmdlxxxiv{Turjee man tash\q@u{a}o minhunna watuwee ilayka man tash\q@u{a}o wamani ibtaghayta mimman AAazalta fal\q@u{a} jun\q@u{ah}a AAalayka \q@u{tha}lika adn\q@u{a} an taqarra aAAyunuhunna wal\q@u{a} ya\q@u{h}zanna wayar\q@u{d}ayna bim\q@u{a} \q@u{a}taytahunna kulluhunna wa\q@b{A}ll\q@u{a}hu yaAAlamu m\q@u{a} fee quloobikum wak\q@u{a}na All\q@u{a}hu AAaleeman \q@u{h}aleem\q@u{a}\q@b{n}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmdlxxxv{L\q@u{a} ya\q@u{h}illu laka a\q@b{l}nnis\q@u{a}o min baAAdu wal\q@u{a} an tabaddala bihinna min azw\q@u{a}jin walaw aAAjabaka \q@u{h}usnuhunna ill\q@u{a} m\q@u{a} malakat yameenuka wak\q@u{a}na All\q@u{a}hu AAal\q@u{a} kulli shayin raqeeb\q@u{a}\q@b{n}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmdlxxxvi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tadkhuloo buyoota a\q@b{l}nnabiyyi ill\q@u{a} an yu\q@u{th}ana lakum il\q@u{a} \q@u{t}aAA\q@u{a}min ghayra n\q@u{a}\q@i{\q@u{th}}ireena in\q@u{a}hu wal\q@u{a}kin i\q@u{tha} duAAeetum fa\q@b{o}dkhuloo fai\q@u{tha} \q@u{t}aAAimtum fa\q@b{i}ntashiroo wal\q@u{a} mustaniseena li\q@u{h}adeethin inna \q@u{tha}likum k\q@u{a}na yu\q@u{th}ee a\q@b{l}nnabiyya fayasta\q@u{h}yee minkum wa\q@b{A}ll\q@u{a}hu l\q@u{a} yasta\q@u{h}yee mina al\q@u{h}aqqi wai\q@u{tha} saaltumoohunna mat\q@u{a}AAan fa\q@b{i}saloohunna min war\q@u{a}i \q@u{h}ij\q@u{a}bin \q@u{tha}likum a\q@u{t}haru liquloobikum waquloobihinna wam\q@u{a} k\q@u{a}na lakum an tu\q@u{th}oo rasoola All\q@u{a}hi wal\q@u{a} an tanki\q@u{h}oo azw\q@u{a}jahu min baAAdihi abadan inna \q@u{tha}likum k\q@u{a}na AAinda All\q@u{a}hi AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmdlxxxvii{In tubdoo shayan aw tukhfoohu fainna All\q@u{a}ha k\q@u{a}na bikulli shayin AAaleem\q@u{a}\q@b{n}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmdlxxxviii{L\q@u{a} jun\q@u{ah}a AAalayhinna fee \q@u{a}b\q@u{a}ihinna wal\q@u{a} abn\q@u{a}ihinna wal\q@u{a} ikhw\q@u{a}nihinna wal\q@u{a} abn\q@u{a}i ikhw\q@u{a}nihinna wal\q@u{a} abn\q@u{a}i akhaw\q@u{a}tihinna wal\q@u{a} nis\q@u{a}ihinna wal\q@u{a} m\q@u{a} malakat aym\q@u{a}nuhunna wa\q@b{i}ttaqeena All\q@u{a}ha inna All\q@u{a}ha k\q@u{a}na AAal\q@u{a} kulli shayin shaheed\q@u{a}\q@b{n}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmdlxxxix{Inna All\q@u{a}ha wamal\q@u{a}ikatahu yu\q@u{s}alloona AAal\q@u{a} a\q@b{l}nnabiyyi y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo \q@u{s}alloo AAalayhi wasallimoo tasleem\q@u{a}\q@b{n}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmdxc{Inna alla\q@u{th}eena yu\q@u{th}oona All\q@u{a}ha warasoolahu laAAanahumu All\q@u{a}hu fee a\q@b{l}dduny\q@u{a} wa\q@b{a}l\q@u{a}khirati waaAAadda lahum AAa\q@u{tha}ban muheen\q@u{a}\q@b{n}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmdxci{Wa\q@b{a}lla\q@u{th}eena yu\q@u{th}oona almumineena wa\q@b{a}lmumin\q@u{a}ti bighayri m\q@u{a} iktasaboo faqadi i\q@u{h}tamaloo buht\q@u{a}nan waithman mubeen\q@u{a}\q@b{n}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmdxcii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu qul liazw\q@u{a}jika waban\q@u{a}tika wanis\q@u{a}i almumineena yudneena AAalayhinna min jal\q@u{a}beebihinna \q@u{tha}lika adn\q@u{a} an yuAArafna fal\q@u{a} yu\q@u{th}ayna wak\q@u{a}na All\q@u{a}hu ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmdxciii{Lain lam yantahi almun\q@u{a}fiqoona wa\q@b{a}lla\q@u{th}eena fee quloobihim mara\q@u{d}un wa\q@b{a}lmurjifoona fee almadeenati lanughriyannaka bihim thumma l\q@u{a} yuj\q@u{a}wiroonaka feeh\q@u{a} ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmdxciv{MalAAooneena aynam\q@u{a} thuqifoo okhi\q@u{th}oo waquttiloo taqteel\q@u{a}\q@b{n}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmdxcv{Sunnata All\q@u{a}hi fee alla\q@u{th}eena khalaw min qablu walan tajida lisunnati All\q@u{a}hi tabdeel\q@u{a}\q@b{n}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmdxcvi{Yasaluka a\q@b{l}nn\q@u{a}su AAani a\q@b{l}ss\q@u{a}AAati qul innam\q@u{a} AAilmuh\q@u{a} AAinda All\q@u{a}hi wam\q@u{a} yudreeka laAAalla a\q@b{l}ss\q@u{a}AAata takoonu qareeb\q@u{a}\q@b{n}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmdxcvii{Inna All\q@u{a}ha laAAana alk\q@u{a}fireena waaAAadda lahum saAAeer\q@u{a}\q@b{n}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmdxcviii{Kh\q@u{a}lideena feeh\q@u{a} abadan l\q@u{a} yajidoona waliyyan wal\q@u{a} na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmdxcix{Yawma tuqallabu wujoohuhum fee a\q@b{l}nn\q@u{a}ri yaqooloona y\q@u{a} laytan\q@u{a} a\q@u{t}aAAn\q@u{a} All\q@u{a}ha waa\q@u{t}aAAn\q@u{a} a\q@b{l}rrasool\q@u{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmdc{Waq\q@u{a}loo rabban\q@u{a} inn\q@u{a} a\q@u{t}aAAn\q@u{a} s\q@u{a}datan\q@u{a} wakubar\q@u{a}an\q@u{a} faa\q@u{d}alloon\q@u{a} a\q@b{l}ssabeel\q@u{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmdci{Rabban\q@u{a} \q@u{a}tihim \q@u{d}iAAfayni mina alAAa\q@u{tha}bi wa\q@b{i}lAAanhum laAAnan kabeer\q@u{a}\q@b{n}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmdcii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} takoonoo ka\q@b{a}lla\q@u{th}eena \q@u{ath}aw moos\q@u{a} fabarraahu All\q@u{a}hu mimm\q@u{a} q\q@u{a}loo wak\q@u{a}na AAinda All\q@u{a}hi wajeeh\q@u{a}\q@b{n}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmdciii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo ittaqoo All\q@u{a}ha waqooloo qawlan sadeed\q@u{a}\q@b{n}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmdciv{Yu\q@u{s}li\q@u{h} lakum aAAm\q@u{a}lakum wayaghfir lakum \q@u{th}unoobakum waman yu\q@u{t}iAAi All\q@u{a}ha warasoolahu faqad f\q@u{a}za fawzan AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmdcv{Inn\q@u{a} AAara\q@u{d}n\q@u{a} alam\q@u{a}nata AAal\q@u{a} a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{a}ljib\q@u{a}li faabayna an ya\q@u{h}milnah\q@u{a} waashfaqna minh\q@u{a} wa\q@u{h}amalah\q@u{a} alins\q@u{a}nu innahu k\q@u{a}na \q@i{\q@u{th}}alooman jahool\q@u{a}\q@b{n}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmdcvi{LiyuAAa\q@u{thth}iba All\q@u{a}hu almun\q@u{a}fiqeena wa\q@b{a}lmun\q@u{a}fiq\q@u{a}ti wa\q@b{a}lmushrikeena wa\q@b{a}lmushrik\q@u{a}ti wayatooba All\q@u{a}hu AAal\q@u{a} almumineena wa\q@b{a}lmumin\q@u{a}ti wak\q@u{a}na All\q@u{a}hu ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmdcvii{\basmalahlt Al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i walahu al\q@u{h}amdu fee al\q@u{a}khirati wahuwa al\q@u{h}akeemu alkhabeer\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmdcviii{YaAAlamu m\q@u{a} yaliju fee alar\q@u{d}i wam\q@u{a} yakhruju minh\q@u{a} wam\q@u{a} yanzilu mina a\q@b{l}ssam\q@u{a}i wam\q@u{a} yaAAruju feeh\q@u{a} wahuwa a\q@b{l}rra\q@u{h}eemu alghafoor\q@b{u}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmdcix{Waq\q@u{a}la alla\q@u{th}eena kafaroo l\q@u{a} tateen\q@u{a} a\q@b{l}ss\q@u{a}AAatu qul bal\q@u{a} warabbee latatiyannakum AA\q@u{a}limi alghaybi l\q@u{a} yaAAzubu AAanhu mithq\q@u{a}lu \q@u{th}arratin fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wal\q@u{a} fee alar\q@u{d}i wal\q@u{a} a\q@u{s}gharu min \q@u{tha}lika wal\q@u{a} akbaru ill\q@u{a} fee kit\q@u{a}bin mubeen\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmdcx{Liyajziya alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti ol\q@u{a}ika lahum maghfiratun warizqun kareem\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmdcxi{Wa\q@b{a}lla\q@u{th}eena saAAaw fee \q@u{a}y\q@u{a}tin\q@u{a} muAA\q@u{a}jizeena ol\q@u{a}ika lahum AAa\q@u{tha}bun min rijzin aleem\q@b{in}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmdcxii{Wayar\q@u{a} alla\q@u{th}eena ootoo alAAilma alla\q@u{th}ee onzila ilayka min rabbika huwa al\q@u{h}aqqa wayahdee il\q@u{a} \q@u{s}ir\q@u{at}i alAAazeezi al\q@u{h}ameed\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmdcxiii{Waq\q@u{a}la alla\q@u{th}eena kafaroo hal nadullukum AAal\q@u{a} rajulin yunabbiokum i\q@u{tha} muzziqtum kulla mumazzaqin innakum lafee khalqin jadeed\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmdcxiv{Aftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban am bihi jinnatun bali alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati fee alAAa\q@u{tha}bi wa\q@b{al}\q@u{dd}al\q@u{a}li albaAAeed\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmdcxv{Afalam yaraw il\q@u{a} m\q@u{a} bayna aydeehim wam\q@u{a} khalfahum mina a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i in nasha nakhsif bihimu alar\q@u{d}a aw nusqi\q@u{t} AAalayhim kisafan mina a\q@b{l}ssam\q@u{a}i inna fee \q@u{tha}lika la\q@u{a}yatan likulli AAabdin muneeb\q@b{in}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmdcxvi{Walaqad \q@u{a}tayn\q@u{a} d\q@u{a}wooda minn\q@u{a} fa\q@u{d}lan y\q@u{a} jib\q@u{a}lu awwibee maAAahu wa\q@b{al}\q@u{tt}ayra waalann\q@u{a} lahu al\q@u{h}adeed\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmdcxvii{Ani iAAmal s\q@u{a}bigh\q@u{a}tin waqaddir fee a\q@b{l}ssardi wa\q@b{i}AAmaloo \q@u{sa}li\q@u{h}an innee bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmdcxviii{Walisulaym\q@u{a}na a\q@b{l}rree\q@u{h}a ghuduwwuh\q@u{a} shahrun waraw\q@u{ah}uh\q@u{a} shahrun waasaln\q@u{a} lahu AAayna alqi\q@u{t}ri wamina aljinni man yaAAmalu bayna yadayhi bii\q@u{th}ni rabbihi waman yazigh minhum AAan amrin\q@u{a} nu\q@u{th}iqhu min AAa\q@u{tha}bi a\q@b{l}ssaAAeer\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmdcxix{YaAAmaloona lahu m\q@u{a} yash\q@u{a}o min ma\q@u{ha}reeba watam\q@u{a}theela wajif\q@u{a}nin ka\q@b{a}ljaw\q@u{a}bi waqudoorin r\q@u{a}siy\q@u{a}tin iAAmaloo \q@u{a}la d\q@u{a}wooda shukran waqaleelun min AAib\q@u{a}diya a\q@b{l}shshakoor\q@b{u}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmdcxx{Falamm\q@u{a} qa\q@u{d}ayn\q@u{a} AAalayhi almawta m\q@u{a} dallahum AAal\q@u{a} mawtihi ill\q@u{a} d\q@u{a}bbatu alar\q@u{d}i takulu minsaatahu falamm\q@u{a} kharra tabayyanati aljinnu an law k\q@u{a}noo yaAAlamoona alghayba m\q@u{a} labithoo fee alAAa\q@u{tha}bi almuheen\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmdcxxi{Laqad k\q@u{a}na lisabain fee maskanihim \q@u{a}yatun jannat\q@u{a}ni AAan yameenin washim\q@u{a}lin kuloo min rizqi rabbikum wa\q@b{o}shkuroo lahu baldatun \q@u{t}ayyibatun warabbun ghafoor\q@b{un}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmdcxxii{FaaAAra\q@u{d}oo faarsaln\q@u{a} AAalayhim sayla alAAarimi wabaddaln\q@u{a}hum bijannatayhim jannatayni \q@u{th}aw\q@u{a}tay okulin kham\q@u{t}in waathlin washayin min sidrin qaleel\q@b{in}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmdcxxiii{\q@u{Tha}lika jazayn\q@u{a}hum bim\q@u{a} kafaroo wahal nuj\q@u{a}zee ill\q@u{a} alkafoor\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmdcxxiv{WajaAAaln\q@u{a} baynahum wabayna alqur\q@u{a} allatee b\q@u{a}rakn\q@u{a} feeh\q@u{a} quran \q@i{\q@u{th}}\q@u{a}hiratan waqaddarn\q@u{a} feeh\q@u{a} a\q@b{l}ssayra seeroo feeh\q@u{a} lay\q@u{a}liya waayy\q@u{a}man \q@u{a}mineen\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmdcxxv{Faq\q@u{a}loo rabban\q@u{a} b\q@u{a}AAid bayna asf\q@u{a}rin\q@u{a} wa\q@i{\q@u{th}}alamoo anfusahum fajaAAaln\q@u{a}hum a\q@u{ha}deetha wamazzaqn\q@u{a}hum kulla mumazzaqin inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin likulli \q@u{s}abb\q@u{a}rin shakoor\q@b{in}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmdcxxvi{Walaqad \q@u{s}addaqa AAalayhim ibleesu \q@i{\q@u{th}}annahu fa\q@b{i}ttabaAAoohu ill\q@u{a} fareeqan mina almumineen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmdcxxvii{Wam\q@u{a} k\q@u{a}na lahu AAalayhim min sul\q@u{ta}nin ill\q@u{a} linaAAlama man yuminu bi\q@b{a}l\q@u{a}khirati mimman huwa minh\q@u{a} fee shakkin warabbuka AAal\q@u{a} kulli shayin \q@u{h}afee\q@i{\q@u{th}}\q@b{un}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmdcxxviii{Quli odAAoo alla\q@u{th}eena zaAAamtum min dooni All\q@u{a}hi l\q@u{a} yamlikoona mithq\q@u{a}la \q@u{th}arratin fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wal\q@u{a} fee alar\q@u{d}i wam\q@u{a} lahum feehim\q@u{a} min shirkin wam\q@u{a} lahu minhum min \q@i{\q@u{th}}aheer\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmdcxxix{Wal\q@u{a} tanfaAAu a\q@b{l}shshaf\q@u{a}AAatu AAindahu ill\q@u{a} liman a\q@u{th}ina lahu \q@u{h}att\q@u{a} i\q@u{tha} fuzziAAa AAan quloobihim q\q@u{a}loo m\q@u{atha} q\q@u{a}la rabbukum q\q@u{a}loo al\q@u{h}aqqa wahuwa alAAaliyyu alkabeer\q@b{u}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmdcxxx{Qul man yarzuqukum mina a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i quli All\q@u{a}hu wainn\q@u{a} aw iyy\q@u{a}kum laAAal\q@u{a} hudan aw fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmdcxxxi{Qul l\q@u{a} tusaloona AAamm\q@u{a} ajramn\q@u{a} wal\q@u{a} nusalu AAamm\q@u{a} taAAmaloon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmdcxxxii{Qul yajmaAAu baynan\q@u{a} rabbun\q@u{a} thumma yafta\q@u{h}u baynan\q@u{a} bi\q@b{a}l\q@u{h}aqqi wahuwa alfatt\q@u{ah}u alAAaleem\q@b{u}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmdcxxxiii{Qul arooniya alla\q@u{th}eena al\q@u{h}aqtum bihi shurak\q@u{a}a kall\q@u{a} bal huwa All\q@u{a}hu alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmdcxxxiv{Wam\q@u{a} arsaln\q@u{a}ka ill\q@u{a} k\q@u{a}ffatan li\q@b{l}nn\q@u{a}si basheeran wana\q@u{th}eeran wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmdcxxxv{Wayaqooloona mat\q@u{a} h\q@u{atha} alwaAAdu in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmdcxxxvi{Qul lakum meeAA\q@u{a}du yawmin l\q@u{a} tastakhiroona AAanhu s\q@u{a}AAatan wal\q@u{a} tastaqdimoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmdcxxxvii{Waq\q@u{a}la alla\q@u{th}eena kafaroo lan numina bih\q@u{atha} alqur\q@u{a}ni wal\q@u{a} bi\q@b{a}lla\q@u{th}ee bayna yadayhi walaw tar\q@u{a} i\q@u{th}i a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoona mawqoofoona AAinda rabbihim yarjiAAu baAA\q@u{d}uhum il\q@u{a} baAA\q@u{d}in alqawla yaqoolu alla\q@u{th}eena istu\q@u{d}AAifoo lilla\q@u{th}eena istakbaroo lawl\q@u{a} antum lakunn\q@u{a} mumineen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmdcxxxviii{Q\q@u{a}la alla\q@u{th}eena istakbaroo lilla\q@u{th}eena istu\q@u{d}AAifoo ana\q@u{h}nu \q@u{s}adadn\q@u{a}kum AAani alhud\q@u{a} baAAda i\q@u{th} j\q@u{a}akum bal kuntum mujrimeen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmdcxxxix{Waq\q@u{a}la alla\q@u{th}eena istu\q@u{d}AAifoo lilla\q@u{th}eena istakbaroo bal makru allayli wa\q@b{al}nnah\q@u{a}ri i\q@u{th} tamuroonan\q@u{a} an nakfura bi\q@b{A}ll\q@u{a}hi wanajAAala lahu and\q@u{a}dan waasarroo a\q@b{l}nnad\q@u{a}mata lamm\q@u{a} raawoo alAAa\q@u{tha}ba wajaAAaln\q@u{a} alaghl\q@u{a}la fee aAAn\q@u{a}qi alla\q@u{th}eena kafaroo hal yujzawna ill\q@u{a} m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmdcxl{Wam\q@u{a} arsaln\q@u{a} fee qaryatin min na\q@u{th}eerin ill\q@u{a} q\q@u{a}la mutrafooh\q@u{a} inn\q@u{a} bim\q@u{a} orsiltum bihi k\q@u{a}firoon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmdcxli{Waq\q@u{a}loo na\q@u{h}nu aktharu amw\q@u{a}lan waawl\q@u{a}dan wam\q@u{a} na\q@u{h}nu bimuAAa\q@u{thth}abeen\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmdcxlii{Qul inna rabbee yabsu\q@u{t}u a\q@b{l}rrizqa liman yash\q@u{a}o wayaqdiru wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmdcxliii{Wam\q@u{a} amw\q@u{a}lukum wal\q@u{a} awl\q@u{a}dukum bi\q@b{a}llatee tuqarribukum AAindan\q@u{a} zulf\q@u{a} ill\q@u{a} man \q@u{a}mana waAAamila \q@u{sa}li\q@u{h}an faol\q@u{a}ika lahum jaz\q@u{a}o a\q@b{l}\q@u{dd}iAAfi bim\q@u{a} AAamiloo wahum fee alghuruf\q@u{a}ti \q@u{a}minoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmdcxliv{Wa\q@b{a}lla\q@u{th}eena yasAAawna fee \q@u{a}y\q@u{a}tin\q@u{a} muAA\q@u{a}jizeena ol\q@u{a}ika fee alAAa\q@u{tha}bi mu\q@u{hd}aroon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmdcxlv{Qul inna rabbee yabsu\q@u{t}u a\q@b{l}rrizqa liman yash\q@u{a}o min AAib\q@u{a}dihi wayaqdiru lahu wam\q@u{a} anfaqtum min shayin fahuwa yukhlifuhu wahuwa khayru a\q@b{l}rr\q@u{a}ziqeen\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmdcxlvi{Wayawma ya\q@u{h}shuruhum jameeAAan thumma yaqoolu lilmal\q@u{a}ikati ah\q@u{a}ol\q@u{a}i iyy\q@u{a}kum k\q@u{a}noo yaAAbudoon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmdcxlvii{Q\q@u{a}loo sub\q@u{ha}naka anta waliyyun\q@u{a} min doonihim bal k\q@u{a}noo yaAAbudoona aljinna aktharuhum bihim muminoon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmdcxlviii{Fa\q@b{a}lyawma l\q@u{a} yamliku baAA\q@u{d}ukum libaAA\q@u{d}in nafAAan wal\q@u{a} \q@u{d}arran wanaqoolu lilla\q@u{th}eena \q@i{\q@u{th}}alamoo \q@u{th}ooqoo AAa\q@u{tha}ba a\q@b{l}nn\q@u{a}ri allatee kuntum bih\q@u{a} tuka\q@u{thth}iboon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmdcxlix{Wai\q@u{tha} tutl\q@u{a} AAalayhim \q@u{a}y\q@u{a}tun\q@u{a} bayyin\q@u{a}tin q\q@u{a}loo m\q@u{a} h\q@u{atha} ill\q@u{a} rajulun yureedu an ya\q@u{s}uddakum AAamm\q@u{a} k\q@u{a}na yaAAbudu \q@u{a}b\q@u{a}okum waq\q@u{a}loo m\q@u{a} h\q@u{atha} ill\q@u{a} ifkun muftaran waq\q@u{a}la alla\q@u{th}eena kafaroo lil\q@u{h}aqqi lamm\q@u{a} j\q@u{a}ahum in h\q@u{atha} ill\q@u{a} si\q@u{h}run mubeen\q@b{un}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmdcl{Wam\q@u{a} \q@u{a}tayn\q@u{a}hum min kutubin yadrusoonah\q@u{a} wam\q@u{a} arsaln\q@u{a} ilayhim qablaka min na\q@u{th}eer\q@b{in}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmdcli{Waka\q@u{thth}aba alla\q@u{th}eena min qablihim wam\q@u{a} balaghoo miAAsh\q@u{a}ra m\q@u{a} \q@u{a}tayn\q@u{a}hum faka\q@u{thth}aboo rusulee fakayfa k\q@u{a}na nakeer\q@b{i}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmdclii{Qul innam\q@u{a} aAAi\q@i{\q@u{th}}ukum biw\q@u{ah}idatin an taqoomoo lill\q@u{a}hi mathn\q@u{a} wafur\q@u{a}d\q@u{a} thumma tatafakkaroo m\q@u{a} bi\q@u{sah}ibikum min jinnatin in huwa ill\q@u{a} na\q@u{th}eerun lakum bayna yaday AAa\q@u{tha}bin shadeed\q@b{in}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmdcliii{Qul m\q@u{a} saaltukum min ajrin fahuwa lakum in ajriya ill\q@u{a} AAal\q@u{a} All\q@u{a}hi wahuwa AAal\q@u{a} kulli shayin shaheed\q@b{un}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmdcliv{Qul inna rabbee yaq\q@u{th}ifu bi\q@b{a}l\q@u{h}aqqi AAall\q@u{a}mu alghuyoob\q@b{i}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmdclv{Qul j\q@u{a}a al\q@u{h}aqqu wam\q@u{a} yubdio alb\q@u{at}ilu wam\q@u{a} yuAAeed\q@b{u}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmdclvi{Qul in \q@u{d}alaltu fainnam\q@u{a} a\q@u{d}illu AAal\q@u{a} nafsee waini ihtadaytu fabim\q@u{a} yoo\q@u{h}ee ilayya rabbee innahu sameeAAun qareeb\q@b{un}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmdclvii{Walaw tar\q@u{a} i\q@u{th} faziAAoo fal\q@u{a} fawta waokhi\q@u{th}oo min mak\q@u{a}nin qareeb\q@b{in}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmdclviii{Waq\q@u{a}loo \q@u{a}mann\q@u{a} bihi waann\q@u{a} lahumu a\q@b{l}ttan\q@u{a}wushu min mak\q@u{a}nin baAAeed\q@b{in}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmdclix{Waqad kafaroo bihi min qablu wayaq\q@u{th}ifoona bi\q@b{a}lghaybi min mak\q@u{a}nin baAAeed\q@b{in}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmdclx{Wa\q@u{h}eela baynahum wabayna m\q@u{a} yashtahoona kam\q@u{a} fuAAila biashy\q@u{a}AAihim min qablu innahum k\q@u{a}noo fee shakkin mureeb\q@b{in}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmdclxi{\basmalahlt Al\q@u{h}amdu lill\q@u{a}hi f\q@u{at}iri a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i j\q@u{a}AAili almal\q@u{a}ikati rusulan olee ajni\q@u{h}atin mathn\q@u{a} wathul\q@u{a}tha warub\q@u{a}AAa yazeedu fee alkhalqi m\q@u{a} yash\q@u{a}o inna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmdclxii{M\q@u{a} yafta\q@u{h}i All\q@u{a}hu li\q@b{l}nn\q@u{a}si min ra\q@u{h}matin fal\q@u{a} mumsika lah\q@u{a} wam\q@u{a} yumsik fal\q@u{a} mursila lahu min baAAdihi wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmdclxiii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su o\q@u{th}kuroo niAAmata All\q@u{a}hi AAalaykum hal min kh\q@u{a}liqin ghayru All\q@u{a}hi yarzuqukum mina a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa faann\q@u{a} tufakoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmdclxiv{Wain yuka\q@u{thth}ibooka faqad kut\q@u{hth}ibat rusulun min qablika wail\q@u{a} All\q@u{a}hi turjaAAu alomoor\q@b{u}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmdclxv{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su inna waAAda All\q@u{a}hi \q@u{h}aqqun fal\q@u{a} taghurrannakumu al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} wal\q@u{a} yaghurrannakum bi\q@b{A}ll\q@u{a}hi algharoor\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmdclxvi{Inna a\q@b{l}shshay\q@u{ta}na lakum AAaduwwun fa\q@b{i}ttakhi\q@u{th}oohu AAaduwwan innam\q@u{a} yadAAoo \q@u{h}izbahu liyakoonoo min a\q@u{s}\q@u{ha}bi a\q@b{l}ssaAAeer\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmdclxvii{Alla\q@u{th}eena kafaroo lahum AAa\q@u{tha}bun shadeedun wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lahum maghfiratun waajrun kabeer\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmdclxviii{Afaman zuyyina lahu sooo AAamalihi fara\q@u{a}hu \q@u{h}asanan fainna All\q@u{a}ha yu\q@u{d}illu man yash\q@u{a}o wayahdee man yash\q@u{a}o fal\q@u{a} ta\q@u{th}hab nafsuka AAalayhim \q@u{h}asar\q@u{a}tin inna All\q@u{a}ha AAaleemun bim\q@u{a} ya\q@u{s}naAAoon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmdclxix{Wa\q@b{A}ll\q@u{a}hu alla\q@u{th}ee arsala a\q@b{l}rriy\q@u{ah}a fatutheeru sa\q@u{ha}ban fasuqn\q@u{a}hu il\q@u{a} baladin mayyitin faa\q@u{h}yayn\q@u{a} bihi alar\q@u{d}a baAAda mawtih\q@u{a} ka\q@u{tha}lika a\q@b{l}nnushoor\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmdclxx{Man k\q@u{a}na yureedu alAAizzata falill\q@u{a}hi alAAizzatu jameeAAan ilayhi ya\q@u{s}AAadu alkalimu a\q@b{l}\q@u{tt}ayyibu wa\q@b{a}lAAamalu a\q@b{l}\q@u{ssa}li\q@u{h}u yarfaAAuhu wa\q@b{a}lla\q@u{th}eena yamkuroona a\q@b{l}ssayyi\q@u{a}ti lahum AAa\q@u{tha}bun shadeedun wamakru ol\q@u{a}ika huwa yaboor\q@b{u}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmdclxxi{Wa\q@b{A}ll\q@u{a}hu khalaqakum min tur\q@u{a}bin thumma min nu\q@u{t}fatin thumma jaAAalakum azw\q@u{a}jan wam\q@u{a} ta\q@u{h}milu min onth\q@u{a} wal\q@u{a} ta\q@u{d}aAAu ill\q@u{a} biAAilmihi wam\q@u{a} yuAAammaru min muAAammarin wal\q@u{a} yunqa\q@u{s}u min AAumurihi ill\q@u{a} fee kit\q@u{a}bin inna \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi yaseer\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmdclxxii{Wam\q@u{a} yastawee alba\q@u{h}r\q@u{a}ni h\q@u{atha} AAa\q@u{th}bun fur\q@u{a}tun s\q@u{a}ighun shar\q@u{a}buhu wah\q@u{atha} mil\q@u{h}un oj\q@u{a}jun wamin kullin takuloona la\q@u{h}man \q@u{t}ariyyan watastakhrijoona \q@u{h}ilyatan talbasoonah\q@u{a} watar\q@u{a} alfulka feehi maw\q@u{a}khira litabtaghoo min fa\q@u{d}lihi walaAAallakum tashkuroon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmdclxxiii{Yooliju allayla fee a\q@b{l}nnah\q@u{a}ri wayooliju a\q@b{l}nnah\q@u{a}ra fee allayli wasakhkhara a\q@b{l}shshamsa wa\q@b{a}lqamara kullun yajree liajalin musamman \q@u{tha}likumu All\q@u{a}hu rabbukum lahu almulku wa\q@b{a}lla\q@u{th}eena tadAAoona min doonihi m\q@u{a} yamlikoona min qi\q@u{t}meer\q@b{in}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmdclxxiv{In tadAAoohum l\q@u{a} yasmaAAoo duAA\q@u{a}akum walaw samiAAoo m\q@u{a} istaj\q@u{a}boo lakum wayawma alqiy\q@u{a}mati yakfuroona bishirkikum wal\q@u{a} yunabbioka mithlu khabeer\q@b{in}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmdclxxv{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su antumu alfuqar\q@u{a}o il\q@u{a} All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu huwa alghaniyyu al\q@u{h}ameed\q@b{u}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmdclxxvi{In yasha yu\q@u{th}hibkum wayati bikhalqin jadeed\q@b{in}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmdclxxvii{Wam\q@u{a} \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi biAAazeez\q@b{in}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmdclxxviii{Wal\q@u{a} taziru w\q@u{a}ziratun wizra okhr\q@u{a} wain tadAAu muthqalatun il\q@u{a} \q@u{h}imlih\q@u{a} l\q@u{a} yu\q@u{h}mal minhu shayon walaw k\q@u{a}na \q@u{tha} qurb\q@u{a} innam\q@u{a} tun\q@u{th}iru alla\q@u{th}eena yakhshawna rabbahum bi\q@b{a}lghaybi waaq\q@u{a}moo a\q@b{l}\q@u{ss}al\q@u{a}ta waman tazakk\q@u{a} fainnam\q@u{a} yatazakk\q@u{a} linafsihi wail\q@u{a} All\q@u{a}hi alma\q@u{s}eer\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmdclxxix{Wam\q@u{a} yastawee alaAAm\q@u{a} wa\q@b{a}lba\q@u{s}eer\q@b{u}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmdclxxx{Wal\q@u{a} a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}tu wal\q@u{a} a\q@b{l}nnoor\q@b{u}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmdclxxxi{Wal\q@u{a} a\q@b{l}\q@i{\q@u{thth}}illu wal\q@u{a} al\q@u{h}aroor\q@b{u}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmdclxxxii{Wam\q@u{a} yastawee ala\q@u{h}y\q@u{a}o wal\q@u{a} alamw\q@u{a}tu inna All\q@u{a}ha yusmiAAu man yash\q@u{a}o wam\q@u{a} anta bimusmiAAin man fee alquboor\q@b{i}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmdclxxxiii{In anta ill\q@u{a} na\q@u{th}eer\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmdclxxxiv{Inn\q@u{a} arsaln\q@u{a}ka bi\q@b{a}l\q@u{h}aqqi basheeran wana\q@u{th}eeran wain min ommatin ill\q@u{a} khal\q@u{a} feeh\q@u{a} na\q@u{th}eer\q@b{un}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmdclxxxv{Wain yuka\q@u{thth}ibooka faqad ka\q@u{thth}aba alla\q@u{th}eena min qablihim j\q@u{a}athum rusuluhum bi\q@b{a}lbayyin\q@u{a}ti wabi\q@b{al}zzuburi wabi\q@b{a}lkit\q@u{a}bi almuneer\q@b{i}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmdclxxxvi{Thumma akha\q@u{th}tu alla\q@u{th}eena kafaroo fakayfa k\q@u{a}na nakeer\q@b{i}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmdclxxxvii{Alam tara anna All\q@u{a}ha anzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an faakhrajn\q@u{a} bihi thamar\q@u{a}tin mukhtalifan alw\q@u{a}nuh\q@u{a} wamina aljib\q@u{a}li judadun bee\q@u{d}un wa\q@u{h}umrun mukhtalifun alw\q@u{a}nuh\q@u{a} waghar\q@u{a}beebu sood\q@b{un}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmdclxxxviii{Wamina a\q@b{l}nn\q@u{a}si wa\q@b{al}ddaw\q@u{a}bbi wa\q@b{a}lanAA\q@u{a}mi mukhtalifun alw\q@u{a}nuhu ka\q@u{tha}lika innam\q@u{a} yakhsh\q@u{a} All\q@u{a}ha min AAib\q@u{a}dihi alAAulam\q@u{a}o inna All\q@u{a}ha AAazeezun ghafoor\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmdclxxxix{Inna alla\q@u{th}eena yatloona kit\q@u{a}ba All\q@u{a}hi waaq\q@u{a}moo a\q@b{l}\q@u{ss}al\q@u{a}ta waanfaqoo mimm\q@u{a} razaqn\q@u{a}hum sirran waAAal\q@u{a}niyatan yarjoona tij\q@u{a}ratan lan taboor\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmdcxc{Liyuwaffiyahum ojoorahum wayazeedahum min fa\q@u{d}lihi innahu ghafoorun shakoor\q@b{un}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmdcxci{Wa\q@b{a}lla\q@u{th}ee aw\q@u{h}ayn\q@u{a} ilayka mina alkit\q@u{a}bi huwa al\q@u{h}aqqu mu\q@u{s}addiqan lim\q@u{a} bayna yadayhi inna All\q@u{a}ha biAAib\q@u{a}dihi lakhabeerun ba\q@u{s}eer\q@b{un}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmdcxcii{Thumma awrathn\q@u{a} alkit\q@u{a}ba alla\q@u{th}eena i\q@u{st}afayn\q@u{a} min AAib\q@u{a}din\q@u{a} faminhum \q@i{\q@u{th}}\q@u{a}limun linafsihi waminhum muqta\q@u{s}idun waminhum s\q@u{a}biqun bi\q@b{a}lkhayr\q@u{a}ti bii\q@u{th}ni All\q@u{a}hi \q@u{tha}lika huwa alfa\q@u{d}lu alkabeer\q@b{u}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmdcxciii{Jann\q@u{a}tu AAadnin yadkhuloonah\q@u{a} yu\q@u{h}allawna feeh\q@u{a} min as\q@u{a}wira min \q@u{th}ahabin waluluan walib\q@u{a}suhum feeh\q@u{a} \q@u{h}areer\q@b{un}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmdcxciv{Waq\q@u{a}loo al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee a\q@u{th}haba AAann\q@u{a} al\q@u{h}azana inna rabban\q@u{a} laghafoorun shakoor\q@b{un}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmdcxcv{Alla\q@u{th}ee a\q@u{h}allan\q@u{a} d\q@u{a}ra almuq\q@u{a}mati min fa\q@u{d}lihi l\q@u{a} yamassun\q@u{a} feeh\q@u{a} na\q@u{s}abun wal\q@u{a} yamassun\q@u{a} feeh\q@u{a} lughoob\q@b{un}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmdcxcvi{Wa\q@b{a}lla\q@u{th}eena kafaroo lahum n\q@u{a}ru jahannama l\q@u{a} yuq\q@u{da} AAalayhim fayamootoo wal\q@u{a} yukhaffafu AAanhum min AAa\q@u{tha}bih\q@u{a} ka\q@u{tha}lika najzee kulla kafoor\q@b{in}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmdcxcvii{Wahum ya\q@u{st}arikhoona feeh\q@u{a} rabban\q@u{a} akhrijn\q@u{a} naAAmal \q@u{sa}li\q@u{h}an ghayra alla\q@u{th}ee kunn\q@u{a} naAAmalu awalam nuAAammirkum m\q@u{a} yata\q@u{th}akkaru feehi man ta\q@u{th}akkara waj\q@u{a}akumu a\q@b{l}nna\q@u{th}eeru fa\q@u{th}ooqoo fam\q@u{a} li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena min na\q@u{s}eer\q@b{in}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmdcxcviii{Inna All\q@u{a}ha AA\q@u{a}limu ghaybi a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i innahu AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmdcxcix{Huwa alla\q@u{th}ee jaAAalakum khal\q@u{a}ifa fee alar\q@u{d}i faman kafara faAAalayhi kufruhu wal\q@u{a} yazeedu alk\q@u{a}fireena kufruhum AAinda rabbihim ill\q@u{a} maqtan wal\q@u{a} yazeedu alk\q@u{a}fireena kufruhum ill\q@u{a} khas\q@u{a}r\q@u{a}\q@b{n}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmdcc{Qul araaytum shurak\q@u{a}akumu alla\q@u{th}eena tadAAoona min dooni All\q@u{a}hi aroonee m\q@u{atha} khalaqoo mina alar\q@u{d}i am lahum shirkun fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti am \q@u{a}tayn\q@u{a}hum kit\q@u{a}ban fahum AAal\q@u{a} bayyinatin minhu bal in yaAAidu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoona baAA\q@u{d}uhum baAA\q@u{d}an ill\q@u{a} ghuroor\q@u{a}\q@b{n}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmdcci{Inna All\q@u{a}ha yumsiku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a an tazool\q@u{a} walain z\q@u{a}lat\q@u{a} in amsakahum\q@u{a} min a\q@u{h}adin min baAAdihi innahu k\q@u{a}na \q@u{h}aleeman ghafoor\q@u{a}\q@b{n}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmdccii{Waaqsamoo bi\q@b{A}ll\q@u{a}hi jahda aym\q@u{a}nihim lain j\q@u{a}ahum na\q@u{th}eerun layakoonunna ahd\q@u{a} min i\q@u{h}d\q@u{a} alomami falamm\q@u{a} j\q@u{a}ahum na\q@u{th}eerun m\q@u{a} z\q@u{a}dahum ill\q@u{a} nufoor\q@u{a}\q@b{n}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmdcciii{Istikb\q@u{a}ran fee alar\q@u{d}i wamakra a\q@b{l}ssayyii wal\q@u{a} ya\q@u{h}eequ almakru a\q@b{l}ssayyio ill\q@u{a} biahlihi fahal yan\q@i{\q@u{th}}uroona ill\q@u{a} sunnata alawwaleena falan tajida lisunnati All\q@u{a}hi tabdeelan walan tajida lisunnati All\q@u{a}hi ta\q@u{h}weel\q@u{a}\q@b{n}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmdcciv{Awalam yaseeroo fee alar\q@u{d}i fayan\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu alla\q@u{th}eena min qablihim wak\q@u{a}noo ashadda minhum quwwatan wam\q@u{a} k\q@u{a}na All\q@u{a}hu liyuAAjizahu min shayin fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wal\q@u{a} fee alar\q@u{d}i innahu k\q@u{a}na AAaleeman qadeer\q@u{a}\q@b{n}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmdccv{Walaw yu\q@u{a}khi\q@u{th}u All\q@u{a}hu a\q@b{l}nn\q@u{a}sa bim\q@u{a} kasaboo m\q@u{a} taraka AAal\q@u{a} \q@i{\q@u{th}}ahrih\q@u{a} min d\q@u{a}bbatin wal\q@u{a}kin yuakhkhiruhum il\q@u{a} ajalin musamman fai\q@u{tha} j\q@u{a}a ajaluhum fainna All\q@u{a}ha k\q@u{a}na biAAib\q@u{a}dihi ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmdccvi{\basmalahlt Y\q@u{a}seen\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmdccvii{Wa\q@b{a}lqur\q@u{a}ni al\q@u{h}akeem\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmdccviii{Innaka lamina almursaleen\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmdccix{AAal\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmdccx{Tanzeela alAAazeezi a\q@b{l}rra\q@u{h}eem\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmdccxi{Litun\q@u{th}ira qawman m\q@u{a} on\q@u{th}ira \q@u{a}b\q@u{a}ohum fahum gh\q@u{a}filoon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmdccxii{Laqad \q@u{h}aqqa alqawlu AAal\q@u{a} aktharihim fahum l\q@u{a} yuminoon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmdccxiii{Inn\q@u{a} jaAAaln\q@u{a} fee aAAn\q@u{a}qihim aghl\q@u{a}lan fahiya il\q@u{a} ala\q@u{th}q\q@u{a}ni fahum muqma\q@u{h}oon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmdccxiv{WajaAAaln\q@u{a} min bayni aydeehim saddan wamin khalfihim saddan faaghshayn\q@u{a}hum fahum l\q@u{a} yub\q@u{s}iroon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmdccxv{Wasaw\q@u{a}on AAalayhim aan\q@u{th}artahum am lam tun\q@u{th}irhum l\q@u{a} yuminoon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmdccxvi{Innam\q@u{a} tun\q@u{th}iru mani ittabaAAa a\q@b{l}\q@u{thth}ikra wakhashiya a\q@b{l}rra\q@u{h}m\q@u{a}na bi\q@b{a}lghaybi fabashshirhu bimaghfiratin waajrin kareem\q@b{in}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmdccxvii{Inn\q@u{a} na\q@u{h}nu nu\q@u{h}yee almawt\q@u{a} wanaktubu m\q@u{a} qaddamoo wa\q@u{a}th\q@u{a}rahum wakulla shayin a\q@u{hs}ayn\q@u{a}hu fee im\q@u{a}min mubeen\q@b{in}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmdccxviii{Wa\q@b{i}\q@u{d}rib lahum mathalan a\q@u{s}\q@u{ha}ba alqaryati i\q@u{th} j\q@u{a}ah\q@u{a} almursaloon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmdccxix{I\q@u{th} arsaln\q@u{a} ilayhimu ithnayni faka\q@u{thth}aboohum\q@u{a} faAAazzazn\q@u{a} bith\q@u{a}lithin faq\q@u{a}loo inn\q@u{a} ilaykum mursaloon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmdccxx{Q\q@u{a}loo m\q@u{a} antum ill\q@u{a} basharun mithlun\q@u{a} wam\q@u{a} anzala a\q@b{l}rra\q@u{h}m\q@u{a}nu min shayin in antum ill\q@u{a} tak\q@u{th}iboon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmdccxxi{Q\q@u{a}loo rabbun\q@u{a} yaAAlamu inn\q@u{a} ilaykum lamursaloon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmdccxxii{Wam\q@u{a} AAalayn\q@u{a} ill\q@u{a} albal\q@u{a}ghu almubeen\q@b{u}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmdccxxiii{Q\q@u{a}loo inn\q@u{a} ta\q@u{t}ayyarn\q@u{a} bikum lain lam tantahoo lanarjumannakum walayamassannakum minn\q@u{a} AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmdccxxiv{Q\q@u{a}loo \q@u{ta}irukum maAAakum ain \q@u{th}ukkirtum bal antum qawmun musrifoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmdccxxv{Waj\q@u{a}a min aq\q@u{sa} almadeenati rajulun yasAA\q@u{a} q\q@u{a}la y\q@u{a} qawmi ittabiAAoo almursaleen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmdccxxvi{IttabiAAoo man l\q@u{a} yasalukum ajran wahum muhtadoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmdccxxvii{Wam\q@u{a} liya l\q@u{a} aAAbudu alla\q@u{th}ee fa\q@u{t}aranee wailayhi turjaAAoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmdccxxviii{Aattakhi\q@u{th}u min doonihi \q@u{a}lihatan in yuridni a\q@b{l}rra\q@u{h}m\q@u{a}nu bi\q@u{d}urrin l\q@u{a }tughni AAannee shaf\q@u{a}AAatuhum shayan wal\q@u{a} yunqi\q@u{th}oon\q@b{i}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmdccxxix{Innee i\q@u{th}an lafee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmdccxxx{Innee \q@u{a}mantu birabbikum fa\q@b{i}smaAAoon\q@b{i}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmdccxxxi{Qeela odkhuli aljannata q\q@u{a}la y\q@u{a} layta qawmee yaAAlamoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmdccxxxii{Bim\q@u{a} ghafara lee rabbee wajaAAalanee mina almukrameen\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmdccxxxiii{Wam\q@u{a} anzaln\q@u{a} AAal\q@u{a} qawmihi min baAAdihi min jundin mina a\q@b{l}ssam\q@u{a}i wam\q@u{a} kunn\q@u{a} munzileen\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmdccxxxiv{In k\q@u{a}nat ill\q@u{a} \q@u{s}ay\q@u{h}atan w\q@u{ah}idatan fai\q@u{tha} hum kh\q@u{a}midoon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmdccxxxv{Y\q@u{a} \q@u{h}asratan AAal\q@u{a} alAAib\q@u{a}di m\q@u{a} yateehim min rasoolin ill\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmdccxxxvi{Alam yaraw kam ahlakn\q@u{a} qablahum mina alqurooni annahum ilayhim l\q@u{a} yarjiAAoon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmdccxxxvii{Wain kullun lamm\q@u{a} jameeAAun ladayn\q@u{a} mu\q@u{hd}aroon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmdccxxxviii{Wa\q@u{a}yatun lahumu alar\q@u{d}u almaytatu a\q@u{h}yayn\q@u{a}h\q@u{a} waakhrajn\q@u{a} minh\q@u{a} \q@u{h}abban faminhu yakuloon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmdccxxxix{WajaAAaln\q@u{a} feeh\q@u{a} jann\q@u{a}tin min nakheelin waaAAn\q@u{a}bin wafajjarn\q@u{a} feeh\q@u{a} mina alAAuyoon\q@b{i}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmdccxl{Liyakuloo min thamarihi wam\q@u{a} AAamilathu aydeehim afal\q@u{a} yashkuroon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmdccxli{Sub\q@u{ha}na alla\q@u{th}ee khalaqa alazw\q@u{a}ja kullah\q@u{a} mimm\q@u{a} tunbitu alar\q@u{d}u wamin anfusihim wamimm\q@u{a} l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmdccxlii{Wa\q@u{a}yatun lahumu allaylu naslakhu minhu a\q@b{l}nnah\q@u{a}ra fai\q@u{tha} hum mu\q@i{\q@u{th}}limoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmdccxliii{Wa\q@b{al}shshamsu tajree limustaqarrin lah\q@u{a} \q@u{tha}lika taqdeeru alAAazeezi alAAaleem\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmdccxliv{Wa\q@b{a}lqamara qaddarn\q@u{a}hu man\q@u{a}zila \q@u{h}att\q@u{a} AA\q@u{a}da ka\q@b{a}lAAurjooni alqadeem\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmdccxlv{L\q@u{a} a\q@b{l}shshamsu yanbaghee lah\q@u{a} an tudrika alqamara wal\q@u{a} allaylu s\q@u{a}biqu a\q@b{l}nnah\q@u{a}ri wakullun fee falakin yasba\q@u{h}oon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmdccxlvi{Wa\q@u{a}yatun lahum ann\q@u{a} \q@u{h}amaln\q@u{a} \q@u{th}urriyyatahum fee alfulki almash\q@u{h}oon\q@b{i}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmdccxlvii{Wakhalaqn\q@u{a} lahum min mithlihi m\q@u{a} yarkaboon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmdccxlviii{Wain nasha nughriqhum fal\q@u{a} \q@u{s}areekha lahum wal\q@u{a} hum yunqa\q@u{th}oon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmdccxlix{Ill\q@u{a} ra\q@u{h}matan minn\q@u{a} wamat\q@u{a}AAan il\q@u{a} \q@u{h}een\q@b{in}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmdccl{Wai\q@u{tha} qeela lahumu ittaqoo m\q@u{a} bayna aydeekum wam\q@u{a} khalfakum laAAallakum tur\q@u{h}amoon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmdccli{Wam\q@u{a} tateehim min \q@u{a}yatin min \q@u{a}y\q@u{a}ti rabbihim ill\q@u{a} k\q@u{a}noo AAanh\q@u{a} muAAri\q@u{d}een\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmdcclii{Wai\q@u{tha} qeela lahum anfiqoo mimm\q@u{a} razaqakumu All\q@u{a}hu q\q@u{a}la alla\q@u{th}eena kafaroo lilla\q@u{th}eena \q@u{a}manoo anu\q@u{t}AAimu man law yash\q@u{a}o All\q@u{a}hu a\q@u{t}AAamahu in antum ill\q@u{a} fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmdccliii{Wayaqooloona mat\q@u{a} h\q@u{atha} alwaAAdu in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmdccliv{M\q@u{a} yan\q@i{\q@u{th}}uroona ill\q@u{a} \q@u{s}ay\q@u{h}atan w\q@u{ah}idatan takhu\q@u{th}uhum wahum yakhi\q@u{ss}imoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmdcclv{Fal\q@u{a} yasta\q@u{t}eeAAoona taw\q@u{s}iyatan wal\q@u{a} il\q@u{a} ahlihim yarjiAAoon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmdcclvi{Wanufikha fee a\q@b{l}\q@u{ss}oori fai\q@u{tha} hum mina alajd\q@u{a}thi il\q@u{a} rabbihim yansiloon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmdcclvii{Q\q@u{a}loo y\q@u{a} waylan\q@u{a} man baAAathan\q@u{a} min marqadin\q@u{a} h\q@u{atha} m\q@u{a} waAAada a\q@b{l}rra\q@u{h}m\q@u{a}nu wa\q@u{s}adaqa almursaloon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmdcclviii{In k\q@u{a}nat ill\q@u{a} \q@u{s}ay\q@u{h}atan w\q@u{ah}idatan fai\q@u{tha} hum jameeAAun ladayn\q@u{a} mu\q@u{hd}aroon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmdcclix{Fa\q@b{a}lyawma l\q@u{a} tu\q@i{\q@u{th}}lamu nafsun shayan wal\q@u{a} tujzawna ill\q@u{a} m\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmdcclx{Inna a\q@u{s}\q@u{ha}ba aljannati alyawma fee shughulin f\q@u{a}kihoon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmdcclxi{Hum waazw\q@u{a}juhum fee \q@i{\q@u{th}}il\q@u{a}lin AAal\q@u{a} alar\q@u{a}iki muttakioon\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmdcclxii{Lahum feeh\q@u{a} f\q@u{a}kihatun walahum m\q@u{a} yaddaAAoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmdcclxiii{Sal\q@u{a}mun qawlan min rabbin ra\q@u{h}eem\q@b{in}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmdcclxiv{Wa\q@b{i}mt\q@u{a}zoo alyawma ayyuh\q@u{a} almujrimoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmdcclxv{Alam aAAhad ilaykum y\q@u{a} banee \q@u{a}dama an l\q@u{a} taAAbudoo a\q@b{l}shshay\q@u{ta}na innahu lakum AAaduwwun mubeen\q@b{un}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmdcclxvi{Waani oAAbudoonee h\q@u{atha} \q@u{s}ir\q@u{at}un mustaqeem\q@b{un}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmdcclxvii{Walaqad a\q@u{d}alla minkum jibillan katheeran afalam takoonoo taAAqiloon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmdcclxviii{H\q@u{ath}ihi jahannamu allatee kuntum tooAAadoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmdcclxix{I\q@u{s}lawh\q@u{a} alyawma bim\q@u{a} kuntum takfuroon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmdcclxx{Alyawma nakhtimu AAal\q@u{a} afw\q@u{a}hihim watukallimun\q@u{a} aydeehim watashhadu arjuluhum bim\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxi{Walaw nash\q@u{a}o la\q@u{t}amasn\q@u{a} AAal\q@u{a} aAAyunihim fa\q@b{i}stabaqoo a\q@b{l}\q@u{ss}ir\q@u{at}a faann\q@u{a} yub\q@u{s}iroon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxii{Walaw nash\q@u{a}o lamasakhn\q@u{a}hum AAal\q@u{a} mak\q@u{a}natihim fam\q@u{a} ista\q@u{ta}AAoo mu\q@u{d}iyyan wal\q@u{a} yarjiAAoon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxiii{Waman nuAAammirhu nunakkishu fee alkhalqi afal\q@u{a} yaAAqiloon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxiv{Wam\q@u{a} AAallamn\q@u{a}hu a\q@b{l}shshiAAra wam\q@u{a} yanbaghee lahu in huwa ill\q@u{a} \q@u{th}ikrun waqur\q@u{a}nun mubeen\q@b{un}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxv{Liyun\q@u{th}ira man k\q@u{a}na \q@u{h}ayyan waya\q@u{h}iqqa alqawlu AAal\q@u{a} alk\q@u{a}fireen\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxvi{Awalam yaraw ann\q@u{a} khalaqn\q@u{a} lahum mimm\q@u{a} AAamilat aydeen\q@u{a} anAA\q@u{a}man fahum lah\q@u{a} m\q@u{a}likoon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxvii{Wa\q@u{th}allaln\q@u{a}h\q@u{a} lahum faminh\q@u{a} rakoobuhum waminh\q@u{a} yakuloon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxviii{Walahum feeh\q@u{a} man\q@u{a}fiAAu wamash\q@u{a}ribu afal\q@u{a} yashkuroon\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxix{Wa\q@b{i}ttakha\q@u{th}oo min dooni All\q@u{a}hi \q@u{a}lihatan laAAallahum yun\q@u{s}aroon\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxx{L\q@u{a} yasta\q@u{t}eeAAoona na\q@u{s}rahum wahum lahum jundun mu\q@u{hd}aroon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxxi{Fal\q@u{a} ya\q@u{h}zunka qawluhum inn\q@u{a} naAAlamu m\q@u{a} yusirroona wam\q@u{a} yuAAlinoon\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxxii{Awalam yar\q@u{a} alins\q@u{a}nu ann\q@u{a} khalaqn\q@u{a}hu min nu\q@u{t}fatin fai\q@u{tha} huwa kha\q@u{s}eemun mubeen\q@b{un}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxxiii{Wa\q@u{d}araba lan\q@u{a} mathalan wanasiya khalqahu q\q@u{a}la man yu\q@u{h}yee alAAi\q@i{\q@u{th}}\q@u{a}ma wahiya rameem\q@b{un}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxxiv{Qul yu\q@u{h}yeeh\q@u{a} alla\q@u{th}ee anshaah\q@u{a} awwala marratin wahuwa bikulli khalqin AAaleem\q@b{un}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxxv{Alla\q@u{th}ee jaAAala lakum mina a\q@b{l}shshajari alakh\q@u{d}ari n\q@u{a}ran fai\q@u{tha} antum minhu tooqidoon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxxvi{Awalaysa alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a biq\q@u{a}dirin AAal\q@u{a} an yakhluqa mithlahum bal\q@u{a} wahuwa alkhall\q@u{a}qu alAAaleem\q@b{u}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxxvii{Innam\q@u{a} amruhu i\q@u{tha} ar\q@u{a}da shayan an yaqoola lahu kun fayakoon\q@b{u}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxxviii{Fasub\q@u{ha}na alla\q@u{th}ee biyadihi malakootu kulli shayin wailayhi turjaAAoon\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmmdcclxxxix{\basmalahlt Wa\q@b{al}\q@u{ssa}ff\q@u{a}ti \q@u{s}aff\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmdccxc{Fa\q@b{al}zz\q@u{a}jir\q@u{a}ti zajr\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmdccxci{Fa\q@b{al}tt\q@u{a}liy\q@u{a}ti \q@u{th}ikr\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmdccxcii{Inna il\q@u{a}hakum law\q@u{ah}id\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmdccxciii{Rabbu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} warabbu almash\q@u{a}riq\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmdccxciv{Inn\q@u{a} zayyann\q@u{a} a\q@b{l}ssam\q@u{a}a a\q@b{l}dduny\q@u{a} bizeenatin alkaw\q@u{a}kib\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmdccxcv{Wa\q@u{h}if\q@i{\q@u{th}}an min kulli shay\q@u{ta}nin m\q@u{a}rid\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmdccxcvi{L\q@u{a} yassammaAAoona il\q@u{a} almalai alaAAl\q@u{a} wayuq\q@u{th}afoona min kulli j\q@u{a}nib\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmdccxcvii{Du\q@u{h}ooran walahum AAa\q@u{tha}bun w\q@u{as}ib\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmdccxcviii{Ill\q@u{a} man kha\q@u{t}ifa alkha\q@u{t}fata faatbaAAahu shih\q@u{a}bun th\q@u{a}qib\q@b{un}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmdccxcix{Fa\q@b{i}staftihim ahum ashaddu khalqan am man khalaqn\q@u{a} inn\q@u{a }khalaqn\q@u{a}hum min \q@u{t}eenin l\q@u{a}zib\q@b{in}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmdccc{Bal AAajibta wayaskharoon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmdccci{Wai\q@u{tha} \q@u{th}ukkiroo l\q@u{a} ya\q@u{th}kuroon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmdcccii{Wai\q@u{tha} raaw \q@u{a}yatan yastaskhiroon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmdccciii{Waq\q@u{a}loo in h\q@u{atha} ill\q@u{a} si\q@u{h}run mubeen\q@b{un}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmdccciv{Ai\q@u{tha} mitn\q@u{a} wakunn\q@u{a} tur\q@u{a}ban waAAi\q@i{\q@u{th}}\q@u{a}man ainn\q@u{a} lamabAAoothoon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmdcccv{Awa\q@u{a}b\q@u{a}on\q@u{a} alawwaloon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmdcccvi{Qul naAAam waantum d\q@u{a}khiroon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmdcccvii{Fainnam\q@u{a} hiya zajratun w\q@u{ah}idatun fai\q@u{tha} hum yan\q@i{\q@u{th}}uroon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmdcccviii{Waq\q@u{a}loo y\q@u{a} waylan\q@u{a} h\q@u{atha} yawmu a\q@b{l}ddeen\q@b{i}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmdcccix{H\q@u{atha} yawmu alfa\q@u{s}li alla\q@u{th}ee kuntum bihi tuka\q@u{thth}iboon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmdcccx{O\q@u{h}shuroo alla\q@u{th}eena \q@i{\q@u{th}}alamoo waazw\q@u{a}jahum wam\q@u{a} k\q@u{a}noo yaAAbudoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmdcccxi{Min dooni All\q@u{a}hi fa\q@b{i}hdoohum il\q@u{a} \q@u{s}ir\q@u{at}i alja\q@u{h}eem\q@b{i}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmdcccxii{Waqifoohum innahum masooloon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmdcccxiii{M\q@u{a} lakum l\q@u{a} tan\q@u{as}aroon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmdcccxiv{Bal humu alyawma mustaslimoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmdcccxv{Waaqbala baAA\q@u{d}uhum AAal\q@u{a} baAA\q@u{d}in yatas\q@u{a}aloon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmdcccxvi{Q\q@u{a}loo innakum kuntum tatoonan\q@u{a} AAani alyameen\q@b{i}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmdcccxvii{Q\q@u{a}loo bal lam takoonoo mumineen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmdcccxviii{Wam\q@u{a} k\q@u{a}na lan\q@u{a} AAalaykum min \q@u{s}ul\q@u{ta}nin bal kuntum qawman \q@u{ta}gheen\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmdcccxix{Fa\q@u{h}aqqa AAalayn\q@u{a} qawlu rabbin\q@u{a} inn\q@u{a} la\q@u{tha}iqoon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmdcccxx{Faaghwayn\q@u{a}kum inn\q@u{a} kunn\q@u{a} gh\q@u{a}ween\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxi{Fainnahum yawmai\q@u{th}in fee alAAa\q@u{tha}bi mushtarikoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxii{Inn\q@u{a} ka\q@u{tha}lika nafAAalu bi\q@b{a}lmujrimeen\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxiii{Innahum k\q@u{a}noo i\q@u{tha} qeela lahum l\q@u{a} il\q@u{a}ha ill\q@u{a} All\q@u{a}hu yastakbiroon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxiv{Wayaqooloona ainn\q@u{a} lat\q@u{a}rikoo \q@u{a}lihatin\q@u{a} lish\q@u{a}AAirin majnoon\q@b{in}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxv{Bal j\q@u{a}a bi\q@b{a}l\q@u{h}aqqi wa\q@u{s}addaqa almursaleen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxvi{Innakum la\q@u{tha}iqoo alAAa\q@u{tha}bi alaleem\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxvii{Wam\q@u{a} tujzawna ill\q@u{a} m\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxviii{Ill\q@u{a} AAib\q@u{a}da All\q@u{a}hi almukhla\q@u{s}een\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxix{Ol\q@u{a}ika lahum rizqun maAAloom\q@b{un}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxx{Faw\q@u{a}kihu wahum mukramoon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxxi{Fee jann\q@u{a}ti a\q@b{l}nnaAAeem\q@b{i}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxxii{AAal\q@u{a} sururin mutaq\q@u{a}bileen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxxiii{Yu\q@u{ta}fu AAalayhim bikasin min maAAeen\q@b{in}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxxiv{Bay\q@u{da}a la\q@u{thth}atin li\q@b{l}shsh\q@u{a}ribeen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxxv{L\q@u{a} feeh\q@u{a} ghawlun wal\q@u{a} hum AAanh\q@u{a} yunzafoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxxvi{WaAAindahum q\q@u{as}ir\q@u{a}tu a\q@b{l}\q@u{tt}arfi AAeen\q@b{un}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxxvii{Kaannahunna bay\q@u{d}un maknoon\q@b{un}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxxviii{Faaqbala baAA\q@u{d}uhum AAal\q@u{a} baAA\q@u{d}in yatas\q@u{a}aloon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmdcccxxxix{Q\q@u{a}la q\q@u{a}ilun minhum innee k\q@u{a}na lee qareen\q@b{un}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmdcccxl{Yaqoolu ainnaka lamina almu\q@u{s}addiqeen\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmdcccxli{Ai\q@u{tha} mitn\q@u{a} wakunn\q@u{a} tur\q@u{a}ban waAAi\q@i{\q@u{th}}\q@u{a}man ainn\q@u{a} lamadeenoon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmdcccxlii{Q\q@u{a}la hal antum mu\q@u{tt}aliAAoon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmdcccxliii{Fa\q@b{i}\q@u{tt}alaAAa fara\q@u{a}hu fee saw\q@u{a}i alja\q@u{h}eem\q@b{i}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmdcccxliv{Q\q@u{a}la ta\q@b{A}ll\q@u{a}hi in kidta laturdeen\q@b{i}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmdcccxlv{Walawl\q@u{a} niAAmatu rabbee lakuntu mina almu\q@u{hd}areen\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmdcccxlvi{Afam\q@u{a} na\q@u{h}nu bimayyiteen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmdcccxlvii{Ill\q@u{a} mawtatan\q@u{a} alool\q@u{a} wam\q@u{a} na\q@u{h}nu bimuAAa\q@u{thth}abeen\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmdcccxlviii{Inna h\q@u{atha} lahuwa alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmdcccxlix{Limithli h\q@u{atha} falyaAAmali alAA\q@u{a}miloon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmdcccl{A\q@u{tha}lika khayrun nuzulan am shajaratu a\q@b{l}zzaqqoom\q@b{i}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmdcccli{Inn\q@u{a} jaAAaln\q@u{a}h\q@u{a} fitnatan li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmdccclii{Innah\q@u{a} shajaratun takhruju fee a\q@u{s}li alja\q@u{h}eem\q@b{i}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmdcccliii{\q@u{T}alAAuh\q@u{a} kaannahu ruoosu a\q@b{l}shshay\q@u{at}een\q@b{i}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmdcccliv{Fainnahum la\q@u{a}kiloona minh\q@u{a} fam\q@u{a}lioona minh\q@u{a} albu\q@u{t}oon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmdccclv{Thumma inna lahum AAalayh\q@u{a} lashawban min \q@u{h}ameem\q@b{in}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmdccclvi{Thumma inna marjiAAahum lail\q@u{a} alja\q@u{h}eem\q@b{i}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmdccclvii{Innahum alfaw \q@u{a}b\q@u{a}ahum \q@u{da}lleen\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmdccclviii{Fahum AAal\q@u{a} \q@u{a}th\q@u{a}rihim yuhraAAoon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmdccclix{Walaqad \q@u{d}alla qablahum aktharu alawwaleen\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmdccclx{Walaqad arsaln\q@u{a} feehim mun\q@u{th}ireen\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmdccclxi{Fa\q@b{o}n\q@i{\q@u{th}}ur kayfa k\q@u{a}na AA\q@u{a}qibatu almun\q@u{th}areen\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmdccclxii{Ill\q@u{a} AAib\q@u{a}da All\q@u{a}hi almukhla\q@u{s}een\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmdccclxiii{Walaqad n\q@u{a}d\q@u{a}n\q@u{a} noo\q@u{h}un falaniAAma almujeeboon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmdccclxiv{Wanajjayn\q@u{a}hu waahlahu mina alkarbi alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmdccclxv{WajaAAaln\q@u{a} \q@u{th}urriyyatahu humu alb\q@u{a}qeen\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmdccclxvi{Watarakn\q@u{a} AAalayhi fee al\q@u{a}khireen\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmdccclxvii{Sal\q@u{a}mun AAal\q@u{a} noo\q@u{h}in fee alAA\q@u{a}lameen\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmmdccclxviii{Inn\q@u{a} ka\q@u{tha}lika najzee almu\q@u{h}sineen\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmmdccclxix{Innahu min AAib\q@u{a}din\q@u{a} almumineen\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmmdccclxx{Thumma aghraqn\q@u{a} al\q@u{a}khareen\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxi{Wainna min sheeAAatihi laibr\q@u{a}heem\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxii{I\q@u{th} j\q@u{a}a rabbahu biqalbin saleem\q@b{in}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxiii{I\q@u{th} q\q@u{a}la liabeehi waqawmihi m\q@u{atha} taAAbudoon\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxiv{Aifkan \q@u{a}lihatan doona All\q@u{a}hi tureedoon\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxv{Fam\q@u{a} \q@i{\q@u{th}}annukum birabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxvi{Fana\q@i{\q@u{th}}ara na\q@i{\q@u{th}}ratan fee a\q@b{l}nnujoom\q@b{i}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxvii{Faq\q@u{a}la innee saqeem\q@b{un}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxviii{Fatawallaw AAanhu mudbireen\q@b{a}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxix{Far\q@u{a}gha il\q@u{a} \q@u{a}lihatihim faq\q@u{a}la al\q@u{a} takuloon\q@b{a}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxx{M\q@u{a} lakum l\q@u{a} tan\q@u{t}iqoon\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxxi{Far\q@u{a}gha AAalayhim \q@u{d}arban bi\q@b{a}lyameen\q@b{i}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxxii{Faaqbaloo ilayhi yaziffoon\q@b{a}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxxiii{Q\q@u{a}la ataAAbudoona m\q@u{a} tan\q@u{h}itoon\q@b{a}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxxiv{Wa\q@b{A}ll\q@u{a}hu khalaqakum wam\q@u{a} taAAmaloon\q@b{a}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxxv{Q\q@u{a}loo ibnoo lahu buny\q@u{a}nan faalqoohu fee alja\q@u{h}eem\q@b{i}\qt@no{(97)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxxvi{Faar\q@u{a}doo bihi kaydan fajaAAaln\q@u{a}humu alasfaleen\q@b{a}\qt@no{(98)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxxvii{Waq\q@u{a}la innee \q@u{tha}hibun il\q@u{a} rabbee sayahdeen\q@b{i}\qt@no{(99)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxxviii{Rabbi hab lee mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(100)}}
\qt@newcmd\qurantrans@lt@mmmdccclxxxix{Fabashsharn\q@u{a}hu bighul\q@u{a}min \q@u{h}aleem\q@b{in}\qt@no{(101)}}
\qt@newcmd\qurantrans@lt@mmmdcccxc{Falamm\q@u{a} balagha maAAahu a\q@b{l}ssaAAya q\q@u{a}la y\q@u{a} bunayya innee ar\q@u{a} fee alman\q@u{a}mi annee a\q@u{th}ba\q@u{h}uka fa\q@b{o}n\q@i{\q@u{th}}ur m\q@u{atha} tar\q@u{a} q\q@u{a}la y\q@u{a} abati ifAAal m\q@u{a} tumaru satajidunee in sh\q@u{a}a All\q@u{a}hu mina a\q@b{l}\q@u{ssa}bireen\q@b{a}\qt@no{(102)}}
\qt@newcmd\qurantrans@lt@mmmdcccxci{Falamm\q@u{a} aslam\q@u{a} watallahu liljabeen\q@b{i}\qt@no{(103)}}
\qt@newcmd\qurantrans@lt@mmmdcccxcii{Wan\q@u{a}dayn\q@u{a}hu an y\q@u{a} ibr\q@u{a}heem\q@b{u}\qt@no{(104)}}
\qt@newcmd\qurantrans@lt@mmmdcccxciii{Qad \q@u{s}addaqta a\q@b{l}rruy\q@u{a} inn\q@u{a} ka\q@u{tha}lika najzee almu\q@u{h}sineen\q@b{a}\qt@no{(105)}}
\qt@newcmd\qurantrans@lt@mmmdcccxciv{Inna h\q@u{atha} lahuwa albal\q@u{a}o almubeen\q@b{u}\qt@no{(106)}}
\qt@newcmd\qurantrans@lt@mmmdcccxcv{Wafadayn\q@u{a}hu bi\q@u{th}ib\q@u{h}in AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(107)}}
\qt@newcmd\qurantrans@lt@mmmdcccxcvi{Watarakn\q@u{a} AAalayhi fee al\q@u{a}khireen\q@b{a}\qt@no{(108)}}
\qt@newcmd\qurantrans@lt@mmmdcccxcvii{Sal\q@u{a}mun AAal\q@u{a} ibr\q@u{a}heem\q@b{a}\qt@no{(109)}}
\qt@newcmd\qurantrans@lt@mmmdcccxcviii{Ka\q@u{tha}lika najzee almu\q@u{h}sineen\q@b{a}\qt@no{(110)}}
\qt@newcmd\qurantrans@lt@mmmdcccxcix{Innahu min AAib\q@u{a}din\q@u{a} almumineen\q@b{a}\qt@no{(111)}}
\qt@newcmd\qurantrans@lt@mmmcm{Wabashsharn\q@u{a}hu biis\q@u{ha}qa nabiyyan mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(112)}}
\qt@newcmd\qurantrans@lt@mmmcmi{Wab\q@u{a}rakn\q@u{a} AAalayhi waAAal\q@u{a} is\q@u{ha}qa wamin \q@u{th}urriyyatihim\q@u{a} mu\q@u{h}sinun wa\q@i{\q@u{th}}\q@u{a}limun linafsihi mubeen\q@b{un}\qt@no{(113)}}
\qt@newcmd\qurantrans@lt@mmmcmii{Walaqad manann\q@u{a} AAal\q@u{a} moos\q@u{a} wah\q@u{a}roon\q@b{a}\qt@no{(114)}}
\qt@newcmd\qurantrans@lt@mmmcmiii{Wanajjayn\q@u{a}hum\q@u{a} waqawmahum\q@u{a} mina alkarbi alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(115)}}
\qt@newcmd\qurantrans@lt@mmmcmiv{Wana\q@u{s}arn\q@u{a}hum fak\q@u{a}noo humu algh\q@u{a}libeen\q@b{a}\qt@no{(116)}}
\qt@newcmd\qurantrans@lt@mmmcmv{Wa\q@u{a}tayn\q@u{a}hum\q@u{a} alkit\q@u{a}ba almustabeen\q@b{a}\qt@no{(117)}}
\qt@newcmd\qurantrans@lt@mmmcmvi{Wahadayn\q@u{a}hum\q@u{a} a\q@b{l}\q@u{ss}ir\q@u{at}a almustaqeem\q@b{a}\qt@no{(118)}}
\qt@newcmd\qurantrans@lt@mmmcmvii{Watarakn\q@u{a} AAalayhim\q@u{a} fee al\q@u{a}khireen\q@b{a}\qt@no{(119)}}
\qt@newcmd\qurantrans@lt@mmmcmviii{Sal\q@u{a}mun AAal\q@u{a} moos\q@u{a} wah\q@u{a}roon\q@b{a}\qt@no{(120)}}
\qt@newcmd\qurantrans@lt@mmmcmix{Inn\q@u{a} ka\q@u{tha}lika najzee almu\q@u{h}sineen\q@b{a}\qt@no{(121)}}
\qt@newcmd\qurantrans@lt@mmmcmx{Innahum\q@u{a} min AAib\q@u{a}din\q@u{a} almumineen\q@b{a}\qt@no{(122)}}
\qt@newcmd\qurantrans@lt@mmmcmxi{Wainna ily\q@u{a}sa lamina almursaleen\q@b{a}\qt@no{(123)}}
\qt@newcmd\qurantrans@lt@mmmcmxii{I\q@u{th} q\q@u{a}la liqawmihi al\q@u{a} tattaqoon\q@b{a}\qt@no{(124)}}
\qt@newcmd\qurantrans@lt@mmmcmxiii{AtadAAoona baAAlan wata\q@u{th}aroona a\q@u{h}sana alkh\q@u{a}liqeen\q@b{a}\qt@no{(125)}}
\qt@newcmd\qurantrans@lt@mmmcmxiv{All\q@u{a}ha rabbakum warabba \q@u{a}b\q@u{a}ikumu alawwaleen\q@b{a}\qt@no{(126)}}
\qt@newcmd\qurantrans@lt@mmmcmxv{Faka\q@u{thth}aboohu fainnahum lamu\q@u{hd}aroon\q@b{a}\qt@no{(127)}}
\qt@newcmd\qurantrans@lt@mmmcmxvi{Ill\q@u{a} AAib\q@u{a}da All\q@u{a}hi almukhla\q@u{s}een\q@b{a}\qt@no{(128)}}
\qt@newcmd\qurantrans@lt@mmmcmxvii{Watarakn\q@u{a} AAalayhi fee al\q@u{a}khireen\q@b{a}\qt@no{(129)}}
\qt@newcmd\qurantrans@lt@mmmcmxviii{Sal\q@u{a}mun AAal\q@u{a} il y\q@u{a}seen\q@b{a}\qt@no{(130)}}
\qt@newcmd\qurantrans@lt@mmmcmxix{Inn\q@u{a} ka\q@u{tha}lika najzee almu\q@u{h}sineen\q@b{a}\qt@no{(131)}}
\qt@newcmd\qurantrans@lt@mmmcmxx{Innahu min AAib\q@u{a}din\q@u{a} almumineen\q@b{a}\qt@no{(132)}}
\qt@newcmd\qurantrans@lt@mmmcmxxi{Wainna loo\q@u{t}an lamina almursaleen\q@b{a}\qt@no{(133)}}
\qt@newcmd\qurantrans@lt@mmmcmxxii{I\q@u{th} najjayn\q@u{a}hu waahlahu ajmaAAeen\q@b{a}\qt@no{(134)}}
\qt@newcmd\qurantrans@lt@mmmcmxxiii{Ill\q@u{a} AAajoozan fee algh\q@u{a}bireen\q@b{a}\qt@no{(135)}}
\qt@newcmd\qurantrans@lt@mmmcmxxiv{Thumma dammarn\q@u{a} al\q@u{a}khareen\q@b{a}\qt@no{(136)}}
\qt@newcmd\qurantrans@lt@mmmcmxxv{Wainnakum latamurroona AAalayhim mu\q@u{s}bi\q@u{h}een\q@b{a}\qt@no{(137)}}
\qt@newcmd\qurantrans@lt@mmmcmxxvi{Wabi\q@b{a}llayli afal\q@u{a} taAAqiloon\q@b{a}\qt@no{(138)}}
\qt@newcmd\qurantrans@lt@mmmcmxxvii{Wainna yoonusa lamina almursaleen\q@b{a}\qt@no{(139)}}
\qt@newcmd\qurantrans@lt@mmmcmxxviii{I\q@u{th} abaqa il\q@u{a} alfulki almash\q@u{h}oon\q@b{i}\qt@no{(140)}}
\qt@newcmd\qurantrans@lt@mmmcmxxix{Fas\q@u{a}hama fak\q@u{a}na mina almud\q@u{h}a\q@u{d}een\q@b{a}\qt@no{(141)}}
\qt@newcmd\qurantrans@lt@mmmcmxxx{Fa\q@b{i}ltaqamahu al\q@u{h}ootu wahuwa muleem\q@b{un}\qt@no{(142)}}
\qt@newcmd\qurantrans@lt@mmmcmxxxi{Falawl\q@u{a} annahu k\q@u{a}na mina almusabbi\q@u{h}een\q@b{a}\qt@no{(143)}}
\qt@newcmd\qurantrans@lt@mmmcmxxxii{Lalabitha fee ba\q@u{t}nihi il\q@u{a} yawmi yubAAathoon\q@b{a}\qt@no{(144)}}
\qt@newcmd\qurantrans@lt@mmmcmxxxiii{Fanaba\q@u{th}n\q@u{a}hu bi\q@b{a}lAAar\q@u{a}i wahuwa saqeem\q@b{un}\qt@no{(145)}}
\qt@newcmd\qurantrans@lt@mmmcmxxxiv{Waanbatn\q@u{a} AAalayhi shajaratan min yaq\q@u{t}een\q@b{in}\qt@no{(146)}}
\qt@newcmd\qurantrans@lt@mmmcmxxxv{Waarsaln\q@u{a}hu il\q@u{a} miati alfin aw yazeedoon\q@b{a}\qt@no{(147)}}
\qt@newcmd\qurantrans@lt@mmmcmxxxvi{Fa\q@u{a}manoo famattaAAn\q@u{a}hum il\q@u{a} \q@u{h}een\q@b{in}\qt@no{(148)}}
\qt@newcmd\qurantrans@lt@mmmcmxxxvii{Fa\q@b{i}staftihim alirabbika alban\q@u{a}tu walahumu albanoon\q@b{a}\qt@no{(149)}}
\qt@newcmd\qurantrans@lt@mmmcmxxxviii{Am khalaqn\q@u{a} almal\q@u{a}ikata in\q@u{a}than wahum sh\q@u{a}hidoon\q@b{a}\qt@no{(150)}}
\qt@newcmd\qurantrans@lt@mmmcmxxxix{Al\q@u{a} innahum min ifkihim layaqooloon\q@b{a}\qt@no{(151)}}
\qt@newcmd\qurantrans@lt@mmmcmxl{Walada All\q@u{a}hu wainnahum lak\q@u{ath}iboon\q@b{a}\qt@no{(152)}}
\qt@newcmd\qurantrans@lt@mmmcmxli{A\q@u{st}af\q@u{a} alban\q@u{a}ti AAal\q@u{a} albaneen\q@b{a}\qt@no{(153)}}
\qt@newcmd\qurantrans@lt@mmmcmxlii{M\q@u{a} lakum kayfa ta\q@u{h}kumoon\q@b{a}\qt@no{(154)}}
\qt@newcmd\qurantrans@lt@mmmcmxliii{Afal\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(155)}}
\qt@newcmd\qurantrans@lt@mmmcmxliv{Am lakum sul\q@u{ta}nun mubeen\q@b{un}\qt@no{(156)}}
\qt@newcmd\qurantrans@lt@mmmcmxlv{Fatoo bikit\q@u{a}bikum in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(157)}}
\qt@newcmd\qurantrans@lt@mmmcmxlvi{WajaAAaloo baynahu wabayna aljinnati nasaban walaqad AAalimati aljinnatu innahum lamu\q@u{hd}aroon\q@b{a}\qt@no{(158)}}
\qt@newcmd\qurantrans@lt@mmmcmxlvii{Sub\q@u{ha}na All\q@u{a}hi AAamm\q@u{a} ya\q@u{s}ifoon\q@b{a}\qt@no{(159)}}
\qt@newcmd\qurantrans@lt@mmmcmxlviii{Ill\q@u{a} AAib\q@u{a}da All\q@u{a}hi almukhla\q@u{s}een\q@b{a}\qt@no{(160)}}
\qt@newcmd\qurantrans@lt@mmmcmxlix{Fainnakum wam\q@u{a} taAAbudoon\q@b{a}\qt@no{(161)}}
\qt@newcmd\qurantrans@lt@mmmcml{M\q@u{a} antum AAalayhi bif\q@u{a}tineen\q@b{a}\qt@no{(162)}}
\qt@newcmd\qurantrans@lt@mmmcmli{Ill\q@u{a} man huwa \q@u{sa}li alja\q@u{h}eem\q@b{i}\qt@no{(163)}}
\qt@newcmd\qurantrans@lt@mmmcmlii{Wam\q@u{a} minn\q@u{a} ill\q@u{a} lahu maq\q@u{a}mun maAAloom\q@b{un}\qt@no{(164)}}
\qt@newcmd\qurantrans@lt@mmmcmliii{Wainn\q@u{a} lana\q@u{h}nu a\q@b{l}\q@u{ssa}ffoon\q@b{a}\qt@no{(165)}}
\qt@newcmd\qurantrans@lt@mmmcmliv{Wainn\q@u{a} lana\q@u{h}nu almusabbi\q@u{h}oon\q@b{a}\qt@no{(166)}}
\qt@newcmd\qurantrans@lt@mmmcmlv{Wain k\q@u{a}noo layaqooloon\q@b{a}\qt@no{(167)}}
\qt@newcmd\qurantrans@lt@mmmcmlvi{Law anna AAindan\q@u{a} \q@u{th}ikran mina alawwaleen\q@b{a}\qt@no{(168)}}
\qt@newcmd\qurantrans@lt@mmmcmlvii{Lakunn\q@u{a} AAib\q@u{a}da All\q@u{a}hi almukhla\q@u{s}een\q@b{a}\qt@no{(169)}}
\qt@newcmd\qurantrans@lt@mmmcmlviii{Fakafaroo bihi fasawfa yaAAlamoon\q@b{a}\qt@no{(170)}}
\qt@newcmd\qurantrans@lt@mmmcmlix{Walaqad sabaqat kalimatun\q@u{a} liAAib\q@u{a}din\q@u{a} almursaleen\q@b{a}\qt@no{(171)}}
\qt@newcmd\qurantrans@lt@mmmcmlx{Innahum lahumu alman\q@u{s}ooroon\q@b{a}\qt@no{(172)}}
\qt@newcmd\qurantrans@lt@mmmcmlxi{Wainna jundan\q@u{a} lahumu algh\q@u{a}liboon\q@b{a}\qt@no{(173)}}
\qt@newcmd\qurantrans@lt@mmmcmlxii{Fatawalla AAanhum \q@u{h}att\q@u{a} \q@u{h}een\q@b{in}\qt@no{(174)}}
\qt@newcmd\qurantrans@lt@mmmcmlxiii{Waab\q@u{s}irhum fasawfa yub\q@u{s}iroon\q@b{a}\qt@no{(175)}}
\qt@newcmd\qurantrans@lt@mmmcmlxiv{AfabiAAa\q@u{tha}bin\q@u{a} yastaAAjiloon\q@b{a}\qt@no{(176)}}
\qt@newcmd\qurantrans@lt@mmmcmlxv{Fai\q@u{tha} nazala bis\q@u{ah}atihim fas\q@u{a}a \q@u{s}ab\q@u{ah}u almun\q@u{th}areen\q@b{a}\qt@no{(177)}}
\qt@newcmd\qurantrans@lt@mmmcmlxvi{Watawalla AAanhum \q@u{h}att\q@u{a} \q@u{h}een\q@b{in}\qt@no{(178)}}
\qt@newcmd\qurantrans@lt@mmmcmlxvii{Waab\q@u{s}ir fasawfa yub\q@u{s}iroon\q@b{a}\qt@no{(179)}}
\qt@newcmd\qurantrans@lt@mmmcmlxviii{Sub\q@u{ha}na rabbika rabbi alAAizzati AAamm\q@u{a} ya\q@u{s}ifoon\q@b{a}\qt@no{(180)}}
\qt@newcmd\qurantrans@lt@mmmcmlxix{Wasal\q@u{a}mun AAal\q@u{a} almursaleen\q@b{a}\qt@no{(181)}}
\qt@newcmd\qurantrans@lt@mmmcmlxx{Wa\q@b{a}l\q@u{h}amdu lill\q@u{a}hi rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(182)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxi{\basmalahlt \q@u{Sa}d wa\q@b{a}lqur\q@u{a}ni \q@u{th}ee a\q@b{l}\q@u{thth}ikr\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxii{Bali alla\q@u{th}eena kafaroo fee AAizzatin washiq\q@u{a}q\q@b{in}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxiii{Kam ahlakn\q@u{a} min qablihim min qarnin fan\q@u{a}daw wal\q@u{a}ta \q@u{h}eena man\q@u{as}\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxiv{WaAAajiboo an j\q@u{a}ahum mun\q@u{th}irun minhum waq\q@u{a}la alk\q@u{a}firoona h\q@u{atha }s\q@u{ah}irun ka\q@u{ththa}b\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxv{AjaAAala al\q@u{a}lihata il\q@u{a}han w\q@u{ah}idan inna h\q@u{atha} lashayon AAuj\q@u{a}b\q@b{un}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxvi{Wa\q@b{i}n\q@u{t}alaqa almalao minhum ani imshoo wa\q@b{i}\q@u{s}biroo AAal\q@u{a} \q@u{a}lihatikum inna h\q@u{atha} lashayon yur\q@u{a}d\q@b{u}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxvii{M\q@u{a} samiAAn\q@u{a} bih\q@u{atha} fee almillati al\q@u{a}khirati in h\q@u{atha} ill\q@u{a} ikhtil\q@u{a}q\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxviii{Aonzila AAalayhi a\q@b{l}\q@u{thth}ikru min baynin\q@u{a} bal hum fee shakkin min \q@u{th}ikree bal lamm\q@u{a} ya\q@u{th}ooqoo AAa\q@u{tha}b\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxix{Am AAindahum khaz\q@u{a}inu ra\q@u{h}mati rabbika alAAazeezi alwahh\q@u{a}b\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxx{Am lahum mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} falyartaqoo fee alasb\q@u{a}b\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxxi{Jundun m\q@u{a} hun\q@u{a}lika mahzoomun mina ala\q@u{h}z\q@u{a}b\q@b{i}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxxii{Ka\q@u{thth}abat qablahum qawmu noo\q@u{h}in waAA\q@u{a}dun wafirAAawnu \q@u{th}oo alawt\q@u{a}d\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxxiii{Wathamoodu waqawmu loo\q@u{t}in waa\q@u{s}\q@u{ha}bu alaykati ol\q@u{a}ika ala\q@u{h}z\q@u{a}b\q@b{u}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxxiv{In kullun ill\q@u{a} ka\q@u{thth}aba a\q@b{l}rrusula fa\q@u{h}aqqa AAiq\q@u{a}b\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxxv{Wam\q@u{a} yan\q@i{\q@u{th}}uru h\q@u{a}ol\q@u{a}i ill\q@u{a} \q@u{s}ay\q@u{h}atan w\q@u{ah}idatan m\q@u{a} lah\q@u{a} min faw\q@u{a}q\q@b{in}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxxvi{Waq\q@u{a}loo rabban\q@u{a} AAajjil lan\q@u{a} qi\q@u{tt}an\q@u{a} qabla yawmi al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxxvii{I\q@u{s}bir AAal\q@u{a} m\q@u{a} yaqooloona wa\q@b{o}\q@u{th}kur AAabdan\q@u{a} d\q@u{a}wooda \q@u{tha} alaydi innahu aww\q@u{a}b\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxxviii{Inn\q@u{a} sakhkharn\q@u{a} aljib\q@u{a}la maAAahu yusabbi\q@u{h}na bi\q@b{a}lAAashiyyi wa\q@b{a}lishr\q@u{a}q\q@b{i}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmcmlxxxix{Wa\q@b{al}\q@u{tt}ayra ma\q@u{h}shooratan kullun lahu aww\q@u{a}b\q@b{un}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmcmxc{Washadadn\q@u{a} mulkahu wa\q@u{a}tayn\q@u{a}hu al\q@u{h}ikmata wafa\q@u{s}la alkhi\q@u{ta}b\q@b{i}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmcmxci{Wahal at\q@u{a}ka nabao alkha\q@u{s}mi i\q@u{th} tasawwaroo almi\q@u{h}r\q@u{a}b\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmcmxcii{Ith dakhaloo AAal\q@u{a} d\q@u{a}wooda fafaziAAa minhum q\q@u{a}loo l\q@u{a} takhaf kha\q@u{s}m\q@u{a}ni bagh\q@u{a} baAA\q@u{d}un\q@u{a} AAal\q@u{a} baAA\q@u{d}in fa\q@b{o}\q@u{h}kum baynan\q@u{a} bi\q@b{a}l\q@u{h}aqqi wal\q@u{a} tush\q@u{t}i\q@u{t} wa\q@b{i}hdin\q@u{a} il\q@u{a} saw\q@u{a}i a\q@b{l}\q@u{ss}ir\q@u{at}\q@b{i}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmcmxciii{Inna h\q@u{atha} akhee lahu tisAAun watisAAoona naAAjatan waliya naAAjatun w\q@u{ah}idatun faq\q@u{a}la akfilneeh\q@u{a} waAAazzanee fee alkhi\q@u{ta}b\q@b{i}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmcmxciv{Q\q@u{a}la laqad \q@i{\q@u{th}}alamaka bisu\q@u{a}li naAAjatika il\q@u{a} niAA\q@u{a}jihi wainna katheeran mina alkhula\q@u{ta}i layabghee baAA\q@u{d}uhum AAal\q@u{a} baAA\q@u{d}in ill\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti waqaleelun m\q@u{a} hum wa\q@i{\q@u{th}}anna d\q@u{a}woodu annam\q@u{a} fatann\q@u{a}hu fa\q@b{i}staghfara rabbahu wakharra r\q@u{a}kiAAan waan\q@u{a}b\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmcmxcv{Faghafarn\q@u{a} lahu \q@u{tha}lika wainna lahu AAindan\q@u{a} lazulf\q@u{a} wa\q@u{h}usna ma\q@u{a}b\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmcmxcvi{Y\q@u{a} d\q@u{a}woodu inn\q@u{a} jaAAaln\q@u{a}ka khaleefatan fee alar\q@u{d}i fa\q@b{o}\q@u{h}kum bayna a\q@b{l}nn\q@u{a}si bi\q@b{a}l\q@u{h}aqqi wal\q@u{a} tattabiAAi alhaw\q@u{a} fayu\q@u{d}illaka AAan sabeeli All\q@u{a}hi inna alla\q@u{th}eena ya\q@u{d}illoona AAan sabeeli All\q@u{a}hi lahum AAa\q@u{tha}bun shadeedun bim\q@u{a} nasoo yawma al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmcmxcvii{Wam\q@u{a} khalaqn\q@u{a} a\q@b{l}ssam\q@u{a}a wa\q@b{a}lar\q@u{d}a wam\q@u{a} baynahum\q@u{a} b\q@u{at}ilan \q@u{tha}lika \q@i{\q@u{th}}annu alla\q@u{th}eena kafaroo fawaylun lilla\q@u{th}eena kafaroo mina a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmcmxcviii{Am najAAalu alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti ka\q@b{a}lmufsideena fee alar\q@u{d}i am najAAalu almuttaqeena ka\q@b{a}lfujj\q@u{a}r\q@b{i}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmcmxcix{Kit\q@u{a}bun anzaln\q@u{a}hu ilayka mub\q@u{a}rakun liyaddabbaroo \q@u{a}y\q@u{a}tihi waliyata\q@u{th}akkara oloo alalb\q@u{a}b\q@b{i}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmm{Wawahabn\q@u{a} lid\q@u{a}wooda sulaym\q@u{a}na niAAma alAAabdu innahu aww\q@u{a}b\q@b{un}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmi{I\q@u{th} AAuri\q@u{d}a AAalayhi bi\q@b{a}lAAashiyyi a\q@b{l}\q@u{ssa}fin\q@u{a}tu aljiy\q@u{a}d\q@b{u}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmii{Faq\q@u{a}la innee a\q@u{h}babtu \q@u{h}ubba alkhayri AAan \q@u{th}ikri rabbee \q@u{h}att\q@u{a} taw\q@u{a}rat bi\q@b{a}l\q@u{h}ij\q@u{a}b\q@b{i}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmiii{Ruddooh\q@u{a} AAalayya fa\q@u{t}afiqa mas\q@u{h}an bi\q@b{al}ssooqi wa\q@b{a}laAAn\q@u{a}q\q@b{i}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmiv{Walaqad fatann\q@u{a} sulaym\q@u{a}na waalqayn\q@u{a} AAal\q@u{a} kursiyyihi jasadan thumma an\q@u{a}b\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmv{Q\q@u{a}la rabbi ighfir lee wahab lee mulkan l\q@u{a} yanbaghee lia\q@u{h}adin min baAAdee innaka anta alwahh\q@u{a}b\q@b{u}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmvi{Fasakhkharn\q@u{a} lahu a\q@b{l}rree\q@u{h}a tajree biamrihi rukh\q@u{a}an \q@u{h}aythu a\q@u{sa}b\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmvii{Wa\q@b{al}shshay\q@u{at}eena kulla bann\q@u{a}in waghaww\q@u{as}\q@b{in}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmviii{Wa\q@u{a}khareena muqarraneena fee ala\q@u{s}f\q@u{a}d\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmix{H\q@u{atha} AAa\q@u{ta}on\q@u{a} fa\q@b{o}mnun aw amsik bighayri \q@u{h}is\q@u{a}b\q@b{in}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmx{Wainna lahu AAindan\q@u{a} lazulf\q@u{a} wa\q@u{h}usna ma\q@u{a}b\q@b{in}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmxi{Wa\q@b{o}\q@u{th}kur AAabdan\q@u{a} ayyooba i\q@u{th} n\q@u{a}d\q@u{a} rabbahu annee massaniya a\q@b{l}shshay\q@u{ta}nu binu\q@u{s}bin waAAa\q@u{tha}b\q@b{in}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmxii{Orku\q@u{d} birijlika h\q@u{atha} mughtasalun b\q@u{a}ridun washar\q@u{a}b\q@b{un}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmxiii{Wawahabn\q@u{a} lahu ahlahu wamithlahum maAAahum ra\q@u{h}matan minn\q@u{a }wa\q@u{th}ikr\q@u{a} liolee alalb\q@u{a}b\q@b{i}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmxiv{Wakhu\q@u{th} biyadika \q@u{d}ighthan fa\q@b{i}\q@u{d}rib bihi wal\q@u{a} ta\q@u{h}nath inn\q@u{a} wajadn\q@u{a}hu \q@u{sa}biran niAAma alAAabdu innahu aww\q@u{a}b\q@b{un}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmxv{Wa\q@b{o}\q@u{th}kur AAib\q@u{a}dan\q@u{a} ibr\q@u{a}heema wais\q@u{ha}qa wayaAAqooba olee alaydee wa\q@b{a}lab\q@u{sa}r\q@b{i}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmxvi{Inn\q@u{a} akhla\q@u{s}n\q@u{a}hum bikh\q@u{a}li\q@u{s}atin \q@u{th}ikr\q@u{a} a\q@b{l}dd\q@u{a}r\q@b{i}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmxvii{Wainnahum AAindan\q@u{a} lamina almu\q@u{st}afayna alakhy\q@u{a}r\q@b{i}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmxviii{Wa\q@b{o}\q@u{th}kur ism\q@u{a}AAeela wailyasaAAa wa\q@u{tha} alkifli wakullun mina alakhy\q@u{a}r\q@b{i}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmxix{H\q@u{atha} \q@u{th}ikrun wainna lilmuttaqeena la\q@u{h}usna ma\q@u{a}b\q@b{in}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmxx{Jann\q@u{a}ti AAadnin mufatta\q@u{h}atan lahumu alabw\q@u{a}b\q@b{u}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmxxi{Muttakieena feeh\q@u{a} yadAAoona feeh\q@u{a} bif\q@u{a}kihatin katheeratin washar\q@u{a}b\q@b{in}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmxxii{WaAAindahum q\q@u{as}ir\q@u{a}tu a\q@b{l}\q@u{tt}arfi atr\q@u{a}b\q@b{un}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmxxiii{H\q@u{atha} m\q@u{a} tooAAadoona liyawmi al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmxxiv{Inna h\q@u{atha} larizqun\q@u{a} m\q@u{a} lahu min naf\q@u{a}d\q@b{in}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmxxv{H\q@u{atha} wainna li\q@b{l}\q@u{tta}gheena lasharra ma\q@u{a}b\q@b{in}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmxxvi{Jahannama ya\q@u{s}lawnah\q@u{a} fabisa almih\q@u{a}d\q@b{u}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmxxvii{H\q@u{atha} falya\q@u{th}ooqoohu \q@u{h}ameemun waghass\q@u{a}q\q@b{un}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmmxxviii{Wa\q@u{a}kharu min shaklihi azw\q@u{a}j\q@b{un}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmmxxix{H\q@u{atha} fawjun muqta\q@u{h}imun maAAakum l\q@u{a} mar\q@u{h}aban bihim innahum \q@u{sa}loo a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmmxxx{Q\q@u{a}loo bal antum l\q@u{a} mar\q@u{h}aban bikum antum qaddamtumoohu lan\q@u{a} fabisa alqar\q@u{a}r\q@b{u}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmmxxxi{Q\q@u{a}loo rabban\q@u{a} man qaddama lan\q@u{a} h\q@u{atha} fazidhu AAa\q@u{tha}ban \q@u{d}iAAfan fee a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmmxxxii{Waq\q@u{a}loo m\q@u{a} lan\q@u{a} l\q@u{a} nar\q@u{a} rij\q@u{a}lan kunn\q@u{a} naAAudduhum mina alashr\q@u{a}r\q@b{i}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmmxxxiii{Attakha\q@u{th}n\q@u{a}hum sikhriyyan am z\q@u{a}ghat AAanhumu alab\q@u{sa}r\q@b{u}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmmxxxiv{Inna \q@u{tha}lika la\q@u{h}aqqun takh\q@u{as}umu ahli a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmmxxxv{Qul innam\q@u{a} an\q@u{a} mun\q@u{th}irun wam\q@u{a} min il\q@u{a}hin ill\q@u{a} All\q@u{a}hu alw\q@u{ah}idu alqahh\q@u{a}r\q@b{u}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmmxxxvi{Rabbu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} alAAazeezu alghaff\q@u{a}r\q@b{u}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmmxxxvii{Qul huwa nabaon AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmmxxxviii{Antum AAanhu muAAri\q@u{d}oon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmmxxxix{M\q@u{a} k\q@u{a}na liya min AAilmin bi\q@b{a}lmalai alaAAl\q@u{a} i\q@u{th} yakhta\q@u{s}imoon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmmxl{In yoo\q@u{ha} ilayya ill\q@u{a} annam\q@u{a} an\q@u{a} na\q@u{th}eerun mubeen\q@b{un}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmmxli{I\q@u{th} q\q@u{a}la rabbuka lilmal\q@u{a}ikati innee kh\q@u{a}liqun basharan min \q@u{t}een\q@b{in}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmmxlii{Fai\q@u{tha} sawwaytuhu wanafakhtu feehi min roo\q@u{h}ee faqaAAoo lahu s\q@u{a}jideen\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmmxliii{Fasajada almal\q@u{a}ikatu kulluhum ajmaAAoon\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmmxliv{Ill\q@u{a} ibleesa istakbara wak\q@u{a}na mina alk\q@u{a}fireen\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmmxlv{Q\q@u{a}la y\q@u{a} ibleesu m\q@u{a} manaAAaka an tasjuda lim\q@u{a} khalaqtu biyadayya astakbarta am kunta mina alAA\q@u{a}leen\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmmxlvi{Q\q@u{a}la an\q@u{a} khayrun minhu khalaqtanee min n\q@u{a}rin wakhalaqtahu min \q@u{t}een\q@b{in}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmmxlvii{Q\q@u{a}la fa\q@b{o}khruj minh\q@u{a} fainnaka rajeem\q@b{un}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmmxlviii{Wainna AAalayka laAAnatee il\q@u{a} yawmi a\q@b{l}ddeen\q@b{i}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmmxlix{Q\q@u{a}la rabbi faan\q@i{\q@u{th}}irnee il\q@u{a} yawmi yubAAathoon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmmml{Q\q@u{a}la fainnaka mina almun\q@i{\q@u{th}}areen\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmmmli{Il\q@u{a} yawmi alwaqti almaAAloom\q@b{i}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmmmlii{Q\q@u{a}la fabiAAizzatika laoghwiyannahum ajmaAAeen\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmmmliii{Ill\q@u{a} AAib\q@u{a}daka minhumu almukhla\q@u{s}een\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmmmliv{Q\q@u{a}la fa\q@b{a}l\q@u{h}aqqu wa\q@b{a}l\q@u{h}aqqa aqool\q@b{u}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmmmlv{Laamlaanna jahannama minka wamimman tabiAAaka minhum ajmaAAeen\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmmmlvi{Qul m\q@u{a} asalukum AAalayhi min ajrin wam\q@u{a} an\q@u{a} mina almutakallifeen\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmmmlvii{In huwa ill\q@u{a} \q@u{th}ikrun lilAA\q@u{a}lameen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmmmlviii{WalataAAlamunna nabaahu baAAda \q@u{h}een\q@b{in}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmmmlix{\basmalahlt Tanzeelu alkit\q@u{a}bi mina All\q@u{a}hi alAAazeezi al\q@u{h}akeem\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmlx{Inn\q@u{a} anzaln\q@u{a} ilayka alkit\q@u{a}ba bi\q@b{a}l\q@u{h}aqqi fa\q@b{o}AAbudi All\q@u{a}ha mukhli\q@u{s}an lahu a\q@b{l}ddeen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmlxi{Al\q@u{a} lill\q@u{a}hi a\q@b{l}ddeenu alkh\q@u{a}li\q@u{s}u wa\q@b{a}lla\q@u{th}eena ittakha\q@u{th}oo min doonihi awliy\q@u{a}a m\q@u{a} naAAbuduhum ill\q@u{a} liyuqarriboon\q@u{a} il\q@u{a} All\q@u{a}hi zulf\q@u{a} inna All\q@u{a}ha ya\q@u{h}kumu baynahum fee m\q@u{a} hum feehi yakhtalifoona inna All\q@u{a}ha l\q@u{a} yahdee man huwa k\q@u{ath}ibun kaff\q@u{a}r\q@b{un}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmlxii{Law ar\q@u{a}da All\q@u{a}hu an yattakhi\q@u{th}a waladan la\q@b{i}\q@u{st}af\q@u{a} mimm\q@u{a} yakhluqu m\q@u{a} yash\q@u{a}o sub\q@u{ha}nahu huwa All\q@u{a}hu alw\q@u{ah}idu alqahh\q@u{a}r\q@b{u}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmlxiii{Khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a bi\q@b{a}l\q@u{h}aqqi yukawwiru allayla AAal\q@u{a} a\q@b{l}nnah\q@u{a}ri wayukawwiru a\q@b{l}nnah\q@u{a}ra AAal\q@u{a} allayli wasakhkhara a\q@b{l}shshamsa wa\q@b{a}lqamara kullun yajree liajalin musamman al\q@u{a} huwa alAAazeezu alghaff\q@u{a}r\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmlxiv{Khalaqakum min nafsin w\q@u{ah}idatin thumma jaAAala minh\q@u{a} zawjah\q@u{a} waanzala lakum mina alanAA\q@u{a}mi tham\q@u{a}niyata azw\q@u{a}jin yakhluqukum fee bu\q@u{t}ooni ommah\q@u{a}tikum khalqan min baAAdi khalqin fee \q@i{\q@u{th}}ulum\q@u{a}tin thal\q@u{a}thin \q@u{tha}likumu All\q@u{a}hu rabbukum lahu almulku l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa faann\q@u{a} tu\q@u{s}rafoon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmlxv{In takfuroo fainna All\q@u{a}ha ghaniyyun AAankum wal\q@u{a} yar\q@u{da} liAAib\q@u{a}dihi alkufra wain tashkuroo yar\q@u{d}ahu lakum wal\q@u{a} taziru w\q@u{a}ziratun wizra okhr\q@u{a} thumma il\q@u{a} rabbikum marjiAAukum fayunabbiokum bim\q@u{a} kuntum taAAmaloona innahu AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmlxvi{Wai\q@u{tha} massa alins\q@u{a}na \q@u{d}urrun daAA\q@u{a} rabbahu muneeban ilayhi thumma i\q@u{tha} khawwalahu niAAmatan minhu nasiya m\q@u{a} k\q@u{a}na yadAAoo ilayhi min qablu wajaAAala lill\q@u{a}hi and\q@u{a}dan liyu\q@u{d}illa AAan sabeelihi qul tamattaAA bikufrika qaleelan innaka min a\q@u{s}\q@u{ha}bi a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmlxvii{Amman huwa q\q@u{a}nitun \q@u{a}n\q@u{a}a allayli s\q@u{a}jidan waq\q@u{a}iman ya\q@u{hth}aru al\q@u{a}khirata wayarjoo ra\q@u{h}mata rabbihi qul hal yastawee alla\q@u{th}eena yaAAlamoona wa\q@b{a}lla\q@u{th}eena l\q@u{a} yaAAlamoona innam\q@u{a} yata\q@u{th}akkaru oloo alalb\q@u{a}b\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmlxviii{Qul y\q@u{a} AAib\q@u{a}di alla\q@u{th}eena \q@u{a}manoo ittaqoo rabbakum lilla\q@u{th}eena a\q@u{h}sanoo fee h\q@u{ath}ihi a\q@b{l}dduny\q@u{a} \q@u{h}asanatun waar\q@u{d}u All\q@u{a}hi w\q@u{a}siAAatun innam\q@u{a} yuwaff\q@u{a} a\q@b{l}\q@u{ssa}biroona ajrahum bighayri \q@u{h}is\q@u{a}b\q@b{in}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmlxix{Qul innee omirtu an aAAbuda All\q@u{a}ha mukhli\q@u{s}an lahu a\q@b{l}ddeen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmlxx{Waomirtu lian akoona awwala almuslimeen\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmlxxi{Qul innee akh\q@u{a}fu in AAa\q@u{s}aytu rabbee AAa\q@u{tha}ba yawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmlxxii{Quli All\q@u{a}ha aAAbudu mukhli\q@u{s}an lahu deenee\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmlxxiii{Fa\q@b{o}AAbudoo m\q@u{a} shitum min doonihi qul inna alkh\q@u{a}sireena alla\q@u{th}eena khasiroo anfusahum waahleehim yawma alqiy\q@u{a}mati al\q@u{a} \q@u{tha}lika huwa alkhusr\q@u{a}nu almubeen\q@b{u}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmlxxiv{Lahum min fawqihim \q@i{\q@u{th}}ulalun mina a\q@b{l}nn\q@u{a}ri wamin ta\q@u{h}tihim \q@i{\q@u{th}}ulalun \q@u{tha}lika yukhawwifu All\q@u{a}hu bihi AAib\q@u{a}dahu y\q@u{a} AAib\q@u{a}di fa\q@b{i}ttaqoon\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmlxxv{Wa\q@b{a}lla\q@u{th}eena ijtanaboo a\q@b{l}\q@u{tta}ghoota an yaAAbudooh\q@u{a} waan\q@u{a}boo il\q@u{a} All\q@u{a}hi lahumu albushr\q@u{a} fabashshir AAib\q@u{a}d\q@b{i}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmlxxvi{Alla\q@u{th}eena yastamiAAoona alqawla fayattabiAAoona a\q@u{h}sanahu ol\q@u{a}ika alla\q@u{th}eena had\q@u{a}humu All\q@u{a}hu waol\q@u{a}ika hum oloo alalb\q@u{a}b\q@b{i}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmlxxvii{Afaman \q@u{h}aqqa AAalayhi kalimatu alAAa\q@u{tha}bi afaanta tunqi\q@u{th}u man fee a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmlxxviii{L\q@u{a}kini alla\q@u{th}eena ittaqaw rabbahum lahum ghurafun min fawqih\q@u{a} ghurafun mabniyyatun tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru waAAda All\q@u{a}hi l\q@u{a} yukhlifu All\q@u{a}hu almeeAA\q@u{a}d\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmlxxix{Alam tara anna All\q@u{a}ha anzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an fasalakahu yan\q@u{a}beeAAa fee alar\q@u{d}i thumma yukhriju bihi zarAAan mukhtalifan alw\q@u{a}nuhu thumma yaheeju fatar\q@u{a}hu mu\q@u{s}farran thumma yajAAaluhu \q@u{h}u\q@u{ta}man inna fee \q@u{tha}lika la\q@u{th}ikr\q@u{a} liolee alalb\q@u{a}b\q@b{i}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmlxxx{Afaman shara\q@u{h}a All\q@u{a}hu \q@u{s}adrahu lilisl\q@u{a}mi fahuwa AAal\q@u{a} noorin min rabbihi fawaylun lilq\q@u{a}siyati quloobuhum min \q@u{th}ikri All\q@u{a}hi ol\q@u{a}ika fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmlxxxi{All\q@u{a}hu nazzala a\q@u{h}sana al\q@u{h}adeethi kit\q@u{a}ban mutash\q@u{a}bihan math\q@u{a}niya taqshaAAirru minhu juloodu alla\q@u{th}eena yakhshawna rabbahum thumma taleenu julooduhum waquloobuhum il\q@u{a} \q@u{th}ikri All\q@u{a}hi \q@u{tha}lika hud\q@u{a} All\q@u{a}hi yahdee bihi man yash\q@u{a}o waman yu\q@u{d}lili All\q@u{a}hu fam\q@u{a} lahu min h\q@u{a}d\q@b{in}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmlxxxii{Afaman yattaqee biwajhihi sooa alAAa\q@u{tha}bi yawma alqiy\q@u{a}mati waqeela li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena \q@u{th}ooqoo m\q@u{a} kuntum taksiboon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmlxxxiii{Ka\q@u{thth}aba alla\q@u{th}eena min qablihim faat\q@u{a}humu alAAa\q@u{tha}bu min \q@u{h}aythu l\q@u{a} yashAAuroon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmlxxxiv{Faa\q@u{tha}qahumu All\q@u{a}hu alkhizya fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} walaAAa\q@u{tha}bu al\q@u{a}khirati akbaru law k\q@u{a}noo yaAAlamoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmlxxxv{Walaqad \q@u{d}arabn\q@u{a} li\q@b{l}nn\q@u{a}si fee h\q@u{atha} alqur\q@u{a}ni min kulli mathalin laAAallahum yata\q@u{th}akkaroon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmlxxxvi{Qur\q@u{a}nan AAarabiyyan ghayra \q@u{th}ee AAiwajin laAAallahum yattaqoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmlxxxvii{\q@u{D}araba All\q@u{a}hu mathalan rajulan feehi shurak\q@u{a}o mutash\q@u{a}kisoona warajulan salaman lirajulin hal yastawiy\q@u{a}ni mathalan al\q@u{h}amdu lill\q@u{a}hi bal aktharuhum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmlxxxviii{Innaka mayyitun wainnahum mayyitoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmlxxxix{Thumma innakum yawma alqiy\q@u{a}mati AAinda rabbikum takhta\q@u{s}imoon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmxc{Faman a\q@i{\q@u{th}}lamu mimman ka\q@u{th}aba AAal\q@u{a} All\q@u{a}hi waka\q@u{thth}aba bi\q@b{al}\q@u{ss}idqi i\q@u{th} j\q@u{a}ahu alaysa fee jahannama mathwan lilk\q@u{a}fireen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmxci{Wa\q@b{a}lla\q@u{th}ee j\q@u{a}a bi\q@b{al}\q@u{ss}idqi wa\q@u{s}addaqa bihi ol\q@u{a}ika humu almuttaqoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmxcii{Lahum m\q@u{a} yash\q@u{a}oona AAinda rabbihim \q@u{tha}lika jaz\q@u{a}o almu\q@u{h}sineen\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmxciii{Liyukaffira All\q@u{a}hu AAanhum aswaa alla\q@u{th}ee AAamiloo wayajziyahum ajrahum bia\q@u{h}sani alla\q@u{th}ee k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmxciv{Alaysa All\q@u{a}hu bik\q@u{a}fin AAabdahu wayukhawwifoonaka bi\q@b{a}lla\q@u{th}eena min doonihi waman yu\q@u{d}lili All\q@u{a}hu fam\q@u{a} lahu min h\q@u{a}d\q@b{in}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmxcv{Waman yahdi All\q@u{a}hu fam\q@u{a} lahu min mu\q@u{d}illin alaysa All\q@u{a}hu biAAazeezin \q@u{th}ee intiq\q@u{a}m\q@b{in}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmxcvi{Walain saaltahum man khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a layaqoolunna All\q@u{a}hu qul afaraaytum m\q@u{a} tadAAoona min dooni All\q@u{a}hi in ar\q@u{a}daniya All\q@u{a}hu bi\q@u{d}urrin hal hunna k\q@u{a}shif\q@u{a}tu \q@u{d}urrihi aw ar\q@u{a}danee bira\q@u{h}matin hal hunna mumsik\q@u{a}tu ra\q@u{h}matihi qul \q@u{h}asbiya All\q@u{a}hu AAalayhi yatawakkalu almutawakkiloon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmxcvii{Qul y\q@u{a} qawmi iAAmaloo AAal\q@u{a} mak\q@u{a}natikum innee AA\q@u{a}milun fasawfa taAAlamoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmxcviii{Man yateehi AAa\q@u{tha}bun yukhzeehi waya\q@u{h}illu AAalayhi AAa\q@u{tha}bun muqeem\q@b{un}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmxcix{Inn\q@u{a} anzaln\q@u{a} AAalayka alkit\q@u{a}ba li\q@b{l}nn\q@u{a}si bi\q@b{a}l\q@u{h}aqqi famani ihtad\q@u{a} falinafsihi waman \q@u{d}alla fainnam\q@u{a} ya\q@u{d}illu AAalayh\q@u{a} wam\q@u{a} anta AAalayhim biwakeel\q@b{in}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmc{All\q@u{a}hu yatawaff\q@u{a} alanfusa \q@u{h}eena mawtih\q@u{a} wa\q@b{a}llatee lam tamut fee man\q@u{a}mih\q@u{a} fayumsiku allatee qa\q@u{da} AAalayh\q@u{a} almawta wayursilu alokhr\q@u{a} il\q@u{a} ajalin musamman inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yatafakkaroon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmci{Ami ittakha\q@u{th}oo min dooni All\q@u{a}hi shufaAA\q@u{a}a qul awalaw k\q@u{a}noo l\q@u{a} yamlikoona shayan wal\q@u{a} yaAAqiloon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmcii{Qul lill\q@u{a}hi a\q@b{l}shshaf\q@u{a}AAatu jameeAAan lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i thumma ilayhi turjaAAoon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmciii{Wai\q@u{tha} \q@u{th}ukira All\q@u{a}hu wa\q@u{h}dahu ishmaazzat quloobu alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati wai\q@u{tha} \q@u{th}ukira alla\q@u{th}eena min doonihi i\q@u{tha} hum yastabshiroon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmciv{Quli all\q@u{a}humma f\q@u{at}ira a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i AA\q@u{a}lima alghaybi wa\q@b{al}shshah\q@u{a}dati anta ta\q@u{h}kumu bayna AAib\q@u{a}dika fee m\q@u{a} k\q@u{a}noo feehi yakhtalifoon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmcv{Walaw anna lilla\q@u{th}eena \q@i{\q@u{th}}alamoo m\q@u{a} fee alar\q@u{d}i jameeAAan wamithlahu maAAahu la\q@b{i}ftadaw bihi min sooi alAAa\q@u{tha}bi yawma alqiy\q@u{a}mati wabad\q@u{a} lahum mina All\q@u{a}hi m\q@u{a} lam yakoonoo ya\q@u{h}tasiboon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmcvi{Wabad\q@u{a} lahum sayyi\q@u{a}tu m\q@u{a} kasaboo wa\q@u{ha}qa bihim m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmcvii{Fai\q@u{tha} massa alins\q@u{a}na \q@u{d}urrun daAA\q@u{a}n\q@u{a} thumma i\q@u{tha} khawwaln\q@u{a}hu niAAmatan minn\q@u{a} q\q@u{a}la innam\q@u{a} ooteetuhu AAal\q@u{a} AAilmin bal hiya fitnatun wal\q@u{a}kinna aktharahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmcviii{Qad q\q@u{a}lah\q@u{a} alla\q@u{th}eena min qablihim fam\q@u{a} aghn\q@u{a} AAanhum m\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmcix{Faa\q@u{sa}bahum sayyi\q@u{a}tu m\q@u{a} kasaboo wa\q@b{a}lla\q@u{th}eena \q@i{\q@u{th}}alamoo min h\q@u{a}ol\q@u{a}i sayu\q@u{s}eebuhum sayyi\q@u{a}tu m\q@u{a} kasaboo wam\q@u{a} hum bimuAAjizeen\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmcx{Awalam yaAAlamoo anna All\q@u{a}ha yabsu\q@u{t}u a\q@b{l}rrizqa liman yash\q@u{a}o wayaqdiru inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yuminoon\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmcxi{Qul y\q@u{a} AAib\q@u{a}diya alla\q@u{th}eena asrafoo AAal\q@u{a} anfusihim l\q@u{a} taqna\q@u{t}oo min ra\q@u{h}mati All\q@u{a}hi inna All\q@u{a}ha yaghfiru a\q@b{l}\q@u{thth}unooba jameeAAan innahu huwa alghafooru a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmcxii{Waaneeboo il\q@u{a} rabbikum waaslimoo lahu min qabli an yatiyakumu alAAa\q@u{tha}bu thumma l\q@u{a} tun\q@u{s}aroon\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmcxiii{Wa\q@b{i}ttabiAAoo a\q@u{h}sana m\q@u{a} onzila ilaykum min rabbikum min qabli an yatiyakumu alAAa\q@u{tha}bu baghtatan waantum l\q@u{a} tashAAuroon\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmcxiv{An taqoola nafsun y\q@u{a} \q@u{h}asrat\q@u{a} AAal\q@u{a} m\q@u{a} farra\q@u{t}tu fee janbi All\q@u{a}hi wain kuntu lamina a\q@b{l}ss\q@u{a}khireen\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmcxv{Aw taqoola law anna All\q@u{a}ha had\q@u{a}nee lakuntu mina almuttaqeen\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmmcxvi{Aw taqoola \q@u{h}eena tar\q@u{a} alAAa\q@u{tha}ba law anna lee karratan faakoona mina almu\q@u{h}sineen\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmmcxvii{Bal\q@u{a} qad j\q@u{a}atka \q@u{a}y\q@u{a}tee faka\q@u{thth}abta bih\q@u{a} wa\q@b{i}stakbarta wakunta mina alk\q@u{a}fireen\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmmcxviii{Wayawma alqiy\q@u{a}mati tar\q@u{a} alla\q@u{th}eena ka\q@u{th}aboo AAal\q@u{a} All\q@u{a}hi wujoohuhum muswaddatun alaysa fee jahannama mathwan lilmutakabbireen\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmmcxix{Wayunajjee All\q@u{a}hu alla\q@u{th}eena ittaqaw bimaf\q@u{a}zatihim l\q@u{a} yamassuhumu a\q@b{l}ssooo wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmmcxx{All\q@u{a}hu kh\q@u{a}liqu kulli shayin wahuwa AAal\q@u{a} kulli shayin wakeel\q@b{un}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmmcxxi{Lahu maq\q@u{a}leedu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{a}lla\q@u{th}eena kafaroo bi\q@u{a}y\q@u{a}ti All\q@u{a}hi ol\q@u{a}ika humu alkh\q@u{a}siroon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmmcxxii{Qul afaghayra All\q@u{a}hi tamuroonnee aAAbudu ayyuh\q@u{a} alj\q@u{a}hiloon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmmcxxiii{Walaqad oo\q@u{h}iya ilayka wail\q@u{a} alla\q@u{th}eena min qablika lain ashrakta laya\q@u{h}ba\q@u{t}anna AAamaluka walatakoonanna mina alkh\q@u{a}sireen\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmmcxxiv{Bali All\q@u{a}ha fa\q@b{o}AAbud wakun mina a\q@b{l}shsh\q@u{a}kireen\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmmcxxv{Wam\q@u{a} qadaroo All\q@u{a}ha \q@u{h}aqqa qadrihi wa\q@b{a}lar\q@u{d}u jameeAAan qab\q@u{d}atuhu yawma alqiy\q@u{a}mati wa\q@b{al}ssam\q@u{a}w\q@u{a}tu ma\q@u{t}wiyy\q@u{a}tun biyameenihi sub\q@u{ha}nahu wataAA\q@u{a}l\q@u{a} AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmmcxxvi{Wanufikha fee a\q@b{l}\q@u{ss}oori fa\q@u{s}aAAiqa man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti waman fee alar\q@u{d}i ill\q@u{a} man sh\q@u{a}a All\q@u{a}hu thumma nufikha feehi okhr\q@u{a} fai\q@u{tha} hum qiy\q@u{a}mun yan\q@i{\q@u{th}}uroon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmmcxxvii{Waashraqati alar\q@u{d}u binoori rabbih\q@u{a} wawu\q@u{d}iAAa alkit\q@u{a}bu wajeea bi\q@b{al}nnabiyyeena wa\q@b{al}shshuhad\q@u{a}i waqu\q@u{d}iya baynahum bi\q@b{a}l\q@u{h}aqqi wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmmcxxviii{Wawuffiyat kullu nafsin m\q@u{a} AAamilat wahuwa aAAlamu bim\q@u{a} yafAAaloon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmmcxxix{Waseeqa alla\q@u{th}eena kafaroo il\q@u{a} jahannama zumaran \q@u{h}att\q@u{a} i\q@u{tha} j\q@u{a}ooh\q@u{a} futi\q@u{h}at abw\q@u{a}buh\q@u{a} waq\q@u{a}la lahum khazanatuh\q@u{a} alam yatikum rusulun minkum yatloona AAalaykum \q@u{a}y\q@u{a}ti rabbikum wayun\q@u{th}iroonakum liq\q@u{a}a yawmikum h\q@u{atha} q\q@u{a}loo bal\q@u{a} wal\q@u{a}kin \q@u{h}aqqat kalimatu alAAa\q@u{tha}bi AAal\q@u{a} alk\q@u{a}fireen\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmmcxxx{Qeela odkhuloo abw\q@u{a}ba jahannama kh\q@u{a}lideena feeh\q@u{a} fabisa mathw\q@u{a} almutakabbireen\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmmcxxxi{Waseeqa alla\q@u{th}eena ittaqaw rabbahum il\q@u{a} aljannati zumaran \q@u{h}att\q@u{a} i\q@u{tha} j\q@u{a}ooh\q@u{a} wafuti\q@u{h}at abw\q@u{a}buh\q@u{a} waq\q@u{a}la lahum khazanatuh\q@u{a} sal\q@u{a}mun AAalaykum \q@u{t}ibtum fa\q@b{o}dkhulooh\q@u{a} kh\q@u{a}lideen\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmmcxxxii{Waq\q@u{a}loo al\q@u{h}amdu lill\q@u{a}hi alla\q@u{th}ee \q@u{s}adaqan\q@u{a} waAAdahu waawrathan\q@u{a} alar\q@u{d}a natabawwao mina aljannati \q@u{h}aythu nash\q@u{a}o faniAAma ajru alAA\q@u{a}mileen\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmmcxxxiii{Watar\q@u{a} almal\q@u{a}ikata \q@u{ha}ffeena min \q@u{h}awli alAAarshi yusabbi\q@u{h}oona bi\q@u{h}amdi rabbihim waqu\q@u{d}iya baynahum bi\q@b{a}l\q@u{h}aqqi waqeela al\q@u{h}amdu lill\q@u{a}hi rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmmcxxxiv{\basmalahlt \q@u{Ha}meem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmcxxxv{Tanzeelu alkit\q@u{a}bi mina All\q@u{a}hi alAAazeezi alAAaleem\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmcxxxvi{Gh\q@u{a}firi a\q@b{l}\q@u{thth}anbi waq\q@u{a}bili a\q@b{l}ttawbi shadeedi alAAiq\q@u{a}bi \q@u{th}ee a\q@b{l}\q@u{tt}awli l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa ilayhi alma\q@u{s}eer\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmcxxxvii{M\q@u{a} yuj\q@u{a}dilu fee \q@u{a}y\q@u{a}ti All\q@u{a}hi ill\q@u{a} alla\q@u{th}eena kafaroo fal\q@u{a} yaghrurka taqallubuhum fee albil\q@u{a}d\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmcxxxviii{Ka\q@u{thth}abat qablahum qawmu noo\q@u{h}in wa\q@b{a}la\q@u{h}z\q@u{a}bu min baAAdihim wahammat kullu ommatin birasoolihim liyakhu\q@u{th}oohu waj\q@u{a}daloo bi\q@b{a}lb\q@u{at}ili liyud\q@u{h}i\q@u{d}oo bihi al\q@u{h}aqqa faakha\q@u{th}tuhum fakayfa k\q@u{a}na AAiq\q@u{a}b\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmcxxxix{Waka\q@u{tha}lika \q@u{h}aqqat kalimatu rabbika AAal\q@u{a} alla\q@u{th}eena kafaroo annahum a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmcxl{Alla\q@u{th}eena ya\q@u{h}miloona alAAarsha waman \q@u{h}awlahu yusabbi\q@u{h}oona bi\q@u{h}amdi rabbihim wayuminoona bihi wayastaghfiroona lilla\q@u{th}eena \q@u{a}manoo rabban\q@u{a} wasiAAta kulla shayin ra\q@u{h}matan waAAilman fa\q@b{i}ghfir lilla\q@u{th}eena t\q@u{a}boo wa\q@b{i}ttabaAAoo sabeelaka waqihim AAa\q@u{tha}ba alja\q@u{h}eem\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmcxli{Rabban\q@u{a} waadkhilhum jann\q@u{a}ti AAadnin allatee waAAadtahum waman \q@u{s}ala\q@u{h}a min \q@u{a}b\q@u{a}ihim waazw\q@u{a}jihim wa\q@u{th}urriyy\q@u{a}tihim innaka anta alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmcxlii{Waqihimu a\q@b{l}ssayyi\q@u{a}ti waman taqi a\q@b{l}ssayyi\q@u{a}ti yawmai\q@u{th}in faqad ra\q@u{h}imtahu wa\q@u{tha}lika huwa alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmcxliii{Inna alla\q@u{th}eena kafaroo yun\q@u{a}dawna lamaqtu All\q@u{a}hi akbaru min maqtikum anfusakum i\q@u{th} tudAAawna il\q@u{a} aleem\q@u{a}ni fatakfuroon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmcxliv{Q\q@u{a}loo rabban\q@u{a} amattan\q@u{a} ithnatayni waa\q@u{h}yaytan\q@u{a} ithnatayni fa\q@b{i}AAtarafn\q@u{a} bi\q@u{th}unoobin\q@u{a} fahal il\q@u{a} khuroojin min sabeel\q@b{in}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmcxlv{\q@u{Tha}likum biannahu i\q@u{tha} duAAiya All\q@u{a}hu wa\q@u{h}dahu kafartum wain yushrak bihi tuminoo fa\q@b{a}l\q@u{h}ukmu lill\q@u{a}hi alAAaliyyi alkabeer\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmcxlvi{Huwa alla\q@u{th}ee yureekum \q@u{a}y\q@u{a}tihi wayunazzilu lakum mina a\q@b{l}ssam\q@u{a}i rizqan wam\q@u{a} yata\q@u{th}akkaru ill\q@u{a} man yuneeb\q@b{u}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmcxlvii{Fa\q@b{o}dAAoo All\q@u{a}ha mukhli\q@u{s}eena lahu a\q@b{l}ddeena walaw kariha alk\q@u{a}firoon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmcxlviii{RafeeAAu a\q@b{l}ddaraj\q@u{a}ti \q@u{th}oo alAAarshi yulqee a\q@b{l}rroo\q@u{h}a min amrihi AAal\q@u{a} man yash\q@u{a}o min AAib\q@u{a}dihi liyun\q@u{th}ira yawma a\q@b{l}ttal\q@u{a}q\q@b{i}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmcxlix{Yawma hum b\q@u{a}rizoona l\q@u{a} yakhf\q@u{a} AAal\q@u{a} All\q@u{a}hi minhum shayon limani almulku alyawma lill\q@u{a}hi alw\q@u{ah}idi alqahh\q@u{a}r\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmcl{Alyawma tujz\q@u{a} kullu nafsin bim\q@u{a} kasabat l\q@u{a} \q@i{\q@u{th}}ulma alyawma inna All\q@u{a}ha sareeAAu al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmcli{Waan\q@u{th}irhum yawma al\q@u{a}zifati i\q@u{th}i alquloobu lad\q@u{a} al\q@u{h}an\q@u{a}jiri k\q@u{a}\q@i{\q@u{th}}imeena m\q@u{a} li\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena min \q@u{h}ameemin wal\q@u{a} shafeeAAin yu\q@u{ta}AA\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmclii{YaAAlamu kh\q@u{a}inata alaAAyuni wam\q@u{a} tukhfee a\q@b{l}\q@u{ss}udoor\q@b{u}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmcliii{Wa\q@b{A}ll\q@u{a}hu yaq\q@u{d}ee bi\q@b{a}l\q@u{h}aqqi wa\q@b{a}lla\q@u{th}eena yadAAoona min doonihi l\q@u{a} yaq\q@u{d}oona bishayin inna All\q@u{a}ha huwa a\q@b{l}ssameeAAu alba\q@u{s}eer\q@b{u}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmcliv{Awa lam yaseeroo fee alar\q@u{d}i fayan\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu alla\q@u{th}eena k\q@u{a}noo min qablihim k\q@u{a}noo hum ashadda minhum quwwatan wa\q@u{a}th\q@u{a}ran fee alar\q@u{d}i faakha\q@u{th}ahumu All\q@u{a}hu bi\q@u{th}unoobihim wam\q@u{a} k\q@u{a}na lahum mina All\q@u{a}hi min w\q@u{a}q\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmclv{\q@u{Tha}lika biannahum k\q@u{a}nat tateehim rusuluhum bi\q@b{a}lbayyin\q@u{a}ti fakafaroo faakha\q@u{th}ahumu All\q@u{a}hu innahu qawiyyun shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmclvi{Walaqad arsaln\q@u{a} moos\q@u{a} bi\q@u{a}y\q@u{a}tin\q@u{a} wasul\q@u{ta}nin mubeen\q@b{in}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmclvii{Il\q@u{a} firAAawna wah\q@u{a}m\q@u{a}na waq\q@u{a}roona faq\q@u{a}loo s\q@u{ah}irun ka\q@u{ththa}b\q@b{un}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmclviii{Falamm\q@u{a} j\q@u{a}ahum bi\q@b{a}l\q@u{h}aqqi min AAindin\q@u{a} q\q@u{a}loo oqtuloo abn\q@u{a}a alla\q@u{th}eena \q@u{a}manoo maAAahu wa\q@b{i}sta\q@u{h}yoo nis\q@u{a}ahum wam\q@u{a} kaydu alk\q@u{a}fireena ill\q@u{a} fee \q@u{d}al\q@u{a}l\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmclix{Waq\q@u{a}la firAAawnu \q@u{th}aroonee aqtul moos\q@u{a} walyadAAu rabbahu innee akh\q@u{a}fu an yubaddila deenakum aw an yu\q@i{\q@u{th}}hira fee alar\q@u{d}i alfas\q@u{a}d\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmclx{Waq\q@u{a}la moos\q@u{a} innee AAu\q@u{th}tu birabbee warabbikum min kulli mutakabbirin l\q@u{a} yuminu biyawmi al\q@u{h}is\q@u{a}b\q@b{i}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmclxi{Waq\q@u{a}la rajulun muminun min \q@u{a}li firAAawna yaktumu eem\q@u{a}nahu ataqtuloona rajulan an yaqoola rabbiyya All\q@u{a}hu waqad j\q@u{a}akum bi\q@b{a}lbayyin\q@u{a}ti min rabbikum wain yaku k\q@u{ath}iban faAAalayhi ka\q@u{th}ibuhu wain yaku \q@u{sa}diqan yu\q@u{s}ibkum baAA\q@u{d}u alla\q@u{th}ee yaAAidukum inna All\q@u{a}ha l\q@u{a} yahdee man huwa musrifun ka\q@u{ththa}b\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmclxii{Y\q@u{a} qawmi lakumu almulku alyawma \q@i{\q@u{th}}\q@u{a}hireena fee alar\q@u{d}i faman yan\q@u{s}urun\q@u{a} min basi All\q@u{a}hi in j\q@u{a}an\q@u{a} q\q@u{a}la firAAawnu m\q@u{a} oreekum ill\q@u{a} m\q@u{a} ar\q@u{a} wam\q@u{a} ahdeekum ill\q@u{a} sabeela a\q@b{l}rrash\q@u{a}d\q@b{i}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmclxiii{Waq\q@u{a}la alla\q@u{th}ee \q@u{a}mana y\q@u{a} qawmi innee akh\q@u{a}fu AAalaykum mithla yawmi ala\q@u{h}z\q@u{a}b\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmclxiv{Mithla dabi qawmi noo\q@u{h}in waAA\q@u{a}din wathamooda wa\q@b{a}lla\q@u{th}eena min baAAdihim wam\q@u{a} All\q@u{a}hu yureedu \q@i{\q@u{th}}ulman lilAAib\q@u{a}d\q@b{i}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmclxv{Way\q@u{a} qawmi innee akh\q@u{a}fu AAalaykum yawma a\q@b{l}ttan\q@u{a}d\q@b{i}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmclxvi{Yawma tuwalloona mudbireena m\q@u{a} lakum mina All\q@u{a}hi min AA\q@u{as}imin waman yu\q@u{d}lili All\q@u{a}hu fam\q@u{a} lahu min h\q@u{a}d\q@b{in}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmclxvii{Walaqad j\q@u{a}akum yoosufu min qablu bi\q@b{a}lbayyin\q@u{a}ti fam\q@u{a} ziltum fee shakkin mimm\q@u{a} j\q@u{a}akum bihi \q@u{h}att\q@u{a} i\q@u{tha} halaka qultum lan yabAAatha All\q@u{a}hu min baAAdihi rasoolan ka\q@u{tha}lika yu\q@u{d}illu All\q@u{a}hu man huwa musrifun murt\q@u{a}b\q@b{un}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmclxviii{Alla\q@u{th}eena yuj\q@u{a}diloona fee \q@u{a}y\q@u{a}ti All\q@u{a}hi bighayri sul\q@u{ta}nin at\q@u{a}hum kabura maqtan AAinda All\q@u{a}hi waAAinda alla\q@u{th}eena \q@u{a}manoo ka\q@u{tha}lika ya\q@u{t}baAAu All\q@u{a}hu AAal\q@u{a} kulli qalbi mutakabbirin jabb\q@u{a}r\q@b{in}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmclxix{Waq\q@u{a}la firAAawnu y\q@u{a} h\q@u{a}m\q@u{a}nu ibni lee \q@u{s}ar\q@u{h}an laAAallee ablughu alasb\q@u{a}b\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmclxx{Asb\q@u{a}ba a\q@b{l}ssam\q@u{a}w\q@u{a}ti faa\q@u{tt}aliAAa il\q@u{a} il\q@u{a}hi moos\q@u{a} wainnee laa\q@i{\q@u{th}}unnuhu k\q@u{ath}iban waka\q@u{tha}lika zuyyina lifirAAawna sooo AAamalihi wa\q@u{s}udda AAani a\q@b{l}ssabeeli wam\q@u{a} kaydu firAAawna ill\q@u{a} fee tab\q@u{a}b\q@b{in}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmclxxi{Waq\q@u{a}la alla\q@u{th}ee \q@u{a}mana y\q@u{a} qawmi ittabiAAooni ahdikum sabeela a\q@b{l}rrash\q@u{a}d\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmclxxii{Y\q@u{a} qawmi innam\q@u{a} h\q@u{ath}ihi al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} mat\q@u{a}AAun wainna al\q@u{a}khirata hiya d\q@u{a}ru alqar\q@u{a}r\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmclxxiii{Man AAamila sayyiatan fal\q@u{a} yujz\q@u{a} ill\q@u{a} mithlah\q@u{a} waman AAamila \q@u{sa}li\q@u{h}an min \q@u{th}akarin aw onth\q@u{a} wahuwa muminun faol\q@u{a}ika yadkhuloona aljannata yurzaqoona feeh\q@u{a} bighayri \q@u{h}is\q@u{a}b\q@b{in}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmclxxiv{Way\q@u{a} qawmi m\q@u{a} lee adAAookum il\q@u{a} a\q@b{l}nnaj\q@u{a}ti watadAAoonanee il\q@u{a} a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmclxxv{TadAAoonanee liakfura bi\q@b{A}ll\q@u{a}hi waoshrika bihi m\q@u{a} laysa lee bihi AAilmun waan\q@u{a} adAAookum il\q@u{a} alAAazeezi alghaff\q@u{a}r\q@b{i}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmclxxvi{L\q@u{a} jarama annam\q@u{a} tadAAoonanee ilayhi laysa lahu daAAwatun fee a\q@b{l}dduny\q@u{a} wal\q@u{a} fee al\q@u{a}khirati waanna maraddan\q@u{a} il\q@u{a} All\q@u{a}hi waanna almusrifeena hum a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmclxxvii{Fasata\q@u{th}kuroona m\q@u{a} aqoolu lakum waofawwi\q@u{d}u amree il\q@u{a} All\q@u{a}hi inna All\q@u{a}ha ba\q@u{s}eerun bi\q@b{a}lAAib\q@u{a}d\q@b{i}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmclxxviii{Fawaq\q@u{a}hu All\q@u{a}hu sayyi\q@u{a}ti m\q@u{a} makaroo wa\q@u{ha}qa bi\q@u{a}li firAAawna sooo alAAa\q@u{tha}b\q@b{i}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmclxxix{A\q@b{l}nn\q@u{a}ru yuAAra\q@u{d}oona AAalayh\q@u{a} ghuduwwan waAAashiyyan wayawma taqoomu a\q@b{l}ss\q@u{a}AAatu adkhiloo \q@u{a}la firAAawna ashadda alAAa\q@u{tha}b\q@b{i}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmclxxx{Wai\q@u{th} yata\q@u{ha}jjoona fee a\q@b{l}nn\q@u{a}ri fayaqoolu a\q@b{l}\q@u{dd}uAAaf\q@u{a}o lilla\q@u{th}eena istakbaroo inn\q@u{a} kunn\q@u{a} lakum tabaAAan fahal antum mughnoona AAann\q@u{a} na\q@u{s}eeban mina a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmclxxxi{Q\q@u{a}la alla\q@u{th}eena istakbaroo inn\q@u{a} kullun feeh\q@u{a} inna All\q@u{a}ha qad \q@u{h}akama bayna alAAib\q@u{a}d\q@b{i}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmclxxxii{Waq\q@u{a}la alla\q@u{th}eena fee a\q@b{l}nn\q@u{a}ri likhazanati jahannama odAAoo rabbakum yukhaffif AAann\q@u{a} yawman mina alAAa\q@u{tha}b\q@b{i}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmclxxxiii{Q\q@u{a}loo awalam taku tateekum rusulukum bi\q@b{a}lbayyin\q@u{a}ti q\q@u{a}loo bal\q@u{a} q\q@u{a}loo fa\q@b{o}dAAoo wam\q@u{a} duAA\q@u{a}o alk\q@u{a}fireena ill\q@u{a} fee \q@u{d}al\q@u{a}l\q@b{in}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmclxxxiv{Inn\q@u{a} lanan\q@u{s}uru rusulan\q@u{a} wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wayawma yaqoomu alashh\q@u{a}d\q@b{u}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmclxxxv{Yawma l\q@u{a} yanfaAAu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena maAA\q@u{th}iratuhum walahumu allaAAnatu walahum sooo a\q@b{l}dd\q@u{a}r\q@b{i}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmclxxxvi{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} alhud\q@u{a} waawrathn\q@u{a} banee isr\q@u{a}eela alkit\q@u{a}b\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmclxxxvii{Hudan wa\q@u{th}ikr\q@u{a} liolee alalb\q@u{a}b\q@b{i}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmclxxxviii{Fa\q@b{i}\q@u{s}bir inna waAAda All\q@u{a}hi \q@u{h}aqqun wa\q@b{i}staghfir li\q@u{th}anbika wasabbi\q@u{h} bi\q@u{h}amdi rabbika bi\q@b{a}lAAashiyyi wa\q@b{a}libk\q@u{a}r\q@b{i}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmclxxxix{Inna alla\q@u{th}eena yuj\q@u{a}diloona fee \q@u{a}y\q@u{a}ti All\q@u{a}hi bighayri sul\q@u{ta}nin at\q@u{a}hum in fee \q@u{s}udoorihim ill\q@u{a} kibrun m\q@u{a} hum bib\q@u{a}ligheehi fa\q@b{i}staAAi\q@u{th} bi\q@b{A}ll\q@u{a}hi innahu huwa a\q@b{l}ssameeAAu alba\q@u{s}eer\q@b{u}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmcxc{Lakhalqu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i akbaru min khalqi a\q@b{l}nn\q@u{a}si wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmmcxci{Wam\q@u{a} yastawee alaAAm\q@u{a} wa\q@b{a}lba\q@u{s}eeru wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti wal\q@u{a} almuseeo qaleelan m\q@u{a} tata\q@u{th}akkaroon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmmcxcii{Inna a\q@b{l}ss\q@u{a}AAata la\q@u{a}tiyatun l\q@u{a} rayba feeh\q@u{a} wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yuminoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmmcxciii{Waq\q@u{a}la rabbukumu odAAoonee astajib lakum inna alla\q@u{th}eena yastakbiroona AAan AAib\q@u{a}datee sayadkhuloona jahannama d\q@u{a}khireen\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmmcxciv{All\q@u{a}hu alla\q@u{th}ee jaAAala lakumu allayla litaskunoo feehi wa\q@b{al}nnah\q@u{a}ra mub\q@u{s}iran inna All\q@u{a}ha la\q@u{th}oo fa\q@u{d}lin AAal\q@u{a} a\q@b{l}nn\q@u{a}si wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yashkuroon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmmcxcv{\q@u{Tha}likumu All\q@u{a}hu rabbukum kh\q@u{a}liqu kulli shayin l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa faann\q@u{a} tufakoon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmmcxcvi{Ka\q@u{tha}lika yufaku alla\q@u{th}eena k\q@u{a}noo bi\q@u{a}y\q@u{a}ti All\q@u{a}hi yaj\q@u{h}adoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmmcxcvii{All\q@u{a}hu alla\q@u{th}ee jaAAala lakumu alar\q@u{d}a qar\q@u{a}ran wa\q@b{al}ssam\q@u{a}a bin\q@u{a}an wa\q@u{s}awwarakum faa\q@u{h}sana \q@u{s}uwarakum warazaqakum mina a\q@b{l}\q@u{tt}ayyib\q@u{a}ti \q@u{tha}likumu All\q@u{a}hu rabbukum fatab\q@u{a}raka All\q@u{a}hu rabbu alAA\q@u{a}lameen\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmmcxcviii{Huwa al\q@u{h}ayyu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa fa\q@b{o}dAAoohu mukhli\q@u{s}eena lahu a\q@b{l}ddeena al\q@u{h}amdu lill\q@u{a}hi rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmmcxcix{Qul innee nuheetu an aAAbuda alla\q@u{th}eena tadAAoona min dooni All\q@u{a}hi lamm\q@u{a} j\q@u{a}aniya albayyin\q@u{a}tu min rabbee waomirtu an oslima lirabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmmcc{Huwa alla\q@u{th}ee khalaqakum min tur\q@u{a}bin thumma min nu\q@u{t}fatin thumma min AAalaqatin thumma yukhrijukum \q@u{t}iflan thumma litablughoo ashuddakum thumma litakoonoo shuyookhan waminkum man yutawaff\q@u{a} min qablu walitablughoo ajalan musamman walaAAallakum taAAqiloon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmmcci{Huwa alla\q@u{th}ee yu\q@u{h}yee wayumeetu fai\q@u{tha} qa\q@u{da} amran fainnam\q@u{a} yaqoolu lahu kun fayakoon\q@b{u}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmmccii{Alam tara il\q@u{a} alla\q@u{th}eena yuj\q@u{a}diloona fee \q@u{a}y\q@u{a}ti All\q@u{a}hi ann\q@u{a} yu\q@u{s}rafoon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmmcciii{Alla\q@u{th}eena ka\q@u{thth}aboo bi\q@b{a}lkit\q@u{a}bi wabim\q@u{a} arsaln\q@u{a} bihi rusulan\q@u{a} fasawfa yaAAlamoon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmmcciv{I\q@u{th}i alaghl\q@u{a}lu fee aAAn\q@u{a}qihim wa\q@b{al}ssal\q@u{a}silu yus\q@u{h}aboon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmmccv{Fee al\q@u{h}ameemi thumma fee a\q@b{l}nn\q@u{a}ri yusjaroon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmmccvi{Thumma qeela lahum ayna m\q@u{a} kuntum tushrikoon\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmmccvii{Min dooni All\q@u{a}hi q\q@u{a}loo \q@u{d}alloo AAann\q@u{a} bal lam nakun nadAAoo min qablu shayan ka\q@u{tha}lika yu\q@u{d}illu All\q@u{a}hu alk\q@u{a}fireen\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmmccviii{\q@u{Tha}likum bim\q@u{a} kuntum tafra\q@u{h}oona fee alar\q@u{d}i bighayri al\q@u{h}aqqi wabim\q@u{a} kuntum tamra\q@u{h}oon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmmccix{Odkhuloo abw\q@u{a}ba jahannama kh\q@u{a}lideena feeh\q@u{a} fabisa mathw\q@u{a} almutakabbireen\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmmccx{Fa\q@b{i}\q@u{s}bir inna waAAda All\q@u{a}hi \q@u{h}aqqun faimm\q@u{a} nuriyannaka baAA\q@u{d}a alla\q@u{th}ee naAAiduhum aw natawaffayannaka failayn\q@u{a} yurjaAAoon\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmmccxi{Walaqad arsaln\q@u{a} rusulan min qablika minhum man qa\q@u{s}a\q@u{s}n\q@u{a} AAalayka waminhum man lam naq\q@u{s}u\q@u{s} AAalayka wam\q@u{a} k\q@u{a}na lirasoolin an yatiya bi\q@u{a}yatin ill\q@u{a} bii\q@u{th}ni All\q@u{a}hi fai\q@u{tha} j\q@u{a}a amru All\q@u{a}hi qu\q@u{d}iya bi\q@b{a}l\q@u{h}aqqi wakhasira hun\q@u{a}lika almub\q@u{t}iloon\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmmccxii{All\q@u{a}hu alla\q@u{th}ee jaAAala lakumu alanAA\q@u{a}ma litarkaboo minh\q@u{a} waminh\q@u{a} takuloon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmmmccxiii{Walakum feeh\q@u{a} man\q@u{a}fiAAu walitablughoo AAalayh\q@u{a} \q@u{ha}jatan fee \q@u{s}udoorikum waAAalayh\q@u{a} waAAal\q@u{a} alfulki tu\q@u{h}maloon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmmmccxiv{Wayureekum \q@u{a}y\q@u{a}tihi faayya \q@u{a}y\q@u{a}ti All\q@u{a}hi tunkiroon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmmmccxv{Afalam yaseeroo fee alar\q@u{d}i fayan\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu alla\q@u{th}eena min qablihim k\q@u{a}noo akthara minhum waashadda quwwatan wa\q@u{a}th\q@u{a}ran fee alar\q@u{d}i fam\q@u{a} aghn\q@u{a} AAanhum m\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmmmccxvi{Falamm\q@u{a} j\q@u{a}athum rusuluhum bi\q@b{a}lbayyin\q@u{a}ti fari\q@u{h}oo bim\q@u{a} AAindahum mina alAAilmi wa\q@u{ha}qa bihim m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmmmccxvii{Falamm\q@u{a} raaw basan\q@u{a} q\q@u{a}loo \q@u{a}mann\q@u{a} bi\q@b{A}ll\q@u{a}hi wa\q@u{h}dahu wakafarn\q@u{a} bim\q@u{a} kunn\q@u{a} bihi mushrikeen\q@b{a}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmmmccxviii{Falam yaku yanfaAAuhum eem\q@u{a}nuhum lamm\q@u{a} raaw basan\q@u{a} sunnata All\q@u{a}hi allatee qad khalat fee AAib\q@u{a}dihi wakhasira hun\q@u{a}lika alk\q@u{a}firoon\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmmmccxix{\basmalahlt \q@u{Ha}meem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmccxx{Tanzeelun mina a\q@b{l}rra\q@u{h}m\q@u{a}ni a\q@b{l}rra\q@u{h}eem\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmccxxi{Kit\q@u{a}bun fu\q@u{ss}ilat \q@u{a}y\q@u{a}tuhu qur\q@u{a}nan AAarabiyyan liqawmin yaAAlamoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmccxxii{Basheeran wana\q@u{th}eeran faaAAra\q@u{d}a aktharuhum fahum l\q@u{a} yasmaAAoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmccxxiii{Waq\q@u{a}loo quloobun\q@u{a} fee akinnatin mimm\q@u{a} tadAAoon\q@u{a} ilayhi wafee \q@u{atha}nin\q@u{a} waqrun wamin baynin\q@u{a} wabaynika \q@u{h}ij\q@u{a}bun fa\q@b{i}AAmal innan\q@u{a} AA\q@u{a}miloon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmccxxiv{Qul innam\q@u{a} an\q@u{a} basharun mithlukum yoo\q@u{ha} ilayya annam\q@u{a} il\q@u{a}hukum il\q@u{a}hun w\q@u{ah}idun fa\q@b{i}staqeemoo ilayhi wa\q@b{i}staghfiroohu wawaylun lilmushrikeen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmccxxv{Alla\q@u{th}eena l\q@u{a} yutoona a\q@b{l}zzak\q@u{a}ta wahum bi\q@b{a}l\q@u{a}khirati hum k\q@u{a}firoon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmccxxvi{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lahum ajrun ghayru mamnoon\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmccxxvii{Qul ainnakum latakfuroona bi\q@b{a}lla\q@u{th}ee khalaqa alar\q@u{d}a fee yawmayni watajAAaloona lahu and\q@u{a}dan \q@u{tha}lika rabbu alAA\q@u{a}lameen\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmccxxviii{WajaAAala feeh\q@u{a} raw\q@u{a}siya min fawqih\q@u{a} wab\q@u{a}raka feeh\q@u{a} waqaddara feeh\q@u{a} aqw\q@u{a}tah\q@u{a} fee arbaAAati ayy\q@u{a}min saw\q@u{a}an li\q@b{l}ss\q@u{a}ileen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmccxxix{Thumma istaw\q@u{a} il\q@u{a} a\q@b{l}ssam\q@u{a}i wahiya dukh\q@u{a}nun faq\q@u{a}la lah\q@u{a} walilar\q@u{d}i itiy\q@u{a} \q@u{t}awAAan aw karhan q\q@u{a}lat\q@u{a} atayn\q@u{a} \q@u{ta}iAAeen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmccxxx{Faqa\q@u{da}hunna sabAAa sam\q@u{a}w\q@u{a}tin fee yawmayni waaw\q@u{ha} fee kulli sam\q@u{a}in amrah\q@u{a} wazayyann\q@u{a} a\q@b{l}ssam\q@u{a}a a\q@b{l}dduny\q@u{a} bima\q@u{sa}bee\q@u{h}a wa\q@u{h}if\q@i{\q@u{th}}an \q@u{tha}lika taqdeeru alAAazeezi alAAaleem\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmccxxxi{Fain aAAra\q@u{d}oo fuqul an\q@u{th}artukum \q@u{sa}AAiqatan mithla \q@u{sa}AAiqati AA\q@u{a}din wathamood\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmccxxxii{I\q@u{th} j\q@u{a}athumu a\q@b{l}rrusulu min bayni aydeehim wamin khalfihim all\q@u{a} taAAbudoo ill\q@u{a} All\q@u{a}ha q\q@u{a}loo law sh\q@u{a}a rabbun\q@u{a} laanzala mal\q@u{a}ikatan fainn\q@u{a} bim\q@u{a} orsiltum bihi k\q@u{a}firoon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmccxxxiii{Faamm\q@u{a} AA\q@u{a}dun fa\q@b{i}stakbaroo fee alar\q@u{d}i bighayri al\q@u{h}aqqi waq\q@u{a}loo man ashaddu minn\q@u{a} quwwatan awalam yaraw anna All\q@u{a}ha alla\q@u{th}ee khalaqahum huwa ashaddu minhum quwwatan wak\q@u{a}noo bi\q@u{a}y\q@u{a}tin\q@u{a} yaj\q@u{h}adoon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmccxxxiv{Faarsaln\q@u{a} AAalayhim ree\q@u{h}an \q@u{s}ar\q@u{s}aran fee ayy\q@u{a}min na\q@u{h}is\q@u{a}tin linu\q@u{th}eeqahum AAa\q@u{tha}ba alkhizyi fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} walaAAa\q@u{tha}bu al\q@u{a}khirati akhz\q@u{a} wahum l\q@u{a} yun\q@u{s}aroon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmccxxxv{Waamm\q@u{a} thamoodu fahadayn\q@u{a}hum fa\q@b{i}sta\q@u{h}abboo alAAam\q@u{a} AAal\q@u{a} alhud\q@u{a} faakha\q@u{th}athum \q@u{sa}AAiqatu alAAa\q@u{tha}bi alhooni bim\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmccxxxvi{Wanajjayn\q@u{a} alla\q@u{th}eena \q@u{a}manoo wak\q@u{a}noo yattaqoon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmccxxxvii{Wayawma yu\q@u{h}sharu aAAd\q@u{a}o All\q@u{a}hi il\q@u{a} a\q@b{l}nn\q@u{a}ri fahum yoozaAAoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmccxxxviii{\q@u{H}att\q@u{a} i\q@u{tha} m\q@u{a} j\q@u{a}ooh\q@u{a} shahida AAalayhim samAAuhum waab\q@u{sa}ruhum wajulooduhum bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmccxxxix{Waq\q@u{a}loo lijuloodihim lima shahidtum AAalayn\q@u{a} q\q@u{a}loo an\q@u{t}aqan\q@u{a} All\q@u{a}hu alla\q@u{th}ee an\q@u{t}aqa kulla shayin wahuwa khalaqakum awwala marratin wailayhi turjaAAoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmccxl{Wam\q@u{a} kuntum tastatiroona an yashhada AAalaykum samAAukum wal\q@u{a} ab\q@u{sa}rukum wal\q@u{a} juloodukum wal\q@u{a}kin \q@i{\q@u{th}}anantum anna All\q@u{a}ha l\q@u{a} yaAAlamu katheeran mimm\q@u{a} taAAmaloon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmccxli{Wa\q@u{tha}likum \q@i{\q@u{th}}annukumu alla\q@u{th}ee \q@i{\q@u{th}}anantum birabbikum ard\q@u{a}kum faa\q@u{s}ba\q@u{h}tum mina alkh\q@u{a}sireen\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmccxlii{Fain ya\q@u{s}biroo fa\q@b{al}nn\q@u{a}ru mathwan lahum wain yastaAAtiboo fam\q@u{a} hum mina almuAAtabeen\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmccxliii{Waqayya\q@u{d}n\q@u{a} lahum quran\q@u{a}a fazayyanoo lahum m\q@u{a} bayna aydeehim wam\q@u{a} khalfahum wa\q@u{h}aqqa AAalayhimu alqawlu fee omamin qad khalat min qablihim mina aljinni wa\q@b{a}linsi innahum k\q@u{a}noo kh\q@u{a}sireen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmccxliv{Waq\q@u{a}la alla\q@u{th}eena kafaroo l\q@u{a} tasmaAAoo lih\q@u{atha} alqur\q@u{a}ni wa\q@b{i}lghaw feehi laAAallakum taghliboon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmccxlv{Falanu\q@u{th}eeqanna alla\q@u{th}eena kafaroo AAa\q@u{tha}ban shadeedan walanajziyannahum aswaa alla\q@u{th}ee k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmccxlvi{\q@u{Tha}lika jaz\q@u{a}o aAAd\q@u{a}i All\q@u{a}hi a\q@b{l}nn\q@u{a}ru lahum feeh\q@u{a} d\q@u{a}ru alkhuldi jaz\q@u{a}an bim\q@u{a} k\q@u{a}noo bi\q@u{a}y\q@u{a}tin\q@u{a} yaj\q@u{h}adoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmccxlvii{Waq\q@u{a}la alla\q@u{th}eena kafaroo rabban\q@u{a} arin\q@u{a} alla\q@u{th}ayni a\q@u{d}all\q@u{a}n\q@u{a} mina aljinni wa\q@b{a}linsi najAAalhum\q@u{a} ta\q@u{h}ta aqd\q@u{a}min\q@u{a} liyakoon\q@u{a} mina alasfaleen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmccxlviii{Inna alla\q@u{th}eena q\q@u{a}loo rabbun\q@u{a} All\q@u{a}hu thumma istaq\q@u{a}moo tatanazzalu AAalayhimu almal\q@u{a}ikatu all\q@u{a} takh\q@u{a}foo wal\q@u{a} ta\q@u{h}zanoo waabshiroo bi\q@b{a}ljannati allatee kuntum tooAAadoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmccxlix{Na\q@u{h}nu awliy\q@u{a}okum fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wafee al\q@u{a}khirati walakum feeh\q@u{a} m\q@u{a} tashtahee anfusukum walakum feeh\q@u{a} m\q@u{a} taddaAAoon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmccl{Nuzulan min ghafoorin ra\q@u{h}eem\q@b{in}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmccli{Waman a\q@u{h}sanu qawlan mimman daAA\q@u{a} il\q@u{a} All\q@u{a}hi waAAamila \q@u{sa}li\q@u{h}an waq\q@u{a}la innanee mina almuslimeen\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmcclii{Wal\q@u{a} tastawee al\q@u{h}asanatu wal\q@u{a} a\q@b{l}ssayyiatu idfaAA bi\q@b{a}llatee hiya a\q@u{h}sanu fai\q@u{tha} alla\q@u{th}ee baynaka wabaynahu AAad\q@u{a}watun kaannahu waliyyun \q@u{h}ameem\q@b{un}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmccliii{Wam\q@u{a} yulaqq\q@u{a}h\q@u{a} ill\q@u{a} alla\q@u{th}eena \q@u{s}abaroo wam\q@u{a} yulaqq\q@u{a}h\q@u{a} ill\q@u{a} \q@u{th}oo \q@u{h}a\q@i{\q@u{thth}}in AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmccliv{Waimm\q@u{a} yanzaghannaka mina a\q@b{l}shshay\q@u{ta}ni nazghun fa\q@b{i}staAAi\q@u{th} bi\q@b{A}ll\q@u{a}hi innahu huwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmcclv{Wamin \q@u{a}y\q@u{a}tihi allaylu wa\q@b{al}nnah\q@u{a}ru wa\q@b{al}shshamsu wa\q@b{a}lqamaru l\q@u{a} tasjudoo li\q@b{l}shshamsi wal\q@u{a} lilqamari wa\q@b{o}sjudoo lill\q@u{a}hi ala\q@u{th}ee khalaqahunna in kuntum iyy\q@u{a}hu taAAbudoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmcclvi{Faini istakbaroo fa\q@b{a}lla\q@u{th}eena AAinda rabbika yusabbi\q@u{h}oona lahu bi\q@b{a}llayli wa\q@b{al}nnah\q@u{a}ri wahum l\q@u{a} yasamoon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmcclvii{Wamin \q@u{a}y\q@u{a}tihi annaka tar\q@u{a} alar\q@u{d}a kh\q@u{a}shiAAatan fai\q@u{tha} anzaln\q@u{a} AAalayh\q@u{a} alm\q@u{a}a ihtazzat warabat inna alla\q@u{th}ee a\q@u{h}y\q@u{a}h\q@u{a} lamu\q@u{h}yee almawt\q@u{a} innahu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmcclviii{Inna alla\q@u{th}eena yul\q@u{h}idoona fee \q@u{a}y\q@u{a}tin\q@u{a} l\q@u{a} yakhfawna AAalayn\q@u{a} afaman yulq\q@u{a} fee a\q@b{l}nn\q@u{a}ri khayrun am man yatee \q@u{a}minan yawma alqiy\q@u{a}mati iAAmaloo m\q@u{a} shitum innahu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmcclix{Inna alla\q@u{th}eena kafaroo bi\q@b{al}\q@u{thth}ikri lamm\q@u{a} j\q@u{a}ahum wainnahu lakit\q@u{a}bun AAazeez\q@b{un}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmcclx{L\q@u{a} yateehi alb\q@u{at}ilu min bayni yadayhi wal\q@u{a} min khalfihi tanzeelun min \q@u{h}akeemin \q@u{h}ameed\q@b{in}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmcclxi{M\q@u{a} yuq\q@u{a}lu laka ill\q@u{a} m\q@u{a} qad qeela li\q@b{l}rrusuli min qablika inna rabbaka la\q@u{th}oo maghfiratin wa\q@u{th}oo AAiq\q@u{a}bin aleem\q@b{in}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmcclxii{Walaw jaAAaln\q@u{a}hu qur\q@u{a}nan aAAjamiyyan laq\q@u{a}loo lawl\q@u{a} fu\q@u{ss}ilat \q@u{a}y\q@u{a}tuhu aaAAjamiyyun waAAarabiyyun qul huwa lilla\q@u{th}eena \q@u{a}manoo hudan washif\q@u{a}on wa\q@b{a}lla\q@u{th}eena l\q@u{a} yuminoona fee \q@u{atha}nihim waqrun wahuwa AAalayhim AAaman ol\q@u{a}ika yun\q@u{a}dawna min mak\q@u{a}nin baAAeed\q@b{in}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmcclxiii{Walaqad \q@u{a}tayn\q@u{a} moos\q@u{a} alkit\q@u{a}ba fa\q@b{i}khtulifa feehi walawl\q@u{a} kalimatun sabaqat min rabbika laqu\q@u{d}iya baynahum wainnahum lafee shakkin minhu mureeb\q@b{in}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmcclxiv{Man AAamila \q@u{sa}li\q@u{h}an falinafsihi waman as\q@u{a}a faAAalayh\q@u{a} wam\q@u{a} rabbuka bi\q@i{\q@u{th}}all\q@u{a}min lilAAabeed\q@b{i}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmcclxv{Ilayhi yuraddu AAilmu a\q@b{l}ss\q@u{a}AAati wam\q@u{a} takhruju min thamar\q@u{a}tin min akm\q@u{a}mih\q@u{a} wam\q@u{a} ta\q@u{h}milu min onth\q@u{a} wal\q@u{a} ta\q@u{d}aAAu ill\q@u{a} biAAilmihi wayawma yun\q@u{a}deehim ayna shurak\q@u{a}ee q\q@u{a}loo \q@u{ath}ann\q@u{a}ka m\q@u{a} minn\q@u{a} min shaheed\q@b{in}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmcclxvi{Wa\q@u{d}alla AAanhum m\q@u{a} k\q@u{a}noo yadAAoona min qablu wa\q@i{\q@u{th}}annoo m\q@u{a} lahum min ma\q@u{h}ee\q@u{s}\q@b{in}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmcclxvii{L\q@u{a} yasamu alins\q@u{a}nu min duAA\q@u{a}i alkhayri wain massahu a\q@b{l}shsharru fayaoosun qanoo\q@u{t}\q@b{un}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmcclxviii{Walain a\q@u{th}aqn\q@u{a}hu ra\q@u{h}matan minn\q@u{a} min baAAdi \q@u{d}arr\q@u{a}a massathu layaqoolanna h\q@u{atha} lee wam\q@u{a} a\q@i{\q@u{th}}unnu a\q@b{l}ss\q@u{a}AAata q\q@u{a}imatan walain rujiAAtu il\q@u{a} rabbee inna lee AAindahu lal\q@u{h}usn\q@u{a} falanunabbianna alla\q@u{th}eena kafaroo bim\q@u{a} AAamiloo walanu\q@u{th}eeqannahum min AAa\q@u{tha}bin ghalee\q@i{\q@u{th}}\q@b{in}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmcclxix{Wai\q@u{tha} anAAamn\q@u{a} AAal\q@u{a} alins\q@u{a}ni aAAra\q@u{d}a wana\q@u{a} bij\q@u{a}nibihi wai\q@u{tha} massahu a\q@b{l}shsharru fa\q@u{th}oo duAA\q@u{a}in AAaree\q@u{d}\q@b{in}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmcclxx{Qul araaytum in k\q@u{a}na min AAindi All\q@u{a}hi thumma kafartum bihi man a\q@u{d}allu mimman huwa fee shiq\q@u{a}qin baAAeed\q@b{in}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxi{Sanureehim \q@u{a}y\q@u{a}tin\q@u{a} fee al\q@u{a}f\q@u{a}qi wafee anfusihim \q@u{h}att\q@u{a} yatabayyana lahum annahu al\q@u{h}aqqu awalam yakfi birabbika annahu AAal\q@u{a} kulli shayin shaheed\q@b{un}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxii{Al\q@u{a} innahum fee miryatin min liq\q@u{a}i rabbihim al\q@u{a} innahu bikulli shayin mu\q@u{h}ee\q@u{t}\q@b{un}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxiii{\basmalahlt \q@u{Ha}meem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxiv{AAaynseenq\q@u{a}f\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxv{Ka\q@u{tha}lika yoo\q@u{h}ee ilayka wail\q@u{a} alla\q@u{th}eena min qablika All\q@u{a}hu alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxvi{Lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wahuwa alAAaliyyu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxvii{Tak\q@u{a}du a\q@b{l}ssam\q@u{a}w\q@u{a}tu yatafa\q@u{tt}arna min fawqihinna wa\q@b{a}lmal\q@u{a}ikatu yusabbi\q@u{h}oona bi\q@u{h}amdi rabbihim wayastaghfiroona liman fee alar\q@u{d}i al\q@u{a} inna All\q@u{a}ha huwa alghafooru a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxviii{Wa\q@b{a}lla\q@u{th}eena ittakha\q@u{th}oo min doonihi awliy\q@u{a}a All\q@u{a}hu \q@u{h}afee\q@i{\q@u{th}}un AAalayhim wam\q@u{a} anta AAalayhim biwakeel\q@b{in}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxix{Waka\q@u{tha}lika aw\q@u{h}ayn\q@u{a} ilayka qur\q@u{a}nan AAarabiyyan litun\q@u{th}ira omma alqur\q@u{a} waman \q@u{h}awlah\q@u{a} watun\q@u{th}ira yawma aljamAAi l\q@u{a} rayba feehi fareequn fee aljannati wafareequn fee a\q@b{l}ssaAAeer\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxx{Walaw sh\q@u{a}a All\q@u{a}hu lajaAAalahum ommatan w\q@u{ah}idatan wal\q@u{a}kin yudkhilu man yash\q@u{a}o fee ra\q@u{h}matihi wa\q@b{al}\q@i{\q@u{thth}}\q@u{a}limoona m\q@u{a} lahum min waliyyin wal\q@u{a} na\q@u{s}eer\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxxi{Ami ittakha\q@u{th}oo min doonihi awliy\q@u{a}a fa\q@b{A}ll\q@u{a}hu huwa alwaliyyu wahuwa yu\q@u{h}yee almawt\q@u{a} wahuwa AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxxii{Wam\q@u{a} ikhtalaftum feehi min shayin fa\q@u{h}ukmuhu il\q@u{a} All\q@u{a}hi \q@u{tha}likumu All\q@u{a}hu rabbee AAalayhi tawakkaltu wailayhi oneeb\q@b{u}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxxiii{F\q@u{at}iru a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i jaAAala lakum min anfusikum azw\q@u{a}jan wamina alanAA\q@u{a}mi azw\q@u{a}jan ya\q@u{th}raokum feehi laysa kamithlihi shayon wahuwa a\q@b{l}ssameeAAu alba\q@u{s}eer\q@b{u}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxxiv{Lahu maq\q@u{a}leedu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i yabsu\q@u{t}u a\q@b{l}rrizqa liman yash\q@u{a}o wayaqdiru innahu bikulli shayin AAaleem\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxxv{SharaAAa lakum mina a\q@b{l}ddeeni m\q@u{a} wa\q@u{ssa} bihi noo\q@u{h}an wa\q@b{a}lla\q@u{th}ee aw\q@u{h}ayn\q@u{a} ilayka wam\q@u{a} wa\q@u{ss}ayn\q@u{a} bihi ibr\q@u{a}heema wamoos\q@u{a} waAAees\q@u{a} an aqeemoo a\q@b{l}ddeena wal\q@u{a} tatafarraqoo feehi kabura AAal\q@u{a} almushrikeena m\q@u{a} tadAAoohum ilayhi All\q@u{a}hu yajtabee ilayhi man yash\q@u{a}o wayahdee ilayhi man yuneeb\q@b{u}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxxvi{Wam\q@u{a} tafarraqoo ill\q@u{a} min baAAdi m\q@u{a} j\q@u{a}ahumu alAAilmu baghyan baynahum walawl\q@u{a} kalimatun sabaqat min rabbika il\q@u{a} ajalin musamman laqu\q@u{d}iya baynahum wainna alla\q@u{th}eena oorithoo alkit\q@u{a}ba min baAAdihim lafee shakkin minhu mureeb\q@b{in}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxxvii{Fali\q@u{tha}lika fa\q@b{o}dAAu wa\q@b{i}staqim kam\q@u{a} omirta wal\q@u{a} tattabiAA ahw\q@u{a}ahum waqul \q@u{a}mantu bim\q@u{a} anzala All\q@u{a}hu min kit\q@u{a}bin waomirtu liaAAdila baynakum All\q@u{a}hu rabbun\q@u{a} warabbukum lan\q@u{a} aAAm\q@u{a}lun\q@u{a} walakum aAAm\q@u{a}lukum l\q@u{a} \q@u{h}ujjata baynan\q@u{a} wabaynakumu All\q@u{a}hu yajmaAAu baynan\q@u{a} wailayhi alma\q@u{s}eer\q@b{u}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxxviii{Wa\q@b{a}lla\q@u{th}eena yu\q@u{ha}jjoona fee All\q@u{a}hi min baAAdi m\q@u{a} istujeeba lahu \q@u{h}ujjatuhum d\q@u{ah}i\q@u{d}atun AAinda rabbihim waAAalayhim gha\q@u{d}abun walahum AAa\q@u{tha}bun shadeed\q@b{un}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmcclxxxix{All\q@u{a}hu alla\q@u{th}ee anzala alkit\q@u{a}ba bi\q@b{a}l\q@u{h}aqqi wa\q@b{a}lmeez\q@u{a}ni wam\q@u{a} yudreeka laAAalla a\q@b{l}ss\q@u{a}AAata qareeb\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmccxc{YastaAAjilu bih\q@u{a} alla\q@u{th}eena l\q@u{a} yuminoona bih\q@u{a} wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo mushfiqoona minh\q@u{a} wayaAAlamoona annah\q@u{a} al\q@u{h}aqqu al\q@u{a} inna alla\q@u{th}eena yum\q@u{a}roona fee a\q@b{l}ss\q@u{a}AAati lafee \q@u{d}al\q@u{a}lin baAAeed\q@b{in}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmccxci{All\q@u{a}hu la\q@u{t}eefun biAAib\q@u{a}dihi yarzuqu man yash\q@u{a}o wahuwa alqawiyyu alAAazeez\q@b{u}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmccxcii{Man k\q@u{a}na yureedu \q@u{h}artha al\q@u{a}khirati nazid lahu fee \q@u{h}arthihi waman k\q@u{a}na yureedu \q@u{h}artha a\q@b{l}dduny\q@u{a} nutihi minh\q@u{a} wam\q@u{a} lahu fee al\q@u{a}khirati min na\q@u{s}eeb\q@b{in}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmccxciii{Am lahum shurak\q@u{a}o sharaAAoo lahum mina a\q@b{l}ddeeni m\q@u{a} lam ya\q@u{th}an bihi All\q@u{a}hu walawl\q@u{a} kalimatu alfa\q@u{s}li laqu\q@u{d}iya baynahum wainna a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena lahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmccxciv{Tar\q@u{a} a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena mushfiqeena mimm\q@u{a} kasaboo wahuwa w\q@u{a}qiAAun bihim wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti fee raw\q@u{da}ti aljann\q@u{a}ti lahum m\q@u{a} yash\q@u{a}oona AAinda rabbihim \q@u{tha}lika huwa alfa\q@u{d}lu alkabeer\q@b{u}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmccxcv{\q@u{Tha}lika alla\q@u{th}ee yubashshiru All\q@u{a}hu AAib\q@u{a}dahu alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti qul l\q@u{a} asalukum AAalayhi ajran ill\q@u{a} almawaddata fee alqurb\q@u{a} waman yaqtarif \q@u{h}asanatan nazid lahu feeh\q@u{a} \q@u{h}usnan inna All\q@u{a}ha ghafoorun shakoor\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmccxcvi{Am yaqooloona iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi ka\q@u{th}iban fain yashai All\q@u{a}hu yakhtim AAal\q@u{a} qalbika wayam\q@u{h}u All\q@u{a}hu alb\q@u{at}ila wayu\q@u{h}iqqu al\q@u{h}aqqa bikalim\q@u{a}tihi innahu AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmccxcvii{Wahuwa alla\q@u{th}ee yaqbalu a\q@b{l}ttawbata AAan AAib\q@u{a}dihi wayaAAfoo AAani a\q@b{l}ssayyiati wayaAAlamu m\q@u{a} tafAAaloon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmccxcviii{Wayastajeebu alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti wayazeeduhum min fa\q@u{d}lihi wa\q@b{a}lk\q@u{a}firoona lahum AAa\q@u{tha}bun shadeed\q@b{un}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmccxcix{Walaw basa\q@u{t}a All\q@u{a}hu a\q@b{l}rrizqa liAAib\q@u{a}dihi labaghaw fee alar\q@u{d}i wal\q@u{a}kin yunazzilu biqadarin m\q@u{a} yash\q@u{a}o innahu biAAib\q@u{a}dihi khabeerun ba\q@u{s}eer\q@b{un}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmccc{Wahuwa alla\q@u{th}ee yunazzilu alghaytha min baAAdi m\q@u{a} qana\q@u{t}oo wayanshuru ra\q@u{h}matahu wahuwa alwaliyyu al\q@u{h}ameed\q@b{u}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmccci{Wamin \q@u{a}y\q@u{a}tihi khalqu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baththa feehim\q@u{a} min d\q@u{a}bbatin wahuwa AAal\q@u{a} jamAAihim i\q@u{tha} yash\q@u{a}o qadeer\q@b{un}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmcccii{Wam\q@u{a} a\q@u{sa}bakum min mu\q@u{s}eebatin fabim\q@u{a} kasabat aydeekum wayaAAfoo AAan katheer\q@b{in}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmccciii{Wam\q@u{a} antum bimuAAjizeena fee alar\q@u{d}i wam\q@u{a} lakum min dooni All\q@u{a}hi min waliyyin wal\q@u{a} na\q@u{s}eer\q@b{in}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmccciv{Wamin \q@u{a}y\q@u{a}tihi aljaw\q@u{a}ri fee alba\q@u{h}ri ka\q@b{a}laAAl\q@u{a}m\q@b{i}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmcccv{In yasha yuskini a\q@b{l}rree\q@u{h}a faya\q@i{\q@u{th}}lalna raw\q@u{a}kida AAal\q@u{a} \q@i{\q@u{th}}ahrihi inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin likulli \q@u{s}abb\q@u{a}rin shakoor\q@b{in}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmcccvi{Aw yoobiqhunna bim\q@u{a} kasaboo wayaAAfu AAan katheer\q@b{in}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmcccvii{WayaAAlama alla\q@u{th}eena yuj\q@u{a}diloona fee \q@u{a}y\q@u{a}tin\q@u{a} m\q@u{a} lahum min ma\q@u{h}ee\q@u{s}\q@b{in}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmcccviii{Fam\q@u{a} ooteetum min shayin famat\q@u{a}AAu al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} wam\q@u{a} AAinda All\q@u{a}hi khayrun waabq\q@u{a} lilla\q@u{th}eena \q@u{a}manoo waAAal\q@u{a} rabbihim yatawakkaloon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmcccix{Wa\q@b{a}lla\q@u{th}eena yajtaniboona kab\q@u{a}ira alithmi wa\q@b{a}lfaw\q@u{ah}isha wai\q@u{tha} m\q@u{a} gha\q@u{d}iboo hum yaghfiroon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmcccx{Wa\q@b{a}lla\q@u{th}eena istaj\q@u{a}boo lirabbihim waaq\q@u{a}moo a\q@b{l}\q@u{ss}al\q@u{a}ta waamruhum shoor\q@u{a} baynahum wamimm\q@u{a} razaqn\q@u{a}hum yunfiqoon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmcccxi{Wa\q@b{a}lla\q@u{th}eena i\q@u{tha} a\q@u{sa}bahumu albaghyu hum yanta\q@u{s}iroon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmcccxii{Wajaz\q@u{a}o sayyiatin sayyiatun mithluh\q@u{a} faman AAaf\q@u{a} waa\q@u{s}la\q@u{h}a faajruhu AAal\q@u{a} All\q@u{a}hi innahu l\q@u{a} yu\q@u{h}ibbu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmcccxiii{Walamani inta\q@u{s}ara baAAda \q@i{\q@u{th}}ulmihi faol\q@u{a}ika m\q@u{a} AAalayhim min sabeel\q@b{in}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmcccxiv{Innam\q@u{a} a\q@b{l}ssabeelu AAal\q@u{a} alla\q@u{th}eena ya\q@i{\q@u{th}}limoona a\q@b{l}nn\q@u{a}sa wayabghoona fee alar\q@u{d}i bighayri al\q@u{h}aqqi ol\q@u{a}ika lahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmcccxv{Walaman \q@u{s}abara waghafara inna \q@u{tha}lika lamin AAazmi alomoor\q@b{i}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmcccxvi{Waman yu\q@u{d}lili All\q@u{a}hu fam\q@u{a} lahu min waliyyin min baAAdihi watar\q@u{a} a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena lamm\q@u{a} raawoo alAAa\q@u{tha}ba yaqooloona hal il\q@u{a} maraddin min sabeel\q@b{in}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmcccxvii{Watar\q@u{a}hum yuAAra\q@u{d}oona AAalayh\q@u{a} kh\q@u{a}shiAAeena mina a\q@b{l}\q@u{thth}ulli yan\q@i{\q@u{th}}uroona min \q@u{t}arfin khafiyyin waq\q@u{a}la alla\q@u{th}eena \q@u{a}manoo inna alkh\q@u{a}sireena alla\q@u{th}eena khasiroo anfusahum waahleehim yawma alqiy\q@u{a}mati al\q@u{a} inna a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena fee AAa\q@u{tha}bin muqeem\q@b{in}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmcccxviii{Wam\q@u{a} k\q@u{a}na lahum min awliy\q@u{a}a yan\q@u{s}uroonahum min dooni All\q@u{a}hi waman yu\q@u{d}lili All\q@u{a}hu fam\q@u{a} lahu min sabeel\q@b{in}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmcccxix{Istajeeboo lirabbikum min qabli an yatiya yawmun l\q@u{a} maradda lahu mina All\q@u{a}hi m\q@u{a} lakum min maljain yawmai\q@u{th}in wam\q@u{a} lakum min nakeer\q@b{in}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmcccxx{Fain aAAra\q@u{d}oo fam\q@u{a} arsaln\q@u{a}ka AAalayhim \q@u{h}afee\q@i{\q@u{th}}an in AAalayka ill\q@u{a} albal\q@u{a}ghu wainn\q@u{a} i\q@u{tha} a\q@u{th}aqn\q@u{a} alins\q@u{a}na minn\q@u{a} ra\q@u{h}matan fari\q@u{h}a bih\q@u{a} wain tu\q@u{s}ibhum sayyiatun bim\q@u{a} qaddamat aydeehim fainna alins\q@u{a}na kafoor\q@b{un}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxi{Lill\q@u{a}hi mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i yakhluqu m\q@u{a} yash\q@u{a}o yahabu liman yash\q@u{a}o in\q@u{a}than wayahabu liman yash\q@u{a}o a\q@b{l}\q@u{thth}ukoor\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxii{Aw yuzawwijuhum \q@u{th}ukr\q@u{a}nan wain\q@u{a}than wayajAAalu man yash\q@u{a}o AAaqeeman innahu AAaleemun qadeer\q@b{un}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxiii{Wam\q@u{a} k\q@u{a}na libasharin an yukallimahu All\q@u{a}hu ill\q@u{a} wa\q@u{h}yan aw min war\q@u{a}i \q@u{h}ij\q@u{a}bin aw yursila rasoolan fayoo\q@u{h}iya bii\q@u{th}nihi m\q@u{a} yash\q@u{a}o innahu AAaliyyun \q@u{h}akeem\q@b{un}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxiv{Waka\q@u{tha}lika aw\q@u{h}ayn\q@u{a} ilayka roo\q@u{h}an min amrin\q@u{a} m\q@u{a} kunta tadree m\q@u{a} alkit\q@u{a}bu wal\q@u{a} aleem\q@u{a}nu wal\q@u{a}kin jaAAaln\q@u{a}hu nooran nahdee bihi man nash\q@u{a}o min AAib\q@u{a}din\q@u{a} wainnaka latahdee il\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxv{\q@u{S}ir\q@u{at}i All\q@u{a}hi alla\q@u{th}ee lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i al\q@u{a} il\q@u{a} All\q@u{a}hi ta\q@u{s}eeru alomoor\q@b{u}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxvi{\basmalahlt \q@u{Ha}meem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxvii{Wa\q@b{a}lkit\q@u{a}bi almubeen\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxviii{Inn\q@u{a} jaAAaln\q@u{a}hu qur\q@u{a}nan AAarabiyyan laAAallakum taAAqiloona\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxix{Wainnahu fee ommi alkit\q@u{a}bi ladayn\q@u{a} laAAaliyyun \q@u{h}akeem\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxx{Afana\q@u{d}ribu AAankumu a\q@b{l}\q@u{thth}ikra \q@u{s}af\q@u{h}an an kuntum qawman musrifeen\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxxi{Wakam arsaln\q@u{a} min nabiyyin fee alawwaleen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxxii{Wam\q@u{a} yateehim min nabiyyin ill\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxxiii{Faahlakn\q@u{a} ashadda minhum ba\q@u{t}shan wama\q@u{da} mathalu alawwaleen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxxiv{Walain saaltahum man khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a layaqoolunna khalaqahunna alAAazeezu alAAaleem\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxxv{Alla\q@u{th}ee jaAAala lakumu alar\q@u{d}a mahdan wajaAAala lakum feeh\q@u{a} subulan laAAallakum tahtadoon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxxvi{Wa\q@b{a}lla\q@u{th}ee nazzala mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an biqadarin faansharn\q@u{a} bihi baldatan maytan ka\q@u{tha}lika tukhrajoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxxvii{Wa\q@b{a}lla\q@u{th}ee khalaqa alazw\q@u{a}ja kullah\q@u{a} wajaAAala lakum mina alfulki wa\q@b{a}lanAA\q@u{a}mi m\q@u{a} tarkaboon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxxviii{Litastawoo AAal\q@u{a} \q@i{\q@u{th}}uhoorihi thumma ta\q@u{th}kuroo niAAmata rabbikum i\q@u{tha} istawaytum AAalayhi wataqooloo sub\q@u{ha}na alla\q@u{th}ee sakhkhara lan\q@u{a} h\q@u{atha} wam\q@u{a} kunn\q@u{a} lahu muqrineen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmcccxxxix{Wainn\q@u{a} il\q@u{a} rabbin\q@u{a} lamunqaliboon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmcccxl{WajaAAaloo lahu min AAib\q@u{a}dihi juzan inna alins\q@u{a}na lakafoorun mubeen\q@b{un}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmcccxli{Ami ittakha\q@u{th}a mimm\q@u{a} yakhluqu ban\q@u{a}tin waa\q@u{s}f\q@u{a}kum bi\q@b{a}lbaneen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmcccxlii{Wai\q@u{tha} bushshira a\q@u{h}aduhum bim\q@u{a} \q@u{d}araba li\q@b{l}rra\q@u{h}m\q@u{a}ni mathalan \q@i{\q@u{th}}alla wajhuhu muswaddan wahuwa ka\q@i{\q@u{th}}eem\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmcccxliii{Awaman yunashshao fee al\q@u{h}ilyati wahuwa fee alkhi\q@u{sa}mi ghayru mubeen\q@b{in}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmcccxliv{WajaAAaloo almal\q@u{a}ikata alla\q@u{th}eena hum AAib\q@u{a}du a\q@b{l}rra\q@u{h}m\q@u{a}ni in\q@u{a}than ashahidoo khalqahum satuktabu shah\q@u{a}datuhum wayusaloon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmcccxlv{Waq\q@u{a}loo law sh\q@u{a}a a\q@b{l}rra\q@u{h}m\q@u{a}nu m\q@u{a} AAabadn\q@u{a}hum m\q@u{a} lahum bi\q@u{tha}lika min AAilmin in hum ill\q@u{a} yakhru\q@u{s}oon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmcccxlvi{Am \q@u{a}tayn\q@u{a}hum kit\q@u{a}ban min qablihi fahum bihi mustamsikoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmcccxlvii{Bal q\q@u{a}loo inn\q@u{a} wajadn\q@u{a} \q@u{a}b\q@u{a}an\q@u{a} AAal\q@u{a} ommatin wainn\q@u{a} AAal\q@u{a} \q@u{a}th\q@u{a}rihim muhtadoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmcccxlviii{Waka\q@u{tha}lika m\q@u{a} arsaln\q@u{a} min qablika fee qaryatin min na\q@u{th}eerin ill\q@u{a} q\q@u{a}la mutrafooh\q@u{a} inn\q@u{a} wajadn\q@u{a} \q@u{a}b\q@u{a}an\q@u{a} AAal\q@u{a} ommatin wainn\q@u{a} AAal\q@u{a} \q@u{a}th\q@u{a}rihim muqtadoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmcccxlix{Q\q@u{a}la awalaw jitukum biahd\q@u{a} mimm\q@u{a} wajadtum AAalayhi \q@u{a}b\q@u{a}akum q\q@u{a}loo inn\q@u{a} bim\q@u{a} orsiltum bihi k\q@u{a}firoon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmcccl{Fa\q@b{i}ntaqamn\q@u{a} minhum fa\q@b{o}n\q@i{\q@u{th}}ur kayfa k\q@u{a}na AA\q@u{a}qibatu almuka\q@u{thth}ibeen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmcccli{Wai\q@u{th} q\q@u{a}la ibr\q@u{a}heemu liabeehi waqawmihi innanee bar\q@u{a}on mimm\q@u{a} taAAbudoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmccclii{Ill\q@u{a} alla\q@u{th}ee fa\q@u{t}aranee fainnahu sayahdeen\q@b{i}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmcccliii{WajaAAalah\q@u{a} kalimatan b\q@u{a}qiyatan fee AAaqibihi laAAallahum yarjiAAoon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmcccliv{Bal mattaAAtu h\q@u{a}ol\q@u{a}i wa\q@u{a}b\q@u{a}ahum \q@u{h}att\q@u{a} j\q@u{a}ahumu al\q@u{h}aqqu warasoolun mubeen\q@b{un}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmccclv{Walamm\q@u{a} j\q@u{a}ahumu al\q@u{h}aqqu q\q@u{a}loo h\q@u{atha} si\q@u{h}run wainn\q@u{a} bihi k\q@u{a}firoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmccclvi{Waq\q@u{a}loo lawl\q@u{a} nuzzila h\q@u{atha} alqur\q@u{a}nu AAal\q@u{a} rajulin mina alqaryatayni AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmccclvii{Ahum yaqsimoona ra\q@u{h}mata rabbika na\q@u{h}nu qasamn\q@u{a} baynahum maAAeeshatahum fee al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a} warafaAAn\q@u{a} baAA\q@u{d}ahum fawqa baAA\q@u{d}in daraj\q@u{a}tin liyattakhi\q@u{th}a baAA\q@u{d}uhum baAA\q@u{d}an sukhriyyan wara\q@u{h}matu rabbika khayrun mimm\q@u{a} yajmaAAoon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmccclviii{Walawl\q@u{a} an yakoona a\q@b{l}nn\q@u{a}su ommatan w\q@u{ah}idatan lajaAAaln\q@u{a} liman yakfuru bi\q@b{al}rra\q@u{h}m\q@u{a}ni libuyootihim suqufan min fi\q@u{dd}atin wamaAA\q@u{a}rija AAalayh\q@u{a} ya\q@i{\q@u{th}}haroon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmccclix{Walibuyootihim abw\q@u{a}ban wasururan AAalayh\q@u{a} yattakioon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmccclx{Wazukhrufan wain kullu \q@u{tha}lika lamm\q@u{a} mat\q@u{a}AAu al\q@u{h}ay\q@u{a}ti a\q@b{l}dduny\q@u{a }wa\q@b{a}l\q@u{a}khiratu AAinda rabbika lilmuttaqeen\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmccclxi{Waman yaAAshu AAan \q@u{th}ikri a\q@b{l}rra\q@u{h}m\q@u{a}ni nuqayyi\q@u{d} lahu shay\q@u{ta}nan fahuwa lahu qareen\q@b{un}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmccclxii{Wainnahum laya\q@u{s}uddoonahum AAani a\q@b{l}ssabeeli waya\q@u{h}saboona annahum muhtadoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmccclxiii{\q@u{H}att\q@u{a} i\q@u{tha} j\q@u{a}an\q@u{a} q\q@u{a}la y\q@u{a} layta baynee wabaynaka buAAda almashriqayni fabisa alqareen\q@b{u}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmccclxiv{Walan yanfaAAakumu alyawma i\q@u{th} \q@i{\q@u{th}}alamtum annakum fee alAAa\q@u{tha}bi mushtarikoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmccclxv{Afaanta tusmiAAu a\q@b{l}\q@u{ss}umma aw tahdee alAAumya waman k\q@u{a}na fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmccclxvi{Faimm\q@u{a} na\q@u{th}habanna bika fainn\q@u{a} minhum muntaqimoon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmccclxvii{Aw nuriyannaka alla\q@u{th}ee waAAadn\q@u{a}hum fainn\q@u{a} AAalayhim muqtadiroon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmccclxviii{Fa\q@b{i}stamsik bi\q@b{a}lla\q@u{th}ee oo\q@u{h}iya ilayka innaka AAal\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmccclxix{Wainnahu la\q@u{th}ikrun laka waliqawmika wasawfa tusaloon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmccclxx{Wa\q@b{i}sal man arsaln\q@u{a} min qablika min rusulin\q@u{a} ajaAAaln\q@u{a} min dooni a\q@b{l}rra\q@u{h}m\q@u{a}ni \q@u{a}lihatan yuAAbadoon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxi{Walaqad arsaln\q@u{a} moos\q@u{a} bi\q@u{a}y\q@u{a}tin\q@u{a} il\q@u{a} firAAawna wamalaihi faq\q@u{a}la innee rasoolu rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxii{Falamm\q@u{a} j\q@u{a}ahum bi\q@u{a}y\q@u{a}tin\q@u{a} i\q@u{tha} hum minh\q@u{a} ya\q@u{dh}akoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxiii{Wam\q@u{a} nureehim min \q@u{a}yatin ill\q@u{a} hiya akbaru min okhtih\q@u{a} waakha\q@u{th}n\q@u{a}hum bi\q@b{a}lAAa\q@u{tha}bi laAAallahum yarjiAAoon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxiv{Waq\q@u{a}loo y\q@u{a} ayyuh\q@u{a} a\q@b{l}s\q@u{ah}iru odAAu lan\q@u{a} rabbaka bim\q@u{a} AAahida AAindaka innan\q@u{a} lamuhtadoon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxv{Falamm\q@u{a} kashafn\q@u{a} AAanhumu alAAa\q@u{tha}ba i\q@u{tha} hum yankuthoon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxvi{Wan\q@u{a}d\q@u{a} firAAawnu fee qawmihi q\q@u{a}la y\q@u{a} qawmi alaysa lee mulku mi\q@u{s}ra wah\q@u{ath}ihi alanh\q@u{a}ru tajree min ta\q@u{h}tee afal\q@u{a} tub\q@u{s}iroon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxvii{Am an\q@u{a} khayrun min h\q@u{atha} alla\q@u{th}ee huwa maheenun wal\q@u{a} yak\q@u{a}du yubeen\q@b{u}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxviii{Falawl\q@u{a} olqiya AAalayhi aswiratun min \q@u{th}ahabin aw j\q@u{a}a maAAahu almal\q@u{a}ikatu muqtarineen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxix{Fa\q@b{i}stakhaffa qawmahu faa\q@u{ta}AAoohu innahum k\q@u{a}noo qawman f\q@u{a}siqeen\q@b{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxx{Falamm\q@u{a} \q@u{a}safoon\q@u{a} intaqamn\q@u{a} minhum faaghraqn\q@u{a}hum ajmaAAeen\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxxi{FajaAAaln\q@u{a}hum salafan wamathalan lil\q@u{a}khireen\q@b{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxxii{Walamm\q@u{a} \q@u{d}uriba ibnu maryama mathalan i\q@u{tha} qawmuka minhu ya\q@u{s}iddoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxxiii{Waq\q@u{a}loo a\q@u{a}lihatun\q@u{a} khayrun am huwa m\q@u{a} \q@u{d}araboohu laka ill\q@u{a} jadalan bal hum qawmun kha\q@u{s}imoon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxxiv{In huwa ill\q@u{a} AAabdun anAAamn\q@u{a} AAalayhi wajaAAaln\q@u{a}hu mathalan libanee isr\q@u{a}eel\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxxv{Walaw nash\q@u{a}o lajaAAaln\q@u{a} minkum mal\q@u{a}ikatan fee alar\q@u{d}i yakhlufoon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxxvi{Wainnahu laAAilmun li\q@b{l}ss\q@u{a}AAati fal\q@u{a} tamtarunna bih\q@u{a} wa\q@b{i}ttabiAAooni h\q@u{atha} \q@u{s}ir\q@u{at}un mustaqeem\q@b{un}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxxvii{Wal\q@u{a} ya\q@u{s}uddannakumu a\q@b{l}shshay\q@u{ta}nu innahu lakum AAaduwwun mubeen\q@b{un}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxxviii{Walamm\q@u{a} j\q@u{a}a AAees\q@u{a} bi\q@b{a}lbayyin\q@u{a}ti q\q@u{a}la qad jitukum bi\q@b{a}l\q@u{h}ikmati waliobayyina lakum baAA\q@u{d}a alla\q@u{th}ee takhtalifoona feehi fa\q@b{i}ttaqoo All\q@u{a}ha waa\q@u{t}eeAAoon\q@b{i}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmmccclxxxix{Inna All\q@u{a}ha huwa rabbee warabbukum fa\q@b{o}AAbudoohu h\q@u{atha} \q@u{s}ir\q@u{at}un mustaqeem\q@b{un}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmmcccxc{Fa\q@b{i}khtalafa ala\q@u{h}z\q@u{a}bu min baynihim fawaylun lilla\q@u{th}eena \q@i{\q@u{th}}alamoo min AAa\q@u{tha}bi yawmin aleem\q@b{in}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmmcccxci{Hal yan\q@i{\q@u{th}}uroona ill\q@u{a} a\q@b{l}ss\q@u{a}AAata an tatiyahum baghtatan wahum l\q@u{a} yashAAuroon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmmcccxcii{Alakhill\q@u{a}o yawmai\q@u{th}in baAA\q@u{d}uhum libaAA\q@u{d}in AAaduwwun ill\q@u{a} almuttaqeen\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmmcccxciii{Y\q@u{a} AAib\q@u{a}di l\q@u{a} khawfun AAalaykumu alyawma wal\q@u{a} antum ta\q@u{h}zanoon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmmcccxciv{Alla\q@u{th}eena \q@u{a}manoo bi\q@u{a}y\q@u{a}tin\q@u{a} wak\q@u{a}noo muslimeen\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmmcccxcv{Odkhuloo aljannata antum waazw\q@u{a}jukum tu\q@u{h}baroon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmmcccxcvi{Yu\q@u{ta}fu AAalayhim bi\q@u{s}i\q@u{ha}fin min \q@u{th}ahabin waakw\q@u{a}bin wafeeh\q@u{a} m\q@u{a} tashtaheehi alanfusu watala\q@u{thth}u alaAAyunu waantum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmmcccxcvii{Watilka aljannatu allatee oorithtumooh\q@u{a} bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmmcccxcviii{Lakum feeh\q@u{a} f\q@u{a}kihatun katheeratun minh\q@u{a} takuloon\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmmcccxcix{Inna almujrimeena fee AAa\q@u{tha}bi jahannama kh\q@u{a}lidoon\q@b{a}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmmcd{L\q@u{a} yufattaru AAanhum wahum feehi mublisoon\q@b{a}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmmcdi{Wam\q@u{a} \q@i{\q@u{th}}alamn\q@u{a}hum wal\q@u{a}kin k\q@u{a}noo humu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmmcdii{Wan\q@u{a}daw y\q@u{a} m\q@u{a}liku liyaq\q@u{d}i AAalayn\q@u{a} rabbuka q\q@u{a}la innakum m\q@u{a}kithoon\q@b{a}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmmcdiii{Laqad jin\q@u{a}kum bi\q@b{a}l\q@u{h}aqqi wal\q@u{a}kinna aktharakum lil\q@u{h}aqqi k\q@u{a}rihoon\q@b{a}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmmcdiv{Am abramoo amran fainn\q@u{a} mubrimoon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmmmcdv{Am ya\q@u{h}saboona ann\q@u{a} l\q@u{a} nasmaAAu sirrahum wanajw\q@u{a}hum bal\q@u{a} warusulun\q@u{a} ladayhim yaktuboon\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmmmcdvi{Qul in k\q@u{a}na li\q@b{l}rra\q@u{h}m\q@u{a}ni waladun faan\q@u{a} awwalu alAA\q@u{a}bideen\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmmmcdvii{Sub\q@u{ha}na rabbi a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i rabbi alAAarshi AAamm\q@u{a} ya\q@u{s}ifoon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmmmcdviii{Fa\q@u{th}arhum yakhoo\q@u{d}oo wayalAAaboo \q@u{h}att\q@u{a} yul\q@u{a}qoo yawmahumu alla\q@u{th}ee yooAAadoon\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmmmcdix{Wahuwa alla\q@u{th}ee fee a\q@b{l}ssam\q@u{a}i il\q@u{a}hun wafee alar\q@u{d}i il\q@u{a}hun wahuwa al\q@u{h}akeemu alAAaleem\q@b{u}\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmmmcdx{Watab\q@u{a}raka alla\q@u{th}ee lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} waAAindahu AAilmu a\q@b{l}ss\q@u{a}AAati wailayhi turjaAAoon\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmmmcdxi{Wal\q@u{a} yamliku alla\q@u{th}eena yadAAoona min doonihi a\q@b{l}shshaf\q@u{a}AAata ill\q@u{a} man shahida bi\q@b{a}l\q@u{h}aqqi wahum yaAAlamoon\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmmmcdxii{Walain saaltahum man khalaqahum layaqoolunna All\q@u{a}hu faann\q@u{a} yufakoon\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmmmcdxiii{Waqeelihi y\q@u{a}rabbi inna h\q@u{a}ol\q@u{a}i qawmun l\q@u{a} yuminoon\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmmmcdxiv{Fa\q@b{i}\q@u{s}fa\q@u{h} AAanhum waqul sal\q@u{a}mun fasawfa yaAAlamoon\q@b{a}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmmmcdxv{\basmalahlt \q@u{Ha}meem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmcdxvi{Wa\q@b{a}lkit\q@u{a}bi almubeen\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmcdxvii{Inn\q@u{a} anzaln\q@u{a}hu fee laylatin mub\q@u{a}rakatin inn\q@u{a} kunn\q@u{a} mun\q@u{th}ireen\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmcdxviii{Feeh\q@u{a} yufraqu kullu amrin \q@u{h}akeem\q@b{in}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmcdxix{Amran min AAindin\q@u{a} inn\q@u{a} kunn\q@u{a} mursileen\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmcdxx{Ra\q@u{h}matan min rabbika innahu huwa a\q@b{l}ssameeAAu alAAaleem\q@b{u}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxi{Rabbi a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} in kuntum mooqineen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxii{L\q@u{a} il\q@u{a}ha ill\q@u{a} huwa yu\q@u{h}yee wayumeetu rabbukum warabbu \q@u{a}b\q@u{a}ikumu alawwaleen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxiii{Bal hum fee shakkin yalAAaboon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxiv{Fa\q@b{i}rtaqib yawma tatee a\q@b{l}ssam\q@u{a}o bidukh\q@u{a}nin mubeen\q@b{in}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxv{Yaghsh\q@u{a} a\q@b{l}nn\q@u{a}sa h\q@u{atha} AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxvi{Rabban\q@u{a} ikshif AAann\q@u{a} alAAa\q@u{tha}ba inn\q@u{a} muminoon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxvii{Ann\q@u{a} lahumu a\q@b{l}\q@u{thth}ikr\q@u{a} waqad j\q@u{a}ahum rasoolun mubeen\q@b{un}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxviii{Thumma tawallaw AAanhu waq\q@u{a}loo muAAallamun majnoon\q@b{un}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxix{Inn\q@u{a} k\q@u{a}shifoo alAAa\q@u{tha}bi qaleelan innakum AA\q@u{a}idoon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxx{Yawma nab\q@u{t}ishu alba\q@u{t}shata alkubr\q@u{a} inn\q@u{a} muntaqimoon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxxi{Walaqad fatann\q@u{a} qablahum qawma firAAawna waj\q@u{a}ahum rasoolun kareem\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxxii{An addoo ilayya AAib\q@u{a}da All\q@u{a}hi innee lakum rasoolun ameen\q@b{un}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxxiii{Waan l\q@u{a} taAAloo AAal\q@u{a} All\q@u{a}hi innee \q@u{a}teekum bisul\q@u{ta}nin mubeen\q@b{in}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxxiv{Wainnee AAu\q@u{th}tu birabbee warabbikum an tarjumoon\q@b{i}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxxv{Wain lam tuminoo lee fa\q@b{i}AAtaziloon\q@b{i}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxxvi{FadaAA\q@u{a} rabbahu anna h\q@u{a}ol\q@u{a}i qawmun mujrimoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxxvii{Faasri biAAib\q@u{a}dee laylan innakum muttabaAAoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxxviii{Wa\q@b{o}truki alba\q@u{h}ra rahwan innahum jundun mughraqoon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmcdxxxix{Kam tarakoo min jann\q@u{a}tin waAAuyoon\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmcdxl{WazurooAAin wamaq\q@u{a}min kareem\q@b{in}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmcdxli{WanaAAmatin k\q@u{a}noo feeh\q@u{a} f\q@u{a}kiheen\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmcdxlii{Ka\q@u{tha}lika waawrathn\q@u{a}h\q@u{a} qawman \q@u{a}khareen\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmcdxliii{Fam\q@u{a} bakat AAalayhimu a\q@b{l}ssam\q@u{a}o wa\q@b{a}lar\q@u{d}u wam\q@u{a} k\q@u{a}noo mun\q@i{\q@u{th}}areen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmcdxliv{Walaqad najjayn\q@u{a} banee isr\q@u{a}eela mina alAAa\q@u{tha}bi almuheen\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmcdxlv{Min firAAawna innahu k\q@u{a}na AA\q@u{a}liyan mina almusrifeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmcdxlvi{Walaqadi ikhtarn\q@u{a}hum AAal\q@u{a} AAilmin AAal\q@u{a} alAA\q@u{a}lameen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmcdxlvii{Wa\q@u{a}tayn\q@u{a}hum mina al\q@u{a}y\q@u{a}ti m\q@u{a} feehi bal\q@u{a}on mubeen\q@b{un}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmcdxlviii{Inna h\q@u{a}ol\q@u{a}i layaqooloon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmcdxlix{In hiya ill\q@u{a} mawtatun\q@u{a} alool\q@u{a} wam\q@u{a} na\q@u{h}nu bimunshareen\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmcdl{Fatoo bi\q@u{a}b\q@u{a}in\q@u{a} in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmcdli{Ahum khayrun am qawmu tubbaAAin wa\q@b{a}lla\q@u{th}eena min qablihim ahlakn\q@u{a}hum innahum k\q@u{a}noo mujrimeen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmcdlii{Wam\q@u{a} khalaqn\q@u{a} a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wam\q@u{a} baynahum\q@u{a} l\q@u{a}AAibeen\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmcdliii{M\q@u{a} khalaqn\q@u{a}hum\q@u{a} ill\q@u{a} bi\q@b{a}l\q@u{h}aqqi wal\q@u{a}kinna aktharahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmcdliv{Inna yawma alfa\q@u{s}li meeq\q@u{a}tuhum ajmaAAeen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmcdlv{Yawma l\q@u{a} yughnee mawlan AAan mawlan shayan wal\q@u{a} hum yun\q@u{s}aroon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmcdlvi{Ill\q@u{a} man ra\q@u{h}ima All\q@u{a}hu innahu huwa alAAazeezu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmcdlvii{Inna shajarata a\q@b{l}zzaqqoom\q@b{i}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmcdlviii{\q@u{T}aAA\q@u{a}mu alatheem\q@b{i}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmcdlix{Ka\q@b{a}lmuhli yaghlee fee albu\q@u{t}oon\q@b{i}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmcdlx{Kaghalyi al\q@u{h}ameem\q@b{i}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxi{Khu\q@u{th}oohu fa\q@b{i}AAtiloohu il\q@u{a} saw\q@u{a}i alja\q@u{h}eem\q@b{i}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxii{Thumma \q@u{s}ubboo fawqa rasihi min AAa\q@u{tha}bi al\q@u{h}ameem\q@b{i}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxiii{\q@u{Th}uq innaka anta alAAazeezu alkareem\q@b{u}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxiv{Inna h\q@u{atha} m\q@u{a} kuntum bihi tamtaroon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxv{Inna almuttaqeena fee maq\q@u{a}min ameen\q@b{in}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxvi{Fee jann\q@u{a}tin waAAuyoon\q@b{in}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxvii{Yalbasoona min sundusin waistabraqin mutaq\q@u{a}bileen\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxviii{Ka\q@u{tha}lika wazawwajn\q@u{a}hum bi\q@u{h}oorin AAeen\q@b{in}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxix{YadAAoona feeh\q@u{a} bikulli f\q@u{a}kihatin \q@u{a}mineen\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxx{L\q@u{a} ya\q@u{th}ooqoona feeh\q@u{a} almawta ill\q@u{a} almawtata alool\q@u{a} wawaq\q@u{a}hum AAa\q@u{tha}ba alja\q@u{h}eem\q@b{i}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxi{Fa\q@u{d}lan min rabbika \q@u{tha}lika huwa alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxii{Fainnam\q@u{a} yassarn\q@u{a}hu bilis\q@u{a}nika laAAallahum yata\q@u{th}akkaroon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxiii{Fa\q@b{i}rtaqib innahum murtaqiboon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxiv{\basmalahlt \q@u{Ha}meem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxv{Tanzeelu alkit\q@u{a}bi mina All\q@u{a}hi alAAazeezi al\q@u{h}akeem\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxvi{Inna fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i la\q@u{a}y\q@u{a}tin lilmumineen\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxvii{Wafee khalqikum wam\q@u{a} yabuththu min d\q@u{a}bbatin \q@u{a}y\q@u{a}tun liqawmin yooqinoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxviii{Wa\q@b{i}khtil\q@u{a}fi allayli wa\q@b{al}nnah\q@u{a}ri wam\q@u{a} anzala All\q@u{a}hu mina a\q@b{l}ssam\q@u{a}i min rizqin faa\q@u{h}y\q@u{a} bihi alar\q@u{d}a baAAda mawtih\q@u{a} wata\q@u{s}reefi a\q@b{l}rriy\q@u{ah}i \q@u{a}y\q@u{a}tun liqawmin yaAAqiloon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxix{Tilka \q@u{a}y\q@u{a}tu All\q@u{a}hi natlooh\q@u{a} AAalayka bi\q@b{a}l\q@u{h}aqqi fabiayyi \q@u{h}adeethin baAAda All\q@u{a}hi wa\q@u{a}y\q@u{a}tihi yuminoon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxx{Waylun likulli aff\q@u{a}kin atheem\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxxi{YasmaAAu \q@u{a}y\q@u{a}ti All\q@u{a}hi tutl\q@u{a} AAalayhi thumma yu\q@u{s}irru mustakbiran kaan lam yasmaAAh\q@u{a} fabashshirhu biAAa\q@u{tha}bin aleem\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxxii{Wai\q@u{tha} AAalima min \q@u{a}y\q@u{a}tin\q@u{a} shayan ittakha\q@u{th}ah\q@u{a} huzuwan ol\q@u{a}ika lahum AAa\q@u{tha}bun muheen\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxxiii{Min war\q@u{a}ihim jahannamu wal\q@u{a} yughnee AAanhum m\q@u{a} kasaboo shayan wal\q@u{a} m\q@u{a} ittakha\q@u{th}oo min dooni All\q@u{a}hi awliy\q@u{a}a walahum AAa\q@u{tha}bun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxxiv{H\q@u{atha} hudan wa\q@b{a}lla\q@u{th}eena kafaroo bi\q@u{a}y\q@u{a}ti rabbihim lahum AAa\q@u{tha}bun min rijzin aleem\q@b{in}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxxv{All\q@u{a}hu alla\q@u{th}ee sakhkhara lakumu alba\q@u{h}ra litajriya alfulku feehi biamrihi walitabtaghoo min fa\q@u{d}lihi walaAAallakum tashkuroon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxxvi{Wasakhkhara lakum m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i jameeAAan minhu inna fee \q@u{tha}lika la\q@u{a}y\q@u{a}tin liqawmin yatafakkaroon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxxvii{Qul lilla\q@u{th}eena \q@u{a}manoo yaghfiroo lilla\q@u{th}eena l\q@u{a} yarjoona ayy\q@u{a}ma All\q@u{a}hi liyajziya qawman bim\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxxviii{Man AAamila \q@u{sa}li\q@u{h}an falinafsihi waman as\q@u{a}a faAAalayh\q@u{a} thumma il\q@u{a} rabbikum turjaAAoon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmcdlxxxix{Walaqad \q@u{a}tayn\q@u{a} banee isr\q@u{a}eela alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ukma wa\q@b{al}nnubuwwata warazaqn\q@u{a}hum mina a\q@b{l}\q@u{tt}ayyib\q@u{a}ti wafa\q@u{dd}aln\q@u{a}hum AAal\q@u{a} alAA\q@u{a}lameen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmcdxc{Wa\q@u{a}tayn\q@u{a}hum bayyin\q@u{a}tin mina alamri fam\q@u{a} ikhtalafoo ill\q@u{a} min baAAdi m\q@u{a} j\q@u{a}ahumu alAAilmu baghyan baynahum inna rabbaka yaq\q@u{d}ee baynahum yawma alqiy\q@u{a}mati feem\q@u{a} k\q@u{a}noo feehi yakhtalifoon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmcdxci{Thumma jaAAaln\q@u{a}ka AAal\q@u{a} shareeAAatin mina alamri fa\q@b{i}ttabiAAh\q@u{a} wal\q@u{a} tattabiAA ahw\q@u{a}a alla\q@u{th}eena l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmcdxcii{Innahum lan yughnoo AAanka mina All\q@u{a}hi shayan wainna a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena baAA\q@u{d}uhum awliy\q@u{a}o baAA\q@u{d}in wa\q@b{A}ll\q@u{a}hu waliyyu almuttaqeen\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmcdxciii{H\q@u{atha} ba\q@u{sa}iru li\q@b{l}nn\q@u{a}si wahudan wara\q@u{h}matun liqawmin yooqinoon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmcdxciv{Am \q@u{h}asiba alla\q@u{th}eena ijtara\q@u{h}oo a\q@b{l}ssayyi\q@u{a}ti an najAAalahum ka\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti saw\q@u{a}an ma\q@u{h}y\q@u{a}hum wamam\q@u{a}tuhum s\q@u{a}a m\q@u{a} ya\q@u{h}kumoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmcdxcv{Wakhalaqa All\q@u{a}hu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a bi\q@b{a}l\q@u{h}aqqi walitujz\q@u{a} kullu nafsin bim\q@u{a} kasabat wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmcdxcvi{Afaraayta mani ittakha\q@u{th}a il\q@u{a}hahu haw\q@u{a}hu waa\q@u{d}allahu All\q@u{a}hu AAal\q@u{a} AAilmin wakhatama AAal\q@u{a} samAAihi waqalbihi wajaAAala AAal\q@u{a} ba\q@u{s}arihi ghish\q@u{a}watan faman yahdeehi min baAAdi All\q@u{a}hi afal\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmcdxcvii{Waq\q@u{a}loo m\q@u{a} hiya ill\q@u{a} \q@u{h}ay\q@u{a}tun\q@u{a} a\q@b{l}dduny\q@u{a} namootu wana\q@u{h}y\q@u{a} wam\q@u{a} yuhlikun\q@u{a} ill\q@u{a} a\q@b{l}ddahru wam\q@u{a} lahum bi\q@u{tha}lika min AAilmin in hum ill\q@u{a} ya\q@i{\q@u{th}}unnoon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmcdxcviii{Wai\q@u{tha} tutl\q@u{a} AAalayhim \q@u{a}y\q@u{a}tun\q@u{a} bayyin\q@u{a}tin m\q@u{a} k\q@u{a}na \q@u{h}ujjatahum ill\q@u{a} an q\q@u{a}loo itoo bi\q@u{a}b\q@u{a}in\q@u{a} in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmcdxcix{Quli All\q@u{a}hu yu\q@u{h}yeekum thumma yumeetukum thumma yajmaAAukum il\q@u{a} yawmi alqiy\q@u{a}mati l\q@u{a} rayba feehi wal\q@u{a}kinna akthara a\q@b{l}nn\q@u{a}si l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmd{Walill\q@u{a}hi mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wayawma taqoomu a\q@b{l}ss\q@u{a}AAatu yawmai\q@u{th}in yakhsaru almub\q@u{t}iloon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmdi{Watar\q@u{a} kulla ommatin j\q@u{a}thiyatan kullu ommatin tudAA\q@u{a} il\q@u{a} kit\q@u{a}bih\q@u{a} alyawma tujzawna m\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmdii{H\q@u{atha} kit\q@u{a}bun\q@u{a} yan\q@u{t}iqu AAalaykum bi\q@b{a}l\q@u{h}aqqi inn\q@u{a} kunn\q@u{a} nastansikhu m\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmdiii{Faamm\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti fayudkhiluhum rabbuhum fee ra\q@u{h}matihi \q@u{tha}lika huwa alfawzu almubeen\q@b{u}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmdiv{Waamm\q@u{a} alla\q@u{th}eena kafaroo afalam takun \q@u{a}y\q@u{a}tee tutl\q@u{a} AAalaykum fa\q@b{i}stakbartum wakuntum qawman mujrimeen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmdv{Wai\q@u{tha} qeela inna waAAda All\q@u{a}hi \q@u{h}aqqun wa\q@b{al}ss\q@u{a}AAatu l\q@u{a} rayba feeh\q@u{a} qultum m\q@u{a} nadree m\q@u{a} a\q@b{l}ss\q@u{a}AAatu in na\q@i{\q@u{th}}unnu ill\q@u{a} \q@i{\q@u{th}}annan wam\q@u{a} na\q@u{h}nu bimustayqineen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmdvi{Wabad\q@u{a} lahum sayyi\q@u{a}tu m\q@u{a} AAamiloo wa\q@u{ha}qa bihim m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmdvii{Waqeela alyawma nans\q@u{a}kum kam\q@u{a} naseetum liq\q@u{a}a yawmikum h\q@u{atha} wamaw\q@u{a}kumu a\q@b{l}nn\q@u{a}ru wam\q@u{a} lakum min n\q@u{as}ireen\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmdviii{\q@u{Tha}likum biannakumu ittakha\q@u{th}tum \q@u{a}y\q@u{a}ti All\q@u{a}hi huzuwan wagharratkumu al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} fa\q@b{a}lyawma l\q@u{a} yukhrajoona minh\q@u{a} wal\q@u{a} hum yustaAAtaboon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmdix{Falill\q@u{a}hi al\q@u{h}amdu rabbi a\q@b{l}ssam\q@u{a}w\q@u{a}ti warabbi alar\q@u{d}i rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmdx{Walahu alkibriy\q@u{a}o fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmdxi{\basmalahlt \q@u{Ha}meem\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmdxii{Tanzeelu alkit\q@u{a}bi mina All\q@u{a}hi alAAazeezi al\q@u{h}akeem\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmdxiii{M\q@u{a} khalaqn\q@u{a} a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wam\q@u{a} baynahum\q@u{a} ill\q@u{a} bi\q@b{a}l\q@u{h}aqqi waajalin musamman wa\q@b{a}lla\q@u{th}eena kafaroo AAamm\q@u{a} on\q@u{th}iroo muAAri\q@u{d}oon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmdxiv{Qul araaytum m\q@u{a} tadAAoona min dooni All\q@u{a}hi aroonee m\q@u{atha} khalaqoo mina alar\q@u{d}i am lahum shirkun fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti eetoonee bikit\q@u{a}bin min qabli h\q@u{atha} aw ath\q@u{a}ratin min AAilmin in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmdxv{Waman a\q@u{d}allu mimman yadAAoo min dooni All\q@u{a}hi man l\q@u{a} yastajeebu lahu il\q@u{a} yawmi alqiy\q@u{a}mati wahum AAan duAA\q@u{a}ihim gh\q@u{a}filoon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmdxvi{Wai\q@u{tha} \q@u{h}ushira a\q@b{l}nn\q@u{a}su k\q@u{a}noo lahum aAAd\q@u{a}an wak\q@u{a}noo biAAib\q@u{a}datihim k\q@u{a}fireen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmdxvii{Wai\q@u{tha} tutl\q@u{a} AAalayhim \q@u{a}y\q@u{a}tun\q@u{a} bayyin\q@u{a}tin q\q@u{a}la alla\q@u{th}eena kafaroo lil\q@u{h}aqqi lamm\q@u{a} j\q@u{a}ahum h\q@u{atha} si\q@u{h}run mubeen\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmdxviii{Am yaqooloona iftar\q@u{a}hu qul ini iftaraytuhu fal\q@u{a} tamlikoona lee mina All\q@u{a}hi shayan huwa aAAlamu bim\q@u{a} tufee\q@u{d}oona feehi kaf\q@u{a} bihi shaheedan baynee wabaynakum wahuwa alghafooru a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmdxix{Qul m\q@u{a} kuntu bidAAan mina a\q@b{l}rrusuli wam\q@u{a} adree m\q@u{a} yufAAalu bee wal\q@u{a} bikum in attabiAAu ill\q@u{a} m\q@u{a} yoo\q@u{ha} ilayya wam\q@u{a} an\q@u{a} ill\q@u{a} na\q@u{th}eerun mubeen\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmdxx{Qul araaytum in k\q@u{a}na min AAindi All\q@u{a}hi wakafartum bihi washahida sh\q@u{a}hidun min banee isr\q@u{a}eela AAal\q@u{a} mithlihi fa\q@u{a}mana wa\q@b{i}stakbartum inna All\q@u{a}ha l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmdxxi{Waq\q@u{a}la alla\q@u{th}eena kafaroo lilla\q@u{th}eena \q@u{a}manoo law k\q@u{a}na khayran m\q@u{a} sabaqoon\q@u{a} ilayhi wai\q@u{th} lam yahtadoo bihi fasayaqooloona h\q@u{atha} ifkun qadeem\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmdxxii{Wamin qablihi kit\q@u{a}bu moos\q@u{a} im\q@u{a}man wara\q@u{h}matan wah\q@u{atha} kit\q@u{a}bun mu\q@u{s}addiqun lis\q@u{a}nan AAarabiyyan liyun\q@u{th}ira alla\q@u{th}eena \q@i{\q@u{th}}alamoo wabushr\q@u{a} lilmu\q@u{h}sineen\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmdxxiii{Inna alla\q@u{th}eena q\q@u{a}loo rabbun\q@u{a} All\q@u{a}hu thumma istaq\q@u{a}moo fal\q@u{a} khawfun AAalayhim wal\q@u{a} hum ya\q@u{h}zanoon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmdxxiv{Ol\q@u{a}ika a\q@u{s}\q@u{ha}bu aljannati kh\q@u{a}lideena feeh\q@u{a} jaz\q@u{a}an bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmdxxv{Wawa\q@u{ss}ayn\q@u{a} alins\q@u{a}na biw\q@u{a}lidayhi i\q@u{h}s\q@u{a}nan \q@u{h}amalathu ommuhu kurhan wawa\q@u{d}aAAathu kurhan wa\q@u{h}amluhu wafi\q@u{sa}luhu thal\q@u{a}thoona shahran \q@u{h}att\q@u{a} i\q@u{tha} balagha ashuddahu wabalagha arbaAAeena sanatan q\q@u{a}la rabbi awziAAnee an ashkura niAAmataka allatee anAAamta AAalayya waAAal\q@u{a} w\q@u{a}lidayya waan aAAmala \q@u{sa}li\q@u{h}an tar\q@u{da}hu waa\q@u{s}li\q@u{h} lee fee \q@u{th}urriyyatee innee tubtu ilayka wainnee mina almuslimeen\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmdxxvi{Ol\q@u{a}ika alla\q@u{th}eena nataqabbalu AAanhum a\q@u{h}sana m\q@u{a} AAamiloo wanataj\q@u{a}wazu AAan sayyi\q@u{a}tihim fee a\q@u{s}\q@u{ha}bi aljannati waAAda a\q@b{l}\q@u{ss}idqi alla\q@u{th}ee k\q@u{a}noo yooAAadoon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmdxxvii{Wa\q@b{a}lla\q@u{th}ee q\q@u{a}la liw\q@u{a}lidayhi offin lakum\q@u{a} ataAAid\q@u{a}ninee an okhraja waqad khalati alquroonu min qablee wahum\q@u{a} yastagheeth\q@u{a}ni All\q@u{a}ha waylaka \q@u{a}min inna waAAda All\q@u{a}hi \q@u{h}aqqun fayaqoolu m\q@u{a} h\q@u{atha} ill\q@u{a} as\q@u{at}eeru alawwaleen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmdxxviii{Ol\q@u{a}ika alla\q@u{th}eena \q@u{h}aqqa AAalayhimu alqawlu fee umamin qad khalat min qablihim mina aljinni wa\q@b{a}linsi innahum k\q@u{a}noo kh\q@u{a}sireen\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmdxxix{Walikullin daraj\q@u{a}tun mimm\q@u{a} AAamiloo waliyuwaffiyahum aAAm\q@u{a}lahum wahum l\q@u{a} yu\q@i{\q@u{th}}lamoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmdxxx{Wayawma yuAAra\q@u{d}u alla\q@u{th}eena kafaroo AAal\q@u{a} a\q@b{l}nn\q@u{a}ri a\q@u{th}habtum \q@u{t}ayyib\q@u{a}tikum fee \q@u{h}ay\q@u{a}tikumu a\q@b{l}dduny\q@u{a} wa\q@b{i}stamtaAAtum bih\q@u{a} fa\q@b{a}lyawma tujzawna AAa\q@u{tha}ba alhooni bim\q@u{a} kuntum tastakbiroona fee alar\q@u{d}i bighayri al\q@u{h}aqqi wabim\q@u{a} kuntum tafsuqoon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmdxxxi{Wa\q@b{o}\q@u{th}kur akh\q@u{a} AA\q@u{a}din i\q@u{th} an\q@u{th}ara qawmahu bi\q@b{a}la\q@u{h}q\q@u{a}fi waqad khalati a\q@b{l}nnu\q@u{th}uru min bayni yadayhi wamin khalfihi all\q@u{a} taAAbudoo ill\q@u{a} All\q@u{a}ha innee akh\q@u{a}fu AAalaykum AAa\q@u{tha}ba yawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmdxxxii{Q\q@u{a}loo ajitan\q@u{a} litafikan\q@u{a} AAan \q@u{a}lihatin\q@u{a} fatin\q@u{a} bim\q@u{a} taAAidun\q@u{a} in kunta mina a\q@b{l}\q@u{ssa}diqeen\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmdxxxiii{Q\q@u{a}la innam\q@u{a} alAAilmu AAinda All\q@u{a}hi waoballighukum m\q@u{a} orsiltu bihi wal\q@u{a}kinnee ar\q@u{a}kum qawman tajhaloon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmdxxxiv{Falamm\q@u{a} raawhu AA\q@u{a}ri\q@u{d}an mustaqbila awdiyatihim q\q@u{a}loo h\q@u{atha} AA\q@u{a}ri\q@u{d}un mum\q@u{t}irun\q@u{a} bal huwa m\q@u{a} istaAAjaltum bihi ree\q@u{h}un feeh\q@u{a} AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmdxxxv{Tudammiru kulla shayin biamri rabbih\q@u{a} faa\q@u{s}ba\q@u{h}oo l\q@u{a} yur\q@u{a} ill\q@u{a} mas\q@u{a}kinuhum ka\q@u{tha}lika najzee alqawma almujrimeen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmdxxxvi{Walaqad makkann\q@u{a}hum feem\q@u{a} in makkann\q@u{a}kum feehi wajaAAaln\q@u{a} lahum samAAan waab\q@u{sa}ran waafidatan fam\q@u{a} aghn\q@u{a} AAanhum samAAuhum wal\q@u{a} ab\q@u{sa}ruhum wal\q@u{a} afidatuhum min shayin i\q@u{th} k\q@u{a}noo yaj\q@u{h}adoona bi\q@u{a}y\q@u{a}ti All\q@u{a}hi wa\q@u{ha}qa bihim m\q@u{a} k\q@u{a}noo bihi yastahzioon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmdxxxvii{Walaqad ahlakn\q@u{a} m\q@u{a} \q@u{h}awlakum mina alqur\q@u{a} wa\q@u{s}arrafn\q@u{a} al\q@u{a}y\q@u{a}ti laAAallahum yarjiAAoon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmdxxxviii{Falawl\q@u{a} na\q@u{s}arahumu alla\q@u{th}eena ittakha\q@u{th}oo min dooni All\q@u{a}hi qurb\q@u{a}nan \q@u{a}lihatan bal \q@u{d}alloo AAanhum wa\q@u{tha}lika ifkuhum wam\q@u{a} k\q@u{a}noo yaftaroon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmdxxxix{Wai\q@u{th} \q@u{s}arafn\q@u{a} ilayka nafaran mina aljinni yastamiAAoona alqur\q@u{a}na falamm\q@u{a} \q@u{h}a\q@u{d}aroohu q\q@u{a}loo an\q@u{s}itoo falamm\q@u{a} qu\q@u{d}iya wallaw il\q@u{a} qawmihim mun\q@u{th}ireen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmdxl{Q\q@u{a}loo y\q@u{a} qawman\q@u{a} inn\q@u{a} samiAAn\q@u{a} kit\q@u{a}ban onzila min baAAdi moos\q@u{a} mu\q@u{s}addiqan lim\q@u{a} bayna yadayhi yahdee il\q@u{a} al\q@u{h}aqqi wail\q@u{a} \q@u{t}areeqin mustaqeem\q@b{in}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmdxli{Y\q@u{a} qawman\q@u{a} ajeeboo d\q@u{a}AAiya All\q@u{a}hi wa\q@u{a}minoo bihi yaghfir lakum min \q@u{th}unoobikum wayujirkum min AAa\q@u{tha}bin aleem\q@b{in}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmdxlii{Waman l\q@u{a} yujib d\q@u{a}AAiya All\q@u{a}hi falaysa bimuAAjizin fee alar\q@u{d}i walaysa lahu min doonihi awliy\q@u{a}a ol\q@u{a}ika fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmdxliii{Awalam yaraw anna All\q@u{a}ha alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a walam yaAAya bikhalqihinna biq\q@u{a}dirin AAal\q@u{a} an yu\q@u{h}yiya almawt\q@u{a} bal\q@u{a} innahu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmdxliv{Wayawma yuAAra\q@u{d}u alla\q@u{th}eena kafaroo AAal\q@u{a} a\q@b{l}nn\q@u{a}ri alaysa h\q@u{atha} bi\q@b{a}l\q@u{h}aqqi q\q@u{a}loo bal\q@u{a} warabbin\q@u{a} q\q@u{a}la fa\q@u{th}ooqoo alAAa\q@u{tha}ba bim\q@u{a} kuntum takfuroon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmdxlv{Fa\q@b{i}\q@u{s}bir kam\q@u{a} \q@u{s}abara oloo alAAazmi mina a\q@b{l}rrusuli wal\q@u{a} tastaAAjil lahum kaannahum yawma yarawna m\q@u{a} yooAAadoona lam yalbathoo ill\q@u{a} s\q@u{a}AAatan min nah\q@u{a}rin bal\q@u{a}ghun fahal yuhlaku ill\q@u{a} alqawmu alf\q@u{a}siqoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmdxlvi{\basmalahlt Alla\q@u{th}eena kafaroo wa\q@u{s}addoo AAan sabeeli All\q@u{a}hi a\q@u{d}alla aAAm\q@u{a}lahum\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmdxlvii{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti wa\q@u{a}manoo bim\q@u{a} nuzzila AAal\q@u{a} mu\q@u{h}ammadin wahuwa al\q@u{h}aqqu min rabbihim kaffara AAanhum sayyi\q@u{a}tihim waa\q@u{s}la\q@u{h}a b\q@u{a}lahum\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmdxlviii{\q@u{Tha}lika bianna alla\q@u{th}eena kafaroo ittabaAAoo alb\q@u{at}ila waanna alla\q@u{th}eena \q@u{a}manoo ittabaAAoo al\q@u{h}aqqa min rabbihim ka\q@u{tha}lika ya\q@u{d}ribu All\q@u{a}hu li\q@b{l}nn\q@u{a}si amth\q@u{a}lahum\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmdxlix{Fai\q@u{tha} laqeetumu alla\q@u{th}eena kafaroo fa\q@u{d}arba a\q@b{l}rriq\q@u{a}bi \q@u{h}att\q@u{a} i\q@u{tha} athkhantumoohum fashuddoo alwath\q@u{a}qa faimm\q@u{a} mannan baAAdu waimm\q@u{a} fid\q@u{a}an \q@u{h}att\q@u{a} ta\q@u{d}aAAa al\q@u{h}arbu awz\q@u{a}rah\q@u{a} \q@u{tha}lika walaw yash\q@u{a}o All\q@u{a}hu la\q@b{i}nta\q@u{s}ara minhum wal\q@u{a}kin liyabluwa baAA\q@u{d}akum bibaAA\q@u{d}in wa\q@b{a}lla\q@u{th}eena qutiloo fee sabeeli All\q@u{a}hi falan yu\q@u{d}illa aAAm\q@u{a}lahum\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmdl{Sayahdeehim wayu\q@u{s}li\q@u{h}u b\q@u{a}lahum\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmdli{Wayudkhiluhumu aljannata AAarrafah\q@u{a} lahum\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmdlii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo in tan\q@u{s}uroo All\q@u{a}ha yan\q@u{s}urkum wayuthabbit aqd\q@u{a}makum\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmdliii{Wa\q@b{a}lla\q@u{th}eena kafaroo fataAAsan lahum waa\q@u{d}alla aAAm\q@u{a}lahum\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmdliv{\q@u{Tha}lika biannahum karihoo m\q@u{a} anzala All\q@u{a}hu faa\q@u{h}ba\q@u{t}a aAAm\q@u{a}lahum\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmdlv{Afalam yaseeroo fee alar\q@u{d}i fayan\q@i{\q@u{th}}uroo kayfa k\q@u{a}na AA\q@u{a}qibatu alla\q@u{th}eena min qablihim dammara All\q@u{a}hu AAalayhim walilk\q@u{a}fireena amth\q@u{a}luh\q@u{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmdlvi{\q@u{Tha}lika bianna All\q@u{a}ha mawl\q@u{a} alla\q@u{th}eena \q@u{a}manoo waanna alk\q@u{a}fireena l\q@u{a} mawl\q@u{a} lahum\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmdlvii{Inna All\q@u{a}ha yudkhilu alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru wa\q@b{a}lla\q@u{th}eena kafaroo yatamattaAAoona wayakuloona kam\q@u{a} takulu alanAA\q@u{a}mu wa\q@b{al}nn\q@u{a}ru mathwan lahum\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmdlviii{Wakaayyin min qaryatin hiya ashaddu quwwatan min qaryatika allatee akhrajatka ahlakn\q@u{a}hum fal\q@u{a} n\q@u{as}ira lahum\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmdlix{Afaman k\q@u{a}na AAal\q@u{a} bayyinatin min rabbihi kaman zuyyina lahu sooo AAamalihi wa\q@b{i}ttabaAAoo ahw\q@u{a}ahum\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmdlx{Mathalu aljannati allatee wuAAida almuttaqoona feeh\q@u{a} anh\q@u{a}run min m\q@u{a}in ghayri \q@u{a}sinin waanh\q@u{a}run min labanin lam yataghayyar \q@u{t}aAAmuhu waanh\q@u{a}run min khamrin la\q@u{thth}atin li\q@b{l}shsh\q@u{a}ribeena waanh\q@u{a}run min AAasalin mu\q@u{s}affan walahum feeh\q@u{a} min kulli a\q@b{l}ththamar\q@u{a}ti wamaghfiratun min rabbihim kaman huwa kh\q@u{a}lidun fee a\q@b{l}nn\q@u{a}ri wasuqoo m\q@u{a}an \q@u{h}ameeman faqa\q@u{tt}aAAa amAA\q@u{a}ahum\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmdlxi{Waminhum man yastamiAAu ilayka \q@u{h}att\q@u{a} i\q@u{tha} kharajoo min AAindika q\q@u{a}loo lilla\q@u{th}eena ootoo alAAilma m\q@u{atha} q\q@u{a}la \q@u{a}nifan ol\q@u{a}ika alla\q@u{th}eena \q@u{t}abaAAa All\q@u{a}hu AAal\q@u{a} quloobihim wa\q@b{i}ttabaAAoo ahw\q@u{a}ahum\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmdlxii{Wa\q@b{a}lla\q@u{th}eena ihtadaw z\q@u{a}dahum hudan wa\q@u{a}t\q@u{a}hum taqw\q@u{a}hum\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmdlxiii{Fahal yan\q@i{\q@u{th}}uroona ill\q@u{a} a\q@b{l}ss\q@u{a}AAata an tatiyahum baghtatan faqad j\q@u{a}a ashr\q@u{at}uh\q@u{a} faann\q@u{a} lahum i\q@u{tha} j\q@u{a}athum \q@u{th}ikr\q@u{a}hum\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmdlxiv{Fa\q@b{i}AAlam annahu l\q@u{a} il\q@u{a}ha ill\q@u{a} All\q@u{a}hu wa\q@b{i}staghfir li\q@u{th}anbika walilmumineena wa\q@b{a}lmumin\q@u{a}ti wa\q@b{A}ll\q@u{a}hu yaAAlamu mutaqallabakum wamathw\q@u{a}kum\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmdlxv{Wayaqoolu alla\q@u{th}eena \q@u{a}manoo lawl\q@u{a} nuzzilat sooratun fai\q@u{tha} onzilat sooratun mu\q@u{h}kamatun wa\q@u{th}ukira feeh\q@u{a} alqit\q@u{a}lu raayta alla\q@u{th}eena fee quloobihim mara\q@u{d}un yan\q@i{\q@u{th}}uroona ilayka na\q@i{\q@u{th}}ara almaghshiyyi AAalayhi mina almawti faawl\q@u{a} lahum\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmdlxvi{\q@u{Ta}AAatun waqawlun maAAroofun fai\q@u{tha} AAazama alamru falaw \q@u{s}adaqoo All\q@u{a}ha lak\q@u{a}na khayran lahum\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmdlxvii{Fahal AAasaytum in tawallaytum an tufsidoo fee alar\q@u{d}i watuqa\q@u{tt}iAAoo ar\q@u{ha}makum\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmdlxviii{Ol\q@u{a}ika alla\q@u{th}eena laAAanahumu All\q@u{a}hu faa\q@u{s}ammahum waaAAm\q@u{a} ab\q@u{sa}rahum\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmdlxix{Afal\q@u{a} yatadabbaroona alqur\q@u{a}na am AAal\q@u{a} quloobin aqf\q@u{a}luh\q@u{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmdlxx{Inna alla\q@u{th}eena irtaddoo AAal\q@u{a} adb\q@u{a}rihim min baAAdi m\q@u{a} tabayyana lahumu alhud\q@u{a} a\q@b{l}shshay\q@u{ta}nu sawwala lahum waaml\q@u{a} lahum\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxi{\q@u{Tha}lika biannahum q\q@u{a}loo lilla\q@u{th}eena karihoo m\q@u{a} nazzala All\q@u{a}hu sanu\q@u{t}eeAAukum fee baAA\q@u{d}i alamri wa\q@b{A}ll\q@u{a}hu yaAAlamu isr\q@u{a}rahum\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxii{Fakayfa i\q@u{tha} tawaffathumu almal\q@u{a}ikatu ya\q@u{d}riboona wujoohahum waadb\q@u{a}rahum\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxiii{\q@u{Tha}lika biannahumu ittabaAAoo m\q@u{a} askha\q@u{t}a All\q@u{a}ha wakarihoo ri\q@u{d}w\q@u{a}nahu faa\q@u{h}ba\q@u{t}a aAAm\q@u{a}lahum\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxiv{Am \q@u{h}asiba alla\q@u{th}eena fee quloobihim mara\q@u{d}un an lan yukhrija All\q@u{a}hu a\q@u{d}gh\q@u{a}nahum\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxv{Walaw nash\q@u{a}o laarayn\q@u{a}kahum falaAAaraftahum biseem\q@u{a}hum walataAArifannahum fee la\q@u{h}ni alqawli wa\q@b{A}ll\q@u{a}hu yaAAlamu aAAm\q@u{a}lakum\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxvi{Walanabluwannakum \q@u{h}att\q@u{a} naAAlama almuj\q@u{a}hideena minkum wa\q@b{al}\q@u{ssa}bireena wanabluwa akhb\q@u{a}rakum\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxvii{Inna alla\q@u{th}eena kafaroo wa\q@u{s}addoo AAan sabeeli All\q@u{a}hi wash\q@u{a}qqoo a\q@b{l}rrasoola min baAAdi m\q@u{a} tabayyana lahumu alhud\q@u{a} lan ya\q@u{d}uroo All\q@u{a}ha shayan wasayu\q@u{h}bi\q@u{t}u aAAm\q@u{a}lahum\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxviii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo a\q@u{t}eeAAoo All\q@u{a}ha waa\q@u{t}eeAAoo a\q@b{l}rrasoola wal\q@u{a} tub\q@u{t}iloo aAAm\q@u{a}lakum\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxix{Inna alla\q@u{th}eena kafaroo wa\q@u{s}addoo AAan sabeeli All\q@u{a}hi thumma m\q@u{a}too wahum kuff\q@u{a}run falan yaghfira All\q@u{a}hu lahum\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxx{Fal\q@u{a} tahinoo watadAAoo il\q@u{a} a\q@b{l}ssalmi waantumu alaAAlawna wa\q@b{A}ll\q@u{a}hu maAAakum walan yatirakum aAAm\q@u{a}lakum\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxxi{Innam\q@u{a} al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} laAAibun walahwun wain tuminoo watattaqoo yutikum ojoorakum wal\q@u{a} yasalkum amw\q@u{a}lakum\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxxii{In yasalkumooh\q@u{a} fayu\q@u{h}fikum tabkhaloo wayukhrij a\q@u{d}gh\q@u{a}nakum\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxxiii{H\q@u{a}antum h\q@u{a}ol\q@u{a}i tudAAawna litunfiqoo fee sabeeli All\q@u{a}hi faminkum man yabkhalu waman yabkhal fainnam\q@u{a} yabkhalu AAan nafsihi wa\q@b{A}ll\q@u{a}hu alghaniyyu waantumu alfuqar\q@u{a}o wain tatawallaw yastabdil qawman ghayrakum thumma l\q@u{a} yakoonoo amth\q@u{a}lakum\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxxiv{\basmalahlt Inn\q@u{a} fata\q@u{h}n\q@u{a} laka fat\q@u{h}an mubeen\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxxv{Liyaghfira laka All\q@u{a}hu m\q@u{a} taqaddama min \q@u{th}anbika wam\q@u{a} taakhkhara wayutimma niAAmatahu AAalayka wayahdiyaka \q@u{s}ir\q@u{at}an mustaqeem\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxxvi{Wayan\q@u{s}uraka All\q@u{a}hu na\q@u{s}ran AAazeez\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxxvii{Huwa alla\q@u{th}ee anzala a\q@b{l}ssakeenata fee quloobi almumineena liyazd\q@u{a}doo eem\q@u{a}nan maAAa eem\q@u{a}nihim walill\q@u{a}hi junoodu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wak\q@u{a}na All\q@u{a}hu AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxxviii{Liyudkhila almumineena wa\q@b{a}lmumin\q@u{a}ti jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} wayukaffira AAanhum sayyi\q@u{a}tihim wak\q@u{a}na \q@u{tha}lika AAinda All\q@u{a}hi fawzan AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmdlxxxix{WayuAAa\q@u{thth}iba almun\q@u{a}fiqeena wa\q@b{a}lmun\q@u{a}fiq\q@u{a}ti wa\q@b{a}lmushrikeena wa\q@b{a}lmushrik\q@u{a}ti a\q@b{l}\q@i{\q@u{thth}}\q@u{a}nneena bi\q@b{A}ll\q@u{a}hi \q@i{\q@u{th}}anna a\q@b{l}ssawi AAalayhim d\q@u{a}iratu a\q@b{l}ssawi wagha\q@u{d}iba All\q@u{a}hu AAalayhim walaAAanahum waaAAadda lahum jahannama was\q@u{a}at ma\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmdxc{Walill\q@u{a}hi junoodu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wak\q@u{a}na All\q@u{a}hu AAazeezan \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmdxci{Inn\q@u{a} arsaln\q@u{a}ka sh\q@u{a}hidan wamubashshiran wana\q@u{th}eer\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmdxcii{Lituminoo bi\q@b{A}ll\q@u{a}hi warasoolihi watuAAazziroohu watuwaqqiroohu watusabbi\q@u{h}oohu bukratan waa\q@u{s}eel\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmdxciii{Inna alla\q@u{th}eena yub\q@u{a}yiAAoonaka innam\q@u{a} yub\q@u{a}yiAAoona All\q@u{a}ha yadu All\q@u{a}hi fawqa aydeehim faman nakatha fainnam\q@u{a} yankuthu AAal\q@u{a} nafsihi waman awf\q@u{a} bim\q@u{a} AA\q@u{a}hada AAalayhu All\q@u{a}ha fasayuteehi ajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmdxciv{Sayaqoolu laka almukhallafoona mina alaAAr\q@u{a}bi shaghalatn\q@u{a} amw\q@u{a}lun\q@u{a} waahloon\q@u{a} fa\q@b{i}staghfir lan\q@u{a} yaqooloona bialsinatihim m\q@u{a} laysa fee quloobihim qul faman yamliku lakum mina All\q@u{a}hi shayan in ar\q@u{a}da bikum \q@u{d}arran aw ar\q@u{a}da bikum nafAAan bal k\q@u{a}na All\q@u{a}hu bim\q@u{a} taAAmaloona khabeer\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmdxcv{Bal \q@i{\q@u{th}}anantum an lan yanqaliba a\q@b{l}rrasoolu wa\q@b{a}lmuminoona il\q@u{a} ahleehim abadan wazuyyina \q@u{tha}lika fee quloobikum wa\q@i{\q@u{th}}anantum \q@i{\q@u{th}}anna a\q@b{l}ssawi wakuntum qawman boor\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmdxcvi{Waman lam yumin bi\q@b{A}ll\q@u{a}hi warasoolihi fainn\q@u{a} aAAtadn\q@u{a} lilk\q@u{a}fireena saAAeer\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmdxcvii{Walill\q@u{a}hi mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i yaghfiru liman yash\q@u{a}o wayuAAa\q@u{thth}ibu man yash\q@u{a}o wak\q@u{a}na All\q@u{a}hu ghafooran ra\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmdxcviii{Sayaqoolu almukhallafoona i\q@u{tha} in\q@u{t}alaqtum il\q@u{a} magh\q@u{a}nima litakhu\q@u{th}ooh\q@u{a} \q@u{th}aroon\q@u{a} nattabiAAkum yureedoona an yubaddiloo kal\q@u{a}ma All\q@u{a}hi qul lan tattabiAAoon\q@u{a} ka\q@u{tha}likum q\q@u{a}la All\q@u{a}hu min qablu fasayaqooloona bal ta\q@u{h}sudoonan\q@u{a} bal k\q@u{a}noo l\q@u{a} yafqahoona ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmdxcix{Qul lilmukhallafeena mina alaAAr\q@u{a}bi satudAAawna il\q@u{a} qawmin olee basin shadeedin tuq\q@u{a}tiloonahum aw yuslimoona fain tu\q@u{t}eeAAoo yutikumu All\q@u{a}hu ajran \q@u{h}asanan wain tatawallaw kam\q@u{a} tawallaytum min qablu yuAAa\q@u{thth}ibkum AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmdc{Laysa AAal\q@u{a} alaAAm\q@u{a} \q@u{h}arajun wal\q@u{a} AAal\q@u{a} alaAAraji \q@u{h}arajun wal\q@u{a} AAal\q@u{a} almaree\q@u{d}i \q@u{h}arajun waman yu\q@u{t}iAAi All\q@u{a}ha warasoolahu yudkhilhu jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru waman yatawalla yuAAa\q@u{thth}ibhu AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmdci{Laqad ra\q@u{d}iya All\q@u{a}hu AAani almumineena i\q@u{th} yub\q@u{a}yiAAoonaka ta\q@u{h}ta a\q@b{l}shshajarati faAAalima m\q@u{a} fee quloobihim faanzala a\q@b{l}sakeenata AAalayhim waath\q@u{a}bahum fat\q@u{h}an qareeb\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmdcii{Wamagh\q@u{a}nima katheeratan yakhu\q@u{th}oonah\q@u{a} wak\q@u{a}na All\q@u{a}hu AAazeezan \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmdciii{WaAAadakumu All\q@u{a}hu magh\q@u{a}nima katheeratan takhu\q@u{th}oonah\q@u{a} faAAajjala lakum h\q@u{ath}ihi wakaffa aydiya a\q@b{l}nn\q@u{a}si AAankum walitakoona \q@u{a}yatan lilmumineena wayahdiyakum \q@u{s}ir\q@u{at}an mustaqeem\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmdciv{Waokhr\q@u{a} lam taqdiroo AAalayh\q@u{a} qad a\q@u{hat}a All\q@u{a}hu bih\q@u{a} wak\q@u{a}na All\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmdcv{Walaw q\q@u{a}talakumu alla\q@u{th}eena kafaroo lawallawoo aladb\q@u{a}ra thumma l\q@u{a} yajidoona waliyyan wal\q@u{a} na\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmdcvi{Sunnata All\q@u{a}hi allatee qad khalat min qablu walan tajida lisunnati All\q@u{a}hi tabdeel\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmdcvii{Wahuwa alla\q@u{th}ee kaffa aydiyahum AAankum waaydiyakum AAanhum biba\q@u{t}ni makkata min baAAdi an a\q@i{\q@u{th}}farakum AAalayhim wak\q@u{a}na All\q@u{a}hu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmdcviii{Humu alla\q@u{th}eena kafaroo wa\q@u{s}addookum AAani almasjidi al\q@u{h}ar\q@u{a}mi wa\q@b{a}lhadya maAAkoofan an yablugha ma\q@u{h}illahu walawl\q@u{a} rij\q@u{a}lun muminoona wanis\q@u{a}on mumin\q@u{a}tun lam taAAlamoohum an ta\q@u{t}aoohum fatu\q@u{s}eebakum minhum maAAarratun bighayri AAilmin liyudkhila All\q@u{a}hu fee ra\q@u{h}matihi man yash\q@u{a}o law tazayyaloo laAAa\q@u{thth}abn\q@u{a} alla\q@u{th}eena kafaroo minhum AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmdcix{I\q@u{th} jaAAala alla\q@u{th}eena kafaroo fee quloobihimu al\q@u{h}amiyyata \q@u{h}amiyyata alj\q@u{a}hiliyyati faanzala All\q@u{a}hu sakeenatahu AAal\q@u{a} rasoolihi waAAal\q@u{a} almumineena waalzamahum kalimata a\q@b{l}ttaqw\q@u{a} wak\q@u{a}noo a\q@u{h}aqqa bih\q@u{a} waahlah\q@u{a} wak\q@u{a}na All\q@u{a}hu bikulli shayin AAaleem\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmdcx{Laqad \q@u{s}adaqa All\q@u{a}hu rasoolahu a\q@b{l}rruy\q@u{a} bi\q@b{a}l\q@u{h}aqqi latadkhulunna almasjida al\q@u{h}ar\q@u{a}ma in sh\q@u{a}a All\q@u{a}hu \q@u{a}mineena mu\q@u{h}alliqeena ruoosakum wamuqa\q@u{ss}ireena l\q@u{a} takh\q@u{a}foona faAAalima m\q@u{a} lam taAAlamoo fajaAAala min dooni \q@u{tha}lika fat\q@u{h}an qareeb\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmdcxi{Huwa alla\q@u{th}ee arsala rasoolahu bi\q@b{a}lhud\q@u{a} wadeeni al\q@u{h}aqqi liyu\q@i{\q@u{th}}hirahu AAal\q@u{a} a\q@b{l}ddeeni kullihi wakaf\q@u{a} bi\q@b{A}ll\q@u{a}hi shaheed\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmdcxii{Mu\q@u{h}ammadun rasoolu All\q@u{a}hi wa\q@b{a}lla\q@u{th}eena maAAahu ashidd\q@u{a}o AAal\q@u{a} alkuff\q@u{a}ri ru\q@u{h}am\q@u{a}o baynahum tar\q@u{a}hum rukkaAAan sujjadan yabtaghoona fa\q@u{d}lan mina All\q@u{a}hi wari\q@u{d}w\q@u{a}nan seem\q@u{a}hum fee wujoohihim min athari a\q@b{l}ssujoodi \q@u{tha}lika mathaluhum fee a\q@b{l}ttawr\q@u{a}ti wamathaluhum fee alinjeeli kazarAAin akhraja sha\q@u{t}ahu fa\q@u{a}zarahu fa\q@b{i}staghla\q@i{\q@u{th}}a fa\q@b{i}staw\q@u{a} AAal\q@u{a} sooqihi yuAAjibu a\q@b{l}zzurr\q@u{a}AAa liyaghee\q@i{\q@u{th}}a bihimu alkuff\q@u{a}ra waAAada All\q@u{a}hu alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti minhum maghfiratan waajran AAa\q@i{\q@u{th}}eem\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmdcxiii{\basmalahlt Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tuqaddimoo bayna yadayi All\q@u{a}hi warasoolihi wa\q@b{i}ttaqoo All\q@u{a}ha inna All\q@u{a}ha sameeAAun AAaleem\q@b{un}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmdcxiv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tarfaAAoo a\q@u{s}w\q@u{a}takum fawqa \q@u{s}awti a\q@b{l}nnabiyyi wal\q@u{a} tajharoo lahu bi\q@b{a}lqawli kajahri baAA\q@u{d}ikum libaAA\q@u{d}in an ta\q@u{h}ba\q@u{t}a aAAm\q@u{a}lukum waantum l\q@u{a} tashAAuroon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmdcxv{Inna alla\q@u{th}eena yaghu\q@u{dd}oona a\q@u{s}w\q@u{a}tahum AAinda rasooli All\q@u{a}hi ol\q@u{a}ika alla\q@u{th}eena imta\q@u{h}ana All\q@u{a}hu quloobahum li\q@b{l}ttaqw\q@u{a} lahum maghfiratun waajrun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmdcxvi{Inna alla\q@u{th}eena yun\q@u{a}doonaka min war\q@u{a}i al\q@u{h}ujur\q@u{a}ti aktharuhum l\q@u{a} yaAAqiloon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmdcxvii{Walaw annahum \q@u{s}abaroo \q@u{h}att\q@u{a} takhruja ilayhim lak\q@u{a}na khayran lahum wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmdcxviii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo in j\q@u{a}akum f\q@u{a}siqun binabain fatabayyanoo an tu\q@u{s}eeboo qawman bijah\q@u{a}latin fatu\q@u{s}bi\q@u{h}oo AAal\q@u{a} m\q@u{a} faAAaltum n\q@u{a}dimeen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmdcxix{Wa\q@b{i}AAlamoo anna feekum rasoola All\q@u{a}hi law yu\q@u{t}eeAAukum fee katheerin mina alamri laAAanittum wal\q@u{a}kinna All\q@u{a}ha \q@u{h}abbaba ilaykumu aleem\q@u{a}na wazayyanahu fee quloobikum wakarraha ilaykumu alkufra wa\q@b{a}lfusooqa wa\q@b{a}lAAi\q@u{s}y\q@u{a}na ol\q@u{a}ika humu a\q@b{l}rr\q@u{a}shidoon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmdcxx{Fa\q@u{d}lan mina All\q@u{a}hi waniAAmatan wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxi{Wain \q@u{ta}ifat\q@u{a}ni mina almumineena iqtataloo faa\q@u{s}li\q@u{h}oo baynahum\q@u{a} fain baghat i\q@u{h}d\q@u{a}hum\q@u{a} AAal\q@u{a} alokhr\q@u{a} faq\q@u{a}tiloo allatee tabghee \q@u{h}att\q@u{a} tafeea il\q@u{a} amri All\q@u{a}hi fain f\q@u{a}at faa\q@u{s}li\q@u{h}oo baynahum\q@u{a} bi\q@b{a}lAAadli waaqsi\q@u{t}oo inna All\q@u{a}ha yu\q@u{h}ibbu almuqsi\q@u{t}een\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxii{Innam\q@u{a} almuminoona ikhwatun faa\q@u{s}li\q@u{h}oo bayna akhawaykum wa\q@b{i}ttaqoo All\q@u{a}ha laAAallakum tur\q@u{h}amoon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} yaskhar qawmun min qawmin AAas\q@u{a} an yakoonoo khayran minhum wal\q@u{a} nis\q@u{a}on min nis\q@u{a}in AAas\q@u{a} an yakunna khayran minhunna wal\q@u{a} talmizoo anfusakum wal\q@u{a} tan\q@u{a}bazoo bi\q@b{a}lalq\q@u{a}bi bisa alismu alfusooqu baAAda aleem\q@u{a}ni waman lam yatub faol\q@u{a}ika humu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxiv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo ijtaniboo katheeran mina a\q@b{l}\q@i{\q@u{thth}}anni inna baAA\q@u{d}a a\q@b{l}\q@i{\q@u{thth}}anni ithmun wal\q@u{a} tajassasoo wal\q@u{a} yaghtab baAA\q@u{d}ukum baAA\q@u{d}an ayu\q@u{h}ibbu a\q@u{h}adukum an yakula la\q@u{h}ma akheehi maytan fakarihtumoohu wa\q@b{i}ttaqoo All\q@u{a}ha inna All\q@u{a}ha taww\q@u{a}bun ra\q@u{h}eem\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxv{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nn\q@u{a}su inn\q@u{a} khalaqn\q@u{a}kum min \q@u{th}akarin waonth\q@u{a} wajaAAaln\q@u{a}kum shuAAooban waqab\q@u{a}ila litaAA\q@u{a}rafoo inna akramakum AAinda All\q@u{a}hi atq\q@u{a}kum inna All\q@u{a}ha AAaleemun khabeer\q@b{un}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxvi{Q\q@u{a}lati alaAAr\q@u{a}bu \q@u{a}mann\q@u{a} qul lam tuminoo wal\q@u{a}kin qooloo aslamn\q@u{a} walamm\q@u{a} yadkhuli aleem\q@u{a}nu fee quloobikum wain tu\q@u{t}eeAAoo All\q@u{a}ha warasoolahu l\q@u{a} yalitkum min aAAm\q@u{a}likum shayan inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxvii{Innam\q@u{a} almuminoona alla\q@u{th}eena \q@u{a}manoo bi\q@b{A}ll\q@u{a}hi warasoolihi thumma lam yart\q@u{a}boo waj\q@u{a}hadoo biamw\q@u{a}lihim waanfusihim fee sabeeli All\q@u{a}hi ol\q@u{a}ika humu a\q@b{l}\q@u{ssa}diqoon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxviii{Qul atuAAallimoona All\q@u{a}ha bideenikum wa\q@b{A}ll\q@u{a}hu yaAAlamu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wa\q@b{A}ll\q@u{a}hu bikulli shayin AAaleem\q@b{un}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxix{Yamunnoona AAalayka an aslamoo qul l\q@u{a} tamunnoo AAalayya isl\q@u{a}makum bali All\q@u{a}hu yamunnu AAalaykum an had\q@u{a}kum lileem\q@u{a}ni in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxx{Inna All\q@u{a}ha yaAAlamu ghayba a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{A}ll\q@u{a}hu ba\q@u{s}eerun bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxxi{\basmalahlt Q\q@u{a}f wa\q@b{a}lqur\q@u{a}ni almajeed\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxxii{Bal AAajiboo an j\q@u{a}ahum mun\q@u{th}irun minhum faq\q@u{a}la alk\q@u{a}firoona h\q@u{atha} shayon AAajeeb\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxxiii{Ai\q@u{tha} mitn\q@u{a} wakunn\q@u{a} tur\q@u{a}ban \q@u{tha}lika rajAAun baAAeed\q@b{un}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxxiv{Qad AAalimn\q@u{a} m\q@u{a} tanqu\q@u{s}u alar\q@u{d}u minhum waAAindan\q@u{a} kit\q@u{a}bun \q@u{h}afee\q@i{\q@u{th}}\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxxv{Bal ka\q@u{thth}aboo bi\q@b{a}l\q@u{h}aqqi lamm\q@u{a} j\q@u{a}ahum fahum fee amrin mareej\q@b{in}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxxvi{Afalam yan\q@i{\q@u{th}}uroo il\q@u{a} a\q@b{l}ssam\q@u{a}i fawqahum kayfa banayn\q@u{a}h\q@u{a} wazayyann\q@u{a}h\q@u{a} wam\q@u{a} lah\q@u{a} min furooj\q@b{in}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxxvii{Wa\q@b{a}lar\q@u{d}a madadn\q@u{a}h\q@u{a} waalqayn\q@u{a} feeh\q@u{a} raw\q@u{a}siya waanbatn\q@u{a} feeh\q@u{a} min kulli zawjin baheej\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxxviii{Tab\q@u{s}iratan wa\q@u{th}ikr\q@u{a} likulli AAabdin muneeb\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmdcxxxix{Wanazzaln\q@u{a} mina a\q@b{l}ssam\q@u{a}i m\q@u{a}an mub\q@u{a}rakan faanbatn\q@u{a} bihi jann\q@u{a}tin wa\q@u{h}abba al\q@u{h}a\q@u{s}eed\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmdcxl{Wa\q@b{al}nnakhla b\q@u{a}siq\q@u{a}tin lah\q@u{a} \q@u{t}alAAun na\q@u{d}eed\q@b{un}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmdcxli{Rizqan lilAAib\q@u{a}di waa\q@u{h}yayn\q@u{a} bihi baldatan maytan ka\q@u{tha}lika alkhurooj\q@b{u}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmdcxlii{Ka\q@u{thth}abat qablahum qawmu noo\q@u{h}in waa\q@u{s}\q@u{ha}bu a\q@b{l}rrassi wathamood\q@b{u}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmdcxliii{WaAA\q@u{a}dun wafirAAawnu waikhw\q@u{a}nu loo\q@u{t}\q@b{in}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmdcxliv{Waa\q@u{s}\q@u{ha}bu alaykati waqawmu tubbaAAin kullun ka\q@u{thth}aba a\q@b{l}rrusula fa\q@u{h}aqqa waAAeed\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmdcxlv{AfaAAayeen\q@u{a} bi\q@b{a}lkhalqi alawwali bal hum fee labsin min khalqin jadeed\q@b{in}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmdcxlvi{Walaqad khalaqn\q@u{a} alins\q@u{a}na wanaAAlamu m\q@u{a} tuwaswisu bihi nafsuhu wana\q@u{h}nu aqrabu ilayhi min \q@u{h}abli alwareed\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmdcxlvii{I\q@u{th} yatalaqq\q@u{a} almutalaqqiy\q@u{a}ni AAani alyameeni waAAani a\q@b{l}shshim\q@u{a}li qaAAeed\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmdcxlviii{M\q@u{a} yalfi\q@i{\q@u{th}}u min qawlin ill\q@u{a} ladayhi raqeebun AAateed\q@b{un}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmdcxlix{Waj\q@u{a}at sakratu almawti bi\q@b{a}l\q@u{h}aqqi \q@u{tha}lika m\q@u{a} kunta minhu ta\q@u{h}eed\q@b{u}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmdcl{Wanufikha fee a\q@b{l}\q@u{ss}oori \q@u{tha}lika yawmu alwaAAeed\q@b{i}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmdcli{Waj\q@u{a}at kullu nafsin maAAah\q@u{a} s\q@u{a}iqun washaheed\q@b{un}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmdclii{Laqad kunta fee ghaflatin min h\q@u{atha} fakashafn\q@u{a} AAanka ghi\q@u{ta}aka faba\q@u{s}aruka alyawma \q@u{h}adeed\q@b{un}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmdcliii{Waq\q@u{a}la qareenuhu h\q@u{atha} m\q@u{a} ladayya AAateed\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmdcliv{Alqiy\q@u{a} fee jahannama kulla kaff\q@u{a}rin AAaneed\q@b{in}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmdclv{Mann\q@u{a}AAin lilkhayri muAAtadin mureeb\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmdclvi{Alla\q@u{th}ee jaAAala maAAa All\q@u{a}hi il\q@u{a}han \q@u{a}khara faalqiy\q@u{a}hu fee alAAa\q@u{tha}bi a\q@b{l}shshadeed\q@b{i}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmdclvii{Q\q@u{a}la qareenuhu rabban\q@u{a} m\q@u{a} a\q@u{t}ghaytuhu wal\q@u{a}kin k\q@u{a}na fee \q@u{d}al\q@u{a}lin baAAeed\q@b{in}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmdclviii{Q\q@u{a}la l\q@u{a} takhta\q@u{s}imoo ladayya waqad qaddamtu ilaykum bi\q@b{a}lwaAAeed\q@b{i}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmdclix{M\q@u{a} yubaddalu alqawlu ladayya wam\q@u{a} an\q@u{a} bi\q@i{\q@u{th}}all\q@u{a}min lilAAabeed\q@b{i}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmdclx{Yawma naqoolu lijahannama hali imtalati wataqoolu hal min mazeed\q@b{in}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmdclxi{Waozlifati aljannatu lilmuttaqeena ghayra baAAeed\q@b{in}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmdclxii{H\q@u{atha} m\q@u{a} tooAAadoona likulli aww\q@u{a}bin \q@u{h}afee\q@i{\q@u{th}}\q@b{in}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmdclxiii{Man khashiya a\q@b{l}rra\q@u{h}m\q@u{a}na bi\q@b{a}lghaybi waj\q@u{a}a biqalbin muneeb\q@b{in}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmdclxiv{Odkhulooh\q@u{a} bisal\q@u{a}min \q@u{tha}lika yawmu alkhulood\q@b{i}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmdclxv{Lahum m\q@u{a} yash\q@u{a}oona feeh\q@u{a} waladayn\q@u{a} mazeed\q@b{un}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmdclxvi{Wakam ahlakn\q@u{a} qablahum min qarnin hum ashaddu minhum ba\q@u{t}shan fanaqqaboo fee albil\q@u{a}di hal min ma\q@u{h}ee\q@u{s}\q@b{in}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmdclxvii{Inna fee \q@u{tha}lika la\q@u{th}ikr\q@u{a} liman k\q@u{a}na lahu qalbun aw alq\q@u{a} a\q@b{l}ssamAAa wahuwa shaheed\q@b{un}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmdclxviii{Walaqad khalaqn\q@u{a} a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a wam\q@u{a} baynahum\q@u{a} fee sittati ayy\q@u{a}min wam\q@u{a} massan\q@u{a} min lughoob\q@b{in}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmdclxix{Fa\q@b{i}\q@u{s}bir AAal\q@u{a} m\q@u{a} yaqooloona wasabbi\q@u{h} bi\q@u{h}amdi rabbika qabla \q@u{t}ulooAAi a\q@b{l}shshamsi waqabla alghuroob\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmdclxx{Wamina allayli fasabbi\q@u{h}hu waadb\q@u{a}ra a\q@b{l}ssujood\q@b{i}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxi{Wa\q@b{i}stamiAA yawma yun\q@u{a}di almun\q@u{a}di min mak\q@u{a}nin qareeb\q@b{in}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxii{Yawma yasmaAAoona a\q@b{l}\q@u{ss}ay\q@u{h}ata bi\q@b{a}l\q@u{h}aqqi \q@u{tha}lika yawmu alkhurooj\q@b{i}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxiii{Inn\q@u{a} na\q@u{h}nu nu\q@u{h}yee wanumeetu wailayn\q@u{a} alma\q@u{s}eer\q@b{u}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxiv{Yawma tashaqqaqu alar\q@u{d}u AAanhum sir\q@u{a}AAan \q@u{tha}lika \q@u{h}ashrun AAalayn\q@u{a} yaseer\q@b{un}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxv{Na\q@u{h}nu aAAlamu bim\q@u{a} yaqooloona wam\q@u{a} anta AAalayhim bijabb\q@u{a}rin fa\q@u{th}akkir bi\q@b{a}lqur\q@u{a}ni man yakh\q@u{a}fu waAAeed\q@b{i}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxvi{\basmalahlt Wa\q@b{al}\q@u{ththa}riy\q@u{a}ti \q@u{th}arw\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxvii{Fa\q@b{a}l\q@u{ha}mil\q@u{a}ti wiqr\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxviii{Fa\q@b{a}lj\q@u{a}riy\q@u{a}ti yusr\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxix{Fa\q@b{a}lmuqassim\q@u{a}ti amr\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxx{Innam\q@u{a} tooAAadoona la\q@u{sa}diq\q@b{un}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxxi{Wainna a\q@b{l}ddeena law\q@u{a}qiAA\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxxii{Wa\q@b{al}ssam\q@u{a}i \q@u{tha}ti al\q@u{h}ubuk\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxxiii{Innakum lafee qawlin mukhtalif\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxxiv{Yufaku AAanhu man ofik\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxxv{Qutila alkharr\q@u{as}oon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxxvi{Alla\q@u{th}eena hum fee ghamratin s\q@u{a}hoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxxvii{Yasaloona ayy\q@u{a}na yawmu a\q@b{l}ddeen\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxxviii{Yawma hum AAal\q@u{a} a\q@b{l}nn\q@u{a}ri yuftanoon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmdclxxxix{\q@u{Th}ooqoo fitnatakum h\q@u{atha} alla\q@u{th}ee kuntum bihi tastaAAjiloon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmdcxc{Inna almuttaqeena fee jann\q@u{a}tin waAAuyoon\q@b{in}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmdcxci{\q@u{A}khi\q@u{th}eena m\q@u{a} \q@u{a}t\q@u{a}hum rabbuhum innahum k\q@u{a}noo qabla \q@u{tha}lika mu\q@u{h}sineen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmdcxcii{K\q@u{a}noo qaleelan mina allayli m\q@u{a} yahjaAAoon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmdcxciii{Wabi\q@b{a}las\q@u{ha}ri hum yastaghfiroon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmdcxciv{Wafee amw\q@u{a}lihim \q@u{h}aqqun li\q@b{l}ss\q@u{a}ili wa\q@b{a}lma\q@u{h}room\q@b{i}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmdcxcv{Wafee alar\q@u{d}i \q@u{a}y\q@u{a}tun lilmooqineen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmdcxcvi{Wafee anfusikum afal\q@u{a} tub\q@u{s}iroon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmdcxcvii{Wafee a\q@b{l}ssam\q@u{a}i rizqukum wam\q@u{a} tooAAadoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmdcxcviii{Fawarabbi a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i innahu la\q@u{h}aqqun mithla m\q@u{a} annakum tan\q@u{t}iqoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmdcxcix{Hal at\q@u{a}ka \q@u{h}adeethu \q@u{d}ayfi ibr\q@u{a}heema almukrameen\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmdcc{I\q@u{th} dakhaloo AAalayhi faq\q@u{a}loo sal\q@u{a}man q\q@u{a}la sal\q@u{a}mun qawmun munkaroon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmdcci{Far\q@u{a}gha il\q@u{a} ahlihi faj\q@u{a}a biAAijlin sameen\q@b{in}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmdccii{Faqarrabahu ilayhim q\q@u{a}la al\q@u{a} takuloon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmdcciii{Faawjasa minhum kheefatan q\q@u{a}loo l\q@u{a} takhaf wabashsharoohu bighul\q@u{a}min AAaleem\q@b{in}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmdcciv{Faaqbalati imraatuhu fee \q@u{s}arratin fa\q@u{s}akkat wajhah\q@u{a} waq\q@u{a}lat AAajoozun AAaqeem\q@b{un}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmdccv{Q\q@u{a}loo ka\q@u{tha}liki q\q@u{a}la rabbuki innahu huwa al\q@u{h}akeemu alAAaleem\q@b{u}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmdccvi{Q\q@u{a}la fam\q@u{a} kha\q@u{t}bukum ayyuh\q@u{a} almursaloon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmdccvii{Q\q@u{a}loo inn\q@u{a} orsiln\q@u{a} il\q@u{a} qawmin mujrimeen\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmdccviii{Linursila AAalayhim \q@u{h}ij\q@u{a}ratan min \q@u{t}een\q@b{in}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmdccix{Musawwamatan AAinda rabbika lilmusrifeen\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmdccx{Faakhrajn\q@u{a} man k\q@u{a}na feeh\q@u{a} mina almumineen\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmdccxi{Fam\q@u{a} wajadn\q@u{a} feeh\q@u{a} ghayra baytin mina almuslimeen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmdccxii{Watarakn\q@u{a} feeh\q@u{a} \q@u{a}yatan lilla\q@u{th}eena yakh\q@u{a}foona alAAa\q@u{tha}ba alaleem\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmdccxiii{Wafee moos\q@u{a} i\q@u{th} arsa\q@b{l}n\q@u{a}hu il\q@u{a} firAAawna bisul\q@u{ta}nin mubeen\q@b{in}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmdccxiv{Fatawall\q@u{a} biruknihi waq\q@u{a}la s\q@u{ah}irun aw majnoon\q@b{un}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmdccxv{Faakha\q@u{th}n\q@u{a}hu wajunoodahu fanaba\q@u{th}n\q@u{a}hum fee alyammi wahuwa muleem\q@b{un}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmdccxvi{Wafee AA\q@u{a}din i\q@u{th} arsaln\q@u{a} AAalayhimu a\q@b{l}rree\q@u{h}a alAAaqeem\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmdccxvii{M\q@u{a} ta\q@u{th}aru min shayin atat AAalayhi ill\q@u{a} jaAAalathu ka\q@b{al}rrameem\q@b{i}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmdccxviii{Wafee thamooda i\q@u{th} qeela lahum tamattaAAoo \q@u{h}att\q@u{a} \q@u{h}een\q@b{in}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmdccxix{FaAAataw AAan amri rabbihim faakha\q@u{th}athumu a\q@b{l}\q@u{ssa}AAiqatu wahum yan\q@i{\q@u{th}}uroon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmdccxx{Fam\q@u{a} ista\q@u{ta}AAoo min qiy\q@u{a}min wam\q@u{a} k\q@u{a}noo munta\q@u{s}ireen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxi{Waqawma noo\q@u{h}in min qablu innahum k\q@u{a}noo qawman f\q@u{a}siqeen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxii{Wa\q@b{al}ssam\q@u{a}a banayn\q@u{a}h\q@u{a} biaydin wainn\q@u{a} lamoosiAAoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxiii{Wa\q@b{a}lar\q@u{d}a farashn\q@u{a}h\q@u{a} faniAAma alm\q@u{a}hidoon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxiv{Wamin kulli shayin khalaqn\q@u{a} zawjayni laAAallakum ta\q@u{th}akkaroon\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxv{Fafirroo il\q@u{a} All\q@u{a}hi innee lakum minhu na\q@u{th}eerun mubeen\q@b{un}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxvi{Wal\q@u{a} tajAAaloo maAAa All\q@u{a}hi il\q@u{a}han \q@u{a}khara innee lakum minhu na\q@u{th}eerun mubeen\q@b{un}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxvii{Ka\q@u{tha}lika m\q@u{a} at\q@u{a} alla\q@u{th}eena min qablihim min rasoolin ill\q@u{a} q\q@u{a}loo s\q@u{ah}irun aw majnoon\q@b{un}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxviii{Ataw\q@u{as}aw bihi bal hum qawmun \q@u{ta}ghoon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxix{Fatawalla AAanhum fam\q@u{a} anta bimaloom\q@b{in}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxx{Wa\q@u{th}akkir fainna a\q@b{l}\q@u{thth}ikr\q@u{a} tanfaAAu almumineen\q@b{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxxi{Wam\q@u{a} khalaqtu aljinna wa\q@b{a}linsa ill\q@u{a} liyaAAbudoon\q@b{i}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxxii{M\q@u{a} oreedu minhum min rizqin wam\q@u{a} oreedu an yu\q@u{t}AAimoon\q@b{i}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxxiii{Inna All\q@u{a}ha huwa a\q@b{l}rrazz\q@u{a}qu \q@u{th}oo alquwwati almateen\q@b{u}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxxiv{Fainna lilla\q@u{th}eena \q@i{\q@u{th}}alamoo \q@u{th}anooban mithla \q@u{th}anoobi a\q@u{s}\q@u{ha}bihim fal\q@u{a} yastaAAjiloon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxxv{Fawaylun lilla\q@u{th}eena kafaroo min yawmihimu alla\q@u{th}ee yooAAadoon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxxvi{\basmalahlt Wa\q@b{al}\q@u{tt}oor\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxxvii{Wakit\q@u{a}bin mas\q@u{t}oor\q@b{in}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxxviii{Fee raqqin manshoor\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmdccxxxix{Wa\q@b{a}lbayti almaAAmoor\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmdccxl{Wa\q@b{al}ssaqfi almarfooAA\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmdccxli{Wa\q@b{a}lba\q@u{h}ri almasjoor\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmdccxlii{Inna AAa\q@u{tha}ba rabbika law\q@u{a}qiAA\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmdccxliii{M\q@u{a} lahu min d\q@u{a}fiAA\q@b{in}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmdccxliv{Yawma tamooru a\q@b{l}ssam\q@u{a}o mawr\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmdccxlv{Wataseeru aljib\q@u{a}lu sayr\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmdccxlvi{Fawaylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmdccxlvii{Alla\q@u{th}eena hum fee khaw\q@u{d}in yalAAaboon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmdccxlviii{Yawma yudaAAAAoona il\q@u{a} n\q@u{a}ri jahannama daAAAA\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmdccxlix{H\q@u{ath}ihi a\q@b{l}nn\q@u{a}ru allatee kuntum bih\q@u{a} tuka\q@u{thth}iboon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmdccl{Afasi\q@u{h}run h\q@u{atha} am antum l\q@u{a} tub\q@u{s}iroon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmdccli{I\q@u{s}lawh\q@u{a} fa\q@b{i}\q@u{s}biroo aw l\q@u{a} ta\q@u{s}biroo saw\q@u{a}on AAalaykum innam\q@u{a} tujzawna m\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmdcclii{Inna almuttaqeena fee jann\q@u{a}tin wanaAAeem\q@b{in}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmdccliii{F\q@u{a}kiheena bim\q@u{a} \q@u{a}t\q@u{a}hum rabbuhum wawaq\q@u{a}hum rabbuhum AAa\q@u{tha}ba alja\q@u{h}eem\q@b{i}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmdccliv{Kuloo wa\q@b{i}shraboo haneean bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmdcclv{Muttakieena AAal\q@u{a} sururin ma\q@u{s}foofatin wazawwajn\q@u{a}hum bi\q@u{h}oorin AAeen\q@b{in}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmdcclvi{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo wa\q@b{i}ttabaAAathum \q@u{th}urriyyatuhum bieem\q@u{a}nin al\q@u{h}aqn\q@u{a} bihim \q@u{th}urriyyatahum wam\q@u{a} alatn\q@u{a}hum min AAamalihim min shayin kullu imriin bim\q@u{a} kasaba raheen\q@b{un}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmdcclvii{Waamdadn\q@u{a}hum bif\q@u{a}kihatin wala\q@u{h}min mimm\q@u{a} yashtahoon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmdcclviii{Yatan\q@u{a}zaAAoona feeh\q@u{a} kasan l\q@u{a} laghwun feeh\q@u{a} wal\q@u{a} tatheem\q@b{un}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmdcclix{Waya\q@u{t}oofu AAalayhim ghilm\q@u{a}nun lahum kaannahum luluon maknoon\q@b{un}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmdcclx{Waaqbala baAA\q@u{d}uhum AAal\q@u{a} baAA\q@u{d}in yatas\q@u{a}aloon\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxi{Q\q@u{a}loo inn\q@u{a} kunn\q@u{a} qablu fee ahlin\q@u{a} mushfiqeen\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxii{Famanna All\q@u{a}hu AAalayn\q@u{a} wawaq\q@u{a}n\q@u{a} AAa\q@u{tha}ba a\q@b{l}ssamoom\q@b{i}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxiii{Inn\q@u{a} kunn\q@u{a} min qablu nadAAoohu innahu huwa albarru a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxiv{Fa\q@u{th}akkir fam\q@u{a} anta biniAAmati rabbika bik\q@u{a}hin wal\q@u{a} majnoon\q@b{in}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxv{Am yaqooloona sh\q@u{a}AAirun natarabba\q@u{s}u bihi rayba almanoon\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxvi{Qul tarabba\q@u{s}oo fainnee maAAakum mina almutarabbi\q@u{s}een\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxvii{Am tamuruhum a\q@u{h}l\q@u{a}muhum bih\q@u{atha} am hum qawmun \q@u{ta}ghoon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxviii{Am yaqooloona taqawwalahu bal l\q@u{a} yuminoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxix{Falyatoo bi\q@u{h}adeethin mithlihi in k\q@u{a}noo \q@u{sa}diqeena\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxx{Am khuliqoo min ghayri shayin am humu alkh\q@u{a}liqoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxi{Am khalaqoo a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a bal l\q@u{a} yooqinoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxii{Am AAindahum khaz\q@u{a}inu rabbika am humu almu\q@u{s}ay\q@u{t}iroon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxiii{Am lahum sullamun yastamiAAoona feehi falyati mustamiAAuhum bisul\q@u{ta}nin mubeen\q@b{in}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxiv{Am lahu alban\q@u{a}tu walakumu albanoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxv{Am tasaluhum ajran fahum min maghramin muthqaloon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxvi{Am AAindahumu alghaybu fahum yaktuboon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxvii{Am yureedoona kaydan fa\q@b{a}lla\q@u{th}eena kafaroo humu almakeedoon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxviii{Am lahum il\q@u{a}hun ghayru All\q@u{a}hi sub\q@u{ha}na All\q@u{a}hi AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxix{Wain yaraw kisfan mina a\q@b{l}ssam\q@u{a}i s\q@u{a}qi\q@u{t}an yaqooloo sa\q@u{ha}bun markoom\q@b{un}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxx{Fa\q@u{th}arhum \q@u{h}att\q@u{a} yul\q@u{a}qoo yawmahumu alla\q@u{th}ee feehi yu\q@u{s}AAaqoon\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxxi{Yawma l\q@u{a} yughnee AAanhum kayduhum shayan wal\q@u{a} hum yun\q@u{s}aroon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxxii{Wainna lilla\q@u{th}eena \q@i{\q@u{th}}alamoo AAa\q@u{tha}ban doona \q@u{tha}lika wal\q@u{a}kinna aktharahum l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxxiii{Wa\q@b{i}\q@u{s}bir li\q@u{h}ukmi rabbika fainnaka biaAAyunin\q@u{a} wasabbi\q@u{h} bi\q@u{h}amdi rabbika \q@u{h}eena taqoom\q@b{u}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxxiv{Wamina allayli fasabbi\q@u{h}hu waidb\q@u{a}ra a\q@b{l}nnujoom\q@b{i}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxxv{\basmalahlt Wa\q@b{al}nnajmi i\q@u{tha} haw\q@u{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxxvi{M\q@u{a} \q@u{d}alla \q@u{sah}ibukum wam\q@u{a} ghaw\q@u{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxxvii{Wam\q@u{a} yan\q@u{t}iqu AAani alhaw\q@u{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxxviii{In huwa ill\q@u{a} wa\q@u{h}yun yoo\q@u{ha}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmdcclxxxix{AAallamahu shadeedu alquw\q@u{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmdccxc{\q@u{Th}oo mirratin fa\q@b{i}staw\q@u{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmdccxci{Wahuwa bi\q@b{a}lofuqi alaAAl\q@u{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmdccxcii{Thumma dan\q@u{a} fatadall\q@u{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmdccxciii{Fak\q@u{a}na q\q@u{a}ba qawsayni aw adn\q@u{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmdccxciv{Faaw\q@u{ha} il\q@u{a} AAabdihi m\q@u{a} aw\q@u{ha}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmdccxcv{M\q@u{a} ka\q@u{th}aba alfu\q@u{a}du m\q@u{a} ra\q@u{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmdccxcvi{Afatum\q@u{a}roonahu AAal\q@u{a} m\q@u{a} yar\q@u{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmdccxcvii{Walaqad ra\q@u{a}hu nazlatan okhr\q@u{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmdccxcviii{AAinda sidrati almuntah\q@u{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmdccxcix{AAindah\q@u{a} jannatu almaw\q@u{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmdccc{I\q@u{th} yaghsh\q@u{a} a\q@b{l}ssidrata m\q@u{a} yaghsh\q@u{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmdccci{M\q@u{a} z\q@u{a}gha alba\q@u{s}aru wam\q@u{a} \q@u{t}agh\q@u{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmdcccii{Laqad ra\q@u{a} min \q@u{a}y\q@u{a}ti rabbihi alkubr\q@u{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmdccciii{Afaraaytumu all\q@u{a}ta wa\q@b{a}lAAuzz\q@u{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmdccciv{Waman\q@u{a}ta a\q@b{l}thth\q@u{a}lithata alokhr\q@u{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmdcccv{Alakumu a\q@b{l}\q@u{thth}akaru walahu alonth\q@u{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmdcccvi{Tilka i\q@u{th}an qismatun \q@u{d}eez\q@u{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmdcccvii{In hiya ill\q@u{a} asm\q@u{a}on sammaytumooh\q@u{a} antum wa\q@u{a}b\q@u{a}okum m\q@u{a} anzala All\q@u{a}hu bih\q@u{a} min sul\q@u{ta}nin in yattabiAAoona ill\q@u{a} a\q@b{l}\q@i{\q@u{thth}}anna wam\q@u{a} tahw\q@u{a} alanfusu walaqad j\q@u{a}ahum min rabbihimu alhud\q@u{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmdcccviii{Am lilins\q@u{a}ni m\q@u{a} tamann\q@u{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmdcccix{Falill\q@u{a}hi al\q@u{a}khiratu wa\q@b{a}lool\q@u{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmdcccx{Wakam min malakin fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti l\q@u{a} tughnee shaf\q@u{a}AAatuhum shayan ill\q@u{a} min baAAdi an ya\q@u{th}ana All\q@u{a}hu liman yash\q@u{a}o wayar\q@u{da}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxi{Inna alla\q@u{th}eena l\q@u{a} yuminoona bi\q@b{a}l\q@u{a}khirati layusammoona almal\q@u{a}ikata tasmiyata alonth\q@u{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxii{Wam\q@u{a} lahum bihi min AAilmin in yattabiAAoona ill\q@u{a} a\q@b{l}\q@i{\q@u{thth}}anna wainna a\q@b{l}\q@i{\q@u{thth}}anna l\q@u{a} yughnee mina al\q@u{h}aqqi shay\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxiii{FaaAAri\q@u{d} AAan man tawall\q@u{a} AAan \q@u{th}ikrin\q@u{a} walam yurid ill\q@u{a} al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxiv{\q@u{Tha}lika mablaghuhum mina alAAilmi inna rabbaka huwa aAAlamu biman \q@u{d}alla AAan sabeelihi wahuwa aAAlamu bimani ihtad\q@u{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxv{Walill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i liyajziya alla\q@u{th}eena as\q@u{a}oo bim\q@u{a} AAamiloo wayajziya alla\q@u{th}eena a\q@u{h}sanoo bi\q@b{a}l\q@u{h}usn\q@u{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxvi{Alla\q@u{th}eena yajtaniboona kab\q@u{a}ira alithmi wa\q@b{a}lfaw\q@u{ah}isha ill\q@u{a} allamama inna rabbaka w\q@u{a}siAAu almaghfirati huwa aAAlamu bikum i\q@u{th} anshaakum mina alar\q@u{d}i wai\q@u{th} antum ajinnatun fee bu\q@u{t}ooni ommah\q@u{a}tikum fal\q@u{a} tuzakkoo anfusakum huwa aAAlamu bimani ittaq\q@u{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxvii{Afaraayta alla\q@u{th}ee tawall\q@u{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxviii{WaaAA\q@u{ta} qaleelan waakd\q@u{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxix{aAAindahu AAilmu alghaybi fahuwa yar\q@u{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxx{Am lam yunabba bim\q@u{a} fee \q@u{s}u\q@u{h}ufi moos\q@u{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxi{Waibr\q@u{a}heema alla\q@u{th}ee waff\q@u{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxii{All\q@u{a} taziru w\q@u{a}ziratun wizra okhr\q@u{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxiii{Waan laysa lilins\q@u{a}ni ill\q@u{a} m\q@u{a} saAA\q@u{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxiv{Waanna saAAyahu sawfa yur\q@u{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxv{Thumma yujz\q@u{a}hu aljaz\q@u{a}a alawf\q@u{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxvi{Waanna il\q@u{a} rabbika almuntah\q@u{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxvii{Waannahu huwa a\q@u{dh}aka waabk\q@u{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxviii{Waannahu huwa am\q@u{a}ta waa\q@u{h}y\q@u{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxix{Waannahu khalaqa a\q@b{l}zzawjayni a\q@b{l}\q@u{thth}akara wa\q@b{a}lonth\q@u{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxx{Min nu\q@u{t}fatin i\q@u{tha} tumn\q@u{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxxi{Waanna AAalayhi a\q@b{l}nnashata alokhr\q@u{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxxii{Waannahu huwa aghn\q@u{a} waaqn\q@u{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxxiii{Waannahu huwa rabbu a\q@b{l}shshiAAr\q@u{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxxiv{Waannahu ahlaka AA\q@u{a}dan alool\q@u{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxxv{Wathamooda fam\q@u{a} abq\q@u{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxxvi{Waqawma noo\q@u{h}in min qablu innahum k\q@u{a}noo hum a\q@i{\q@u{th}}lama waa\q@u{t}gh\q@u{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxxvii{Wa\q@b{a}lmutafikata ahw\q@u{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxxviii{Faghashsh\q@u{a}h\q@u{a} m\q@u{a} ghashsh\q@u{a}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxxxix{Fabiayyi \q@u{a}l\q@u{a}i rabbika tatam\q@u{a}r\q@u{a}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxl{H\q@u{atha }na\q@u{th}eerun mina a\q@b{l}nnu\q@u{th}uri alool\q@u{a}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxli{Azifati al\q@u{a}zifat\q@b{u}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxlii{Laysa lah\q@u{a} min dooni All\q@u{a}hi k\q@u{a}shifat\q@b{un}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxliii{Afamin h\q@u{atha} al\q@u{h}adeethi taAAjaboon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxliv{Wata\q@u{dh}akoona wal\q@u{a} tabkoon\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxlv{Waantum s\q@u{a}midoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxlvi{Fa\q@b{o}sjudoo lill\q@u{a}hi wa\q@b{o}AAbudoo\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxlvii{\basmalahlt Iqtarabati a\q@b{l}ss\q@u{a}AAatu wa\q@b{i}nshaqqa alqamar\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxlviii{Wain yaraw \q@u{a}yatan yuAAri\q@u{d}oo wayaqooloo si\q@u{h}run mustamirr\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxlix{Waka\q@u{thth}aboo wa\q@b{i}ttabaAAoo ahw\q@u{a}ahum wakullu amrin mustaqirr\q@b{un}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmdcccl{Walaqad j\q@u{a}ahum mina alanb\q@u{a}i m\q@u{a} feehi muzdajar\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmdcccli{\q@u{H}ikmatun b\q@u{a}lighatun fam\q@u{a} tughnee a\q@b{l}nnu\q@u{th}ur\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmdccclii{Fatawalla AAanhum yawma yadAAu a\q@b{l}dd\q@u{a}AAi il\q@u{a} shayin nukur\q@b{in}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmdcccliii{KhushshaAAan ab\q@u{sa}ruhum yakhrujoona mina alajd\q@u{a}thi kaannahum jar\q@u{a}dun muntashir\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmdcccliv{Muh\q@u{t}iAAeena il\q@u{a} a\q@b{l}dd\q@u{a}AAi yaqoolu alk\q@u{a}firoona h\q@u{atha} yawmun AAasir\q@b{un}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmdccclv{Ka\q@u{thth}abat qablahum qawmu noo\q@u{h}in faka\q@u{thth}aboo AAabdan\q@u{a} waq\q@u{a}loo majnoonun wa\q@b{i}zdujir\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmdccclvi{FadaAA\q@u{a} rabbahu annee maghloobun fa\q@b{i}nta\q@u{s}ir\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmdccclvii{Fafata\q@u{h}n\q@u{a} abw\q@u{a}ba a\q@b{l}ssam\q@u{a}i bim\q@u{a}in munhamir\q@b{in}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmdccclviii{Wafajjarn\q@u{a} alar\q@u{d}a AAuyoonan fa\q@b{i}ltaq\q@u{a} alm\q@u{a}o AAal\q@u{a} amrin qad qudir\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmdccclix{Wa\q@u{h}amaln\q@u{a}hu AAal\q@u{a} \q@u{tha}ti alw\q@u{ah}in wadusur\q@b{in}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmdccclx{Tajree biaAAyunin\q@u{a} jaz\q@u{a}an liman k\q@u{a}na kufir\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxi{Walaqad tarakn\q@u{a}h\q@u{a} \q@u{a}yatan fahal min muddakir\q@b{in}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxii{Fakayfa k\q@u{a}na AAa\q@u{tha}bee wanu\q@u{th}ur\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxiii{Walaqad yassarn\q@u{a} alqur\q@u{a}na li\q@b{l}\q@u{thth}ikri fahal min muddakir\q@b{in}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxiv{Ka\q@u{thth}abat AA\q@u{a}dun fakayfa k\q@u{a}na AAa\q@u{tha}bee wanu\q@u{th}ur\q@b{i}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxv{Inn\q@u{a} arsaln\q@u{a} AAalayhim ree\q@u{h}an \q@u{s}ar\q@u{s}aran fee yawmi na\q@u{h}sin mustamirr\q@b{in}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxvi{TanziAAu a\q@b{l}nn\q@u{a}sa kaannahum aAAj\q@u{a}zu nakhlin munqaAAir\q@b{in}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxvii{Fakayfa k\q@u{a}na AAa\q@u{tha}bee wanu\q@u{th}ur\q@b{i}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxviii{Walaqad yassarn\q@u{a} alqur\q@u{a}na li\q@b{l}\q@u{thth}ikri fahal min muddakir\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxix{Ka\q@u{thth}abat thamoodu bi\q@b{al}nnu\q@u{th}ur\q@b{i}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxx{Faq\q@u{a}loo abasharan minn\q@u{a} w\q@u{ah}idan nattabiAAuhu inn\q@u{a} i\q@u{th}an lafee \q@u{d}al\q@u{a}lin wasuAAur\q@b{in}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxi{Aolqiya a\q@b{l}\q@u{thth}ikru AAalayhi min baynin\q@u{a} bal huwa ka\q@u{ththa}bun ashir\q@b{un}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxii{SayaAAlamoona ghadan mani alka\q@u{ththa}bu alashir\q@b{u}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxiii{Inn\q@u{a} mursiloo a\q@b{l}nn\q@u{a}qati fitnatan lahum fa\q@b{i}rtaqibhum wa\q@b{i}\q@u{st}abir\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxiv{Wanabbihum anna alm\q@u{a}a qismatun baynahum kullu shirbin mu\q@u{h}ta\q@u{d}ar\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxv{Fan\q@u{a}daw \q@u{sah}ibahum fataAA\q@u{ata} faAAaqar\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxvi{Fakayfa k\q@u{a}na AAa\q@u{tha}bee wanu\q@u{th}ur\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxvii{Inn\q@u{a} arsaln\q@u{a} AAalayhim \q@u{s}ay\q@u{h}atan w\q@u{ah}idatan fak\q@u{a}noo kahasheemi almu\q@u{h}ta\q@i{\q@u{th}}ir\q@b{i}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxviii{Walaqad yassarn\q@u{a} alqur\q@u{a}na li\q@b{l}\q@u{thth}ikri fahal min muddakir\q@b{in}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxix{Ka\q@u{thth}abat qawmu loo\q@u{t}in bi\q@b{al}nnu\q@u{th}ur\q@b{i}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxx{Inn\q@u{a} arsaln\q@u{a} AAalayhim \q@u{has}iban ill\q@u{a} \q@u{a}la loo\q@u{t}in najjayn\q@u{a}hum bisa\q@u{h}ar\q@b{in}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxxi{NiAAmatan min AAindin\q@u{a} ka\q@u{tha}lika najzee man shakar\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxxii{Walaqad an\q@u{th}arahum ba\q@u{t}shatan\q@u{a} fatam\q@u{a}raw bi\q@b{al}nnu\q@u{th}ur\q@b{i}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxxiii{Walaqad r\q@u{a}wadoohu AAan \q@u{d}ayfihi fa\q@u{t}amasn\q@u{a} aAAyunahum fa\q@u{th}ooqoo AAa\q@u{tha}bee wanu\q@u{th}ur\q@b{i}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxxiv{Walaqad \q@u{s}abba\q@u{h}ahum bukratan AAa\q@u{tha}bun mustaqirr\q@b{un}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxxv{Fa\q@u{th}ooqoo AAa\q@u{tha}bee wanu\q@u{th}ur\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxxvi{Walaqad yassarn\q@u{a} alqur\q@u{a}na li\q@b{l}\q@u{thth}ikri fahal min muddakir\q@b{in}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxxvii{Walaqad j\q@u{a}a \q@u{a}la firAAawna a\q@b{l}nnu\q@u{th}ur\q@b{u}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxxviii{Ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} kullih\q@u{a} faakha\q@u{th}n\q@u{a}hum akh\q@u{th}a AAazeezin muqtadir\q@b{in}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmdccclxxxix{Akuff\q@u{a}rukum khayrun min ol\q@u{a}ikum am lakum bar\q@u{a}atun fee a\q@b{l}zzubur\q@b{i}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxc{Am yaqooloona na\q@u{h}nu jameeAAun munta\q@u{s}ir\q@b{un}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxci{Sayuhzamu aljamAAu wayuwalloona a\q@b{l}ddubur\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxcii{Bali a\q@b{l}ss\q@u{a}AAatu mawAAiduhum wa\q@b{al}ss\q@u{a}AAatu adh\q@u{a} waamar\q@b{ru}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxciii{Inna almujrimeena fee \q@u{d}al\q@u{a}lin wasuAAur\q@b{in}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxciv{Yawma yus\q@u{h}aboona fee a\q@b{l}nn\q@u{a}ri AAal\q@u{a} wujoohihim \q@u{th}ooqoo massa saqar\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxcv{Inn\q@u{a} kulla shayin khalaqn\q@u{a}hu biqadar\q@b{in}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxcvi{Wam\q@u{a} amrun\q@u{a} ill\q@u{a} w\q@u{ah}idatun kalam\q@u{h}in bi\q@b{a}lba\q@u{s}ar\q@b{i}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxcvii{Walaqad ahlakn\q@u{a} ashy\q@u{a}AAakum fahal min muddakir\q@b{in}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxcviii{Wakullu shayin faAAaloohu fee a\q@b{l}zzubur\q@b{i}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmdcccxcix{Wakullu \q@u{s}agheerin wakabeerin musta\q@u{t}ar\q@b{un}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmcm{Inna almuttaqeena fee jann\q@u{a}tin wanahar\q@b{in}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmcmi{Fee maqAAadi \q@u{s}idqin AAinda maleekin muqtadir\q@b{in}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmcmii{\basmalahlt A\q@b{l}rra\q@u{h}m\q@u{a}n\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmcmiii{AAallama alqur\q@u{a}n\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmcmiv{Khalaqa alins\q@u{a}n\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmcmv{AAallamahu albay\q@u{a}n\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmcmvi{A\q@b{l}shshamsu wa\q@b{a}lqamaru bi\q@u{h}usb\q@u{a}n\q@b{in}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmcmvii{Wa\q@b{al}nnajmu wa\q@b{al}shshajaru yasjud\q@u{a}n\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmcmviii{Wa\q@b{al}ssam\q@u{a}a rafaAAah\q@u{a} wawa\q@u{d}aAAa almeez\q@u{a}n\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmcmix{All\q@u{a} ta\q@u{t}ghaw fee almeez\q@u{a}n\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmcmx{Waaqeemoo alwazna bi\q@b{a}lqis\q@u{t}i wal\q@u{a} tukhsiroo almeez\q@u{a}n\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmcmxi{Wa\q@b{a}lar\q@u{d}a wa\q@u{d}aAAah\q@u{a} lilan\q@u{a}m\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmcmxii{Feeh\q@u{a} f\q@u{a}kihatun wa\q@b{al}nnakhlu \q@u{tha}tu alakm\q@u{a}m\q@b{i}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmcmxiii{Wa\q@b{a}l\q@u{h}abbu \q@u{th}oo alAAa\q@u{s}fi wa\q@b{al}rray\q@u{ha}n\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmcmxiv{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmcmxv{Khalaqa alins\q@u{a}na min \q@u{s}al\q@u{sa}lin ka\q@b{a}lfakhkh\q@u{a}r\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmcmxvi{Wakhalaqa alj\q@u{a}nna min m\q@u{a}rijin min n\q@u{a}r\q@b{in}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmcmxvii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmcmxviii{Rabbu almashriqayni warabbu almaghribayn\q@b{i}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmcmxix{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmcmxx{Maraja alba\q@u{h}rayni yaltaqiy\q@u{a}n\q@b{i}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxi{Baynahum\q@u{a} barzakhun l\q@u{a} yabghiy\q@u{a}n\q@b{i}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxiii{Yakhruju minhum\q@u{a} alluluo wa\q@b{a}lmarj\q@u{a}n\q@b{u}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxiv{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}ni\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxv{Walahu aljaw\q@u{a}ri almunsha\q@u{a}tu fee alba\q@u{h}ri ka\q@b{a}laAAl\q@u{a}m\q@b{i}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxvi{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxvii{Kullu man AAalayh\q@u{a} f\q@u{a}n\q@b{in}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxviii{Wayabq\q@u{a} wajhu rabbika \q@u{th}oo aljal\q@u{a}li wa\q@b{a}likr\q@u{a}m\q@b{i}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxix{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxx{Yasaluhu man fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i kulla yawmin huwa fee shan\q@b{in}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxxi{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxxii{Sanafrughu lakum ayyuh\q@u{a} a\q@b{l}ththaqal\q@u{a}n\q@b{i}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxxiii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxxiv{Y\q@u{a} maAAshara aljinni wa\q@b{a}linsi ini ista\q@u{t}aAAtum an tanfu\q@u{th}oo min aq\q@u{ta}ri a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i fa\q@b{o}nfu\q@u{th}oo l\q@u{a} tanfu\q@u{th}oona ill\q@u{a} bisul\q@u{ta}n\q@b{in}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxxv{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxxvi{Yursalu AAalaykum\q@u{a} shuw\q@u{a}\q@i{\q@u{th}}un min n\q@u{a}rin wanu\q@u{ha}sun fal\q@u{a} tanta\q@u{s}ir\q@u{a}n\q@b{i}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxxvii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxxviii{Fai\q@u{tha} inshaqqati a\q@b{l}ssam\q@u{a}o fak\q@u{a}nat wardatan ka\q@b{al}ddih\q@u{a}n\q@b{i}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmcmxxxix{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmcmxl{Fayawmai\q@u{th}in l\q@u{a} yusalu AAan \q@u{th}anbihi insun wal\q@u{a} j\q@u{a}n\q@b{nun}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmcmxli{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmcmxlii{YuAArafu almujrimoona biseem\q@u{a}hum fayukha\q@u{th}u bi\q@b{al}nnaw\q@u{as}ee wa\q@b{a}laqd\q@u{a}m\q@b{i}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmcmxliii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmcmxliv{H\q@u{ath}ihi jahannamu allatee yuka\q@u{thth}ibu bih\q@u{a} almujrimoon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmcmxlv{Ya\q@u{t}oofoona baynah\q@u{a} wabayna \q@u{h}ameemin \q@u{a}n\q@b{in}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmcmxlvi{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmcmxlvii{Waliman kh\q@u{a}fa maq\q@u{a}ma rabbihi jannat\q@u{a}n\q@b{i}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmcmxlviii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmcmxlix{\q@u{Th}aw\q@u{a}t\q@u{a} afn\q@u{a}n\q@b{in}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmcml{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmcmli{Feehim\q@u{a} AAayn\q@u{a}ni tajriy\q@u{a}n\q@b{i}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmcmlii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmcmliii{Feehim\q@u{a} min kulli f\q@u{a}kihatin zawj\q@u{a}n\q@b{i}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmcmliv{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmcmlv{Muttakieena AAal\q@u{a} furushin ba\q@u{ta}inuh\q@u{a} min istabraqin wajan\q@u{a} aljannatayni d\q@u{a}n\q@b{in}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmcmlvi{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmcmlvii{Feehinna q\q@u{as}ir\q@u{a}tu a\q@b{l}\q@u{tt}arfi lam ya\q@u{t}mithhunna insun qablahum wal\q@u{a} j\q@u{a}n\q@b{nun}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmcmlviii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmmcmlix{Kaannahunna aly\q@u{a}qootu wa\q@b{a}lmarj\q@u{a}n\q@b{u}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmmcmlx{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxi{Hal jaz\q@u{a}o ali\q@u{h}s\q@u{a}ni ill\q@u{a} ali\q@u{h}s\q@u{a}n\q@b{u}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxiii{Wamin doonihim\q@u{a} jannat\q@u{a}n\q@b{i}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxiv{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxv{Mudh\q@u{a}mmat\q@u{a}n\q@b{i}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxvi{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxvii{Feehim\q@u{a} AAayn\q@u{a}ni na\q@u{dda}khat\q@u{a}n\q@b{i}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxviii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxix{Feehim\q@u{a} f\q@u{a}kihatun wanakhlun warumm\q@u{a}n\q@b{un}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxx{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxi{Feehinna khayr\q@u{a}tun \q@u{h}is\q@u{a}n\q@b{un}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxiii{\q@u{H}oorun maq\q@u{s}oor\q@u{a}tun fee alkhiy\q@u{a}m\q@b{i}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxiv{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxv{Lam ya\q@u{t}mithhunna insun qablahum wal\q@u{a} j\q@u{a}n\q@b{nun}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxvi{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxvii{Muttakieena AAal\q@u{a} rafrafin khu\q@u{d}rin waAAabqariyyin \q@u{h}is\q@u{a}n\q@b{in}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxviii{Fabiayyi \q@u{a}l\q@u{a}i rabbikum\q@u{a} tuka\q@u{thth}ib\q@u{a}n\q@b{i}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxix{Tab\q@u{a}raka ismu rabbika \q@u{th}ee aljal\q@u{a}li wa\q@b{a}likr\q@u{a}m\q@b{i}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxx{\basmalahlt I\q@u{tha} waqaAAati alw\q@u{a}qiAAat\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxxi{Laysa liwaqAAatih\q@u{a} k\q@u{ath}iba\q@b{tun}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxxii{Kh\q@u{a}fi\q@u{d}atun r\q@u{a}fiAAa\q@b{tun}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxxiii{I\q@u{tha} rujjati alar\q@u{d}u rajj\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxxiv{Wabussati aljib\q@u{a}lu bass\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxxv{Fak\q@u{a}nat hab\q@u{a}an munbathth\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxxvi{Wakuntum azw\q@u{a}jan thal\q@u{a}tha\q@b{tan}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxxvii{Faa\q@u{s}\q@u{ha}bu almaymanati m\q@u{a} a\q@u{s}\q@u{ha}bu almaymanat\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxxviii{Waa\q@u{s}\q@u{ha}bu almashamati m\q@u{a} a\q@u{s}\q@u{ha}bu almashamat\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmcmlxxxix{Wa\q@b{al}ss\q@u{a}biqoona a\q@b{l}ss\q@u{a}biqoon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmcmxc{Ol\q@u{a}ika almuqarraboon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmcmxci{Fee jann\q@u{a}ti a\q@b{l}nnaAAeem\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmcmxcii{Thullatun mina alawwaleen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmcmxciii{Waqaleelun mina al\q@u{a}khireena\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmcmxciv{AAal\q@u{a} sururin maw\q@u{d}oona\q@b{tin}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmcmxcv{Muttakieena AAalayh\q@u{a} mutaq\q@u{a}bileen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmcmxcvi{Ya\q@u{t}oofu AAalayhim wild\q@u{a}nun mukhalladoon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmcmxcvii{Biakw\q@u{a}bin waab\q@u{a}reeqa wakasin min maAAeen\q@b{in}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmcmxcviii{L\q@u{a} yu\q@u{s}addaAAoona AAanh\q@u{a} wal\q@u{a} yunzifoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmcmxcix{Waf\q@u{a}kihatin mimm\q@u{a} yatakhayyaroon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmm{Wala\q@u{h}mi \q@u{t}ayrin mimm\q@u{a} yashtahoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmi{Wa\q@u{h}oorun AAeen\q@b{un}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmii{Kaamth\q@u{a}li allului almaknoon\q@b{i}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmiii{Jaz\q@u{a}an bim\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmiv{L\q@u{a} yasmaAAoona feeh\q@u{a} laghwan wal\q@u{a} tatheem\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmv{Ill\q@u{a} qeelan sal\q@u{a}man sal\q@u{a}m\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmvi{Waa\q@u{s}\q@u{ha}bu alyameeni m\q@u{a} a\q@u{s}\q@u{ha}bu alyameen\q@b{i}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmvii{Fee sidrin makh\q@u{d}ood\q@b{in}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmviii{Wa\q@u{t}al\q@u{h}in man\q@u{d}ood\q@b{in}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmix{Wa\q@i{\q@u{th}}illin mamdood\q@b{in}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmx{Wam\q@u{a}in maskoob\q@b{in}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmxi{Waf\q@u{a}kihatin katheera\q@b{tin}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmxii{L\q@u{a} maq\q@u{t}ooAAatin wal\q@u{a} mamnooAAa\q@b{tin}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmxiii{Wafurushin marfooAAa\q@b{tin}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmxiv{Inn\q@u{a} anshan\q@u{a}hunna insh\q@u{aa}\q@b{n}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmxv{FajaAAaln\q@u{a}hunna abk\q@u{a}r\q@u{a}\q@b{n}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmxvi{AAuruban atr\q@u{a}b\q@u{a}\q@b{n}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmxvii{Lia\q@u{s}\q@u{ha}bi alyameen\q@b{i}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmxviii{Thullatun mina alawwaleen\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmxix{Wathullatun mina al\q@u{a}khireen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmxx{Waa\q@u{s}\q@u{ha}bu a\q@b{l}shshim\q@u{a}li m\q@u{a} a\q@u{s}\q@u{ha}bu a\q@b{l}shshim\q@u{a}l\q@b{i}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmmxxi{Fee samoomin wa\q@u{h}ameem\q@b{in}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmmxxii{Wa\q@i{\q@u{th}}illin min ya\q@u{h}moom\q@b{in}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmmxxiii{L\q@u{a} b\q@u{a}ridin wal\q@u{a} kareem\q@b{in}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmmxxiv{Innahum k\q@u{a}noo qabla \q@u{tha}lika mutrafeen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmmxxv{Wak\q@u{a}noo yu\q@u{s}irroona AAal\q@u{a} al\q@u{h}inthi alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmmxxvi{Wak\q@u{a}noo yaqooloona ai\q@u{tha} mitn\q@u{a} wakunn\q@u{a} tur\q@u{a}ban waAAi\q@i{\q@u{th}}\q@u{a}man ainn\q@u{a} lamabAAoothoon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmmxxvii{Awa \q@u{a}b\q@u{a}on\q@u{a} alawwaloon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmmxxviii{Qul inna alawwaleena wa\q@b{a}l\q@u{a}khireen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmmxxix{LamajmooAAoona il\q@u{a} meeq\q@u{a}ti yawmin maAAloom\q@b{in}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmmxxx{Thumma innakum ayyuh\q@u{a} a\q@b{l}\q@u{dda}lloona almuka\q@u{thth}iboon\q@b{a}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmmxxxi{La\q@u{a}kiloona min shajarin min zaqqoom\q@b{in}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmmxxxii{Fam\q@u{a}lioona minh\q@u{a} albu\q@u{t}oon\q@b{a}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmmxxxiii{Fash\q@u{a}riboona AAalayhi mina al\q@u{h}ameem\q@b{i}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmmxxxiv{Fash\q@u{a}riboona shurba alheem\q@b{i}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmmxxxv{H\q@u{atha} nuzuluhum yawma a\q@b{l}ddeen\q@b{i}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmmxxxvi{Na\q@u{h}nu khalaqn\q@u{a}kum falawl\q@u{a} tu\q@u{s}addiqoon\q@b{a}\qt@no{(57)}}
\qt@newcmd\qurantrans@lt@mmmmmxxxvii{Afaraaytum m\q@u{a} tumnoon\q@b{a}\qt@no{(58)}}
\qt@newcmd\qurantrans@lt@mmmmmxxxviii{Aantum takhluqoonahu am na\q@u{h}nu alkh\q@u{a}liqoon\q@b{a}\qt@no{(59)}}
\qt@newcmd\qurantrans@lt@mmmmmxxxix{Na\q@u{h}nu qaddarn\q@u{a} baynakumu almawta wam\q@u{a} na\q@u{h}nu bimasbooqeen\q@b{a}\qt@no{(60)}}
\qt@newcmd\qurantrans@lt@mmmmmxl{AAal\q@u{a} an nubaddila amth\q@u{a}lakum wanunshiakum fee m\q@u{a} l\q@u{a} taAAlamoon\q@b{a}\qt@no{(61)}}
\qt@newcmd\qurantrans@lt@mmmmmxli{Walaqad AAalimtumu a\q@b{l}nnashata alool\q@u{a} falawl\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(62)}}
\qt@newcmd\qurantrans@lt@mmmmmxlii{Afaraaytum m\q@u{a} ta\q@u{h}ruthoon\q@b{a}\qt@no{(63)}}
\qt@newcmd\qurantrans@lt@mmmmmxliii{Aantum tazraAAoonahu am na\q@u{h}nu a\q@b{l}zz\q@u{a}riAAoon\q@b{a}\qt@no{(64)}}
\qt@newcmd\qurantrans@lt@mmmmmxliv{Law nash\q@u{a}o lajaAAaln\q@u{a}hu \q@u{h}u\q@u{ta}man fa\q@i{\q@u{th}}altum tafakkahoon\q@b{a}\qt@no{(65)}}
\qt@newcmd\qurantrans@lt@mmmmmxlv{Inn\q@u{a} lamughramoon\q@b{a}\qt@no{(66)}}
\qt@newcmd\qurantrans@lt@mmmmmxlvi{Bal na\q@u{h}nu ma\q@u{h}roomoon\q@b{a}\qt@no{(67)}}
\qt@newcmd\qurantrans@lt@mmmmmxlvii{Afaraaytumu alm\q@u{a}a alla\q@u{th}ee tashraboon\q@b{a}\qt@no{(68)}}
\qt@newcmd\qurantrans@lt@mmmmmxlviii{Aantum anzaltumoohu mina almuzni am na\q@u{h}nu almunziloon\q@b{a}\qt@no{(69)}}
\qt@newcmd\qurantrans@lt@mmmmmxlix{Law nash\q@u{a}o jaAAaln\q@u{a}hu oj\q@u{a}jan falawl\q@u{a} tashkuroon\q@b{a}\qt@no{(70)}}
\qt@newcmd\qurantrans@lt@mmmmml{Afaraaytumu a\q@b{l}nn\q@u{a}ra allatee tooroon\q@b{a}\qt@no{(71)}}
\qt@newcmd\qurantrans@lt@mmmmmli{Aantum anshatum shajaratah\q@u{a} am na\q@u{h}nu almunshioon\q@b{a}\qt@no{(72)}}
\qt@newcmd\qurantrans@lt@mmmmmlii{Na\q@u{h}nu jaAAaln\q@u{a}h\q@u{a} ta\q@u{th}kiratan wamat\q@u{a}AAan lilmuqween\q@b{a}\qt@no{(73)}}
\qt@newcmd\qurantrans@lt@mmmmmliii{Fasabbi\q@u{h} bi\q@b{i}smi rabbika alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(74)}}
\qt@newcmd\qurantrans@lt@mmmmmliv{Fal\q@u{a} oqsimu bimaw\q@u{a}qiAAi a\q@b{l}nnujoom\q@b{i}\qt@no{(75)}}
\qt@newcmd\qurantrans@lt@mmmmmlv{Wainnahu laqasamun law taAAlamoona AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(76)}}
\qt@newcmd\qurantrans@lt@mmmmmlvi{Innahu laqur\q@u{a}nun kareem\q@b{un}\qt@no{(77)}}
\qt@newcmd\qurantrans@lt@mmmmmlvii{Fee kit\q@u{a}bin maknoon\q@b{in}\qt@no{(78)}}
\qt@newcmd\qurantrans@lt@mmmmmlviii{L\q@u{a} yamassuhu ill\q@u{a} almu\q@u{t}ahharoon\q@b{a}\qt@no{(79)}}
\qt@newcmd\qurantrans@lt@mmmmmlix{Tanzeelun min rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(80)}}
\qt@newcmd\qurantrans@lt@mmmmmlx{Afabih\q@u{atha} al\q@u{h}adeethi antum mudhinoon\q@b{a}\qt@no{(81)}}
\qt@newcmd\qurantrans@lt@mmmmmlxi{WatajAAaloona rizqakum annakum tuka\q@u{thth}iboon\q@b{a}\qt@no{(82)}}
\qt@newcmd\qurantrans@lt@mmmmmlxii{Falawl\q@u{a} i\q@u{tha} balaghati al\q@u{h}ulqoom\q@b{a}\qt@no{(83)}}
\qt@newcmd\qurantrans@lt@mmmmmlxiii{Waantum \q@u{h}eenai\q@u{th}in tan\q@i{\q@u{th}}uroona\qt@no{(84)}}
\qt@newcmd\qurantrans@lt@mmmmmlxiv{Wana\q@u{h}nu aqrabu ilayhi minkum wal\q@u{a}kin l\q@u{a} tub\q@u{s}iroon\q@b{a}\qt@no{(85)}}
\qt@newcmd\qurantrans@lt@mmmmmlxv{Falawl\q@u{a} in kuntum ghayra madeeneen\q@b{a}\qt@no{(86)}}
\qt@newcmd\qurantrans@lt@mmmmmlxvi{TarjiAAoonah\q@u{a} in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(87)}}
\qt@newcmd\qurantrans@lt@mmmmmlxvii{Faamm\q@u{a} in k\q@u{a}na mina almuqarrabeen\q@b{a}\qt@no{(88)}}
\qt@newcmd\qurantrans@lt@mmmmmlxviii{Faraw\q@u{h}un waray\q@u{ha}nun wajannatu naAAeem\q@b{in}\qt@no{(89)}}
\qt@newcmd\qurantrans@lt@mmmmmlxix{Waamm\q@u{a} in k\q@u{a}na min a\q@u{s}\q@u{ha}bi alyameen\q@b{i}\qt@no{(90)}}
\qt@newcmd\qurantrans@lt@mmmmmlxx{Fasal\q@u{a}mun laka min a\q@u{s}\q@u{ha}bi alyameen\q@b{i}\qt@no{(91)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxi{Waamm\q@u{a} in k\q@u{a}na mina almuka\q@u{thth}ibeena a\q@b{l}\q@u{dda}lleen\q@b{a}\qt@no{(92)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxii{Fanuzulun min \q@u{h}ameem\q@b{in}\qt@no{(93)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxiii{Wata\q@u{s}liyatu ja\q@u{h}eem\q@b{in}\qt@no{(94)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxiv{Inna h\q@u{atha} lahuwa \q@u{h}aqqu alyaqeen\q@b{i}\qt@no{(95)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxv{Fasabbi\q@u{h} bi\q@b{i}smi rabbika alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(96)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxvi{\basmalahlt Sabba\q@u{h}a lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxvii{Lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i yu\q@u{h}yee wayumeetu wahuwa AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxviii{Huwa alawwalu wa\q@b{a}l\q@u{a}khiru wa\q@b{al}\q@i{\q@u{thth}}\q@u{a}hiru wa\q@b{a}lb\q@u{at}inu wahuwa bikulli shayin AAaleem\q@b{un}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxix{Huwa alla\q@u{th}ee khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a fee sittati ayy\q@u{a}min thumma istaw\q@u{a} AAal\q@u{a} alAAarshi yaAAlamu m\q@u{a} yaliju fee alar\q@u{d}i wam\q@u{a} yakhruju minh\q@u{a} wam\q@u{a} yanzilu mina a\q@b{l}ssam\q@u{a}i wam\q@u{a} yaAAruju feeh\q@u{a} wahuwa maAAakum ayna m\q@u{a} kuntum wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxx{Lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wail\q@u{a} All\q@u{a}hi turjaAAu alomoor\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxxi{Yooliju allayla fee a\q@b{l}nnah\q@u{a}ri wayooliju a\q@b{l}nnah\q@u{a}ra fee allayi wahuwa AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxxii{\q@u{A}minoo bi\q@b{A}ll\q@u{a}hi warasoolihi waanfiqoo mimm\q@u{a} jaAAalakum mustakhlafeena feehi fa\q@b{a}lla\q@u{th}eena \q@u{a}manoo minkum waanfaqoo lahum ajrun kabeer\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxxiii{Wam\q@u{a} lakum l\q@u{a} tuminoona bi\q@b{A}ll\q@u{a}hi wa\q@b{al}rrasoolu yadAAookum lituminoo birabbikum waqad akha\q@u{th}a meeth\q@u{a}qakum in kuntum mumineen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxxiv{Huwa alla\q@u{th}ee yunazzilu AAal\q@u{a} AAabdihi \q@u{a}y\q@u{a}tin bayyin\q@u{a}tin liyukhrijakum mina a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti il\q@u{a} a\q@b{l}nnoori wainna All\q@u{a}ha bikum laraoofun ra\q@u{h}eem\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxxv{Wam\q@u{a} lakum all\q@u{a} tunfiqoo fee sabeeli All\q@u{a}hi walill\q@u{a}hi meer\q@u{a}thu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i l\q@u{a} yastawee minkum man anfaqa min qabli alfat\q@u{h}i waq\q@u{a}tala ol\q@u{a}ika aAA\q@i{\q@u{th}}amu darajatan mina alla\q@u{th}eena anfaqoo min baAAdu waq\q@u{a}taloo wakullan waAAada All\q@u{a}hu al\q@u{h}usn\q@u{a} wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona khabeer\q@b{un}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxxvi{Man \q@u{tha} alla\q@u{th}ee yuqri\q@u{d}u All\q@u{a}ha qar\q@u{d}an \q@u{h}asanan fayu\q@u{da}AAifahu lahu walahu ajrun kareem\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxxvii{Yawma tar\q@u{a} almumineena wa\q@b{a}lmumin\q@u{a}ti yasAA\q@u{a} nooruhum bayna aydeehim wabiaym\q@u{a}nihim bushr\q@u{a}kumu alyawma jann\q@u{a}tun tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} \q@u{tha}lika huwa alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxxviii{Yawma yaqoolu almun\q@u{a}fiqoona wa\q@b{a}lmun\q@u{a}fiq\q@u{a}tu lilla\q@u{th}eena \q@u{a}manoo on\q@i{\q@u{th}}uroon\q@u{a} naqtabis min noorikum qeela irjiAAoo war\q@u{a}akum fa\q@b{i}ltamisoo nooran fa\q@u{d}uriba baynahum bisoorin lahu b\q@u{a}bun b\q@u{at}inuhu feehi a\q@b{l}rra\q@u{h}matu wa\q@i{\q@u{th}}\q@u{a}hiruhu min qibalihi alAAa\q@u{tha}b\q@b{u}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmlxxxix{Yun\q@u{a}doonahum alam nakun maAAakum q\q@u{a}loo bal\q@u{a} wal\q@u{a}kinnakum fatantum anfusakum watarabba\q@u{s}tum wa\q@b{i}rtabtum wagharratkumu alam\q@u{a}niyyu \q@u{h}att\q@u{a} j\q@u{a}a amru All\q@u{a}hi wagharrakum bi\q@b{A}ll\q@u{a}hi algharoor\q@b{u}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmxc{Fa\q@b{a}lyawma l\q@u{a} yukha\q@u{th}u minkum fidyatun wal\q@u{a} mina alla\q@u{th}eena kafaroo maw\q@u{a}kumu a\q@b{l}nn\q@u{a}ru hiya mawl\q@u{a}kum wabisa alma\q@u{s}eer\q@b{u}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmxci{Alam yani lilla\q@u{th}eena \q@u{a}manoo an takhshaAAa quloobuhum li\q@u{th}ikri All\q@u{a}hi wam\q@u{a} nazala mina al\q@u{h}aqqi wal\q@u{a} yakoonoo ka\q@b{a}lla\q@u{th}eena ootoo alkit\q@u{a}ba min qablu fa\q@u{ta}la AAalayhimu alamadu faqasat quloobuhum wakatheerun minhum f\q@u{a}siqoon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmxcii{IAAlamoo anna All\q@u{a}ha yu\q@u{h}yee alar\q@u{d}a baAAda mawtih\q@u{a} qad bayyann\q@u{a} lakumu al\q@u{a}y\q@u{a}ti laAAallakum taAAqiloon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmxciii{Inna almu\q@u{ss}addiqeena wa\q@b{a}lmu\q@u{ss}addiq\q@u{a}ti waaqra\q@u{d}oo All\q@u{a}ha qar\q@u{d}an \q@u{h}asanan yu\q@u{da}AAafu lahum walahum ajrun kareem\q@b{un}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmxciv{Wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo bi\q@b{A}ll\q@u{a}hi warusulihi ol\q@u{a}ika humu a\q@b{l}\q@u{ss}iddeeqoona wa\q@b{al}shshuhad\q@u{a}o AAinda rabbihim lahum ajruhum wanooruhum wa\q@b{a}lla\q@u{th}eena kafaroo waka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} ol\q@u{a}ika a\q@u{s}\q@u{ha}bu alja\q@u{h}eem\q@b{i}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmxcv{IAAlamoo annam\q@u{a} al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} laAAibun walahwun wazeenatun wataf\q@u{a}khurun baynakum watak\q@u{a}thurun fee alamw\q@u{a}li wa\q@b{a}lawl\q@u{a}di kamathali ghaythin aAAjaba alkuff\q@u{a}ra nab\q@u{a}tuhu thumma yaheeju fatar\q@u{a}hu mu\q@u{s}farran thumma yakoonu \q@u{h}u\q@u{ta}man wafee al\q@u{a}khirati AAa\q@u{tha}bun shadeedun wamaghfiratun mina All\q@u{a}hi wari\q@u{d}w\q@u{a}nun wam\q@u{a} al\q@u{h}ay\q@u{a}tu a\q@b{l}dduny\q@u{a} ill\q@u{a} mat\q@u{a}AAu alghuroor\q@b{i}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmxcvi{S\q@u{a}biqoo il\q@u{a} maghfiratin min rabbikum wajannatin AAar\q@u{d}uh\q@u{a} kaAAar\q@u{d}i a\q@b{l}ssam\q@u{a}i wa\q@b{a}lar\q@u{d}i oAAiddat lilla\q@u{th}eena \q@u{a}manoo bi\q@b{A}ll\q@u{a}hi warusulihi \q@u{tha}lika fa\q@u{d}lu All\q@u{a}hi yuteehi man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu \q@u{th}oo alfa\q@u{d}li alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmxcvii{M\q@u{a} a\q@u{sa}ba min mu\q@u{s}eebatin fee alar\q@u{d}i wal\q@u{a} fee anfusikum ill\q@u{a} fee kit\q@u{a}bin min qabli an nabraah\q@u{a} inna \q@u{tha}lika AAal\q@u{a} All\q@u{a}hi yaseer\q@b{un}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmxcviii{Likayl\q@u{a} tasaw AAal\q@u{a} m\q@u{a} f\q@u{a}takum wal\q@u{a} tafra\q@u{h}oo bim\q@u{a} \q@u{a}t\q@u{a}kum wa\q@b{A}ll\q@u{a}hu l\q@u{a} yu\q@u{h}ibbu kulla mukht\q@u{a}lin fakhoor\q@b{in}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmxcix{Alla\q@u{th}eena yabkhaloona wayamuroona a\q@b{l}nn\q@u{a}sa bi\q@b{a}lbukhli waman yatawalla fainna All\q@u{a}ha huwa alghaniyyu al\q@u{h}ameed\q@b{u}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmc{Laqad arsaln\q@u{a} rusulan\q@u{a} bi\q@b{a}lbayyin\q@u{a}ti waanzaln\q@u{a} maAAahumu alkit\q@u{a}ba wa\q@b{a}lmeez\q@u{a}na liyaqooma a\q@b{l}nn\q@u{a}su bi\q@b{a}lqis\q@u{t}i waanzaln\q@u{a} al\q@u{h}adeeda feehi basun shadeedun waman\q@u{a}fiAAu li\q@b{l}nn\q@u{a}si waliyaAAlama All\q@u{a}hu man yan\q@u{s}uruhu warusulahu bi\q@b{a}lghaybi inna All\q@u{a}ha qawiyyun AAazeez\q@b{un}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmci{Walaqad arsaln\q@u{a} noo\q@u{h}an waibr\q@u{a}heema wajaAAaln\q@u{a} fee \q@u{th}urriyyatihim\q@u{a} a\q@b{l}nnubuwwata wa\q@b{a}lkit\q@u{a}ba faminhum muhtadin wakatheerun minhum f\q@u{a}siqoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmcii{Thumma qaffayn\q@u{a} AAal\q@u{a} \q@u{a}th\q@u{a}rihim birusulin\q@u{a} waqaffayn\q@u{a} biAAees\q@u{a} ibni maryama wa\q@u{a}tayn\q@u{a}hu alinjeela wajaAAaln\q@u{a} fee quloobi alla\q@u{th}eena ittabaAAoohu rafatan wara\q@u{h}matan warahb\q@u{a}niyyatan ibtadaAAooh\q@u{a} m\q@u{a} katabn\q@u{a}h\q@u{a} AAalayhim ill\q@u{a} ibtigh\q@u{a}a ri\q@u{d}w\q@u{a}ni All\q@u{a}hi fam\q@u{a} raAAawh\q@u{a} \q@u{h}aqqa riAA\q@u{a}yatih\q@u{a} fa\q@u{a}tayn\q@u{a} alla\q@u{th}eena \q@u{a}manoo minhum ajrahum wakatheerun minhum f\q@u{a}siqoon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmciii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo ittaqoo All\q@u{a}ha wa\q@u{a}minoo birasoolihi yutikum kiflayni min ra\q@u{h}matihi wayajAAal lakum nooran tamshoona bihi wayaghfir lakum wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmciv{Liall\q@u{a} yaAAlama ahlu alkit\q@u{a}bi all\q@u{a} yaqdiroona AAal\q@u{a} shayin min fa\q@u{d}li All\q@u{a}hi waanna alfa\q@u{d}la biyadi All\q@u{a}hi yuteehi man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu \q@u{th}oo alfa\q@u{d}li alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmcv{\basmalahlt Qad samiAAa All\q@u{a}hu qawla allatee tuj\q@u{a}diluka fee zawjih\q@u{a} watashtakee il\q@u{a} All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu yasmaAAu ta\q@u{ha}wurakum\q@u{a} inna All\q@u{a}ha sameeAAun ba\q@u{s}eer\q@b{un}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcvi{Alla\q@u{th}eena yu\q@i{\q@u{th}}\q@u{a}hiroona minkum min nis\q@u{a}ihim m\q@u{a} hunna ommah\q@u{a}tihim in ommah\q@u{a}tuhum ill\q@u{a} all\q@u{a}ee waladnahum wainnahum layaqooloona munkaran mina alqawli wazooran wainna All\q@u{a}ha laAAafuwwun ghafoor\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcvii{Wa\q@b{a}lla\q@u{th}eena yu\q@i{\q@u{th}}\q@u{a}hiroona min nis\q@u{a}ihim thumma yaAAoodoona lim\q@u{a} q\q@u{a}loo fata\q@u{h}reeru raqabatin min qabli an yatam\q@u{a}ss\q@u{a} \q@u{tha}likum tooAAa\q@i{\q@u{th}}oona bihi wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona khabeer\q@b{un}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcviii{Faman lam yajid fa\q@u{s}iy\q@u{a}mu shahrayni mutat\q@u{a}biAAayni min qabli an yatam\q@u{a}ss\q@u{a} faman lam yasta\q@u{t}iAA fai\q@u{t}AA\q@u{a}mu sitteena miskeenan \q@u{tha}lika lituminoo bi\q@b{A}ll\q@u{a}hi warasoolihi watilka \q@u{h}udoodu All\q@u{a}hi walilk\q@u{a}fireena AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcix{Inna alla\q@u{th}eena yu\q@u{ha}ddoona All\q@u{a}ha warasoolahu kubitoo kam\q@u{a} kubita alla\q@u{th}eena min qablihim waqad anzaln\q@u{a} \q@u{a}y\q@u{a}tin bayyin\q@u{a}tin walilk\q@u{a}fireena AAa\q@u{tha}bun muheen\q@b{un}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcx{Yawma yabAAathuhumu All\q@u{a}hu jameeAAan fayunabbiohum bim\q@u{a} AAamiloo a\q@u{hsa}hu All\q@u{a}hu wanasoohu wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin shaheed\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcxi{Alam tara anna All\q@u{a}ha yaAAlamu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i m\q@u{a} yakoonu min najw\q@u{a} thal\q@u{a}thatin ill\q@u{a} huwa r\q@u{a}biAAuhum wal\q@u{a} khamsatin ill\q@u{a} huwa s\q@u{a}disuhum wal\q@u{a} adn\q@u{a} min \q@u{tha}lika wal\q@u{a} akthara ill\q@u{a} huwa maAAahum ayna m\q@u{a} k\q@u{a}noo thumma yunabbiohum bim\q@u{a} AAamiloo yawma alqiy\q@u{a}mati inna All\q@u{a}ha bikulli shayin AAaleem\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcxii{Alam tara il\q@u{a} alla\q@u{th}eena nuhoo AAani a\q@b{l}nnajw\q@u{a} thumma yaAAoodoona lim\q@u{a} nuhoo AAanhu wayatan\q@u{a}jawna bi\q@b{a}lithmi wa\q@b{a}lAAudw\q@u{a}ni wamaAA\q@u{s}iyati a\q@b{l}rrasooli wai\q@u{tha} j\q@u{a}ooka \q@u{h}ayyawka bim\q@u{a} lam yu\q@u{h}ayyika bihi All\q@u{a}hu wayaqooloona fee anfusihim lawl\q@u{a} yuAAa\q@u{thth}ibun\q@u{a} All\q@u{a}hu bim\q@u{a} naqoolu \q@u{h}asbuhum jahannamu ya\q@u{s}lawnah\q@u{a} fabisa alma\q@u{s}eer\q@b{u}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} tan\q@u{a}jaytum fal\q@u{a} tatan\q@u{a}jaw bi\q@b{a}lithmi wa\q@b{a}lAAudw\q@u{a}ni wamaAA\q@u{s}iyati a\q@b{l}rrasooli watan\q@u{a}jaw bi\q@b{a}lbirri wa\q@b{al}ttaqw\q@u{a} wa\q@b{i}ttaqoo All\q@u{a}ha alla\q@u{th}ee ilayhi tu\q@u{h}sharoon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcxiv{Innam\q@u{a} a\q@b{l}nnajw\q@u{a} mina a\q@b{l}shshay\q@u{ta}ni liya\q@u{h}zuna alla\q@u{th}eena \q@u{a}manoo walaysa bi\q@u{da}rrihim shayan ill\q@u{a} bii\q@u{th}ni All\q@u{a}hi waAAal\q@u{a} All\q@u{a}hi falyatawakkali almuminoon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcxv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} qeela lakum tafassa\q@u{h}oo fee almaj\q@u{a}lisi fa\q@b{i}fsa\q@u{h}oo yafsa\q@u{h}i All\q@u{a}hu lakum wai\q@u{tha} qeela onshuzoo fa\q@b{o}nshuzoo yarfaAAi All\q@u{a}hu alla\q@u{th}eena \q@u{a}manoo minkum wa\q@b{a}lla\q@u{th}eena ootoo alAAilma daraj\q@u{a}tin wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona khabeer\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcxvi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} n\q@u{a}jaytumu a\q@b{l}rrasoola faqaddimoo bayna yaday najw\q@u{a}kum \q@u{s}adaqatan \q@u{tha}lika khayrun lakum waa\q@u{t}haru fain lam tajidoo fainna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcxvii{Aashfaqtum an tuqaddimoo bayna yaday najw\q@u{a}kum \q@u{s}adaq\q@u{a}tin fai\q@u{th} lam tafAAaloo wat\q@u{a}ba All\q@u{a}hu AAalaykum faaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}too a\q@b{l}zzak\q@u{a}ta waa\q@u{t}eeAAoo All\q@u{a}ha warasoolahu wa\q@b{A}ll\q@u{a}hu khabeerun bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcxviii{Alam tara il\q@u{a} alla\q@u{th}eena tawallaw qawman gha\q@u{d}iba All\q@u{a}hu AAalayhim m\q@u{a} hum minkum wal\q@u{a} minhum waya\q@u{h}lifoona AAal\q@u{a} alka\q@u{th}ibi wahum yaAAlamoon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcxix{aAAadda All\q@u{a}hu lahum AAa\q@u{tha}ban shadeedan innahum s\q@u{a}a m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcxx{Ittakha\q@u{th}oo aym\q@u{a}nahum junnatan fa\q@u{s}addoo AAan sabeeli All\q@u{a}hi falahum AAa\q@u{tha}bun muheen\q@b{un}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxi{Lan tughniya AAanhum amw\q@u{a}luhum wal\q@u{a} awl\q@u{a}duhum mina All\q@u{a}hi shayan ol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri hum feeh\q@u{a} kh\q@u{a}lidoon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxii{Yawma yabAAathuhumu All\q@u{a}hu jameeAAan faya\q@u{h}lifoona lahu kam\q@u{a} ya\q@u{h}lifoona lakum waya\q@u{h}saboona annahum AAal\q@u{a} shayin al\q@u{a} innahum humu alk\q@u{ath}iboon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxiii{Ista\q@u{h}wa\q@u{th}a AAalayhimu a\q@b{l}shshay\q@u{ta}nu faans\q@u{a}hum \q@u{th}ikra All\q@u{a}hi ol\q@u{a}ika \q@u{h}izbu a\q@b{l}shshay\q@u{ta}ni al\q@u{a} inna \q@u{h}izba a\q@b{l}shshay\q@u{ta}ni humu alkh\q@u{a}siroon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxiv{Inna alla\q@u{th}eena yu\q@u{ha}ddoona All\q@u{a}ha warasoolahu ol\q@u{a}ika fee ala\q@u{th}alleen\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxv{Kataba All\q@u{a}hu laaghlibanna an\q@u{a} warusulee inna All\q@u{a}ha qawiyyun AAazeez\q@b{un}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxvi{L\q@u{a} tajidu qawman yuminoona bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri yuw\q@u{a}ddoona man \q@u{ha}dda All\q@u{a}ha warasoolahu walaw k\q@u{a}noo \q@u{a}b\q@u{a}ahum aw abn\q@u{a}ahum aw ikhw\q@u{a}nahum aw AAasheeratahum ol\q@u{a}ika kataba fee quloobihimu aleem\q@u{a}na waayyadahum biroo\q@u{h}in minhu wayudkhiluhum jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} ra\q@u{d}iya All\q@u{a}hu AAanhum wara\q@u{d}oo AAanhu ol\q@u{a}ika \q@u{h}izbu All\q@u{a}hi al\q@u{a} inna \q@u{h}izba All\q@u{a}hi humu almufli\q@u{h}oon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxvii{\basmalahlt Sabba\q@u{h}a lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxviii{Huwa alla\q@u{th}ee akhraja alla\q@u{th}eena kafaroo min ahli alkit\q@u{a}bi min diy\q@u{a}rihim liawwali al\q@u{h}ashri m\q@u{a} \q@i{\q@u{th}}anantum an yakhrujoo wa\q@i{\q@u{th}}annoo annahum m\q@u{a}niAAatuhum \q@u{h}u\q@u{s}oonuhum mina All\q@u{a}hi faat\q@u{a}humu All\q@u{a}hu min \q@u{h}aythu lam ya\q@u{h}tasiboo waqa\q@u{th}afa fee quloobihimu a\q@b{l}rruAAba yukhriboona buyootahum biaydeehim waaydee almumineena fa\q@b{i}AAtabiroo y\q@u{a} olee alab\q@u{sa}r\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxix{Walawl\q@u{a} an kataba All\q@u{a}hu AAalayhimu aljal\q@u{a}a laAAa\q@u{thth}abahum fee a\q@b{l}dduny\q@u{a} walahum fee al\q@u{a}khirati AAa\q@u{tha}bu a\q@b{l}nn\q@u{a}r\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxx{\q@u{Tha}lika biannahum sh\q@u{a}qqoo All\q@u{a}ha warasoolahu waman yush\q@u{a}qqi All\q@u{a}ha fainna All\q@u{a}ha shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxxi{M\q@u{a} qa\q@u{t}aAAtum min leenatin aw taraktumooh\q@u{a} q\q@u{a}imatan AAal\q@u{a} o\q@u{s}oolih\q@u{a} fabii\q@u{th}ni All\q@u{a}hi waliyukhziya alf\q@u{a}siqeen\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxxii{Wam\q@u{a} af\q@u{a}a All\q@u{a}hu AAal\q@u{a} rasoolihi minhum fam\q@u{a} awjaftum AAalayhi min khaylin wal\q@u{a} rik\q@u{a}bin wal\q@u{a}kinna All\q@u{a}ha yusalli\q@u{t}u rusulahu AAal\q@u{a} man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxxiii{M\q@u{a} af\q@u{a}a All\q@u{a}hu AAal\q@u{a} rasoolihi min ahli alqur\q@u{a} falill\q@u{a}hi wali\q@b{l}rrasooli wali\q@u{th}ee alqurb\q@u{a} wa\q@b{a}lyat\q@u{a}m\q@u{a} wa\q@b{a}lmas\q@u{a}keeni wa\q@b{i}bni a\q@b{l}ssabeeli kay l\q@u{a} yakoona doolatan bayna alaghniy\q@u{a}i minkum wam\q@u{a} \q@u{a}t\q@u{a}kumu a\q@b{l}rrasoolu fakhu\q@u{th}oohu wam\q@u{a} nah\q@u{a}kum AAanhu fa\q@b{i}ntahoo wa\q@b{i}ttaqoo All\q@u{a}ha inna All\q@u{a}ha shadeedu alAAiq\q@u{a}b\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxxiv{Lilfuqar\q@u{a}i almuh\q@u{a}jireena alla\q@u{th}eena okhrijoo min diy\q@u{a}rihim waamw\q@u{a}lihim yabtaghoona fa\q@u{d}lan mina All\q@u{a}hi wari\q@u{d}w\q@u{a}nan wayan\q@u{s}uroona All\q@u{a}ha warasoolahu ol\q@u{a}ika humu a\q@b{l}\q@u{ssa}diqoon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxxv{Wa\q@b{a}lla\q@u{th}eena tabawwaoo a\q@b{l}dd\q@u{a}ra wa\q@b{a}leem\q@u{a}na min qablihim yu\q@u{h}ibboona man h\q@u{a}jara ilayhim wal\q@u{a} yajidoona fee \q@u{s}udoorihim \q@u{ha}jatan mimm\q@u{a} ootoo wayuthiroona AAal\q@u{a} anfusihim walaw k\q@u{a}na bihim kha\q@u{sas}atun waman yooqa shu\q@u{hh}a nafsihi faol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxxvi{Wa\q@b{a}lla\q@u{th}eena j\q@u{a}oo min baAAdihim yaqooloona rabban\q@u{a} ighfir lan\q@u{a} waliikhw\q@u{a}nin\q@u{a} alla\q@u{th}eena sabaqoon\q@u{a} bi\q@b{a}leem\q@u{a}ni wal\q@u{a} tajAAal fee quloobin\q@u{a} ghillan lilla\q@u{th}eena \q@u{a}manoo rabban\q@u{a} innaka raoofun ra\q@u{h}eem\q@b{un}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxxvii{Alam tara il\q@u{a} alla\q@u{th}eena n\q@u{a}faqoo yaqooloona liikhw\q@u{a}nihimu alla\q@u{th}eena kafaroo min ahli alkit\q@u{a}bi lain okhrijtum lanakhrujanna maAAakum wal\q@u{a} nu\q@u{t}eeAAu feekum a\q@u{h}adan abadan wain qootiltum lanan\q@u{s}urannakum wa\q@b{A}ll\q@u{a}hu yashhadu innahum lak\q@u{ath}iboon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxxviii{Lain okhrijoo l\q@u{a} yakhrujoona maAAahum walain qootiloo l\q@u{a} yan\q@u{s}uroonahum walain na\q@u{s}aroohum layuwallunna aladb\q@u{a}ra thumma l\q@u{a} yun\q@u{s}aroon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcxxxix{Laantum ashaddu rahbatan fee \q@u{s}udoorihim mina All\q@u{a}hi \q@u{tha}lika biannahum qawmun l\q@u{a} yafqahoon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcxl{L\q@u{a} yuq\q@u{a}tiloonakum jameeAAan ill\q@u{a} fee quran mu\q@u{h}a\q@u{ss}anatin aw min war\q@u{a}i judurin basuhum baynahum shadeedun ta\q@u{h}sabuhum jameeAAan waquloobuhum shatt\q@u{a} \q@u{tha}lika biannahum qawmun l\q@u{a} yaAAqiloon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcxli{Kamathali alla\q@u{th}eena min qablihim qareeban \q@u{tha}qoo wab\q@u{a}la amrihim walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcxlii{Kamathali a\q@b{l}shshay\q@u{ta}ni i\q@u{th} q\q@u{a}la lilins\q@u{a}ni okfur falamm\q@u{a} kafara q\q@u{a}la innee bareeon minka innee akh\q@u{a}fu All\q@u{a}ha rabba alAA\q@u{a}lameen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcxliii{Fak\q@u{a}na AA\q@u{a}qibatahum\q@u{a} annahum\q@u{a} fee a\q@b{l}nn\q@u{a}ri kh\q@u{a}lidayni feeh\q@u{a} wa\q@u{tha}lika jaz\q@u{a}o a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcxliv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo ittaqoo All\q@u{a}ha waltan\q@i{\q@u{th}}ur nafsun m\q@u{a} qaddamat lighadin wa\q@b{i}ttaqoo All\q@u{a}ha inna All\q@u{a}ha khabeerun bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcxlv{Wal\q@u{a} takoonoo ka\q@b{a}lla\q@u{th}eena nasoo All\q@u{a}ha faans\q@u{a}hum anfusahum ol\q@u{a}ika humu alf\q@u{a}siqoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcxlvi{L\q@u{a} yastawee a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri waa\q@u{s}\q@u{ha}bu aljannati a\q@u{s}\q@u{ha}bu aljannati humu alf\q@u{a}izoon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcxlvii{Law anzaln\q@u{a} h\q@u{atha} alqur\q@u{a}na AAal\q@u{a} jabalin laraaytahu kh\q@u{a}shiAAan muta\q@u{s}addiAAan min khashyati All\q@u{a}hi watilka alamth\q@u{a}lu na\q@u{d}ribuh\q@u{a} li\q@b{l}nn\q@u{a}si laAAallahum yatafakkaroon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcxlviii{Huwa All\q@u{a}hu alla\q@u{th}ee l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa AA\q@u{a}limu alghaybi wa\q@b{al}shshah\q@u{a}dati huwa a\q@b{l}rra\q@u{h}m\q@u{a}nu a\q@b{l}rra\q@u{h}eem\q@b{u}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcxlix{Huwa All\q@u{a}hu alla\q@u{th}ee l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa almaliku alquddoosu a\q@b{l}ssal\q@u{a}mu almuminu almuhayminu alAAazeezu aljabb\q@u{a}ru almutakabbiru sub\q@u{ha}na All\q@u{a}hi AAamm\q@u{a} yushrikoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmcl{Huwa All\q@u{a}hu alkh\q@u{a}liqu alb\q@u{a}rio almu\q@u{s}awwiru lahu alasm\q@u{a}o al\q@u{h}usn\q@u{a} yusabbi\q@u{h}u lahu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmcli{\basmalahlt Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tattakhi\q@u{th}oo AAaduwwee waAAaduwwakum awliy\q@u{a}a tulqoona ilayhim bi\q@b{a}lmawaddati waqad kafaroo bim\q@u{a} j\q@u{a}akum mina al\q@u{h}aqqi yukhrijoona a\q@b{l}rrasoola waiyy\q@u{a}kum an tuminoo bi\q@b{A}ll\q@u{a}hi rabbikum in kuntum kharajtum jih\q@u{a}dan fee sabeelee wa\q@b{i}btigh\q@u{a}a mar\q@u{da}tee tusirroona ilayhim bi\q@b{a}lmawaddati waan\q@u{a} aAAlamu bim\q@u{a} akhfaytum wam\q@u{a} aAAlantum waman yafAAalhu minkum faqad \q@u{d}alla saw\q@u{a}a a\q@b{l}ssabeel\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmclii{In yathqafookum yakoonoo lakam aAAd\q@u{a}an wayabsu\q@u{t}oo ilaykum aydiyahum waalsinatahum bi\q@b{al}ssooi wawaddoo law takfuroon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcliii{Lan tanfaAAakum ar\q@u{ha}mukum wal\q@u{a} awl\q@u{a}dukum yawma alqiy\q@u{a}mati yaf\q@u{s}ilu baynakum wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcliv{Qad k\q@u{a}nat lakum oswatun \q@u{h}asanatun fee ibr\q@u{a}heema wa\q@b{a}lla\q@u{th}eena maAAahu i\q@u{th} q\q@u{a}loo liqawmihim inn\q@u{a} bura\q@u{a}o minkum wamimm\q@u{a} taAAbudoona min dooni All\q@u{a}hi kafarn\q@u{a} bikum wabad\q@u{a} baynan\q@u{a} wabaynakumu alAAad\q@u{a}watu wa\q@b{a}lbagh\q@u{da}o abadan \q@u{h}att\q@u{a} tuminoo bi\q@b{A}ll\q@u{a}hi wa\q@u{h}dahu ill\q@u{a} qawla ibr\q@u{a}heema liabeehi laastaghfiranna laka wam\q@u{a} amliku laka mina All\q@u{a}hi min shayin rabban\q@u{a} AAalayka tawakkaln\q@u{a} wailayka anabn\q@u{a} wailayka alma\q@u{s}eer\q@b{u}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmclv{Rabban\q@u{a} l\q@u{a} tajAAaln\q@u{a} fitnatan lilla\q@u{th}eena kafaroo wa\q@b{i}ghfir lan\q@u{a} rabban\q@u{a} innaka anta alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmclvi{Laqad k\q@u{a}na lakum feehim oswatun \q@u{h}asanatun liman k\q@u{a}na yarjoo All\q@u{a}ha wa\q@b{a}lyawma al\q@u{a}khira waman yatawalla fainna All\q@u{a}ha huwa alghanniyyu al\q@u{h}ameed\q@b{u}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmclvii{AAas\q@u{a} All\q@u{a}hu an yajAAala baynakum wabayna alla\q@u{th}eena AA\q@u{a}daytum minhum mawaddatan wa\q@b{A}ll\q@u{a}hu qadeerun wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmclviii{L\q@u{a} yanh\q@u{a}kumu All\q@u{a}hu AAani alla\q@u{th}eena lam yuq\q@u{a}tilookum fee a\q@b{l}ddeeni walam yukhrijookum min diy\q@u{a}rikum an tabarroohum watuqsi\q@u{t}oo ilayhim inna All\q@u{a}ha yu\q@u{h}ibbu almuqsi\q@u{t}een\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmclix{Innam\q@u{a} yanh\q@u{a}kumu All\q@u{a}hu AAani alla\q@u{th}eena q\q@u{a}talookum fee a\q@b{l}ddeeni waakhrajookum min diy\q@u{a}rikum wa\q@i{\q@u{th}}\q@u{a}haroo AAal\q@u{a} ikhr\q@u{a}jikum an tawallawhum waman yatawallahum faol\q@u{a}ika humu a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limoon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmclx{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} j\q@u{a}akumu almumin\q@u{a}tu muh\q@u{a}jir\q@u{a}tin fa\q@b{i}mta\q@u{h}inoohunna All\q@u{a}hu aAAlamu bieem\q@u{a}nihinna fain AAalimtumoohunna mumin\q@u{a}tin fal\q@u{a} tarjiAAoohunna il\q@u{a} alkuff\q@u{a}ri l\q@u{a} hunna \q@u{h}illun lahum wal\q@u{a} hum ya\q@u{h}illoona lahunna wa\q@u{a}toohum m\q@u{a} anfaqoo wal\q@u{a} jun\q@u{ah}a AAalaykum an tanki\q@u{h}oohunna i\q@u{tha} \q@u{a}taytumoohunna ojoorahunna wal\q@u{a} tumsikoo biAAi\q@u{s}ami alkaw\q@u{a}firi wa\q@b{i}saloo m\q@u{a} anfaqtum walyasaloo m\q@u{a} anfaqoo \q@u{tha}likum \q@u{h}ukmu All\q@u{a}hi ya\q@u{h}kumu baynakum wa\q@b{A}ll\q@u{a}hu AAaleemun \q@u{h}akeem\q@b{un}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmclxi{Wain f\q@u{a}takum shayon min azw\q@u{a}jikum il\q@u{a} alkuff\q@u{a}ri faAA\q@u{a}qabtum fa\q@u{a}too alla\q@u{th}eena \q@u{th}ahabat azw\q@u{a}juhum mithla m\q@u{a} anfaqoo wa\q@b{i}ttaqoo All\q@u{a}ha alla\q@u{th}ee antum bihi muminoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmclxii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu i\q@u{tha} j\q@u{a}aka almumin\q@u{a}tu yub\q@u{a}yiAAnaka AAal\q@u{a} an l\q@u{a} yushrikna bi\q@b{A}ll\q@u{a}hi shayan wal\q@u{a} yasriqna wal\q@u{a} yazneena wal\q@u{a} yaqtulna awl\q@u{a}dahunna wal\q@u{a} yateena bibuht\q@u{a}nin yaftareenahu bayna aydeehinna waarjulihinna wal\q@u{a} yaAA\q@u{s}eenaka fee maAAroofin fab\q@u{a}yiAAhunna wa\q@b{i}staghfir lahunna All\q@u{a}ha inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmclxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tatawallaw qawman gha\q@u{d}iba All\q@u{a}hu AAalayhim qad yaisoo mina al\q@u{a}khirati kam\q@u{a} yaisa alkuff\q@u{a}ru min a\q@u{s}\q@u{ha}bi alquboor\q@b{i}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmclxiv{\basmalahlt Sabba\q@u{h}a lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmclxv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo lima taqooloona m\q@u{a} l\q@u{a} tafAAaloon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmclxvi{Kabura maqtan AAinda All\q@u{a}hi an taqooloo m\q@u{a} l\q@u{a} tafAAaloon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmclxvii{Inna All\q@u{a}ha yu\q@u{h}ibbu alla\q@u{th}eena yuq\q@u{a}tiloona fee sabeelihi \q@u{s}affan kaannahum buny\q@u{a}nun mar\q@u{s}oo\q@u{s}\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmclxviii{Wai\q@u{th} q\q@u{a}la moos\q@u{a} liqawmihi y\q@u{a} qawmi lima tu\q@u{th}oonanee waqad taAAlamoona annee rasoolu All\q@u{a}hi ilaykum falamm\q@u{a} z\q@u{a}ghoo az\q@u{a}gha All\q@u{a}hu quloobahum wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma alf\q@u{a}siqeen\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmclxix{Wai\q@u{th} q\q@u{a}la AAees\q@u{a} ibnu maryama y\q@u{a} banee isr\q@u{a}eela innee rasoolu All\q@u{a}hi ilaykum mu\q@u{s}addiqan lim\q@u{a} bayna yadayya mina a\q@b{l}ttawr\q@u{a}ti wamubashshiran birasoolin yatee min baAAdee ismuhu a\q@u{h}madu falamm\q@u{a} j\q@u{a}ahum bi\q@b{a}lbayyin\q@u{a}ti q\q@u{a}loo h\q@u{atha} si\q@u{h}run mubeen\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmclxx{Waman a\q@i{\q@u{th}}lamu mimmani iftar\q@u{a} AAal\q@u{a} All\q@u{a}hi alka\q@u{th}iba wahuwa yudAA\q@u{a} il\q@u{a} alisl\q@u{a}mi wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxi{Yureedoona liyu\q@u{t}fioo noora All\q@u{a}hi biafw\q@u{a}hihim wa\q@b{A}ll\q@u{a}hu mutimmu noorihi walaw kariha alk\q@u{a}firoon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxii{Huwa alla\q@u{th}ee arsala rasoolahu bi\q@b{a}lhud\q@u{a} wadeeni al\q@u{h}aqqi liyu\q@i{\q@u{th}}hirahu AAal\q@u{a} a\q@b{l}ddeeni kullihi walaw kariha almushrikoon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo hal adullukum AAal\q@u{a} tij\q@u{a}ratin tunjeekum min AAa\q@u{tha}bin aleem\q@b{in}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxiv{Tuminoona bi\q@b{A}ll\q@u{a}hi warasoolihi watuj\q@u{a}hidoona fee sabeeli All\q@u{a}hi biamw\q@u{a}likum waanfusikum \q@u{tha}likum khayrun lakum in kuntum taAAlamoon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxv{Yaghfir lakum \q@u{th}unoobakum wayudkhilkum jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru wamas\q@u{a}kina \q@u{t}ayyibatan fee jann\q@u{a}ti AAadnin \q@u{tha}lika alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxvi{Waokhr\q@u{a} tu\q@u{h}ibboonah\q@u{a} na\q@u{s}run mina All\q@u{a}hi wafat\q@u{h}un qarreebun wabashshiri almumineen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxvii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo koonoo an\q@u{sa}ra All\q@u{a}hi kam\q@u{a} q\q@u{a}la AAees\q@u{a} ibnu maryama lil\q@u{h}aw\q@u{a}riyyeena man an\q@u{sa}ree il\q@u{a} All\q@u{a}hi q\q@u{a}la al\q@u{h}aw\q@u{a}riyyoona na\q@u{h}nu an\q@u{sa}ru All\q@u{a}hi fa\q@u{a}manat \q@u{ta}ifatun min banee isr\q@u{a}eela wakafarat \q@u{ta}ifatun faayyadn\q@u{a} alla\q@u{th}eena \q@u{a}manoo AAal\q@u{a} AAaduwwihim faa\q@u{s}ba\q@u{h}oo \q@i{\q@u{th}}\q@u{a}hireen\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxviii{\basmalahlt Yusabbi\q@u{h}u lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i almaliki alquddoosi alAAazeezi al\q@u{h}akeem\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxix{Huwa alla\q@u{th}ee baAAatha fee alommiyyeena rasoolan minhum yatloo AAalayhim \q@u{a}y\q@u{a}tihi wayuzakkeehim wayuAAallimuhumu alkit\q@u{a}ba wa\q@b{a}l\q@u{h}ikmata wain k\q@u{a}noo min qablu lafee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxx{Wa\q@u{a}khareena minhum lamm\q@u{a} yal\q@u{h}aqoo bihim wahuwa alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxxi{\q@u{Tha}lika fa\q@u{d}lu All\q@u{a}hi yuteehi man yash\q@u{a}o wa\q@b{A}ll\q@u{a}hu \q@u{th}oo alfa\q@u{d}li alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxxii{Mathalu alla\q@u{th}eena \q@u{h}ummiloo a\q@b{l}ttawr\q@u{a}ta thumma lam ya\q@u{h}milooh\q@u{a} kamathali al\q@u{h}im\q@u{a}ri ya\q@u{h}milu asf\q@u{a}ran bisa mathalu alqawmi alla\q@u{th}eena ka\q@u{thth}aboo bi\q@u{a}y\q@u{a}ti All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu l\q@u{a} yahdee alqawma a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxxiii{Qul y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena h\q@u{a}doo in zaAAamtum annakum awliy\q@u{a}o lill\q@u{a}hi min dooni a\q@b{l}nn\q@u{a}si fatamannawoo almawta in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxxiv{Wal\q@u{a} yatamannawnahu abadan bim\q@u{a} qaddamat aydeehim wa\q@b{A}ll\q@u{a}hu AAaleemun bi\q@b{al}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxxv{Qul inna almawta alla\q@u{th}ee tafirroona minhu fainnahu mul\q@u{a}qeekum thumma turaddoona il\q@u{a} AA\q@u{a}limi alghaybi wa\q@b{al}shshah\q@u{a}dati fayunabbiokum bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxxvi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo i\q@u{tha} noodiya li\q@b{l}\q@u{ss}al\q@u{a}ti min yawmi aljumuAAati fa\q@b{i}sAAaw il\q@u{a} \q@u{th}ikri All\q@u{a}hi wa\q@u{th}aroo albayAAa \q@u{tha}likum khayrun lakum in kuntum taAAlamoon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxxvii{Fai\q@u{tha} qu\q@u{d}iyati a\q@b{l}\q@u{ss}al\q@u{a}tu fa\q@b{i}ntashiroo fee alar\q@u{d}i wa\q@b{i}btaghoo min fa\q@u{d}li All\q@u{a}hi wa\q@b{o}\q@u{th}kuroo All\q@u{a}ha katheeran laAAallakum tufli\q@u{h}oon\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxxviii{Wai\q@u{tha} raaw tij\q@u{a}ratan aw lahwan infa\q@u{dd}oo ilayh\q@u{a} watarakooka q\q@u{a}iman qul m\q@u{a} AAinda All\q@u{a}hi khayrun mina allahwi wamina a\q@b{l}ttij\q@u{a}rati wa\q@b{A}ll\q@u{a}hu khayru a\q@b{l}rr\q@u{a}ziqeen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmclxxxix{\basmalahlt I\q@u{tha} j\q@u{a}aka almun\q@u{a}fiqoona q\q@u{a}loo nashhadu innaka larasoolu All\q@u{a}hi wa\q@b{A}ll\q@u{a}hu yaAAlamu innaka larasooluhu wa\q@b{A}ll\q@u{a}hu yashhadu inna almun\q@u{a}fiqeena lak\q@u{ath}iboon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcxc{Ittakha\q@u{th}oo aym\q@u{a}nahum junnatan fa\q@u{s}addoo AAan sabeeli All\q@u{a}hi innahum s\q@u{a}a m\q@u{a} k\q@u{a}noo yaAAmaloon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcxci{\q@u{Tha}lika biannahum \q@u{a}manoo thumma kafaroo fa\q@u{t}ubiAAa AAal\q@u{a} quloobihim fahum l\q@u{a} yafqahoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcxcii{Wai\q@u{tha} raaytahum tuAAjibuka ajs\q@u{a}muhum wain yaqooloo tasmaAA liqawlihim kaannahum khushubun musannadatun ya\q@u{h}saboona kulla \q@u{s}ay\q@u{h}atin AAalayhim humu alAAaduwwu fa\q@b{i}\q@u{hth}arhum q\q@u{a}talahumu All\q@u{a}hu ann\q@u{a} yufakoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcxciii{Wai\q@u{tha} qeela lahum taAA\q@u{a}law yastaghfir lakum rasoolu All\q@u{a}hi lawwaw ruoosahum waraaytahum ya\q@u{s}uddoona wahum mustakbiroon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcxciv{Saw\q@u{a}on AAalayhim astaghfarta lahum am lam tastaghfir lahum lan yaghfira All\q@u{a}hu lahum inna All\q@u{a}ha l\q@u{a} yahdee alqawma alf\q@u{a}siqeen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcxcv{Humu alla\q@u{th}eena yaqooloona l\q@u{a} tunfiqoo AAal\q@u{a} man AAinda rasooli All\q@u{a}hi \q@u{h}att\q@u{a} yanfa\q@u{dd}oo walill\q@u{a}hi khaz\q@u{a}inu a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wal\q@u{a}kinna almun\q@u{a}fiqeena l\q@u{a} yafqahoon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcxcvi{Yaqooloona lain rajaAAn\q@u{a} il\q@u{a} almadeenati layukhrijanna alaAAazzu minh\q@u{a} ala\q@u{th}alla walill\q@u{a}hi alAAizzatu walirasoolihi walilmumineena wal\q@u{a}kinna almun\q@u{a}fiqeena l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcxcvii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo l\q@u{a} tulhikum amw\q@u{a}lukum wal\q@u{a} awl\q@u{a}dukum AAan \q@u{th}ikri All\q@u{a}hi waman yafAAal \q@u{tha}lika faol\q@u{a}ika humu alkh\q@u{a}siroon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcxcviii{Waanfiqoo min m\q@u{a} razaqn\q@u{a}kum min qabli an yatiya a\q@u{h}adakumu almawtu fayaqoola rabbi lawl\q@u{a} akhkhartanee il\q@u{a} ajalin qareebin faa\q@u{ss}addaqa waakun mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcxcix{Walan yuakhkhira All\q@u{a}hu nafsan i\q@u{tha} j\q@u{a}a ajaluh\q@u{a} wa\q@b{A}ll\q@u{a}hu khabeerun bim\q@u{a} taAAmaloon\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcc{\basmalahlt Yusabbi\q@u{h}u lill\q@u{a}hi m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wam\q@u{a} fee alar\q@u{d}i lahu almulku walahu al\q@u{h}amdu wahuwa AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcci{Huwa alla\q@u{th}ee khalaqakum faminkum k\q@u{a}firun waminkum muminun wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona ba\q@u{s}eer\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmccii{Khalaqa a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}a bi\q@b{a}l\q@u{h}aqqi wa\q@u{s}awwarakum faa\q@u{h}sana \q@u{s}uwarakum wailayhi alma\q@u{s}eer\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcciii{YaAAlamu m\q@u{a} fee a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wayaAAlamu m\q@u{a} tusirroona wam\q@u{a} tuAAlinoona wa\q@b{A}ll\q@u{a}hu AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcciv{Alam yatikum nabao alla\q@u{th}eena kafaroo min qablu fa\q@u{tha}qoo wab\q@u{a}la amrihim walahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmccv{\q@u{Tha}lika biannahu k\q@u{a}nat tateehim rusuluhum bi\q@b{a}lbayyin\q@u{a}ti faq\q@u{a}loo abasharun yahdoonan\q@u{a} fakafaroo watawallaw wa\q@b{i}staghn\q@u{a} All\q@u{a}hu wa\q@b{A}ll\q@u{a}hu ghaniyyun \q@u{h}ameed\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmccvi{ZaAAama alla\q@u{th}eena kafaroo an lan yubAAathoo qul bal\q@u{a} warabbee latubAAathunna thumma latunabbaonna bim\q@u{a} AAamiltum wa\q@u{tha}lika AAal\q@u{a} All\q@u{a}hi yaseer\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmccvii{Fa\q@u{a}minoo bi\q@b{A}ll\q@u{a}hi warasoolihi wa\q@b{al}nnoori alla\q@u{th}ee anzaln\q@u{a} wa\q@b{A}ll\q@u{a}hu bim\q@u{a} taAAmaloona khabeer\q@b{un}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmccviii{Yawma yajmaAAukum liyawmi aljamAAi \q@u{tha}lika yawmu a\q@b{l}ttagh\q@u{a}buni waman yumin bi\q@b{A}ll\q@u{a}hi wayaAAmal \q@u{sa}li\q@u{h}an yukaffir AAanhu sayyi\q@u{a}tihi wayudkhilhu jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} abadan \q@u{tha}lika alfawzu alAAa\q@i{\q@u{th}}eem\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmccix{Wa\q@b{a}lla\q@u{th}eena kafaroo waka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} ol\q@u{a}ika a\q@u{s}\q@u{ha}bu a\q@b{l}nn\q@u{a}ri kh\q@u{a}lideena feeh\q@u{a} wabisa alma\q@u{s}eer\q@b{u}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmccx{M\q@u{a} a\q@u{sa}ba min mu\q@u{s}eebatin ill\q@u{a} bii\q@u{th}ni All\q@u{a}hi waman yumin bi\q@b{A}ll\q@u{a}hi yahdi qalbahu wa\q@b{A}ll\q@u{a}hu bikulli shayin AAaleem\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmccxi{Waa\q@u{t}eeAAoo All\q@u{a}ha waa\q@u{t}eeAAoo a\q@b{l}rrasoola fain tawallaytum fainnam\q@u{a} AAal\q@u{a} rasoolin\q@u{a} albal\q@u{a}ghu almubeen\q@b{u}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmccxii{All\q@u{a}hu l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa waAAal\q@u{a} All\q@u{a}hi falyatawakkali almuminoon\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmccxiii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo inna min azw\q@u{a}jikum waawl\q@u{a}dikum AAaduwwan lakum fa\q@b{i}\q@u{hth}aroohum wain taAAfoo wata\q@u{s}fa\q@u{h}oo wataghfiroo fainna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmccxiv{Innam\q@u{a} amw\q@u{a}lukum waawl\q@u{a}dukum fitnatun wa\q@b{A}ll\q@u{a}hu AAindahu ajrun AAa\q@i{\q@u{th}}eem\q@b{un}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmccxv{Fa\q@b{i}ttaqoo All\q@u{a}ha m\q@u{a} ista\q@u{t}aAAtum wa\q@b{i}smaAAoo waa\q@u{t}eeAAoo waanfiqoo khayran lianfusikum waman yooqa shu\q@u{hh}a nafsihi faol\q@u{a}ika humu almufli\q@u{h}oon\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmccxvi{In tuqri\q@u{d}oo All\q@u{a}ha qar\q@u{d}an \q@u{h}asanan yu\q@u{da}AAifhu lakum wayaghfir lakum wa\q@b{A}ll\q@u{a}hu shakoorun \q@u{h}aleem\q@b{un}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmccxvii{AA\q@u{a}limu alghaybi wa\q@b{al}shshah\q@u{a}dati alAAazeezu al\q@u{h}akeem\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmccxviii{\basmalahlt Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu i\q@u{tha} \q@u{t}allaqtumu a\q@b{l}nnis\q@u{a}a fa\q@u{t}alliqoohunna liAAiddatihinna waa\q@u{hs}oo alAAiddata wa\q@b{i}ttaqoo All\q@u{a}ha rabbakum l\q@u{a} tukhrijoohunna min buyootihinna wal\q@u{a} yakhrujna ill\q@u{a} an yateena bif\q@u{ah}ishatin mubayyinatin watilka \q@u{h}udoodu All\q@u{a}hi waman yataAAadda \q@u{h}udooda All\q@u{a}hi faqad \q@i{\q@u{th}}alama nafsahu l\q@u{a} tadree laAAalla All\q@u{a}ha yu\q@u{h}dithu baAAda \q@u{tha}lika amr\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmccxix{Fai\q@u{tha} balaghna ajalahunna faamsikoohunna bimaAAroofin aw f\q@u{a}riqoohunna bimaAAroofin waashhidoo \q@u{th}away AAadlin minkum waaqeemoo a\q@b{l}shshah\q@u{a}data lill\q@u{a}hi \q@u{tha}likum yooAAa\q@i{\q@u{th}}u bihi man k\q@u{a}na yuminu bi\q@b{A}ll\q@u{a}hi wa\q@b{a}lyawmi al\q@u{a}khiri waman yattaqi All\q@u{a}ha yajAAal lahu makhraj\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmccxx{Wayarzuqhu min \q@u{h}aythu l\q@u{a} ya\q@u{h}tasibu waman yatawakkal AAal\q@u{a} All\q@u{a}hi fahuwa \q@u{h}asbuhu inna All\q@u{a}ha b\q@u{a}lighu amrihi qad jaAAala All\q@u{a}hu likulli shayin qadr\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxi{Wa\q@b{a}ll\q@u{a}ee yaisna mina alma\q@u{h}ee\q@u{d}i min nis\q@u{a}ikum ini irtabtum faAAiddatuhunna thal\q@u{a}thatu ashhurin wa\q@b{a}ll\q@u{a}ee lam ya\q@u{h}i\q@u{d}na waol\q@u{a}tu ala\q@u{h}m\q@u{a}li ajaluhunna an ya\q@u{d}aAAna \q@u{h}amlahunna waman yattaqi All\q@u{a}ha yajAAal lahu min amrihi yusr\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxii{\q@u{Tha}lika amru All\q@u{a}hi anzalahu ilaykum waman yattaqi All\q@u{a}ha yukaffir AAanhu sayyi\q@u{a}tihi wayuAA\q@i{\q@u{th}}im lahu ajr\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxiii{Askinoohunna min \q@u{h}aythu sakantum min wujdikum wal\q@u{a} tu\q@u{da}rroohunna litu\q@u{d}ayyiqoo AAalayhinna wain kunna ol\q@u{a}ti \q@u{h}amlin faanfiqoo AAalayhinna \q@u{h}att\q@u{a} ya\q@u{d}aAAna \q@u{h}amlahunna fain ar\q@u{d}aAAna lakum fa\q@u{a}toohunna ojoorahunna watamiroo baynakum bimaAAroofin wain taAA\q@u{a}sartum fasatur\q@u{d}iAAu lahu okhr\q@u{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxiv{Liyunfiq \q@u{th}oo saAAatin min saAAatihi waman qudira AAalayhi rizquhu falyunfiq mimm\q@u{a} \q@u{a}t\q@u{a}hu All\q@u{a}hu l\q@u{a} yukallifu All\q@u{a}hu nafsan ill\q@u{a} m\q@u{a} \q@u{a}t\q@u{a}h\q@u{a} sayajAAalu All\q@u{a}hu baAAda AAusrin yusr\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxv{Wakaayyin min qaryatin AAatat AAan amri rabbih\q@u{a} warusulihi fa\q@u{ha}sabn\q@u{a}h\q@u{a} \q@u{h}is\q@u{a}ban shadeedan waAAa\q@u{thth}abn\q@u{a}h\q@u{a} AAa\q@u{tha}ban nukr\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxvi{Fa\q@u{tha}qat wab\q@u{a}la amrih\q@u{a} wak\q@u{a}na AA\q@u{a}qibatu amrih\q@u{a} khusr\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxvii{aAAadda All\q@u{a}hu lahum AAa\q@u{tha}ban shadeedan fa\q@b{i}ttaqoo All\q@u{a}ha y\q@u{a} olee alalb\q@u{a}bi alla\q@u{th}eena \q@u{a}manoo qad anzala All\q@u{a}hu ilaykum \q@u{th}ikr\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxviii{Rasoolan yatloo AAalaykum \q@u{a}y\q@u{a}ti All\q@u{a}hi mubayyin\q@u{a}tin liyukhrija alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti mina a\q@b{l}\q@i{\q@u{thth}}ulum\q@u{a}ti il\q@u{a} a\q@b{l}nnoori waman yumin bi\q@b{A}ll\q@u{a}hi wayaAAmal \q@u{sa}li\q@u{h}an yudkhilhu jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} abadan qad a\q@u{h}sana All\q@u{a}hu lahu rizq\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxix{All\q@u{a}hu alla\q@u{th}ee khalaqa sabAAa sam\q@u{a}w\q@u{a}tin wamina alar\q@u{d}i mithlahunna yatanazzalu alamru baynahunna litaAAlamoo anna All\q@u{a}ha AAal\q@u{a} kulli shayin qadeerun waanna All\q@u{a}ha qad a\q@u{hat}a bikulli shayin AAilm\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxx{\basmalahlt Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu lima tu\q@u{h}arrimu m\q@u{a} a\q@u{h}alla All\q@u{a}hu laka tabtaghee mar\q@u{da}ta azw\q@u{a}jika wa\q@b{A}ll\q@u{a}hu ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxxi{Qad fara\q@u{d}a All\q@u{a}hu lakum ta\q@u{h}illata aym\q@u{a}nikum wa\q@b{A}ll\q@u{a}hu mawl\q@u{a}kum wahuwa alAAaleemu al\q@u{h}akeem\q@b{u}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxxii{Wai\q@u{th} asarra a\q@b{l}nnabiyyu il\q@u{a} baAA\q@u{d}i azw\q@u{a}jihi \q@u{h}adeethan falamm\q@u{a} nabbaat bihi waa\q@i{\q@u{th}}harahu All\q@u{a}hu AAalayhi AAarrafa baAA\q@u{d}ahu waaAAra\q@u{d}a AAan baAA\q@u{d}in falamm\q@u{a} nabbaah\q@u{a} bihi q\q@u{a}lat man anbaaka h\q@u{atha} q\q@u{a}la nabbaaniya alAAaleemu alkhabeer\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxxiii{In tatoob\q@u{a} il\q@u{a} All\q@u{a}hi faqad \q@u{s}aghat quloobukum\q@u{a} wain ta\q@i{\q@u{th}}\q@u{a}har\q@u{a} AAalayhi fainna All\q@u{a}ha huwa mawl\q@u{a}hu wajibreelu wa\q@u{sa}li\q@u{h}u almumineena wa\q@b{a}lmal\q@u{a}ikatu baAAda \q@u{tha}lika \q@i{\q@u{th}}aheer\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxxiv{AAas\q@u{a} rabbuhu in \q@u{t}allaqakunna an yubdilahu azw\q@u{a}jan khayran minkunna muslim\q@u{a}tin mumin\q@u{a}tin q\q@u{a}nit\q@u{a}tin t\q@u{a}ib\q@u{a}tin AA\q@u{a}bid\q@u{a}tin s\q@u{a}i\q@u{ha}tin thayyib\q@u{a}tin waabk\q@u{a}r\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxxv{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo qoo anfusakum waahleekum n\q@u{a}ran waqooduh\q@u{a} a\q@b{l}nn\q@u{a}su wa\q@b{a}l\q@u{h}ij\q@u{a}ratu AAalayh\q@u{a} mal\q@u{a}ikatun ghil\q@u{a}\q@i{\q@u{th}}un shid\q@u{a}dun l\q@u{a} yaAA\q@u{s}oona All\q@u{a}ha m\q@u{a} amarahum wayafAAaloona m\q@u{a} yumaroon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxxvi{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena kafaroo l\q@u{a} taAAta\q@u{th}iroo alyawma innam\q@u{a} tujzawna m\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxxvii{Y\q@u{a} ayyuh\q@u{a} alla\q@u{th}eena \q@u{a}manoo tooboo il\q@u{a} All\q@u{a}hi tawbatan na\q@u{s}oo\q@u{h}an AAas\q@u{a} rabbukum an yukaffira AAankum sayyi\q@u{a}tikum wayudkhilakum jann\q@u{a}tin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru yawma l\q@u{a} yukhzee All\q@u{a}hu a\q@b{l}nnabiyya wa\q@b{a}lla\q@u{th}eena \q@u{a}manoo maAAahu nooruhum yasAA\q@u{a} bayna aydeehim wabiaym\q@u{a}nihim yaqooloona rabban\q@u{a} atmim lan\q@u{a} nooran\q@u{a} wa\q@b{i}ghfir lan\q@u{a} innaka AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxxviii{Y\q@u{a} ayyuh\q@u{a} a\q@b{l}nnabiyyu j\q@u{a}hidi alkuff\q@u{a}ra wa\q@b{a}lmun\q@u{a}fiqeena wa\q@b{o}ghlu\q@i{\q@u{th}} AAalayhim wamaw\q@u{a}hum jahannamu wabisa alma\q@u{s}eer\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmccxxxix{\q@u{D}araba All\q@u{a}hu mathalan lilla\q@u{th}eena kafaroo imraata noo\q@u{h}in wa\q@b{i}mraata loo\q@u{t}in k\q@u{a}nat\q@u{a} ta\q@u{h}ta AAabdayni min AAib\q@u{a}din\q@u{a} \q@u{sa}li\q@u{h}ayni fakh\q@u{a}nat\q@u{a}hum\q@u{a} falam yughniy\q@u{a} AAanhum\q@u{a} mina All\q@u{a}hi shayan waqeela odkhul\q@u{a} a\q@b{l}nn\q@u{a}ra maAAa a\q@b{l}dd\q@u{a}khileen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmccxl{Wa\q@u{d}araba All\q@u{a}hu mathalan lilla\q@u{th}eena \q@u{a}manoo imraata firAAawna i\q@u{th} q\q@u{a}lat rabbi ibni lee AAindaka baytan fee aljannati wanajjinee min firAAawna waAAamalihi wanajjinee mina alqawmi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmccxli{Wamaryama ibnata AAimr\q@u{a}na allatee a\q@u{hs}anat farjah\q@u{a} fanafakhn\q@u{a} feehi min roo\q@u{h}in\q@u{a} wa\q@u{s}addaqat bikalim\q@u{a}ti rabbih\q@u{a} wakutubihi wak\q@u{a}nat mina alq\q@u{a}niteen\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmccxlii{\basmalahlt Tab\q@u{a}raka alla\q@u{th}ee biyadihi almulku wahuwa AAal\q@u{a} kulli shayin qadeer\q@b{un}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmccxliii{Alla\q@u{th}ee khalaqa almawta wa\q@b{a}l\q@u{h}ay\q@u{a}ta liyabluwakum ayyukum a\q@u{h}sanu AAamalan wahuwa alAAazeezu alghafoor\q@b{u}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmccxliv{Alla\q@u{th}ee khalaqa sabAAa sam\q@u{a}w\q@u{a}tin \q@u{t}ib\q@u{a}qan m\q@u{a} tar\q@u{a} fee khalqi a\q@b{l}rra\q@u{h}m\q@u{a}ni min taf\q@u{a}wutin fa\q@b{i}rjiAAi alba\q@u{s}ara hal tar\q@u{a} min fu\q@u{t}oor\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmccxlv{Thumma irjiAAi alba\q@u{s}ara karratayni yanqalib ilayka alba\q@u{s}aru kh\q@u{a}sian wahuwa \q@u{h}aseer\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmccxlvi{Walaqad zayyann\q@u{a} a\q@b{l}ssam\q@u{a}a a\q@b{l}dduny\q@u{a} bima\q@u{sa}bee\q@u{h}a wajaAAaln\q@u{a}h\q@u{a} rujooman li\q@b{l}shshay\q@u{at}eeni waaAAtadn\q@u{a} lahum AAa\q@u{tha}ba a\q@b{l}ssaAAeer\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmccxlvii{Walilla\q@u{th}eena kafaroo birabbihim AAa\q@u{tha}bu jahannama wabisa alma\q@u{s}eer\q@b{u}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmccxlviii{I\q@u{tha} olqoo feeh\q@u{a} samiAAoo lah\q@u{a} shaheeqan wahiya tafoor\q@b{u}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmccxlix{Tak\q@u{a}du tamayyazu mina alghay\q@i{\q@u{th}}i kullam\q@u{a} olqiya feeh\q@u{a} fawjun saalahum khazanatuh\q@u{a} alam yatikum na\q@u{th}eer\q@b{un}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmccl{Q\q@u{a}loo bal\q@u{a} qad j\q@u{a}an\q@u{a} na\q@u{th}eerun faka\q@u{thth}abn\q@u{a} waquln\q@u{a} m\q@u{a} nazzala All\q@u{a}hu min shayin in antum ill\q@u{a} fee \q@u{d}al\q@u{a}lin kabeer\q@b{in}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmccli{Waq\q@u{a}loo law kunn\q@u{a} nasmaAAu aw naAAqilu m\q@u{a} kunn\q@u{a} fee a\q@u{s}\q@u{ha}bi a\q@b{l}ssaAAeer\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcclii{Fa\q@b{i}AAtarafoo bi\q@u{th}anbihim fasu\q@u{h}qan lia\q@u{s}\q@u{ha}bi a\q@b{l}ssaAAeer\q@b{i}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmccliii{Inna alla\q@u{th}eena yakhshawna rabbahum bi\q@b{a}lghaybi lahum maghfiratun waajrun kabeer\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmccliv{Waasirroo qawlakum awi ijharoo bihi innahu AAaleemun bi\q@u{tha}ti a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcclv{Al\q@u{a} yaAAlamu man khalaqa wahuwa alla\q@u{t}eefu alkhabeer\q@b{u}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcclvi{Huwa alla\q@u{th}ee jaAAala lakumu alar\q@u{d}a \q@u{th}aloolan fa\q@b{i}mshoo fee man\q@u{a}kibih\q@u{a} wakuloo min rizqihi wailayhi a\q@b{l}nnushoor\q@b{u}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcclvii{Aamintum man fee a\q@b{l}ssam\q@u{a}i an yakhsifa bikumu alar\q@u{d}a fai\q@u{tha} hiya tamoor\q@b{u}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcclviii{Am amintum man fee a\q@b{l}ssam\q@u{a}i an yursila AAalaykum \q@u{has}iban fasataAAlamoona kayfa na\q@u{th}eer\q@b{i}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcclix{Walaqad ka\q@u{thth}aba alla\q@u{th}eena min qablihim fakayfa k\q@u{a}na nakeer\q@b{i}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcclx{Awalam yaraw il\q@u{a} a\q@b{l}\q@u{tt}ayri fawqahum \q@u{sa}ff\q@u{a}tin wayaqbi\q@u{d}na m\q@u{a} yumsikuhunna ill\q@u{a} a\q@b{l}rra\q@u{h}m\q@u{a}nu innahu bikulli shayin ba\q@u{s}eer\q@b{un}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxi{Amman h\q@u{atha} alla\q@u{th}ee huwa jundun lakum yan\q@u{s}urukum min dooni a\q@b{l}rra\q@u{h}m\q@u{a}ni ini alk\q@u{a}firoona ill\q@u{a} fee ghuroor\q@b{in}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxii{Amman h\q@u{atha} alla\q@u{th}ee yarzuqukum in amsaka rizqahu bal lajjoo fee AAutuwwin wanufoor\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxiii{Afaman yamshee mukibban AAal\q@u{a} wajhihi ahd\q@u{a} amman yamshee sawiyyan AAal\q@u{a} \q@u{s}ir\q@u{at}in mustaqeem\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxiv{Qul huwa alla\q@u{th}ee anshaakum wajaAAala lakumu a\q@b{l}ssamAAa wa\q@b{a}lab\q@u{sa}ra wa\q@b{a}lafidata qaleelan m\q@u{a} tashkuroon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxv{Qul huwa alla\q@u{th}ee \q@u{th}araakum fee alar\q@u{d}i wailayhi tu\q@u{h}sharoon\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxvi{Wayaqooloona mat\q@u{a} h\q@u{atha} alwaAAdu in kuntum \q@u{sa}diqeen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxvii{Qul innam\q@u{a} alAAilmu AAinda All\q@u{a}hi wainnam\q@u{a} an\q@u{a} na\q@u{th}eerun mubeen\q@b{un}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxviii{Falamm\q@u{a} raawhu zulfatan seeat wujoohu alla\q@u{th}eena kafaroo waqeela h\q@u{atha} alla\q@u{th}ee kuntum bihi taddaAAoon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxix{Qul araaytum in ahlakaniya All\q@u{a}hu waman maAAiya aw ra\q@u{h}iman\q@u{a} faman yujeeru alk\q@u{a}fireena min AAa\q@u{tha}bin aleem\q@b{in}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxx{Qul huwa a\q@b{l}rra\q@u{h}m\q@u{a}nu \q@u{a}mann\q@u{a} bihi waAAalayhi tawakkaln\q@u{a} fasataAAlamoona man huwa fee \q@u{d}al\q@u{a}lin mubeen\q@b{in}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxi{Qul araaytum in a\q@u{s}ba\q@u{h}a m\q@u{a}okum ghawran faman yateekum bim\q@u{a}in maAAeen\q@b{in}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxii{\basmalahlt Noon wa\q@b{a}lqalami wam\q@u{a} yas\q@u{t}uroon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxiii{M\q@u{a} anta biniAAmati rabbika bimajnoon\q@b{in}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxiv{Wainna laka laajran ghayra mamnoon\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxv{Wainnaka laAAal\q@u{a} khuluqin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxvi{Fasatub\q@u{s}iru wayub\q@u{s}iroon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxvii{Biayyikumu almaftoon\q@b{u}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxviii{Inna rabbaka huwa aAAlamu biman \q@u{d}alla AAan sabeelihi wahuwa aAAlamu bi\q@b{a}lmuhtadeen\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxix{Fal\q@u{a} tu\q@u{t}iAAi almuka\q@u{thth}ibeen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxx{Waddoo law tudhinu fayudhinoon\q@b{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxxi{Wal\q@u{a} tu\q@u{t}iAA kulla \q@u{h}all\q@u{a}fin maheen\q@b{in}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxxii{Hamm\q@u{a}zin mashsh\q@u{a}in binameem\q@b{in}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxxiii{Mann\q@u{a}AAin lilkhayri muAAtadin atheem\q@b{in}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxxiv{AAutullin baAAda \q@u{tha}lika zaneem\q@b{in}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxxv{An k\q@u{a}na \q@u{tha} m\q@u{a}lin wabaneen\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxxvi{I\q@u{tha} tutl\q@u{a} AAalayhi \q@u{a}y\q@u{a}tun\q@u{a} q\q@u{a}la as\q@u{at}eeru alawwaleen\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxxvii{Sanasimuhu AAal\q@u{a} alkhur\q@u{t}oom\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxxviii{Inn\q@u{a} balawn\q@u{a}hum kam\q@u{a} balawn\q@u{a} a\q@u{s}\q@u{ha}ba aljannati i\q@u{th} aqsamoo laya\q@u{s}rimunnah\q@u{a} mu\q@u{s}bi\q@u{h}een\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcclxxxix{Wal\q@u{a} yastathnoon\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmccxc{Fa\q@u{ta}fa AAalayh\q@u{a} \q@u{ta}ifun min rabbika wahum n\q@u{a}imoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmccxci{Faa\q@u{s}ba\q@u{h}at ka\q@b{al}\q@u{ss}areem\q@b{i}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmccxcii{Fatan\q@u{a}daw mu\q@u{s}bi\q@u{h}een\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmccxciii{Ani ighdoo AAal\q@u{a} \q@u{h}arthikum in kuntum \q@u{sa}rimeen\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmccxciv{Fa\q@b{i}n\q@u{t}alaqoo wahum yatakh\q@u{a}fatoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmccxcv{An l\q@u{a} yadkhulannah\q@u{a} alyawma AAalaykum miskeen\q@b{un}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmccxcvi{Waghadaw AAal\q@u{a} \q@u{h}ardin q\q@u{a}direen\q@b{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmccxcvii{Falamm\q@u{a} raawh\q@u{a} q\q@u{a}loo inn\q@u{a} la\q@u{da}lloon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmccxcviii{Bal na\q@u{h}nu ma\q@u{h}roomoon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmccxcix{Q\q@u{a}la awsa\q@u{t}uhum alam aqul lakum lawl\q@u{a} tusabbi\q@u{h}oon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmccc{Q\q@u{a}loo sub\q@u{ha}na rabbin\q@u{a} inn\q@u{a} kunn\q@u{a} \q@i{\q@u{th}}\q@u{a}limeen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmccci{Faaqbala baAA\q@u{d}uhum AAal\q@u{a} baAA\q@u{d}in yatal\q@u{a}wamoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmcccii{Q\q@u{a}loo y\q@u{a} waylan\q@u{a} inn\q@u{a} kunn\q@u{a} \q@u{ta}gheen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmccciii{AAas\q@u{a} rabbun\q@u{a} an yubdilan\q@u{a} khayran minh\q@u{a} inn\q@u{a} il\q@u{a} rabbin\q@u{a} r\q@u{a}ghiboon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmccciv{Ka\q@u{tha}lika alAAa\q@u{tha}bu walaAAa\q@u{tha}bu al\q@u{a}khirati akbaru law k\q@u{a}noo yaAAlamoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmcccv{Inna lilmuttaqeena AAinda rabbihim jann\q@u{a}ti a\q@b{l}nnaAAeem\q@b{i}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmcccvi{AfanajAAalu almuslimeena ka\q@b{a}lmujrimeen\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmcccvii{M\q@u{a} lakum kayfa ta\q@u{h}kumoon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmcccviii{Am lakum kit\q@u{a}bun feehi tadrusoon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmcccix{Inna lakum feehi lam\q@u{a} takhayyaroon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmcccx{Am lakum aym\q@u{a}nun AAalayn\q@u{a} b\q@u{a}lighatun il\q@u{a} yawmi alqiy\q@u{a}mati inna lakum lam\q@u{a} ta\q@u{h}kumoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxi{Salhum ayyuhum bi\q@u{tha}lika zaAAeem\q@b{un}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxii{Am lahum shurak\q@u{a}o falyatoo bishurak\q@u{a}ihim in k\q@u{a}noo \q@u{sa}diqeen\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxiii{Yawma yukshafu AAan s\q@u{a}qin wayudAAawna il\q@u{a} a\q@b{l}ssujoodi fal\q@u{a} yasta\q@u{t}eeAAoon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxiv{Kh\q@u{a}shiAAatan ab\q@u{sa}ruhum tarhaquhum \q@u{th}illatun waqad k\q@u{a}noo yudAAawna il\q@u{a} a\q@b{l}ssujoodi wahum s\q@u{a}limoon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxv{Fa\q@u{th}arnee waman yuka\q@u{thth}ibu bih\q@u{atha} al\q@u{h}adeethi sanastadrijuhum min \q@u{h}aythu l\q@u{a} yaAAlamoon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxvi{Waomlee lahum inna kaydee mateen\q@b{un}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxvii{Am tasaluhum ajran fahum min maghramin muthqaloon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxviii{Am AAindahumu alghaybu fahum yaktuboon\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxix{Fa\q@b{i}\q@u{s}bir li\q@u{h}ukmi rabbika wal\q@u{a} takun ka\q@u{sah}ibi al\q@u{h}ooti i\q@u{th} n\q@u{a}d\q@u{a} wahuwa mak\q@i{\q@u{th}}oom\q@b{un}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxx{Lawl\q@u{a} an tad\q@u{a}rakahu niAAmatun min rabbihi lanubi\q@u{th}a bi\q@b{a}lAAar\q@u{a}i wahuwa ma\q@u{th}moom\q@b{un}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxi{Fa\q@b{i}jtab\q@u{a}hu rabbuhu fajaAAalahu mina a\q@b{l}\q@u{ssa}li\q@u{h}een\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxii{Wain yak\q@u{a}du alla\q@u{th}eena kafaroo layuzliqoonaka biab\q@u{sa}rihim lamm\q@u{a} samiAAoo a\q@b{l}\q@u{thth}ikra wayaqooloona innahu lamajnoon\q@b{un}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxiii{Wam\q@u{a} huwa ill\q@u{a} \q@u{th}ikrun lilAA\q@u{a}lameen\q@b{a}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxiv{\basmalahlt Al\q@u{ha}qqa\q@b{tu}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxv{M\q@u{a} al\q@u{ha}qqa\q@b{tu}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxvi{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} al\q@u{ha}qqa\q@b{tu}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxvii{Ka\q@u{thth}abat thamoodu waAA\q@u{a}dun bi\q@b{a}lq\q@u{a}riAAa\q@b{ti}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxviii{Faamm\q@u{a} thamoodu faohlikoo bi\q@b{al}\q@u{tta}ghiya\q@b{ti}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxix{Waamm\q@u{a} AA\q@u{a}dun faohlikoo biree\q@u{h}in \q@u{s}ar\q@u{s}arin AA\q@u{a}tiya\q@b{tin}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxx{Sakhkharah\q@u{a} AAalayhim sabAAa lay\q@u{a}lin watham\q@u{a}niyata ayy\q@u{a}min \q@u{h}usooman fatar\q@u{a} alqawma feeh\q@u{a} \q@u{s}arAA\q@u{a} kaannahum aAAj\q@u{a}zu nakhlin kh\q@u{a}wiya\q@b{tun}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxxi{Fahal tar\q@u{a} lahum min b\q@u{a}qiya\q@b{tin}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxxii{Waj\q@u{a}a firAAawnu waman qablahu wa\q@b{a}lmutafik\q@u{a}tu bi\q@b{a}lkh\q@u{at}ia\q@b{ti}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxxiii{FaAAa\q@u{s}aw rasoola rabbihim faakha\q@u{th}ahum akh\q@u{th}atan r\q@u{a}biya\q@b{tan}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxxiv{Inn\q@u{a} lamm\q@u{a} \q@u{t}agh\q@u{a} alm\q@u{a}o \q@u{h}amaln\q@u{a}kum fee alj\q@u{a}riya\q@b{ti}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxxv{LinajAAalah\q@u{a} lakum ta\q@u{th}kiratan wataAAiyah\q@u{a} o\q@u{th}unun w\q@u{a}AAiya\q@b{tun}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxxvi{Fai\q@u{tha} nufikha fee a\q@b{l}\q@u{ss}oori nafkhatun w\q@u{ah}ida\q@b{tun}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxxvii{Wa\q@u{h}umilati alar\q@u{d}u wa\q@b{a}ljib\q@u{a}lu fadukkat\q@u{a} dakkatan w\q@u{ah}ida\q@b{tan}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxxviii{Fayawmai\q@u{th}in waqaAAati alw\q@u{a}qiAAa\q@b{tu}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxxxix{Wa\q@b{i}nshaqqati a\q@b{l}ssam\q@u{a}o fahiya yawmai\q@u{th}in w\q@u{a}hiya\q@b{tun}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxl{Wa\q@b{a}lmalaku AAal\q@u{a} arj\q@u{a}ih\q@u{a} waya\q@u{h}milu AAarsha rabbika fawqahum yawmai\q@u{th}in tham\q@u{a}niya\q@b{tun}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxli{Yawmai\q@u{th}in tuAAra\q@u{d}oona l\q@u{a} takhf\q@u{a} minkum kh\q@u{a}fiya\q@b{tun}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxlii{Faamm\q@u{a} man ootiya kit\q@u{a}bahu biyameenihi fayaqoolu h\q@u{a}omu iqraoo kit\q@u{a}biyah\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxliii{Innee \q@i{\q@u{th}}anantu annee mul\q@u{a}qin \q@u{h}is\q@u{a}biyah\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxliv{Fahuwa fee AAeeshatin r\q@u{ad}iya\q@b{tin}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxlv{Fee jannatin AA\q@u{a}liya\q@b{tin}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxlvi{Qu\q@u{t}oofuh\q@u{a} d\q@u{a}niya\q@b{tun}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxlvii{Kuloo wa\q@b{i}shraboo haneean bim\q@u{a} aslaftum fee alayy\q@u{a}mi alkh\q@u{a}liya\q@b{ti}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxlviii{Waamm\q@u{a} man ootiya kit\q@u{a}bahu bishim\q@u{a}lihi fayaqoolu y\q@u{a} laytanee lam oota kit\q@u{a}biyah\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxlix{Walam adri m\q@u{a} \q@u{h}is\q@u{a}biyah\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmcccl{Y\q@u{a} laytah\q@u{a} k\q@u{a}nati alq\q@u{ad}iya\q@b{tu}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmcccli{M\q@u{a} aghn\q@u{a} AAannee m\q@u{a}liyah\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmccclii{Halaka AAannee sul\q@u{ta}niyah\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmcccliii{Khu\q@u{th}oohu faghullooh\q@b{u}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmcccliv{Thumma alja\q@u{h}eema \q@u{s}allooh\q@b{u}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmccclv{Thumma fee silsilatin \q@u{th}arAAuh\q@u{a} sabAAoona \q@u{th}ir\q@u{a}AAan fa\q@b{o}slukooh\q@b{u}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmccclvi{Innahu k\q@u{a}na l\q@u{a} yuminu bi\q@b{A}ll\q@u{a}hi alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmccclvii{Wal\q@u{a} ya\q@u{h}u\q@u{dd}u AAal\q@u{a} \q@u{t}aAA\q@u{a}mi almiskeen\q@b{i}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmccclviii{Falaysa lahu alyawma h\q@u{a}hun\q@u{a} \q@u{h}ameem\q@b{un}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmccclix{Wal\q@u{a} \q@u{t}aAA\q@u{a}mun ill\q@u{a} min ghisleen\q@b{in}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmccclx{L\q@u{a} yakuluhu ill\q@u{a} alkh\q@u{at}ioon\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxi{Fal\q@u{a} oqsimu bim\q@u{a} tub\q@u{s}iroon\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxii{Wam\q@u{a} l\q@u{a} tub\q@u{s}iroon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxiii{Innahu laqawlu rasoolin kareem\q@b{in}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxiv{Wam\q@u{a} huwa biqawli sh\q@u{a}AAirin qaleelan m\q@u{a} tuminoon\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxv{Wal\q@u{a} biqawli k\q@u{a}hinin qaleelan m\q@u{a} ta\q@u{th}akkaroon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxvi{Tanzeelun min rabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxvii{Walaw taqawwala AAalayn\q@u{a} baAA\q@u{d}a alaq\q@u{a}weel\q@b{i}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxviii{Laakha\q@u{th}n\q@u{a} minhu bi\q@b{a}lyameen\q@b{i}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxix{Thumma laqa\q@u{t}aAAn\q@u{a} minhu alwateen\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxx{Fam\q@u{a} minkum min a\q@u{h}adin AAanhu \q@u{ha}jizeen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxi{Wainnahu lata\q@u{th}kiratun lilmuttaqeen\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxii{Wainn\q@u{a} lanaAAlamu anna minkum muka\q@u{thth}ibeen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxiii{Wainnahu la\q@u{h}asratun AAal\q@u{a} alk\q@u{a}fireen\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxiv{Wainnahu la\q@u{h}aqqu alyaqeen\q@b{i}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxv{Fasabbi\q@u{h} bi\q@b{i}smi rabbika alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxvi{\basmalahlt Saala s\q@u{a}ilun biAAa\q@u{tha}bin w\q@u{a}qiAA\q@b{in}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxvii{Lilk\q@u{a}fireena laysa lahu d\q@u{a}fiAA\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxviii{Mina All\q@u{a}hi \q@u{th}ee almaAA\q@u{a}rij\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxix{TaAAruju almal\q@u{a}ikatu wa\q@b{al}rroo\q@u{h}u ilayhi fee yawmin k\q@u{a}na miqd\q@u{a}ruhu khamseena alfa sana\q@b{tin}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxx{Fa\q@b{i}\q@u{s}bir \q@u{s}abran jameel\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxxi{Innahum yarawnahu baAAeed\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxxii{Wanar\q@u{a}hu qareeb\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxxiii{Yawma takoonu a\q@b{l}ssam\q@u{a}o ka\q@b{a}lmuhl\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxxiv{Watakoonu aljib\q@u{a}lu ka\q@b{a}lAAihn\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxxv{Wal\q@u{a} yasalu \q@u{h}ameemun \q@u{h}ameem\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxxvi{Yuba\q@u{ss}aroonahum yawaddu almujrimu law yaftadee min AAa\q@u{tha}bi yawmii\q@u{th}in bibaneeh\q@b{i}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxxvii{Wa\q@u{sah}ibatihi waakheeh\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxxviii{Wafa\q@u{s}eelatihi allatee tuweeh\q@b{i}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmccclxxxix{Waman fee alar\q@u{d}i jameeAAan thumma yunjeeh\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxc{Kall\q@u{a} innah\q@u{a} la\q@i{\q@u{th}}\q@u{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxci{Nazz\q@u{a}AAatan li\q@b{l}shshaw\q@u{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxcii{TadAAoo man adbara watawall\q@u{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxciii{WajamaAAa faawAA\q@u{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxciv{Inna alins\q@u{a}na khuliqa halooAA\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxcv{I\q@u{tha} massahu a\q@b{l}shsharru jazooAA\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxcvi{Wai\q@u{tha} massahu alkhayru manooAA\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxcvii{Ill\q@u{a} almu\q@u{s}alleen\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxcviii{Alla\q@u{th}eena hum AAal\q@u{a} \q@u{s}al\q@u{a}tihim d\q@u{a}imoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmcccxcix{Wa\q@b{a}lla\q@u{th}eena fee amw\q@u{a}lihim \q@u{h}aqqun maAAloom\q@b{un}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmcd{Li\q@b{l}ss\q@u{a}ili wa\q@b{a}lma\q@u{h}room\q@b{i}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmcdi{Wa\q@b{a}lla\q@u{th}eena yu\q@u{s}addiqoona biyawmi a\q@b{l}ddeen\q@b{i}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmcdii{Wa\q@b{a}lla\q@u{th}eena hum min AAa\q@u{tha}bi rabbihim mushfiqoon\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmcdiii{Inna AAa\q@u{tha}ba rabbihim ghayru mamoon\q@b{in}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmcdiv{Wa\q@b{a}lla\q@u{th}eena hum lifuroojihim \q@u{ha}fi\q@i{\q@u{th}}oon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmcdv{Ill\q@u{a} AAal\q@u{a} azw\q@u{a}jihim aw m\q@u{a} malakat aym\q@u{a}nuhum fainnahum ghayru maloomeen\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmcdvi{Famani ibtagh\q@u{a} war\q@u{a}a \q@u{tha}lika faol\q@u{a}ika humu alAA\q@u{a}doon\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmcdvii{Wa\q@b{a}lla\q@u{th}eena hum liam\q@u{a}n\q@u{a}tihim waAAahdihim r\q@u{a}AAoon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmcdviii{Wa\q@b{a}lla\q@u{th}eena hum bishah\q@u{a}d\q@u{a}tihim q\q@u{a}imoon\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmcdix{Wa\q@b{a}lla\q@u{th}eena hum AAal\q@u{a} \q@u{s}al\q@u{a}tihim yu\q@u{ha}fi\q@i{\q@u{th}}oon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmcdx{Ol\q@u{a}ika fee jann\q@u{a}tin mukramoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxi{Fam\q@u{a}li alla\q@u{th}eena kafaroo qibalaka muh\q@u{t}iAAeen\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxii{AAani alyameeni waAAani a\q@b{l}shshim\q@u{a}li AAizeen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxiii{Aya\q@u{t}maAAu kullu imriin minhum an yudkhala jannata naAAeem\q@b{in}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxiv{Kall\q@u{a} inn\q@u{a} khalaqn\q@u{a}hum mimm\q@u{a} yaAAlamoon\q@b{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxv{Fal\q@u{a} oqsimu birabbi almash\q@u{a}riqi wa\q@b{a}lmagh\q@u{a}ribi inn\q@u{a} laq\q@u{a}diroon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxvi{AAal\q@u{a} an nubaddila khayran minhum wam\q@u{a} na\q@u{h}nu bimasbooqeen\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxvii{Fa\q@u{th}arhum yakhoo\q@u{d}oo wayalAAaboo \q@u{h}att\q@u{a} yul\q@u{a}qoo yawmahumu alla\q@u{th}ee yooAAadoon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxviii{Yawma yakhrujoona mina alajd\q@u{a}thi sir\q@u{a}AAan kaannahum il\q@u{a} nu\q@u{s}ubin yoofi\q@u{d}oon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxix{Kh\q@u{a}shiAAatan ab\q@u{sa}ruhum tarhaquhum \q@u{th}illatun \q@u{tha}lika alyawmu alla\q@u{th}ee k\q@u{a}noo yooAAadoon\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxx{\basmalahlt Inn\q@u{a} arsaln\q@u{a} noo\q@u{h}an il\q@u{a} qawmihi an an\q@u{th}ir qawmaka min qabli an yatiyahum AAa\q@u{tha}bun aleem\q@b{un}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxi{Q\q@u{a}la y\q@u{a} qawmi innee lakum na\q@u{th}eerun mubeen\q@b{un}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxii{Ani oAAbudoo All\q@u{a}ha wa\q@b{i}ttaqoohu waa\q@u{t}eeAAoon\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxiii{Yaghfir lakum min \q@u{th}unoobikum wayuakhkhirkum il\q@u{a} ajalin musamman inna ajala All\q@u{a}hi i\q@u{tha} j\q@u{a}a l\q@u{a} yuakhkharu law kuntum taAAlamoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxiv{Q\q@u{a}la rabbi innee daAAawtu qawmee laylan wanah\q@u{a}r\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxv{Falam yazidhum duAA\q@u{a}ee ill\q@u{a} fir\q@u{a}r\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxvi{Wainnee kullam\q@u{a} daAAawtuhum litaghfira lahum jaAAaloo a\q@u{sa}biAAahum fee \q@u{atha}nihim wa\q@b{i}staghshaw thiy\q@u{a}bahum waa\q@u{s}arroo wa\q@b{i}stakbaroo istikb\q@u{a}r\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxvii{Thumma innee daAAawtuhum jih\q@u{a}r\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxviii{Thumma innee aAAlantu lahum waasrartu lahum isr\q@u{a}r\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxix{Faqultu istaghfiroo rabbakum innahu k\q@u{a}na ghaff\q@u{a}r\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxx{Yursili a\q@b{l}ssam\q@u{a}a AAalaykum midr\q@u{a}r\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxxi{Wayumdidkum biamw\q@u{a}lin wabaneena wayajAAal lakum jann\q@u{a}tin wayajAAal lakum anh\q@u{a}r\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxxii{M\q@u{a} lakum l\q@u{a} tarjoona lill\q@u{a}hi waq\q@u{a}r\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxxiii{Waqad khalaqakum a\q@u{t}w\q@u{a}r\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxxiv{Alam taraw kayfa khalaqa All\q@u{a}hu sabAAa sam\q@u{a}w\q@u{a}tin \q@u{t}ib\q@u{a}q\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxxv{WajaAAala alqamara feehinna nooran wajaAAala a\q@b{l}shshamsa sir\q@u{a}j\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxxvi{Wa\q@b{A}ll\q@u{a}hu anbatakum mina alar\q@u{d}i nab\q@u{a}t\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxxvii{Thumma yuAAeedukum feeh\q@u{a} wayukhrijukum ikhr\q@u{a}j\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxxviii{Wa\q@b{A}ll\q@u{a}hu jaAAala lakumu alar\q@u{d}a bis\q@u{ata}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxxxix{Litaslukoo minh\q@u{a} subulan fij\q@u{a}j\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxl{Q\q@u{a}la noo\q@u{h}un rabbi innahum AAa\q@u{s}awnee wa\q@b{i}ttabaAAoo man lam yazidhu m\q@u{a}luhu wawaladuhu ill\q@u{a} khas\q@u{a}r\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxli{Wamakaroo makran kubb\q@u{a}r\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxlii{Waq\q@u{a}loo l\q@u{a} ta\q@u{th}arunna \q@u{a}lihatakum wal\q@u{a} ta\q@u{th}arunna waddan wal\q@u{a} suw\q@u{a}AAan wal\q@u{a} yaghootha wayaAAooqa wanasr\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxliii{Waqad a\q@u{d}alloo katheeran wal\q@u{a} tazidi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena ill\q@u{a} \q@u{d}al\q@u{a}l\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxliv{Mimm\q@u{a} kha\q@u{t}ee\q@u{a}tihim oghriqoo faodkhiloo n\q@u{a}ran falam yajidoo lahum min dooni All\q@u{a}hi an\q@u{sa}r\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxlv{Waq\q@u{a}la noo\q@u{h}un rabbi l\q@u{a} ta\q@u{th}ar AAal\q@u{a} alar\q@u{d}i mina alk\q@u{a}fireena dayy\q@u{a}r\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxlvi{Innaka in ta\q@u{th}arhum yu\q@u{d}illoo AAib\q@u{a}daka wal\q@u{a} yalidoo ill\q@u{a} f\q@u{a}jiran kaff\q@u{a}r\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxlvii{Rabbi ighfir lee waliw\q@u{a}lidayya waliman dakhala baytiya muminan walilmumineena wa\q@b{a}lmumin\q@u{a}ti wal\q@u{a} tazidi a\q@b{l}\q@i{\q@u{thth}}\q@u{a}limeena ill\q@u{a} tab\q@u{a}ran\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxlviii{\basmalahlt Qul oo\q@u{h}iya ilayya annahu istamaAAa nafarun mina aljinni faq\q@u{a}loo inn\q@u{a} samiAAn\q@u{a} qur\q@u{a}nan AAajab\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxlix{Yahdee il\q@u{a} a\q@b{l}rrushdi fa\q@u{a}mann\q@u{a} bihi walan nushrika birabbin\q@u{a} a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcdl{Waannahu taAA\q@u{a}l\q@u{a} jaddu rabbin\q@u{a} m\q@u{a} ittakha\q@u{th}a \q@u{sah}ibatan wal\q@u{a} walad\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcdli{Waannahu k\q@u{a}na yaqoolu safeehun\q@u{a} AAal\q@u{a} All\q@u{a}hi sha\q@u{t}a\q@u{ta}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlii{Waann\q@u{a} \q@i{\q@u{th}}anann\q@u{a} an lan taqoola alinsu wa\q@b{a}ljinnu AAal\q@u{a} All\q@u{a}hi ka\q@u{th}ib\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcdliii{Waannahu k\q@u{a}na rij\q@u{a}lun mina alinsi yaAAoo\q@u{th}oona birij\q@u{a}lin mina aljinni faz\q@u{a}doohum rahaq\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcdliv{Waannahum \q@i{\q@u{th}}annoo kam\q@u{a} \q@i{\q@u{th}}anantum an lan yabAAatha All\q@u{a}hu a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlv{Waann\q@u{a} lamasn\q@u{a} a\q@b{l}ssam\q@u{a}a fawajadn\q@u{a}h\q@u{a} muliat \q@u{h}arasan shadeedan washuhub\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlvi{Waann\q@u{a} kunn\q@u{a} naqAAudu minh\q@u{a} maq\q@u{a}AAida li\q@b{l}ssamAAi faman yastamiAAi al\q@u{a}na yajid lahu shih\q@u{a}ban ra\q@u{s}ad\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlvii{Waann\q@u{a} l\q@u{a} nadree asharrun oreeda biman fee alar\q@u{d}i am ar\q@u{a}da bihim rabbuhum rashad\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlviii{Waann\q@u{a} minn\q@u{a} a\q@b{l}\q@u{ssa}li\q@u{h}oona waminn\q@u{a} doona \q@u{tha}lika kunn\q@u{a} \q@u{t}ar\q@u{a}iqa qidad\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlix{Wann\q@u{a} \q@i{\q@u{th}}anann\q@u{a} an lan nuAAjiza All\q@u{a}ha fee alar\q@u{d}i walan nuAAjizahu harab\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlx{Waann\q@u{a} lamm\q@u{a} samiAAn\q@u{a} alhud\q@u{a} \q@u{a}mann\q@u{a} bihi faman yumin birabbihi fal\q@u{a} yakh\q@u{a}fu bakhsan wal\q@u{a} rahaq\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxi{Waann\q@u{a} minn\q@u{a} almuslimoona waminn\q@u{a} alq\q@u{a}si\q@u{t}oona faman aslama faol\q@u{a}ika ta\q@u{h}arraw rashad\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxii{Waam\q@u{a} alq\q@u{a}si\q@u{t}oona fak\q@u{a}noo lijahannama \q@u{h}a\q@u{t}ab\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxiii{Waallawi istaq\q@u{a}moo AAal\q@u{a} a\q@b{l}\q@u{tt}areeqati laasqayn\q@u{a}hum m\q@u{a}an ghadaq\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxiv{Linaftinahum feehi waman yuAAri\q@u{d} AAan \q@u{th}ikri rabbihi yaslukhu AAa\q@u{tha}ban \q@u{s}aAAad\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxv{Waanna almas\q@u{a}jida lill\q@u{a}hi fal\q@u{a} tadAAoo maAAa All\q@u{a}hi a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxvi{Waannahu lamm\q@u{a} q\q@u{a}ma AAabdu All\q@u{a}hi yadAAoohu k\q@u{a}doo yakoonoona AAalayhi libad\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxvii{Qul innam\q@u{a} adAAoo rabbee wal\q@u{a} oshriku bihi a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxviii{Qul innee l\q@u{a} amliku lakum \q@u{d}arran wal\q@u{a} rashad\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxix{Qul innee lan yujeeranee mina All\q@u{a}hi a\q@u{h}adun walan ajida min doonihi multa\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxx{Ill\q@u{a} bal\q@u{a}ghan mina All\q@u{a}hi waris\q@u{a}l\q@u{a}tihi waman yaAA\q@u{s}i All\q@u{a}ha warasoolahu fainna lahu n\q@u{a}ra jahannama kh\q@u{a}lideena feeh\q@u{a} abad\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxi{\q@u{H}att\q@u{a} i\q@u{tha} raaw m\q@u{a} yooAAadoona fasayaAAlamoona man a\q@u{d}AAafu n\q@u{as}iran waaqallu AAadad\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxii{Qul in adree aqareebun m\q@u{a} tooAAadoona am yajAAalu lahu rabbee amad\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxiii{AA\q@u{a}limu alghaybi fal\q@u{a} yu\q@i{\q@u{th}}hiru AAal\q@u{a} ghaybihi a\q@u{h}ad\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxiv{Ill\q@u{a} mani irta\q@u{da} min rasoolin fainnahu yasluku min bayni yadayhi wamin khalfihi ra\q@u{s}ad\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxv{LiyaAAlama an qad ablaghoo ris\q@u{a}l\q@u{a}ti rabbihim waa\q@u{hat}a bim\q@u{a} ladayhim waa\q@u{hsa} kulla shayin AAadad\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxvi{\basmalahlt Y\q@u{a} ayyuh\q@u{a} almuzzammil\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxvii{Qumi allayla ill\q@u{a} qaleel\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxviii{Ni\q@u{s}fahu awi onqu\q@u{s} minhu qaleel\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxix{Aw zid AAalayhi warattili alqur\q@u{a}na tarteel\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxx{Inn\q@u{a} sanulqee AAalayka qawlan thaqeel\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxxi{Inna n\q@u{a}shiata allayli hiya ashaddu wa\q@u{t}an waaqwamu qeel\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxxii{Inna laka fee a\q@b{l}nnah\q@u{a}ri sab\q@u{h}an \q@u{t}aweel\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxxiii{Wa\q@b{o}\q@u{th}kuri isma rabbika watabattal ilayhi tabteel\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxxiv{Rabbu almashriqi wa\q@b{a}lmaghribi l\q@u{a} il\q@u{a}ha ill\q@u{a} huwa fa\q@b{i}ttakhi\q@u{th}hu wakeel\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxxv{Wa\q@b{i}\q@u{s}bir AAal\q@u{a} m\q@u{a} yaqooloona wa\q@b{o}hjurhum hajran jameel\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxxvi{Wa\q@u{th}arnee wa\q@b{a}lmuka\q@u{thth}ibeena olee a\q@b{l}nnaAAmati wamahhilhum qaleel\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxxvii{Inna ladayn\q@u{a} ank\q@u{a}lan waja\q@u{h}eem\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxxviii{Wa\q@u{t}aAA\q@u{a}man \q@u{tha} ghu\q@u{ss}atin waAAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcdlxxxix{Yawma tarjufu alar\q@u{d}u wa\q@b{a}ljib\q@u{a}lu wak\q@u{a}nati aljib\q@u{a}lu katheeban maheel\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxc{Inn\q@u{a} arsaln\q@u{a} ilaykum rasoolan sh\q@u{a}hidan AAalaykum kam\q@u{a} arsaln\q@u{a} il\q@u{a} firAAawna rasool\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxci{FaAAa\q@u{sa} firAAawnu a\q@b{l}rrasoola faakha\q@u{th}n\q@u{a}hu akh\q@u{th}an wabeel\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxcii{Fakayfa tattaqoona in kafartum yawman yajAAalu alwild\q@u{a}na sheeb\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxciii{A\q@b{l}ssam\q@u{a}o munfa\q@u{t}irun bihi k\q@u{a}na waAAduhu mafAAool\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxciv{Inna h\q@u{ath}ihi ta\q@u{th}kiratun faman sh\q@u{a}a ittakha\q@u{th}a il\q@u{a} rabbihi sabeel\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxcv{Inna rabbaka yaAAlamu annaka taqoomu adn\q@u{a} min thuluthayi allayli wani\q@u{s}fahu wathuluthahu wa\q@u{ta}ifatun mina alla\q@u{th}eena maAAaka wa\q@b{A}ll\q@u{a}hu yuqaddiru allayla wa\q@b{al}nnah\q@u{a}ra AAalima an lan tu\q@u{hs}oohu fat\q@u{a}ba AAalaykum fa\q@b{i}qraoo m\q@u{a} tayassara mina alqur\q@u{a}ni AAalima an sayakoonu minkum mar\q@u{da} wa\q@u{a}kharoona ya\q@u{d}riboona fee alar\q@u{d}i yabtaghoona min fa\q@u{d}li All\q@u{a}hi wa\q@u{a}kharoona yuq\q@u{a}tiloona fee sabeeli All\q@u{a}hi fa\q@b{i}qraoo m\q@u{a} tayassara minhu waaqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wa\q@u{a}too a\q@b{l}zzak\q@u{a}ta waaqri\q@u{d}oo All\q@u{a}ha qar\q@u{d}an \q@u{h}asanan wam\q@u{a} tuqaddimoo lianfusikum min khayrin tajidoohu AAinda All\q@u{a}hi huwa khayran waaAA\q@i{\q@u{th}}ama ajran wa\q@b{i}staghfiroo All\q@u{a}ha inna All\q@u{a}ha ghafoorun ra\q@u{h}eem\q@b{un}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxcvi{\basmalahlt Y\q@u{a} ayyuh\q@u{a} almuddaththir\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxcvii{Qum faan\q@u{th}ir\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxcviii{Warabbaka fakabbir\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcdxcix{Wathiy\q@u{a}baka fa\q@u{t}ahhir\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmd{Wa\q@b{al}rrujza fa\q@b{o}hjur\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdi{Wal\q@u{a} tamnun tastakthir\q@b{u}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdii{Walirabbika fa\q@b{i}\q@u{s}bir\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdiii{Fai\q@u{tha} nuqira fee a\q@b{l}nn\q@u{a}qoor\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdiv{Fa\q@u{thal}ika yawmai\q@u{th}in yawmun AAaseer\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdv{AAal\q@u{a} alk\q@u{a}fireena ghayru yaseer\q@b{in}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdvi{\q@u{Th}arnee waman khalaqtu wa\q@u{h}eed\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdvii{WajaAAaltu lahu m\q@u{a}lan mamdood\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdviii{Wabaneena shuhood\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdix{Wamahhadtu lahu tamheed\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdx{Thumma ya\q@u{t}maAAu an azeed\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdxi{Kall\q@u{a} innahu k\q@u{a}na li\q@u{a}y\q@u{a}tin\q@u{a} AAaneed\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdxii{Saorhiquhu \q@u{s}aAAood\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdxiii{Innahu fakkara waqaddar\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdxiv{Faqutila kayfa qaddar\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdxv{Thumma qutila kayfa qaddar\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmdxvi{Thumma na\q@i{\q@u{th}}ar\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmdxvii{Thumma AAabasa wabasar\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmdxviii{Thumma adbara wa\q@b{i}stakbar\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmdxix{Faq\q@u{a}la in h\q@u{atha} ill\q@u{a} si\q@u{h}run yuthar\q@b{u}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmdxx{In h\q@u{atha} ill\q@u{a} qawlu albashar\q@b{i}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxi{Sao\q@u{s}leehi saqar\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxii{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} saqar\q@b{u}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxiii{L\q@u{a} tubqee wal\q@u{a} ta\q@u{th}ar\q@b{u}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxiv{Laww\q@u{ah}atun lilbashar\q@b{i}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxv{AAalayh\q@u{a} tisAAata AAashar\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxvi{Wam\q@u{a} jaAAaln\q@u{a} a\q@u{s}\q@u{ha}ba a\q@b{l}nn\q@u{a}ri ill\q@u{a} mal\q@u{a}ikatan wam\q@u{a} jaAAaln\q@u{a} AAiddatahum ill\q@u{a} fitnatan lilla\q@u{th}eena kafaroo liyastayqina alla\q@u{th}eena ootoo alkit\q@u{a}ba wayazd\q@u{a}da alla\q@u{th}eena \q@u{a}manoo eem\q@u{a}nan wal\q@u{a} yart\q@u{a}ba alla\q@u{th}eena ootoo alkit\q@u{a}ba wa\q@b{a}lmuminoona waliyaqoola alla\q@u{th}eena fee quloobihim mara\q@u{d}un wa\q@b{a}lk\q@u{a}firoona m\q@u{atha} ar\q@u{a}da All\q@u{a}hu bih\q@u{atha} mathalan ka\q@u{tha}lika yu\q@u{d}illu All\q@u{a}hu man yash\q@u{a}o wayahdee man yash\q@u{a}o wam\q@u{a} yaAAlamu junooda rabbika ill\q@u{a} huwa wam\q@u{a} hiya ill\q@u{a} \q@u{th}ikr\q@u{a} lilbashar\q@b{i}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxvii{Kall\q@u{a} wa\q@b{a}lqamar\q@b{i}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxviii{Wa\q@b{a}llayli i\q@u{th} adbar\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxix{Wa\q@b{al}\q@u{ss}ub\q@u{h}i i\q@u{tha} asfar\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxx{Innah\q@u{a} lai\q@u{h}d\q@u{a} alkubar\q@b{i}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxxi{Na\q@u{th}eeran lilbashar\q@b{i}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxxii{Liman sh\q@u{a}a minkum an yataqaddama aw yataakhkhar\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxxiii{Kullu nafsin bim\q@u{a} kasabat raheena\q@b{tun}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxxiv{Ill\q@u{a} a\q@u{s}\q@u{ha}ba alyameen\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxxv{Fee jann\q@u{a}tin yatas\q@u{a}aloon\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxxvi{AAani almujrimeen\q@b{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxxvii{M\q@u{a} salakakum fee saqar\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxxviii{Q\q@u{a}loo lam naku mina almu\q@u{s}alleen\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmmdxxxix{Walam naku nu\q@u{t}AAimu almiskeen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmmdxl{Wakunn\q@u{a} nakhoo\q@u{d}u maAAa alkh\q@u{a}i\q@u{d}een\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmmdxli{Wakunn\q@u{a} nuka\q@u{thth}ibu biyawmi a\q@b{l}ddeen\q@b{i}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmmdxlii{\q@u{H}att\q@u{a} at\q@u{a}n\q@u{a} alyaqeen\q@b{u}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmmdxliii{Fam\q@u{a} tanfaAAuhum shaf\q@u{a}AAatu a\q@b{l}shsh\q@u{a}fiAAeen\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmmdxliv{Fam\q@u{a} lahum AAani a\q@b{l}tta\q@u{th}kirati muAAri\q@u{d}een\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmmdxlv{Kaannahum \q@u{h}umurun mustanfira\q@b{tun}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmmdxlvi{Farrat min qaswara\q@b{tin}\qt@no{(51)}}
\qt@newcmd\qurantrans@lt@mmmmmdxlvii{Bal yureedu kullu imriin minhum an yut\q@u{a} \q@u{s}u\q@u{h}ufan munashshara\q@b{tan}\qt@no{(52)}}
\qt@newcmd\qurantrans@lt@mmmmmdxlviii{Kall\q@u{a} bal l\q@u{a} yakh\q@u{a}foona al\q@u{a}khira\q@b{ta}\qt@no{(53)}}
\qt@newcmd\qurantrans@lt@mmmmmdxlix{Kall\q@u{a} innahu ta\q@u{th}kira\q@b{tun}\qt@no{(54)}}
\qt@newcmd\qurantrans@lt@mmmmmdl{Faman sh\q@u{a}a \q@u{th}akarah\q@b{u}\qt@no{(55)}}
\qt@newcmd\qurantrans@lt@mmmmmdli{Wam\q@u{a} ya\q@u{th}kuroona ill\q@u{a} an yash\q@u{a}a All\q@u{a}hu huwa ahlu a\q@b{l}ttaqw\q@u{a} waahlu almaghfirat\q@b{i}\qt@no{(56)}}
\qt@newcmd\qurantrans@lt@mmmmmdlii{\basmalahlt L\q@u{a} oqsimu biyawmi alqiy\q@u{a}mat\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdliii{Wal\q@u{a} oqsimu bi\q@b{al}nnafsi allaww\q@u{a}mat\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdliv{Aya\q@u{h}sabu alins\q@u{a}nu allan najmaAAa AAi\q@i{\q@u{th}}\q@u{a}mah\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdlv{Bal\q@u{a} q\q@u{a}direena AAal\q@u{a} an nusawwiya ban\q@u{a}nah\q@b{u}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdlvi{Bal yureedu alins\q@u{a}nu liyafjura am\q@u{a}mah\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdlvii{Yasalu ayy\q@u{a}na yawmu alqiy\q@u{a}ma\q@b{ti}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdlviii{Fai\q@u{tha} bariqa alba\q@u{s}ar\q@b{u}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdlix{Wakhasafa alqamar\q@b{u}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdlx{WajumiAAa a\q@b{l}shshamsu wa\q@b{a}lqamar\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxi{Yaqoolu alins\q@u{a}nu yawmai\q@u{th}in ayna almafar\q@b{ru}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxii{Kall\q@u{a} l\q@u{a} wazar\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxiii{Il\q@u{a} rabbika yawmai\q@u{th}in almustaqar\q@b{ru}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxiv{Yunabbao alins\q@u{a}nu yawmai\q@u{th}in bim\q@u{a} qaddama waakhkhar\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxv{Bali alins\q@u{a}nu AAal\q@u{a} nafsihi ba\q@u{s}eera\q@b{tun}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxvi{Walaw alq\q@u{a} maAA\q@u{ath}eerah\q@b{u}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxvii{L\q@u{a} tu\q@u{h}arrik bihi lis\q@u{a}naka litaAAjala bih\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxviii{Inna AAalayn\q@u{a} jamAAahu waqur\q@u{a}nah\q@b{u}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxix{Fai\q@u{tha} qaran\q@u{a}hu fa\q@b{i}ttabiAA qur\q@u{a}nah\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxx{Thumma inna AAalayn\q@u{a} bay\q@u{a}nah\q@b{u}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxi{Kall\q@u{a} bal tu\q@u{h}ibboona alAA\q@u{a}jila\q@b{ta}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxii{Wata\q@u{th}aroona al\q@u{a}khira\q@b{ta}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxiii{Wujoohun yawmai\q@u{th}in n\q@u{ad}ira\q@b{tun}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxiv{Il\q@u{a} rabbih\q@u{a} n\q@u{a}\q@i{\q@u{th}}ira\q@b{tun}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxv{Wawujoohun yawmai\q@u{th}in b\q@u{a}sira\q@b{tun}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxvi{Ta\q@i{\q@u{th}}unnu an yufAAala bih\q@u{a} f\q@u{a}qira\q@b{tun}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxvii{Kall\q@u{a} i\q@u{tha} balaghati a\q@b{l}ttar\q@u{a}qiy\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxviii{Waqeela man r\q@u{a}q\q@b{in}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxix{Wa\q@i{\q@u{th}}anna annahu alfir\q@u{a}q\q@b{u}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxx{Wa\q@b{i}ltaffati a\q@b{l}ss\q@u{a}qu bi\q@b{a}lss\q@u{a}q\q@b{i}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxxi{Il\q@u{a} rabbika yawmai\q@u{th}in almas\q@u{a}q\q@b{u}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxxii{Fal\q@u{a} \q@u{s}addaqa wal\q@u{a} \q@u{s}all\q@u{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxxiii{Wal\q@u{a}kin ka\q@u{thth}aba watawall\q@u{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxxiv{Thumma \q@u{th}ahaba il\q@u{a} ahlihi yatama\q@u{tta}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxxv{Awl\q@u{a} laka faawl\q@u{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxxvi{Thumma awl\q@u{a} laka faawl\q@u{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxxvii{Aya\q@u{h}sabu alins\q@u{a}nu an yutraka sud\q@u{a}\q@b{n}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxxviii{Alam yaku nu\q@u{t}fatan min manayyin yumn\q@u{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmdlxxxix{Thumma k\q@u{a}na AAalaqatan fakhalaqa fasaww\q@u{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmdxc{FajaAAala minhu a\q@b{l}zzawjayni a\q@b{l}\q@u{thth}akara wa\q@b{a}lonth\q@u{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmdxci{Alaysa \q@u{tha}lika biq\q@u{a}dirin AAal\q@u{a} an yu\q@u{h}yiya almawt\q@u{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmdxcii{\basmalahlt Hal at\q@u{a} AAal\q@u{a} alins\q@u{a}ni \q@u{h}eenun mina a\q@b{l}ddahri lam yakun shayan ma\q@u{th}koor\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdxciii{Inn\q@u{a} khalaqn\q@u{a} alins\q@u{a}na min nu\q@u{t}fatin amsh\q@u{a}jin nabtaleehi fajaAAaln\q@u{a}hu sameeAAan ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdxciv{Inn\q@u{a} hadayn\q@u{a}hu a\q@b{l}ssabeela imm\q@u{a} sh\q@u{a}kiran waimm\q@u{a} kafoor\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdxcv{Inn\q@u{a} aAAtadn\q@u{a} lilk\q@u{a}fireena sal\q@u{a}sila waaghl\q@u{a}lan wasaAAeer\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdxcvi{Inna alabr\q@u{a}ra yashraboona min kasin k\q@u{a}na miz\q@u{a}juh\q@u{a} k\q@u{a}foor\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdxcvii{AAaynan yashrabu bih\q@u{a} AAib\q@u{a}du All\q@u{a}hi yufajjiroonah\q@u{a} tafjeer\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdxcviii{Yoofoona bi\q@b{al}nna\q@u{th}ri wayakh\q@u{a}foona yawman k\q@u{a}na sharruhu musta\q@u{t}eer\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdxcix{Wayu\q@u{t}AAimona a\q@b{l}\q@u{tt}aAA\q@u{a}ma AAal\q@u{a} \q@u{h}ubbihi miskeenan wayateeman waaseer\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdc{Innam\q@u{a} nu\q@u{t}AAimukum liwajhi All\q@u{a}hi l\q@u{a} nureedu minkum jaz\q@u{a}an wal\q@u{a} shukoor\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdci{Inn\q@u{a} nakh\q@u{a}fu min rabbin\q@u{a} yawman AAaboosan qam\q@u{t}areer\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdcii{Fawaq\q@u{a}humu All\q@u{a}hu sharra \q@u{tha}lika alyawmi walaqq\q@u{a}hum na\q@u{d}ratan wasuroor\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdciii{Wajaz\q@u{a}hum bim\q@u{a} \q@u{s}abaroo jannatan wa\q@u{h}areer\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdciv{Muttakieena feeh\q@u{a} AAal\q@u{a} alar\q@u{a}iki l\q@u{a} yarawna feeh\q@u{a} shamsan wal\q@u{a} zamhareer\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdcv{Wad\q@u{a}niyatan AAalayhim \q@i{\q@u{th}}il\q@u{a}luh\q@u{a} wa\q@u{th}ullilat qu\q@u{t}oofuh\q@u{a} ta\q@u{th}leel\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdcvi{Wayu\q@u{ta}fu AAalayhim bi\q@u{a}niyatin min fi\q@u{dd}atin waakw\q@u{a}bin k\q@u{a}nat qaw\q@u{a}reer\q@u{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdcvii{Qaw\q@u{a}reera min fi\q@u{dd}atin qaddarooh\q@u{a} taqdeer\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdcviii{Wayusqawna feeh\q@u{a} kasan k\q@u{a}na miz\q@u{a}juh\q@u{a} zanjabeel\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdcix{AAaynan feeh\q@u{a} tusamm\q@u{a} salsabeel\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdcx{Waya\q@u{t}oofu AAalayhim wild\q@u{a}nun mukhalladoona i\q@u{tha} raaytahum \q@u{h}asibtahum luluan manthoor\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxi{Wai\q@u{tha} raayta thamma raayta naAAeeman wamulkan kabeer\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxii{AA\q@u{a}liyahum thiy\q@u{a}bu sundusin khu\q@u{d}run waistabraqun wa\q@u{h}ulloo as\q@u{a}wira min fi\q@u{dd}atin wasaq\q@u{a}hum rabbuhum shar\q@u{a}ban \q@u{t}ahoor\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxiii{Inna h\q@u{atha} k\q@u{a}na lakum jaz\q@u{a}an wak\q@u{a}na saAAyukum mashkoor\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxiv{Inn\q@u{a} na\q@u{h}nu nazzaln\q@u{a} AAalayka alqur\q@u{a}na tanzeel\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxv{Fa\q@b{i}\q@u{s}bir li\q@u{h}ukmi rabbika wal\q@u{a} tu\q@u{t}iAA minhum \q@u{a}thiman aw kafoor\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxvi{Wa\q@b{o}\q@u{th}kuri isma rabbika bukratan waa\q@u{s}eel\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxvii{Wamina allayli fa\q@b{o}sjud lahu wasabbi\q@u{h}hu laylan \q@u{t}aweel\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxviii{Inna h\q@u{a}ol\q@u{a}i yu\q@u{h}ibboona alAA\q@u{a}jilata waya\q@u{th}aroona war\q@u{a}ahum yawman thaqeel\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxix{Na\q@u{h}nu khalaqn\q@u{a}hum washadadn\q@u{a} asrahum wai\q@u{tha} shin\q@u{a} baddaln\q@u{a} amth\q@u{a}lahum tabdeel\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxx{Inna h\q@u{ath}ihi ta\q@u{th}kiratun faman sh\q@u{a}a ittakha\q@u{th}a il\q@u{a} rabbihi sabeel\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxi{Wam\q@u{a} tash\q@u{a}oona ill\q@u{a} an yash\q@u{a}a All\q@u{a}hu inna All\q@u{a}ha k\q@u{a}na AAaleeman \q@u{h}akeem\q@u{a}\q@b{n}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxii{Yudkhilu man yash\q@u{a}o fee ra\q@u{h}matihi wa\q@b{al}\q@i{\q@u{thth}}\q@u{a}limeena aAAadda lahum AAa\q@u{tha}ban aleem\q@u{a}\q@b{n}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxiii{\basmalahlt Wa\q@b{a}lmursal\q@u{a}ti AAurf\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxiv{Fa\q@b{a}lAA\q@u{as}if\q@u{a}ti AAa\q@u{s}f\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxv{Wa\q@b{al}nn\q@u{a}shir\q@u{a}ti nashr\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxvi{Fa\q@b{a}lf\q@u{a}riq\q@u{a}ti farq\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxvii{Fa\q@b{a}lmulqiy\q@u{a}ti \q@u{th}ikr\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxviii{AAu\q@u{th}ran aw nu\q@u{th}ra\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxix{Innam\q@u{a} tooAAadoona law\q@u{a}qiAA\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxx{Fai\q@u{tha} a\q@b{l}nnujoomu \q@u{t}umisat\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxxi{Wai\q@u{tha} a\q@b{l}ssam\q@u{a}o furijat\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxxii{Wai\q@u{tha} aljib\q@u{a}lu nusifat\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxxiii{Wai\q@u{tha} a\q@b{l}rrusulu oqqitat\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxxiv{Liayyi yawmin ojjilat\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxxv{Liyawmi alfa\q@u{s}l\q@b{i}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxxvi{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} yawmu alfa\q@u{s}l\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxxvii{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxxviii{Alam nuhliki alawwaleen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxxxix{Thumma nutbiAAuhumu al\q@u{a}khireen\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxl{Ka\q@u{tha}lika nafAAalu bi\q@b{a}lmujrimeen\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxli{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxlii{Alam nakhluqkum min m\q@u{a}in maheen\q@b{in}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxliii{FajaAAaln\q@u{a}hu fee qar\q@u{a}rin makeen\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxliv{Il\q@u{a} qadarin maAAloom\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxlv{Faqadarn\q@u{a} faniAAma alq\q@u{a}diroon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxlvi{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxlvii{Alam najAAali alar\q@u{d}a kif\q@u{a}t\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxlviii{A\q@u{h}y\q@u{a}an waamw\q@u{a}t\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxlix{WajaAAaln\q@u{a} feeh\q@u{a} raw\q@u{a}siya sh\q@u{a}mikh\q@u{a}tin waasqayn\q@u{a}kum m\q@u{a}an fur\q@u{a}t\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmdcl{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmdcli{In\q@u{t}aliqoo il\q@u{a} m\q@u{a} kuntum bihi tuka\q@u{thth}iboon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmdclii{In\q@u{t}aliqoo il\q@u{a} \q@i{\q@u{th}}illin \q@u{th}ee thal\q@u{a}thi shuAAab\q@b{in}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmdcliii{L\q@u{a} \q@i{\q@u{th}}aleelin wal\q@u{a} yughnee mina allahab\q@b{i}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmdcliv{Innah\q@u{a} tarmee bishararin ka\q@b{a}lqa\q@u{s}r\q@b{i}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmdclv{Kaannahu jim\q@u{a}latun \q@u{s}ufr\q@b{un}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmdclvi{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmdclvii{H\q@u{atha} yawmu l\q@u{a} yan\q@u{t}iqoon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmdclviii{Wal\q@u{a} yu\q@u{th}anu lahum fayaAAta\q@u{th}iroon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmdclix{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmdclx{H\q@u{atha} yawmu alfa\q@u{s}li jamaAAn\q@u{a}kum wa\q@b{a}lawwaleen\q@b{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxi{Fain k\q@u{a}na lakum kaydun fakeedoon\q@b{i}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxii{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxiii{Inna almuttaqeena fee \q@i{\q@u{th}}il\q@u{a}lin waAAuyoon\q@b{in}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxiv{Wafaw\q@u{a}kiha mimm\q@u{a} yashtahoon\q@b{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxv{Kuloo wa\q@b{i}shraboo haneean bim\q@u{a} kuntum taAAmaloon\q@b{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxvi{Inn\q@u{a} ka\q@u{tha}lika najzee almu\q@u{h}sineen\q@b{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxvii{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxviii{Kuloo watamattaAAoo qaleelan innakum mujrimoon\q@b{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxix{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(47)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxx{Wai\q@u{tha} qeela lahumu irkaAAoo l\q@u{a} yarkaAAoon\q@b{a}\qt@no{(48)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxi{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(49)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxii{Fabiayyi \q@u{h}adeethin baAAdahu yuminoon\q@b{a}\qt@no{(50)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxiii{\basmalahlt AAamma yatas\q@u{a}aloon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxiv{AAani a\q@b{l}nnabai alAAa\q@i{\q@u{th}}eem\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxv{Alla\q@u{th}ee hum feehi mukhtalifoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxvi{Kall\q@u{a} sayaAAlamoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxvii{Thumma kall\q@u{a} sayaAAlamoon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxviii{Alam najAAali alar\q@u{d}a mih\q@u{a}d\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxix{Wa\q@b{a}ljib\q@u{a}la awt\q@u{a}d\q@u{a}\q@b{n}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxx{Wakhalaqn\q@u{a}kum azw\q@u{a}j\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxxi{WajaAAaln\q@u{a} nawmakum sub\q@u{a}t\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxxii{WajaAAaln\q@u{a} allayla lib\q@u{a}s\q@u{a}\q@b{n}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxxiii{WajaAAaln\q@u{a} a\q@b{l}nnah\q@u{a}ra maAA\q@u{a}sh\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxxiv{Wabanayn\q@u{a} fawqakum sabAAan shid\q@u{a}d\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxxv{WajaAAaln\q@u{a} sir\q@u{a}jan wahh\q@u{a}j\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxxvi{Waanzaln\q@u{a} mina almuAA\q@u{s}ir\q@u{a}ti m\q@u{a}an thajj\q@u{a}j\q@u{a}\q@b{n}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxxvii{Linukhrija bihi \q@u{h}abban wanab\q@u{a}t\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxxviii{Wajann\q@u{a}tin alf\q@u{a}f\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdclxxxix{Inna yawma alfa\q@u{s}li k\q@u{a}na meeq\q@u{a}t\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxc{Yawma yunfakhu fee a\q@b{l}\q@u{ss}oori fatatoona afw\q@u{a}j\q@u{a}\q@b{n}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxci{Wafuti\q@u{h}ati a\q@b{l}ssam\q@u{a}o fak\q@u{a}nat abw\q@u{a}b\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxcii{Wasuyyirati aljib\q@u{a}lu fak\q@u{a}nat sar\q@u{a}b\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxciii{Inna jahannama k\q@u{a}nat mir\q@u{sa}d\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxciv{Li\q@b{l}\q@u{tta}gheena ma\q@u{a}b\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxcv{L\q@u{a}bitheena feeh\q@u{a} a\q@u{h}q\q@u{a}b\q@u{a}\q@b{n}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxcvi{L\q@u{a} ya\q@u{th}ooqoona feeh\q@u{a} bardan wal\q@u{a} shar\q@u{a}b\q@u{a}\q@b{n}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxcvii{Ill\q@u{a} \q@u{h}ameeman waghass\q@u{a}q\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxcviii{Jaz\q@u{a}an wif\q@u{a}q\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmdcxcix{Innahum k\q@u{a}noo l\q@u{a} yarjoona \q@u{h}is\q@u{a}b\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmdcc{Waka\q@u{thth}aboo bi\q@u{a}y\q@u{a}tin\q@u{a} ki\q@u{ththa}b\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmdcci{Wakulla shayin a\q@u{hs}ayn\q@u{a}hu kit\q@u{a}b\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmdccii{Fa\q@u{th}ooqoo falan nazeedakum ill\q@u{a} AAa\q@u{tha}b\q@u{a}\q@b{n}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmdcciii{Inna lilmuttaqeena maf\q@u{a}z\q@u{a}\q@b{n}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmdcciv{\q@u{H}ad\q@u{a}iqa waaAAn\q@u{a}b\q@u{a}\q@b{n}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmdccv{Wakaw\q@u{a}AAiba atr\q@u{a}b\q@u{a}\q@b{n}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmdccvi{Wakasan dih\q@u{a}q\q@u{a}\q@b{n}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmdccvii{L\q@u{a} yasmaAAoona feeh\q@u{a} laghwan wal\q@u{a} ki\q@u{ththa}b\q@u{a}\q@b{n}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmdccviii{Jaz\q@u{a}an min rabbika AAa\q@u{ta}an \q@u{h}is\q@u{a}b\q@u{a}\q@b{n}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmdccix{Rabbi a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wam\q@u{a} baynahum\q@u{a} a\q@b{l}rra\q@u{h}m\q@u{a}ni l\q@u{a} yamlikoona minhu khi\q@u{ta}b\q@u{a}\q@b{n}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmdccx{Yawma yaqoomu a\q@b{l}rroo\q@u{h}u wa\q@b{a}lmal\q@u{a}ikatu \q@u{s}affan l\q@u{a} yatakallamoona ill\q@u{a} man a\q@u{th}ina lahu a\q@b{l}rra\q@u{h}m\q@u{a}nu waq\q@u{a}la \q@u{s}aw\q@u{a}b\q@u{a}\q@b{n}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxi{\q@u{Tha}lika alyawmu al\q@u{h}aqqu faman sh\q@u{a}a ittakha\q@u{th}a il\q@u{a} rabbihi ma\q@u{a}b\q@u{a}\q@b{n}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxii{Inn\q@u{a} an\q@u{th}arn\q@u{a}kum AAa\q@u{tha}ban qareeban yawma yan\q@i{\q@u{th}}uru almaro m\q@u{a} qaddamat yad\q@u{a}hu wayaqoolu alk\q@u{a}firu y\q@u{a} laytanee kuntu tur\q@u{a}b\q@u{a}\q@b{n}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxiii{\basmalahlt Wa\q@b{al}nn\q@u{a}ziAA\q@u{a}ti gharq\q@u{a}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxiv{Wa\q@b{al}nn\q@u{a}shi\q@u{ta}ti nash\q@u{ta}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxv{Wa\q@b{al}ss\q@u{a}bi\q@u{ha}ti sab\q@u{ha}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxvi{Fa\q@b{al}ss\q@u{a}biq\q@u{a}ti sabq\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxvii{Fa\q@b{a}lmudabbir\q@u{a}ti amr\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxviii{Yawma tarjufu a\q@b{l}rr\q@u{a}jifa\q@b{tu}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxix{TatbaAAuh\q@u{a} a\q@b{l}rr\q@u{a}difa\q@b{tu}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxx{Quloobun yawmai\q@u{th}in w\q@u{a}jifa\q@b{tun}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxi{Ab\q@u{sa}ruh\q@u{a} kh\q@u{a}shiAAa\q@b{tun}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxii{Yaqooloona ainn\q@u{a} lamardoodoona fee al\q@u{ha}fira\q@b{ti}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxiii{Ai\q@u{tha} kunn\q@u{a} AAi\q@i{\q@u{th}}\q@u{a}man nakhira\q@b{tan}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxiv{Q\q@u{a}loo tilka i\q@u{th}an karratun kh\q@u{a}sira\q@b{tun}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxv{Fainnam\q@u{a} hiya zajratun w\q@u{ah}ida\q@b{tun}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxvi{Fai\q@u{tha} hum bi\q@b{al}ss\q@u{a}hira\q@b{ti}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxvii{Hal at\q@u{a}ka \q@u{h}adeethu moos\q@u{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxviii{I\q@u{th} n\q@u{a}d\q@u{a}hu rabbuhu bi\q@b{a}lw\q@u{a}di almuqaddasi \q@u{t}uw\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxix{I\q@u{th}hab il\q@u{a} firAAawna innahu \q@u{t}agh\q@u{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxx{Faqul hal laka il\q@u{a} an tazakk\q@u{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxxi{Waahdiyaka il\q@u{a} rabbika fatakhsh\q@u{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxxii{Faar\q@u{a}hu al\q@u{a}yata alkubr\q@u{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxxiii{Faka\q@u{thth}aba waAAa\q@u{sa}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxxiv{Thumma adbara yasAA\q@u{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxxv{Fa\q@u{h}ashara fan\q@u{a}d\q@u{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxxvi{Faq\q@u{a}la an\q@u{a} rabbukumu alaAAl\q@u{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxxvii{Faakha\q@u{th}ahu All\q@u{a}hu nak\q@u{a}la al\q@u{a}khirati wa\q@b{a}lool\q@u{a}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxxviii{Inna fee \q@u{tha}lika laAAibratan liman yakhsh\q@u{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxxxix{Aantum ashaddu khalqan ami a\q@b{l}ssam\q@u{a}o ban\q@u{a}h\q@u{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxl{RafaAAa samkah\q@u{a} fasaww\q@u{a}h\q@u{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxli{Waagh\q@u{t}asha laylah\q@u{a} waakhraja \q@u{d}u\q@u{ha}h\q@u{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxlii{Wa\q@b{a}lar\q@u{d}a baAAda \q@u{tha}lika da\q@u{ha}h\q@u{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxliii{Akhraja minh\q@u{a} m\q@u{a}ah\q@u{a} wamarAA\q@u{a}h\q@u{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxliv{Wa\q@b{a}ljib\q@u{a}la ars\q@u{a}h\q@u{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxlv{Mat\q@u{a}AAan lakum walianAA\q@u{a}mikum\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxlvi{Fai\q@u{tha} j\q@u{a}ati a\q@b{l}\q@u{tta}mmatu alkubr\q@u{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxlvii{Yawma yata\q@u{th}akkaru alins\q@u{a}nu m\q@u{a} saAA\q@u{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxlviii{Waburrizati alja\q@u{h}eemu liman yar\q@u{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxlix{Faamm\q@u{a} man \q@u{t}agh\q@u{a}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmdccl{Wa\q@u{a}thara al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmdccli{Fainna alja\q@u{h}eema hiya almaw\q@u{a}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclii{Waam\q@u{a} man kh\q@u{a}fa maq\q@u{a}ma rabbihi wanah\q@u{a} a\q@b{l}nnafsa AAani alhaw\q@u{a}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmdccliii{Fainna aljannata hiya almaw\q@u{a}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmmdccliv{Yasaloonaka AAani a\q@b{l}ss\q@u{a}AAati ayy\q@u{a}na murs\q@u{a}h\q@u{a}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclv{Feema anta min \q@u{th}ikr\q@u{a}h\q@u{a}\qt@no{(43)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclvi{Il\q@u{a} rabbika muntah\q@u{a}h\q@u{a}\qt@no{(44)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclvii{Innam\q@u{a} anta mun\q@u{th}iru man yakhsh\q@u{a}h\q@u{a}\qt@no{(45)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclviii{Kaannahum yawma yarawnah\q@u{a} lam yalbathoo ill\q@u{a} AAashiyyatan aw \q@u{d}u\q@u{ha}h\q@u{a}\qt@no{(46)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclix{\basmalahlt AAabasa watawall\q@u{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclx{An j\q@u{a}ahu alaAAm\q@u{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxi{Wam\q@u{a} yudreeka laAAallahu yazzakk\q@u{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxii{Aw ya\q@u{thth}akkaru fatanfaAAahu a\q@b{l}\q@u{thth}ikr\q@u{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxiii{Amm\q@u{a} mani istaghn\q@u{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxiv{Faanta lahu ta\q@u{s}add\q@u{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxv{Wam\q@u{a} AAalayka all\q@u{a} yazzakk\q@u{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxvi{Waamm\q@u{a} man j\q@u{a}aka yasAA\q@u{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxvii{Wahuwa yakhsh\q@u{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxviii{Faanta AAanhu talahh\q@u{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxix{Kall\q@u{a} innah\q@u{a} ta\q@u{th}kira\q@b{tun}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxx{Faman sh\q@u{a}a \q@u{th}akarah\q@b{u}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxi{Fee \q@u{s}u\q@u{h}ufin mukarrama\q@b{tin}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxii{MarfooAAatin mu\q@u{t}ahhara\q@b{tin}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxiii{Biaydee safara\q@b{tin}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxiv{Kir\q@u{a}min barara\q@b{tin}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxv{Qutila alins\q@u{a}nu m\q@u{a} akfarah\q@b{u}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxvi{Min ayyi shayin khalaqah\q@b{u}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxvii{Min nu\q@u{t}fatin khalaqahu faqaddarah\q@b{u}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxviii{Thumma a\q@b{l}ssabeela yassarah\q@b{u}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxix{Thumma am\q@u{a}tahu faaqbarah\q@b{u}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxx{Thumma i\q@u{tha} sh\q@u{a}a ansharah\q@b{u}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxxi{Kall\q@u{a} lamm\q@u{a} yaq\q@u{d}i m\q@u{a} amarah\q@b{u}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxxii{Falyan\q@i{\q@u{th}}uri alins\q@u{a}nu il\q@u{a} \q@u{t}aAA\q@u{a}mih\q@b{i}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxxiii{Ann\q@u{a} \q@u{s}ababn\q@u{a} alm\q@u{a}a \q@u{s}abb\q@u{a}\q@b{n}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxxiv{Thumma shaqaqn\q@u{a} alar\q@u{d}a shaqq\q@u{a}\q@b{n}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxxv{Faanbatn\q@u{a} feeh\q@u{a} \q@u{h}abb\q@u{a}\q@b{n}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxxvi{WaAAinaban waqa\q@u{d}b\q@u{a}\q@b{n}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxxvii{Wazaytoonan wanakhl\q@u{a}\q@b{n}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxxviii{Wa\q@u{h}ad\q@u{a}iqa ghulb\q@u{a}\q@b{n}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmdcclxxxix{Waf\q@u{a}kihatan waabb\q@u{a}\q@b{n}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxc{Mat\q@u{a}AAan lakum walianAA\q@u{a}mikum\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxci{Fai\q@u{tha} j\q@u{a}ati a\q@b{l}\q@u{ssa}khkha\q@b{tu}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxcii{Yawma yafirru almaro min akheeh\q@b{i}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxciii{Waommihi waabeeh\q@b{i}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxciv{Wa\q@u{sah}ibatihi wabaneeh\q@b{i}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxcv{Likulli imriin minhum yawmai\q@u{th}in shanun yughneeh\q@b{i}\qt@no{(37)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxcvi{Wujoohun yawmai\q@u{th}in musfira\q@b{tun}\qt@no{(38)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxcvii{\q@u{Dah}ikatun mustabshira\q@b{tun}\qt@no{(39)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxcviii{Wawujoohun yawmai\q@u{th}in AAalayh\q@u{a} ghabara\q@b{tun}\qt@no{(40)}}
\qt@newcmd\qurantrans@lt@mmmmmdccxcix{Tarhaquh\q@u{a} qatara\q@b{tun}\qt@no{(41)}}
\qt@newcmd\qurantrans@lt@mmmmmdccc{Ol\q@u{a}ika humu alkafaratu alfajara\q@b{tu}\qt@no{(42)}}
\qt@newcmd\qurantrans@lt@mmmmmdccci{\basmalahlt I\q@u{tha} a\q@b{l}shshamsu kuwwirat\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccii{Wai\q@u{tha} a\q@b{l}nnujoomu inkadarat\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdccciii{Wai\q@u{tha} aljib\q@u{a}lu suyyirat\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdccciv{Wai\q@u{tha} alAAish\q@u{a}ru AAu\q@u{tt}ilat\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccv{Wai\q@u{tha} alwu\q@u{h}ooshu \q@u{h}ushirat\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccvi{Wai\q@u{tha} albi\q@u{ha}ru sujjirat\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccvii{Wai\q@u{tha} a\q@b{l}nnufoosu zuwwijat\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccviii{Wai\q@u{tha} almawoodatu suilat\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccix{Biayyi \q@u{th}anbin qutilat\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccx{Wai\q@u{tha} a\q@b{l}\q@u{ss}u\q@u{h}ufu nushirat\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxi{Wai\q@u{tha} a\q@b{l}ssam\q@u{a}o kushi\q@u{t}at\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxii{Wai\q@u{tha} alja\q@u{h}eemu suAAAAirat\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxiii{Wai\q@u{tha} aljannatu ozlifat\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxiv{AAalimat nafsun m\q@u{a} a\q@u{hd}arat\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxv{Fal\q@u{a} oqsimu bi\q@b{a}lkhunnas\q@b{i}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxvi{Aljaw\q@u{a}ri alkunnas\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxvii{Wa\q@b{a}llayli i\q@u{tha} AAasAAas\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxviii{Wa\q@b{al}\q@u{ss}ub\q@u{h}i i\q@u{tha} tanaffas\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxix{Innahu laqawlu rasoolin kareem\q@b{in}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxx{\q@u{Th}ee quwwatin AAinda \q@u{th}ee alAAarshi makeen\q@b{in}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxi{Mu\q@u{ta}AAin thamma ameen\q@b{in}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxii{Wam\q@u{a} \q@u{sah}ibukum bimajnoon\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxiii{Walaqad ra\q@u{a}hu bi\q@b{a}lofuqi almubeen\q@b{i}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxiv{Wam\q@u{a} huwa AAal\q@u{a} alghaybi bi\q@u{d}aneen\q@b{in}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxv{Wam\q@u{a} huwa biqawli shay\q@u{ta}nin rajeem\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxvi{Faayna ta\q@u{th}haboon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxvii{In huwa ill\q@u{a} \q@u{th}ikrun lilAA\q@u{a}lameen\q@b{a}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxviii{Liman sh\q@u{a}a minkum an yastaqeem\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxix{Wam\q@u{a} tash\q@u{a}oona ill\q@u{a} an yash\q@u{a}a All\q@u{a}hu rabbu alAA\q@u{a}lameen\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxx{\basmalahlt I\q@u{tha} a\q@b{l}ssam\q@u{a}o infa\q@u{t}arat\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxxi{Wai\q@u{tha} alkaw\q@u{a}kibu intatharat\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxxii{Wai\q@u{tha} albi\q@u{ha}ru fujjirat\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxxiii{Wai\q@u{tha} alqubooru buAAthirat\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxxiv{AAalimat nafsun m\q@u{a} qaddamat waakhkharat\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxxv{Y\q@u{a} ayyuh\q@u{a} alins\q@u{a}nu m\q@u{a} gharraka birabbika alkareem\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxxvi{Alla\q@u{th}ee khalaqaka fasaww\q@u{a}ka faAAadalak\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxxvii{Fee ayyi \q@u{s}ooratin m\q@u{a} sh\q@u{a}a rakkabak\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxxviii{Kall\q@u{a} bal tuka\q@u{thth}iboona bi\q@b{al}ddeen\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxxxix{Wainna AAalaykum la\q@u{ha}fi\q@i{\q@u{th}}een\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxl{Kir\q@u{a}man k\q@u{a}tibeen\q@b{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxli{YaAAlamoona m\q@u{a} tafAAaloon\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxlii{Inna alabr\q@u{a}ra lafee naAAeem\q@b{in}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxliii{Wainna alfujj\q@u{a}ra lafee ja\q@u{h}eem\q@b{in}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxliv{Ya\q@u{s}lawnah\q@u{a} yawma a\q@b{l}ddeen\q@b{i}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxlv{Wam\q@u{a} hum AAanh\q@u{a} bigh\q@u{a}ibeen\q@b{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxlvi{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} yawmu a\q@b{l}ddeeni\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxlvii{Thumma m\q@u{a} adr\q@u{a}ka m\q@u{a} yawmu a\q@b{l}ddeen\q@b{i}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxlviii{Yawma l\q@u{a} tamliku nafsun linafsin shayan wa\q@b{a}lamru yawmai\q@u{th}in lill\q@u{a}h\q@b{i}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxlix{\basmalahlt Waylun lilmu\q@u{t}affifeen\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccl{Alla\q@u{th}eena i\q@u{tha} ikt\q@u{a}loo AAal\q@u{a} a\q@b{l}nn\q@u{a}si yastawfoon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccli{Wai\q@u{tha} k\q@u{a}loohum aw wazanoohum yukhsiroon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclii{Al\q@u{a} ya\q@i{\q@u{th}}unnu ol\q@u{a}ika annahum mabAAoothoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccliii{Liyawmin AAa\q@i{\q@u{th}}eem\q@b{in}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccliv{Yawma yaqoomu a\q@b{l}nn\q@u{a}su lirabbi alAA\q@u{a}lameen\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclv{Kall\q@u{a} inna kit\q@u{a}ba alfujj\q@u{a}ri lafee sijjeen\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclvi{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} sijjeen\q@b{un}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclvii{Kit\q@u{a}bun marqoom\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclviii{Waylun yawmai\q@u{th}in lilmuka\q@u{thth}ibeen\q@b{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclix{Alla\q@u{th}eena yuka\q@u{thth}iboona biyawmi a\q@b{l}ddeen\q@b{i}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclx{Wam\q@u{a} yuka\q@u{thth}ibu bihi ill\q@u{a} kullu muAAtadin atheem\q@b{in}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxi{I\q@u{tha} tutl\q@u{a} AAalayhi \q@u{a}y\q@u{a}tun\q@u{a} q\q@u{a}la as\q@u{at}eeru alawwaleen\q@b{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxii{Kall\q@u{a} bal r\q@u{a}na AAal\q@u{a} quloobihim m\q@u{a} k\q@u{a}noo yaksiboon\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxiii{Kall\q@u{a} innahum AAan rabbihim yawmai\q@u{th}in lama\q@u{h}jooboon\q@b{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxiv{Thumma innahum la\q@u{sa}loo alja\q@u{h}eem\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxv{Thumma yuq\q@u{a}lu h\q@u{atha} alla\q@u{th}ee kuntum bihi tuka\q@u{thth}iboon\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxvi{Kall\q@u{a} inna kit\q@u{a}ba alabr\q@u{a}ri lafee AAilliyyeen\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxvii{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} AAilliyyoon\q@b{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxviii{Kit\q@u{a}bun marqoom\q@b{un}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxix{Yashhaduhu almuqarraboon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxx{Inna alabr\q@u{a}ra lafee naAAeem\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxi{AAal\q@u{a} alar\q@u{a}iki yan\q@i{\q@u{th}}uroon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxii{TaAArifu fee wujoohihim na\q@u{d}rata a\q@b{l}nnaAAeem\q@b{i}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxiii{Yusqawna min ra\q@u{h}eeqin makhtoom\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxiv{Khit\q@u{a}muhu miskun wafee \q@u{tha}lika falyatan\q@u{a}fasi almutan\q@u{a}fisoon\q@b{a}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxv{Wamiz\q@u{a}juhu min tasneem\q@b{in}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxvi{AAaynan yashrabu bih\q@u{a} almuqarraboon\q@b{a}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxvii{Inna alla\q@u{th}eena ajramoo k\q@u{a}noo mina alla\q@u{th}eena \q@u{a}manoo ya\q@u{dh}akoon\q@b{a}\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxviii{Wai\q@u{tha} marroo bihim yatagh\q@u{a}mazoon\q@b{a}\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxix{Wai\q@u{tha} inqalaboo il\q@u{a} ahlihimu inqalaboo fakiheen\q@b{a}\qt@no{(31)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxx{Wai\q@u{tha} raawhum q\q@u{a}loo inna h\q@u{a}ol\q@u{a}i la\q@u{da}lloon\q@b{a}\qt@no{(32)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxxi{Wam\q@u{a} orsiloo AAalayhim \q@u{ha}fi\q@i{\q@u{th}}een\q@b{a}\qt@no{(33)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxxii{Fa\q@b{a}lyawma alla\q@u{th}eena \q@u{a}manoo mina alkuff\q@u{a}ri ya\q@u{dh}akoon\q@b{a}\qt@no{(34)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxxiii{AAal\q@u{a} alar\q@u{a}iki yan\q@i{\q@u{th}}uroon\q@b{a}\qt@no{(35)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxxiv{Hal thuwwiba alkuff\q@u{a}ru m\q@u{a} k\q@u{a}noo yafAAaloon\q@b{a}\qt@no{(36)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxxv{\basmalahlt I\q@u{tha} a\q@b{l}ssam\q@u{a}o inshaqqat\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxxvi{Waa\q@u{th}inat lirabbih\q@u{a} wa\q@u{h}uqqat\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxxvii{Wai\q@u{tha} alar\q@u{d}u muddat\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxxviii{Waalqat m\q@u{a} feeh\q@u{a} watakhallat\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmdccclxxxix{Waa\q@u{th}inat lirabbih\q@u{a} wa\q@u{h}uqqat\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxc{Y\q@u{a} ayyuh\q@u{a} alins\q@u{a}nu innaka k\q@u{a}di\q@u{h}un il\q@u{a} rabbika kad\q@u{h}an famul\q@u{a}qeeh\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxci{Faam\q@u{a} man ootiya kit\q@u{a}bahu biyameenih\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxcii{Fasawfa yu\q@u{ha}sabu \q@u{h}is\q@u{a}ban yaseer\q@u{a}\q@b{n}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxciii{Wayanqalibu il\q@u{a} ahlihi masroor\q@u{a}\q@b{n}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxciv{Waamm\q@u{a} man ootiya kit\q@u{a}bahu war\q@u{a}a \q@i{\q@u{th}}ahrih\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxcv{Fasawfa yadAAoo thuboor\q@u{a}\q@b{n}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxcvi{Waya\q@u{s}l\q@u{a} saAAeer\q@u{a}\q@b{n}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxcvii{Innahu k\q@u{a}na fee ahlihi masroor\q@u{a}\q@b{n}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxcviii{Innahu \q@i{\q@u{th}}anna an lan ya\q@u{h}oor\q@b{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmdcccxcix{Bal\q@u{a} inna rabbahu k\q@u{a}na bihi ba\q@u{s}eer\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcm{Fal\q@u{a} oqsimu bi\q@b{al}shshafaq\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcmi{Wa\q@b{a}llayli wam\q@u{a} wasaq\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcmii{Wa\q@b{a}lqamari i\q@u{tha} ittasaq\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcmiii{Latarkabunna \q@u{t}abaqan AAan \q@u{t}abaq\q@b{in}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcmiv{Fam\q@u{a} lahum l\q@u{a} yuminoon\q@b{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcmv{Wai\q@u{tha} quria AAalayhimu alqur\q@u{a}nu l\q@u{a} yasjudoon\q@b{a}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcmvi{Bali alla\q@u{th}eena kafaroo yuka\q@u{thth}iboon\q@b{a}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcmvii{Wa\q@b{A}ll\q@u{a}hu aAAlamu bim\q@u{a} yooAAoon\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmcmviii{Fabashshirhum biAAa\q@u{tha}bin aleem\q@b{in}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmcmix{Ill\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lahum ajrun ghayru mamnoon\q@b{in}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmcmx{\basmalahlt Wa\q@b{al}ssam\q@u{a}i \q@u{tha}ti alburooj\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxi{Wa\q@b{a}lyawmi almawAAood\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxii{Wash\q@u{a}hidin wamashhood\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxiii{Qutila a\q@u{s}\q@u{ha}bu alukhdood\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxiv{A\q@b{l}nn\q@u{a}ri \q@u{tha}ti alwaqood\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxv{I\q@u{th} hum AAalayh\q@u{a} quAAood\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxvi{Wahum AAal\q@u{a} m\q@u{a} yafAAaloona bi\q@b{a}lmumineena shuhood\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxvii{Wam\q@u{a} naqamoo minhum ill\q@u{a} an yuminoo bi\q@b{A}ll\q@u{a}hi alAAazeezi al\q@u{h}ameed\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxviii{Alla\q@u{th}ee lahu mulku a\q@b{l}ssam\q@u{a}w\q@u{a}ti wa\q@b{a}lar\q@u{d}i wa\q@b{A}ll\q@u{a}hu AAal\q@u{a} kulli shayin shaheed\q@b{un}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxix{Inna alla\q@u{th}eena fatanoo almumineena wa\q@b{a}lmumin\q@u{a}ti thumma lam yatooboo falahum AAa\q@u{tha}bu jahannama walahum AAa\q@u{tha}bu al\q@u{h}areeq\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxx{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti lahum jann\q@u{a}tun tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru \q@u{tha}lika alfawzu alkabeer\q@b{u}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxi{Inna ba\q@u{t}sha rabbika lashadeed\q@b{un}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxii{Innahu huwa yubdio wayuAAeed\q@b{u}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxiii{Wahuwa alghafooru alwadood\q@b{u}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxiv{\q@u{Th}oo alAAarshi almajeed\q@b{i}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxv{FaAAAA\q@u{a}lun lim\q@u{a} yureed\q@b{u}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxvi{Hal at\q@u{a}ka \q@u{h}adeethu aljunood\q@b{i}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxvii{FirAAawna wathamood\q@b{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxviii{Bali alla\q@u{th}eena kafaroo fee tak\q@u{th}eeb\q@b{in}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxix{Wa\q@b{A}ll\q@u{a}hu min war\q@u{a}ihim mu\q@u{h}ee\q@u{t}\q@b{un}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxx{Bal huwa qur\q@u{a}nun majeed\q@b{un}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxxi{Fee law\q@u{h}in ma\q@u{h}foo\q@i{\q@u{th}}\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxxii{\basmalahlt Wa\q@b{al}ssam\q@u{a}i wa\q@b{al}\q@u{tta}riq\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxxiii{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} a\q@b{l}\q@u{tta}riq\q@b{u}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxxiv{A\q@b{l}nnajmu a\q@b{l}thth\q@u{a}qib\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxxv{In kullu nafsin lamm\q@u{a} AAalayh\q@u{a} \q@u{ha}fi\q@i{\q@u{th}}\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxxvi{Falyan\q@i{\q@u{th}}uri alins\q@u{a}nu mimma khuliq\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxxvii{Khuliqa min m\q@u{a}in d\q@u{a}fiq\q@b{in}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxxviii{Yakhruju min bayni a\q@b{l}\q@u{ss}ulbi wa\q@b{al}ttar\q@u{a}ib\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxxxix{Innahu AAal\q@u{a} rajAAihi laq\q@u{a}dir\q@b{un}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxl{Yawma tubl\q@u{a} a\q@b{l}ssar\q@u{a}ir\q@b{u}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxli{Fam\q@u{a} lahu min quwwatin wal\q@u{a} n\q@u{as}ir\q@b{in}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxlii{Wa\q@b{al}ssam\q@u{a}i \q@u{tha}ti a\q@b{l}rrajAA\q@b{i}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxliii{Wa\q@b{a}lar\q@u{d}i \q@u{tha}ti a\q@b{l}\q@u{ss}adAA\q@b{i}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxliv{Innahu laqawlun fa\q@u{s}l\q@b{un}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxlv{Wam\q@u{a} huwa bi\q@b{a}lhazl\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxlvi{Innahum yakeedoona kayd\q@u{a}\q@b{n}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxlvii{Waakeedu kayd\q@u{a}\q@b{n}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxlviii{Famahhili alk\q@u{a}fireena amhilhum ruwayd\q@u{a}\q@b{n}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxlix{\basmalahlt Sabbi\q@u{h}i isma rabbika alaAAl\q@u{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcml{Alla\q@u{th}ee khalaqa fasaww\q@u{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcmli{Wa\q@b{a}lla\q@u{th}ee qaddara fahad\q@u{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlii{Wa\q@b{a}lla\q@u{th}ee akhraja almarAA\q@u{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcmliii{FajaAAalahu ghuth\q@u{a}an a\q@u{h}w\q@u{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcmliv{Sanuqrioka fal\q@u{a} tans\q@u{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlv{Ill\q@u{a} m\q@u{a} sh\q@u{a}a All\q@u{a}hu innahu yaAAlamu aljahra wam\q@u{a} yakhf\q@u{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlvi{Wanuyassiruka lilyusr\q@u{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlvii{Fa\q@u{th}akkir in nafaAAati a\q@b{l}\q@u{thth}ikr\q@u{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlviii{Saya\q@u{thth}akkaru man yakhsh\q@u{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlix{Wayatajannabuh\q@u{a} alashq\q@u{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlx{Alla\q@u{th}ee ya\q@u{s}l\q@u{a} a\q@b{l}nn\q@u{a}ra alkubr\q@u{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxi{Thumma l\q@u{a} yamootu feeh\q@u{a} wal\q@u{a} ya\q@u{h}y\q@u{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxii{Qad afla\q@u{h}a man tazakk\q@u{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxiii{Wa\q@u{th}akara isma rabbihi fa\q@u{s}all\q@u{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxiv{Bal tuthiroona al\q@u{h}ay\q@u{a}ta a\q@b{l}dduny\q@u{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxv{Wa\q@b{a}l\q@u{a}khiratu khayrun waabq\q@u{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxvi{Inna h\q@u{atha} lafee a\q@b{l}\q@u{ss}u\q@u{h}ufi alool\q@u{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxvii{\q@u{S}u\q@u{h}ufi ibr\q@u{a}heema wamoos\q@u{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxviii{\basmalahlt Hal at\q@u{a}ka \q@u{h}adeethu algh\q@u{a}shiyat\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxix{Wujoohun yawmai\q@u{th}in kh\q@u{a}shiAAa\q@b{tun}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxx{AA\q@u{a}milatun n\q@u{as}iba\q@b{tun}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxi{Ta\q@u{s}l\q@u{a} n\q@u{a}ran \q@u{ha}miya\q@b{tan}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxii{Tusq\q@u{a} min AAaynin \q@u{a}niya\q@b{tin}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxiii{Laysa lahum \q@u{t}aAA\q@u{a}mun ill\q@u{a} min \q@u{d}areeAA\q@b{in}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxiv{L\q@u{a} yusminu wal\q@u{a} yughnee min jooAA\q@b{in}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxv{Wujoohun yawmai\q@u{th}in n\q@u{a}AAima\q@b{tun}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxvi{LisaAAyih\q@u{a} r\q@u{ad}iya\q@b{tun}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxvii{Fee jannatin AA\q@u{a}liya\q@b{tin}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxviii{L\q@u{a} tasmaAAu feeh\q@u{a} l\q@u{a}ghiya\q@b{tan}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxix{Feeh\q@u{a} AAaynun j\q@u{a}riya\q@b{tun}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxx{Feeh\q@u{a} sururun marfooAAa\q@b{tun}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxxi{Waakw\q@u{a}bun maw\q@u{d}ooAAa\q@b{tun}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxxii{Wanam\q@u{a}riqu ma\q@u{s}foofa\q@b{tun}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxxiii{Wazar\q@u{a}biyyu mabthootha\q@b{tun}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxxiv{Afal\q@u{a} yan\q@i{\q@u{th}}uroona il\q@u{a} alibili kayfa khuliqat\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxxv{Wail\q@u{a} a\q@b{l}ssam\q@u{a}i kayfa rufiAAat\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxxvi{Wail\q@u{a} aljib\q@u{a}li kayfa nu\q@u{s}ibat\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxxvii{Wail\q@u{a} alar\q@u{d}i kayfa su\q@u{t}i\q@u{h}at\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxxviii{Fa\q@u{th}akkir innam\q@u{a} anta mu\q@u{th}akkir\q@b{un}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmcmlxxxix{Lasta AAalayhim bimu\q@u{s}ay\q@u{t}ir\q@b{in}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxc{Ill\q@u{a} man tawall\q@u{a} wakafar\q@b{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxci{FayuAAa\q@u{thth}ibuhu All\q@u{a}hu alAAa\q@u{tha}ba alakbar\q@b{a}\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxcii{Inna ilayn\q@u{a} iy\q@u{a}bahum\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxciii{Thumma inna AAalayn\q@u{a} \q@u{h}is\q@u{a}bahum\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxciv{\basmalahlt Wa\q@b{a}lfajr\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxcv{Walay\q@u{a}lin AAashr\q@b{in}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxcvi{Wa\q@b{al}shshafAAi wa\q@b{a}lwatr\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxcvii{Wa\q@b{a}llayli i\q@u{tha} yasr\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxcviii{Hal fee \q@u{tha}lika qasamun li\q@u{th}ee \q@u{h}ijr\q@b{in}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmcmxcix{Alam tara kayfa faAAala rabbuka biAA\q@u{a}d\q@b{in}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmm{Irama \q@u{tha}ti alAAim\q@u{a}d\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmi{Allatee lam yukhlaq mithluh\q@u{a} fee albil\q@u{a}d\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmii{Wathamooda alla\q@u{th}eena j\q@u{a}boo a\q@b{l}\q@u{ss}akhra bi\q@b{a}lw\q@u{a}d\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmmiii{WafirAAawna \q@u{th}ee alawt\q@u{a}d\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmmiv{Alla\q@u{th}eena \q@u{t}aghaw fee albil\q@u{a}d\q@b{i}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmmv{Faaktharoo feeh\q@u{a} alfas\q@u{a}d\q@b{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmmvi{Fa\q@u{s}abba AAalayhim rabbuka saw\q@u{t}a AAa\q@u{tha}b\q@b{in}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmmvii{Inna rabbaka labi\q@b{a}lmir\q@u{sa}d\q@b{i}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmmviii{Faamm\q@u{a} alins\q@u{a}nu i\q@u{tha} m\q@u{a} ibtal\q@u{a}hu rabbuhu faakramahu wanaAAAAamahu fayaqoolu rabbee akraman\q@b{i}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmmix{Waamm\q@u{a} i\q@u{tha} m\q@u{a} ibtal\q@u{a}hu faqadara AAalayhi rizqahu fayaqoolu rabbee ah\q@u{a}nan\q@b{i}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmmx{Kall\q@u{a} bal l\q@u{a} tukrimoona alyateem\q@b{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmmxi{Wal\q@u{a} ta\q@u{hadd}oona AAal\q@u{a} \q@u{t}aAA\q@u{a}mi almiskeen\q@b{i}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmmxii{Watakuloona a\q@b{l}ttur\q@u{a}tha aklan lamm\q@u{a}\q@b{n}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmmxiii{Watu\q@u{h}ibboona alm\q@u{a}la \q@u{h}ubban jamm\q@u{a}\q@b{n}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmmxiv{Kall\q@u{a} i\q@u{tha} dukkati alar\q@u{d}u dakkan dakk\q@u{a}\q@b{n}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmmxv{Waj\q@u{a}a rabbuka wa\q@b{a}lmalaku \q@u{s}affan \q@u{s}aff\q@u{a}\q@b{n}\qt@no{(22)}}
\qt@newcmd\qurantrans@lt@mmmmmmxvi{Wajeea yawmai\q@u{th}in bijahannama yawmai\q@u{th}in yata\q@u{th}akkaru alins\q@u{a}nu waann\q@u{a} lahu a\q@b{l}\q@u{thth}ikr\q@u{a}\qt@no{(23)}}
\qt@newcmd\qurantrans@lt@mmmmmmxvii{Yaqoolu y\q@u{a} laytanee qaddamtu li\q@u{h}ay\q@u{a}tee\qt@no{(24)}}
\qt@newcmd\qurantrans@lt@mmmmmmxviii{Fayawmai\q@u{th}in l\q@u{a} yuAAa\q@u{thth}ibu AAa\q@u{tha}bahu a\q@u{h}ad\q@b{un}\qt@no{(25)}}
\qt@newcmd\qurantrans@lt@mmmmmmxix{Wal\q@u{a} yoothiqu wath\q@u{a}qahu a\q@u{h}ad\q@b{un}\qt@no{(26)}}
\qt@newcmd\qurantrans@lt@mmmmmmxx{Y\q@u{a} ayyatuh\q@u{a} a\q@b{l}nnafsu almu\q@u{t}mainna\q@b{tu}\qt@no{(27)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxi{IrjiAAee il\q@u{a} rabbiki r\q@u{ad}iyatan mar\q@u{d}iyya\q@b{tan}\qt@no{(28)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxii{Fa\q@b{o}dkhulee fee AAib\q@u{a}dee\qt@no{(29)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxiii{Wa\q@b{o}dkhulee jannatee\qt@no{(30)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxiv{\basmalahlt L\q@u{a} oqsimu bih\q@u{atha} albalad\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxv{Waanta \q@u{h}illun bih\q@u{atha} albalad\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxvi{Waw\q@u{a}lidin wam\q@u{a} walad\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxvii{Laqad khalaqn\q@u{a} alins\q@u{a}na fee kabad\q@b{in}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxviii{Aya\q@u{h}sabu an lan yaqdira AAalayhi a\q@u{h}ad\q@b{un}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxix{Yaqoolu ahlaktu m\q@u{a}lan lubad\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxx{Aya\q@u{h}sabu an lam yarahu a\q@u{h}ad\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxxi{Alam najAAal lahu AAaynayn\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxxii{Walis\q@u{a}nan washafatayn\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxxiii{Wahadayn\q@u{a}hu a\q@b{l}nnajdayn\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxxiv{Fal\q@u{a} iqta\q@u{h}ama alAAaqaba\q@b{ta}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxxv{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} alAAaqaba\q@b{tu}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxxvi{Fakku raqaba\q@b{tin}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxxvii{Aw i\q@u{t}AA\q@u{a}mun fee yawmin \q@u{th}ee masghaba\q@b{tin}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxxviii{Yateeman \q@u{tha} maqraba\q@b{tin}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmmxxxix{Aw miskeenan \q@u{tha} matraba\q@b{tin}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmmxl{Thumma k\q@u{a}na mina alla\q@u{th}eena \q@u{a}manoo wataw\q@u{as}aw bi\q@b{al}\q@u{ss}abri wataw\q@u{as}aw bi\q@b{a}lmar\q@u{h}ama\q@b{ti}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmmxli{Ol\q@u{a}ika a\q@u{s}\q@u{ha}bu almaymana\q@b{ti}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmmxlii{Wa\q@b{a}lla\q@u{th}eena kafaroo bi\q@u{a}y\q@u{a}tin\q@u{a} hum a\q@u{s}\q@u{ha}bu almashama\q@b{ti}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmmxliii{AAalayhim n\q@u{a}run mu\q@u{s}ada\q@b{tun}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmmxliv{\basmalahlt Wa\q@b{al}shshamsi wa\q@u{d}u\q@u{ha}h\q@u{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmxlv{Wa\q@b{a}lqamari i\q@u{tha} tal\q@u{a}h\q@u{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmxlvi{Wa\q@b{al}nnah\q@u{a}ri i\q@u{tha} jall\q@u{a}h\q@u{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmxlvii{Wa\q@b{a}llayli i\q@u{tha} yaghsh\q@u{a}h\q@u{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmxlviii{Wa\q@b{al}ssam\q@u{a}i wam\q@u{a} ban\q@u{a}h\q@u{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmxlix{Wa\q@b{a}lar\q@u{d}i wam\q@u{a} \q@u{t}a\q@u{ha}h\q@u{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmml{Wanafsin wam\q@u{a} saww\q@u{a}h\q@u{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmli{Faalhamah\q@u{a} fujoorah\q@u{a} wataqw\q@u{a}h\q@u{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmlii{Qad afla\q@u{h}a man zakk\q@u{a}h\q@u{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmmliii{Waqad kh\q@u{a}ba man dass\q@u{a}h\q@u{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmmliv{Ka\q@u{thth}abat thamoodu bi\q@u{t}aghw\q@u{a}h\q@u{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmmlv{I\q@u{th}i inbaAAatha ashq\q@u{a}h\q@u{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmmlvi{Faq\q@u{a}la lahum rasoolu All\q@u{a}hi n\q@u{a}qata All\q@u{a}hi wasuqy\q@u{a}h\q@u{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmmlvii{Faka\q@u{thth}aboohu faAAaqarooh\q@u{a} fadamdama AAalayhim rabbuhum bi\q@u{th}anbihim fasaww\q@u{a}h\q@u{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmmlviii{Wal\q@u{a} yakh\q@u{a}fu AAuqb\q@u{a}h\q@u{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmmlix{\basmalahlt Wa\q@b{a}llayli i\q@u{tha} yaghsh\q@u{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmlx{Wa\q@b{al}nnah\q@u{a}ri i\q@u{tha} tajall\q@u{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxi{Wam\q@u{a} khalaqa a\q@b{l}\q@u{thth}akara wa\q@b{a}lonth\q@u{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxii{Inna saAAyakum lashatt\q@u{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxiii{Faamm\q@u{a} man aAA\q@u{ta} wa\q@b{i}ttaq\q@u{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxiv{Wa\q@u{s}addaqa bi\q@b{a}l\q@u{h}usn\q@u{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxv{Fasanuyassiruhu lilyusr\q@u{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxvi{Waamm\q@u{a} man bakhila wa\q@b{i}staghn\q@u{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxvii{Waka\q@u{thth}aba bi\q@b{a}l\q@u{h}usn\q@u{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxviii{Fasanuyassiruhu lilAAusr\q@u{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxix{Wam\q@u{a} yughnee AAanhu m\q@u{a}luhu i\q@u{tha} taradd\q@u{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxx{Inna AAalayn\q@u{a} lalhud\q@u{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxi{Wainna lan\q@u{a} lal\q@u{a}khirata wa\q@b{a}lool\q@u{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxii{Faan\q@u{th}artukum n\q@u{a}ran tala\q@i{\q@u{thth}}\q@u{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxiii{L\q@u{a} ya\q@u{s}l\q@u{a}h\q@u{a} ill\q@u{a} alashq\q@u{a}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxiv{Alla\q@u{th}ee ka\q@u{thth}aba watawall\q@u{a}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxv{Wasayujannabuh\q@u{a} alatq\q@u{a}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxvi{Alla\q@u{th}ee yutee m\q@u{a}lahu yatazakk\q@u{a}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxvii{Wam\q@u{a} lia\q@u{h}adin AAindahu min niAAmatin tujz\q@u{a}\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxviii{Ill\q@u{a} ibtigh\q@u{a}a wajhi rabbihi alaAAl\q@u{a}\qt@no{(20)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxix{Walasawfa yar\q@u{da}\qt@no{(21)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxx{\basmalahlt Wa\q@b{al}\q@u{dd}u\q@u{ha}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxxi{Wa\q@b{a}llayli i\q@u{tha} saj\q@u{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxxii{M\q@u{a} waddaAAaka rabbuka wam\q@u{a} qal\q@u{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxxiii{Walal\q@u{a}khiratu khayrun laka mina alool\q@u{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxxiv{Walasawfa yuAA\q@u{t}eeka rabbuka fatar\q@u{da}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxxv{Alam yajidka yateeman fa\q@u{a}w\q@u{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxxvi{Wawajadaka \q@u{da}llan fahad\q@u{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxxvii{Wawajadaka AA\q@u{a}ilan faaghn\q@u{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxxviii{Faamm\q@u{a} alyateema fal\q@u{a} taqhar\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmmlxxxix{Waamm\q@u{a} a\q@b{l}ss\q@u{a}ila fal\q@u{a} tanhar\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmmxc{Waamm\q@u{a} biniAAmati rabbika fa\q@u{h}addith\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmmxci{\basmalahlt Alam nashra\q@u{h} laka \q@u{s}adrak\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmxcii{Wawa\q@u{d}aAAn\q@u{a} AAanka wizrak\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmxciii{Alla\q@u{th}ee anqa\q@u{d}a \q@i{\q@u{th}}ahrak\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmxciv{WarafaAAn\q@u{a} laka \q@u{th}ikrak\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmxcv{Fainna maAAa alAAusri yusr\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmxcvi{Inna maAAa alAAusri yusr\q@u{a}\q@b{n}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmxcvii{Fai\q@u{tha} faraghta fa\q@b{i}n\q@u{s}ab\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmxcviii{Wail\q@u{a} rabbika fa\q@b{i}rghab\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmxcix{\basmalahlt Wa\q@b{al}tteeni wa\q@b{al}zzaytoon\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmc{Wa\q@u{t}oori seeneen\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmci{Wah\q@u{atha} albaladi alameen\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmcii{Laqad khalaqn\q@u{a} alins\q@u{a}na fee a\q@u{h}sani taqweem\q@b{in}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmciii{Thumma radadn\q@u{a}hu asfala s\q@u{a}fileen\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmciv{Ill\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti falahum ajrun ghayru mamnoon\q@b{in}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmcv{Fam\q@u{a} yuka\q@u{thth}ibuka baAAdu bi\q@b{al}ddeen\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmcvi{Alaysa All\q@u{a}hu bia\q@u{h}kami al\q@u{ha}kimeen\q@b{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmcvii{\basmalahlt Iqra biismi rabbika alla\q@u{th}ee khalaq\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmcviii{Khalaqa alins\q@u{a}na min AAalaq\q@b{in}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmcix{Iqra warabbuka alakram\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmcx{Alla\q@u{th}ee AAallama bi\q@b{a}lqalam\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxi{AAallama alins\q@u{a}na m\q@u{a} lam yaAAlam\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxii{Kall\q@u{a} inna alins\q@u{a}na laya\q@u{t}gh\q@u{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxiii{An ra\q@u{a}hu istaghn\q@u{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxiv{Inna il\q@u{a} rabbika a\q@b{l}rrujAA\q@u{a}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxv{Araayta alla\q@u{th}ee yanh\q@u{a}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxvi{AAabdan i\q@u{tha} \q@u{s}all\q@u{a}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxvii{Araayta in k\q@u{a}na AAal\q@u{a} alhud\q@u{a}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxviii{Aw amara bi\q@b{al}ttaqw\q@u{a}\qt@no{(12)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxix{Araayta in ka\q@u{thth}aba watawall\q@u{a}\qt@no{(13)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxx{Alam yaAAlam bianna All\q@u{a}ha yar\q@u{a}\qt@no{(14)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxi{Kall\q@u{a} lain lam yantahi lanasfaAAan bi\q@b{al}nn\q@u{as}iya\q@b{ti}\qt@no{(15)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxii{N\q@u{as}iyatin k\q@u{ath}ibatin kh\q@u{at}ia\q@b{tin}\qt@no{(16)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxiii{FalyadAAu n\q@u{a}diyah\q@b{u}\qt@no{(17)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxiv{SanadAAu a\q@b{l}zzab\q@u{a}niya\q@b{ta}\qt@no{(18)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxv{Kall\q@u{a} l\q@u{a} tu\q@u{t}iAAhu wa\q@b{o}sjud wa\q@b{i}qtarib\qt@no{(19)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxvi{\basmalahlt Inn\q@u{a} anzaln\q@u{a}hu fee laylati alqadr\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxvii{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} laylatu alqadr\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxviii{Laylatu alqadri khayrun min alfi shahr\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxix{Tanazzalu almal\q@u{a}ikatu wa\q@b{al}rroo\q@u{h}u feeh\q@u{a} bii\q@u{th}ni rabbihim min kulli amr\q@b{in}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxx{Sal\q@u{a}mun hiya \q@u{h}att\q@u{a} ma\q@u{t}laAAi alfajr\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxxi{\basmalahlt Lam yakuni alla\q@u{th}eena kafaroo min ahli alkit\q@u{a}bi wa\q@b{a}lmushrikeena munfakkeena \q@u{h}att\q@u{a} tatiyahumu albayyina\q@b{tu}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxxii{Rasoolun mina All\q@u{a}hi yatloo \q@u{s}u\q@u{h}ufan mu\q@u{t}ahhara\q@b{tan}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxxiii{Feeh\q@u{a} kutubun qayyima\q@b{tun}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxxiv{Wam\q@u{a} tafarraqa alla\q@u{th}eena ootoo alkit\q@u{a}ba ill\q@u{a} min baAAdi m\q@u{a} j\q@u{a}athumu albayyina\q@b{tu}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxxv{Wam\q@u{a} omiroo ill\q@u{a} liyaAAbudoo All\q@u{a}ha mukhli\q@u{s}eena lahu a\q@b{l}ddeena \q@u{h}unaf\q@u{a}a wayuqeemoo a\q@b{l}\q@u{ss}al\q@u{a}ta wayutoo a\q@b{l}zzak\q@u{a}ta wa\q@u{tha}lika deenu alqayyima\q@b{ti}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxxvi{Inna alla\q@u{th}eena kafaroo min ahli alkit\q@u{a}bi wa\q@b{a}lmushrikeena fee n\q@u{a}ri jahannama kh\q@u{a}lideena feeh\q@u{a} ol\q@u{a}ika hum sharru albariyya\q@b{ti}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxxvii{Inna alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti ol\q@u{a}ika hum khayru albariyya\q@b{ti}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxxviii{Jaz\q@u{a}ohum AAinda rabbihim jann\q@u{a}tu AAadnin tajree min ta\q@u{h}tih\q@u{a} alanh\q@u{a}ru kh\q@u{a}lideena feeh\q@u{a} abadan ra\q@u{d}iya All\q@u{a}hu AAanhum wara\q@u{d}oo AAanhu \q@u{tha}lika liman khashiya rabbah\q@b{u}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxxxix{\basmalahlt I\q@u{tha} zulzilati alar\q@u{d}u zilz\q@u{a}lah\q@u{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxl{Waakhrajati alar\q@u{d}u athq\q@u{a}lah\q@u{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxli{Waq\q@u{a}la alins\q@u{a}nu m\q@u{a} lah\q@u{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxlii{Yawmai\q@u{th}in tu\q@u{h}addithu akhb\q@u{a}rah\q@u{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxliii{Bianna rabbaka aw\q@u{ha} lah\q@u{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxliv{Yawmai\q@u{th}in ya\q@u{s}duru a\q@b{l}nn\q@u{a}su asht\q@u{a}tan liyuraw aAAm\q@u{a}lahum\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxlv{Faman yaAAmal mithq\q@u{a}la \q@u{th}arratin khayran yarah\q@b{u}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxlvi{Waman yaAAmal mithq\q@u{a}la \q@u{th}arratin sharran yarah\q@b{u}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxlvii{\basmalahlt Wa\q@b{a}lAA\q@u{a}diy\q@u{a}ti \q@u{d}ab\q@u{ha}\q@b{n}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxlviii{Fa\q@b{a}lmooriy\q@u{a}ti qad\q@u{ha}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxlix{Fa\q@b{a}lmugheer\q@u{a}ti \q@u{s}ub\q@u{ha}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmcl{Faatharna bihi naqAA\q@u{a}\q@b{n}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmcli{Fawasa\q@u{t}na bihi jamAA\q@u{a}\q@b{n}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmclii{Inna alins\q@u{a}na lirabbihi lakanood\q@b{un}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmcliii{Wainnahu AAal\q@u{a} \q@u{tha}lika lashaheed\q@b{un}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmcliv{Wainnahu li\q@u{h}ubbi alkhayri lashadeed\q@b{un}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmclv{Afal\q@u{a} yaAAlamu i\q@u{tha} buAAthira m\q@u{a} fee alquboor\q@b{i}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmmclvi{Wa\q@u{h}u\q@u{ss}ila m\q@u{a} fee a\q@b{l}\q@u{ss}udoor\q@b{i}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmmclvii{Inna rabbahum bihim yawmai\q@u{th}in lakhabeer\q@b{un}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmmclviii{\basmalahlt Alq\q@u{a}riAAa\q@b{tu}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmclix{M\q@u{a} alq\q@u{a}riAAa\q@b{tu}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmclx{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} alq\q@u{a}riAAa\q@b{tu}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxi{Yawma yakoonu a\q@b{l}nn\q@u{a}su ka\q@b{a}lfar\q@u{a}shi almabthooth\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxii{Watakoonu aljib\q@u{a}lu ka\q@b{a}lAAihni almanfoosh\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxiii{Faamm\q@u{a} man thaqulat maw\q@u{a}zeenuh\q@b{u}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxiv{Fahuwa fee AAeeshatin r\q@u{ad}iya\q@b{tin}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxv{Waamm\q@u{a} man khaffat maw\q@u{a}zeenuh\q@b{u}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxvi{Faommuhu h\q@u{a}wiya\q@b{tun}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxvii{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} hiya\q@b{h}\qt@no{(10)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxviii{N\q@u{a}run \q@u{ha}miya\q@b{tun}\qt@no{(11)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxix{\basmalahlt Alh\q@u{a}kumu a\q@b{l}ttak\q@u{a}thur\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxx{\q@u{H}att\q@u{a} zurtumu almaq\q@u{a}bir\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxi{Kall\q@u{a} sawfa taAAlamoon\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxii{Thumma kall\q@u{a} sawfa taAAlamoon\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxiii{Kall\q@u{a} law taAAlamoona AAilma alyaqeen\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxiv{Latarawunna alja\q@u{h}eem\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxv{Thumma latarawunnah\q@u{a} AAayna alyaqeen\q@b{i}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxvi{Thumma latusalunna yawmai\q@u{th}in AAani a\q@b{l}nnaAAeem\q@b{i}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxvii{\basmalahlt Wa\q@b{a}lAAa\q@u{s}r\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxviii{Inna alins\q@u{a}na lafee khusr\q@b{in}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxix{Ill\q@u{a} alla\q@u{th}eena \q@u{a}manoo waAAamiloo a\q@b{l}\q@u{ssa}li\q@u{ha}ti wataw\q@u{as}aw bi\q@b{a}l\q@u{h}aqqi wataw\q@u{as}aw bi\q@b{al}\q@u{ss}abr\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxx{\basmalahlt Waylun likulli humazatin lumaza\q@b{tin}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxxi{Alla\q@u{th}ee jamaAAa m\q@u{a}lan waAAaddadah\q@b{u}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxxii{Ya\q@u{h}sabu anna m\q@u{a}lahu akhladah\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxxiii{Kall\q@u{a} layunba\q@u{th}anna fee al\q@u{h}u\q@u{t}ama\q@b{ti}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxxiv{Wam\q@u{a} adr\q@u{a}ka m\q@u{a} al\q@u{h}u\q@u{t}ama\q@b{tu}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxxv{N\q@u{a}ru All\q@u{a}hi almooqada\q@b{tu}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxxvi{Allatee ta\q@u{tt}aliAAu AAal\q@u{a} alafida\q@b{ti}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxxvii{lnnah\q@u{a} AAalayhim mu\q@u{s}ada\q@b{tun}\qt@no{(8)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxxviii{Fee AAamadin mumaddada\q@b{tin}\qt@no{(9)}}
\qt@newcmd\qurantrans@lt@mmmmmmclxxxix{\basmalahlt Alam tara kayfa faAAala rabbuka bia\q@u{s}\q@u{ha}bi alfeel\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxc{Alam yajAAal kaydahum fee ta\q@u{d}leel\q@b{in}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxci{Waarsala AAalayhim \q@u{t}ayran ab\q@u{a}beel\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxcii{Tarmeehim bi\q@u{h}ij\q@u{a}ratin min sijjeel\q@b{in}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxciii{FajaAAalahum kaAAa\q@u{s}fin makool\q@b{in}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxciv{\basmalahlt Lieel\q@u{a}fi quraysh\q@b{in}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxcv{Eel\q@u{a}fihim ri\q@u{h}lata a\q@b{l}shshit\q@u{a}i wa\q@b{al}\q@u{ss}ayf\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxcvi{FalyaAAbudoo rabba h\q@u{atha} albayt\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxcvii{Alla\q@u{th}ee a\q@u{t}AAamahum min jooAAin wa\q@u{a}manahum min khawf\q@b{in}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxcviii{\basmalahlt Araayta alla\q@u{th}ee yuka\q@u{thth}ibu bi\q@b{al}ddeen\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmcxcix{Fa\q@u{tha}lika alla\q@u{th}ee yaduAAAAu alyateem\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmcc{Wal\q@u{a} ya\q@u{h}u\q@u{dd}u AAal\q@u{a} \q@u{t}aAA\q@u{a}mi almiskeen\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmcci{Fawaylun lilmu\q@u{s}alleen\q@b{a}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmccii{Alla\q@u{th}eena hum AAan \q@u{s}al\q@u{a}tihim s\q@u{a}hoon\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmcciii{Alla\q@u{th}eena hum yur\q@u{a}oon\q@b{a}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmcciv{WayamnaAAoona alm\q@u{a}AAoon\q@b{a}\qt@no{(7)}}
\qt@newcmd\qurantrans@lt@mmmmmmccv{\basmalahlt Inn\q@u{a} aAA\q@u{t}ayn\q@u{a}ka alkawthar\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmccvi{Fa\q@u{s}alli lirabbika wa\q@b{i}n\q@u{h}ar\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmccvii{Inna sh\q@u{a}niaka huwa alabtar\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmccviii{\basmalahlt Qul y\q@u{a} ayyuh\q@u{a} alk\q@u{a}firoon\q@b{a}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmccix{L\q@u{a} aAAbudu m\q@u{a} taAAbudoon\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmccx{Wal\q@u{a} antum AA\q@u{a}bidoona m\q@u{a} aAAbud\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxi{Wal\q@u{a} an\q@u{a} AA\q@u{a}bidun m\q@u{a} AAabadtum\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxii{Wal\q@u{a} antum AA\q@u{a}bidoona m\q@u{a} aAAbud\q@b{u}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxiii{Lakum deenukum waliya deen\q@b{i}\qt@no{(6)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxiv{\basmalahlt I\q@u{tha} j\q@u{a}a na\q@u{s}ru All\q@u{a}hi wa\q@b{a}lfat\q@u{h}\q@b{u}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxv{Waraayta a\q@b{l}nn\q@u{a}sa yadkhuloona fee deeni All\q@u{a}hi afw\q@u{a}j\q@u{a}\q@b{n}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxvi{Fasabbi\q@u{h} bi\q@u{h}amdi rabbika wa\q@b{i}staghfirhu innahu k\q@u{a}na taww\q@u{a}b\q@u{a}\q@b{n}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxvii{\basmalahlt Tabbat yad\q@u{a} abee lahabin watab\q@b{ba}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxviii{M\q@u{a} aghn\q@u{a} AAanhu m\q@u{a}luhu wam\q@u{a} kasab\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxix{Saya\q@u{s}l\q@u{a} n\q@u{a}ran \q@u{tha}ta lahab\q@b{in}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxx{Wa\q@b{i}mraatuhu \q@u{h}amm\q@u{a}lata al\q@u{h}a\q@u{t}ab\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxi{Fee jeedih\q@u{a} \q@u{h}ablun min masad\q@b{in}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxii{\basmalahlt Qul huwa All\q@u{a}hu a\q@u{h}ad\q@b{un}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxiii{All\q@u{a}hu a\q@b{l}\q@u{ss}amad\q@b{u}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxiv{Lam yalid walam yoolad\q@b{u}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxv{Walam yakun lahu kufuwan a\q@u{h}ad\q@b{un}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxvi{\basmalahlt Qul aAAoo\q@u{th}u birabbi alfalaq\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxvii{Min sharri m\q@u{a} khalaq\q@b{a}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxviii{Wamin sharri gh\q@u{a}siqin i\q@u{tha} waqab\q@b{a}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxix{Wamin sharri a\q@b{l}nnaff\q@u{a}th\q@u{a}ti fee alAAuqad\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxx{Wamin sharri \q@u{ha}sidin i\q@u{tha} \q@u{h}asad\q@b{a}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxxi{\basmalahlt Qul aAAoo\q@u{th}u birabbi a\q@b{l}nn\q@u{a}s\q@b{i}\qt@no{(1)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxxii{Maliki a\q@b{l}nn\q@u{a}s\q@b{i}\qt@no{(2)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxxiii{Il\q@u{a}hi a\q@b{l}nn\q@u{a}s\q@b{i}\qt@no{(3)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxxiv{Min sharri alwasw\q@u{a}si alkhann\q@u{a}s\q@b{i}\qt@no{(4)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxxv{Alla\q@u{th}ee yuwaswisu fee \q@u{s}udoori a\q@b{l}nn\q@u{a}s\q@b{i}\qt@no{(5)}}
\qt@newcmd\qurantrans@lt@mmmmmmccxxxvi{Mina aljinnati wa\q@b{ al}nn\q@u{a}s\q@b{m}\qt@no{(6)}}
