%% This is file `qurantext-simple.def',
%% 
%% Copyright © 2015-2021
%% Seiied-Mohammad-Javad Razavian <javadr@gmail.com>
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%% 
%% This work is “author-maintained” (as per LPPL maintenance status).
%% 
%% The Current Maintainer of this work is Seiied-Mohammad-Javad Razavian.
%% 
%% to one who has devoted his life to Quran
%%
\qt@newcmd\qurantext@i{بِسمِ اللَّهِ الرَّحمٰنِ الرَّحيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@ii{الحَمدُ لِلَّهِ رَبِّ العالَمينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@iii{الرَّحمٰنِ الرَّحيمِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@iv{مالِكِ يَومِ الدّينِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@v{إِيّاكَ نَعبُدُ وَإِيّاكَ نَستَعينُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@vi{اهدِنَا الصِّراطَ المُستَقيمَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@vii{صِراطَ الَّذينَ أَنعَمتَ عَلَيهِم غَيرِ المَغضوبِ عَلَيهِم وَلَا الضّالّينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@viii{\basmalah الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@ix{ذٰلِكَ الكِتابُ لا رَيبَ ۛ فيهِ ۛ هُدًى لِلمُتَّقينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@x{الَّذينَ يُؤمِنونَ بِالغَيبِ وَيُقيمونَ الصَّلاةَ وَمِمّا رَزَقناهُم يُنفِقونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@xi{وَالَّذينَ يُؤمِنونَ بِما أُنزِلَ إِلَيكَ وَما أُنزِلَ مِن قَبلِكَ وَبِالآخِرَةِ هُم يوقِنونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@xii{أُولٰئِكَ عَلىٰ هُدًى مِن رَبِّهِم ۖ وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@xiii{إِنَّ الَّذينَ كَفَروا سَواءٌ عَلَيهِم أَأَنذَرتَهُم أَم لَم تُنذِرهُم لا يُؤمِنونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@xiv{خَتَمَ اللَّهُ عَلىٰ قُلوبِهِم وَعَلىٰ سَمعِهِم ۖ وَعَلىٰ أَبصارِهِم غِشاوَةٌ ۖ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@xv{وَمِنَ النّاسِ مَن يَقولُ آمَنّا بِاللَّهِ وَبِاليَومِ الآخِرِ وَما هُم بِمُؤمِنينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@xvi{يُخادِعونَ اللَّهَ وَالَّذينَ آمَنوا وَما يَخدَعونَ إِلّا أَنفُسَهُم وَما يَشعُرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@xvii{في قُلوبِهِم مَرَضٌ فَزادَهُمُ اللَّهُ مَرَضًا ۖ وَلَهُم عَذابٌ أَليمٌ بِما كانوا يَكذِبونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@xviii{وَإِذا قيلَ لَهُم لا تُفسِدوا فِي الأَرضِ قالوا إِنَّما نَحنُ مُصلِحونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@xix{أَلا إِنَّهُم هُمُ المُفسِدونَ وَلٰكِن لا يَشعُرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@xx{وَإِذا قيلَ لَهُم آمِنوا كَما آمَنَ النّاسُ قالوا أَنُؤمِنُ كَما آمَنَ السُّفَهاءُ ۗ أَلا إِنَّهُم هُمُ السُّفَهاءُ وَلٰكِن لا يَعلَمونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@xxi{وَإِذا لَقُوا الَّذينَ آمَنوا قالوا آمَنّا وَإِذا خَلَوا إِلىٰ شَياطينِهِم قالوا إِنّا مَعَكُم إِنَّما نَحنُ مُستَهزِئونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@xxii{اللَّهُ يَستَهزِئُ بِهِم وَيَمُدُّهُم في طُغيانِهِم يَعمَهونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@xxiii{أُولٰئِكَ الَّذينَ اشتَرَوُا الضَّلالَةَ بِالهُدىٰ فَما رَبِحَت تِجارَتُهُم وَما كانوا مُهتَدينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@xxiv{مَثَلُهُم كَمَثَلِ الَّذِي استَوقَدَ نارًا فَلَمّا أَضاءَت ما حَولَهُ ذَهَبَ اللَّهُ بِنورِهِم وَتَرَكَهُم في ظُلُماتٍ لا يُبصِرونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@xxv{صُمٌّ بُكمٌ عُميٌ فَهُم لا يَرجِعونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@xxvi{أَو كَصَيِّبٍ مِنَ السَّماءِ فيهِ ظُلُماتٌ وَرَعدٌ وَبَرقٌ يَجعَلونَ أَصابِعَهُم في آذانِهِم مِنَ الصَّواعِقِ حَذَرَ المَوتِ ۚ وَاللَّهُ مُحيطٌ بِالكافِرينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@xxvii{يَكادُ البَرقُ يَخطَفُ أَبصارَهُم ۖ كُلَّما أَضاءَ لَهُم مَشَوا فيهِ وَإِذا أَظلَمَ عَلَيهِم قاموا ۚ وَلَو شاءَ اللَّهُ لَذَهَبَ بِسَمعِهِم وَأَبصارِهِم ۚ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@xxviii{يا أَيُّهَا النّاسُ اعبُدوا رَبَّكُمُ الَّذي خَلَقَكُم وَالَّذينَ مِن قَبلِكُم لَعَلَّكُم تَتَّقونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@xxix{الَّذي جَعَلَ لَكُمُ الأَرضَ فِراشًا وَالسَّماءَ بِناءً وَأَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجَ بِهِ مِنَ الثَّمَراتِ رِزقًا لَكُم ۖ فَلا تَجعَلوا لِلَّهِ أَندادًا وَأَنتُم تَعلَمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@xxx{وَإِن كُنتُم في رَيبٍ مِمّا نَزَّلنا عَلىٰ عَبدِنا فَأتوا بِسورَةٍ مِن مِثلِهِ وَادعوا شُهَداءَكُم مِن دونِ اللَّهِ إِن كُنتُم صادِقينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@xxxi{فَإِن لَم تَفعَلوا وَلَن تَفعَلوا فَاتَّقُوا النّارَ الَّتي وَقودُهَا النّاسُ وَالحِجارَةُ ۖ أُعِدَّت لِلكافِرينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@xxxii{وَبَشِّرِ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ أَنَّ لَهُم جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ ۖ كُلَّما رُزِقوا مِنها مِن ثَمَرَةٍ رِزقًا ۙ قالوا هٰذَا الَّذي رُزِقنا مِن قَبلُ ۖ وَأُتوا بِهِ مُتَشابِهًا ۖ وَلَهُم فيها أَزواجٌ مُطَهَّرَةٌ ۖ وَهُم فيها خالِدونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@xxxiii{۞ إِنَّ اللَّهَ لا يَستَحيي أَن يَضرِبَ مَثَلًا ما بَعوضَةً فَما فَوقَها ۚ فَأَمَّا الَّذينَ آمَنوا فَيَعلَمونَ أَنَّهُ الحَقُّ مِن رَبِّهِم ۖ وَأَمَّا الَّذينَ كَفَروا فَيَقولونَ ماذا أَرادَ اللَّهُ بِهٰذا مَثَلًا ۘ يُضِلُّ بِهِ كَثيرًا وَيَهدي بِهِ كَثيرًا ۚ وَما يُضِلُّ بِهِ إِلَّا الفاسِقينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@xxxiv{الَّذينَ يَنقُضونَ عَهدَ اللَّهِ مِن بَعدِ ميثاقِهِ وَيَقطَعونَ ما أَمَرَ اللَّهُ بِهِ أَن يوصَلَ وَيُفسِدونَ فِي الأَرضِ ۚ أُولٰئِكَ هُمُ الخاسِرونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@xxxv{كَيفَ تَكفُرونَ بِاللَّهِ وَكُنتُم أَمواتًا فَأَحياكُم ۖ ثُمَّ يُميتُكُم ثُمَّ يُحييكُم ثُمَّ إِلَيهِ تُرجَعونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@xxxvi{هُوَ الَّذي خَلَقَ لَكُم ما فِي الأَرضِ جَميعًا ثُمَّ استَوىٰ إِلَى السَّماءِ فَسَوّاهُنَّ سَبعَ سَماواتٍ ۚ وَهُوَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@xxxvii{وَإِذ قالَ رَبُّكَ لِلمَلائِكَةِ إِنّي جاعِلٌ فِي الأَرضِ خَليفَةً ۖ قالوا أَتَجعَلُ فيها مَن يُفسِدُ فيها وَيَسفِكُ الدِّماءَ وَنَحنُ نُسَبِّحُ بِحَمدِكَ وَنُقَدِّسُ لَكَ ۖ قالَ إِنّي أَعلَمُ ما لا تَعلَمونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@xxxviii{وَعَلَّمَ آدَمَ الأَسماءَ كُلَّها ثُمَّ عَرَضَهُم عَلَى المَلائِكَةِ فَقالَ أَنبِئوني بِأَسماءِ هٰؤُلاءِ إِن كُنتُم صادِقينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@xxxix{قالوا سُبحانَكَ لا عِلمَ لَنا إِلّا ما عَلَّمتَنا ۖ إِنَّكَ أَنتَ العَليمُ الحَكيمُ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@xl{قالَ يا آدَمُ أَنبِئهُم بِأَسمائِهِم ۖ فَلَمّا أَنبَأَهُم بِأَسمائِهِم قالَ أَلَم أَقُل لَكُم إِنّي أَعلَمُ غَيبَ السَّماواتِ وَالأَرضِ وَأَعلَمُ ما تُبدونَ وَما كُنتُم تَكتُمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@xli{وَإِذ قُلنا لِلمَلائِكَةِ اسجُدوا لِآدَمَ فَسَجَدوا إِلّا إِبليسَ أَبىٰ وَاستَكبَرَ وَكانَ مِنَ الكافِرينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@xlii{وَقُلنا يا آدَمُ اسكُن أَنتَ وَزَوجُكَ الجَنَّةَ وَكُلا مِنها رَغَدًا حَيثُ شِئتُما وَلا تَقرَبا هٰذِهِ الشَّجَرَةَ فَتَكونا مِنَ الظّالِمينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@xliii{فَأَزَلَّهُمَا الشَّيطانُ عَنها فَأَخرَجَهُما مِمّا كانا فيهِ ۖ وَقُلنَا اهبِطوا بَعضُكُم لِبَعضٍ عَدُوٌّ ۖ وَلَكُم فِي الأَرضِ مُستَقَرٌّ وَمَتاعٌ إِلىٰ حينٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@xliv{فَتَلَقّىٰ آدَمُ مِن رَبِّهِ كَلِماتٍ فَتابَ عَلَيهِ ۚ إِنَّهُ هُوَ التَّوّابُ الرَّحيمُ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@xlv{قُلنَا اهبِطوا مِنها جَميعًا ۖ فَإِمّا يَأتِيَنَّكُم مِنّي هُدًى فَمَن تَبِعَ هُدايَ فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@xlvi{وَالَّذينَ كَفَروا وَكَذَّبوا بِآياتِنا أُولٰئِكَ أَصحابُ النّارِ ۖ هُم فيها خالِدونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@xlvii{يا بَني إِسرائيلَ اذكُروا نِعمَتِيَ الَّتي أَنعَمتُ عَلَيكُم وَأَوفوا بِعَهدي أوفِ بِعَهدِكُم وَإِيّايَ فَارهَبونِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@xlviii{وَآمِنوا بِما أَنزَلتُ مُصَدِّقًا لِما مَعَكُم وَلا تَكونوا أَوَّلَ كافِرٍ بِهِ ۖ وَلا تَشتَروا بِآياتي ثَمَنًا قَليلًا وَإِيّايَ فَاتَّقونِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@xlix{وَلا تَلبِسُوا الحَقَّ بِالباطِلِ وَتَكتُمُوا الحَقَّ وَأَنتُم تَعلَمونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@l{وَأَقيمُوا الصَّلاةَ وَآتُوا الزَّكاةَ وَاركَعوا مَعَ الرّاكِعينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@li{۞ أَتَأمُرونَ النّاسَ بِالبِرِّ وَتَنسَونَ أَنفُسَكُم وَأَنتُم تَتلونَ الكِتابَ ۚ أَفَلا تَعقِلونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@lii{وَاستَعينوا بِالصَّبرِ وَالصَّلاةِ ۚ وَإِنَّها لَكَبيرَةٌ إِلّا عَلَى الخاشِعينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@liii{الَّذينَ يَظُنّونَ أَنَّهُم مُلاقو رَبِّهِم وَأَنَّهُم إِلَيهِ راجِعونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@liv{يا بَني إِسرائيلَ اذكُروا نِعمَتِيَ الَّتي أَنعَمتُ عَلَيكُم وَأَنّي فَضَّلتُكُم عَلَى العالَمينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@lv{وَاتَّقوا يَومًا لا تَجزي نَفسٌ عَن نَفسٍ شَيئًا وَلا يُقبَلُ مِنها شَفاعَةٌ وَلا يُؤخَذُ مِنها عَدلٌ وَلا هُم يُنصَرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@lvi{وَإِذ نَجَّيناكُم مِن آلِ فِرعَونَ يَسومونَكُم سوءَ العَذابِ يُذَبِّحونَ أَبناءَكُم وَيَستَحيونَ نِساءَكُم ۚ وَفي ذٰلِكُم بَلاءٌ مِن رَبِّكُم عَظيمٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@lvii{وَإِذ فَرَقنا بِكُمُ البَحرَ فَأَنجَيناكُم وَأَغرَقنا آلَ فِرعَونَ وَأَنتُم تَنظُرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@lviii{وَإِذ واعَدنا موسىٰ أَربَعينَ لَيلَةً ثُمَّ اتَّخَذتُمُ العِجلَ مِن بَعدِهِ وَأَنتُم ظالِمونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@lix{ثُمَّ عَفَونا عَنكُم مِن بَعدِ ذٰلِكَ لَعَلَّكُم تَشكُرونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@lx{وَإِذ آتَينا موسَى الكِتابَ وَالفُرقانَ لَعَلَّكُم تَهتَدونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@lxi{وَإِذ قالَ موسىٰ لِقَومِهِ يا قَومِ إِنَّكُم ظَلَمتُم أَنفُسَكُم بِاتِّخاذِكُمُ العِجلَ فَتوبوا إِلىٰ بارِئِكُم فَاقتُلوا أَنفُسَكُم ذٰلِكُم خَيرٌ لَكُم عِندَ بارِئِكُم فَتابَ عَلَيكُم ۚ إِنَّهُ هُوَ التَّوّابُ الرَّحيمُ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@lxii{وَإِذ قُلتُم يا موسىٰ لَن نُؤمِنَ لَكَ حَتّىٰ نَرَى اللَّهَ جَهرَةً فَأَخَذَتكُمُ الصّاعِقَةُ وَأَنتُم تَنظُرونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@lxiii{ثُمَّ بَعَثناكُم مِن بَعدِ مَوتِكُم لَعَلَّكُم تَشكُرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@lxiv{وَظَلَّلنا عَلَيكُمُ الغَمامَ وَأَنزَلنا عَلَيكُمُ المَنَّ وَالسَّلوىٰ ۖ كُلوا مِن طَيِّباتِ ما رَزَقناكُم ۖ وَما ظَلَمونا وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@lxv{وَإِذ قُلنَا ادخُلوا هٰذِهِ القَريَةَ فَكُلوا مِنها حَيثُ شِئتُم رَغَدًا وَادخُلُوا البابَ سُجَّدًا وَقولوا حِطَّةٌ نَغفِر لَكُم خَطاياكُم ۚ وَسَنَزيدُ المُحسِنينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@lxvi{فَبَدَّلَ الَّذينَ ظَلَموا قَولًا غَيرَ الَّذي قيلَ لَهُم فَأَنزَلنا عَلَى الَّذينَ ظَلَموا رِجزًا مِنَ السَّماءِ بِما كانوا يَفسُقونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@lxvii{۞ وَإِذِ استَسقىٰ موسىٰ لِقَومِهِ فَقُلنَا اضرِب بِعَصاكَ الحَجَرَ ۖ فَانفَجَرَت مِنهُ اثنَتا عَشرَةَ عَينًا ۖ قَد عَلِمَ كُلُّ أُناسٍ مَشرَبَهُم ۖ كُلوا وَاشرَبوا مِن رِزقِ اللَّهِ وَلا تَعثَوا فِي الأَرضِ مُفسِدينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@lxviii{وَإِذ قُلتُم يا موسىٰ لَن نَصبِرَ عَلىٰ طَعامٍ واحِدٍ فَادعُ لَنا رَبَّكَ يُخرِج لَنا مِمّا تُنبِتُ الأَرضُ مِن بَقلِها وَقِثّائِها وَفومِها وَعَدَسِها وَبَصَلِها ۖ قالَ أَتَستَبدِلونَ الَّذي هُوَ أَدنىٰ بِالَّذي هُوَ خَيرٌ ۚ اهبِطوا مِصرًا فَإِنَّ لَكُم ما سَأَلتُم ۗ وَضُرِبَت عَلَيهِمُ الذِّلَّةُ وَالمَسكَنَةُ وَباءوا بِغَضَبٍ مِنَ اللَّهِ ۗ ذٰلِكَ بِأَنَّهُم كانوا يَكفُرونَ بِآياتِ اللَّهِ وَيَقتُلونَ النَّبِيّينَ بِغَيرِ الحَقِّ ۗ ذٰلِكَ بِما عَصَوا وَكانوا يَعتَدونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@lxix{إِنَّ الَّذينَ آمَنوا وَالَّذينَ هادوا وَالنَّصارىٰ وَالصّابِئينَ مَن آمَنَ بِاللَّهِ وَاليَومِ الآخِرِ وَعَمِلَ صالِحًا فَلَهُم أَجرُهُم عِندَ رَبِّهِم وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@lxx{وَإِذ أَخَذنا ميثاقَكُم وَرَفَعنا فَوقَكُمُ الطّورَ خُذوا ما آتَيناكُم بِقُوَّةٍ وَاذكُروا ما فيهِ لَعَلَّكُم تَتَّقونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@lxxi{ثُمَّ تَوَلَّيتُم مِن بَعدِ ذٰلِكَ ۖ فَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ لَكُنتُم مِنَ الخاسِرينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@lxxii{وَلَقَد عَلِمتُمُ الَّذينَ اعتَدَوا مِنكُم فِي السَّبتِ فَقُلنا لَهُم كونوا قِرَدَةً خاسِئينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@lxxiii{فَجَعَلناها نَكالًا لِما بَينَ يَدَيها وَما خَلفَها وَمَوعِظَةً لِلمُتَّقينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@lxxiv{وَإِذ قالَ موسىٰ لِقَومِهِ إِنَّ اللَّهَ يَأمُرُكُم أَن تَذبَحوا بَقَرَةً ۖ قالوا أَتَتَّخِذُنا هُزُوًا ۖ قالَ أَعوذُ بِاللَّهِ أَن أَكونَ مِنَ الجاهِلينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@lxxv{قالُوا ادعُ لَنا رَبَّكَ يُبَيِّن لَنا ما هِيَ ۚ قالَ إِنَّهُ يَقولُ إِنَّها بَقَرَةٌ لا فارِضٌ وَلا بِكرٌ عَوانٌ بَينَ ذٰلِكَ ۖ فَافعَلوا ما تُؤمَرونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@lxxvi{قالُوا ادعُ لَنا رَبَّكَ يُبَيِّن لَنا ما لَونُها ۚ قالَ إِنَّهُ يَقولُ إِنَّها بَقَرَةٌ صَفراءُ فاقِعٌ لَونُها تَسُرُّ النّاظِرينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@lxxvii{قالُوا ادعُ لَنا رَبَّكَ يُبَيِّن لَنا ما هِيَ إِنَّ البَقَرَ تَشابَهَ عَلَينا وَإِنّا إِن شاءَ اللَّهُ لَمُهتَدونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@lxxviii{قالَ إِنَّهُ يَقولُ إِنَّها بَقَرَةٌ لا ذَلولٌ تُثيرُ الأَرضَ وَلا تَسقِي الحَرثَ مُسَلَّمَةٌ لا شِيَةَ فيها ۚ قالُوا الآنَ جِئتَ بِالحَقِّ ۚ فَذَبَحوها وَما كادوا يَفعَلونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@lxxix{وَإِذ قَتَلتُم نَفسًا فَادّارَأتُم فيها ۖ وَاللَّهُ مُخرِجٌ ما كُنتُم تَكتُمونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@lxxx{فَقُلنَا اضرِبوهُ بِبَعضِها ۚ كَذٰلِكَ يُحيِي اللَّهُ المَوتىٰ وَيُريكُم آياتِهِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@lxxxi{ثُمَّ قَسَت قُلوبُكُم مِن بَعدِ ذٰلِكَ فَهِيَ كَالحِجارَةِ أَو أَشَدُّ قَسوَةً ۚ وَإِنَّ مِنَ الحِجارَةِ لَما يَتَفَجَّرُ مِنهُ الأَنهارُ ۚ وَإِنَّ مِنها لَما يَشَّقَّقُ فَيَخرُجُ مِنهُ الماءُ ۚ وَإِنَّ مِنها لَما يَهبِطُ مِن خَشيَةِ اللَّهِ ۗ وَمَا اللَّهُ بِغافِلٍ عَمّا تَعمَلونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@lxxxii{۞ أَفَتَطمَعونَ أَن يُؤمِنوا لَكُم وَقَد كانَ فَريقٌ مِنهُم يَسمَعونَ كَلامَ اللَّهِ ثُمَّ يُحَرِّفونَهُ مِن بَعدِ ما عَقَلوهُ وَهُم يَعلَمونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@lxxxiii{وَإِذا لَقُوا الَّذينَ آمَنوا قالوا آمَنّا وَإِذا خَلا بَعضُهُم إِلىٰ بَعضٍ قالوا أَتُحَدِّثونَهُم بِما فَتَحَ اللَّهُ عَلَيكُم لِيُحاجّوكُم بِهِ عِندَ رَبِّكُم ۚ أَفَلا تَعقِلونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@lxxxiv{أَوَلا يَعلَمونَ أَنَّ اللَّهَ يَعلَمُ ما يُسِرّونَ وَما يُعلِنونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@lxxxv{وَمِنهُم أُمِّيّونَ لا يَعلَمونَ الكِتابَ إِلّا أَمانِيَّ وَإِن هُم إِلّا يَظُنّونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@lxxxvi{فَوَيلٌ لِلَّذينَ يَكتُبونَ الكِتابَ بِأَيديهِم ثُمَّ يَقولونَ هٰذا مِن عِندِ اللَّهِ لِيَشتَروا بِهِ ثَمَنًا قَليلًا ۖ فَوَيلٌ لَهُم مِمّا كَتَبَت أَيديهِم وَوَيلٌ لَهُم مِمّا يَكسِبونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@lxxxvii{وَقالوا لَن تَمَسَّنَا النّارُ إِلّا أَيّامًا مَعدودَةً ۚ قُل أَتَّخَذتُم عِندَ اللَّهِ عَهدًا فَلَن يُخلِفَ اللَّهُ عَهدَهُ ۖ أَم تَقولونَ عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@lxxxviii{بَلىٰ مَن كَسَبَ سَيِّئَةً وَأَحاطَت بِهِ خَطيئَتُهُ فَأُولٰئِكَ أَصحابُ النّارِ ۖ هُم فيها خالِدونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@lxxxix{وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ أُولٰئِكَ أَصحابُ الجَنَّةِ ۖ هُم فيها خالِدونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@xc{وَإِذ أَخَذنا ميثاقَ بَني إِسرائيلَ لا تَعبُدونَ إِلَّا اللَّهَ وَبِالوالِدَينِ إِحسانًا وَذِي القُربىٰ وَاليَتامىٰ وَالمَساكينِ وَقولوا لِلنّاسِ حُسنًا وَأَقيمُوا الصَّلاةَ وَآتُوا الزَّكاةَ ثُمَّ تَوَلَّيتُم إِلّا قَليلًا مِنكُم وَأَنتُم مُعرِضونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@xci{وَإِذ أَخَذنا ميثاقَكُم لا تَسفِكونَ دِماءَكُم وَلا تُخرِجونَ أَنفُسَكُم مِن دِيارِكُم ثُمَّ أَقرَرتُم وَأَنتُم تَشهَدونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@xcii{ثُمَّ أَنتُم هٰؤُلاءِ تَقتُلونَ أَنفُسَكُم وَتُخرِجونَ فَريقًا مِنكُم مِن دِيارِهِم تَظاهَرونَ عَلَيهِم بِالإِثمِ وَالعُدوانِ وَإِن يَأتوكُم أُسارىٰ تُفادوهُم وَهُوَ مُحَرَّمٌ عَلَيكُم إِخراجُهُم ۚ أَفَتُؤمِنونَ بِبَعضِ الكِتابِ وَتَكفُرونَ بِبَعضٍ ۚ فَما جَزاءُ مَن يَفعَلُ ذٰلِكَ مِنكُم إِلّا خِزيٌ فِي الحَياةِ الدُّنيا ۖ وَيَومَ القِيامَةِ يُرَدّونَ إِلىٰ أَشَدِّ العَذابِ ۗ وَمَا اللَّهُ بِغافِلٍ عَمّا تَعمَلونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@xciii{أُولٰئِكَ الَّذينَ اشتَرَوُا الحَياةَ الدُّنيا بِالآخِرَةِ ۖ فَلا يُخَفَّفُ عَنهُمُ العَذابُ وَلا هُم يُنصَرونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@xciv{وَلَقَد آتَينا موسَى الكِتابَ وَقَفَّينا مِن بَعدِهِ بِالرُّسُلِ ۖ وَآتَينا عيسَى ابنَ مَريَمَ البَيِّناتِ وَأَيَّدناهُ بِروحِ القُدُسِ ۗ أَفَكُلَّما جاءَكُم رَسولٌ بِما لا تَهوىٰ أَنفُسُكُمُ استَكبَرتُم فَفَريقًا كَذَّبتُم وَفَريقًا تَقتُلونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@xcv{وَقالوا قُلوبُنا غُلفٌ ۚ بَل لَعَنَهُمُ اللَّهُ بِكُفرِهِم فَقَليلًا ما يُؤمِنونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@xcvi{وَلَمّا جاءَهُم كِتابٌ مِن عِندِ اللَّهِ مُصَدِّقٌ لِما مَعَهُم وَكانوا مِن قَبلُ يَستَفتِحونَ عَلَى الَّذينَ كَفَروا فَلَمّا جاءَهُم ما عَرَفوا كَفَروا بِهِ ۚ فَلَعنَةُ اللَّهِ عَلَى الكافِرينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@xcvii{بِئسَمَا اشتَرَوا بِهِ أَنفُسَهُم أَن يَكفُروا بِما أَنزَلَ اللَّهُ بَغيًا أَن يُنَزِّلَ اللَّهُ مِن فَضلِهِ عَلىٰ مَن يَشاءُ مِن عِبادِهِ ۖ فَباءوا بِغَضَبٍ عَلىٰ غَضَبٍ ۚ وَلِلكافِرينَ عَذابٌ مُهينٌ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@xcviii{وَإِذا قيلَ لَهُم آمِنوا بِما أَنزَلَ اللَّهُ قالوا نُؤمِنُ بِما أُنزِلَ عَلَينا وَيَكفُرونَ بِما وَراءَهُ وَهُوَ الحَقُّ مُصَدِّقًا لِما مَعَهُم ۗ قُل فَلِمَ تَقتُلونَ أَنبِياءَ اللَّهِ مِن قَبلُ إِن كُنتُم مُؤمِنينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@xcix{۞ وَلَقَد جاءَكُم موسىٰ بِالبَيِّناتِ ثُمَّ اتَّخَذتُمُ العِجلَ مِن بَعدِهِ وَأَنتُم ظالِمونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@c{وَإِذ أَخَذنا ميثاقَكُم وَرَفَعنا فَوقَكُمُ الطّورَ خُذوا ما آتَيناكُم بِقُوَّةٍ وَاسمَعوا ۖ قالوا سَمِعنا وَعَصَينا وَأُشرِبوا في قُلوبِهِمُ العِجلَ بِكُفرِهِم ۚ قُل بِئسَما يَأمُرُكُم بِهِ إيمانُكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@ci{قُل إِن كانَت لَكُمُ الدّارُ الآخِرَةُ عِندَ اللَّهِ خالِصَةً مِن دونِ النّاسِ فَتَمَنَّوُا المَوتَ إِن كُنتُم صادِقينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@cii{وَلَن يَتَمَنَّوهُ أَبَدًا بِما قَدَّمَت أَيديهِم ۗ وَاللَّهُ عَليمٌ بِالظّالِمينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@ciii{وَلَتَجِدَنَّهُم أَحرَصَ النّاسِ عَلىٰ حَياةٍ وَمِنَ الَّذينَ أَشرَكوا ۚ يَوَدُّ أَحَدُهُم لَو يُعَمَّرُ أَلفَ سَنَةٍ وَما هُوَ بِمُزَحزِحِهِ مِنَ العَذابِ أَن يُعَمَّرَ ۗ وَاللَّهُ بَصيرٌ بِما يَعمَلونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@civ{قُل مَن كانَ عَدُوًّا لِجِبريلَ فَإِنَّهُ نَزَّلَهُ عَلىٰ قَلبِكَ بِإِذنِ اللَّهِ مُصَدِّقًا لِما بَينَ يَدَيهِ وَهُدًى وَبُشرىٰ لِلمُؤمِنينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@cv{مَن كانَ عَدُوًّا لِلَّهِ وَمَلائِكَتِهِ وَرُسُلِهِ وَجِبريلَ وَميكالَ فَإِنَّ اللَّهَ عَدُوٌّ لِلكافِرينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@cvi{وَلَقَد أَنزَلنا إِلَيكَ آياتٍ بَيِّناتٍ ۖ وَما يَكفُرُ بِها إِلَّا الفاسِقونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@cvii{أَوَكُلَّما عاهَدوا عَهدًا نَبَذَهُ فَريقٌ مِنهُم ۚ بَل أَكثَرُهُم لا يُؤمِنونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@cviii{وَلَمّا جاءَهُم رَسولٌ مِن عِندِ اللَّهِ مُصَدِّقٌ لِما مَعَهُم نَبَذَ فَريقٌ مِنَ الَّذينَ أوتُوا الكِتابَ كِتابَ اللَّهِ وَراءَ ظُهورِهِم كَأَنَّهُم لا يَعلَمونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@cix{وَاتَّبَعوا ما تَتلُو الشَّياطينُ عَلىٰ مُلكِ سُلَيمانَ ۖ وَما كَفَرَ سُلَيمانُ وَلٰكِنَّ الشَّياطينَ كَفَروا يُعَلِّمونَ النّاسَ السِّحرَ وَما أُنزِلَ عَلَى المَلَكَينِ بِبابِلَ هاروتَ وَماروتَ ۚ وَما يُعَلِّمانِ مِن أَحَدٍ حَتّىٰ يَقولا إِنَّما نَحنُ فِتنَةٌ فَلا تَكفُر ۖ فَيَتَعَلَّمونَ مِنهُما ما يُفَرِّقونَ بِهِ بَينَ المَرءِ وَزَوجِهِ ۚ وَما هُم بِضارّينَ بِهِ مِن أَحَدٍ إِلّا بِإِذنِ اللَّهِ ۚ وَيَتَعَلَّمونَ ما يَضُرُّهُم وَلا يَنفَعُهُم ۚ وَلَقَد عَلِموا لَمَنِ اشتَراهُ ما لَهُ فِي الآخِرَةِ مِن خَلاقٍ ۚ وَلَبِئسَ ما شَرَوا بِهِ أَنفُسَهُم ۚ لَو كانوا يَعلَمونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@cx{وَلَو أَنَّهُم آمَنوا وَاتَّقَوا لَمَثوبَةٌ مِن عِندِ اللَّهِ خَيرٌ ۖ لَو كانوا يَعلَمونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@cxi{يا أَيُّهَا الَّذينَ آمَنوا لا تَقولوا راعِنا وَقولُوا انظُرنا وَاسمَعوا ۗ وَلِلكافِرينَ عَذابٌ أَليمٌ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@cxii{ما يَوَدُّ الَّذينَ كَفَروا مِن أَهلِ الكِتابِ وَلَا المُشرِكينَ أَن يُنَزَّلَ عَلَيكُم مِن خَيرٍ مِن رَبِّكُم ۗ وَاللَّهُ يَختَصُّ بِرَحمَتِهِ مَن يَشاءُ ۚ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@cxiii{۞ ما نَنسَخ مِن آيَةٍ أَو نُنسِها نَأتِ بِخَيرٍ مِنها أَو مِثلِها ۗ أَلَم تَعلَم أَنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@cxiv{أَلَم تَعلَم أَنَّ اللَّهَ لَهُ مُلكُ السَّماواتِ وَالأَرضِ ۗ وَما لَكُم مِن دونِ اللَّهِ مِن وَلِيٍّ وَلا نَصيرٍ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@cxv{أَم تُريدونَ أَن تَسأَلوا رَسولَكُم كَما سُئِلَ موسىٰ مِن قَبلُ ۗ وَمَن يَتَبَدَّلِ الكُفرَ بِالإيمانِ فَقَد ضَلَّ سَواءَ السَّبيلِ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@cxvi{وَدَّ كَثيرٌ مِن أَهلِ الكِتابِ لَو يَرُدّونَكُم مِن بَعدِ إيمانِكُم كُفّارًا حَسَدًا مِن عِندِ أَنفُسِهِم مِن بَعدِ ما تَبَيَّنَ لَهُمُ الحَقُّ ۖ فَاعفوا وَاصفَحوا حَتّىٰ يَأتِيَ اللَّهُ بِأَمرِهِ ۗ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@cxvii{وَأَقيمُوا الصَّلاةَ وَآتُوا الزَّكاةَ ۚ وَما تُقَدِّموا لِأَنفُسِكُم مِن خَيرٍ تَجِدوهُ عِندَ اللَّهِ ۗ إِنَّ اللَّهَ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@cxviii{وَقالوا لَن يَدخُلَ الجَنَّةَ إِلّا مَن كانَ هودًا أَو نَصارىٰ ۗ تِلكَ أَمانِيُّهُم ۗ قُل هاتوا بُرهانَكُم إِن كُنتُم صادِقينَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@cxix{بَلىٰ مَن أَسلَمَ وَجهَهُ لِلَّهِ وَهُوَ مُحسِنٌ فَلَهُ أَجرُهُ عِندَ رَبِّهِ وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@cxx{وَقالَتِ اليَهودُ لَيسَتِ النَّصارىٰ عَلىٰ شَيءٍ وَقالَتِ النَّصارىٰ لَيسَتِ اليَهودُ عَلىٰ شَيءٍ وَهُم يَتلونَ الكِتابَ ۗ كَذٰلِكَ قالَ الَّذينَ لا يَعلَمونَ مِثلَ قَولِهِم ۚ فَاللَّهُ يَحكُمُ بَينَهُم يَومَ القِيامَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@cxxi{وَمَن أَظلَمُ مِمَّن مَنَعَ مَساجِدَ اللَّهِ أَن يُذكَرَ فيهَا اسمُهُ وَسَعىٰ في خَرابِها ۚ أُولٰئِكَ ما كانَ لَهُم أَن يَدخُلوها إِلّا خائِفينَ ۚ لَهُم فِي الدُّنيا خِزيٌ وَلَهُم فِي الآخِرَةِ عَذابٌ عَظيمٌ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@cxxii{وَلِلَّهِ المَشرِقُ وَالمَغرِبُ ۚ فَأَينَما تُوَلّوا فَثَمَّ وَجهُ اللَّهِ ۚ إِنَّ اللَّهَ واسِعٌ عَليمٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@cxxiii{وَقالُوا اتَّخَذَ اللَّهُ وَلَدًا ۗ سُبحانَهُ ۖ بَل لَهُ ما فِي السَّماواتِ وَالأَرضِ ۖ كُلٌّ لَهُ قانِتونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@cxxiv{بَديعُ السَّماواتِ وَالأَرضِ ۖ وَإِذا قَضىٰ أَمرًا فَإِنَّما يَقولُ لَهُ كُن فَيَكونُ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@cxxv{وَقالَ الَّذينَ لا يَعلَمونَ لَولا يُكَلِّمُنَا اللَّهُ أَو تَأتينا آيَةٌ ۗ كَذٰلِكَ قالَ الَّذينَ مِن قَبلِهِم مِثلَ قَولِهِم ۘ تَشابَهَت قُلوبُهُم ۗ قَد بَيَّنَّا الآياتِ لِقَومٍ يوقِنونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@cxxvi{إِنّا أَرسَلناكَ بِالحَقِّ بَشيرًا وَنَذيرًا ۖ وَلا تُسأَلُ عَن أَصحابِ الجَحيمِ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@cxxvii{وَلَن تَرضىٰ عَنكَ اليَهودُ وَلَا النَّصارىٰ حَتّىٰ تَتَّبِعَ مِلَّتَهُم ۗ قُل إِنَّ هُدَى اللَّهِ هُوَ الهُدىٰ ۗ وَلَئِنِ اتَّبَعتَ أَهواءَهُم بَعدَ الَّذي جاءَكَ مِنَ العِلمِ ۙ ما لَكَ مِنَ اللَّهِ مِن وَلِيٍّ وَلا نَصيرٍ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@cxxviii{الَّذينَ آتَيناهُمُ الكِتابَ يَتلونَهُ حَقَّ تِلاوَتِهِ أُولٰئِكَ يُؤمِنونَ بِهِ ۗ وَمَن يَكفُر بِهِ فَأُولٰئِكَ هُمُ الخاسِرونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@cxxix{يا بَني إِسرائيلَ اذكُروا نِعمَتِيَ الَّتي أَنعَمتُ عَلَيكُم وَأَنّي فَضَّلتُكُم عَلَى العالَمينَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@cxxx{وَاتَّقوا يَومًا لا تَجزي نَفسٌ عَن نَفسٍ شَيئًا وَلا يُقبَلُ مِنها عَدلٌ وَلا تَنفَعُها شَفاعَةٌ وَلا هُم يُنصَرونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@cxxxi{۞ وَإِذِ ابتَلىٰ إِبراهيمَ رَبُّهُ بِكَلِماتٍ فَأَتَمَّهُنَّ ۖ قالَ إِنّي جاعِلُكَ لِلنّاسِ إِمامًا ۖ قالَ وَمِن ذُرِّيَّتي ۖ قالَ لا يَنالُ عَهدِي الظّالِمينَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@cxxxii{وَإِذ جَعَلنَا البَيتَ مَثابَةً لِلنّاسِ وَأَمنًا وَاتَّخِذوا مِن مَقامِ إِبراهيمَ مُصَلًّى ۖ وَعَهِدنا إِلىٰ إِبراهيمَ وَإِسماعيلَ أَن طَهِّرا بَيتِيَ لِلطّائِفينَ وَالعاكِفينَ وَالرُّكَّعِ السُّجودِ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@cxxxiii{وَإِذ قالَ إِبراهيمُ رَبِّ اجعَل هٰذا بَلَدًا آمِنًا وَارزُق أَهلَهُ مِنَ الثَّمَراتِ مَن آمَنَ مِنهُم بِاللَّهِ وَاليَومِ الآخِرِ ۖ قالَ وَمَن كَفَرَ فَأُمَتِّعُهُ قَليلًا ثُمَّ أَضطَرُّهُ إِلىٰ عَذابِ النّارِ ۖ وَبِئسَ المَصيرُ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@cxxxiv{وَإِذ يَرفَعُ إِبراهيمُ القَواعِدَ مِنَ البَيتِ وَإِسماعيلُ رَبَّنا تَقَبَّل مِنّا ۖ إِنَّكَ أَنتَ السَّميعُ العَليمُ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@cxxxv{رَبَّنا وَاجعَلنا مُسلِمَينِ لَكَ وَمِن ذُرِّيَّتِنا أُمَّةً مُسلِمَةً لَكَ وَأَرِنا مَناسِكَنا وَتُب عَلَينا ۖ إِنَّكَ أَنتَ التَّوّابُ الرَّحيمُ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@cxxxvi{رَبَّنا وَابعَث فيهِم رَسولًا مِنهُم يَتلو عَلَيهِم آياتِكَ وَيُعَلِّمُهُمُ الكِتابَ وَالحِكمَةَ وَيُزَكّيهِم ۚ إِنَّكَ أَنتَ العَزيزُ الحَكيمُ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@cxxxvii{وَمَن يَرغَبُ عَن مِلَّةِ إِبراهيمَ إِلّا مَن سَفِهَ نَفسَهُ ۚ وَلَقَدِ اصطَفَيناهُ فِي الدُّنيا ۖ وَإِنَّهُ فِي الآخِرَةِ لَمِنَ الصّالِحينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@cxxxviii{إِذ قالَ لَهُ رَبُّهُ أَسلِم ۖ قالَ أَسلَمتُ لِرَبِّ العالَمينَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@cxxxix{وَوَصّىٰ بِها إِبراهيمُ بَنيهِ وَيَعقوبُ يا بَنِيَّ إِنَّ اللَّهَ اصطَفىٰ لَكُمُ الدّينَ فَلا تَموتُنَّ إِلّا وَأَنتُم مُسلِمونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@cxl{أَم كُنتُم شُهَداءَ إِذ حَضَرَ يَعقوبَ المَوتُ إِذ قالَ لِبَنيهِ ما تَعبُدونَ مِن بَعدي قالوا نَعبُدُ إِلٰهَكَ وَإِلٰهَ آبائِكَ إِبراهيمَ وَإِسماعيلَ وَإِسحاقَ إِلٰهًا واحِدًا وَنَحنُ لَهُ مُسلِمونَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@cxli{تِلكَ أُمَّةٌ قَد خَلَت ۖ لَها ما كَسَبَت وَلَكُم ما كَسَبتُم ۖ وَلا تُسأَلونَ عَمّا كانوا يَعمَلونَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@cxlii{وَقالوا كونوا هودًا أَو نَصارىٰ تَهتَدوا ۗ قُل بَل مِلَّةَ إِبراهيمَ حَنيفًا ۖ وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@cxliii{قولوا آمَنّا بِاللَّهِ وَما أُنزِلَ إِلَينا وَما أُنزِلَ إِلىٰ إِبراهيمَ وَإِسماعيلَ وَإِسحاقَ وَيَعقوبَ وَالأَسباطِ وَما أوتِيَ موسىٰ وَعيسىٰ وَما أوتِيَ النَّبِيّونَ مِن رَبِّهِم لا نُفَرِّقُ بَينَ أَحَدٍ مِنهُم وَنَحنُ لَهُ مُسلِمونَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@cxliv{فَإِن آمَنوا بِمِثلِ ما آمَنتُم بِهِ فَقَدِ اهتَدَوا ۖ وَإِن تَوَلَّوا فَإِنَّما هُم في شِقاقٍ ۖ فَسَيَكفيكَهُمُ اللَّهُ ۚ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@cxlv{صِبغَةَ اللَّهِ ۖ وَمَن أَحسَنُ مِنَ اللَّهِ صِبغَةً ۖ وَنَحنُ لَهُ عابِدونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@cxlvi{قُل أَتُحاجّونَنا فِي اللَّهِ وَهُوَ رَبُّنا وَرَبُّكُم وَلَنا أَعمالُنا وَلَكُم أَعمالُكُم وَنَحنُ لَهُ مُخلِصونَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@cxlvii{أَم تَقولونَ إِنَّ إِبراهيمَ وَإِسماعيلَ وَإِسحاقَ وَيَعقوبَ وَالأَسباطَ كانوا هودًا أَو نَصارىٰ ۗ قُل أَأَنتُم أَعلَمُ أَمِ اللَّهُ ۗ وَمَن أَظلَمُ مِمَّن كَتَمَ شَهادَةً عِندَهُ مِنَ اللَّهِ ۗ وَمَا اللَّهُ بِغافِلٍ عَمّا تَعمَلونَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@cxlviii{تِلكَ أُمَّةٌ قَد خَلَت ۖ لَها ما كَسَبَت وَلَكُم ما كَسَبتُم ۖ وَلا تُسأَلونَ عَمّا كانوا يَعمَلونَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@cxlix{۞ سَيَقولُ السُّفَهاءُ مِنَ النّاسِ ما وَلّاهُم عَن قِبلَتِهِمُ الَّتي كانوا عَلَيها ۚ قُل لِلَّهِ المَشرِقُ وَالمَغرِبُ ۚ يَهدي مَن يَشاءُ إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@cl{وَكَذٰلِكَ جَعَلناكُم أُمَّةً وَسَطًا لِتَكونوا شُهَداءَ عَلَى النّاسِ وَيَكونَ الرَّسولُ عَلَيكُم شَهيدًا ۗ وَما جَعَلنَا القِبلَةَ الَّتي كُنتَ عَلَيها إِلّا لِنَعلَمَ مَن يَتَّبِعُ الرَّسولَ مِمَّن يَنقَلِبُ عَلىٰ عَقِبَيهِ ۚ وَإِن كانَت لَكَبيرَةً إِلّا عَلَى الَّذينَ هَدَى اللَّهُ ۗ وَما كانَ اللَّهُ لِيُضيعَ إيمانَكُم ۚ إِنَّ اللَّهَ بِالنّاسِ لَرَءوفٌ رَحيمٌ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@cli{قَد نَرىٰ تَقَلُّبَ وَجهِكَ فِي السَّماءِ ۖ فَلَنُوَلِّيَنَّكَ قِبلَةً تَرضاها ۚ فَوَلِّ وَجهَكَ شَطرَ المَسجِدِ الحَرامِ ۚ وَحَيثُ ما كُنتُم فَوَلّوا وُجوهَكُم شَطرَهُ ۗ وَإِنَّ الَّذينَ أوتُوا الكِتابَ لَيَعلَمونَ أَنَّهُ الحَقُّ مِن رَبِّهِم ۗ وَمَا اللَّهُ بِغافِلٍ عَمّا يَعمَلونَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@clii{وَلَئِن أَتَيتَ الَّذينَ أوتُوا الكِتابَ بِكُلِّ آيَةٍ ما تَبِعوا قِبلَتَكَ ۚ وَما أَنتَ بِتابِعٍ قِبلَتَهُم ۚ وَما بَعضُهُم بِتابِعٍ قِبلَةَ بَعضٍ ۚ وَلَئِنِ اتَّبَعتَ أَهواءَهُم مِن بَعدِ ما جاءَكَ مِنَ العِلمِ ۙ إِنَّكَ إِذًا لَمِنَ الظّالِمينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@cliii{الَّذينَ آتَيناهُمُ الكِتابَ يَعرِفونَهُ كَما يَعرِفونَ أَبناءَهُم ۖ وَإِنَّ فَريقًا مِنهُم لَيَكتُمونَ الحَقَّ وَهُم يَعلَمونَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@cliv{الحَقُّ مِن رَبِّكَ ۖ فَلا تَكونَنَّ مِنَ المُمتَرينَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@clv{وَلِكُلٍّ وِجهَةٌ هُوَ مُوَلّيها ۖ فَاستَبِقُوا الخَيراتِ ۚ أَينَ ما تَكونوا يَأتِ بِكُمُ اللَّهُ جَميعًا ۚ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@clvi{وَمِن حَيثُ خَرَجتَ فَوَلِّ وَجهَكَ شَطرَ المَسجِدِ الحَرامِ ۖ وَإِنَّهُ لَلحَقُّ مِن رَبِّكَ ۗ وَمَا اللَّهُ بِغافِلٍ عَمّا تَعمَلونَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@clvii{وَمِن حَيثُ خَرَجتَ فَوَلِّ وَجهَكَ شَطرَ المَسجِدِ الحَرامِ ۚ وَحَيثُ ما كُنتُم فَوَلّوا وُجوهَكُم شَطرَهُ لِئَلّا يَكونَ لِلنّاسِ عَلَيكُم حُجَّةٌ إِلَّا الَّذينَ ظَلَموا مِنهُم فَلا تَخشَوهُم وَاخشَوني وَلِأُتِمَّ نِعمَتي عَلَيكُم وَلَعَلَّكُم تَهتَدونَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@clviii{كَما أَرسَلنا فيكُم رَسولًا مِنكُم يَتلو عَلَيكُم آياتِنا وَيُزَكّيكُم وَيُعَلِّمُكُمُ الكِتابَ وَالحِكمَةَ وَيُعَلِّمُكُم ما لَم تَكونوا تَعلَمونَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@clix{فَاذكُروني أَذكُركُم وَاشكُروا لي وَلا تَكفُرونِ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@clx{يا أَيُّهَا الَّذينَ آمَنُوا استَعينوا بِالصَّبرِ وَالصَّلاةِ ۚ إِنَّ اللَّهَ مَعَ الصّابِرينَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@clxi{وَلا تَقولوا لِمَن يُقتَلُ في سَبيلِ اللَّهِ أَمواتٌ ۚ بَل أَحياءٌ وَلٰكِن لا تَشعُرونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@clxii{وَلَنَبلُوَنَّكُم بِشَيءٍ مِنَ الخَوفِ وَالجوعِ وَنَقصٍ مِنَ الأَموالِ وَالأَنفُسِ وَالثَّمَراتِ ۗ وَبَشِّرِ الصّابِرينَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@clxiii{الَّذينَ إِذا أَصابَتهُم مُصيبَةٌ قالوا إِنّا لِلَّهِ وَإِنّا إِلَيهِ راجِعونَ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@clxiv{أُولٰئِكَ عَلَيهِم صَلَواتٌ مِن رَبِّهِم وَرَحمَةٌ ۖ وَأُولٰئِكَ هُمُ المُهتَدونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@clxv{۞ إِنَّ الصَّفا وَالمَروَةَ مِن شَعائِرِ اللَّهِ ۖ فَمَن حَجَّ البَيتَ أَوِ اعتَمَرَ فَلا جُناحَ عَلَيهِ أَن يَطَّوَّفَ بِهِما ۚ وَمَن تَطَوَّعَ خَيرًا فَإِنَّ اللَّهَ شاكِرٌ عَليمٌ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@clxvi{إِنَّ الَّذينَ يَكتُمونَ ما أَنزَلنا مِنَ البَيِّناتِ وَالهُدىٰ مِن بَعدِ ما بَيَّنّاهُ لِلنّاسِ فِي الكِتابِ ۙ أُولٰئِكَ يَلعَنُهُمُ اللَّهُ وَيَلعَنُهُمُ اللّاعِنونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@clxvii{إِلَّا الَّذينَ تابوا وَأَصلَحوا وَبَيَّنوا فَأُولٰئِكَ أَتوبُ عَلَيهِم ۚ وَأَنَا التَّوّابُ الرَّحيمُ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@clxviii{إِنَّ الَّذينَ كَفَروا وَماتوا وَهُم كُفّارٌ أُولٰئِكَ عَلَيهِم لَعنَةُ اللَّهِ وَالمَلائِكَةِ وَالنّاسِ أَجمَعينَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@clxix{خالِدينَ فيها ۖ لا يُخَفَّفُ عَنهُمُ العَذابُ وَلا هُم يُنظَرونَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@clxx{وَإِلٰهُكُم إِلٰهٌ واحِدٌ ۖ لا إِلٰهَ إِلّا هُوَ الرَّحمٰنُ الرَّحيمُ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@clxxi{إِنَّ في خَلقِ السَّماواتِ وَالأَرضِ وَاختِلافِ اللَّيلِ وَالنَّهارِ وَالفُلكِ الَّتي تَجري فِي البَحرِ بِما يَنفَعُ النّاسَ وَما أَنزَلَ اللَّهُ مِنَ السَّماءِ مِن ماءٍ فَأَحيا بِهِ الأَرضَ بَعدَ مَوتِها وَبَثَّ فيها مِن كُلِّ دابَّةٍ وَتَصريفِ الرِّياحِ وَالسَّحابِ المُسَخَّرِ بَينَ السَّماءِ وَالأَرضِ لَآياتٍ لِقَومٍ يَعقِلونَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@clxxii{وَمِنَ النّاسِ مَن يَتَّخِذُ مِن دونِ اللَّهِ أَندادًا يُحِبّونَهُم كَحُبِّ اللَّهِ ۖ وَالَّذينَ آمَنوا أَشَدُّ حُبًّا لِلَّهِ ۗ وَلَو يَرَى الَّذينَ ظَلَموا إِذ يَرَونَ العَذابَ أَنَّ القُوَّةَ لِلَّهِ جَميعًا وَأَنَّ اللَّهَ شَديدُ العَذابِ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@clxxiii{إِذ تَبَرَّأَ الَّذينَ اتُّبِعوا مِنَ الَّذينَ اتَّبَعوا وَرَأَوُا العَذابَ وَتَقَطَّعَت بِهِمُ الأَسبابُ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@clxxiv{وَقالَ الَّذينَ اتَّبَعوا لَو أَنَّ لَنا كَرَّةً فَنَتَبَرَّأَ مِنهُم كَما تَبَرَّءوا مِنّا ۗ كَذٰلِكَ يُريهِمُ اللَّهُ أَعمالَهُم حَسَراتٍ عَلَيهِم ۖ وَما هُم بِخارِجينَ مِنَ النّارِ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@clxxv{يا أَيُّهَا النّاسُ كُلوا مِمّا فِي الأَرضِ حَلالًا طَيِّبًا وَلا تَتَّبِعوا خُطُواتِ الشَّيطانِ ۚ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@clxxvi{إِنَّما يَأمُرُكُم بِالسّوءِ وَالفَحشاءِ وَأَن تَقولوا عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@clxxvii{وَإِذا قيلَ لَهُمُ اتَّبِعوا ما أَنزَلَ اللَّهُ قالوا بَل نَتَّبِعُ ما أَلفَينا عَلَيهِ آباءَنا ۗ أَوَلَو كانَ آباؤُهُم لا يَعقِلونَ شَيئًا وَلا يَهتَدونَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@clxxviii{وَمَثَلُ الَّذينَ كَفَروا كَمَثَلِ الَّذي يَنعِقُ بِما لا يَسمَعُ إِلّا دُعاءً وَنِداءً ۚ صُمٌّ بُكمٌ عُميٌ فَهُم لا يَعقِلونَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@clxxix{يا أَيُّهَا الَّذينَ آمَنوا كُلوا مِن طَيِّباتِ ما رَزَقناكُم وَاشكُروا لِلَّهِ إِن كُنتُم إِيّاهُ تَعبُدونَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@clxxx{إِنَّما حَرَّمَ عَلَيكُمُ المَيتَةَ وَالدَّمَ وَلَحمَ الخِنزيرِ وَما أُهِلَّ بِهِ لِغَيرِ اللَّهِ ۖ فَمَنِ اضطُرَّ غَيرَ باغٍ وَلا عادٍ فَلا إِثمَ عَلَيهِ ۚ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@clxxxi{إِنَّ الَّذينَ يَكتُمونَ ما أَنزَلَ اللَّهُ مِنَ الكِتابِ وَيَشتَرونَ بِهِ ثَمَنًا قَليلًا ۙ أُولٰئِكَ ما يَأكُلونَ في بُطونِهِم إِلَّا النّارَ وَلا يُكَلِّمُهُمُ اللَّهُ يَومَ القِيامَةِ وَلا يُزَكّيهِم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@clxxxii{أُولٰئِكَ الَّذينَ اشتَرَوُا الضَّلالَةَ بِالهُدىٰ وَالعَذابَ بِالمَغفِرَةِ ۚ فَما أَصبَرَهُم عَلَى النّارِ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@clxxxiii{ذٰلِكَ بِأَنَّ اللَّهَ نَزَّلَ الكِتابَ بِالحَقِّ ۗ وَإِنَّ الَّذينَ اختَلَفوا فِي الكِتابِ لَفي شِقاقٍ بَعيدٍ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@clxxxiv{۞ لَيسَ البِرَّ أَن تُوَلّوا وُجوهَكُم قِبَلَ المَشرِقِ وَالمَغرِبِ وَلٰكِنَّ البِرَّ مَن آمَنَ بِاللَّهِ وَاليَومِ الآخِرِ وَالمَلائِكَةِ وَالكِتابِ وَالنَّبِيّينَ وَآتَى المالَ عَلىٰ حُبِّهِ ذَوِي القُربىٰ وَاليَتامىٰ وَالمَساكينَ وَابنَ السَّبيلِ وَالسّائِلينَ وَفِي الرِّقابِ وَأَقامَ الصَّلاةَ وَآتَى الزَّكاةَ وَالموفونَ بِعَهدِهِم إِذا عاهَدوا ۖ وَالصّابِرينَ فِي البَأساءِ وَالضَّرّاءِ وَحينَ البَأسِ ۗ أُولٰئِكَ الَّذينَ صَدَقوا ۖ وَأُولٰئِكَ هُمُ المُتَّقونَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@clxxxv{يا أَيُّهَا الَّذينَ آمَنوا كُتِبَ عَلَيكُمُ القِصاصُ فِي القَتلَى ۖ الحُرُّ بِالحُرِّ وَالعَبدُ بِالعَبدِ وَالأُنثىٰ بِالأُنثىٰ ۚ فَمَن عُفِيَ لَهُ مِن أَخيهِ شَيءٌ فَاتِّباعٌ بِالمَعروفِ وَأَداءٌ إِلَيهِ بِإِحسانٍ ۗ ذٰلِكَ تَخفيفٌ مِن رَبِّكُم وَرَحمَةٌ ۗ فَمَنِ اعتَدىٰ بَعدَ ذٰلِكَ فَلَهُ عَذابٌ أَليمٌ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@clxxxvi{وَلَكُم فِي القِصاصِ حَياةٌ يا أُولِي الأَلبابِ لَعَلَّكُم تَتَّقونَ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@clxxxvii{كُتِبَ عَلَيكُم إِذا حَضَرَ أَحَدَكُمُ المَوتُ إِن تَرَكَ خَيرًا الوَصِيَّةُ لِلوالِدَينِ وَالأَقرَبينَ بِالمَعروفِ ۖ حَقًّا عَلَى المُتَّقينَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@clxxxviii{فَمَن بَدَّلَهُ بَعدَما سَمِعَهُ فَإِنَّما إِثمُهُ عَلَى الَّذينَ يُبَدِّلونَهُ ۚ إِنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@clxxxix{فَمَن خافَ مِن موصٍ جَنَفًا أَو إِثمًا فَأَصلَحَ بَينَهُم فَلا إِثمَ عَلَيهِ ۚ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@cxc{يا أَيُّهَا الَّذينَ آمَنوا كُتِبَ عَلَيكُمُ الصِّيامُ كَما كُتِبَ عَلَى الَّذينَ مِن قَبلِكُم لَعَلَّكُم تَتَّقونَ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@cxci{أَيّامًا مَعدوداتٍ ۚ فَمَن كانَ مِنكُم مَريضًا أَو عَلىٰ سَفَرٍ فَعِدَّةٌ مِن أَيّامٍ أُخَرَ ۚ وَعَلَى الَّذينَ يُطيقونَهُ فِديَةٌ طَعامُ مِسكينٍ ۖ فَمَن تَطَوَّعَ خَيرًا فَهُوَ خَيرٌ لَهُ ۚ وَأَن تَصوموا خَيرٌ لَكُم ۖ إِن كُنتُم تَعلَمونَ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@cxcii{شَهرُ رَمَضانَ الَّذي أُنزِلَ فيهِ القُرآنُ هُدًى لِلنّاسِ وَبَيِّناتٍ مِنَ الهُدىٰ وَالفُرقانِ ۚ فَمَن شَهِدَ مِنكُمُ الشَّهرَ فَليَصُمهُ ۖ وَمَن كانَ مَريضًا أَو عَلىٰ سَفَرٍ فَعِدَّةٌ مِن أَيّامٍ أُخَرَ ۗ يُريدُ اللَّهُ بِكُمُ اليُسرَ وَلا يُريدُ بِكُمُ العُسرَ وَلِتُكمِلُوا العِدَّةَ وَلِتُكَبِّرُوا اللَّهَ عَلىٰ ما هَداكُم وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@cxciii{وَإِذا سَأَلَكَ عِبادي عَنّي فَإِنّي قَريبٌ ۖ أُجيبُ دَعوَةَ الدّاعِ إِذا دَعانِ ۖ فَليَستَجيبوا لي وَليُؤمِنوا بي لَعَلَّهُم يَرشُدونَ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@cxciv{أُحِلَّ لَكُم لَيلَةَ الصِّيامِ الرَّفَثُ إِلىٰ نِسائِكُم ۚ هُنَّ لِباسٌ لَكُم وَأَنتُم لِباسٌ لَهُنَّ ۗ عَلِمَ اللَّهُ أَنَّكُم كُنتُم تَختانونَ أَنفُسَكُم فَتابَ عَلَيكُم وَعَفا عَنكُم ۖ فَالآنَ باشِروهُنَّ وَابتَغوا ما كَتَبَ اللَّهُ لَكُم ۚ وَكُلوا وَاشرَبوا حَتّىٰ يَتَبَيَّنَ لَكُمُ الخَيطُ الأَبيَضُ مِنَ الخَيطِ الأَسوَدِ مِنَ الفَجرِ ۖ ثُمَّ أَتِمُّوا الصِّيامَ إِلَى اللَّيلِ ۚ وَلا تُباشِروهُنَّ وَأَنتُم عاكِفونَ فِي المَساجِدِ ۗ تِلكَ حُدودُ اللَّهِ فَلا تَقرَبوها ۗ كَذٰلِكَ يُبَيِّنُ اللَّهُ آياتِهِ لِلنّاسِ لَعَلَّهُم يَتَّقونَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@cxcv{وَلا تَأكُلوا أَموالَكُم بَينَكُم بِالباطِلِ وَتُدلوا بِها إِلَى الحُكّامِ لِتَأكُلوا فَريقًا مِن أَموالِ النّاسِ بِالإِثمِ وَأَنتُم تَعلَمونَ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@cxcvi{۞ يَسأَلونَكَ عَنِ الأَهِلَّةِ ۖ قُل هِيَ مَواقيتُ لِلنّاسِ وَالحَجِّ ۗ وَلَيسَ البِرُّ بِأَن تَأتُوا البُيوتَ مِن ظُهورِها وَلٰكِنَّ البِرَّ مَنِ اتَّقىٰ ۗ وَأتُوا البُيوتَ مِن أَبوابِها ۚ وَاتَّقُوا اللَّهَ لَعَلَّكُم تُفلِحونَ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@cxcvii{وَقاتِلوا في سَبيلِ اللَّهِ الَّذينَ يُقاتِلونَكُم وَلا تَعتَدوا ۚ إِنَّ اللَّهَ لا يُحِبُّ المُعتَدينَ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@cxcviii{وَاقتُلوهُم حَيثُ ثَقِفتُموهُم وَأَخرِجوهُم مِن حَيثُ أَخرَجوكُم ۚ وَالفِتنَةُ أَشَدُّ مِنَ القَتلِ ۚ وَلا تُقاتِلوهُم عِندَ المَسجِدِ الحَرامِ حَتّىٰ يُقاتِلوكُم فيهِ ۖ فَإِن قاتَلوكُم فَاقتُلوهُم ۗ كَذٰلِكَ جَزاءُ الكافِرينَ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@cxcix{فَإِنِ انتَهَوا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@cc{وَقاتِلوهُم حَتّىٰ لا تَكونَ فِتنَةٌ وَيَكونَ الدّينُ لِلَّهِ ۖ فَإِنِ انتَهَوا فَلا عُدوانَ إِلّا عَلَى الظّالِمينَ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@cci{الشَّهرُ الحَرامُ بِالشَّهرِ الحَرامِ وَالحُرُماتُ قِصاصٌ ۚ فَمَنِ اعتَدىٰ عَلَيكُم فَاعتَدوا عَلَيهِ بِمِثلِ مَا اعتَدىٰ عَلَيكُم ۚ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّ اللَّهَ مَعَ المُتَّقينَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@ccii{وَأَنفِقوا في سَبيلِ اللَّهِ وَلا تُلقوا بِأَيديكُم إِلَى التَّهلُكَةِ ۛ وَأَحسِنوا ۛ إِنَّ اللَّهَ يُحِبُّ المُحسِنينَ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@cciii{وَأَتِمُّوا الحَجَّ وَالعُمرَةَ لِلَّهِ ۚ فَإِن أُحصِرتُم فَمَا استَيسَرَ مِنَ الهَديِ ۖ وَلا تَحلِقوا رُءوسَكُم حَتّىٰ يَبلُغَ الهَديُ مَحِلَّهُ ۚ فَمَن كانَ مِنكُم مَريضًا أَو بِهِ أَذًى مِن رَأسِهِ فَفِديَةٌ مِن صِيامٍ أَو صَدَقَةٍ أَو نُسُكٍ ۚ فَإِذا أَمِنتُم فَمَن تَمَتَّعَ بِالعُمرَةِ إِلَى الحَجِّ فَمَا استَيسَرَ مِنَ الهَديِ ۚ فَمَن لَم يَجِد فَصِيامُ ثَلاثَةِ أَيّامٍ فِي الحَجِّ وَسَبعَةٍ إِذا رَجَعتُم ۗ تِلكَ عَشَرَةٌ كامِلَةٌ ۗ ذٰلِكَ لِمَن لَم يَكُن أَهلُهُ حاضِرِي المَسجِدِ الحَرامِ ۚ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@cciv{الحَجُّ أَشهُرٌ مَعلوماتٌ ۚ فَمَن فَرَضَ فيهِنَّ الحَجَّ فَلا رَفَثَ وَلا فُسوقَ وَلا جِدالَ فِي الحَجِّ ۗ وَما تَفعَلوا مِن خَيرٍ يَعلَمهُ اللَّهُ ۗ وَتَزَوَّدوا فَإِنَّ خَيرَ الزّادِ التَّقوىٰ ۚ وَاتَّقونِ يا أُولِي الأَلبابِ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@ccv{لَيسَ عَلَيكُم جُناحٌ أَن تَبتَغوا فَضلًا مِن رَبِّكُم ۚ فَإِذا أَفَضتُم مِن عَرَفاتٍ فَاذكُرُوا اللَّهَ عِندَ المَشعَرِ الحَرامِ ۖ وَاذكُروهُ كَما هَداكُم وَإِن كُنتُم مِن قَبلِهِ لَمِنَ الضّالّينَ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@ccvi{ثُمَّ أَفيضوا مِن حَيثُ أَفاضَ النّاسُ وَاستَغفِرُوا اللَّهَ ۚ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@ccvii{فَإِذا قَضَيتُم مَناسِكَكُم فَاذكُرُوا اللَّهَ كَذِكرِكُم آباءَكُم أَو أَشَدَّ ذِكرًا ۗ فَمِنَ النّاسِ مَن يَقولُ رَبَّنا آتِنا فِي الدُّنيا وَما لَهُ فِي الآخِرَةِ مِن خَلاقٍ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@ccviii{وَمِنهُم مَن يَقولُ رَبَّنا آتِنا فِي الدُّنيا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً وَقِنا عَذابَ النّارِ\qt@no{﴿٢٠١﴾}}
\qt@newcmd\qurantext@ccix{أُولٰئِكَ لَهُم نَصيبٌ مِمّا كَسَبوا ۚ وَاللَّهُ سَريعُ الحِسابِ\qt@no{﴿٢٠٢﴾}}
\qt@newcmd\qurantext@ccx{۞ وَاذكُرُوا اللَّهَ في أَيّامٍ مَعدوداتٍ ۚ فَمَن تَعَجَّلَ في يَومَينِ فَلا إِثمَ عَلَيهِ وَمَن تَأَخَّرَ فَلا إِثمَ عَلَيهِ ۚ لِمَنِ اتَّقىٰ ۗ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّكُم إِلَيهِ تُحشَرونَ\qt@no{﴿٢٠٣﴾}}
\qt@newcmd\qurantext@ccxi{وَمِنَ النّاسِ مَن يُعجِبُكَ قَولُهُ فِي الحَياةِ الدُّنيا وَيُشهِدُ اللَّهَ عَلىٰ ما في قَلبِهِ وَهُوَ أَلَدُّ الخِصامِ\qt@no{﴿٢٠٤﴾}}
\qt@newcmd\qurantext@ccxii{وَإِذا تَوَلّىٰ سَعىٰ فِي الأَرضِ لِيُفسِدَ فيها وَيُهلِكَ الحَرثَ وَالنَّسلَ ۗ وَاللَّهُ لا يُحِبُّ الفَسادَ\qt@no{﴿٢٠٥﴾}}
\qt@newcmd\qurantext@ccxiii{وَإِذا قيلَ لَهُ اتَّقِ اللَّهَ أَخَذَتهُ العِزَّةُ بِالإِثمِ ۚ فَحَسبُهُ جَهَنَّمُ ۚ وَلَبِئسَ المِهادُ\qt@no{﴿٢٠٦﴾}}
\qt@newcmd\qurantext@ccxiv{وَمِنَ النّاسِ مَن يَشري نَفسَهُ ابتِغاءَ مَرضاتِ اللَّهِ ۗ وَاللَّهُ رَءوفٌ بِالعِبادِ\qt@no{﴿٢٠٧﴾}}
\qt@newcmd\qurantext@ccxv{يا أَيُّهَا الَّذينَ آمَنُوا ادخُلوا فِي السِّلمِ كافَّةً وَلا تَتَّبِعوا خُطُواتِ الشَّيطانِ ۚ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿٢٠٨﴾}}
\qt@newcmd\qurantext@ccxvi{فَإِن زَلَلتُم مِن بَعدِ ما جاءَتكُمُ البَيِّناتُ فَاعلَموا أَنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٢٠٩﴾}}
\qt@newcmd\qurantext@ccxvii{هَل يَنظُرونَ إِلّا أَن يَأتِيَهُمُ اللَّهُ في ظُلَلٍ مِنَ الغَمامِ وَالمَلائِكَةُ وَقُضِيَ الأَمرُ ۚ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٢١٠﴾}}
\qt@newcmd\qurantext@ccxviii{سَل بَني إِسرائيلَ كَم آتَيناهُم مِن آيَةٍ بَيِّنَةٍ ۗ وَمَن يُبَدِّل نِعمَةَ اللَّهِ مِن بَعدِ ما جاءَتهُ فَإِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٢١١﴾}}
\qt@newcmd\qurantext@ccxix{زُيِّنَ لِلَّذينَ كَفَرُوا الحَياةُ الدُّنيا وَيَسخَرونَ مِنَ الَّذينَ آمَنوا ۘ وَالَّذينَ اتَّقَوا فَوقَهُم يَومَ القِيامَةِ ۗ وَاللَّهُ يَرزُقُ مَن يَشاءُ بِغَيرِ حِسابٍ\qt@no{﴿٢١٢﴾}}
\qt@newcmd\qurantext@ccxx{كانَ النّاسُ أُمَّةً واحِدَةً فَبَعَثَ اللَّهُ النَّبِيّينَ مُبَشِّرينَ وَمُنذِرينَ وَأَنزَلَ مَعَهُمُ الكِتابَ بِالحَقِّ لِيَحكُمَ بَينَ النّاسِ فيمَا اختَلَفوا فيهِ ۚ وَمَا اختَلَفَ فيهِ إِلَّا الَّذينَ أوتوهُ مِن بَعدِ ما جاءَتهُمُ البَيِّناتُ بَغيًا بَينَهُم ۖ فَهَدَى اللَّهُ الَّذينَ آمَنوا لِمَا اختَلَفوا فيهِ مِنَ الحَقِّ بِإِذنِهِ ۗ وَاللَّهُ يَهدي مَن يَشاءُ إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٢١٣﴾}}
\qt@newcmd\qurantext@ccxxi{أَم حَسِبتُم أَن تَدخُلُوا الجَنَّةَ وَلَمّا يَأتِكُم مَثَلُ الَّذينَ خَلَوا مِن قَبلِكُم ۖ مَسَّتهُمُ البَأساءُ وَالضَّرّاءُ وَزُلزِلوا حَتّىٰ يَقولَ الرَّسولُ وَالَّذينَ آمَنوا مَعَهُ مَتىٰ نَصرُ اللَّهِ ۗ أَلا إِنَّ نَصرَ اللَّهِ قَريبٌ\qt@no{﴿٢١٤﴾}}
\qt@newcmd\qurantext@ccxxii{يَسأَلونَكَ ماذا يُنفِقونَ ۖ قُل ما أَنفَقتُم مِن خَيرٍ فَلِلوالِدَينِ وَالأَقرَبينَ وَاليَتامىٰ وَالمَساكينِ وَابنِ السَّبيلِ ۗ وَما تَفعَلوا مِن خَيرٍ فَإِنَّ اللَّهَ بِهِ عَليمٌ\qt@no{﴿٢١٥﴾}}
\qt@newcmd\qurantext@ccxxiii{كُتِبَ عَلَيكُمُ القِتالُ وَهُوَ كُرهٌ لَكُم ۖ وَعَسىٰ أَن تَكرَهوا شَيئًا وَهُوَ خَيرٌ لَكُم ۖ وَعَسىٰ أَن تُحِبّوا شَيئًا وَهُوَ شَرٌّ لَكُم ۗ وَاللَّهُ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿٢١٦﴾}}
\qt@newcmd\qurantext@ccxxiv{يَسأَلونَكَ عَنِ الشَّهرِ الحَرامِ قِتالٍ فيهِ ۖ قُل قِتالٌ فيهِ كَبيرٌ ۖ وَصَدٌّ عَن سَبيلِ اللَّهِ وَكُفرٌ بِهِ وَالمَسجِدِ الحَرامِ وَإِخراجُ أَهلِهِ مِنهُ أَكبَرُ عِندَ اللَّهِ ۚ وَالفِتنَةُ أَكبَرُ مِنَ القَتلِ ۗ وَلا يَزالونَ يُقاتِلونَكُم حَتّىٰ يَرُدّوكُم عَن دينِكُم إِنِ استَطاعوا ۚ وَمَن يَرتَدِد مِنكُم عَن دينِهِ فَيَمُت وَهُوَ كافِرٌ فَأُولٰئِكَ حَبِطَت أَعمالُهُم فِي الدُّنيا وَالآخِرَةِ ۖ وَأُولٰئِكَ أَصحابُ النّارِ ۖ هُم فيها خالِدونَ\qt@no{﴿٢١٧﴾}}
\qt@newcmd\qurantext@ccxxv{إِنَّ الَّذينَ آمَنوا وَالَّذينَ هاجَروا وَجاهَدوا في سَبيلِ اللَّهِ أُولٰئِكَ يَرجونَ رَحمَتَ اللَّهِ ۚ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢١٨﴾}}
\qt@newcmd\qurantext@ccxxvi{۞ يَسأَلونَكَ عَنِ الخَمرِ وَالمَيسِرِ ۖ قُل فيهِما إِثمٌ كَبيرٌ وَمَنافِعُ لِلنّاسِ وَإِثمُهُما أَكبَرُ مِن نَفعِهِما ۗ وَيَسأَلونَكَ ماذا يُنفِقونَ قُلِ العَفوَ ۗ كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُمُ الآياتِ لَعَلَّكُم تَتَفَكَّرونَ\qt@no{﴿٢١٩﴾}}
\qt@newcmd\qurantext@ccxxvii{فِي الدُّنيا وَالآخِرَةِ ۗ وَيَسأَلونَكَ عَنِ اليَتامىٰ ۖ قُل إِصلاحٌ لَهُم خَيرٌ ۖ وَإِن تُخالِطوهُم فَإِخوانُكُم ۚ وَاللَّهُ يَعلَمُ المُفسِدَ مِنَ المُصلِحِ ۚ وَلَو شاءَ اللَّهُ لَأَعنَتَكُم ۚ إِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٢٢٠﴾}}
\qt@newcmd\qurantext@ccxxviii{وَلا تَنكِحُوا المُشرِكاتِ حَتّىٰ يُؤمِنَّ ۚ وَلَأَمَةٌ مُؤمِنَةٌ خَيرٌ مِن مُشرِكَةٍ وَلَو أَعجَبَتكُم ۗ وَلا تُنكِحُوا المُشرِكينَ حَتّىٰ يُؤمِنوا ۚ وَلَعَبدٌ مُؤمِنٌ خَيرٌ مِن مُشرِكٍ وَلَو أَعجَبَكُم ۗ أُولٰئِكَ يَدعونَ إِلَى النّارِ ۖ وَاللَّهُ يَدعو إِلَى الجَنَّةِ وَالمَغفِرَةِ بِإِذنِهِ ۖ وَيُبَيِّنُ آياتِهِ لِلنّاسِ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٢٢١﴾}}
\qt@newcmd\qurantext@ccxxix{وَيَسأَلونَكَ عَنِ المَحيضِ ۖ قُل هُوَ أَذًى فَاعتَزِلُوا النِّساءَ فِي المَحيضِ ۖ وَلا تَقرَبوهُنَّ حَتّىٰ يَطهُرنَ ۖ فَإِذا تَطَهَّرنَ فَأتوهُنَّ مِن حَيثُ أَمَرَكُمُ اللَّهُ ۚ إِنَّ اللَّهَ يُحِبُّ التَّوّابينَ وَيُحِبُّ المُتَطَهِّرينَ\qt@no{﴿٢٢٢﴾}}
\qt@newcmd\qurantext@ccxxx{نِساؤُكُم حَرثٌ لَكُم فَأتوا حَرثَكُم أَنّىٰ شِئتُم ۖ وَقَدِّموا لِأَنفُسِكُم ۚ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّكُم مُلاقوهُ ۗ وَبَشِّرِ المُؤمِنينَ\qt@no{﴿٢٢٣﴾}}
\qt@newcmd\qurantext@ccxxxi{وَلا تَجعَلُوا اللَّهَ عُرضَةً لِأَيمانِكُم أَن تَبَرّوا وَتَتَّقوا وَتُصلِحوا بَينَ النّاسِ ۗ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٢٢٤﴾}}
\qt@newcmd\qurantext@ccxxxii{لا يُؤاخِذُكُمُ اللَّهُ بِاللَّغوِ في أَيمانِكُم وَلٰكِن يُؤاخِذُكُم بِما كَسَبَت قُلوبُكُم ۗ وَاللَّهُ غَفورٌ حَليمٌ\qt@no{﴿٢٢٥﴾}}
\qt@newcmd\qurantext@ccxxxiii{لِلَّذينَ يُؤلونَ مِن نِسائِهِم تَرَبُّصُ أَربَعَةِ أَشهُرٍ ۖ فَإِن فاءوا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٢٢٦﴾}}
\qt@newcmd\qurantext@ccxxxiv{وَإِن عَزَمُوا الطَّلاقَ فَإِنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿٢٢٧﴾}}
\qt@newcmd\qurantext@ccxxxv{وَالمُطَلَّقاتُ يَتَرَبَّصنَ بِأَنفُسِهِنَّ ثَلاثَةَ قُروءٍ ۚ وَلا يَحِلُّ لَهُنَّ أَن يَكتُمنَ ما خَلَقَ اللَّهُ في أَرحامِهِنَّ إِن كُنَّ يُؤمِنَّ بِاللَّهِ وَاليَومِ الآخِرِ ۚ وَبُعولَتُهُنَّ أَحَقُّ بِرَدِّهِنَّ في ذٰلِكَ إِن أَرادوا إِصلاحًا ۚ وَلَهُنَّ مِثلُ الَّذي عَلَيهِنَّ بِالمَعروفِ ۚ وَلِلرِّجالِ عَلَيهِنَّ دَرَجَةٌ ۗ وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٢٢٨﴾}}
\qt@newcmd\qurantext@ccxxxvi{الطَّلاقُ مَرَّتانِ ۖ فَإِمساكٌ بِمَعروفٍ أَو تَسريحٌ بِإِحسانٍ ۗ وَلا يَحِلُّ لَكُم أَن تَأخُذوا مِمّا آتَيتُموهُنَّ شَيئًا إِلّا أَن يَخافا أَلّا يُقيما حُدودَ اللَّهِ ۖ فَإِن خِفتُم أَلّا يُقيما حُدودَ اللَّهِ فَلا جُناحَ عَلَيهِما فيمَا افتَدَت بِهِ ۗ تِلكَ حُدودُ اللَّهِ فَلا تَعتَدوها ۚ وَمَن يَتَعَدَّ حُدودَ اللَّهِ فَأُولٰئِكَ هُمُ الظّالِمونَ\qt@no{﴿٢٢٩﴾}}
\qt@newcmd\qurantext@ccxxxvii{فَإِن طَلَّقَها فَلا تَحِلُّ لَهُ مِن بَعدُ حَتّىٰ تَنكِحَ زَوجًا غَيرَهُ ۗ فَإِن طَلَّقَها فَلا جُناحَ عَلَيهِما أَن يَتَراجَعا إِن ظَنّا أَن يُقيما حُدودَ اللَّهِ ۗ وَتِلكَ حُدودُ اللَّهِ يُبَيِّنُها لِقَومٍ يَعلَمونَ\qt@no{﴿٢٣٠﴾}}
\qt@newcmd\qurantext@ccxxxviii{وَإِذا طَلَّقتُمُ النِّساءَ فَبَلَغنَ أَجَلَهُنَّ فَأَمسِكوهُنَّ بِمَعروفٍ أَو سَرِّحوهُنَّ بِمَعروفٍ ۚ وَلا تُمسِكوهُنَّ ضِرارًا لِتَعتَدوا ۚ وَمَن يَفعَل ذٰلِكَ فَقَد ظَلَمَ نَفسَهُ ۚ وَلا تَتَّخِذوا آياتِ اللَّهِ هُزُوًا ۚ وَاذكُروا نِعمَتَ اللَّهِ عَلَيكُم وَما أَنزَلَ عَلَيكُم مِنَ الكِتابِ وَالحِكمَةِ يَعِظُكُم بِهِ ۚ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٢٣١﴾}}
\qt@newcmd\qurantext@ccxxxix{وَإِذا طَلَّقتُمُ النِّساءَ فَبَلَغنَ أَجَلَهُنَّ فَلا تَعضُلوهُنَّ أَن يَنكِحنَ أَزواجَهُنَّ إِذا تَراضَوا بَينَهُم بِالمَعروفِ ۗ ذٰلِكَ يوعَظُ بِهِ مَن كانَ مِنكُم يُؤمِنُ بِاللَّهِ وَاليَومِ الآخِرِ ۗ ذٰلِكُم أَزكىٰ لَكُم وَأَطهَرُ ۗ وَاللَّهُ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿٢٣٢﴾}}
\qt@newcmd\qurantext@ccxl{۞ وَالوالِداتُ يُرضِعنَ أَولادَهُنَّ حَولَينِ كامِلَينِ ۖ لِمَن أَرادَ أَن يُتِمَّ الرَّضاعَةَ ۚ وَعَلَى المَولودِ لَهُ رِزقُهُنَّ وَكِسوَتُهُنَّ بِالمَعروفِ ۚ لا تُكَلَّفُ نَفسٌ إِلّا وُسعَها ۚ لا تُضارَّ والِدَةٌ بِوَلَدِها وَلا مَولودٌ لَهُ بِوَلَدِهِ ۚ وَعَلَى الوارِثِ مِثلُ ذٰلِكَ ۗ فَإِن أَرادا فِصالًا عَن تَراضٍ مِنهُما وَتَشاوُرٍ فَلا جُناحَ عَلَيهِما ۗ وَإِن أَرَدتُم أَن تَستَرضِعوا أَولادَكُم فَلا جُناحَ عَلَيكُم إِذا سَلَّمتُم ما آتَيتُم بِالمَعروفِ ۗ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّ اللَّهَ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٢٣٣﴾}}
\qt@newcmd\qurantext@ccxli{وَالَّذينَ يُتَوَفَّونَ مِنكُم وَيَذَرونَ أَزواجًا يَتَرَبَّصنَ بِأَنفُسِهِنَّ أَربَعَةَ أَشهُرٍ وَعَشرًا ۖ فَإِذا بَلَغنَ أَجَلَهُنَّ فَلا جُناحَ عَلَيكُم فيما فَعَلنَ في أَنفُسِهِنَّ بِالمَعروفِ ۗ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٢٣٤﴾}}
\qt@newcmd\qurantext@ccxlii{وَلا جُناحَ عَلَيكُم فيما عَرَّضتُم بِهِ مِن خِطبَةِ النِّساءِ أَو أَكنَنتُم في أَنفُسِكُم ۚ عَلِمَ اللَّهُ أَنَّكُم سَتَذكُرونَهُنَّ وَلٰكِن لا تُواعِدوهُنَّ سِرًّا إِلّا أَن تَقولوا قَولًا مَعروفًا ۚ وَلا تَعزِموا عُقدَةَ النِّكاحِ حَتّىٰ يَبلُغَ الكِتابُ أَجَلَهُ ۚ وَاعلَموا أَنَّ اللَّهَ يَعلَمُ ما في أَنفُسِكُم فَاحذَروهُ ۚ وَاعلَموا أَنَّ اللَّهَ غَفورٌ حَليمٌ\qt@no{﴿٢٣٥﴾}}
\qt@newcmd\qurantext@ccxliii{لا جُناحَ عَلَيكُم إِن طَلَّقتُمُ النِّساءَ ما لَم تَمَسّوهُنَّ أَو تَفرِضوا لَهُنَّ فَريضَةً ۚ وَمَتِّعوهُنَّ عَلَى الموسِعِ قَدَرُهُ وَعَلَى المُقتِرِ قَدَرُهُ مَتاعًا بِالمَعروفِ ۖ حَقًّا عَلَى المُحسِنينَ\qt@no{﴿٢٣٦﴾}}
\qt@newcmd\qurantext@ccxliv{وَإِن طَلَّقتُموهُنَّ مِن قَبلِ أَن تَمَسّوهُنَّ وَقَد فَرَضتُم لَهُنَّ فَريضَةً فَنِصفُ ما فَرَضتُم إِلّا أَن يَعفونَ أَو يَعفُوَ الَّذي بِيَدِهِ عُقدَةُ النِّكاحِ ۚ وَأَن تَعفوا أَقرَبُ لِلتَّقوىٰ ۚ وَلا تَنسَوُا الفَضلَ بَينَكُم ۚ إِنَّ اللَّهَ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٢٣٧﴾}}
\qt@newcmd\qurantext@ccxlv{حافِظوا عَلَى الصَّلَواتِ وَالصَّلاةِ الوُسطىٰ وَقوموا لِلَّهِ قانِتينَ\qt@no{﴿٢٣٨﴾}}
\qt@newcmd\qurantext@ccxlvi{فَإِن خِفتُم فَرِجالًا أَو رُكبانًا ۖ فَإِذا أَمِنتُم فَاذكُرُوا اللَّهَ كَما عَلَّمَكُم ما لَم تَكونوا تَعلَمونَ\qt@no{﴿٢٣٩﴾}}
\qt@newcmd\qurantext@ccxlvii{وَالَّذينَ يُتَوَفَّونَ مِنكُم وَيَذَرونَ أَزواجًا وَصِيَّةً لِأَزواجِهِم مَتاعًا إِلَى الحَولِ غَيرَ إِخراجٍ ۚ فَإِن خَرَجنَ فَلا جُناحَ عَلَيكُم في ما فَعَلنَ في أَنفُسِهِنَّ مِن مَعروفٍ ۗ وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٢٤٠﴾}}
\qt@newcmd\qurantext@ccxlviii{وَلِلمُطَلَّقاتِ مَتاعٌ بِالمَعروفِ ۖ حَقًّا عَلَى المُتَّقينَ\qt@no{﴿٢٤١﴾}}
\qt@newcmd\qurantext@ccxlix{كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُم آياتِهِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿٢٤٢﴾}}
\qt@newcmd\qurantext@ccl{۞ أَلَم تَرَ إِلَى الَّذينَ خَرَجوا مِن دِيارِهِم وَهُم أُلوفٌ حَذَرَ المَوتِ فَقالَ لَهُمُ اللَّهُ موتوا ثُمَّ أَحياهُم ۚ إِنَّ اللَّهَ لَذو فَضلٍ عَلَى النّاسِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَشكُرونَ\qt@no{﴿٢٤٣﴾}}
\qt@newcmd\qurantext@ccli{وَقاتِلوا في سَبيلِ اللَّهِ وَاعلَموا أَنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿٢٤٤﴾}}
\qt@newcmd\qurantext@cclii{مَن ذَا الَّذي يُقرِضُ اللَّهَ قَرضًا حَسَنًا فَيُضاعِفَهُ لَهُ أَضعافًا كَثيرَةً ۚ وَاللَّهُ يَقبِضُ وَيَبسُطُ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٢٤٥﴾}}
\qt@newcmd\qurantext@ccliii{أَلَم تَرَ إِلَى المَلَإِ مِن بَني إِسرائيلَ مِن بَعدِ موسىٰ إِذ قالوا لِنَبِيٍّ لَهُمُ ابعَث لَنا مَلِكًا نُقاتِل في سَبيلِ اللَّهِ ۖ قالَ هَل عَسَيتُم إِن كُتِبَ عَلَيكُمُ القِتالُ أَلّا تُقاتِلوا ۖ قالوا وَما لَنا أَلّا نُقاتِلَ في سَبيلِ اللَّهِ وَقَد أُخرِجنا مِن دِيارِنا وَأَبنائِنا ۖ فَلَمّا كُتِبَ عَلَيهِمُ القِتالُ تَوَلَّوا إِلّا قَليلًا مِنهُم ۗ وَاللَّهُ عَليمٌ بِالظّالِمينَ\qt@no{﴿٢٤٦﴾}}
\qt@newcmd\qurantext@ccliv{وَقالَ لَهُم نَبِيُّهُم إِنَّ اللَّهَ قَد بَعَثَ لَكُم طالوتَ مَلِكًا ۚ قالوا أَنّىٰ يَكونُ لَهُ المُلكُ عَلَينا وَنَحنُ أَحَقُّ بِالمُلكِ مِنهُ وَلَم يُؤتَ سَعَةً مِنَ المالِ ۚ قالَ إِنَّ اللَّهَ اصطَفاهُ عَلَيكُم وَزادَهُ بَسطَةً فِي العِلمِ وَالجِسمِ ۖ وَاللَّهُ يُؤتي مُلكَهُ مَن يَشاءُ ۚ وَاللَّهُ واسِعٌ عَليمٌ\qt@no{﴿٢٤٧﴾}}
\qt@newcmd\qurantext@cclv{وَقالَ لَهُم نَبِيُّهُم إِنَّ آيَةَ مُلكِهِ أَن يَأتِيَكُمُ التّابوتُ فيهِ سَكينَةٌ مِن رَبِّكُم وَبَقِيَّةٌ مِمّا تَرَكَ آلُ موسىٰ وَآلُ هارونَ تَحمِلُهُ المَلائِكَةُ ۚ إِنَّ في ذٰلِكَ لَآيَةً لَكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٢٤٨﴾}}
\qt@newcmd\qurantext@cclvi{فَلَمّا فَصَلَ طالوتُ بِالجُنودِ قالَ إِنَّ اللَّهَ مُبتَليكُم بِنَهَرٍ فَمَن شَرِبَ مِنهُ فَلَيسَ مِنّي وَمَن لَم يَطعَمهُ فَإِنَّهُ مِنّي إِلّا مَنِ اغتَرَفَ غُرفَةً بِيَدِهِ ۚ فَشَرِبوا مِنهُ إِلّا قَليلًا مِنهُم ۚ فَلَمّا جاوَزَهُ هُوَ وَالَّذينَ آمَنوا مَعَهُ قالوا لا طاقَةَ لَنَا اليَومَ بِجالوتَ وَجُنودِهِ ۚ قالَ الَّذينَ يَظُنّونَ أَنَّهُم مُلاقُو اللَّهِ كَم مِن فِئَةٍ قَليلَةٍ غَلَبَت فِئَةً كَثيرَةً بِإِذنِ اللَّهِ ۗ وَاللَّهُ مَعَ الصّابِرينَ\qt@no{﴿٢٤٩﴾}}
\qt@newcmd\qurantext@cclvii{وَلَمّا بَرَزوا لِجالوتَ وَجُنودِهِ قالوا رَبَّنا أَفرِغ عَلَينا صَبرًا وَثَبِّت أَقدامَنا وَانصُرنا عَلَى القَومِ الكافِرينَ\qt@no{﴿٢٥٠﴾}}
\qt@newcmd\qurantext@cclviii{فَهَزَموهُم بِإِذنِ اللَّهِ وَقَتَلَ داوودُ جالوتَ وَآتاهُ اللَّهُ المُلكَ وَالحِكمَةَ وَعَلَّمَهُ مِمّا يَشاءُ ۗ وَلَولا دَفعُ اللَّهِ النّاسَ بَعضَهُم بِبَعضٍ لَفَسَدَتِ الأَرضُ وَلٰكِنَّ اللَّهَ ذو فَضلٍ عَلَى العالَمينَ\qt@no{﴿٢٥١﴾}}
\qt@newcmd\qurantext@cclix{تِلكَ آياتُ اللَّهِ نَتلوها عَلَيكَ بِالحَقِّ ۚ وَإِنَّكَ لَمِنَ المُرسَلينَ\qt@no{﴿٢٥٢﴾}}
\qt@newcmd\qurantext@cclx{۞ تِلكَ الرُّسُلُ فَضَّلنا بَعضَهُم عَلىٰ بَعضٍ ۘ مِنهُم مَن كَلَّمَ اللَّهُ ۖ وَرَفَعَ بَعضَهُم دَرَجاتٍ ۚ وَآتَينا عيسَى ابنَ مَريَمَ البَيِّناتِ وَأَيَّدناهُ بِروحِ القُدُسِ ۗ وَلَو شاءَ اللَّهُ مَا اقتَتَلَ الَّذينَ مِن بَعدِهِم مِن بَعدِ ما جاءَتهُمُ البَيِّناتُ وَلٰكِنِ اختَلَفوا فَمِنهُم مَن آمَنَ وَمِنهُم مَن كَفَرَ ۚ وَلَو شاءَ اللَّهُ مَا اقتَتَلوا وَلٰكِنَّ اللَّهَ يَفعَلُ ما يُريدُ\qt@no{﴿٢٥٣﴾}}
\qt@newcmd\qurantext@cclxi{يا أَيُّهَا الَّذينَ آمَنوا أَنفِقوا مِمّا رَزَقناكُم مِن قَبلِ أَن يَأتِيَ يَومٌ لا بَيعٌ فيهِ وَلا خُلَّةٌ وَلا شَفاعَةٌ ۗ وَالكافِرونَ هُمُ الظّالِمونَ\qt@no{﴿٢٥٤﴾}}
\qt@newcmd\qurantext@cclxii{اللَّهُ لا إِلٰهَ إِلّا هُوَ الحَيُّ القَيّومُ ۚ لا تَأخُذُهُ سِنَةٌ وَلا نَومٌ ۚ لَهُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۗ مَن ذَا الَّذي يَشفَعُ عِندَهُ إِلّا بِإِذنِهِ ۚ يَعلَمُ ما بَينَ أَيديهِم وَما خَلفَهُم ۖ وَلا يُحيطونَ بِشَيءٍ مِن عِلمِهِ إِلّا بِما شاءَ ۚ وَسِعَ كُرسِيُّهُ السَّماواتِ وَالأَرضَ ۖ وَلا يَئودُهُ حِفظُهُما ۚ وَهُوَ العَلِيُّ العَظيمُ\qt@no{﴿٢٥٥﴾}}
\qt@newcmd\qurantext@cclxiii{لا إِكراهَ فِي الدّينِ ۖ قَد تَبَيَّنَ الرُّشدُ مِنَ الغَيِّ ۚ فَمَن يَكفُر بِالطّاغوتِ وَيُؤمِن بِاللَّهِ فَقَدِ استَمسَكَ بِالعُروَةِ الوُثقىٰ لَا انفِصامَ لَها ۗ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٢٥٦﴾}}
\qt@newcmd\qurantext@cclxiv{اللَّهُ وَلِيُّ الَّذينَ آمَنوا يُخرِجُهُم مِنَ الظُّلُماتِ إِلَى النّورِ ۖ وَالَّذينَ كَفَروا أَولِياؤُهُمُ الطّاغوتُ يُخرِجونَهُم مِنَ النّورِ إِلَى الظُّلُماتِ ۗ أُولٰئِكَ أَصحابُ النّارِ ۖ هُم فيها خالِدونَ\qt@no{﴿٢٥٧﴾}}
\qt@newcmd\qurantext@cclxv{أَلَم تَرَ إِلَى الَّذي حاجَّ إِبراهيمَ في رَبِّهِ أَن آتاهُ اللَّهُ المُلكَ إِذ قالَ إِبراهيمُ رَبِّيَ الَّذي يُحيي وَيُميتُ قالَ أَنا أُحيي وَأُميتُ ۖ قالَ إِبراهيمُ فَإِنَّ اللَّهَ يَأتي بِالشَّمسِ مِنَ المَشرِقِ فَأتِ بِها مِنَ المَغرِبِ فَبُهِتَ الَّذي كَفَرَ ۗ وَاللَّهُ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿٢٥٨﴾}}
\qt@newcmd\qurantext@cclxvi{أَو كَالَّذي مَرَّ عَلىٰ قَريَةٍ وَهِيَ خاوِيَةٌ عَلىٰ عُروشِها قالَ أَنّىٰ يُحيي هٰذِهِ اللَّهُ بَعدَ مَوتِها ۖ فَأَماتَهُ اللَّهُ مِائَةَ عامٍ ثُمَّ بَعَثَهُ ۖ قالَ كَم لَبِثتَ ۖ قالَ لَبِثتُ يَومًا أَو بَعضَ يَومٍ ۖ قالَ بَل لَبِثتَ مِائَةَ عامٍ فَانظُر إِلىٰ طَعامِكَ وَشَرابِكَ لَم يَتَسَنَّه ۖ وَانظُر إِلىٰ حِمارِكَ وَلِنَجعَلَكَ آيَةً لِلنّاسِ ۖ وَانظُر إِلَى العِظامِ كَيفَ نُنشِزُها ثُمَّ نَكسوها لَحمًا ۚ فَلَمّا تَبَيَّنَ لَهُ قالَ أَعلَمُ أَنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٥٩﴾}}
\qt@newcmd\qurantext@cclxvii{وَإِذ قالَ إِبراهيمُ رَبِّ أَرِني كَيفَ تُحيِي المَوتىٰ ۖ قالَ أَوَلَم تُؤمِن ۖ قالَ بَلىٰ وَلٰكِن لِيَطمَئِنَّ قَلبي ۖ قالَ فَخُذ أَربَعَةً مِنَ الطَّيرِ فَصُرهُنَّ إِلَيكَ ثُمَّ اجعَل عَلىٰ كُلِّ جَبَلٍ مِنهُنَّ جُزءًا ثُمَّ ادعُهُنَّ يَأتينَكَ سَعيًا ۚ وَاعلَم أَنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٢٦٠﴾}}
\qt@newcmd\qurantext@cclxviii{مَثَلُ الَّذينَ يُنفِقونَ أَموالَهُم في سَبيلِ اللَّهِ كَمَثَلِ حَبَّةٍ أَنبَتَت سَبعَ سَنابِلَ في كُلِّ سُنبُلَةٍ مِائَةُ حَبَّةٍ ۗ وَاللَّهُ يُضاعِفُ لِمَن يَشاءُ ۗ وَاللَّهُ واسِعٌ عَليمٌ\qt@no{﴿٢٦١﴾}}
\qt@newcmd\qurantext@cclxix{الَّذينَ يُنفِقونَ أَموالَهُم في سَبيلِ اللَّهِ ثُمَّ لا يُتبِعونَ ما أَنفَقوا مَنًّا وَلا أَذًى ۙ لَهُم أَجرُهُم عِندَ رَبِّهِم وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٢٦٢﴾}}
\qt@newcmd\qurantext@cclxx{۞ قَولٌ مَعروفٌ وَمَغفِرَةٌ خَيرٌ مِن صَدَقَةٍ يَتبَعُها أَذًى ۗ وَاللَّهُ غَنِيٌّ حَليمٌ\qt@no{﴿٢٦٣﴾}}
\qt@newcmd\qurantext@cclxxi{يا أَيُّهَا الَّذينَ آمَنوا لا تُبطِلوا صَدَقاتِكُم بِالمَنِّ وَالأَذىٰ كَالَّذي يُنفِقُ مالَهُ رِئَاءَ النّاسِ وَلا يُؤمِنُ بِاللَّهِ وَاليَومِ الآخِرِ ۖ فَمَثَلُهُ كَمَثَلِ صَفوانٍ عَلَيهِ تُرابٌ فَأَصابَهُ وابِلٌ فَتَرَكَهُ صَلدًا ۖ لا يَقدِرونَ عَلىٰ شَيءٍ مِمّا كَسَبوا ۗ وَاللَّهُ لا يَهدِي القَومَ الكافِرينَ\qt@no{﴿٢٦٤﴾}}
\qt@newcmd\qurantext@cclxxii{وَمَثَلُ الَّذينَ يُنفِقونَ أَموالَهُمُ ابتِغاءَ مَرضاتِ اللَّهِ وَتَثبيتًا مِن أَنفُسِهِم كَمَثَلِ جَنَّةٍ بِرَبوَةٍ أَصابَها وابِلٌ فَآتَت أُكُلَها ضِعفَينِ فَإِن لَم يُصِبها وابِلٌ فَطَلٌّ ۗ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٢٦٥﴾}}
\qt@newcmd\qurantext@cclxxiii{أَيَوَدُّ أَحَدُكُم أَن تَكونَ لَهُ جَنَّةٌ مِن نَخيلٍ وَأَعنابٍ تَجري مِن تَحتِهَا الأَنهارُ لَهُ فيها مِن كُلِّ الثَّمَراتِ وَأَصابَهُ الكِبَرُ وَلَهُ ذُرِّيَّةٌ ضُعَفاءُ فَأَصابَها إِعصارٌ فيهِ نارٌ فَاحتَرَقَت ۗ كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُمُ الآياتِ لَعَلَّكُم تَتَفَكَّرونَ\qt@no{﴿٢٦٦﴾}}
\qt@newcmd\qurantext@cclxxiv{يا أَيُّهَا الَّذينَ آمَنوا أَنفِقوا مِن طَيِّباتِ ما كَسَبتُم وَمِمّا أَخرَجنا لَكُم مِنَ الأَرضِ ۖ وَلا تَيَمَّمُوا الخَبيثَ مِنهُ تُنفِقونَ وَلَستُم بِآخِذيهِ إِلّا أَن تُغمِضوا فيهِ ۚ وَاعلَموا أَنَّ اللَّهَ غَنِيٌّ حَميدٌ\qt@no{﴿٢٦٧﴾}}
\qt@newcmd\qurantext@cclxxv{الشَّيطانُ يَعِدُكُمُ الفَقرَ وَيَأمُرُكُم بِالفَحشاءِ ۖ وَاللَّهُ يَعِدُكُم مَغفِرَةً مِنهُ وَفَضلًا ۗ وَاللَّهُ واسِعٌ عَليمٌ\qt@no{﴿٢٦٨﴾}}
\qt@newcmd\qurantext@cclxxvi{يُؤتِي الحِكمَةَ مَن يَشاءُ ۚ وَمَن يُؤتَ الحِكمَةَ فَقَد أوتِيَ خَيرًا كَثيرًا ۗ وَما يَذَّكَّرُ إِلّا أُولُو الأَلبابِ\qt@no{﴿٢٦٩﴾}}
\qt@newcmd\qurantext@cclxxvii{وَما أَنفَقتُم مِن نَفَقَةٍ أَو نَذَرتُم مِن نَذرٍ فَإِنَّ اللَّهَ يَعلَمُهُ ۗ وَما لِلظّالِمينَ مِن أَنصارٍ\qt@no{﴿٢٧٠﴾}}
\qt@newcmd\qurantext@cclxxviii{إِن تُبدُوا الصَّدَقاتِ فَنِعِمّا هِيَ ۖ وَإِن تُخفوها وَتُؤتوهَا الفُقَراءَ فَهُوَ خَيرٌ لَكُم ۚ وَيُكَفِّرُ عَنكُم مِن سَيِّئَاتِكُم ۗ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٢٧١﴾}}
\qt@newcmd\qurantext@cclxxix{۞ لَيسَ عَلَيكَ هُداهُم وَلٰكِنَّ اللَّهَ يَهدي مَن يَشاءُ ۗ وَما تُنفِقوا مِن خَيرٍ فَلِأَنفُسِكُم ۚ وَما تُنفِقونَ إِلَّا ابتِغاءَ وَجهِ اللَّهِ ۚ وَما تُنفِقوا مِن خَيرٍ يُوَفَّ إِلَيكُم وَأَنتُم لا تُظلَمونَ\qt@no{﴿٢٧٢﴾}}
\qt@newcmd\qurantext@cclxxx{لِلفُقَراءِ الَّذينَ أُحصِروا في سَبيلِ اللَّهِ لا يَستَطيعونَ ضَربًا فِي الأَرضِ يَحسَبُهُمُ الجاهِلُ أَغنِياءَ مِنَ التَّعَفُّفِ تَعرِفُهُم بِسيماهُم لا يَسأَلونَ النّاسَ إِلحافًا ۗ وَما تُنفِقوا مِن خَيرٍ فَإِنَّ اللَّهَ بِهِ عَليمٌ\qt@no{﴿٢٧٣﴾}}
\qt@newcmd\qurantext@cclxxxi{الَّذينَ يُنفِقونَ أَموالَهُم بِاللَّيلِ وَالنَّهارِ سِرًّا وَعَلانِيَةً فَلَهُم أَجرُهُم عِندَ رَبِّهِم وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٢٧٤﴾}}
\qt@newcmd\qurantext@cclxxxii{الَّذينَ يَأكُلونَ الرِّبا لا يَقومونَ إِلّا كَما يَقومُ الَّذي يَتَخَبَّطُهُ الشَّيطانُ مِنَ المَسِّ ۚ ذٰلِكَ بِأَنَّهُم قالوا إِنَّمَا البَيعُ مِثلُ الرِّبا ۗ وَأَحَلَّ اللَّهُ البَيعَ وَحَرَّمَ الرِّبا ۚ فَمَن جاءَهُ مَوعِظَةٌ مِن رَبِّهِ فَانتَهىٰ فَلَهُ ما سَلَفَ وَأَمرُهُ إِلَى اللَّهِ ۖ وَمَن عادَ فَأُولٰئِكَ أَصحابُ النّارِ ۖ هُم فيها خالِدونَ\qt@no{﴿٢٧٥﴾}}
\qt@newcmd\qurantext@cclxxxiii{يَمحَقُ اللَّهُ الرِّبا وَيُربِي الصَّدَقاتِ ۗ وَاللَّهُ لا يُحِبُّ كُلَّ كَفّارٍ أَثيمٍ\qt@no{﴿٢٧٦﴾}}
\qt@newcmd\qurantext@cclxxxiv{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ وَأَقامُوا الصَّلاةَ وَآتَوُا الزَّكاةَ لَهُم أَجرُهُم عِندَ رَبِّهِم وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٢٧٧﴾}}
\qt@newcmd\qurantext@cclxxxv{يا أَيُّهَا الَّذينَ آمَنُوا اتَّقُوا اللَّهَ وَذَروا ما بَقِيَ مِنَ الرِّبا إِن كُنتُم مُؤمِنينَ\qt@no{﴿٢٧٨﴾}}
\qt@newcmd\qurantext@cclxxxvi{فَإِن لَم تَفعَلوا فَأذَنوا بِحَربٍ مِنَ اللَّهِ وَرَسولِهِ ۖ وَإِن تُبتُم فَلَكُم رُءوسُ أَموالِكُم لا تَظلِمونَ وَلا تُظلَمونَ\qt@no{﴿٢٧٩﴾}}
\qt@newcmd\qurantext@cclxxxvii{وَإِن كانَ ذو عُسرَةٍ فَنَظِرَةٌ إِلىٰ مَيسَرَةٍ ۚ وَأَن تَصَدَّقوا خَيرٌ لَكُم ۖ إِن كُنتُم تَعلَمونَ\qt@no{﴿٢٨٠﴾}}
\qt@newcmd\qurantext@cclxxxviii{وَاتَّقوا يَومًا تُرجَعونَ فيهِ إِلَى اللَّهِ ۖ ثُمَّ تُوَفّىٰ كُلُّ نَفسٍ ما كَسَبَت وَهُم لا يُظلَمونَ\qt@no{﴿٢٨١﴾}}
\qt@newcmd\qurantext@cclxxxix{يا أَيُّهَا الَّذينَ آمَنوا إِذا تَدايَنتُم بِدَينٍ إِلىٰ أَجَلٍ مُسَمًّى فَاكتُبوهُ ۚ وَليَكتُب بَينَكُم كاتِبٌ بِالعَدلِ ۚ وَلا يَأبَ كاتِبٌ أَن يَكتُبَ كَما عَلَّمَهُ اللَّهُ ۚ فَليَكتُب وَليُملِلِ الَّذي عَلَيهِ الحَقُّ وَليَتَّقِ اللَّهَ رَبَّهُ وَلا يَبخَس مِنهُ شَيئًا ۚ فَإِن كانَ الَّذي عَلَيهِ الحَقُّ سَفيهًا أَو ضَعيفًا أَو لا يَستَطيعُ أَن يُمِلَّ هُوَ فَليُملِل وَلِيُّهُ بِالعَدلِ ۚ وَاستَشهِدوا شَهيدَينِ مِن رِجالِكُم ۖ فَإِن لَم يَكونا رَجُلَينِ فَرَجُلٌ وَامرَأَتانِ مِمَّن تَرضَونَ مِنَ الشُّهَداءِ أَن تَضِلَّ إِحداهُما فَتُذَكِّرَ إِحداهُمَا الأُخرىٰ ۚ وَلا يَأبَ الشُّهَداءُ إِذا ما دُعوا ۚ وَلا تَسأَموا أَن تَكتُبوهُ صَغيرًا أَو كَبيرًا إِلىٰ أَجَلِهِ ۚ ذٰلِكُم أَقسَطُ عِندَ اللَّهِ وَأَقوَمُ لِلشَّهادَةِ وَأَدنىٰ أَلّا تَرتابوا ۖ إِلّا أَن تَكونَ تِجارَةً حاضِرَةً تُديرونَها بَينَكُم فَلَيسَ عَلَيكُم جُناحٌ أَلّا تَكتُبوها ۗ وَأَشهِدوا إِذا تَبايَعتُم ۚ وَلا يُضارَّ كاتِبٌ وَلا شَهيدٌ ۚ وَإِن تَفعَلوا فَإِنَّهُ فُسوقٌ بِكُم ۗ وَاتَّقُوا اللَّهَ ۖ وَيُعَلِّمُكُمُ اللَّهُ ۗ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٢٨٢﴾}}
\qt@newcmd\qurantext@ccxc{۞ وَإِن كُنتُم عَلىٰ سَفَرٍ وَلَم تَجِدوا كاتِبًا فَرِهانٌ مَقبوضَةٌ ۖ فَإِن أَمِنَ بَعضُكُم بَعضًا فَليُؤَدِّ الَّذِي اؤتُمِنَ أَمانَتَهُ وَليَتَّقِ اللَّهَ رَبَّهُ ۗ وَلا تَكتُمُوا الشَّهادَةَ ۚ وَمَن يَكتُمها فَإِنَّهُ آثِمٌ قَلبُهُ ۗ وَاللَّهُ بِما تَعمَلونَ عَليمٌ\qt@no{﴿٢٨٣﴾}}
\qt@newcmd\qurantext@ccxci{لِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۗ وَإِن تُبدوا ما في أَنفُسِكُم أَو تُخفوهُ يُحاسِبكُم بِهِ اللَّهُ ۖ فَيَغفِرُ لِمَن يَشاءُ وَيُعَذِّبُ مَن يَشاءُ ۗ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٨٤﴾}}
\qt@newcmd\qurantext@ccxcii{آمَنَ الرَّسولُ بِما أُنزِلَ إِلَيهِ مِن رَبِّهِ وَالمُؤمِنونَ ۚ كُلٌّ آمَنَ بِاللَّهِ وَمَلائِكَتِهِ وَكُتُبِهِ وَرُسُلِهِ لا نُفَرِّقُ بَينَ أَحَدٍ مِن رُسُلِهِ ۚ وَقالوا سَمِعنا وَأَطَعنا ۖ غُفرانَكَ رَبَّنا وَإِلَيكَ المَصيرُ\qt@no{﴿٢٨٥﴾}}
\qt@newcmd\qurantext@ccxciii{لا يُكَلِّفُ اللَّهُ نَفسًا إِلّا وُسعَها ۚ لَها ما كَسَبَت وَعَلَيها مَا اكتَسَبَت ۗ رَبَّنا لا تُؤاخِذنا إِن نَسينا أَو أَخطَأنا ۚ رَبَّنا وَلا تَحمِل عَلَينا إِصرًا كَما حَمَلتَهُ عَلَى الَّذينَ مِن قَبلِنا ۚ رَبَّنا وَلا تُحَمِّلنا ما لا طاقَةَ لَنا بِهِ ۖ وَاعفُ عَنّا وَاغفِر لَنا وَارحَمنا ۚ أَنتَ مَولانا فَانصُرنا عَلَى القَومِ الكافِرينَ\qt@no{﴿٢٨٦﴾}}
\qt@newcmd\qurantext@ccxciv{\basmalah الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@ccxcv{اللَّهُ لا إِلٰهَ إِلّا هُوَ الحَيُّ القَيّومُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@ccxcvi{نَزَّلَ عَلَيكَ الكِتابَ بِالحَقِّ مُصَدِّقًا لِما بَينَ يَدَيهِ وَأَنزَلَ التَّوراةَ وَالإِنجيلَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@ccxcvii{مِن قَبلُ هُدًى لِلنّاسِ وَأَنزَلَ الفُرقانَ ۗ إِنَّ الَّذينَ كَفَروا بِآياتِ اللَّهِ لَهُم عَذابٌ شَديدٌ ۗ وَاللَّهُ عَزيزٌ ذُو انتِقامٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@ccxcviii{إِنَّ اللَّهَ لا يَخفىٰ عَلَيهِ شَيءٌ فِي الأَرضِ وَلا فِي السَّماءِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@ccxcix{هُوَ الَّذي يُصَوِّرُكُم فِي الأَرحامِ كَيفَ يَشاءُ ۚ لا إِلٰهَ إِلّا هُوَ العَزيزُ الحَكيمُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@ccc{هُوَ الَّذي أَنزَلَ عَلَيكَ الكِتابَ مِنهُ آياتٌ مُحكَماتٌ هُنَّ أُمُّ الكِتابِ وَأُخَرُ مُتَشابِهاتٌ ۖ فَأَمَّا الَّذينَ في قُلوبِهِم زَيغٌ فَيَتَّبِعونَ ما تَشابَهَ مِنهُ ابتِغاءَ الفِتنَةِ وَابتِغاءَ تَأويلِهِ ۗ وَما يَعلَمُ تَأويلَهُ إِلَّا اللَّهُ ۗ وَالرّاسِخونَ فِي العِلمِ يَقولونَ آمَنّا بِهِ كُلٌّ مِن عِندِ رَبِّنا ۗ وَما يَذَّكَّرُ إِلّا أُولُو الأَلبابِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@ccci{رَبَّنا لا تُزِغ قُلوبَنا بَعدَ إِذ هَدَيتَنا وَهَب لَنا مِن لَدُنكَ رَحمَةً ۚ إِنَّكَ أَنتَ الوَهّابُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@cccii{رَبَّنا إِنَّكَ جامِعُ النّاسِ لِيَومٍ لا رَيبَ فيهِ ۚ إِنَّ اللَّهَ لا يُخلِفُ الميعادَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@ccciii{إِنَّ الَّذينَ كَفَروا لَن تُغنِيَ عَنهُم أَموالُهُم وَلا أَولادُهُم مِنَ اللَّهِ شَيئًا ۖ وَأُولٰئِكَ هُم وَقودُ النّارِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@ccciv{كَدَأبِ آلِ فِرعَونَ وَالَّذينَ مِن قَبلِهِم ۚ كَذَّبوا بِآياتِنا فَأَخَذَهُمُ اللَّهُ بِذُنوبِهِم ۗ وَاللَّهُ شَديدُ العِقابِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@cccv{قُل لِلَّذينَ كَفَروا سَتُغلَبونَ وَتُحشَرونَ إِلىٰ جَهَنَّمَ ۚ وَبِئسَ المِهادُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@cccvi{قَد كانَ لَكُم آيَةٌ في فِئَتَينِ التَقَتا ۖ فِئَةٌ تُقاتِلُ في سَبيلِ اللَّهِ وَأُخرىٰ كافِرَةٌ يَرَونَهُم مِثلَيهِم رَأيَ العَينِ ۚ وَاللَّهُ يُؤَيِّدُ بِنَصرِهِ مَن يَشاءُ ۗ إِنَّ في ذٰلِكَ لَعِبرَةً لِأُولِي الأَبصارِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@cccvii{زُيِّنَ لِلنّاسِ حُبُّ الشَّهَواتِ مِنَ النِّساءِ وَالبَنينَ وَالقَناطيرِ المُقَنطَرَةِ مِنَ الذَّهَبِ وَالفِضَّةِ وَالخَيلِ المُسَوَّمَةِ وَالأَنعامِ وَالحَرثِ ۗ ذٰلِكَ مَتاعُ الحَياةِ الدُّنيا ۖ وَاللَّهُ عِندَهُ حُسنُ المَآبِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@cccviii{۞ قُل أَؤُنَبِّئُكُم بِخَيرٍ مِن ذٰلِكُم ۚ لِلَّذينَ اتَّقَوا عِندَ رَبِّهِم جَنّاتٌ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها وَأَزواجٌ مُطَهَّرَةٌ وَرِضوانٌ مِنَ اللَّهِ ۗ وَاللَّهُ بَصيرٌ بِالعِبادِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@cccix{الَّذينَ يَقولونَ رَبَّنا إِنَّنا آمَنّا فَاغفِر لَنا ذُنوبَنا وَقِنا عَذابَ النّارِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@cccx{الصّابِرينَ وَالصّادِقينَ وَالقانِتينَ وَالمُنفِقينَ وَالمُستَغفِرينَ بِالأَسحارِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@cccxi{شَهِدَ اللَّهُ أَنَّهُ لا إِلٰهَ إِلّا هُوَ وَالمَلائِكَةُ وَأُولُو العِلمِ قائِمًا بِالقِسطِ ۚ لا إِلٰهَ إِلّا هُوَ العَزيزُ الحَكيمُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@cccxii{إِنَّ الدّينَ عِندَ اللَّهِ الإِسلامُ ۗ وَمَا اختَلَفَ الَّذينَ أوتُوا الكِتابَ إِلّا مِن بَعدِ ما جاءَهُمُ العِلمُ بَغيًا بَينَهُم ۗ وَمَن يَكفُر بِآياتِ اللَّهِ فَإِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@cccxiii{فَإِن حاجّوكَ فَقُل أَسلَمتُ وَجهِيَ لِلَّهِ وَمَنِ اتَّبَعَنِ ۗ وَقُل لِلَّذينَ أوتُوا الكِتابَ وَالأُمِّيّينَ أَأَسلَمتُم ۚ فَإِن أَسلَموا فَقَدِ اهتَدَوا ۖ وَإِن تَوَلَّوا فَإِنَّما عَلَيكَ البَلاغُ ۗ وَاللَّهُ بَصيرٌ بِالعِبادِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@cccxiv{إِنَّ الَّذينَ يَكفُرونَ بِآياتِ اللَّهِ وَيَقتُلونَ النَّبِيّينَ بِغَيرِ حَقٍّ وَيَقتُلونَ الَّذينَ يَأمُرونَ بِالقِسطِ مِنَ النّاسِ فَبَشِّرهُم بِعَذابٍ أَليمٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@cccxv{أُولٰئِكَ الَّذينَ حَبِطَت أَعمالُهُم فِي الدُّنيا وَالآخِرَةِ وَما لَهُم مِن ناصِرينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@cccxvi{أَلَم تَرَ إِلَى الَّذينَ أوتوا نَصيبًا مِنَ الكِتابِ يُدعَونَ إِلىٰ كِتابِ اللَّهِ لِيَحكُمَ بَينَهُم ثُمَّ يَتَوَلّىٰ فَريقٌ مِنهُم وَهُم مُعرِضونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@cccxvii{ذٰلِكَ بِأَنَّهُم قالوا لَن تَمَسَّنَا النّارُ إِلّا أَيّامًا مَعدوداتٍ ۖ وَغَرَّهُم في دينِهِم ما كانوا يَفتَرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@cccxviii{فَكَيفَ إِذا جَمَعناهُم لِيَومٍ لا رَيبَ فيهِ وَوُفِّيَت كُلُّ نَفسٍ ما كَسَبَت وَهُم لا يُظلَمونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@cccxix{قُلِ اللَّهُمَّ مالِكَ المُلكِ تُؤتِي المُلكَ مَن تَشاءُ وَتَنزِعُ المُلكَ مِمَّن تَشاءُ وَتُعِزُّ مَن تَشاءُ وَتُذِلُّ مَن تَشاءُ ۖ بِيَدِكَ الخَيرُ ۖ إِنَّكَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@cccxx{تولِجُ اللَّيلَ فِي النَّهارِ وَتولِجُ النَّهارَ فِي اللَّيلِ ۖ وَتُخرِجُ الحَيَّ مِنَ المَيِّتِ وَتُخرِجُ المَيِّتَ مِنَ الحَيِّ ۖ وَتَرزُقُ مَن تَشاءُ بِغَيرِ حِسابٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@cccxxi{لا يَتَّخِذِ المُؤمِنونَ الكافِرينَ أَولِياءَ مِن دونِ المُؤمِنينَ ۖ وَمَن يَفعَل ذٰلِكَ فَلَيسَ مِنَ اللَّهِ في شَيءٍ إِلّا أَن تَتَّقوا مِنهُم تُقاةً ۗ وَيُحَذِّرُكُمُ اللَّهُ نَفسَهُ ۗ وَإِلَى اللَّهِ المَصيرُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@cccxxii{قُل إِن تُخفوا ما في صُدورِكُم أَو تُبدوهُ يَعلَمهُ اللَّهُ ۗ وَيَعلَمُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۗ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@cccxxiii{يَومَ تَجِدُ كُلُّ نَفسٍ ما عَمِلَت مِن خَيرٍ مُحضَرًا وَما عَمِلَت مِن سوءٍ تَوَدُّ لَو أَنَّ بَينَها وَبَينَهُ أَمَدًا بَعيدًا ۗ وَيُحَذِّرُكُمُ اللَّهُ نَفسَهُ ۗ وَاللَّهُ رَءوفٌ بِالعِبادِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@cccxxiv{قُل إِن كُنتُم تُحِبّونَ اللَّهَ فَاتَّبِعوني يُحبِبكُمُ اللَّهُ وَيَغفِر لَكُم ذُنوبَكُم ۗ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@cccxxv{قُل أَطيعُوا اللَّهَ وَالرَّسولَ ۖ فَإِن تَوَلَّوا فَإِنَّ اللَّهَ لا يُحِبُّ الكافِرينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@cccxxvi{۞ إِنَّ اللَّهَ اصطَفىٰ آدَمَ وَنوحًا وَآلَ إِبراهيمَ وَآلَ عِمرانَ عَلَى العالَمينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@cccxxvii{ذُرِّيَّةً بَعضُها مِن بَعضٍ ۗ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@cccxxviii{إِذ قالَتِ امرَأَتُ عِمرانَ رَبِّ إِنّي نَذَرتُ لَكَ ما في بَطني مُحَرَّرًا فَتَقَبَّل مِنّي ۖ إِنَّكَ أَنتَ السَّميعُ العَليمُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@cccxxix{فَلَمّا وَضَعَتها قالَت رَبِّ إِنّي وَضَعتُها أُنثىٰ وَاللَّهُ أَعلَمُ بِما وَضَعَت وَلَيسَ الذَّكَرُ كَالأُنثىٰ ۖ وَإِنّي سَمَّيتُها مَريَمَ وَإِنّي أُعيذُها بِكَ وَذُرِّيَّتَها مِنَ الشَّيطانِ الرَّجيمِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@cccxxx{فَتَقَبَّلَها رَبُّها بِقَبولٍ حَسَنٍ وَأَنبَتَها نَباتًا حَسَنًا وَكَفَّلَها زَكَرِيّا ۖ كُلَّما دَخَلَ عَلَيها زَكَرِيَّا المِحرابَ وَجَدَ عِندَها رِزقًا ۖ قالَ يا مَريَمُ أَنّىٰ لَكِ هٰذا ۖ قالَت هُوَ مِن عِندِ اللَّهِ ۖ إِنَّ اللَّهَ يَرزُقُ مَن يَشاءُ بِغَيرِ حِسابٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@cccxxxi{هُنالِكَ دَعا زَكَرِيّا رَبَّهُ ۖ قالَ رَبِّ هَب لي مِن لَدُنكَ ذُرِّيَّةً طَيِّبَةً ۖ إِنَّكَ سَميعُ الدُّعاءِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@cccxxxii{فَنادَتهُ المَلائِكَةُ وَهُوَ قائِمٌ يُصَلّي فِي المِحرابِ أَنَّ اللَّهَ يُبَشِّرُكَ بِيَحيىٰ مُصَدِّقًا بِكَلِمَةٍ مِنَ اللَّهِ وَسَيِّدًا وَحَصورًا وَنَبِيًّا مِنَ الصّالِحينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@cccxxxiii{قالَ رَبِّ أَنّىٰ يَكونُ لي غُلامٌ وَقَد بَلَغَنِيَ الكِبَرُ وَامرَأَتي عاقِرٌ ۖ قالَ كَذٰلِكَ اللَّهُ يَفعَلُ ما يَشاءُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@cccxxxiv{قالَ رَبِّ اجعَل لي آيَةً ۖ قالَ آيَتُكَ أَلّا تُكَلِّمَ النّاسَ ثَلاثَةَ أَيّامٍ إِلّا رَمزًا ۗ وَاذكُر رَبَّكَ كَثيرًا وَسَبِّح بِالعَشِيِّ وَالإِبكارِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@cccxxxv{وَإِذ قالَتِ المَلائِكَةُ يا مَريَمُ إِنَّ اللَّهَ اصطَفاكِ وَطَهَّرَكِ وَاصطَفاكِ عَلىٰ نِساءِ العالَمينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@cccxxxvi{يا مَريَمُ اقنُتي لِرَبِّكِ وَاسجُدي وَاركَعي مَعَ الرّاكِعينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@cccxxxvii{ذٰلِكَ مِن أَنباءِ الغَيبِ نوحيهِ إِلَيكَ ۚ وَما كُنتَ لَدَيهِم إِذ يُلقونَ أَقلامَهُم أَيُّهُم يَكفُلُ مَريَمَ وَما كُنتَ لَدَيهِم إِذ يَختَصِمونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@cccxxxviii{إِذ قالَتِ المَلائِكَةُ يا مَريَمُ إِنَّ اللَّهَ يُبَشِّرُكِ بِكَلِمَةٍ مِنهُ اسمُهُ المَسيحُ عيسَى ابنُ مَريَمَ وَجيهًا فِي الدُّنيا وَالآخِرَةِ وَمِنَ المُقَرَّبينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@cccxxxix{وَيُكَلِّمُ النّاسَ فِي المَهدِ وَكَهلًا وَمِنَ الصّالِحينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@cccxl{قالَت رَبِّ أَنّىٰ يَكونُ لي وَلَدٌ وَلَم يَمسَسني بَشَرٌ ۖ قالَ كَذٰلِكِ اللَّهُ يَخلُقُ ما يَشاءُ ۚ إِذا قَضىٰ أَمرًا فَإِنَّما يَقولُ لَهُ كُن فَيَكونُ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@cccxli{وَيُعَلِّمُهُ الكِتابَ وَالحِكمَةَ وَالتَّوراةَ وَالإِنجيلَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@cccxlii{وَرَسولًا إِلىٰ بَني إِسرائيلَ أَنّي قَد جِئتُكُم بِآيَةٍ مِن رَبِّكُم ۖ أَنّي أَخلُقُ لَكُم مِنَ الطّينِ كَهَيئَةِ الطَّيرِ فَأَنفُخُ فيهِ فَيَكونُ طَيرًا بِإِذنِ اللَّهِ ۖ وَأُبرِئُ الأَكمَهَ وَالأَبرَصَ وَأُحيِي المَوتىٰ بِإِذنِ اللَّهِ ۖ وَأُنَبِّئُكُم بِما تَأكُلونَ وَما تَدَّخِرونَ في بُيوتِكُم ۚ إِنَّ في ذٰلِكَ لَآيَةً لَكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@cccxliii{وَمُصَدِّقًا لِما بَينَ يَدَيَّ مِنَ التَّوراةِ وَلِأُحِلَّ لَكُم بَعضَ الَّذي حُرِّمَ عَلَيكُم ۚ وَجِئتُكُم بِآيَةٍ مِن رَبِّكُم فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@cccxliv{إِنَّ اللَّهَ رَبّي وَرَبُّكُم فَاعبُدوهُ ۗ هٰذا صِراطٌ مُستَقيمٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@cccxlv{۞ فَلَمّا أَحَسَّ عيسىٰ مِنهُمُ الكُفرَ قالَ مَن أَنصاري إِلَى اللَّهِ ۖ قالَ الحَوارِيّونَ نَحنُ أَنصارُ اللَّهِ آمَنّا بِاللَّهِ وَاشهَد بِأَنّا مُسلِمونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@cccxlvi{رَبَّنا آمَنّا بِما أَنزَلتَ وَاتَّبَعنَا الرَّسولَ فَاكتُبنا مَعَ الشّاهِدينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@cccxlvii{وَمَكَروا وَمَكَرَ اللَّهُ ۖ وَاللَّهُ خَيرُ الماكِرينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@cccxlviii{إِذ قالَ اللَّهُ يا عيسىٰ إِنّي مُتَوَفّيكَ وَرافِعُكَ إِلَيَّ وَمُطَهِّرُكَ مِنَ الَّذينَ كَفَروا وَجاعِلُ الَّذينَ اتَّبَعوكَ فَوقَ الَّذينَ كَفَروا إِلىٰ يَومِ القِيامَةِ ۖ ثُمَّ إِلَيَّ مَرجِعُكُم فَأَحكُمُ بَينَكُم فيما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@cccxlix{فَأَمَّا الَّذينَ كَفَروا فَأُعَذِّبُهُم عَذابًا شَديدًا فِي الدُّنيا وَالآخِرَةِ وَما لَهُم مِن ناصِرينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@cccl{وَأَمَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ فَيُوَفّيهِم أُجورَهُم ۗ وَاللَّهُ لا يُحِبُّ الظّالِمينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@cccli{ذٰلِكَ نَتلوهُ عَلَيكَ مِنَ الآياتِ وَالذِّكرِ الحَكيمِ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@ccclii{إِنَّ مَثَلَ عيسىٰ عِندَ اللَّهِ كَمَثَلِ آدَمَ ۖ خَلَقَهُ مِن تُرابٍ ثُمَّ قالَ لَهُ كُن فَيَكونُ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@cccliii{الحَقُّ مِن رَبِّكَ فَلا تَكُن مِنَ المُمتَرينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@cccliv{فَمَن حاجَّكَ فيهِ مِن بَعدِ ما جاءَكَ مِنَ العِلمِ فَقُل تَعالَوا نَدعُ أَبناءَنا وَأَبناءَكُم وَنِساءَنا وَنِساءَكُم وَأَنفُسَنا وَأَنفُسَكُم ثُمَّ نَبتَهِل فَنَجعَل لَعنَتَ اللَّهِ عَلَى الكاذِبينَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@ccclv{إِنَّ هٰذا لَهُوَ القَصَصُ الحَقُّ ۚ وَما مِن إِلٰهٍ إِلَّا اللَّهُ ۚ وَإِنَّ اللَّهَ لَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@ccclvi{فَإِن تَوَلَّوا فَإِنَّ اللَّهَ عَليمٌ بِالمُفسِدينَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@ccclvii{قُل يا أَهلَ الكِتابِ تَعالَوا إِلىٰ كَلِمَةٍ سَواءٍ بَينَنا وَبَينَكُم أَلّا نَعبُدَ إِلَّا اللَّهَ وَلا نُشرِكَ بِهِ شَيئًا وَلا يَتَّخِذَ بَعضُنا بَعضًا أَربابًا مِن دونِ اللَّهِ ۚ فَإِن تَوَلَّوا فَقولُوا اشهَدوا بِأَنّا مُسلِمونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@ccclviii{يا أَهلَ الكِتابِ لِمَ تُحاجّونَ في إِبراهيمَ وَما أُنزِلَتِ التَّوراةُ وَالإِنجيلُ إِلّا مِن بَعدِهِ ۚ أَفَلا تَعقِلونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@ccclix{ها أَنتُم هٰؤُلاءِ حاجَجتُم فيما لَكُم بِهِ عِلمٌ فَلِمَ تُحاجّونَ فيما لَيسَ لَكُم بِهِ عِلمٌ ۚ وَاللَّهُ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@ccclx{ما كانَ إِبراهيمُ يَهودِيًّا وَلا نَصرانِيًّا وَلٰكِن كانَ حَنيفًا مُسلِمًا وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@ccclxi{إِنَّ أَولَى النّاسِ بِإِبراهيمَ لَلَّذينَ اتَّبَعوهُ وَهٰذَا النَّبِيُّ وَالَّذينَ آمَنوا ۗ وَاللَّهُ وَلِيُّ المُؤمِنينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@ccclxii{وَدَّت طائِفَةٌ مِن أَهلِ الكِتابِ لَو يُضِلّونَكُم وَما يُضِلّونَ إِلّا أَنفُسَهُم وَما يَشعُرونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@ccclxiii{يا أَهلَ الكِتابِ لِمَ تَكفُرونَ بِآياتِ اللَّهِ وَأَنتُم تَشهَدونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@ccclxiv{يا أَهلَ الكِتابِ لِمَ تَلبِسونَ الحَقَّ بِالباطِلِ وَتَكتُمونَ الحَقَّ وَأَنتُم تَعلَمونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@ccclxv{وَقالَت طائِفَةٌ مِن أَهلِ الكِتابِ آمِنوا بِالَّذي أُنزِلَ عَلَى الَّذينَ آمَنوا وَجهَ النَّهارِ وَاكفُروا آخِرَهُ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@ccclxvi{وَلا تُؤمِنوا إِلّا لِمَن تَبِعَ دينَكُم قُل إِنَّ الهُدىٰ هُدَى اللَّهِ أَن يُؤتىٰ أَحَدٌ مِثلَ ما أوتيتُم أَو يُحاجّوكُم عِندَ رَبِّكُم ۗ قُل إِنَّ الفَضلَ بِيَدِ اللَّهِ يُؤتيهِ مَن يَشاءُ ۗ وَاللَّهُ واسِعٌ عَليمٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@ccclxvii{يَختَصُّ بِرَحمَتِهِ مَن يَشاءُ ۗ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@ccclxviii{۞ وَمِن أَهلِ الكِتابِ مَن إِن تَأمَنهُ بِقِنطارٍ يُؤَدِّهِ إِلَيكَ وَمِنهُم مَن إِن تَأمَنهُ بِدينارٍ لا يُؤَدِّهِ إِلَيكَ إِلّا ما دُمتَ عَلَيهِ قائِمًا ۗ ذٰلِكَ بِأَنَّهُم قالوا لَيسَ عَلَينا فِي الأُمِّيّينَ سَبيلٌ وَيَقولونَ عَلَى اللَّهِ الكَذِبَ وَهُم يَعلَمونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@ccclxix{بَلىٰ مَن أَوفىٰ بِعَهدِهِ وَاتَّقىٰ فَإِنَّ اللَّهَ يُحِبُّ المُتَّقينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@ccclxx{إِنَّ الَّذينَ يَشتَرونَ بِعَهدِ اللَّهِ وَأَيمانِهِم ثَمَنًا قَليلًا أُولٰئِكَ لا خَلاقَ لَهُم فِي الآخِرَةِ وَلا يُكَلِّمُهُمُ اللَّهُ وَلا يَنظُرُ إِلَيهِم يَومَ القِيامَةِ وَلا يُزَكّيهِم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@ccclxxi{وَإِنَّ مِنهُم لَفَريقًا يَلوونَ أَلسِنَتَهُم بِالكِتابِ لِتَحسَبوهُ مِنَ الكِتابِ وَما هُوَ مِنَ الكِتابِ وَيَقولونَ هُوَ مِن عِندِ اللَّهِ وَما هُوَ مِن عِندِ اللَّهِ وَيَقولونَ عَلَى اللَّهِ الكَذِبَ وَهُم يَعلَمونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@ccclxxii{ما كانَ لِبَشَرٍ أَن يُؤتِيَهُ اللَّهُ الكِتابَ وَالحُكمَ وَالنُّبُوَّةَ ثُمَّ يَقولَ لِلنّاسِ كونوا عِبادًا لي مِن دونِ اللَّهِ وَلٰكِن كونوا رَبّانِيّينَ بِما كُنتُم تُعَلِّمونَ الكِتابَ وَبِما كُنتُم تَدرُسونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@ccclxxiii{وَلا يَأمُرَكُم أَن تَتَّخِذُوا المَلائِكَةَ وَالنَّبِيّينَ أَربابًا ۗ أَيَأمُرُكُم بِالكُفرِ بَعدَ إِذ أَنتُم مُسلِمونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@ccclxxiv{وَإِذ أَخَذَ اللَّهُ ميثاقَ النَّبِيّينَ لَما آتَيتُكُم مِن كِتابٍ وَحِكمَةٍ ثُمَّ جاءَكُم رَسولٌ مُصَدِّقٌ لِما مَعَكُم لَتُؤمِنُنَّ بِهِ وَلَتَنصُرُنَّهُ ۚ قالَ أَأَقرَرتُم وَأَخَذتُم عَلىٰ ذٰلِكُم إِصري ۖ قالوا أَقرَرنا ۚ قالَ فَاشهَدوا وَأَنا مَعَكُم مِنَ الشّاهِدينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@ccclxxv{فَمَن تَوَلّىٰ بَعدَ ذٰلِكَ فَأُولٰئِكَ هُمُ الفاسِقونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@ccclxxvi{أَفَغَيرَ دينِ اللَّهِ يَبغونَ وَلَهُ أَسلَمَ مَن فِي السَّماواتِ وَالأَرضِ طَوعًا وَكَرهًا وَإِلَيهِ يُرجَعونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@ccclxxvii{قُل آمَنّا بِاللَّهِ وَما أُنزِلَ عَلَينا وَما أُنزِلَ عَلىٰ إِبراهيمَ وَإِسماعيلَ وَإِسحاقَ وَيَعقوبَ وَالأَسباطِ وَما أوتِيَ موسىٰ وَعيسىٰ وَالنَّبِيّونَ مِن رَبِّهِم لا نُفَرِّقُ بَينَ أَحَدٍ مِنهُم وَنَحنُ لَهُ مُسلِمونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@ccclxxviii{وَمَن يَبتَغِ غَيرَ الإِسلامِ دينًا فَلَن يُقبَلَ مِنهُ وَهُوَ فِي الآخِرَةِ مِنَ الخاسِرينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@ccclxxix{كَيفَ يَهدِي اللَّهُ قَومًا كَفَروا بَعدَ إيمانِهِم وَشَهِدوا أَنَّ الرَّسولَ حَقٌّ وَجاءَهُمُ البَيِّناتُ ۚ وَاللَّهُ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@ccclxxx{أُولٰئِكَ جَزاؤُهُم أَنَّ عَلَيهِم لَعنَةَ اللَّهِ وَالمَلائِكَةِ وَالنّاسِ أَجمَعينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@ccclxxxi{خالِدينَ فيها لا يُخَفَّفُ عَنهُمُ العَذابُ وَلا هُم يُنظَرونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@ccclxxxii{إِلَّا الَّذينَ تابوا مِن بَعدِ ذٰلِكَ وَأَصلَحوا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@ccclxxxiii{إِنَّ الَّذينَ كَفَروا بَعدَ إيمانِهِم ثُمَّ ازدادوا كُفرًا لَن تُقبَلَ تَوبَتُهُم وَأُولٰئِكَ هُمُ الضّالّونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@ccclxxxiv{إِنَّ الَّذينَ كَفَروا وَماتوا وَهُم كُفّارٌ فَلَن يُقبَلَ مِن أَحَدِهِم مِلءُ الأَرضِ ذَهَبًا وَلَوِ افتَدىٰ بِهِ ۗ أُولٰئِكَ لَهُم عَذابٌ أَليمٌ وَما لَهُم مِن ناصِرينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@ccclxxxv{لَن تَنالُوا البِرَّ حَتّىٰ تُنفِقوا مِمّا تُحِبّونَ ۚ وَما تُنفِقوا مِن شَيءٍ فَإِنَّ اللَّهَ بِهِ عَليمٌ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@ccclxxxvi{۞ كُلُّ الطَّعامِ كانَ حِلًّا لِبَني إِسرائيلَ إِلّا ما حَرَّمَ إِسرائيلُ عَلىٰ نَفسِهِ مِن قَبلِ أَن تُنَزَّلَ التَّوراةُ ۗ قُل فَأتوا بِالتَّوراةِ فَاتلوها إِن كُنتُم صادِقينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@ccclxxxvii{فَمَنِ افتَرىٰ عَلَى اللَّهِ الكَذِبَ مِن بَعدِ ذٰلِكَ فَأُولٰئِكَ هُمُ الظّالِمونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@ccclxxxviii{قُل صَدَقَ اللَّهُ ۗ فَاتَّبِعوا مِلَّةَ إِبراهيمَ حَنيفًا وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@ccclxxxix{إِنَّ أَوَّلَ بَيتٍ وُضِعَ لِلنّاسِ لَلَّذي بِبَكَّةَ مُبارَكًا وَهُدًى لِلعالَمينَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@cccxc{فيهِ آياتٌ بَيِّناتٌ مَقامُ إِبراهيمَ ۖ وَمَن دَخَلَهُ كانَ آمِنًا ۗ وَلِلَّهِ عَلَى النّاسِ حِجُّ البَيتِ مَنِ استَطاعَ إِلَيهِ سَبيلًا ۚ وَمَن كَفَرَ فَإِنَّ اللَّهَ غَنِيٌّ عَنِ العالَمينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@cccxci{قُل يا أَهلَ الكِتابِ لِمَ تَكفُرونَ بِآياتِ اللَّهِ وَاللَّهُ شَهيدٌ عَلىٰ ما تَعمَلونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@cccxcii{قُل يا أَهلَ الكِتابِ لِمَ تَصُدّونَ عَن سَبيلِ اللَّهِ مَن آمَنَ تَبغونَها عِوَجًا وَأَنتُم شُهَداءُ ۗ وَمَا اللَّهُ بِغافِلٍ عَمّا تَعمَلونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@cccxciii{يا أَيُّهَا الَّذينَ آمَنوا إِن تُطيعوا فَريقًا مِنَ الَّذينَ أوتُوا الكِتابَ يَرُدّوكُم بَعدَ إيمانِكُم كافِرينَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@cccxciv{وَكَيفَ تَكفُرونَ وَأَنتُم تُتلىٰ عَلَيكُم آياتُ اللَّهِ وَفيكُم رَسولُهُ ۗ وَمَن يَعتَصِم بِاللَّهِ فَقَد هُدِيَ إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@cccxcv{يا أَيُّهَا الَّذينَ آمَنُوا اتَّقُوا اللَّهَ حَقَّ تُقاتِهِ وَلا تَموتُنَّ إِلّا وَأَنتُم مُسلِمونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@cccxcvi{وَاعتَصِموا بِحَبلِ اللَّهِ جَميعًا وَلا تَفَرَّقوا ۚ وَاذكُروا نِعمَتَ اللَّهِ عَلَيكُم إِذ كُنتُم أَعداءً فَأَلَّفَ بَينَ قُلوبِكُم فَأَصبَحتُم بِنِعمَتِهِ إِخوانًا وَكُنتُم عَلىٰ شَفا حُفرَةٍ مِنَ النّارِ فَأَنقَذَكُم مِنها ۗ كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُم آياتِهِ لَعَلَّكُم تَهتَدونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@cccxcvii{وَلتَكُن مِنكُم أُمَّةٌ يَدعونَ إِلَى الخَيرِ وَيَأمُرونَ بِالمَعروفِ وَيَنهَونَ عَنِ المُنكَرِ ۚ وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@cccxcviii{وَلا تَكونوا كَالَّذينَ تَفَرَّقوا وَاختَلَفوا مِن بَعدِ ما جاءَهُمُ البَيِّناتُ ۚ وَأُولٰئِكَ لَهُم عَذابٌ عَظيمٌ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@cccxcix{يَومَ تَبيَضُّ وُجوهٌ وَتَسوَدُّ وُجوهٌ ۚ فَأَمَّا الَّذينَ اسوَدَّت وُجوهُهُم أَكَفَرتُم بَعدَ إيمانِكُم فَذوقُوا العَذابَ بِما كُنتُم تَكفُرونَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@cd{وَأَمَّا الَّذينَ ابيَضَّت وُجوهُهُم فَفي رَحمَةِ اللَّهِ هُم فيها خالِدونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@cdi{تِلكَ آياتُ اللَّهِ نَتلوها عَلَيكَ بِالحَقِّ ۗ وَمَا اللَّهُ يُريدُ ظُلمًا لِلعالَمينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@cdii{وَلِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۚ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@cdiii{كُنتُم خَيرَ أُمَّةٍ أُخرِجَت لِلنّاسِ تَأمُرونَ بِالمَعروفِ وَتَنهَونَ عَنِ المُنكَرِ وَتُؤمِنونَ بِاللَّهِ ۗ وَلَو آمَنَ أَهلُ الكِتابِ لَكانَ خَيرًا لَهُم ۚ مِنهُمُ المُؤمِنونَ وَأَكثَرُهُمُ الفاسِقونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@cdiv{لَن يَضُرّوكُم إِلّا أَذًى ۖ وَإِن يُقاتِلوكُم يُوَلّوكُمُ الأَدبارَ ثُمَّ لا يُنصَرونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@cdv{ضُرِبَت عَلَيهِمُ الذِّلَّةُ أَينَ ما ثُقِفوا إِلّا بِحَبلٍ مِنَ اللَّهِ وَحَبلٍ مِنَ النّاسِ وَباءوا بِغَضَبٍ مِنَ اللَّهِ وَضُرِبَت عَلَيهِمُ المَسكَنَةُ ۚ ذٰلِكَ بِأَنَّهُم كانوا يَكفُرونَ بِآياتِ اللَّهِ وَيَقتُلونَ الأَنبِياءَ بِغَيرِ حَقٍّ ۚ ذٰلِكَ بِما عَصَوا وَكانوا يَعتَدونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@cdvi{۞ لَيسوا سَواءً ۗ مِن أَهلِ الكِتابِ أُمَّةٌ قائِمَةٌ يَتلونَ آياتِ اللَّهِ آناءَ اللَّيلِ وَهُم يَسجُدونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@cdvii{يُؤمِنونَ بِاللَّهِ وَاليَومِ الآخِرِ وَيَأمُرونَ بِالمَعروفِ وَيَنهَونَ عَنِ المُنكَرِ وَيُسارِعونَ فِي الخَيراتِ وَأُولٰئِكَ مِنَ الصّالِحينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@cdviii{وَما يَفعَلوا مِن خَيرٍ فَلَن يُكفَروهُ ۗ وَاللَّهُ عَليمٌ بِالمُتَّقينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@cdix{إِنَّ الَّذينَ كَفَروا لَن تُغنِيَ عَنهُم أَموالُهُم وَلا أَولادُهُم مِنَ اللَّهِ شَيئًا ۖ وَأُولٰئِكَ أَصحابُ النّارِ ۚ هُم فيها خالِدونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@cdx{مَثَلُ ما يُنفِقونَ في هٰذِهِ الحَياةِ الدُّنيا كَمَثَلِ ريحٍ فيها صِرٌّ أَصابَت حَرثَ قَومٍ ظَلَموا أَنفُسَهُم فَأَهلَكَتهُ ۚ وَما ظَلَمَهُمُ اللَّهُ وَلٰكِن أَنفُسَهُم يَظلِمونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@cdxi{يا أَيُّهَا الَّذينَ آمَنوا لا تَتَّخِذوا بِطانَةً مِن دونِكُم لا يَألونَكُم خَبالًا وَدّوا ما عَنِتُّم قَد بَدَتِ البَغضاءُ مِن أَفواهِهِم وَما تُخفي صُدورُهُم أَكبَرُ ۚ قَد بَيَّنّا لَكُمُ الآياتِ ۖ إِن كُنتُم تَعقِلونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@cdxii{ها أَنتُم أُولاءِ تُحِبّونَهُم وَلا يُحِبّونَكُم وَتُؤمِنونَ بِالكِتابِ كُلِّهِ وَإِذا لَقوكُم قالوا آمَنّا وَإِذا خَلَوا عَضّوا عَلَيكُمُ الأَنامِلَ مِنَ الغَيظِ ۚ قُل موتوا بِغَيظِكُم ۗ إِنَّ اللَّهَ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@cdxiii{إِن تَمسَسكُم حَسَنَةٌ تَسُؤهُم وَإِن تُصِبكُم سَيِّئَةٌ يَفرَحوا بِها ۖ وَإِن تَصبِروا وَتَتَّقوا لا يَضُرُّكُم كَيدُهُم شَيئًا ۗ إِنَّ اللَّهَ بِما يَعمَلونَ مُحيطٌ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@cdxiv{وَإِذ غَدَوتَ مِن أَهلِكَ تُبَوِّئُ المُؤمِنينَ مَقاعِدَ لِلقِتالِ ۗ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@cdxv{إِذ هَمَّت طائِفَتانِ مِنكُم أَن تَفشَلا وَاللَّهُ وَلِيُّهُما ۗ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@cdxvi{وَلَقَد نَصَرَكُمُ اللَّهُ بِبَدرٍ وَأَنتُم أَذِلَّةٌ ۖ فَاتَّقُوا اللَّهَ لَعَلَّكُم تَشكُرونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@cdxvii{إِذ تَقولُ لِلمُؤمِنينَ أَلَن يَكفِيَكُم أَن يُمِدَّكُم رَبُّكُم بِثَلاثَةِ آلافٍ مِنَ المَلائِكَةِ مُنزَلينَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@cdxviii{بَلىٰ ۚ إِن تَصبِروا وَتَتَّقوا وَيَأتوكُم مِن فَورِهِم هٰذا يُمدِدكُم رَبُّكُم بِخَمسَةِ آلافٍ مِنَ المَلائِكَةِ مُسَوِّمينَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@cdxix{وَما جَعَلَهُ اللَّهُ إِلّا بُشرىٰ لَكُم وَلِتَطمَئِنَّ قُلوبُكُم بِهِ ۗ وَمَا النَّصرُ إِلّا مِن عِندِ اللَّهِ العَزيزِ الحَكيمِ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@cdxx{لِيَقطَعَ طَرَفًا مِنَ الَّذينَ كَفَروا أَو يَكبِتَهُم فَيَنقَلِبوا خائِبينَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@cdxxi{لَيسَ لَكَ مِنَ الأَمرِ شَيءٌ أَو يَتوبَ عَلَيهِم أَو يُعَذِّبَهُم فَإِنَّهُم ظالِمونَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@cdxxii{وَلِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۚ يَغفِرُ لِمَن يَشاءُ وَيُعَذِّبُ مَن يَشاءُ ۚ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@cdxxiii{يا أَيُّهَا الَّذينَ آمَنوا لا تَأكُلُوا الرِّبا أَضعافًا مُضاعَفَةً ۖ وَاتَّقُوا اللَّهَ لَعَلَّكُم تُفلِحونَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@cdxxiv{وَاتَّقُوا النّارَ الَّتي أُعِدَّت لِلكافِرينَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@cdxxv{وَأَطيعُوا اللَّهَ وَالرَّسولَ لَعَلَّكُم تُرحَمونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@cdxxvi{۞ وَسارِعوا إِلىٰ مَغفِرَةٍ مِن رَبِّكُم وَجَنَّةٍ عَرضُهَا السَّماواتُ وَالأَرضُ أُعِدَّت لِلمُتَّقينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@cdxxvii{الَّذينَ يُنفِقونَ فِي السَّرّاءِ وَالضَّرّاءِ وَالكاظِمينَ الغَيظَ وَالعافينَ عَنِ النّاسِ ۗ وَاللَّهُ يُحِبُّ المُحسِنينَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@cdxxviii{وَالَّذينَ إِذا فَعَلوا فاحِشَةً أَو ظَلَموا أَنفُسَهُم ذَكَرُوا اللَّهَ فَاستَغفَروا لِذُنوبِهِم وَمَن يَغفِرُ الذُّنوبَ إِلَّا اللَّهُ وَلَم يُصِرّوا عَلىٰ ما فَعَلوا وَهُم يَعلَمونَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@cdxxix{أُولٰئِكَ جَزاؤُهُم مَغفِرَةٌ مِن رَبِّهِم وَجَنّاتٌ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها ۚ وَنِعمَ أَجرُ العامِلينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@cdxxx{قَد خَلَت مِن قَبلِكُم سُنَنٌ فَسيروا فِي الأَرضِ فَانظُروا كَيفَ كانَ عاقِبَةُ المُكَذِّبينَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@cdxxxi{هٰذا بَيانٌ لِلنّاسِ وَهُدًى وَمَوعِظَةٌ لِلمُتَّقينَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@cdxxxii{وَلا تَهِنوا وَلا تَحزَنوا وَأَنتُمُ الأَعلَونَ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@cdxxxiii{إِن يَمسَسكُم قَرحٌ فَقَد مَسَّ القَومَ قَرحٌ مِثلُهُ ۚ وَتِلكَ الأَيّامُ نُداوِلُها بَينَ النّاسِ وَلِيَعلَمَ اللَّهُ الَّذينَ آمَنوا وَيَتَّخِذَ مِنكُم شُهَداءَ ۗ وَاللَّهُ لا يُحِبُّ الظّالِمينَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@cdxxxiv{وَلِيُمَحِّصَ اللَّهُ الَّذينَ آمَنوا وَيَمحَقَ الكافِرينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@cdxxxv{أَم حَسِبتُم أَن تَدخُلُوا الجَنَّةَ وَلَمّا يَعلَمِ اللَّهُ الَّذينَ جاهَدوا مِنكُم وَيَعلَمَ الصّابِرينَ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@cdxxxvi{وَلَقَد كُنتُم تَمَنَّونَ المَوتَ مِن قَبلِ أَن تَلقَوهُ فَقَد رَأَيتُموهُ وَأَنتُم تَنظُرونَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@cdxxxvii{وَما مُحَمَّدٌ إِلّا رَسولٌ قَد خَلَت مِن قَبلِهِ الرُّسُلُ ۚ أَفَإِن ماتَ أَو قُتِلَ انقَلَبتُم عَلىٰ أَعقابِكُم ۚ وَمَن يَنقَلِب عَلىٰ عَقِبَيهِ فَلَن يَضُرَّ اللَّهَ شَيئًا ۗ وَسَيَجزِي اللَّهُ الشّاكِرينَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@cdxxxviii{وَما كانَ لِنَفسٍ أَن تَموتَ إِلّا بِإِذنِ اللَّهِ كِتابًا مُؤَجَّلًا ۗ وَمَن يُرِد ثَوابَ الدُّنيا نُؤتِهِ مِنها وَمَن يُرِد ثَوابَ الآخِرَةِ نُؤتِهِ مِنها ۚ وَسَنَجزِي الشّاكِرينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@cdxxxix{وَكَأَيِّن مِن نَبِيٍّ قاتَلَ مَعَهُ رِبِّيّونَ كَثيرٌ فَما وَهَنوا لِما أَصابَهُم في سَبيلِ اللَّهِ وَما ضَعُفوا وَمَا استَكانوا ۗ وَاللَّهُ يُحِبُّ الصّابِرينَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@cdxl{وَما كانَ قَولَهُم إِلّا أَن قالوا رَبَّنَا اغفِر لَنا ذُنوبَنا وَإِسرافَنا في أَمرِنا وَثَبِّت أَقدامَنا وَانصُرنا عَلَى القَومِ الكافِرينَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@cdxli{فَآتاهُمُ اللَّهُ ثَوابَ الدُّنيا وَحُسنَ ثَوابِ الآخِرَةِ ۗ وَاللَّهُ يُحِبُّ المُحسِنينَ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@cdxlii{يا أَيُّهَا الَّذينَ آمَنوا إِن تُطيعُوا الَّذينَ كَفَروا يَرُدّوكُم عَلىٰ أَعقابِكُم فَتَنقَلِبوا خاسِرينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@cdxliii{بَلِ اللَّهُ مَولاكُم ۖ وَهُوَ خَيرُ النّاصِرينَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@cdxliv{سَنُلقي في قُلوبِ الَّذينَ كَفَرُوا الرُّعبَ بِما أَشرَكوا بِاللَّهِ ما لَم يُنَزِّل بِهِ سُلطانًا ۖ وَمَأواهُمُ النّارُ ۚ وَبِئسَ مَثوَى الظّالِمينَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@cdxlv{وَلَقَد صَدَقَكُمُ اللَّهُ وَعدَهُ إِذ تَحُسّونَهُم بِإِذنِهِ ۖ حَتّىٰ إِذا فَشِلتُم وَتَنازَعتُم فِي الأَمرِ وَعَصَيتُم مِن بَعدِ ما أَراكُم ما تُحِبّونَ ۚ مِنكُم مَن يُريدُ الدُّنيا وَمِنكُم مَن يُريدُ الآخِرَةَ ۚ ثُمَّ صَرَفَكُم عَنهُم لِيَبتَلِيَكُم ۖ وَلَقَد عَفا عَنكُم ۗ وَاللَّهُ ذو فَضلٍ عَلَى المُؤمِنينَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@cdxlvi{۞ إِذ تُصعِدونَ وَلا تَلوونَ عَلىٰ أَحَدٍ وَالرَّسولُ يَدعوكُم في أُخراكُم فَأَثابَكُم غَمًّا بِغَمٍّ لِكَيلا تَحزَنوا عَلىٰ ما فاتَكُم وَلا ما أَصابَكُم ۗ وَاللَّهُ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@cdxlvii{ثُمَّ أَنزَلَ عَلَيكُم مِن بَعدِ الغَمِّ أَمَنَةً نُعاسًا يَغشىٰ طائِفَةً مِنكُم ۖ وَطائِفَةٌ قَد أَهَمَّتهُم أَنفُسُهُم يَظُنّونَ بِاللَّهِ غَيرَ الحَقِّ ظَنَّ الجاهِلِيَّةِ ۖ يَقولونَ هَل لَنا مِنَ الأَمرِ مِن شَيءٍ ۗ قُل إِنَّ الأَمرَ كُلَّهُ لِلَّهِ ۗ يُخفونَ في أَنفُسِهِم ما لا يُبدونَ لَكَ ۖ يَقولونَ لَو كانَ لَنا مِنَ الأَمرِ شَيءٌ ما قُتِلنا هاهُنا ۗ قُل لَو كُنتُم في بُيوتِكُم لَبَرَزَ الَّذينَ كُتِبَ عَلَيهِمُ القَتلُ إِلىٰ مَضاجِعِهِم ۖ وَلِيَبتَلِيَ اللَّهُ ما في صُدورِكُم وَلِيُمَحِّصَ ما في قُلوبِكُم ۗ وَاللَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@cdxlviii{إِنَّ الَّذينَ تَوَلَّوا مِنكُم يَومَ التَقَى الجَمعانِ إِنَّمَا استَزَلَّهُمُ الشَّيطانُ بِبَعضِ ما كَسَبوا ۖ وَلَقَد عَفَا اللَّهُ عَنهُم ۗ إِنَّ اللَّهَ غَفورٌ حَليمٌ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@cdxlix{يا أَيُّهَا الَّذينَ آمَنوا لا تَكونوا كَالَّذينَ كَفَروا وَقالوا لِإِخوانِهِم إِذا ضَرَبوا فِي الأَرضِ أَو كانوا غُزًّى لَو كانوا عِندَنا ما ماتوا وَما قُتِلوا لِيَجعَلَ اللَّهُ ذٰلِكَ حَسرَةً في قُلوبِهِم ۗ وَاللَّهُ يُحيي وَيُميتُ ۗ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@cdl{وَلَئِن قُتِلتُم في سَبيلِ اللَّهِ أَو مُتُّم لَمَغفِرَةٌ مِنَ اللَّهِ وَرَحمَةٌ خَيرٌ مِمّا يَجمَعونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@cdli{وَلَئِن مُتُّم أَو قُتِلتُم لَإِلَى اللَّهِ تُحشَرونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@cdlii{فَبِما رَحمَةٍ مِنَ اللَّهِ لِنتَ لَهُم ۖ وَلَو كُنتَ فَظًّا غَليظَ القَلبِ لَانفَضّوا مِن حَولِكَ ۖ فَاعفُ عَنهُم وَاستَغفِر لَهُم وَشاوِرهُم فِي الأَمرِ ۖ فَإِذا عَزَمتَ فَتَوَكَّل عَلَى اللَّهِ ۚ إِنَّ اللَّهَ يُحِبُّ المُتَوَكِّلينَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@cdliii{إِن يَنصُركُمُ اللَّهُ فَلا غالِبَ لَكُم ۖ وَإِن يَخذُلكُم فَمَن ذَا الَّذي يَنصُرُكُم مِن بَعدِهِ ۗ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@cdliv{وَما كانَ لِنَبِيٍّ أَن يَغُلَّ ۚ وَمَن يَغلُل يَأتِ بِما غَلَّ يَومَ القِيامَةِ ۚ ثُمَّ تُوَفّىٰ كُلُّ نَفسٍ ما كَسَبَت وَهُم لا يُظلَمونَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@cdlv{أَفَمَنِ اتَّبَعَ رِضوانَ اللَّهِ كَمَن باءَ بِسَخَطٍ مِنَ اللَّهِ وَمَأواهُ جَهَنَّمُ ۚ وَبِئسَ المَصيرُ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@cdlvi{هُم دَرَجاتٌ عِندَ اللَّهِ ۗ وَاللَّهُ بَصيرٌ بِما يَعمَلونَ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@cdlvii{لَقَد مَنَّ اللَّهُ عَلَى المُؤمِنينَ إِذ بَعَثَ فيهِم رَسولًا مِن أَنفُسِهِم يَتلو عَلَيهِم آياتِهِ وَيُزَكّيهِم وَيُعَلِّمُهُمُ الكِتابَ وَالحِكمَةَ وَإِن كانوا مِن قَبلُ لَفي ضَلالٍ مُبينٍ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@cdlviii{أَوَلَمّا أَصابَتكُم مُصيبَةٌ قَد أَصَبتُم مِثلَيها قُلتُم أَنّىٰ هٰذا ۖ قُل هُوَ مِن عِندِ أَنفُسِكُم ۗ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@cdlix{وَما أَصابَكُم يَومَ التَقَى الجَمعانِ فَبِإِذنِ اللَّهِ وَلِيَعلَمَ المُؤمِنينَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@cdlx{وَلِيَعلَمَ الَّذينَ نافَقوا ۚ وَقيلَ لَهُم تَعالَوا قاتِلوا في سَبيلِ اللَّهِ أَوِ ادفَعوا ۖ قالوا لَو نَعلَمُ قِتالًا لَاتَّبَعناكُم ۗ هُم لِلكُفرِ يَومَئِذٍ أَقرَبُ مِنهُم لِلإيمانِ ۚ يَقولونَ بِأَفواهِهِم ما لَيسَ في قُلوبِهِم ۗ وَاللَّهُ أَعلَمُ بِما يَكتُمونَ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@cdlxi{الَّذينَ قالوا لِإِخوانِهِم وَقَعَدوا لَو أَطاعونا ما قُتِلوا ۗ قُل فَادرَءوا عَن أَنفُسِكُمُ المَوتَ إِن كُنتُم صادِقينَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@cdlxii{وَلا تَحسَبَنَّ الَّذينَ قُتِلوا في سَبيلِ اللَّهِ أَمواتًا ۚ بَل أَحياءٌ عِندَ رَبِّهِم يُرزَقونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@cdlxiii{فَرِحينَ بِما آتاهُمُ اللَّهُ مِن فَضلِهِ وَيَستَبشِرونَ بِالَّذينَ لَم يَلحَقوا بِهِم مِن خَلفِهِم أَلّا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@cdlxiv{۞ يَستَبشِرونَ بِنِعمَةٍ مِنَ اللَّهِ وَفَضلٍ وَأَنَّ اللَّهَ لا يُضيعُ أَجرَ المُؤمِنينَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@cdlxv{الَّذينَ استَجابوا لِلَّهِ وَالرَّسولِ مِن بَعدِ ما أَصابَهُمُ القَرحُ ۚ لِلَّذينَ أَحسَنوا مِنهُم وَاتَّقَوا أَجرٌ عَظيمٌ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@cdlxvi{الَّذينَ قالَ لَهُمُ النّاسُ إِنَّ النّاسَ قَد جَمَعوا لَكُم فَاخشَوهُم فَزادَهُم إيمانًا وَقالوا حَسبُنَا اللَّهُ وَنِعمَ الوَكيلُ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@cdlxvii{فَانقَلَبوا بِنِعمَةٍ مِنَ اللَّهِ وَفَضلٍ لَم يَمسَسهُم سوءٌ وَاتَّبَعوا رِضوانَ اللَّهِ ۗ وَاللَّهُ ذو فَضلٍ عَظيمٍ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@cdlxviii{إِنَّما ذٰلِكُمُ الشَّيطانُ يُخَوِّفُ أَولِياءَهُ فَلا تَخافوهُم وَخافونِ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@cdlxix{وَلا يَحزُنكَ الَّذينَ يُسارِعونَ فِي الكُفرِ ۚ إِنَّهُم لَن يَضُرُّوا اللَّهَ شَيئًا ۗ يُريدُ اللَّهُ أَلّا يَجعَلَ لَهُم حَظًّا فِي الآخِرَةِ ۖ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@cdlxx{إِنَّ الَّذينَ اشتَرَوُا الكُفرَ بِالإيمانِ لَن يَضُرُّوا اللَّهَ شَيئًا وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@cdlxxi{وَلا يَحسَبَنَّ الَّذينَ كَفَروا أَنَّما نُملي لَهُم خَيرٌ لِأَنفُسِهِم ۚ إِنَّما نُملي لَهُم لِيَزدادوا إِثمًا ۚ وَلَهُم عَذابٌ مُهينٌ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@cdlxxii{ما كانَ اللَّهُ لِيَذَرَ المُؤمِنينَ عَلىٰ ما أَنتُم عَلَيهِ حَتّىٰ يَميزَ الخَبيثَ مِنَ الطَّيِّبِ ۗ وَما كانَ اللَّهُ لِيُطلِعَكُم عَلَى الغَيبِ وَلٰكِنَّ اللَّهَ يَجتَبي مِن رُسُلِهِ مَن يَشاءُ ۖ فَآمِنوا بِاللَّهِ وَرُسُلِهِ ۚ وَإِن تُؤمِنوا وَتَتَّقوا فَلَكُم أَجرٌ عَظيمٌ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@cdlxxiii{وَلا يَحسَبَنَّ الَّذينَ يَبخَلونَ بِما آتاهُمُ اللَّهُ مِن فَضلِهِ هُوَ خَيرًا لَهُم ۖ بَل هُوَ شَرٌّ لَهُم ۖ سَيُطَوَّقونَ ما بَخِلوا بِهِ يَومَ القِيامَةِ ۗ وَلِلَّهِ ميراثُ السَّماواتِ وَالأَرضِ ۗ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@cdlxxiv{لَقَد سَمِعَ اللَّهُ قَولَ الَّذينَ قالوا إِنَّ اللَّهَ فَقيرٌ وَنَحنُ أَغنِياءُ ۘ سَنَكتُبُ ما قالوا وَقَتلَهُمُ الأَنبِياءَ بِغَيرِ حَقٍّ وَنَقولُ ذوقوا عَذابَ الحَريقِ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@cdlxxv{ذٰلِكَ بِما قَدَّمَت أَيديكُم وَأَنَّ اللَّهَ لَيسَ بِظَلّامٍ لِلعَبيدِ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@cdlxxvi{الَّذينَ قالوا إِنَّ اللَّهَ عَهِدَ إِلَينا أَلّا نُؤمِنَ لِرَسولٍ حَتّىٰ يَأتِيَنا بِقُربانٍ تَأكُلُهُ النّارُ ۗ قُل قَد جاءَكُم رُسُلٌ مِن قَبلي بِالبَيِّناتِ وَبِالَّذي قُلتُم فَلِمَ قَتَلتُموهُم إِن كُنتُم صادِقينَ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@cdlxxvii{فَإِن كَذَّبوكَ فَقَد كُذِّبَ رُسُلٌ مِن قَبلِكَ جاءوا بِالبَيِّناتِ وَالزُّبُرِ وَالكِتابِ المُنيرِ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@cdlxxviii{كُلُّ نَفسٍ ذائِقَةُ المَوتِ ۗ وَإِنَّما تُوَفَّونَ أُجورَكُم يَومَ القِيامَةِ ۖ فَمَن زُحزِحَ عَنِ النّارِ وَأُدخِلَ الجَنَّةَ فَقَد فازَ ۗ وَمَا الحَياةُ الدُّنيا إِلّا مَتاعُ الغُرورِ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@cdlxxix{۞ لَتُبلَوُنَّ في أَموالِكُم وَأَنفُسِكُم وَلَتَسمَعُنَّ مِنَ الَّذينَ أوتُوا الكِتابَ مِن قَبلِكُم وَمِنَ الَّذينَ أَشرَكوا أَذًى كَثيرًا ۚ وَإِن تَصبِروا وَتَتَّقوا فَإِنَّ ذٰلِكَ مِن عَزمِ الأُمورِ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@cdlxxx{وَإِذ أَخَذَ اللَّهُ ميثاقَ الَّذينَ أوتُوا الكِتابَ لَتُبَيِّنُنَّهُ لِلنّاسِ وَلا تَكتُمونَهُ فَنَبَذوهُ وَراءَ ظُهورِهِم وَاشتَرَوا بِهِ ثَمَنًا قَليلًا ۖ فَبِئسَ ما يَشتَرونَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@cdlxxxi{لا تَحسَبَنَّ الَّذينَ يَفرَحونَ بِما أَتَوا وَيُحِبّونَ أَن يُحمَدوا بِما لَم يَفعَلوا فَلا تَحسَبَنَّهُم بِمَفازَةٍ مِنَ العَذابِ ۖ وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@cdlxxxii{وَلِلَّهِ مُلكُ السَّماواتِ وَالأَرضِ ۗ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@cdlxxxiii{إِنَّ في خَلقِ السَّماواتِ وَالأَرضِ وَاختِلافِ اللَّيلِ وَالنَّهارِ لَآياتٍ لِأُولِي الأَلبابِ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@cdlxxxiv{الَّذينَ يَذكُرونَ اللَّهَ قِيامًا وَقُعودًا وَعَلىٰ جُنوبِهِم وَيَتَفَكَّرونَ في خَلقِ السَّماواتِ وَالأَرضِ رَبَّنا ما خَلَقتَ هٰذا باطِلًا سُبحانَكَ فَقِنا عَذابَ النّارِ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@cdlxxxv{رَبَّنا إِنَّكَ مَن تُدخِلِ النّارَ فَقَد أَخزَيتَهُ ۖ وَما لِلظّالِمينَ مِن أَنصارٍ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@cdlxxxvi{رَبَّنا إِنَّنا سَمِعنا مُنادِيًا يُنادي لِلإيمانِ أَن آمِنوا بِرَبِّكُم فَآمَنّا ۚ رَبَّنا فَاغفِر لَنا ذُنوبَنا وَكَفِّر عَنّا سَيِّئَاتِنا وَتَوَفَّنا مَعَ الأَبرارِ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@cdlxxxvii{رَبَّنا وَآتِنا ما وَعَدتَنا عَلىٰ رُسُلِكَ وَلا تُخزِنا يَومَ القِيامَةِ ۗ إِنَّكَ لا تُخلِفُ الميعادَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@cdlxxxviii{فَاستَجابَ لَهُم رَبُّهُم أَنّي لا أُضيعُ عَمَلَ عامِلٍ مِنكُم مِن ذَكَرٍ أَو أُنثىٰ ۖ بَعضُكُم مِن بَعضٍ ۖ فَالَّذينَ هاجَروا وَأُخرِجوا مِن دِيارِهِم وَأوذوا في سَبيلي وَقاتَلوا وَقُتِلوا لَأُكَفِّرَنَّ عَنهُم سَيِّئَاتِهِم وَلَأُدخِلَنَّهُم جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ ثَوابًا مِن عِندِ اللَّهِ ۗ وَاللَّهُ عِندَهُ حُسنُ الثَّوابِ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@cdlxxxix{لا يَغُرَّنَّكَ تَقَلُّبُ الَّذينَ كَفَروا فِي البِلادِ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@cdxc{مَتاعٌ قَليلٌ ثُمَّ مَأواهُم جَهَنَّمُ ۚ وَبِئسَ المِهادُ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@cdxci{لٰكِنِ الَّذينَ اتَّقَوا رَبَّهُم لَهُم جَنّاتٌ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها نُزُلًا مِن عِندِ اللَّهِ ۗ وَما عِندَ اللَّهِ خَيرٌ لِلأَبرارِ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@cdxcii{وَإِنَّ مِن أَهلِ الكِتابِ لَمَن يُؤمِنُ بِاللَّهِ وَما أُنزِلَ إِلَيكُم وَما أُنزِلَ إِلَيهِم خاشِعينَ لِلَّهِ لا يَشتَرونَ بِآياتِ اللَّهِ ثَمَنًا قَليلًا ۗ أُولٰئِكَ لَهُم أَجرُهُم عِندَ رَبِّهِم ۗ إِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@cdxciii{يا أَيُّهَا الَّذينَ آمَنُوا اصبِروا وَصابِروا وَرابِطوا وَاتَّقُوا اللَّهَ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@cdxciv{\basmalah يا أَيُّهَا النّاسُ اتَّقوا رَبَّكُمُ الَّذي خَلَقَكُم مِن نَفسٍ واحِدَةٍ وَخَلَقَ مِنها زَوجَها وَبَثَّ مِنهُما رِجالًا كَثيرًا وَنِساءً ۚ وَاتَّقُوا اللَّهَ الَّذي تَساءَلونَ بِهِ وَالأَرحامَ ۚ إِنَّ اللَّهَ كانَ عَلَيكُم رَقيبًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@cdxcv{وَآتُوا اليَتامىٰ أَموالَهُم ۖ وَلا تَتَبَدَّلُوا الخَبيثَ بِالطَّيِّبِ ۖ وَلا تَأكُلوا أَموالَهُم إِلىٰ أَموالِكُم ۚ إِنَّهُ كانَ حوبًا كَبيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@cdxcvi{وَإِن خِفتُم أَلّا تُقسِطوا فِي اليَتامىٰ فَانكِحوا ما طابَ لَكُم مِنَ النِّساءِ مَثنىٰ وَثُلاثَ وَرُباعَ ۖ فَإِن خِفتُم أَلّا تَعدِلوا فَواحِدَةً أَو ما مَلَكَت أَيمانُكُم ۚ ذٰلِكَ أَدنىٰ أَلّا تَعولوا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@cdxcvii{وَآتُوا النِّساءَ صَدُقاتِهِنَّ نِحلَةً ۚ فَإِن طِبنَ لَكُم عَن شَيءٍ مِنهُ نَفسًا فَكُلوهُ هَنيئًا مَريئًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@cdxcviii{وَلا تُؤتُوا السُّفَهاءَ أَموالَكُمُ الَّتي جَعَلَ اللَّهُ لَكُم قِيامًا وَارزُقوهُم فيها وَاكسوهُم وَقولوا لَهُم قَولًا مَعروفًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@cdxcix{وَابتَلُوا اليَتامىٰ حَتّىٰ إِذا بَلَغُوا النِّكاحَ فَإِن آنَستُم مِنهُم رُشدًا فَادفَعوا إِلَيهِم أَموالَهُم ۖ وَلا تَأكُلوها إِسرافًا وَبِدارًا أَن يَكبَروا ۚ وَمَن كانَ غَنِيًّا فَليَستَعفِف ۖ وَمَن كانَ فَقيرًا فَليَأكُل بِالمَعروفِ ۚ فَإِذا دَفَعتُم إِلَيهِم أَموالَهُم فَأَشهِدوا عَلَيهِم ۚ وَكَفىٰ بِاللَّهِ حَسيبًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@d{لِلرِّجالِ نَصيبٌ مِمّا تَرَكَ الوالِدانِ وَالأَقرَبونَ وَلِلنِّساءِ نَصيبٌ مِمّا تَرَكَ الوالِدانِ وَالأَقرَبونَ مِمّا قَلَّ مِنهُ أَو كَثُرَ ۚ نَصيبًا مَفروضًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@di{وَإِذا حَضَرَ القِسمَةَ أُولُو القُربىٰ وَاليَتامىٰ وَالمَساكينُ فَارزُقوهُم مِنهُ وَقولوا لَهُم قَولًا مَعروفًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@dii{وَليَخشَ الَّذينَ لَو تَرَكوا مِن خَلفِهِم ذُرِّيَّةً ضِعافًا خافوا عَلَيهِم فَليَتَّقُوا اللَّهَ وَليَقولوا قَولًا سَديدًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@diii{إِنَّ الَّذينَ يَأكُلونَ أَموالَ اليَتامىٰ ظُلمًا إِنَّما يَأكُلونَ في بُطونِهِم نارًا ۖ وَسَيَصلَونَ سَعيرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@div{يوصيكُمُ اللَّهُ في أَولادِكُم ۖ لِلذَّكَرِ مِثلُ حَظِّ الأُنثَيَينِ ۚ فَإِن كُنَّ نِساءً فَوقَ اثنَتَينِ فَلَهُنَّ ثُلُثا ما تَرَكَ ۖ وَإِن كانَت واحِدَةً فَلَهَا النِّصفُ ۚ وَلِأَبَوَيهِ لِكُلِّ واحِدٍ مِنهُمَا السُّدُسُ مِمّا تَرَكَ إِن كانَ لَهُ وَلَدٌ ۚ فَإِن لَم يَكُن لَهُ وَلَدٌ وَوَرِثَهُ أَبَواهُ فَلِأُمِّهِ الثُّلُثُ ۚ فَإِن كانَ لَهُ إِخوَةٌ فَلِأُمِّهِ السُّدُسُ ۚ مِن بَعدِ وَصِيَّةٍ يوصي بِها أَو دَينٍ ۗ آباؤُكُم وَأَبناؤُكُم لا تَدرونَ أَيُّهُم أَقرَبُ لَكُم نَفعًا ۚ فَريضَةً مِنَ اللَّهِ ۗ إِنَّ اللَّهَ كانَ عَليمًا حَكيمًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@dv{۞ وَلَكُم نِصفُ ما تَرَكَ أَزواجُكُم إِن لَم يَكُن لَهُنَّ وَلَدٌ ۚ فَإِن كانَ لَهُنَّ وَلَدٌ فَلَكُمُ الرُّبُعُ مِمّا تَرَكنَ ۚ مِن بَعدِ وَصِيَّةٍ يوصينَ بِها أَو دَينٍ ۚ وَلَهُنَّ الرُّبُعُ مِمّا تَرَكتُم إِن لَم يَكُن لَكُم وَلَدٌ ۚ فَإِن كانَ لَكُم وَلَدٌ فَلَهُنَّ الثُّمُنُ مِمّا تَرَكتُم ۚ مِن بَعدِ وَصِيَّةٍ توصونَ بِها أَو دَينٍ ۗ وَإِن كانَ رَجُلٌ يورَثُ كَلالَةً أَوِ امرَأَةٌ وَلَهُ أَخٌ أَو أُختٌ فَلِكُلِّ واحِدٍ مِنهُمَا السُّدُسُ ۚ فَإِن كانوا أَكثَرَ مِن ذٰلِكَ فَهُم شُرَكاءُ فِي الثُّلُثِ ۚ مِن بَعدِ وَصِيَّةٍ يوصىٰ بِها أَو دَينٍ غَيرَ مُضارٍّ ۚ وَصِيَّةً مِنَ اللَّهِ ۗ وَاللَّهُ عَليمٌ حَليمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@dvi{تِلكَ حُدودُ اللَّهِ ۚ وَمَن يُطِعِ اللَّهَ وَرَسولَهُ يُدخِلهُ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها ۚ وَذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@dvii{وَمَن يَعصِ اللَّهَ وَرَسولَهُ وَيَتَعَدَّ حُدودَهُ يُدخِلهُ نارًا خالِدًا فيها وَلَهُ عَذابٌ مُهينٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@dviii{وَاللّاتي يَأتينَ الفاحِشَةَ مِن نِسائِكُم فَاستَشهِدوا عَلَيهِنَّ أَربَعَةً مِنكُم ۖ فَإِن شَهِدوا فَأَمسِكوهُنَّ فِي البُيوتِ حَتّىٰ يَتَوَفّاهُنَّ المَوتُ أَو يَجعَلَ اللَّهُ لَهُنَّ سَبيلًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@dix{وَاللَّذانِ يَأتِيانِها مِنكُم فَآذوهُما ۖ فَإِن تابا وَأَصلَحا فَأَعرِضوا عَنهُما ۗ إِنَّ اللَّهَ كانَ تَوّابًا رَحيمًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@dx{إِنَّمَا التَّوبَةُ عَلَى اللَّهِ لِلَّذينَ يَعمَلونَ السّوءَ بِجَهالَةٍ ثُمَّ يَتوبونَ مِن قَريبٍ فَأُولٰئِكَ يَتوبُ اللَّهُ عَلَيهِم ۗ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@dxi{وَلَيسَتِ التَّوبَةُ لِلَّذينَ يَعمَلونَ السَّيِّئَاتِ حَتّىٰ إِذا حَضَرَ أَحَدَهُمُ المَوتُ قالَ إِنّي تُبتُ الآنَ وَلَا الَّذينَ يَموتونَ وَهُم كُفّارٌ ۚ أُولٰئِكَ أَعتَدنا لَهُم عَذابًا أَليمًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@dxii{يا أَيُّهَا الَّذينَ آمَنوا لا يَحِلُّ لَكُم أَن تَرِثُوا النِّساءَ كَرهًا ۖ وَلا تَعضُلوهُنَّ لِتَذهَبوا بِبَعضِ ما آتَيتُموهُنَّ إِلّا أَن يَأتينَ بِفاحِشَةٍ مُبَيِّنَةٍ ۚ وَعاشِروهُنَّ بِالمَعروفِ ۚ فَإِن كَرِهتُموهُنَّ فَعَسىٰ أَن تَكرَهوا شَيئًا وَيَجعَلَ اللَّهُ فيهِ خَيرًا كَثيرًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@dxiii{وَإِن أَرَدتُمُ استِبدالَ زَوجٍ مَكانَ زَوجٍ وَآتَيتُم إِحداهُنَّ قِنطارًا فَلا تَأخُذوا مِنهُ شَيئًا ۚ أَتَأخُذونَهُ بُهتانًا وَإِثمًا مُبينًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@dxiv{وَكَيفَ تَأخُذونَهُ وَقَد أَفضىٰ بَعضُكُم إِلىٰ بَعضٍ وَأَخَذنَ مِنكُم ميثاقًا غَليظًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@dxv{وَلا تَنكِحوا ما نَكَحَ آباؤُكُم مِنَ النِّساءِ إِلّا ما قَد سَلَفَ ۚ إِنَّهُ كانَ فاحِشَةً وَمَقتًا وَساءَ سَبيلًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@dxvi{حُرِّمَت عَلَيكُم أُمَّهاتُكُم وَبَناتُكُم وَأَخَواتُكُم وَعَمّاتُكُم وَخالاتُكُم وَبَناتُ الأَخِ وَبَناتُ الأُختِ وَأُمَّهاتُكُمُ اللّاتي أَرضَعنَكُم وَأَخَواتُكُم مِنَ الرَّضاعَةِ وَأُمَّهاتُ نِسائِكُم وَرَبائِبُكُمُ اللّاتي في حُجورِكُم مِن نِسائِكُمُ اللّاتي دَخَلتُم بِهِنَّ فَإِن لَم تَكونوا دَخَلتُم بِهِنَّ فَلا جُناحَ عَلَيكُم وَحَلائِلُ أَبنائِكُمُ الَّذينَ مِن أَصلابِكُم وَأَن تَجمَعوا بَينَ الأُختَينِ إِلّا ما قَد سَلَفَ ۗ إِنَّ اللَّهَ كانَ غَفورًا رَحيمًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@dxvii{۞ وَالمُحصَناتُ مِنَ النِّساءِ إِلّا ما مَلَكَت أَيمانُكُم ۖ كِتابَ اللَّهِ عَلَيكُم ۚ وَأُحِلَّ لَكُم ما وَراءَ ذٰلِكُم أَن تَبتَغوا بِأَموالِكُم مُحصِنينَ غَيرَ مُسافِحينَ ۚ فَمَا استَمتَعتُم بِهِ مِنهُنَّ فَآتوهُنَّ أُجورَهُنَّ فَريضَةً ۚ وَلا جُناحَ عَلَيكُم فيما تَراضَيتُم بِهِ مِن بَعدِ الفَريضَةِ ۚ إِنَّ اللَّهَ كانَ عَليمًا حَكيمًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@dxviii{وَمَن لَم يَستَطِع مِنكُم طَولًا أَن يَنكِحَ المُحصَناتِ المُؤمِناتِ فَمِن ما مَلَكَت أَيمانُكُم مِن فَتَياتِكُمُ المُؤمِناتِ ۚ وَاللَّهُ أَعلَمُ بِإيمانِكُم ۚ بَعضُكُم مِن بَعضٍ ۚ فَانكِحوهُنَّ بِإِذنِ أَهلِهِنَّ وَآتوهُنَّ أُجورَهُنَّ بِالمَعروفِ مُحصَناتٍ غَيرَ مُسافِحاتٍ وَلا مُتَّخِذاتِ أَخدانٍ ۚ فَإِذا أُحصِنَّ فَإِن أَتَينَ بِفاحِشَةٍ فَعَلَيهِنَّ نِصفُ ما عَلَى المُحصَناتِ مِنَ العَذابِ ۚ ذٰلِكَ لِمَن خَشِيَ العَنَتَ مِنكُم ۚ وَأَن تَصبِروا خَيرٌ لَكُم ۗ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@dxix{يُريدُ اللَّهُ لِيُبَيِّنَ لَكُم وَيَهدِيَكُم سُنَنَ الَّذينَ مِن قَبلِكُم وَيَتوبَ عَلَيكُم ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@dxx{وَاللَّهُ يُريدُ أَن يَتوبَ عَلَيكُم وَيُريدُ الَّذينَ يَتَّبِعونَ الشَّهَواتِ أَن تَميلوا مَيلًا عَظيمًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@dxxi{يُريدُ اللَّهُ أَن يُخَفِّفَ عَنكُم ۚ وَخُلِقَ الإِنسانُ ضَعيفًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@dxxii{يا أَيُّهَا الَّذينَ آمَنوا لا تَأكُلوا أَموالَكُم بَينَكُم بِالباطِلِ إِلّا أَن تَكونَ تِجارَةً عَن تَراضٍ مِنكُم ۚ وَلا تَقتُلوا أَنفُسَكُم ۚ إِنَّ اللَّهَ كانَ بِكُم رَحيمًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@dxxiii{وَمَن يَفعَل ذٰلِكَ عُدوانًا وَظُلمًا فَسَوفَ نُصليهِ نارًا ۚ وَكانَ ذٰلِكَ عَلَى اللَّهِ يَسيرًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@dxxiv{إِن تَجتَنِبوا كَبائِرَ ما تُنهَونَ عَنهُ نُكَفِّر عَنكُم سَيِّئَاتِكُم وَنُدخِلكُم مُدخَلًا كَريمًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@dxxv{وَلا تَتَمَنَّوا ما فَضَّلَ اللَّهُ بِهِ بَعضَكُم عَلىٰ بَعضٍ ۚ لِلرِّجالِ نَصيبٌ مِمَّا اكتَسَبوا ۖ وَلِلنِّساءِ نَصيبٌ مِمَّا اكتَسَبنَ ۚ وَاسأَلُوا اللَّهَ مِن فَضلِهِ ۗ إِنَّ اللَّهَ كانَ بِكُلِّ شَيءٍ عَليمًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@dxxvi{وَلِكُلٍّ جَعَلنا مَوالِيَ مِمّا تَرَكَ الوالِدانِ وَالأَقرَبونَ ۚ وَالَّذينَ عَقَدَت أَيمانُكُم فَآتوهُم نَصيبَهُم ۚ إِنَّ اللَّهَ كانَ عَلىٰ كُلِّ شَيءٍ شَهيدًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@dxxvii{الرِّجالُ قَوّامونَ عَلَى النِّساءِ بِما فَضَّلَ اللَّهُ بَعضَهُم عَلىٰ بَعضٍ وَبِما أَنفَقوا مِن أَموالِهِم ۚ فَالصّالِحاتُ قانِتاتٌ حافِظاتٌ لِلغَيبِ بِما حَفِظَ اللَّهُ ۚ وَاللّاتي تَخافونَ نُشوزَهُنَّ فَعِظوهُنَّ وَاهجُروهُنَّ فِي المَضاجِعِ وَاضرِبوهُنَّ ۖ فَإِن أَطَعنَكُم فَلا تَبغوا عَلَيهِنَّ سَبيلًا ۗ إِنَّ اللَّهَ كانَ عَلِيًّا كَبيرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@dxxviii{وَإِن خِفتُم شِقاقَ بَينِهِما فَابعَثوا حَكَمًا مِن أَهلِهِ وَحَكَمًا مِن أَهلِها إِن يُريدا إِصلاحًا يُوَفِّقِ اللَّهُ بَينَهُما ۗ إِنَّ اللَّهَ كانَ عَليمًا خَبيرًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@dxxix{۞ وَاعبُدُوا اللَّهَ وَلا تُشرِكوا بِهِ شَيئًا ۖ وَبِالوالِدَينِ إِحسانًا وَبِذِي القُربىٰ وَاليَتامىٰ وَالمَساكينِ وَالجارِ ذِي القُربىٰ وَالجارِ الجُنُبِ وَالصّاحِبِ بِالجَنبِ وَابنِ السَّبيلِ وَما مَلَكَت أَيمانُكُم ۗ إِنَّ اللَّهَ لا يُحِبُّ مَن كانَ مُختالًا فَخورًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@dxxx{الَّذينَ يَبخَلونَ وَيَأمُرونَ النّاسَ بِالبُخلِ وَيَكتُمونَ ما آتاهُمُ اللَّهُ مِن فَضلِهِ ۗ وَأَعتَدنا لِلكافِرينَ عَذابًا مُهينًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@dxxxi{وَالَّذينَ يُنفِقونَ أَموالَهُم رِئَاءَ النّاسِ وَلا يُؤمِنونَ بِاللَّهِ وَلا بِاليَومِ الآخِرِ ۗ وَمَن يَكُنِ الشَّيطانُ لَهُ قَرينًا فَساءَ قَرينًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@dxxxii{وَماذا عَلَيهِم لَو آمَنوا بِاللَّهِ وَاليَومِ الآخِرِ وَأَنفَقوا مِمّا رَزَقَهُمُ اللَّهُ ۚ وَكانَ اللَّهُ بِهِم عَليمًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@dxxxiii{إِنَّ اللَّهَ لا يَظلِمُ مِثقالَ ذَرَّةٍ ۖ وَإِن تَكُ حَسَنَةً يُضاعِفها وَيُؤتِ مِن لَدُنهُ أَجرًا عَظيمًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@dxxxiv{فَكَيفَ إِذا جِئنا مِن كُلِّ أُمَّةٍ بِشَهيدٍ وَجِئنا بِكَ عَلىٰ هٰؤُلاءِ شَهيدًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@dxxxv{يَومَئِذٍ يَوَدُّ الَّذينَ كَفَروا وَعَصَوُا الرَّسولَ لَو تُسَوّىٰ بِهِمُ الأَرضُ وَلا يَكتُمونَ اللَّهَ حَديثًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@dxxxvi{يا أَيُّهَا الَّذينَ آمَنوا لا تَقرَبُوا الصَّلاةَ وَأَنتُم سُكارىٰ حَتّىٰ تَعلَموا ما تَقولونَ وَلا جُنُبًا إِلّا عابِري سَبيلٍ حَتّىٰ تَغتَسِلوا ۚ وَإِن كُنتُم مَرضىٰ أَو عَلىٰ سَفَرٍ أَو جاءَ أَحَدٌ مِنكُم مِنَ الغائِطِ أَو لامَستُمُ النِّساءَ فَلَم تَجِدوا ماءً فَتَيَمَّموا صَعيدًا طَيِّبًا فَامسَحوا بِوُجوهِكُم وَأَيديكُم ۗ إِنَّ اللَّهَ كانَ عَفُوًّا غَفورًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@dxxxvii{أَلَم تَرَ إِلَى الَّذينَ أوتوا نَصيبًا مِنَ الكِتابِ يَشتَرونَ الضَّلالَةَ وَيُريدونَ أَن تَضِلُّوا السَّبيلَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@dxxxviii{وَاللَّهُ أَعلَمُ بِأَعدائِكُم ۚ وَكَفىٰ بِاللَّهِ وَلِيًّا وَكَفىٰ بِاللَّهِ نَصيرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@dxxxix{مِنَ الَّذينَ هادوا يُحَرِّفونَ الكَلِمَ عَن مَواضِعِهِ وَيَقولونَ سَمِعنا وَعَصَينا وَاسمَع غَيرَ مُسمَعٍ وَراعِنا لَيًّا بِأَلسِنَتِهِم وَطَعنًا فِي الدّينِ ۚ وَلَو أَنَّهُم قالوا سَمِعنا وَأَطَعنا وَاسمَع وَانظُرنا لَكانَ خَيرًا لَهُم وَأَقوَمَ وَلٰكِن لَعَنَهُمُ اللَّهُ بِكُفرِهِم فَلا يُؤمِنونَ إِلّا قَليلًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@dxl{يا أَيُّهَا الَّذينَ أوتُوا الكِتابَ آمِنوا بِما نَزَّلنا مُصَدِّقًا لِما مَعَكُم مِن قَبلِ أَن نَطمِسَ وُجوهًا فَنَرُدَّها عَلىٰ أَدبارِها أَو نَلعَنَهُم كَما لَعَنّا أَصحابَ السَّبتِ ۚ وَكانَ أَمرُ اللَّهِ مَفعولًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@dxli{إِنَّ اللَّهَ لا يَغفِرُ أَن يُشرَكَ بِهِ وَيَغفِرُ ما دونَ ذٰلِكَ لِمَن يَشاءُ ۚ وَمَن يُشرِك بِاللَّهِ فَقَدِ افتَرىٰ إِثمًا عَظيمًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@dxlii{أَلَم تَرَ إِلَى الَّذينَ يُزَكّونَ أَنفُسَهُم ۚ بَلِ اللَّهُ يُزَكّي مَن يَشاءُ وَلا يُظلَمونَ فَتيلًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@dxliii{انظُر كَيفَ يَفتَرونَ عَلَى اللَّهِ الكَذِبَ ۖ وَكَفىٰ بِهِ إِثمًا مُبينًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@dxliv{أَلَم تَرَ إِلَى الَّذينَ أوتوا نَصيبًا مِنَ الكِتابِ يُؤمِنونَ بِالجِبتِ وَالطّاغوتِ وَيَقولونَ لِلَّذينَ كَفَروا هٰؤُلاءِ أَهدىٰ مِنَ الَّذينَ آمَنوا سَبيلًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@dxlv{أُولٰئِكَ الَّذينَ لَعَنَهُمُ اللَّهُ ۖ وَمَن يَلعَنِ اللَّهُ فَلَن تَجِدَ لَهُ نَصيرًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@dxlvi{أَم لَهُم نَصيبٌ مِنَ المُلكِ فَإِذًا لا يُؤتونَ النّاسَ نَقيرًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@dxlvii{أَم يَحسُدونَ النّاسَ عَلىٰ ما آتاهُمُ اللَّهُ مِن فَضلِهِ ۖ فَقَد آتَينا آلَ إِبراهيمَ الكِتابَ وَالحِكمَةَ وَآتَيناهُم مُلكًا عَظيمًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@dxlviii{فَمِنهُم مَن آمَنَ بِهِ وَمِنهُم مَن صَدَّ عَنهُ ۚ وَكَفىٰ بِجَهَنَّمَ سَعيرًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@dxlix{إِنَّ الَّذينَ كَفَروا بِآياتِنا سَوفَ نُصليهِم نارًا كُلَّما نَضِجَت جُلودُهُم بَدَّلناهُم جُلودًا غَيرَها لِيَذوقُوا العَذابَ ۗ إِنَّ اللَّهَ كانَ عَزيزًا حَكيمًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@dl{وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ سَنُدخِلُهُم جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها أَبَدًا ۖ لَهُم فيها أَزواجٌ مُطَهَّرَةٌ ۖ وَنُدخِلُهُم ظِلًّا ظَليلًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@dli{۞ إِنَّ اللَّهَ يَأمُرُكُم أَن تُؤَدُّوا الأَماناتِ إِلىٰ أَهلِها وَإِذا حَكَمتُم بَينَ النّاسِ أَن تَحكُموا بِالعَدلِ ۚ إِنَّ اللَّهَ نِعِمّا يَعِظُكُم بِهِ ۗ إِنَّ اللَّهَ كانَ سَميعًا بَصيرًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@dlii{يا أَيُّهَا الَّذينَ آمَنوا أَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ وَأُولِي الأَمرِ مِنكُم ۖ فَإِن تَنازَعتُم في شَيءٍ فَرُدّوهُ إِلَى اللَّهِ وَالرَّسولِ إِن كُنتُم تُؤمِنونَ بِاللَّهِ وَاليَومِ الآخِرِ ۚ ذٰلِكَ خَيرٌ وَأَحسَنُ تَأويلًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@dliii{أَلَم تَرَ إِلَى الَّذينَ يَزعُمونَ أَنَّهُم آمَنوا بِما أُنزِلَ إِلَيكَ وَما أُنزِلَ مِن قَبلِكَ يُريدونَ أَن يَتَحاكَموا إِلَى الطّاغوتِ وَقَد أُمِروا أَن يَكفُروا بِهِ وَيُريدُ الشَّيطانُ أَن يُضِلَّهُم ضَلالًا بَعيدًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@dliv{وَإِذا قيلَ لَهُم تَعالَوا إِلىٰ ما أَنزَلَ اللَّهُ وَإِلَى الرَّسولِ رَأَيتَ المُنافِقينَ يَصُدّونَ عَنكَ صُدودًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@dlv{فَكَيفَ إِذا أَصابَتهُم مُصيبَةٌ بِما قَدَّمَت أَيديهِم ثُمَّ جاءوكَ يَحلِفونَ بِاللَّهِ إِن أَرَدنا إِلّا إِحسانًا وَتَوفيقًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@dlvi{أُولٰئِكَ الَّذينَ يَعلَمُ اللَّهُ ما في قُلوبِهِم فَأَعرِض عَنهُم وَعِظهُم وَقُل لَهُم في أَنفُسِهِم قَولًا بَليغًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@dlvii{وَما أَرسَلنا مِن رَسولٍ إِلّا لِيُطاعَ بِإِذنِ اللَّهِ ۚ وَلَو أَنَّهُم إِذ ظَلَموا أَنفُسَهُم جاءوكَ فَاستَغفَرُوا اللَّهَ وَاستَغفَرَ لَهُمُ الرَّسولُ لَوَجَدُوا اللَّهَ تَوّابًا رَحيمًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@dlviii{فَلا وَرَبِّكَ لا يُؤمِنونَ حَتّىٰ يُحَكِّموكَ فيما شَجَرَ بَينَهُم ثُمَّ لا يَجِدوا في أَنفُسِهِم حَرَجًا مِمّا قَضَيتَ وَيُسَلِّموا تَسليمًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@dlix{وَلَو أَنّا كَتَبنا عَلَيهِم أَنِ اقتُلوا أَنفُسَكُم أَوِ اخرُجوا مِن دِيارِكُم ما فَعَلوهُ إِلّا قَليلٌ مِنهُم ۖ وَلَو أَنَّهُم فَعَلوا ما يوعَظونَ بِهِ لَكانَ خَيرًا لَهُم وَأَشَدَّ تَثبيتًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@dlx{وَإِذًا لَآتَيناهُم مِن لَدُنّا أَجرًا عَظيمًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@dlxi{وَلَهَدَيناهُم صِراطًا مُستَقيمًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@dlxii{وَمَن يُطِعِ اللَّهَ وَالرَّسولَ فَأُولٰئِكَ مَعَ الَّذينَ أَنعَمَ اللَّهُ عَلَيهِم مِنَ النَّبِيّينَ وَالصِّدّيقينَ وَالشُّهَداءِ وَالصّالِحينَ ۚ وَحَسُنَ أُولٰئِكَ رَفيقًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@dlxiii{ذٰلِكَ الفَضلُ مِنَ اللَّهِ ۚ وَكَفىٰ بِاللَّهِ عَليمًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@dlxiv{يا أَيُّهَا الَّذينَ آمَنوا خُذوا حِذرَكُم فَانفِروا ثُباتٍ أَوِ انفِروا جَميعًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@dlxv{وَإِنَّ مِنكُم لَمَن لَيُبَطِّئَنَّ فَإِن أَصابَتكُم مُصيبَةٌ قالَ قَد أَنعَمَ اللَّهُ عَلَيَّ إِذ لَم أَكُن مَعَهُم شَهيدًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@dlxvi{وَلَئِن أَصابَكُم فَضلٌ مِنَ اللَّهِ لَيَقولَنَّ كَأَن لَم تَكُن بَينَكُم وَبَينَهُ مَوَدَّةٌ يا لَيتَني كُنتُ مَعَهُم فَأَفوزَ فَوزًا عَظيمًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@dlxvii{۞ فَليُقاتِل في سَبيلِ اللَّهِ الَّذينَ يَشرونَ الحَياةَ الدُّنيا بِالآخِرَةِ ۚ وَمَن يُقاتِل في سَبيلِ اللَّهِ فَيُقتَل أَو يَغلِب فَسَوفَ نُؤتيهِ أَجرًا عَظيمًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@dlxviii{وَما لَكُم لا تُقاتِلونَ في سَبيلِ اللَّهِ وَالمُستَضعَفينَ مِنَ الرِّجالِ وَالنِّساءِ وَالوِلدانِ الَّذينَ يَقولونَ رَبَّنا أَخرِجنا مِن هٰذِهِ القَريَةِ الظّالِمِ أَهلُها وَاجعَل لَنا مِن لَدُنكَ وَلِيًّا وَاجعَل لَنا مِن لَدُنكَ نَصيرًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@dlxix{الَّذينَ آمَنوا يُقاتِلونَ في سَبيلِ اللَّهِ ۖ وَالَّذينَ كَفَروا يُقاتِلونَ في سَبيلِ الطّاغوتِ فَقاتِلوا أَولِياءَ الشَّيطانِ ۖ إِنَّ كَيدَ الشَّيطانِ كانَ ضَعيفًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@dlxx{أَلَم تَرَ إِلَى الَّذينَ قيلَ لَهُم كُفّوا أَيدِيَكُم وَأَقيمُوا الصَّلاةَ وَآتُوا الزَّكاةَ فَلَمّا كُتِبَ عَلَيهِمُ القِتالُ إِذا فَريقٌ مِنهُم يَخشَونَ النّاسَ كَخَشيَةِ اللَّهِ أَو أَشَدَّ خَشيَةً ۚ وَقالوا رَبَّنا لِمَ كَتَبتَ عَلَينَا القِتالَ لَولا أَخَّرتَنا إِلىٰ أَجَلٍ قَريبٍ ۗ قُل مَتاعُ الدُّنيا قَليلٌ وَالآخِرَةُ خَيرٌ لِمَنِ اتَّقىٰ وَلا تُظلَمونَ فَتيلًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@dlxxi{أَينَما تَكونوا يُدرِككُمُ المَوتُ وَلَو كُنتُم في بُروجٍ مُشَيَّدَةٍ ۗ وَإِن تُصِبهُم حَسَنَةٌ يَقولوا هٰذِهِ مِن عِندِ اللَّهِ ۖ وَإِن تُصِبهُم سَيِّئَةٌ يَقولوا هٰذِهِ مِن عِندِكَ ۚ قُل كُلٌّ مِن عِندِ اللَّهِ ۖ فَمالِ هٰؤُلاءِ القَومِ لا يَكادونَ يَفقَهونَ حَديثًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@dlxxii{ما أَصابَكَ مِن حَسَنَةٍ فَمِنَ اللَّهِ ۖ وَما أَصابَكَ مِن سَيِّئَةٍ فَمِن نَفسِكَ ۚ وَأَرسَلناكَ لِلنّاسِ رَسولًا ۚ وَكَفىٰ بِاللَّهِ شَهيدًا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@dlxxiii{مَن يُطِعِ الرَّسولَ فَقَد أَطاعَ اللَّهَ ۖ وَمَن تَوَلّىٰ فَما أَرسَلناكَ عَلَيهِم حَفيظًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@dlxxiv{وَيَقولونَ طاعَةٌ فَإِذا بَرَزوا مِن عِندِكَ بَيَّتَ طائِفَةٌ مِنهُم غَيرَ الَّذي تَقولُ ۖ وَاللَّهُ يَكتُبُ ما يُبَيِّتونَ ۖ فَأَعرِض عَنهُم وَتَوَكَّل عَلَى اللَّهِ ۚ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@dlxxv{أَفَلا يَتَدَبَّرونَ القُرآنَ ۚ وَلَو كانَ مِن عِندِ غَيرِ اللَّهِ لَوَجَدوا فيهِ اختِلافًا كَثيرًا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@dlxxvi{وَإِذا جاءَهُم أَمرٌ مِنَ الأَمنِ أَوِ الخَوفِ أَذاعوا بِهِ ۖ وَلَو رَدّوهُ إِلَى الرَّسولِ وَإِلىٰ أُولِي الأَمرِ مِنهُم لَعَلِمَهُ الَّذينَ يَستَنبِطونَهُ مِنهُم ۗ وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ لَاتَّبَعتُمُ الشَّيطانَ إِلّا قَليلًا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@dlxxvii{فَقاتِل في سَبيلِ اللَّهِ لا تُكَلَّفُ إِلّا نَفسَكَ ۚ وَحَرِّضِ المُؤمِنينَ ۖ عَسَى اللَّهُ أَن يَكُفَّ بَأسَ الَّذينَ كَفَروا ۚ وَاللَّهُ أَشَدُّ بَأسًا وَأَشَدُّ تَنكيلًا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@dlxxviii{مَن يَشفَع شَفاعَةً حَسَنَةً يَكُن لَهُ نَصيبٌ مِنها ۖ وَمَن يَشفَع شَفاعَةً سَيِّئَةً يَكُن لَهُ كِفلٌ مِنها ۗ وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ مُقيتًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@dlxxix{وَإِذا حُيّيتُم بِتَحِيَّةٍ فَحَيّوا بِأَحسَنَ مِنها أَو رُدّوها ۗ إِنَّ اللَّهَ كانَ عَلىٰ كُلِّ شَيءٍ حَسيبًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@dlxxx{اللَّهُ لا إِلٰهَ إِلّا هُوَ ۚ لَيَجمَعَنَّكُم إِلىٰ يَومِ القِيامَةِ لا رَيبَ فيهِ ۗ وَمَن أَصدَقُ مِنَ اللَّهِ حَديثًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@dlxxxi{۞ فَما لَكُم فِي المُنافِقينَ فِئَتَينِ وَاللَّهُ أَركَسَهُم بِما كَسَبوا ۚ أَتُريدونَ أَن تَهدوا مَن أَضَلَّ اللَّهُ ۖ وَمَن يُضلِلِ اللَّهُ فَلَن تَجِدَ لَهُ سَبيلًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@dlxxxii{وَدّوا لَو تَكفُرونَ كَما كَفَروا فَتَكونونَ سَواءً ۖ فَلا تَتَّخِذوا مِنهُم أَولِياءَ حَتّىٰ يُهاجِروا في سَبيلِ اللَّهِ ۚ فَإِن تَوَلَّوا فَخُذوهُم وَاقتُلوهُم حَيثُ وَجَدتُموهُم ۖ وَلا تَتَّخِذوا مِنهُم وَلِيًّا وَلا نَصيرًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@dlxxxiii{إِلَّا الَّذينَ يَصِلونَ إِلىٰ قَومٍ بَينَكُم وَبَينَهُم ميثاقٌ أَو جاءوكُم حَصِرَت صُدورُهُم أَن يُقاتِلوكُم أَو يُقاتِلوا قَومَهُم ۚ وَلَو شاءَ اللَّهُ لَسَلَّطَهُم عَلَيكُم فَلَقاتَلوكُم ۚ فَإِنِ اعتَزَلوكُم فَلَم يُقاتِلوكُم وَأَلقَوا إِلَيكُمُ السَّلَمَ فَما جَعَلَ اللَّهُ لَكُم عَلَيهِم سَبيلًا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@dlxxxiv{سَتَجِدونَ آخَرينَ يُريدونَ أَن يَأمَنوكُم وَيَأمَنوا قَومَهُم كُلَّ ما رُدّوا إِلَى الفِتنَةِ أُركِسوا فيها ۚ فَإِن لَم يَعتَزِلوكُم وَيُلقوا إِلَيكُمُ السَّلَمَ وَيَكُفّوا أَيدِيَهُم فَخُذوهُم وَاقتُلوهُم حَيثُ ثَقِفتُموهُم ۚ وَأُولٰئِكُم جَعَلنا لَكُم عَلَيهِم سُلطانًا مُبينًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@dlxxxv{وَما كانَ لِمُؤمِنٍ أَن يَقتُلَ مُؤمِنًا إِلّا خَطَأً ۚ وَمَن قَتَلَ مُؤمِنًا خَطَأً فَتَحريرُ رَقَبَةٍ مُؤمِنَةٍ وَدِيَةٌ مُسَلَّمَةٌ إِلىٰ أَهلِهِ إِلّا أَن يَصَّدَّقوا ۚ فَإِن كانَ مِن قَومٍ عَدُوٍّ لَكُم وَهُوَ مُؤمِنٌ فَتَحريرُ رَقَبَةٍ مُؤمِنَةٍ ۖ وَإِن كانَ مِن قَومٍ بَينَكُم وَبَينَهُم ميثاقٌ فَدِيَةٌ مُسَلَّمَةٌ إِلىٰ أَهلِهِ وَتَحريرُ رَقَبَةٍ مُؤمِنَةٍ ۖ فَمَن لَم يَجِد فَصِيامُ شَهرَينِ مُتَتابِعَينِ تَوبَةً مِنَ اللَّهِ ۗ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@dlxxxvi{وَمَن يَقتُل مُؤمِنًا مُتَعَمِّدًا فَجَزاؤُهُ جَهَنَّمُ خالِدًا فيها وَغَضِبَ اللَّهُ عَلَيهِ وَلَعَنَهُ وَأَعَدَّ لَهُ عَذابًا عَظيمًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@dlxxxvii{يا أَيُّهَا الَّذينَ آمَنوا إِذا ضَرَبتُم في سَبيلِ اللَّهِ فَتَبَيَّنوا وَلا تَقولوا لِمَن أَلقىٰ إِلَيكُمُ السَّلامَ لَستَ مُؤمِنًا تَبتَغونَ عَرَضَ الحَياةِ الدُّنيا فَعِندَ اللَّهِ مَغانِمُ كَثيرَةٌ ۚ كَذٰلِكَ كُنتُم مِن قَبلُ فَمَنَّ اللَّهُ عَلَيكُم فَتَبَيَّنوا ۚ إِنَّ اللَّهَ كانَ بِما تَعمَلونَ خَبيرًا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@dlxxxviii{لا يَستَوِي القاعِدونَ مِنَ المُؤمِنينَ غَيرُ أُولِي الضَّرَرِ وَالمُجاهِدونَ في سَبيلِ اللَّهِ بِأَموالِهِم وَأَنفُسِهِم ۚ فَضَّلَ اللَّهُ المُجاهِدينَ بِأَموالِهِم وَأَنفُسِهِم عَلَى القاعِدينَ دَرَجَةً ۚ وَكُلًّا وَعَدَ اللَّهُ الحُسنىٰ ۚ وَفَضَّلَ اللَّهُ المُجاهِدينَ عَلَى القاعِدينَ أَجرًا عَظيمًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@dlxxxix{دَرَجاتٍ مِنهُ وَمَغفِرَةً وَرَحمَةً ۚ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@dxc{إِنَّ الَّذينَ تَوَفّاهُمُ المَلائِكَةُ ظالِمي أَنفُسِهِم قالوا فيمَ كُنتُم ۖ قالوا كُنّا مُستَضعَفينَ فِي الأَرضِ ۚ قالوا أَلَم تَكُن أَرضُ اللَّهِ واسِعَةً فَتُهاجِروا فيها ۚ فَأُولٰئِكَ مَأواهُم جَهَنَّمُ ۖ وَساءَت مَصيرًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@dxci{إِلَّا المُستَضعَفينَ مِنَ الرِّجالِ وَالنِّساءِ وَالوِلدانِ لا يَستَطيعونَ حيلَةً وَلا يَهتَدونَ سَبيلًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@dxcii{فَأُولٰئِكَ عَسَى اللَّهُ أَن يَعفُوَ عَنهُم ۚ وَكانَ اللَّهُ عَفُوًّا غَفورًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@dxciii{۞ وَمَن يُهاجِر في سَبيلِ اللَّهِ يَجِد فِي الأَرضِ مُراغَمًا كَثيرًا وَسَعَةً ۚ وَمَن يَخرُج مِن بَيتِهِ مُهاجِرًا إِلَى اللَّهِ وَرَسولِهِ ثُمَّ يُدرِكهُ المَوتُ فَقَد وَقَعَ أَجرُهُ عَلَى اللَّهِ ۗ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@dxciv{وَإِذا ضَرَبتُم فِي الأَرضِ فَلَيسَ عَلَيكُم جُناحٌ أَن تَقصُروا مِنَ الصَّلاةِ إِن خِفتُم أَن يَفتِنَكُمُ الَّذينَ كَفَروا ۚ إِنَّ الكافِرينَ كانوا لَكُم عَدُوًّا مُبينًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@dxcv{وَإِذا كُنتَ فيهِم فَأَقَمتَ لَهُمُ الصَّلاةَ فَلتَقُم طائِفَةٌ مِنهُم مَعَكَ وَليَأخُذوا أَسلِحَتَهُم فَإِذا سَجَدوا فَليَكونوا مِن وَرائِكُم وَلتَأتِ طائِفَةٌ أُخرىٰ لَم يُصَلّوا فَليُصَلّوا مَعَكَ وَليَأخُذوا حِذرَهُم وَأَسلِحَتَهُم ۗ وَدَّ الَّذينَ كَفَروا لَو تَغفُلونَ عَن أَسلِحَتِكُم وَأَمتِعَتِكُم فَيَميلونَ عَلَيكُم مَيلَةً واحِدَةً ۚ وَلا جُناحَ عَلَيكُم إِن كانَ بِكُم أَذًى مِن مَطَرٍ أَو كُنتُم مَرضىٰ أَن تَضَعوا أَسلِحَتَكُم ۖ وَخُذوا حِذرَكُم ۗ إِنَّ اللَّهَ أَعَدَّ لِلكافِرينَ عَذابًا مُهينًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@dxcvi{فَإِذا قَضَيتُمُ الصَّلاةَ فَاذكُرُوا اللَّهَ قِيامًا وَقُعودًا وَعَلىٰ جُنوبِكُم ۚ فَإِذَا اطمَأنَنتُم فَأَقيمُوا الصَّلاةَ ۚ إِنَّ الصَّلاةَ كانَت عَلَى المُؤمِنينَ كِتابًا مَوقوتًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@dxcvii{وَلا تَهِنوا فِي ابتِغاءِ القَومِ ۖ إِن تَكونوا تَألَمونَ فَإِنَّهُم يَألَمونَ كَما تَألَمونَ ۖ وَتَرجونَ مِنَ اللَّهِ ما لا يَرجونَ ۗ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@dxcviii{إِنّا أَنزَلنا إِلَيكَ الكِتابَ بِالحَقِّ لِتَحكُمَ بَينَ النّاسِ بِما أَراكَ اللَّهُ ۚ وَلا تَكُن لِلخائِنينَ خَصيمًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@dxcix{وَاستَغفِرِ اللَّهَ ۖ إِنَّ اللَّهَ كانَ غَفورًا رَحيمًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@dc{وَلا تُجادِل عَنِ الَّذينَ يَختانونَ أَنفُسَهُم ۚ إِنَّ اللَّهَ لا يُحِبُّ مَن كانَ خَوّانًا أَثيمًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@dci{يَستَخفونَ مِنَ النّاسِ وَلا يَستَخفونَ مِنَ اللَّهِ وَهُوَ مَعَهُم إِذ يُبَيِّتونَ ما لا يَرضىٰ مِنَ القَولِ ۚ وَكانَ اللَّهُ بِما يَعمَلونَ مُحيطًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@dcii{ها أَنتُم هٰؤُلاءِ جادَلتُم عَنهُم فِي الحَياةِ الدُّنيا فَمَن يُجادِلُ اللَّهَ عَنهُم يَومَ القِيامَةِ أَم مَن يَكونُ عَلَيهِم وَكيلًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@dciii{وَمَن يَعمَل سوءًا أَو يَظلِم نَفسَهُ ثُمَّ يَستَغفِرِ اللَّهَ يَجِدِ اللَّهَ غَفورًا رَحيمًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@dciv{وَمَن يَكسِب إِثمًا فَإِنَّما يَكسِبُهُ عَلىٰ نَفسِهِ ۚ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@dcv{وَمَن يَكسِب خَطيئَةً أَو إِثمًا ثُمَّ يَرمِ بِهِ بَريئًا فَقَدِ احتَمَلَ بُهتانًا وَإِثمًا مُبينًا\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@dcvi{وَلَولا فَضلُ اللَّهِ عَلَيكَ وَرَحمَتُهُ لَهَمَّت طائِفَةٌ مِنهُم أَن يُضِلّوكَ وَما يُضِلّونَ إِلّا أَنفُسَهُم ۖ وَما يَضُرّونَكَ مِن شَيءٍ ۚ وَأَنزَلَ اللَّهُ عَلَيكَ الكِتابَ وَالحِكمَةَ وَعَلَّمَكَ ما لَم تَكُن تَعلَمُ ۚ وَكانَ فَضلُ اللَّهِ عَلَيكَ عَظيمًا\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@dcvii{۞ لا خَيرَ في كَثيرٍ مِن نَجواهُم إِلّا مَن أَمَرَ بِصَدَقَةٍ أَو مَعروفٍ أَو إِصلاحٍ بَينَ النّاسِ ۚ وَمَن يَفعَل ذٰلِكَ ابتِغاءَ مَرضاتِ اللَّهِ فَسَوفَ نُؤتيهِ أَجرًا عَظيمًا\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@dcviii{وَمَن يُشاقِقِ الرَّسولَ مِن بَعدِ ما تَبَيَّنَ لَهُ الهُدىٰ وَيَتَّبِع غَيرَ سَبيلِ المُؤمِنينَ نُوَلِّهِ ما تَوَلّىٰ وَنُصلِهِ جَهَنَّمَ ۖ وَساءَت مَصيرًا\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@dcix{إِنَّ اللَّهَ لا يَغفِرُ أَن يُشرَكَ بِهِ وَيَغفِرُ ما دونَ ذٰلِكَ لِمَن يَشاءُ ۚ وَمَن يُشرِك بِاللَّهِ فَقَد ضَلَّ ضَلالًا بَعيدًا\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@dcx{إِن يَدعونَ مِن دونِهِ إِلّا إِناثًا وَإِن يَدعونَ إِلّا شَيطانًا مَريدًا\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@dcxi{لَعَنَهُ اللَّهُ ۘ وَقالَ لَأَتَّخِذَنَّ مِن عِبادِكَ نَصيبًا مَفروضًا\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@dcxii{وَلَأُضِلَّنَّهُم وَلَأُمَنِّيَنَّهُم وَلَآمُرَنَّهُم فَلَيُبَتِّكُنَّ آذانَ الأَنعامِ وَلَآمُرَنَّهُم فَلَيُغَيِّرُنَّ خَلقَ اللَّهِ ۚ وَمَن يَتَّخِذِ الشَّيطانَ وَلِيًّا مِن دونِ اللَّهِ فَقَد خَسِرَ خُسرانًا مُبينًا\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@dcxiii{يَعِدُهُم وَيُمَنّيهِم ۖ وَما يَعِدُهُمُ الشَّيطانُ إِلّا غُرورًا\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@dcxiv{أُولٰئِكَ مَأواهُم جَهَنَّمُ وَلا يَجِدونَ عَنها مَحيصًا\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@dcxv{وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ سَنُدخِلُهُم جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها أَبَدًا ۖ وَعدَ اللَّهِ حَقًّا ۚ وَمَن أَصدَقُ مِنَ اللَّهِ قيلًا\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@dcxvi{لَيسَ بِأَمانِيِّكُم وَلا أَمانِيِّ أَهلِ الكِتابِ ۗ مَن يَعمَل سوءًا يُجزَ بِهِ وَلا يَجِد لَهُ مِن دونِ اللَّهِ وَلِيًّا وَلا نَصيرًا\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@dcxvii{وَمَن يَعمَل مِنَ الصّالِحاتِ مِن ذَكَرٍ أَو أُنثىٰ وَهُوَ مُؤمِنٌ فَأُولٰئِكَ يَدخُلونَ الجَنَّةَ وَلا يُظلَمونَ نَقيرًا\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@dcxviii{وَمَن أَحسَنُ دينًا مِمَّن أَسلَمَ وَجهَهُ لِلَّهِ وَهُوَ مُحسِنٌ وَاتَّبَعَ مِلَّةَ إِبراهيمَ حَنيفًا ۗ وَاتَّخَذَ اللَّهُ إِبراهيمَ خَليلًا\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@dcxix{وَلِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۚ وَكانَ اللَّهُ بِكُلِّ شَيءٍ مُحيطًا\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@dcxx{وَيَستَفتونَكَ فِي النِّساءِ ۖ قُلِ اللَّهُ يُفتيكُم فيهِنَّ وَما يُتلىٰ عَلَيكُم فِي الكِتابِ في يَتامَى النِّساءِ اللّاتي لا تُؤتونَهُنَّ ما كُتِبَ لَهُنَّ وَتَرغَبونَ أَن تَنكِحوهُنَّ وَالمُستَضعَفينَ مِنَ الوِلدانِ وَأَن تَقوموا لِليَتامىٰ بِالقِسطِ ۚ وَما تَفعَلوا مِن خَيرٍ فَإِنَّ اللَّهَ كانَ بِهِ عَليمًا\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@dcxxi{وَإِنِ امرَأَةٌ خافَت مِن بَعلِها نُشوزًا أَو إِعراضًا فَلا جُناحَ عَلَيهِما أَن يُصلِحا بَينَهُما صُلحًا ۚ وَالصُّلحُ خَيرٌ ۗ وَأُحضِرَتِ الأَنفُسُ الشُّحَّ ۚ وَإِن تُحسِنوا وَتَتَّقوا فَإِنَّ اللَّهَ كانَ بِما تَعمَلونَ خَبيرًا\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@dcxxii{وَلَن تَستَطيعوا أَن تَعدِلوا بَينَ النِّساءِ وَلَو حَرَصتُم ۖ فَلا تَميلوا كُلَّ المَيلِ فَتَذَروها كَالمُعَلَّقَةِ ۚ وَإِن تُصلِحوا وَتَتَّقوا فَإِنَّ اللَّهَ كانَ غَفورًا رَحيمًا\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@dcxxiii{وَإِن يَتَفَرَّقا يُغنِ اللَّهُ كُلًّا مِن سَعَتِهِ ۚ وَكانَ اللَّهُ واسِعًا حَكيمًا\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@dcxxiv{وَلِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۗ وَلَقَد وَصَّينَا الَّذينَ أوتُوا الكِتابَ مِن قَبلِكُم وَإِيّاكُم أَنِ اتَّقُوا اللَّهَ ۚ وَإِن تَكفُروا فَإِنَّ لِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۚ وَكانَ اللَّهُ غَنِيًّا حَميدًا\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@dcxxv{وَلِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۚ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@dcxxvi{إِن يَشَأ يُذهِبكُم أَيُّهَا النّاسُ وَيَأتِ بِآخَرينَ ۚ وَكانَ اللَّهُ عَلىٰ ذٰلِكَ قَديرًا\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@dcxxvii{مَن كانَ يُريدُ ثَوابَ الدُّنيا فَعِندَ اللَّهِ ثَوابُ الدُّنيا وَالآخِرَةِ ۚ وَكانَ اللَّهُ سَميعًا بَصيرًا\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@dcxxviii{۞ يا أَيُّهَا الَّذينَ آمَنوا كونوا قَوّامينَ بِالقِسطِ شُهَداءَ لِلَّهِ وَلَو عَلىٰ أَنفُسِكُم أَوِ الوالِدَينِ وَالأَقرَبينَ ۚ إِن يَكُن غَنِيًّا أَو فَقيرًا فَاللَّهُ أَولىٰ بِهِما ۖ فَلا تَتَّبِعُوا الهَوىٰ أَن تَعدِلوا ۚ وَإِن تَلووا أَو تُعرِضوا فَإِنَّ اللَّهَ كانَ بِما تَعمَلونَ خَبيرًا\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@dcxxix{يا أَيُّهَا الَّذينَ آمَنوا آمِنوا بِاللَّهِ وَرَسولِهِ وَالكِتابِ الَّذي نَزَّلَ عَلىٰ رَسولِهِ وَالكِتابِ الَّذي أَنزَلَ مِن قَبلُ ۚ وَمَن يَكفُر بِاللَّهِ وَمَلائِكَتِهِ وَكُتُبِهِ وَرُسُلِهِ وَاليَومِ الآخِرِ فَقَد ضَلَّ ضَلالًا بَعيدًا\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@dcxxx{إِنَّ الَّذينَ آمَنوا ثُمَّ كَفَروا ثُمَّ آمَنوا ثُمَّ كَفَروا ثُمَّ ازدادوا كُفرًا لَم يَكُنِ اللَّهُ لِيَغفِرَ لَهُم وَلا لِيَهدِيَهُم سَبيلًا\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@dcxxxi{بَشِّرِ المُنافِقينَ بِأَنَّ لَهُم عَذابًا أَليمًا\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@dcxxxii{الَّذينَ يَتَّخِذونَ الكافِرينَ أَولِياءَ مِن دونِ المُؤمِنينَ ۚ أَيَبتَغونَ عِندَهُمُ العِزَّةَ فَإِنَّ العِزَّةَ لِلَّهِ جَميعًا\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@dcxxxiii{وَقَد نَزَّلَ عَلَيكُم فِي الكِتابِ أَن إِذا سَمِعتُم آياتِ اللَّهِ يُكفَرُ بِها وَيُستَهزَأُ بِها فَلا تَقعُدوا مَعَهُم حَتّىٰ يَخوضوا في حَديثٍ غَيرِهِ ۚ إِنَّكُم إِذًا مِثلُهُم ۗ إِنَّ اللَّهَ جامِعُ المُنافِقينَ وَالكافِرينَ في جَهَنَّمَ جَميعًا\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@dcxxxiv{الَّذينَ يَتَرَبَّصونَ بِكُم فَإِن كانَ لَكُم فَتحٌ مِنَ اللَّهِ قالوا أَلَم نَكُن مَعَكُم وَإِن كانَ لِلكافِرينَ نَصيبٌ قالوا أَلَم نَستَحوِذ عَلَيكُم وَنَمنَعكُم مِنَ المُؤمِنينَ ۚ فَاللَّهُ يَحكُمُ بَينَكُم يَومَ القِيامَةِ ۗ وَلَن يَجعَلَ اللَّهُ لِلكافِرينَ عَلَى المُؤمِنينَ سَبيلًا\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@dcxxxv{إِنَّ المُنافِقينَ يُخادِعونَ اللَّهَ وَهُوَ خادِعُهُم وَإِذا قاموا إِلَى الصَّلاةِ قاموا كُسالىٰ يُراءونَ النّاسَ وَلا يَذكُرونَ اللَّهَ إِلّا قَليلًا\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@dcxxxvi{مُذَبذَبينَ بَينَ ذٰلِكَ لا إِلىٰ هٰؤُلاءِ وَلا إِلىٰ هٰؤُلاءِ ۚ وَمَن يُضلِلِ اللَّهُ فَلَن تَجِدَ لَهُ سَبيلًا\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@dcxxxvii{يا أَيُّهَا الَّذينَ آمَنوا لا تَتَّخِذُوا الكافِرينَ أَولِياءَ مِن دونِ المُؤمِنينَ ۚ أَتُريدونَ أَن تَجعَلوا لِلَّهِ عَلَيكُم سُلطانًا مُبينًا\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@dcxxxviii{إِنَّ المُنافِقينَ فِي الدَّركِ الأَسفَلِ مِنَ النّارِ وَلَن تَجِدَ لَهُم نَصيرًا\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@dcxxxix{إِلَّا الَّذينَ تابوا وَأَصلَحوا وَاعتَصَموا بِاللَّهِ وَأَخلَصوا دينَهُم لِلَّهِ فَأُولٰئِكَ مَعَ المُؤمِنينَ ۖ وَسَوفَ يُؤتِ اللَّهُ المُؤمِنينَ أَجرًا عَظيمًا\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@dcxl{ما يَفعَلُ اللَّهُ بِعَذابِكُم إِن شَكَرتُم وَآمَنتُم ۚ وَكانَ اللَّهُ شاكِرًا عَليمًا\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@dcxli{۞ لا يُحِبُّ اللَّهُ الجَهرَ بِالسّوءِ مِنَ القَولِ إِلّا مَن ظُلِمَ ۚ وَكانَ اللَّهُ سَميعًا عَليمًا\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@dcxlii{إِن تُبدوا خَيرًا أَو تُخفوهُ أَو تَعفوا عَن سوءٍ فَإِنَّ اللَّهَ كانَ عَفُوًّا قَديرًا\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@dcxliii{إِنَّ الَّذينَ يَكفُرونَ بِاللَّهِ وَرُسُلِهِ وَيُريدونَ أَن يُفَرِّقوا بَينَ اللَّهِ وَرُسُلِهِ وَيَقولونَ نُؤمِنُ بِبَعضٍ وَنَكفُرُ بِبَعضٍ وَيُريدونَ أَن يَتَّخِذوا بَينَ ذٰلِكَ سَبيلًا\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@dcxliv{أُولٰئِكَ هُمُ الكافِرونَ حَقًّا ۚ وَأَعتَدنا لِلكافِرينَ عَذابًا مُهينًا\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@dcxlv{وَالَّذينَ آمَنوا بِاللَّهِ وَرُسُلِهِ وَلَم يُفَرِّقوا بَينَ أَحَدٍ مِنهُم أُولٰئِكَ سَوفَ يُؤتيهِم أُجورَهُم ۗ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@dcxlvi{يَسأَلُكَ أَهلُ الكِتابِ أَن تُنَزِّلَ عَلَيهِم كِتابًا مِنَ السَّماءِ ۚ فَقَد سَأَلوا موسىٰ أَكبَرَ مِن ذٰلِكَ فَقالوا أَرِنَا اللَّهَ جَهرَةً فَأَخَذَتهُمُ الصّاعِقَةُ بِظُلمِهِم ۚ ثُمَّ اتَّخَذُوا العِجلَ مِن بَعدِ ما جاءَتهُمُ البَيِّناتُ فَعَفَونا عَن ذٰلِكَ ۚ وَآتَينا موسىٰ سُلطانًا مُبينًا\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@dcxlvii{وَرَفَعنا فَوقَهُمُ الطّورَ بِميثاقِهِم وَقُلنا لَهُمُ ادخُلُوا البابَ سُجَّدًا وَقُلنا لَهُم لا تَعدوا فِي السَّبتِ وَأَخَذنا مِنهُم ميثاقًا غَليظًا\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@dcxlviii{فَبِما نَقضِهِم ميثاقَهُم وَكُفرِهِم بِآياتِ اللَّهِ وَقَتلِهِمُ الأَنبِياءَ بِغَيرِ حَقٍّ وَقَولِهِم قُلوبُنا غُلفٌ ۚ بَل طَبَعَ اللَّهُ عَلَيها بِكُفرِهِم فَلا يُؤمِنونَ إِلّا قَليلًا\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@dcxlix{وَبِكُفرِهِم وَقَولِهِم عَلىٰ مَريَمَ بُهتانًا عَظيمًا\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@dcl{وَقَولِهِم إِنّا قَتَلنَا المَسيحَ عيسَى ابنَ مَريَمَ رَسولَ اللَّهِ وَما قَتَلوهُ وَما صَلَبوهُ وَلٰكِن شُبِّهَ لَهُم ۚ وَإِنَّ الَّذينَ اختَلَفوا فيهِ لَفي شَكٍّ مِنهُ ۚ ما لَهُم بِهِ مِن عِلمٍ إِلَّا اتِّباعَ الظَّنِّ ۚ وَما قَتَلوهُ يَقينًا\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@dcli{بَل رَفَعَهُ اللَّهُ إِلَيهِ ۚ وَكانَ اللَّهُ عَزيزًا حَكيمًا\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@dclii{وَإِن مِن أَهلِ الكِتابِ إِلّا لَيُؤمِنَنَّ بِهِ قَبلَ مَوتِهِ ۖ وَيَومَ القِيامَةِ يَكونُ عَلَيهِم شَهيدًا\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@dcliii{فَبِظُلمٍ مِنَ الَّذينَ هادوا حَرَّمنا عَلَيهِم طَيِّباتٍ أُحِلَّت لَهُم وَبِصَدِّهِم عَن سَبيلِ اللَّهِ كَثيرًا\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@dcliv{وَأَخذِهِمُ الرِّبا وَقَد نُهوا عَنهُ وَأَكلِهِم أَموالَ النّاسِ بِالباطِلِ ۚ وَأَعتَدنا لِلكافِرينَ مِنهُم عَذابًا أَليمًا\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@dclv{لٰكِنِ الرّاسِخونَ فِي العِلمِ مِنهُم وَالمُؤمِنونَ يُؤمِنونَ بِما أُنزِلَ إِلَيكَ وَما أُنزِلَ مِن قَبلِكَ ۚ وَالمُقيمينَ الصَّلاةَ ۚ وَالمُؤتونَ الزَّكاةَ وَالمُؤمِنونَ بِاللَّهِ وَاليَومِ الآخِرِ أُولٰئِكَ سَنُؤتيهِم أَجرًا عَظيمًا\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@dclvi{۞ إِنّا أَوحَينا إِلَيكَ كَما أَوحَينا إِلىٰ نوحٍ وَالنَّبِيّينَ مِن بَعدِهِ ۚ وَأَوحَينا إِلىٰ إِبراهيمَ وَإِسماعيلَ وَإِسحاقَ وَيَعقوبَ وَالأَسباطِ وَعيسىٰ وَأَيّوبَ وَيونُسَ وَهارونَ وَسُلَيمانَ ۚ وَآتَينا داوودَ زَبورًا\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@dclvii{وَرُسُلًا قَد قَصَصناهُم عَلَيكَ مِن قَبلُ وَرُسُلًا لَم نَقصُصهُم عَلَيكَ ۚ وَكَلَّمَ اللَّهُ موسىٰ تَكليمًا\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@dclviii{رُسُلًا مُبَشِّرينَ وَمُنذِرينَ لِئَلّا يَكونَ لِلنّاسِ عَلَى اللَّهِ حُجَّةٌ بَعدَ الرُّسُلِ ۚ وَكانَ اللَّهُ عَزيزًا حَكيمًا\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@dclix{لٰكِنِ اللَّهُ يَشهَدُ بِما أَنزَلَ إِلَيكَ ۖ أَنزَلَهُ بِعِلمِهِ ۖ وَالمَلائِكَةُ يَشهَدونَ ۚ وَكَفىٰ بِاللَّهِ شَهيدًا\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@dclx{إِنَّ الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ قَد ضَلّوا ضَلالًا بَعيدًا\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@dclxi{إِنَّ الَّذينَ كَفَروا وَظَلَموا لَم يَكُنِ اللَّهُ لِيَغفِرَ لَهُم وَلا لِيَهدِيَهُم طَريقًا\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@dclxii{إِلّا طَريقَ جَهَنَّمَ خالِدينَ فيها أَبَدًا ۚ وَكانَ ذٰلِكَ عَلَى اللَّهِ يَسيرًا\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@dclxiii{يا أَيُّهَا النّاسُ قَد جاءَكُمُ الرَّسولُ بِالحَقِّ مِن رَبِّكُم فَآمِنوا خَيرًا لَكُم ۚ وَإِن تَكفُروا فَإِنَّ لِلَّهِ ما فِي السَّماواتِ وَالأَرضِ ۚ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@dclxiv{يا أَهلَ الكِتابِ لا تَغلوا في دينِكُم وَلا تَقولوا عَلَى اللَّهِ إِلَّا الحَقَّ ۚ إِنَّمَا المَسيحُ عيسَى ابنُ مَريَمَ رَسولُ اللَّهِ وَكَلِمَتُهُ أَلقاها إِلىٰ مَريَمَ وَروحٌ مِنهُ ۖ فَآمِنوا بِاللَّهِ وَرُسُلِهِ ۖ وَلا تَقولوا ثَلاثَةٌ ۚ انتَهوا خَيرًا لَكُم ۚ إِنَّمَا اللَّهُ إِلٰهٌ واحِدٌ ۖ سُبحانَهُ أَن يَكونَ لَهُ وَلَدٌ ۘ لَهُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۗ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@dclxv{لَن يَستَنكِفَ المَسيحُ أَن يَكونَ عَبدًا لِلَّهِ وَلَا المَلائِكَةُ المُقَرَّبونَ ۚ وَمَن يَستَنكِف عَن عِبادَتِهِ وَيَستَكبِر فَسَيَحشُرُهُم إِلَيهِ جَميعًا\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@dclxvi{فَأَمَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ فَيُوَفّيهِم أُجورَهُم وَيَزيدُهُم مِن فَضلِهِ ۖ وَأَمَّا الَّذينَ استَنكَفوا وَاستَكبَروا فَيُعَذِّبُهُم عَذابًا أَليمًا وَلا يَجِدونَ لَهُم مِن دونِ اللَّهِ وَلِيًّا وَلا نَصيرًا\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@dclxvii{يا أَيُّهَا النّاسُ قَد جاءَكُم بُرهانٌ مِن رَبِّكُم وَأَنزَلنا إِلَيكُم نورًا مُبينًا\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@dclxviii{فَأَمَّا الَّذينَ آمَنوا بِاللَّهِ وَاعتَصَموا بِهِ فَسَيُدخِلُهُم في رَحمَةٍ مِنهُ وَفَضلٍ وَيَهديهِم إِلَيهِ صِراطًا مُستَقيمًا\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@dclxix{يَستَفتونَكَ قُلِ اللَّهُ يُفتيكُم فِي الكَلالَةِ ۚ إِنِ امرُؤٌ هَلَكَ لَيسَ لَهُ وَلَدٌ وَلَهُ أُختٌ فَلَها نِصفُ ما تَرَكَ ۚ وَهُوَ يَرِثُها إِن لَم يَكُن لَها وَلَدٌ ۚ فَإِن كانَتَا اثنَتَينِ فَلَهُمَا الثُّلُثانِ مِمّا تَرَكَ ۚ وَإِن كانوا إِخوَةً رِجالًا وَنِساءً فَلِلذَّكَرِ مِثلُ حَظِّ الأُنثَيَينِ ۗ يُبَيِّنُ اللَّهُ لَكُم أَن تَضِلّوا ۗ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@dclxx{\basmalah يا أَيُّهَا الَّذينَ آمَنوا أَوفوا بِالعُقودِ ۚ أُحِلَّت لَكُم بَهيمَةُ الأَنعامِ إِلّا ما يُتلىٰ عَلَيكُم غَيرَ مُحِلِّي الصَّيدِ وَأَنتُم حُرُمٌ ۗ إِنَّ اللَّهَ يَحكُمُ ما يُريدُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@dclxxi{يا أَيُّهَا الَّذينَ آمَنوا لا تُحِلّوا شَعائِرَ اللَّهِ وَلَا الشَّهرَ الحَرامَ وَلَا الهَديَ وَلَا القَلائِدَ وَلا آمّينَ البَيتَ الحَرامَ يَبتَغونَ فَضلًا مِن رَبِّهِم وَرِضوانًا ۚ وَإِذا حَلَلتُم فَاصطادوا ۚ وَلا يَجرِمَنَّكُم شَنَآنُ قَومٍ أَن صَدّوكُم عَنِ المَسجِدِ الحَرامِ أَن تَعتَدوا ۘ وَتَعاوَنوا عَلَى البِرِّ وَالتَّقوىٰ ۖ وَلا تَعاوَنوا عَلَى الإِثمِ وَالعُدوانِ ۚ وَاتَّقُوا اللَّهَ ۖ إِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@dclxxii{حُرِّمَت عَلَيكُمُ المَيتَةُ وَالدَّمُ وَلَحمُ الخِنزيرِ وَما أُهِلَّ لِغَيرِ اللَّهِ بِهِ وَالمُنخَنِقَةُ وَالمَوقوذَةُ وَالمُتَرَدِّيَةُ وَالنَّطيحَةُ وَما أَكَلَ السَّبُعُ إِلّا ما ذَكَّيتُم وَما ذُبِحَ عَلَى النُّصُبِ وَأَن تَستَقسِموا بِالأَزلامِ ۚ ذٰلِكُم فِسقٌ ۗ اليَومَ يَئِسَ الَّذينَ كَفَروا مِن دينِكُم فَلا تَخشَوهُم وَاخشَونِ ۚ اليَومَ أَكمَلتُ لَكُم دينَكُم وَأَتمَمتُ عَلَيكُم نِعمَتي وَرَضيتُ لَكُمُ الإِسلامَ دينًا ۚ فَمَنِ اضطُرَّ في مَخمَصَةٍ غَيرَ مُتَجانِفٍ لِإِثمٍ ۙ فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@dclxxiii{يَسأَلونَكَ ماذا أُحِلَّ لَهُم ۖ قُل أُحِلَّ لَكُمُ الطَّيِّباتُ ۙ وَما عَلَّمتُم مِنَ الجَوارِحِ مُكَلِّبينَ تُعَلِّمونَهُنَّ مِمّا عَلَّمَكُمُ اللَّهُ ۖ فَكُلوا مِمّا أَمسَكنَ عَلَيكُم وَاذكُرُوا اسمَ اللَّهِ عَلَيهِ ۖ وَاتَّقُوا اللَّهَ ۚ إِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@dclxxiv{اليَومَ أُحِلَّ لَكُمُ الطَّيِّباتُ ۖ وَطَعامُ الَّذينَ أوتُوا الكِتابَ حِلٌّ لَكُم وَطَعامُكُم حِلٌّ لَهُم ۖ وَالمُحصَناتُ مِنَ المُؤمِناتِ وَالمُحصَناتُ مِنَ الَّذينَ أوتُوا الكِتابَ مِن قَبلِكُم إِذا آتَيتُموهُنَّ أُجورَهُنَّ مُحصِنينَ غَيرَ مُسافِحينَ وَلا مُتَّخِذي أَخدانٍ ۗ وَمَن يَكفُر بِالإيمانِ فَقَد حَبِطَ عَمَلُهُ وَهُوَ فِي الآخِرَةِ مِنَ الخاسِرينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@dclxxv{يا أَيُّهَا الَّذينَ آمَنوا إِذا قُمتُم إِلَى الصَّلاةِ فَاغسِلوا وُجوهَكُم وَأَيدِيَكُم إِلَى المَرافِقِ وَامسَحوا بِرُءوسِكُم وَأَرجُلَكُم إِلَى الكَعبَينِ ۚ وَإِن كُنتُم جُنُبًا فَاطَّهَّروا ۚ وَإِن كُنتُم مَرضىٰ أَو عَلىٰ سَفَرٍ أَو جاءَ أَحَدٌ مِنكُم مِنَ الغائِطِ أَو لامَستُمُ النِّساءَ فَلَم تَجِدوا ماءً فَتَيَمَّموا صَعيدًا طَيِّبًا فَامسَحوا بِوُجوهِكُم وَأَيديكُم مِنهُ ۚ ما يُريدُ اللَّهُ لِيَجعَلَ عَلَيكُم مِن حَرَجٍ وَلٰكِن يُريدُ لِيُطَهِّرَكُم وَلِيُتِمَّ نِعمَتَهُ عَلَيكُم لَعَلَّكُم تَشكُرونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@dclxxvi{وَاذكُروا نِعمَةَ اللَّهِ عَلَيكُم وَميثاقَهُ الَّذي واثَقَكُم بِهِ إِذ قُلتُم سَمِعنا وَأَطَعنا ۖ وَاتَّقُوا اللَّهَ ۚ إِنَّ اللَّهَ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@dclxxvii{يا أَيُّهَا الَّذينَ آمَنوا كونوا قَوّامينَ لِلَّهِ شُهَداءَ بِالقِسطِ ۖ وَلا يَجرِمَنَّكُم شَنَآنُ قَومٍ عَلىٰ أَلّا تَعدِلُوا ۚ اعدِلوا هُوَ أَقرَبُ لِلتَّقوىٰ ۖ وَاتَّقُوا اللَّهَ ۚ إِنَّ اللَّهَ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@dclxxviii{وَعَدَ اللَّهُ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ ۙ لَهُم مَغفِرَةٌ وَأَجرٌ عَظيمٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@dclxxix{وَالَّذينَ كَفَروا وَكَذَّبوا بِآياتِنا أُولٰئِكَ أَصحابُ الجَحيمِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@dclxxx{يا أَيُّهَا الَّذينَ آمَنُوا اذكُروا نِعمَتَ اللَّهِ عَلَيكُم إِذ هَمَّ قَومٌ أَن يَبسُطوا إِلَيكُم أَيدِيَهُم فَكَفَّ أَيدِيَهُم عَنكُم ۖ وَاتَّقُوا اللَّهَ ۚ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@dclxxxi{۞ وَلَقَد أَخَذَ اللَّهُ ميثاقَ بَني إِسرائيلَ وَبَعَثنا مِنهُمُ اثنَي عَشَرَ نَقيبًا ۖ وَقالَ اللَّهُ إِنّي مَعَكُم ۖ لَئِن أَقَمتُمُ الصَّلاةَ وَآتَيتُمُ الزَّكاةَ وَآمَنتُم بِرُسُلي وَعَزَّرتُموهُم وَأَقرَضتُمُ اللَّهَ قَرضًا حَسَنًا لَأُكَفِّرَنَّ عَنكُم سَيِّئَاتِكُم وَلَأُدخِلَنَّكُم جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ ۚ فَمَن كَفَرَ بَعدَ ذٰلِكَ مِنكُم فَقَد ضَلَّ سَواءَ السَّبيلِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@dclxxxii{فَبِما نَقضِهِم ميثاقَهُم لَعَنّاهُم وَجَعَلنا قُلوبَهُم قاسِيَةً ۖ يُحَرِّفونَ الكَلِمَ عَن مَواضِعِهِ ۙ وَنَسوا حَظًّا مِمّا ذُكِّروا بِهِ ۚ وَلا تَزالُ تَطَّلِعُ عَلىٰ خائِنَةٍ مِنهُم إِلّا قَليلًا مِنهُم ۖ فَاعفُ عَنهُم وَاصفَح ۚ إِنَّ اللَّهَ يُحِبُّ المُحسِنينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@dclxxxiii{وَمِنَ الَّذينَ قالوا إِنّا نَصارىٰ أَخَذنا ميثاقَهُم فَنَسوا حَظًّا مِمّا ذُكِّروا بِهِ فَأَغرَينا بَينَهُمُ العَداوَةَ وَالبَغضاءَ إِلىٰ يَومِ القِيامَةِ ۚ وَسَوفَ يُنَبِّئُهُمُ اللَّهُ بِما كانوا يَصنَعونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@dclxxxiv{يا أَهلَ الكِتابِ قَد جاءَكُم رَسولُنا يُبَيِّنُ لَكُم كَثيرًا مِمّا كُنتُم تُخفونَ مِنَ الكِتابِ وَيَعفو عَن كَثيرٍ ۚ قَد جاءَكُم مِنَ اللَّهِ نورٌ وَكِتابٌ مُبينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@dclxxxv{يَهدي بِهِ اللَّهُ مَنِ اتَّبَعَ رِضوانَهُ سُبُلَ السَّلامِ وَيُخرِجُهُم مِنَ الظُّلُماتِ إِلَى النّورِ بِإِذنِهِ وَيَهديهِم إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@dclxxxvi{لَقَد كَفَرَ الَّذينَ قالوا إِنَّ اللَّهَ هُوَ المَسيحُ ابنُ مَريَمَ ۚ قُل فَمَن يَملِكُ مِنَ اللَّهِ شَيئًا إِن أَرادَ أَن يُهلِكَ المَسيحَ ابنَ مَريَمَ وَأُمَّهُ وَمَن فِي الأَرضِ جَميعًا ۗ وَلِلَّهِ مُلكُ السَّماواتِ وَالأَرضِ وَما بَينَهُما ۚ يَخلُقُ ما يَشاءُ ۚ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@dclxxxvii{وَقالَتِ اليَهودُ وَالنَّصارىٰ نَحنُ أَبناءُ اللَّهِ وَأَحِبّاؤُهُ ۚ قُل فَلِمَ يُعَذِّبُكُم بِذُنوبِكُم ۖ بَل أَنتُم بَشَرٌ مِمَّن خَلَقَ ۚ يَغفِرُ لِمَن يَشاءُ وَيُعَذِّبُ مَن يَشاءُ ۚ وَلِلَّهِ مُلكُ السَّماواتِ وَالأَرضِ وَما بَينَهُما ۖ وَإِلَيهِ المَصيرُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@dclxxxviii{يا أَهلَ الكِتابِ قَد جاءَكُم رَسولُنا يُبَيِّنُ لَكُم عَلىٰ فَترَةٍ مِنَ الرُّسُلِ أَن تَقولوا ما جاءَنا مِن بَشيرٍ وَلا نَذيرٍ ۖ فَقَد جاءَكُم بَشيرٌ وَنَذيرٌ ۗ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@dclxxxix{وَإِذ قالَ موسىٰ لِقَومِهِ يا قَومِ اذكُروا نِعمَةَ اللَّهِ عَلَيكُم إِذ جَعَلَ فيكُم أَنبِياءَ وَجَعَلَكُم مُلوكًا وَآتاكُم ما لَم يُؤتِ أَحَدًا مِنَ العالَمينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@dcxc{يا قَومِ ادخُلُوا الأَرضَ المُقَدَّسَةَ الَّتي كَتَبَ اللَّهُ لَكُم وَلا تَرتَدّوا عَلىٰ أَدبارِكُم فَتَنقَلِبوا خاسِرينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@dcxci{قالوا يا موسىٰ إِنَّ فيها قَومًا جَبّارينَ وَإِنّا لَن نَدخُلَها حَتّىٰ يَخرُجوا مِنها فَإِن يَخرُجوا مِنها فَإِنّا داخِلونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@dcxcii{قالَ رَجُلانِ مِنَ الَّذينَ يَخافونَ أَنعَمَ اللَّهُ عَلَيهِمَا ادخُلوا عَلَيهِمُ البابَ فَإِذا دَخَلتُموهُ فَإِنَّكُم غالِبونَ ۚ وَعَلَى اللَّهِ فَتَوَكَّلوا إِن كُنتُم مُؤمِنينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@dcxciii{قالوا يا موسىٰ إِنّا لَن نَدخُلَها أَبَدًا ما داموا فيها ۖ فَاذهَب أَنتَ وَرَبُّكَ فَقاتِلا إِنّا هاهُنا قاعِدونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@dcxciv{قالَ رَبِّ إِنّي لا أَملِكُ إِلّا نَفسي وَأَخي ۖ فَافرُق بَينَنا وَبَينَ القَومِ الفاسِقينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@dcxcv{قالَ فَإِنَّها مُحَرَّمَةٌ عَلَيهِم ۛ أَربَعينَ سَنَةً ۛ يَتيهونَ فِي الأَرضِ ۚ فَلا تَأسَ عَلَى القَومِ الفاسِقينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@dcxcvi{۞ وَاتلُ عَلَيهِم نَبَأَ ابنَي آدَمَ بِالحَقِّ إِذ قَرَّبا قُربانًا فَتُقُبِّلَ مِن أَحَدِهِما وَلَم يُتَقَبَّل مِنَ الآخَرِ قالَ لَأَقتُلَنَّكَ ۖ قالَ إِنَّما يَتَقَبَّلُ اللَّهُ مِنَ المُتَّقينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@dcxcvii{لَئِن بَسَطتَ إِلَيَّ يَدَكَ لِتَقتُلَني ما أَنا بِباسِطٍ يَدِيَ إِلَيكَ لِأَقتُلَكَ ۖ إِنّي أَخافُ اللَّهَ رَبَّ العالَمينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@dcxcviii{إِنّي أُريدُ أَن تَبوءَ بِإِثمي وَإِثمِكَ فَتَكونَ مِن أَصحابِ النّارِ ۚ وَذٰلِكَ جَزاءُ الظّالِمينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@dcxcix{فَطَوَّعَت لَهُ نَفسُهُ قَتلَ أَخيهِ فَقَتَلَهُ فَأَصبَحَ مِنَ الخاسِرينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@dcc{فَبَعَثَ اللَّهُ غُرابًا يَبحَثُ فِي الأَرضِ لِيُرِيَهُ كَيفَ يُواري سَوءَةَ أَخيهِ ۚ قالَ يا وَيلَتا أَعَجَزتُ أَن أَكونَ مِثلَ هٰذَا الغُرابِ فَأُوارِيَ سَوءَةَ أَخي ۖ فَأَصبَحَ مِنَ النّادِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@dcci{مِن أَجلِ ذٰلِكَ كَتَبنا عَلىٰ بَني إِسرائيلَ أَنَّهُ مَن قَتَلَ نَفسًا بِغَيرِ نَفسٍ أَو فَسادٍ فِي الأَرضِ فَكَأَنَّما قَتَلَ النّاسَ جَميعًا وَمَن أَحياها فَكَأَنَّما أَحيَا النّاسَ جَميعًا ۚ وَلَقَد جاءَتهُم رُسُلُنا بِالبَيِّناتِ ثُمَّ إِنَّ كَثيرًا مِنهُم بَعدَ ذٰلِكَ فِي الأَرضِ لَمُسرِفونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@dccii{إِنَّما جَزاءُ الَّذينَ يُحارِبونَ اللَّهَ وَرَسولَهُ وَيَسعَونَ فِي الأَرضِ فَسادًا أَن يُقَتَّلوا أَو يُصَلَّبوا أَو تُقَطَّعَ أَيديهِم وَأَرجُلُهُم مِن خِلافٍ أَو يُنفَوا مِنَ الأَرضِ ۚ ذٰلِكَ لَهُم خِزيٌ فِي الدُّنيا ۖ وَلَهُم فِي الآخِرَةِ عَذابٌ عَظيمٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@dcciii{إِلَّا الَّذينَ تابوا مِن قَبلِ أَن تَقدِروا عَلَيهِم ۖ فَاعلَموا أَنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@dcciv{يا أَيُّهَا الَّذينَ آمَنُوا اتَّقُوا اللَّهَ وَابتَغوا إِلَيهِ الوَسيلَةَ وَجاهِدوا في سَبيلِهِ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@dccv{إِنَّ الَّذينَ كَفَروا لَو أَنَّ لَهُم ما فِي الأَرضِ جَميعًا وَمِثلَهُ مَعَهُ لِيَفتَدوا بِهِ مِن عَذابِ يَومِ القِيامَةِ ما تُقُبِّلَ مِنهُم ۖ وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@dccvi{يُريدونَ أَن يَخرُجوا مِنَ النّارِ وَما هُم بِخارِجينَ مِنها ۖ وَلَهُم عَذابٌ مُقيمٌ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@dccvii{وَالسّارِقُ وَالسّارِقَةُ فَاقطَعوا أَيدِيَهُما جَزاءً بِما كَسَبا نَكالًا مِنَ اللَّهِ ۗ وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@dccviii{فَمَن تابَ مِن بَعدِ ظُلمِهِ وَأَصلَحَ فَإِنَّ اللَّهَ يَتوبُ عَلَيهِ ۗ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@dccix{أَلَم تَعلَم أَنَّ اللَّهَ لَهُ مُلكُ السَّماواتِ وَالأَرضِ يُعَذِّبُ مَن يَشاءُ وَيَغفِرُ لِمَن يَشاءُ ۗ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@dccx{۞ يا أَيُّهَا الرَّسولُ لا يَحزُنكَ الَّذينَ يُسارِعونَ فِي الكُفرِ مِنَ الَّذينَ قالوا آمَنّا بِأَفواهِهِم وَلَم تُؤمِن قُلوبُهُم ۛ وَمِنَ الَّذينَ هادوا ۛ سَمّاعونَ لِلكَذِبِ سَمّاعونَ لِقَومٍ آخَرينَ لَم يَأتوكَ ۖ يُحَرِّفونَ الكَلِمَ مِن بَعدِ مَواضِعِهِ ۖ يَقولونَ إِن أوتيتُم هٰذا فَخُذوهُ وَإِن لَم تُؤتَوهُ فَاحذَروا ۚ وَمَن يُرِدِ اللَّهُ فِتنَتَهُ فَلَن تَملِكَ لَهُ مِنَ اللَّهِ شَيئًا ۚ أُولٰئِكَ الَّذينَ لَم يُرِدِ اللَّهُ أَن يُطَهِّرَ قُلوبَهُم ۚ لَهُم فِي الدُّنيا خِزيٌ ۖ وَلَهُم فِي الآخِرَةِ عَذابٌ عَظيمٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@dccxi{سَمّاعونَ لِلكَذِبِ أَكّالونَ لِلسُّحتِ ۚ فَإِن جاءوكَ فَاحكُم بَينَهُم أَو أَعرِض عَنهُم ۖ وَإِن تُعرِض عَنهُم فَلَن يَضُرّوكَ شَيئًا ۖ وَإِن حَكَمتَ فَاحكُم بَينَهُم بِالقِسطِ ۚ إِنَّ اللَّهَ يُحِبُّ المُقسِطينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@dccxii{وَكَيفَ يُحَكِّمونَكَ وَعِندَهُمُ التَّوراةُ فيها حُكمُ اللَّهِ ثُمَّ يَتَوَلَّونَ مِن بَعدِ ذٰلِكَ ۚ وَما أُولٰئِكَ بِالمُؤمِنينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@dccxiii{إِنّا أَنزَلنَا التَّوراةَ فيها هُدًى وَنورٌ ۚ يَحكُمُ بِهَا النَّبِيّونَ الَّذينَ أَسلَموا لِلَّذينَ هادوا وَالرَّبّانِيّونَ وَالأَحبارُ بِمَا استُحفِظوا مِن كِتابِ اللَّهِ وَكانوا عَلَيهِ شُهَداءَ ۚ فَلا تَخشَوُا النّاسَ وَاخشَونِ وَلا تَشتَروا بِآياتي ثَمَنًا قَليلًا ۚ وَمَن لَم يَحكُم بِما أَنزَلَ اللَّهُ فَأُولٰئِكَ هُمُ الكافِرونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@dccxiv{وَكَتَبنا عَلَيهِم فيها أَنَّ النَّفسَ بِالنَّفسِ وَالعَينَ بِالعَينِ وَالأَنفَ بِالأَنفِ وَالأُذُنَ بِالأُذُنِ وَالسِّنَّ بِالسِّنِّ وَالجُروحَ قِصاصٌ ۚ فَمَن تَصَدَّقَ بِهِ فَهُوَ كَفّارَةٌ لَهُ ۚ وَمَن لَم يَحكُم بِما أَنزَلَ اللَّهُ فَأُولٰئِكَ هُمُ الظّالِمونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@dccxv{وَقَفَّينا عَلىٰ آثارِهِم بِعيسَى ابنِ مَريَمَ مُصَدِّقًا لِما بَينَ يَدَيهِ مِنَ التَّوراةِ ۖ وَآتَيناهُ الإِنجيلَ فيهِ هُدًى وَنورٌ وَمُصَدِّقًا لِما بَينَ يَدَيهِ مِنَ التَّوراةِ وَهُدًى وَمَوعِظَةً لِلمُتَّقينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@dccxvi{وَليَحكُم أَهلُ الإِنجيلِ بِما أَنزَلَ اللَّهُ فيهِ ۚ وَمَن لَم يَحكُم بِما أَنزَلَ اللَّهُ فَأُولٰئِكَ هُمُ الفاسِقونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@dccxvii{وَأَنزَلنا إِلَيكَ الكِتابَ بِالحَقِّ مُصَدِّقًا لِما بَينَ يَدَيهِ مِنَ الكِتابِ وَمُهَيمِنًا عَلَيهِ ۖ فَاحكُم بَينَهُم بِما أَنزَلَ اللَّهُ ۖ وَلا تَتَّبِع أَهواءَهُم عَمّا جاءَكَ مِنَ الحَقِّ ۚ لِكُلٍّ جَعَلنا مِنكُم شِرعَةً وَمِنهاجًا ۚ وَلَو شاءَ اللَّهُ لَجَعَلَكُم أُمَّةً واحِدَةً وَلٰكِن لِيَبلُوَكُم في ما آتاكُم ۖ فَاستَبِقُوا الخَيراتِ ۚ إِلَى اللَّهِ مَرجِعُكُم جَميعًا فَيُنَبِّئُكُم بِما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@dccxviii{وَأَنِ احكُم بَينَهُم بِما أَنزَلَ اللَّهُ وَلا تَتَّبِع أَهواءَهُم وَاحذَرهُم أَن يَفتِنوكَ عَن بَعضِ ما أَنزَلَ اللَّهُ إِلَيكَ ۖ فَإِن تَوَلَّوا فَاعلَم أَنَّما يُريدُ اللَّهُ أَن يُصيبَهُم بِبَعضِ ذُنوبِهِم ۗ وَإِنَّ كَثيرًا مِنَ النّاسِ لَفاسِقونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@dccxix{أَفَحُكمَ الجاهِلِيَّةِ يَبغونَ ۚ وَمَن أَحسَنُ مِنَ اللَّهِ حُكمًا لِقَومٍ يوقِنونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@dccxx{۞ يا أَيُّهَا الَّذينَ آمَنوا لا تَتَّخِذُوا اليَهودَ وَالنَّصارىٰ أَولِياءَ ۘ بَعضُهُم أَولِياءُ بَعضٍ ۚ وَمَن يَتَوَلَّهُم مِنكُم فَإِنَّهُ مِنهُم ۗ إِنَّ اللَّهَ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@dccxxi{فَتَرَى الَّذينَ في قُلوبِهِم مَرَضٌ يُسارِعونَ فيهِم يَقولونَ نَخشىٰ أَن تُصيبَنا دائِرَةٌ ۚ فَعَسَى اللَّهُ أَن يَأتِيَ بِالفَتحِ أَو أَمرٍ مِن عِندِهِ فَيُصبِحوا عَلىٰ ما أَسَرّوا في أَنفُسِهِم نادِمينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@dccxxii{وَيَقولُ الَّذينَ آمَنوا أَهٰؤُلاءِ الَّذينَ أَقسَموا بِاللَّهِ جَهدَ أَيمانِهِم ۙ إِنَّهُم لَمَعَكُم ۚ حَبِطَت أَعمالُهُم فَأَصبَحوا خاسِرينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@dccxxiii{يا أَيُّهَا الَّذينَ آمَنوا مَن يَرتَدَّ مِنكُم عَن دينِهِ فَسَوفَ يَأتِي اللَّهُ بِقَومٍ يُحِبُّهُم وَيُحِبّونَهُ أَذِلَّةٍ عَلَى المُؤمِنينَ أَعِزَّةٍ عَلَى الكافِرينَ يُجاهِدونَ في سَبيلِ اللَّهِ وَلا يَخافونَ لَومَةَ لائِمٍ ۚ ذٰلِكَ فَضلُ اللَّهِ يُؤتيهِ مَن يَشاءُ ۚ وَاللَّهُ واسِعٌ عَليمٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@dccxxiv{إِنَّما وَلِيُّكُمُ اللَّهُ وَرَسولُهُ وَالَّذينَ آمَنُوا الَّذينَ يُقيمونَ الصَّلاةَ وَيُؤتونَ الزَّكاةَ وَهُم راكِعونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@dccxxv{وَمَن يَتَوَلَّ اللَّهَ وَرَسولَهُ وَالَّذينَ آمَنوا فَإِنَّ حِزبَ اللَّهِ هُمُ الغالِبونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@dccxxvi{يا أَيُّهَا الَّذينَ آمَنوا لا تَتَّخِذُوا الَّذينَ اتَّخَذوا دينَكُم هُزُوًا وَلَعِبًا مِنَ الَّذينَ أوتُوا الكِتابَ مِن قَبلِكُم وَالكُفّارَ أَولِياءَ ۚ وَاتَّقُوا اللَّهَ إِن كُنتُم مُؤمِنينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@dccxxvii{وَإِذا نادَيتُم إِلَى الصَّلاةِ اتَّخَذوها هُزُوًا وَلَعِبًا ۚ ذٰلِكَ بِأَنَّهُم قَومٌ لا يَعقِلونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@dccxxviii{قُل يا أَهلَ الكِتابِ هَل تَنقِمونَ مِنّا إِلّا أَن آمَنّا بِاللَّهِ وَما أُنزِلَ إِلَينا وَما أُنزِلَ مِن قَبلُ وَأَنَّ أَكثَرَكُم فاسِقونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@dccxxix{قُل هَل أُنَبِّئُكُم بِشَرٍّ مِن ذٰلِكَ مَثوبَةً عِندَ اللَّهِ ۚ مَن لَعَنَهُ اللَّهُ وَغَضِبَ عَلَيهِ وَجَعَلَ مِنهُمُ القِرَدَةَ وَالخَنازيرَ وَعَبَدَ الطّاغوتَ ۚ أُولٰئِكَ شَرٌّ مَكانًا وَأَضَلُّ عَن سَواءِ السَّبيلِ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@dccxxx{وَإِذا جاءوكُم قالوا آمَنّا وَقَد دَخَلوا بِالكُفرِ وَهُم قَد خَرَجوا بِهِ ۚ وَاللَّهُ أَعلَمُ بِما كانوا يَكتُمونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@dccxxxi{وَتَرىٰ كَثيرًا مِنهُم يُسارِعونَ فِي الإِثمِ وَالعُدوانِ وَأَكلِهِمُ السُّحتَ ۚ لَبِئسَ ما كانوا يَعمَلونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@dccxxxii{لَولا يَنهاهُمُ الرَّبّانِيّونَ وَالأَحبارُ عَن قَولِهِمُ الإِثمَ وَأَكلِهِمُ السُّحتَ ۚ لَبِئسَ ما كانوا يَصنَعونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@dccxxxiii{وَقالَتِ اليَهودُ يَدُ اللَّهِ مَغلولَةٌ ۚ غُلَّت أَيديهِم وَلُعِنوا بِما قالوا ۘ بَل يَداهُ مَبسوطَتانِ يُنفِقُ كَيفَ يَشاءُ ۚ وَلَيَزيدَنَّ كَثيرًا مِنهُم ما أُنزِلَ إِلَيكَ مِن رَبِّكَ طُغيانًا وَكُفرًا ۚ وَأَلقَينا بَينَهُمُ العَداوَةَ وَالبَغضاءَ إِلىٰ يَومِ القِيامَةِ ۚ كُلَّما أَوقَدوا نارًا لِلحَربِ أَطفَأَهَا اللَّهُ ۚ وَيَسعَونَ فِي الأَرضِ فَسادًا ۚ وَاللَّهُ لا يُحِبُّ المُفسِدينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@dccxxxiv{وَلَو أَنَّ أَهلَ الكِتابِ آمَنوا وَاتَّقَوا لَكَفَّرنا عَنهُم سَيِّئَاتِهِم وَلَأَدخَلناهُم جَنّاتِ النَّعيمِ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@dccxxxv{وَلَو أَنَّهُم أَقامُوا التَّوراةَ وَالإِنجيلَ وَما أُنزِلَ إِلَيهِم مِن رَبِّهِم لَأَكَلوا مِن فَوقِهِم وَمِن تَحتِ أَرجُلِهِم ۚ مِنهُم أُمَّةٌ مُقتَصِدَةٌ ۖ وَكَثيرٌ مِنهُم ساءَ ما يَعمَلونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@dccxxxvi{۞ يا أَيُّهَا الرَّسولُ بَلِّغ ما أُنزِلَ إِلَيكَ مِن رَبِّكَ ۖ وَإِن لَم تَفعَل فَما بَلَّغتَ رِسالَتَهُ ۚ وَاللَّهُ يَعصِمُكَ مِنَ النّاسِ ۗ إِنَّ اللَّهَ لا يَهدِي القَومَ الكافِرينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@dccxxxvii{قُل يا أَهلَ الكِتابِ لَستُم عَلىٰ شَيءٍ حَتّىٰ تُقيمُوا التَّوراةَ وَالإِنجيلَ وَما أُنزِلَ إِلَيكُم مِن رَبِّكُم ۗ وَلَيَزيدَنَّ كَثيرًا مِنهُم ما أُنزِلَ إِلَيكَ مِن رَبِّكَ طُغيانًا وَكُفرًا ۖ فَلا تَأسَ عَلَى القَومِ الكافِرينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@dccxxxviii{إِنَّ الَّذينَ آمَنوا وَالَّذينَ هادوا وَالصّابِئونَ وَالنَّصارىٰ مَن آمَنَ بِاللَّهِ وَاليَومِ الآخِرِ وَعَمِلَ صالِحًا فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@dccxxxix{لَقَد أَخَذنا ميثاقَ بَني إِسرائيلَ وَأَرسَلنا إِلَيهِم رُسُلًا ۖ كُلَّما جاءَهُم رَسولٌ بِما لا تَهوىٰ أَنفُسُهُم فَريقًا كَذَّبوا وَفَريقًا يَقتُلونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@dccxl{وَحَسِبوا أَلّا تَكونَ فِتنَةٌ فَعَموا وَصَمّوا ثُمَّ تابَ اللَّهُ عَلَيهِم ثُمَّ عَموا وَصَمّوا كَثيرٌ مِنهُم ۚ وَاللَّهُ بَصيرٌ بِما يَعمَلونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@dccxli{لَقَد كَفَرَ الَّذينَ قالوا إِنَّ اللَّهَ هُوَ المَسيحُ ابنُ مَريَمَ ۖ وَقالَ المَسيحُ يا بَني إِسرائيلَ اعبُدُوا اللَّهَ رَبّي وَرَبَّكُم ۖ إِنَّهُ مَن يُشرِك بِاللَّهِ فَقَد حَرَّمَ اللَّهُ عَلَيهِ الجَنَّةَ وَمَأواهُ النّارُ ۖ وَما لِلظّالِمينَ مِن أَنصارٍ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@dccxlii{لَقَد كَفَرَ الَّذينَ قالوا إِنَّ اللَّهَ ثالِثُ ثَلاثَةٍ ۘ وَما مِن إِلٰهٍ إِلّا إِلٰهٌ واحِدٌ ۚ وَإِن لَم يَنتَهوا عَمّا يَقولونَ لَيَمَسَّنَّ الَّذينَ كَفَروا مِنهُم عَذابٌ أَليمٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@dccxliii{أَفَلا يَتوبونَ إِلَى اللَّهِ وَيَستَغفِرونَهُ ۚ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@dccxliv{مَا المَسيحُ ابنُ مَريَمَ إِلّا رَسولٌ قَد خَلَت مِن قَبلِهِ الرُّسُلُ وَأُمُّهُ صِدّيقَةٌ ۖ كانا يَأكُلانِ الطَّعامَ ۗ انظُر كَيفَ نُبَيِّنُ لَهُمُ الآياتِ ثُمَّ انظُر أَنّىٰ يُؤفَكونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@dccxlv{قُل أَتَعبُدونَ مِن دونِ اللَّهِ ما لا يَملِكُ لَكُم ضَرًّا وَلا نَفعًا ۚ وَاللَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@dccxlvi{قُل يا أَهلَ الكِتابِ لا تَغلوا في دينِكُم غَيرَ الحَقِّ وَلا تَتَّبِعوا أَهواءَ قَومٍ قَد ضَلّوا مِن قَبلُ وَأَضَلّوا كَثيرًا وَضَلّوا عَن سَواءِ السَّبيلِ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@dccxlvii{لُعِنَ الَّذينَ كَفَروا مِن بَني إِسرائيلَ عَلىٰ لِسانِ داوودَ وَعيسَى ابنِ مَريَمَ ۚ ذٰلِكَ بِما عَصَوا وَكانوا يَعتَدونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@dccxlviii{كانوا لا يَتَناهَونَ عَن مُنكَرٍ فَعَلوهُ ۚ لَبِئسَ ما كانوا يَفعَلونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@dccxlix{تَرىٰ كَثيرًا مِنهُم يَتَوَلَّونَ الَّذينَ كَفَروا ۚ لَبِئسَ ما قَدَّمَت لَهُم أَنفُسُهُم أَن سَخِطَ اللَّهُ عَلَيهِم وَفِي العَذابِ هُم خالِدونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@dccl{وَلَو كانوا يُؤمِنونَ بِاللَّهِ وَالنَّبِيِّ وَما أُنزِلَ إِلَيهِ مَا اتَّخَذوهُم أَولِياءَ وَلٰكِنَّ كَثيرًا مِنهُم فاسِقونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@dccli{۞ لَتَجِدَنَّ أَشَدَّ النّاسِ عَداوَةً لِلَّذينَ آمَنُوا اليَهودَ وَالَّذينَ أَشرَكوا ۖ وَلَتَجِدَنَّ أَقرَبَهُم مَوَدَّةً لِلَّذينَ آمَنُوا الَّذينَ قالوا إِنّا نَصارىٰ ۚ ذٰلِكَ بِأَنَّ مِنهُم قِسّيسينَ وَرُهبانًا وَأَنَّهُم لا يَستَكبِرونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@dcclii{وَإِذا سَمِعوا ما أُنزِلَ إِلَى الرَّسولِ تَرىٰ أَعيُنَهُم تَفيضُ مِنَ الدَّمعِ مِمّا عَرَفوا مِنَ الحَقِّ ۖ يَقولونَ رَبَّنا آمَنّا فَاكتُبنا مَعَ الشّاهِدينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@dccliii{وَما لَنا لا نُؤمِنُ بِاللَّهِ وَما جاءَنا مِنَ الحَقِّ وَنَطمَعُ أَن يُدخِلَنا رَبُّنا مَعَ القَومِ الصّالِحينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@dccliv{فَأَثابَهُمُ اللَّهُ بِما قالوا جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها ۚ وَذٰلِكَ جَزاءُ المُحسِنينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@dcclv{وَالَّذينَ كَفَروا وَكَذَّبوا بِآياتِنا أُولٰئِكَ أَصحابُ الجَحيمِ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@dcclvi{يا أَيُّهَا الَّذينَ آمَنوا لا تُحَرِّموا طَيِّباتِ ما أَحَلَّ اللَّهُ لَكُم وَلا تَعتَدوا ۚ إِنَّ اللَّهَ لا يُحِبُّ المُعتَدينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@dcclvii{وَكُلوا مِمّا رَزَقَكُمُ اللَّهُ حَلالًا طَيِّبًا ۚ وَاتَّقُوا اللَّهَ الَّذي أَنتُم بِهِ مُؤمِنونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@dcclviii{لا يُؤاخِذُكُمُ اللَّهُ بِاللَّغوِ في أَيمانِكُم وَلٰكِن يُؤاخِذُكُم بِما عَقَّدتُمُ الأَيمانَ ۖ فَكَفّارَتُهُ إِطعامُ عَشَرَةِ مَساكينَ مِن أَوسَطِ ما تُطعِمونَ أَهليكُم أَو كِسوَتُهُم أَو تَحريرُ رَقَبَةٍ ۖ فَمَن لَم يَجِد فَصِيامُ ثَلاثَةِ أَيّامٍ ۚ ذٰلِكَ كَفّارَةُ أَيمانِكُم إِذا حَلَفتُم ۚ وَاحفَظوا أَيمانَكُم ۚ كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُم آياتِهِ لَعَلَّكُم تَشكُرونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@dcclix{يا أَيُّهَا الَّذينَ آمَنوا إِنَّمَا الخَمرُ وَالمَيسِرُ وَالأَنصابُ وَالأَزلامُ رِجسٌ مِن عَمَلِ الشَّيطانِ فَاجتَنِبوهُ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@dcclx{إِنَّما يُريدُ الشَّيطانُ أَن يوقِعَ بَينَكُمُ العَداوَةَ وَالبَغضاءَ فِي الخَمرِ وَالمَيسِرِ وَيَصُدَّكُم عَن ذِكرِ اللَّهِ وَعَنِ الصَّلاةِ ۖ فَهَل أَنتُم مُنتَهونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@dcclxi{وَأَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ وَاحذَروا ۚ فَإِن تَوَلَّيتُم فَاعلَموا أَنَّما عَلىٰ رَسولِنَا البَلاغُ المُبينُ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@dcclxii{لَيسَ عَلَى الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ جُناحٌ فيما طَعِموا إِذا مَا اتَّقَوا وَآمَنوا وَعَمِلُوا الصّالِحاتِ ثُمَّ اتَّقَوا وَآمَنوا ثُمَّ اتَّقَوا وَأَحسَنوا ۗ وَاللَّهُ يُحِبُّ المُحسِنينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@dcclxiii{يا أَيُّهَا الَّذينَ آمَنوا لَيَبلُوَنَّكُمُ اللَّهُ بِشَيءٍ مِنَ الصَّيدِ تَنالُهُ أَيديكُم وَرِماحُكُم لِيَعلَمَ اللَّهُ مَن يَخافُهُ بِالغَيبِ ۚ فَمَنِ اعتَدىٰ بَعدَ ذٰلِكَ فَلَهُ عَذابٌ أَليمٌ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@dcclxiv{يا أَيُّهَا الَّذينَ آمَنوا لا تَقتُلُوا الصَّيدَ وَأَنتُم حُرُمٌ ۚ وَمَن قَتَلَهُ مِنكُم مُتَعَمِّدًا فَجَزاءٌ مِثلُ ما قَتَلَ مِنَ النَّعَمِ يَحكُمُ بِهِ ذَوا عَدلٍ مِنكُم هَديًا بالِغَ الكَعبَةِ أَو كَفّارَةٌ طَعامُ مَساكينَ أَو عَدلُ ذٰلِكَ صِيامًا لِيَذوقَ وَبالَ أَمرِهِ ۗ عَفَا اللَّهُ عَمّا سَلَفَ ۚ وَمَن عادَ فَيَنتَقِمُ اللَّهُ مِنهُ ۗ وَاللَّهُ عَزيزٌ ذُو انتِقامٍ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@dcclxv{أُحِلَّ لَكُم صَيدُ البَحرِ وَطَعامُهُ مَتاعًا لَكُم وَلِلسَّيّارَةِ ۖ وَحُرِّمَ عَلَيكُم صَيدُ البَرِّ ما دُمتُم حُرُمًا ۗ وَاتَّقُوا اللَّهَ الَّذي إِلَيهِ تُحشَرونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@dcclxvi{۞ جَعَلَ اللَّهُ الكَعبَةَ البَيتَ الحَرامَ قِيامًا لِلنّاسِ وَالشَّهرَ الحَرامَ وَالهَديَ وَالقَلائِدَ ۚ ذٰلِكَ لِتَعلَموا أَنَّ اللَّهَ يَعلَمُ ما فِي السَّماواتِ وَما فِي الأَرضِ وَأَنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@dcclxvii{اعلَموا أَنَّ اللَّهَ شَديدُ العِقابِ وَأَنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@dcclxviii{ما عَلَى الرَّسولِ إِلَّا البَلاغُ ۗ وَاللَّهُ يَعلَمُ ما تُبدونَ وَما تَكتُمونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@dcclxix{قُل لا يَستَوِي الخَبيثُ وَالطَّيِّبُ وَلَو أَعجَبَكَ كَثرَةُ الخَبيثِ ۚ فَاتَّقُوا اللَّهَ يا أُولِي الأَلبابِ لَعَلَّكُم تُفلِحونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@dcclxx{يا أَيُّهَا الَّذينَ آمَنوا لا تَسأَلوا عَن أَشياءَ إِن تُبدَ لَكُم تَسُؤكُم وَإِن تَسأَلوا عَنها حينَ يُنَزَّلُ القُرآنُ تُبدَ لَكُم عَفَا اللَّهُ عَنها ۗ وَاللَّهُ غَفورٌ حَليمٌ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@dcclxxi{قَد سَأَلَها قَومٌ مِن قَبلِكُم ثُمَّ أَصبَحوا بِها كافِرينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@dcclxxii{ما جَعَلَ اللَّهُ مِن بَحيرَةٍ وَلا سائِبَةٍ وَلا وَصيلَةٍ وَلا حامٍ ۙ وَلٰكِنَّ الَّذينَ كَفَروا يَفتَرونَ عَلَى اللَّهِ الكَذِبَ ۖ وَأَكثَرُهُم لا يَعقِلونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@dcclxxiii{وَإِذا قيلَ لَهُم تَعالَوا إِلىٰ ما أَنزَلَ اللَّهُ وَإِلَى الرَّسولِ قالوا حَسبُنا ما وَجَدنا عَلَيهِ آباءَنا ۚ أَوَلَو كانَ آباؤُهُم لا يَعلَمونَ شَيئًا وَلا يَهتَدونَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@dcclxxiv{يا أَيُّهَا الَّذينَ آمَنوا عَلَيكُم أَنفُسَكُم ۖ لا يَضُرُّكُم مَن ضَلَّ إِذَا اهتَدَيتُم ۚ إِلَى اللَّهِ مَرجِعُكُم جَميعًا فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@dcclxxv{يا أَيُّهَا الَّذينَ آمَنوا شَهادَةُ بَينِكُم إِذا حَضَرَ أَحَدَكُمُ المَوتُ حينَ الوَصِيَّةِ اثنانِ ذَوا عَدلٍ مِنكُم أَو آخَرانِ مِن غَيرِكُم إِن أَنتُم ضَرَبتُم فِي الأَرضِ فَأَصابَتكُم مُصيبَةُ المَوتِ ۚ تَحبِسونَهُما مِن بَعدِ الصَّلاةِ فَيُقسِمانِ بِاللَّهِ إِنِ ارتَبتُم لا نَشتَري بِهِ ثَمَنًا وَلَو كانَ ذا قُربىٰ ۙ وَلا نَكتُمُ شَهادَةَ اللَّهِ إِنّا إِذًا لَمِنَ الآثِمينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@dcclxxvi{فَإِن عُثِرَ عَلىٰ أَنَّهُمَا استَحَقّا إِثمًا فَآخَرانِ يَقومانِ مَقامَهُما مِنَ الَّذينَ استَحَقَّ عَلَيهِمُ الأَولَيانِ فَيُقسِمانِ بِاللَّهِ لَشَهادَتُنا أَحَقُّ مِن شَهادَتِهِما وَمَا اعتَدَينا إِنّا إِذًا لَمِنَ الظّالِمينَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@dcclxxvii{ذٰلِكَ أَدنىٰ أَن يَأتوا بِالشَّهادَةِ عَلىٰ وَجهِها أَو يَخافوا أَن تُرَدَّ أَيمانٌ بَعدَ أَيمانِهِم ۗ وَاتَّقُوا اللَّهَ وَاسمَعوا ۗ وَاللَّهُ لا يَهدِي القَومَ الفاسِقينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@dcclxxviii{۞ يَومَ يَجمَعُ اللَّهُ الرُّسُلَ فَيَقولُ ماذا أُجِبتُم ۖ قالوا لا عِلمَ لَنا ۖ إِنَّكَ أَنتَ عَلّامُ الغُيوبِ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@dcclxxix{إِذ قالَ اللَّهُ يا عيسَى ابنَ مَريَمَ اذكُر نِعمَتي عَلَيكَ وَعَلىٰ والِدَتِكَ إِذ أَيَّدتُكَ بِروحِ القُدُسِ تُكَلِّمُ النّاسَ فِي المَهدِ وَكَهلًا ۖ وَإِذ عَلَّمتُكَ الكِتابَ وَالحِكمَةَ وَالتَّوراةَ وَالإِنجيلَ ۖ وَإِذ تَخلُقُ مِنَ الطّينِ كَهَيئَةِ الطَّيرِ بِإِذني فَتَنفُخُ فيها فَتَكونُ طَيرًا بِإِذني ۖ وَتُبرِئُ الأَكمَهَ وَالأَبرَصَ بِإِذني ۖ وَإِذ تُخرِجُ المَوتىٰ بِإِذني ۖ وَإِذ كَفَفتُ بَني إِسرائيلَ عَنكَ إِذ جِئتَهُم بِالبَيِّناتِ فَقالَ الَّذينَ كَفَروا مِنهُم إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@dcclxxx{وَإِذ أَوحَيتُ إِلَى الحَوارِيّينَ أَن آمِنوا بي وَبِرَسولي قالوا آمَنّا وَاشهَد بِأَنَّنا مُسلِمونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@dcclxxxi{إِذ قالَ الحَوارِيّونَ يا عيسَى ابنَ مَريَمَ هَل يَستَطيعُ رَبُّكَ أَن يُنَزِّلَ عَلَينا مائِدَةً مِنَ السَّماءِ ۖ قالَ اتَّقُوا اللَّهَ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@dcclxxxii{قالوا نُريدُ أَن نَأكُلَ مِنها وَتَطمَئِنَّ قُلوبُنا وَنَعلَمَ أَن قَد صَدَقتَنا وَنَكونَ عَلَيها مِنَ الشّاهِدينَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@dcclxxxiii{قالَ عيسَى ابنُ مَريَمَ اللَّهُمَّ رَبَّنا أَنزِل عَلَينا مائِدَةً مِنَ السَّماءِ تَكونُ لَنا عيدًا لِأَوَّلِنا وَآخِرِنا وَآيَةً مِنكَ ۖ وَارزُقنا وَأَنتَ خَيرُ الرّازِقينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@dcclxxxiv{قالَ اللَّهُ إِنّي مُنَزِّلُها عَلَيكُم ۖ فَمَن يَكفُر بَعدُ مِنكُم فَإِنّي أُعَذِّبُهُ عَذابًا لا أُعَذِّبُهُ أَحَدًا مِنَ العالَمينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@dcclxxxv{وَإِذ قالَ اللَّهُ يا عيسَى ابنَ مَريَمَ أَأَنتَ قُلتَ لِلنّاسِ اتَّخِذوني وَأُمِّيَ إِلٰهَينِ مِن دونِ اللَّهِ ۖ قالَ سُبحانَكَ ما يَكونُ لي أَن أَقولَ ما لَيسَ لي بِحَقٍّ ۚ إِن كُنتُ قُلتُهُ فَقَد عَلِمتَهُ ۚ تَعلَمُ ما في نَفسي وَلا أَعلَمُ ما في نَفسِكَ ۚ إِنَّكَ أَنتَ عَلّامُ الغُيوبِ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@dcclxxxvi{ما قُلتُ لَهُم إِلّا ما أَمَرتَني بِهِ أَنِ اعبُدُوا اللَّهَ رَبّي وَرَبَّكُم ۚ وَكُنتُ عَلَيهِم شَهيدًا ما دُمتُ فيهِم ۖ فَلَمّا تَوَفَّيتَني كُنتَ أَنتَ الرَّقيبَ عَلَيهِم ۚ وَأَنتَ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@dcclxxxvii{إِن تُعَذِّبهُم فَإِنَّهُم عِبادُكَ ۖ وَإِن تَغفِر لَهُم فَإِنَّكَ أَنتَ العَزيزُ الحَكيمُ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@dcclxxxviii{قالَ اللَّهُ هٰذا يَومُ يَنفَعُ الصّادِقينَ صِدقُهُم ۚ لَهُم جَنّاتٌ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها أَبَدًا ۚ رَضِيَ اللَّهُ عَنهُم وَرَضوا عَنهُ ۚ ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@dcclxxxix{لِلَّهِ مُلكُ السَّماواتِ وَالأَرضِ وَما فيهِنَّ ۚ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@dccxc{\basmalah الحَمدُ لِلَّهِ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ وَجَعَلَ الظُّلُماتِ وَالنّورَ ۖ ثُمَّ الَّذينَ كَفَروا بِرَبِّهِم يَعدِلونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@dccxci{هُوَ الَّذي خَلَقَكُم مِن طينٍ ثُمَّ قَضىٰ أَجَلًا ۖ وَأَجَلٌ مُسَمًّى عِندَهُ ۖ ثُمَّ أَنتُم تَمتَرونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@dccxcii{وَهُوَ اللَّهُ فِي السَّماواتِ وَفِي الأَرضِ ۖ يَعلَمُ سِرَّكُم وَجَهرَكُم وَيَعلَمُ ما تَكسِبونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@dccxciii{وَما تَأتيهِم مِن آيَةٍ مِن آياتِ رَبِّهِم إِلّا كانوا عَنها مُعرِضينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@dccxciv{فَقَد كَذَّبوا بِالحَقِّ لَمّا جاءَهُم ۖ فَسَوفَ يَأتيهِم أَنباءُ ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@dccxcv{أَلَم يَرَوا كَم أَهلَكنا مِن قَبلِهِم مِن قَرنٍ مَكَّنّاهُم فِي الأَرضِ ما لَم نُمَكِّن لَكُم وَأَرسَلنَا السَّماءَ عَلَيهِم مِدرارًا وَجَعَلنَا الأَنهارَ تَجري مِن تَحتِهِم فَأَهلَكناهُم بِذُنوبِهِم وَأَنشَأنا مِن بَعدِهِم قَرنًا آخَرينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@dccxcvi{وَلَو نَزَّلنا عَلَيكَ كِتابًا في قِرطاسٍ فَلَمَسوهُ بِأَيديهِم لَقالَ الَّذينَ كَفَروا إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@dccxcvii{وَقالوا لَولا أُنزِلَ عَلَيهِ مَلَكٌ ۖ وَلَو أَنزَلنا مَلَكًا لَقُضِيَ الأَمرُ ثُمَّ لا يُنظَرونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@dccxcviii{وَلَو جَعَلناهُ مَلَكًا لَجَعَلناهُ رَجُلًا وَلَلَبَسنا عَلَيهِم ما يَلبِسونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@dccxcix{وَلَقَدِ استُهزِئَ بِرُسُلٍ مِن قَبلِكَ فَحاقَ بِالَّذينَ سَخِروا مِنهُم ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@dccc{قُل سيروا فِي الأَرضِ ثُمَّ انظُروا كَيفَ كانَ عاقِبَةُ المُكَذِّبينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@dccci{قُل لِمَن ما فِي السَّماواتِ وَالأَرضِ ۖ قُل لِلَّهِ ۚ كَتَبَ عَلىٰ نَفسِهِ الرَّحمَةَ ۚ لَيَجمَعَنَّكُم إِلىٰ يَومِ القِيامَةِ لا رَيبَ فيهِ ۚ الَّذينَ خَسِروا أَنفُسَهُم فَهُم لا يُؤمِنونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@dcccii{۞ وَلَهُ ما سَكَنَ فِي اللَّيلِ وَالنَّهارِ ۚ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@dccciii{قُل أَغَيرَ اللَّهِ أَتَّخِذُ وَلِيًّا فاطِرِ السَّماواتِ وَالأَرضِ وَهُوَ يُطعِمُ وَلا يُطعَمُ ۗ قُل إِنّي أُمِرتُ أَن أَكونَ أَوَّلَ مَن أَسلَمَ ۖ وَلا تَكونَنَّ مِنَ المُشرِكينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@dccciv{قُل إِنّي أَخافُ إِن عَصَيتُ رَبّي عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@dcccv{مَن يُصرَف عَنهُ يَومَئِذٍ فَقَد رَحِمَهُ ۚ وَذٰلِكَ الفَوزُ المُبينُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@dcccvi{وَإِن يَمسَسكَ اللَّهُ بِضُرٍّ فَلا كاشِفَ لَهُ إِلّا هُوَ ۖ وَإِن يَمسَسكَ بِخَيرٍ فَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@dcccvii{وَهُوَ القاهِرُ فَوقَ عِبادِهِ ۚ وَهُوَ الحَكيمُ الخَبيرُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@dcccviii{قُل أَيُّ شَيءٍ أَكبَرُ شَهادَةً ۖ قُلِ اللَّهُ ۖ شَهيدٌ بَيني وَبَينَكُم ۚ وَأوحِيَ إِلَيَّ هٰذَا القُرآنُ لِأُنذِرَكُم بِهِ وَمَن بَلَغَ ۚ أَئِنَّكُم لَتَشهَدونَ أَنَّ مَعَ اللَّهِ آلِهَةً أُخرىٰ ۚ قُل لا أَشهَدُ ۚ قُل إِنَّما هُوَ إِلٰهٌ واحِدٌ وَإِنَّني بَريءٌ مِمّا تُشرِكونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@dcccix{الَّذينَ آتَيناهُمُ الكِتابَ يَعرِفونَهُ كَما يَعرِفونَ أَبناءَهُمُ ۘ الَّذينَ خَسِروا أَنفُسَهُم فَهُم لا يُؤمِنونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@dcccx{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو كَذَّبَ بِآياتِهِ ۗ إِنَّهُ لا يُفلِحُ الظّالِمونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@dcccxi{وَيَومَ نَحشُرُهُم جَميعًا ثُمَّ نَقولُ لِلَّذينَ أَشرَكوا أَينَ شُرَكاؤُكُمُ الَّذينَ كُنتُم تَزعُمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@dcccxii{ثُمَّ لَم تَكُن فِتنَتُهُم إِلّا أَن قالوا وَاللَّهِ رَبِّنا ما كُنّا مُشرِكينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@dcccxiii{انظُر كَيفَ كَذَبوا عَلىٰ أَنفُسِهِم ۚ وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@dcccxiv{وَمِنهُم مَن يَستَمِعُ إِلَيكَ ۖ وَجَعَلنا عَلىٰ قُلوبِهِم أَكِنَّةً أَن يَفقَهوهُ وَفي آذانِهِم وَقرًا ۚ وَإِن يَرَوا كُلَّ آيَةٍ لا يُؤمِنوا بِها ۚ حَتّىٰ إِذا جاءوكَ يُجادِلونَكَ يَقولُ الَّذينَ كَفَروا إِن هٰذا إِلّا أَساطيرُ الأَوَّلينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@dcccxv{وَهُم يَنهَونَ عَنهُ وَيَنأَونَ عَنهُ ۖ وَإِن يُهلِكونَ إِلّا أَنفُسَهُم وَما يَشعُرونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@dcccxvi{وَلَو تَرىٰ إِذ وُقِفوا عَلَى النّارِ فَقالوا يا لَيتَنا نُرَدُّ وَلا نُكَذِّبَ بِآياتِ رَبِّنا وَنَكونَ مِنَ المُؤمِنينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@dcccxvii{بَل بَدا لَهُم ما كانوا يُخفونَ مِن قَبلُ ۖ وَلَو رُدّوا لَعادوا لِما نُهوا عَنهُ وَإِنَّهُم لَكاذِبونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@dcccxviii{وَقالوا إِن هِيَ إِلّا حَياتُنَا الدُّنيا وَما نَحنُ بِمَبعوثينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@dcccxix{وَلَو تَرىٰ إِذ وُقِفوا عَلىٰ رَبِّهِم ۚ قالَ أَلَيسَ هٰذا بِالحَقِّ ۚ قالوا بَلىٰ وَرَبِّنا ۚ قالَ فَذوقُوا العَذابَ بِما كُنتُم تَكفُرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@dcccxx{قَد خَسِرَ الَّذينَ كَذَّبوا بِلِقاءِ اللَّهِ ۖ حَتّىٰ إِذا جاءَتهُمُ السّاعَةُ بَغتَةً قالوا يا حَسرَتَنا عَلىٰ ما فَرَّطنا فيها وَهُم يَحمِلونَ أَوزارَهُم عَلىٰ ظُهورِهِم ۚ أَلا ساءَ ما يَزِرونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@dcccxxi{وَمَا الحَياةُ الدُّنيا إِلّا لَعِبٌ وَلَهوٌ ۖ وَلَلدّارُ الآخِرَةُ خَيرٌ لِلَّذينَ يَتَّقونَ ۗ أَفَلا تَعقِلونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@dcccxxii{قَد نَعلَمُ إِنَّهُ لَيَحزُنُكَ الَّذي يَقولونَ ۖ فَإِنَّهُم لا يُكَذِّبونَكَ وَلٰكِنَّ الظّالِمينَ بِآياتِ اللَّهِ يَجحَدونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@dcccxxiii{وَلَقَد كُذِّبَت رُسُلٌ مِن قَبلِكَ فَصَبَروا عَلىٰ ما كُذِّبوا وَأوذوا حَتّىٰ أَتاهُم نَصرُنا ۚ وَلا مُبَدِّلَ لِكَلِماتِ اللَّهِ ۚ وَلَقَد جاءَكَ مِن نَبَإِ المُرسَلينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@dcccxxiv{وَإِن كانَ كَبُرَ عَلَيكَ إِعراضُهُم فَإِنِ استَطَعتَ أَن تَبتَغِيَ نَفَقًا فِي الأَرضِ أَو سُلَّمًا فِي السَّماءِ فَتَأتِيَهُم بِآيَةٍ ۚ وَلَو شاءَ اللَّهُ لَجَمَعَهُم عَلَى الهُدىٰ ۚ فَلا تَكونَنَّ مِنَ الجاهِلينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@dcccxxv{۞ إِنَّما يَستَجيبُ الَّذينَ يَسمَعونَ ۘ وَالمَوتىٰ يَبعَثُهُمُ اللَّهُ ثُمَّ إِلَيهِ يُرجَعونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@dcccxxvi{وَقالوا لَولا نُزِّلَ عَلَيهِ آيَةٌ مِن رَبِّهِ ۚ قُل إِنَّ اللَّهَ قادِرٌ عَلىٰ أَن يُنَزِّلَ آيَةً وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@dcccxxvii{وَما مِن دابَّةٍ فِي الأَرضِ وَلا طائِرٍ يَطيرُ بِجَناحَيهِ إِلّا أُمَمٌ أَمثالُكُم ۚ ما فَرَّطنا فِي الكِتابِ مِن شَيءٍ ۚ ثُمَّ إِلىٰ رَبِّهِم يُحشَرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@dcccxxviii{وَالَّذينَ كَذَّبوا بِآياتِنا صُمٌّ وَبُكمٌ فِي الظُّلُماتِ ۗ مَن يَشَإِ اللَّهُ يُضلِلهُ وَمَن يَشَأ يَجعَلهُ عَلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@dcccxxix{قُل أَرَأَيتَكُم إِن أَتاكُم عَذابُ اللَّهِ أَو أَتَتكُمُ السّاعَةُ أَغَيرَ اللَّهِ تَدعونَ إِن كُنتُم صادِقينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@dcccxxx{بَل إِيّاهُ تَدعونَ فَيَكشِفُ ما تَدعونَ إِلَيهِ إِن شاءَ وَتَنسَونَ ما تُشرِكونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@dcccxxxi{وَلَقَد أَرسَلنا إِلىٰ أُمَمٍ مِن قَبلِكَ فَأَخَذناهُم بِالبَأساءِ وَالضَّرّاءِ لَعَلَّهُم يَتَضَرَّعونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@dcccxxxii{فَلَولا إِذ جاءَهُم بَأسُنا تَضَرَّعوا وَلٰكِن قَسَت قُلوبُهُم وَزَيَّنَ لَهُمُ الشَّيطانُ ما كانوا يَعمَلونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@dcccxxxiii{فَلَمّا نَسوا ما ذُكِّروا بِهِ فَتَحنا عَلَيهِم أَبوابَ كُلِّ شَيءٍ حَتّىٰ إِذا فَرِحوا بِما أوتوا أَخَذناهُم بَغتَةً فَإِذا هُم مُبلِسونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@dcccxxxiv{فَقُطِعَ دابِرُ القَومِ الَّذينَ ظَلَموا ۚ وَالحَمدُ لِلَّهِ رَبِّ العالَمينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@dcccxxxv{قُل أَرَأَيتُم إِن أَخَذَ اللَّهُ سَمعَكُم وَأَبصارَكُم وَخَتَمَ عَلىٰ قُلوبِكُم مَن إِلٰهٌ غَيرُ اللَّهِ يَأتيكُم بِهِ ۗ انظُر كَيفَ نُصَرِّفُ الآياتِ ثُمَّ هُم يَصدِفونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@dcccxxxvi{قُل أَرَأَيتَكُم إِن أَتاكُم عَذابُ اللَّهِ بَغتَةً أَو جَهرَةً هَل يُهلَكُ إِلَّا القَومُ الظّالِمونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@dcccxxxvii{وَما نُرسِلُ المُرسَلينَ إِلّا مُبَشِّرينَ وَمُنذِرينَ ۖ فَمَن آمَنَ وَأَصلَحَ فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@dcccxxxviii{وَالَّذينَ كَذَّبوا بِآياتِنا يَمَسُّهُمُ العَذابُ بِما كانوا يَفسُقونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@dcccxxxix{قُل لا أَقولُ لَكُم عِندي خَزائِنُ اللَّهِ وَلا أَعلَمُ الغَيبَ وَلا أَقولُ لَكُم إِنّي مَلَكٌ ۖ إِن أَتَّبِعُ إِلّا ما يوحىٰ إِلَيَّ ۚ قُل هَل يَستَوِي الأَعمىٰ وَالبَصيرُ ۚ أَفَلا تَتَفَكَّرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@dcccxl{وَأَنذِر بِهِ الَّذينَ يَخافونَ أَن يُحشَروا إِلىٰ رَبِّهِم ۙ لَيسَ لَهُم مِن دونِهِ وَلِيٌّ وَلا شَفيعٌ لَعَلَّهُم يَتَّقونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@dcccxli{وَلا تَطرُدِ الَّذينَ يَدعونَ رَبَّهُم بِالغَداةِ وَالعَشِيِّ يُريدونَ وَجهَهُ ۖ ما عَلَيكَ مِن حِسابِهِم مِن شَيءٍ وَما مِن حِسابِكَ عَلَيهِم مِن شَيءٍ فَتَطرُدَهُم فَتَكونَ مِنَ الظّالِمينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@dcccxlii{وَكَذٰلِكَ فَتَنّا بَعضَهُم بِبَعضٍ لِيَقولوا أَهٰؤُلاءِ مَنَّ اللَّهُ عَلَيهِم مِن بَينِنا ۗ أَلَيسَ اللَّهُ بِأَعلَمَ بِالشّاكِرينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@dcccxliii{وَإِذا جاءَكَ الَّذينَ يُؤمِنونَ بِآياتِنا فَقُل سَلامٌ عَلَيكُم ۖ كَتَبَ رَبُّكُم عَلىٰ نَفسِهِ الرَّحمَةَ ۖ أَنَّهُ مَن عَمِلَ مِنكُم سوءًا بِجَهالَةٍ ثُمَّ تابَ مِن بَعدِهِ وَأَصلَحَ فَأَنَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@dcccxliv{وَكَذٰلِكَ نُفَصِّلُ الآياتِ وَلِتَستَبينَ سَبيلُ المُجرِمينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@dcccxlv{قُل إِنّي نُهيتُ أَن أَعبُدَ الَّذينَ تَدعونَ مِن دونِ اللَّهِ ۚ قُل لا أَتَّبِعُ أَهواءَكُم ۙ قَد ضَلَلتُ إِذًا وَما أَنا مِنَ المُهتَدينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@dcccxlvi{قُل إِنّي عَلىٰ بَيِّنَةٍ مِن رَبّي وَكَذَّبتُم بِهِ ۚ ما عِندي ما تَستَعجِلونَ بِهِ ۚ إِنِ الحُكمُ إِلّا لِلَّهِ ۖ يَقُصُّ الحَقَّ ۖ وَهُوَ خَيرُ الفاصِلينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@dcccxlvii{قُل لَو أَنَّ عِندي ما تَستَعجِلونَ بِهِ لَقُضِيَ الأَمرُ بَيني وَبَينَكُم ۗ وَاللَّهُ أَعلَمُ بِالظّالِمينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@dcccxlviii{۞ وَعِندَهُ مَفاتِحُ الغَيبِ لا يَعلَمُها إِلّا هُوَ ۚ وَيَعلَمُ ما فِي البَرِّ وَالبَحرِ ۚ وَما تَسقُطُ مِن وَرَقَةٍ إِلّا يَعلَمُها وَلا حَبَّةٍ في ظُلُماتِ الأَرضِ وَلا رَطبٍ وَلا يابِسٍ إِلّا في كِتابٍ مُبينٍ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@dcccxlix{وَهُوَ الَّذي يَتَوَفّاكُم بِاللَّيلِ وَيَعلَمُ ما جَرَحتُم بِالنَّهارِ ثُمَّ يَبعَثُكُم فيهِ لِيُقضىٰ أَجَلٌ مُسَمًّى ۖ ثُمَّ إِلَيهِ مَرجِعُكُم ثُمَّ يُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@dcccl{وَهُوَ القاهِرُ فَوقَ عِبادِهِ ۖ وَيُرسِلُ عَلَيكُم حَفَظَةً حَتّىٰ إِذا جاءَ أَحَدَكُمُ المَوتُ تَوَفَّتهُ رُسُلُنا وَهُم لا يُفَرِّطونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@dcccli{ثُمَّ رُدّوا إِلَى اللَّهِ مَولاهُمُ الحَقِّ ۚ أَلا لَهُ الحُكمُ وَهُوَ أَسرَعُ الحاسِبينَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@dccclii{قُل مَن يُنَجّيكُم مِن ظُلُماتِ البَرِّ وَالبَحرِ تَدعونَهُ تَضَرُّعًا وَخُفيَةً لَئِن أَنجانا مِن هٰذِهِ لَنَكونَنَّ مِنَ الشّاكِرينَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@dcccliii{قُلِ اللَّهُ يُنَجّيكُم مِنها وَمِن كُلِّ كَربٍ ثُمَّ أَنتُم تُشرِكونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@dcccliv{قُل هُوَ القادِرُ عَلىٰ أَن يَبعَثَ عَلَيكُم عَذابًا مِن فَوقِكُم أَو مِن تَحتِ أَرجُلِكُم أَو يَلبِسَكُم شِيَعًا وَيُذيقَ بَعضَكُم بَأسَ بَعضٍ ۗ انظُر كَيفَ نُصَرِّفُ الآياتِ لَعَلَّهُم يَفقَهونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@dccclv{وَكَذَّبَ بِهِ قَومُكَ وَهُوَ الحَقُّ ۚ قُل لَستُ عَلَيكُم بِوَكيلٍ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@dccclvi{لِكُلِّ نَبَإٍ مُستَقَرٌّ ۚ وَسَوفَ تَعلَمونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@dccclvii{وَإِذا رَأَيتَ الَّذينَ يَخوضونَ في آياتِنا فَأَعرِض عَنهُم حَتّىٰ يَخوضوا في حَديثٍ غَيرِهِ ۚ وَإِمّا يُنسِيَنَّكَ الشَّيطانُ فَلا تَقعُد بَعدَ الذِّكرىٰ مَعَ القَومِ الظّالِمينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@dccclviii{وَما عَلَى الَّذينَ يَتَّقونَ مِن حِسابِهِم مِن شَيءٍ وَلٰكِن ذِكرىٰ لَعَلَّهُم يَتَّقونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@dccclix{وَذَرِ الَّذينَ اتَّخَذوا دينَهُم لَعِبًا وَلَهوًا وَغَرَّتهُمُ الحَياةُ الدُّنيا ۚ وَذَكِّر بِهِ أَن تُبسَلَ نَفسٌ بِما كَسَبَت لَيسَ لَها مِن دونِ اللَّهِ وَلِيٌّ وَلا شَفيعٌ وَإِن تَعدِل كُلَّ عَدلٍ لا يُؤخَذ مِنها ۗ أُولٰئِكَ الَّذينَ أُبسِلوا بِما كَسَبوا ۖ لَهُم شَرابٌ مِن حَميمٍ وَعَذابٌ أَليمٌ بِما كانوا يَكفُرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@dccclx{قُل أَنَدعو مِن دونِ اللَّهِ ما لا يَنفَعُنا وَلا يَضُرُّنا وَنُرَدُّ عَلىٰ أَعقابِنا بَعدَ إِذ هَدانَا اللَّهُ كَالَّذِي استَهوَتهُ الشَّياطينُ فِي الأَرضِ حَيرانَ لَهُ أَصحابٌ يَدعونَهُ إِلَى الهُدَى ائتِنا ۗ قُل إِنَّ هُدَى اللَّهِ هُوَ الهُدىٰ ۖ وَأُمِرنا لِنُسلِمَ لِرَبِّ العالَمينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@dccclxi{وَأَن أَقيمُوا الصَّلاةَ وَاتَّقوهُ ۚ وَهُوَ الَّذي إِلَيهِ تُحشَرونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@dccclxii{وَهُوَ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ بِالحَقِّ ۖ وَيَومَ يَقولُ كُن فَيَكونُ ۚ قَولُهُ الحَقُّ ۚ وَلَهُ المُلكُ يَومَ يُنفَخُ فِي الصّورِ ۚ عالِمُ الغَيبِ وَالشَّهادَةِ ۚ وَهُوَ الحَكيمُ الخَبيرُ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@dccclxiii{۞ وَإِذ قالَ إِبراهيمُ لِأَبيهِ آزَرَ أَتَتَّخِذُ أَصنامًا آلِهَةً ۖ إِنّي أَراكَ وَقَومَكَ في ضَلالٍ مُبينٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@dccclxiv{وَكَذٰلِكَ نُري إِبراهيمَ مَلَكوتَ السَّماواتِ وَالأَرضِ وَلِيَكونَ مِنَ الموقِنينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@dccclxv{فَلَمّا جَنَّ عَلَيهِ اللَّيلُ رَأىٰ كَوكَبًا ۖ قالَ هٰذا رَبّي ۖ فَلَمّا أَفَلَ قالَ لا أُحِبُّ الآفِلينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@dccclxvi{فَلَمّا رَأَى القَمَرَ بازِغًا قالَ هٰذا رَبّي ۖ فَلَمّا أَفَلَ قالَ لَئِن لَم يَهدِني رَبّي لَأَكونَنَّ مِنَ القَومِ الضّالّينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@dccclxvii{فَلَمّا رَأَى الشَّمسَ بازِغَةً قالَ هٰذا رَبّي هٰذا أَكبَرُ ۖ فَلَمّا أَفَلَت قالَ يا قَومِ إِنّي بَريءٌ مِمّا تُشرِكونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@dccclxviii{إِنّي وَجَّهتُ وَجهِيَ لِلَّذي فَطَرَ السَّماواتِ وَالأَرضَ حَنيفًا ۖ وَما أَنا مِنَ المُشرِكينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@dccclxix{وَحاجَّهُ قَومُهُ ۚ قالَ أَتُحاجّونّي فِي اللَّهِ وَقَد هَدانِ ۚ وَلا أَخافُ ما تُشرِكونَ بِهِ إِلّا أَن يَشاءَ رَبّي شَيئًا ۗ وَسِعَ رَبّي كُلَّ شَيءٍ عِلمًا ۗ أَفَلا تَتَذَكَّرونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@dccclxx{وَكَيفَ أَخافُ ما أَشرَكتُم وَلا تَخافونَ أَنَّكُم أَشرَكتُم بِاللَّهِ ما لَم يُنَزِّل بِهِ عَلَيكُم سُلطانًا ۚ فَأَيُّ الفَريقَينِ أَحَقُّ بِالأَمنِ ۖ إِن كُنتُم تَعلَمونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@dccclxxi{الَّذينَ آمَنوا وَلَم يَلبِسوا إيمانَهُم بِظُلمٍ أُولٰئِكَ لَهُمُ الأَمنُ وَهُم مُهتَدونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@dccclxxii{وَتِلكَ حُجَّتُنا آتَيناها إِبراهيمَ عَلىٰ قَومِهِ ۚ نَرفَعُ دَرَجاتٍ مَن نَشاءُ ۗ إِنَّ رَبَّكَ حَكيمٌ عَليمٌ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@dccclxxiii{وَوَهَبنا لَهُ إِسحاقَ وَيَعقوبَ ۚ كُلًّا هَدَينا ۚ وَنوحًا هَدَينا مِن قَبلُ ۖ وَمِن ذُرِّيَّتِهِ داوودَ وَسُلَيمانَ وَأَيّوبَ وَيوسُفَ وَموسىٰ وَهارونَ ۚ وَكَذٰلِكَ نَجزِي المُحسِنينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@dccclxxiv{وَزَكَرِيّا وَيَحيىٰ وَعيسىٰ وَإِلياسَ ۖ كُلٌّ مِنَ الصّالِحينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@dccclxxv{وَإِسماعيلَ وَاليَسَعَ وَيونُسَ وَلوطًا ۚ وَكُلًّا فَضَّلنا عَلَى العالَمينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@dccclxxvi{وَمِن آبائِهِم وَذُرِّيّاتِهِم وَإِخوانِهِم ۖ وَاجتَبَيناهُم وَهَدَيناهُم إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@dccclxxvii{ذٰلِكَ هُدَى اللَّهِ يَهدي بِهِ مَن يَشاءُ مِن عِبادِهِ ۚ وَلَو أَشرَكوا لَحَبِطَ عَنهُم ما كانوا يَعمَلونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@dccclxxviii{أُولٰئِكَ الَّذينَ آتَيناهُمُ الكِتابَ وَالحُكمَ وَالنُّبُوَّةَ ۚ فَإِن يَكفُر بِها هٰؤُلاءِ فَقَد وَكَّلنا بِها قَومًا لَيسوا بِها بِكافِرينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@dccclxxix{أُولٰئِكَ الَّذينَ هَدَى اللَّهُ ۖ فَبِهُداهُمُ اقتَدِه ۗ قُل لا أَسأَلُكُم عَلَيهِ أَجرًا ۖ إِن هُوَ إِلّا ذِكرىٰ لِلعالَمينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@dccclxxx{وَما قَدَرُوا اللَّهَ حَقَّ قَدرِهِ إِذ قالوا ما أَنزَلَ اللَّهُ عَلىٰ بَشَرٍ مِن شَيءٍ ۗ قُل مَن أَنزَلَ الكِتابَ الَّذي جاءَ بِهِ موسىٰ نورًا وَهُدًى لِلنّاسِ ۖ تَجعَلونَهُ قَراطيسَ تُبدونَها وَتُخفونَ كَثيرًا ۖ وَعُلِّمتُم ما لَم تَعلَموا أَنتُم وَلا آباؤُكُم ۖ قُلِ اللَّهُ ۖ ثُمَّ ذَرهُم في خَوضِهِم يَلعَبونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@dccclxxxi{وَهٰذا كِتابٌ أَنزَلناهُ مُبارَكٌ مُصَدِّقُ الَّذي بَينَ يَدَيهِ وَلِتُنذِرَ أُمَّ القُرىٰ وَمَن حَولَها ۚ وَالَّذينَ يُؤمِنونَ بِالآخِرَةِ يُؤمِنونَ بِهِ ۖ وَهُم عَلىٰ صَلاتِهِم يُحافِظونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@dccclxxxii{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو قالَ أوحِيَ إِلَيَّ وَلَم يوحَ إِلَيهِ شَيءٌ وَمَن قالَ سَأُنزِلُ مِثلَ ما أَنزَلَ اللَّهُ ۗ وَلَو تَرىٰ إِذِ الظّالِمونَ في غَمَراتِ المَوتِ وَالمَلائِكَةُ باسِطو أَيديهِم أَخرِجوا أَنفُسَكُمُ ۖ اليَومَ تُجزَونَ عَذابَ الهونِ بِما كُنتُم تَقولونَ عَلَى اللَّهِ غَيرَ الحَقِّ وَكُنتُم عَن آياتِهِ تَستَكبِرونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@dccclxxxiii{وَلَقَد جِئتُمونا فُرادىٰ كَما خَلَقناكُم أَوَّلَ مَرَّةٍ وَتَرَكتُم ما خَوَّلناكُم وَراءَ ظُهورِكُم ۖ وَما نَرىٰ مَعَكُم شُفَعاءَكُمُ الَّذينَ زَعَمتُم أَنَّهُم فيكُم شُرَكاءُ ۚ لَقَد تَقَطَّعَ بَينَكُم وَضَلَّ عَنكُم ما كُنتُم تَزعُمونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@dccclxxxiv{۞ إِنَّ اللَّهَ فالِقُ الحَبِّ وَالنَّوىٰ ۖ يُخرِجُ الحَيَّ مِنَ المَيِّتِ وَمُخرِجُ المَيِّتِ مِنَ الحَيِّ ۚ ذٰلِكُمُ اللَّهُ ۖ فَأَنّىٰ تُؤفَكونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@dccclxxxv{فالِقُ الإِصباحِ وَجَعَلَ اللَّيلَ سَكَنًا وَالشَّمسَ وَالقَمَرَ حُسبانًا ۚ ذٰلِكَ تَقديرُ العَزيزِ العَليمِ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@dccclxxxvi{وَهُوَ الَّذي جَعَلَ لَكُمُ النُّجومَ لِتَهتَدوا بِها في ظُلُماتِ البَرِّ وَالبَحرِ ۗ قَد فَصَّلنَا الآياتِ لِقَومٍ يَعلَمونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@dccclxxxvii{وَهُوَ الَّذي أَنشَأَكُم مِن نَفسٍ واحِدَةٍ فَمُستَقَرٌّ وَمُستَودَعٌ ۗ قَد فَصَّلنَا الآياتِ لِقَومٍ يَفقَهونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@dccclxxxviii{وَهُوَ الَّذي أَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجنا بِهِ نَباتَ كُلِّ شَيءٍ فَأَخرَجنا مِنهُ خَضِرًا نُخرِجُ مِنهُ حَبًّا مُتَراكِبًا وَمِنَ النَّخلِ مِن طَلعِها قِنوانٌ دانِيَةٌ وَجَنّاتٍ مِن أَعنابٍ وَالزَّيتونَ وَالرُّمّانَ مُشتَبِهًا وَغَيرَ مُتَشابِهٍ ۗ انظُروا إِلىٰ ثَمَرِهِ إِذا أَثمَرَ وَيَنعِهِ ۚ إِنَّ في ذٰلِكُم لَآياتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@dccclxxxix{وَجَعَلوا لِلَّهِ شُرَكاءَ الجِنَّ وَخَلَقَهُم ۖ وَخَرَقوا لَهُ بَنينَ وَبَناتٍ بِغَيرِ عِلمٍ ۚ سُبحانَهُ وَتَعالىٰ عَمّا يَصِفونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@dcccxc{بَديعُ السَّماواتِ وَالأَرضِ ۖ أَنّىٰ يَكونُ لَهُ وَلَدٌ وَلَم تَكُن لَهُ صاحِبَةٌ ۖ وَخَلَقَ كُلَّ شَيءٍ ۖ وَهُوَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@dcccxci{ذٰلِكُمُ اللَّهُ رَبُّكُم ۖ لا إِلٰهَ إِلّا هُوَ ۖ خالِقُ كُلِّ شَيءٍ فَاعبُدوهُ ۚ وَهُوَ عَلىٰ كُلِّ شَيءٍ وَكيلٌ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@dcccxcii{لا تُدرِكُهُ الأَبصارُ وَهُوَ يُدرِكُ الأَبصارَ ۖ وَهُوَ اللَّطيفُ الخَبيرُ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@dcccxciii{قَد جاءَكُم بَصائِرُ مِن رَبِّكُم ۖ فَمَن أَبصَرَ فَلِنَفسِهِ ۖ وَمَن عَمِيَ فَعَلَيها ۚ وَما أَنا عَلَيكُم بِحَفيظٍ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@dcccxciv{وَكَذٰلِكَ نُصَرِّفُ الآياتِ وَلِيَقولوا دَرَستَ وَلِنُبَيِّنَهُ لِقَومٍ يَعلَمونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@dcccxcv{اتَّبِع ما أوحِيَ إِلَيكَ مِن رَبِّكَ ۖ لا إِلٰهَ إِلّا هُوَ ۖ وَأَعرِض عَنِ المُشرِكينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@dcccxcvi{وَلَو شاءَ اللَّهُ ما أَشرَكوا ۗ وَما جَعَلناكَ عَلَيهِم حَفيظًا ۖ وَما أَنتَ عَلَيهِم بِوَكيلٍ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@dcccxcvii{وَلا تَسُبُّوا الَّذينَ يَدعونَ مِن دونِ اللَّهِ فَيَسُبُّوا اللَّهَ عَدوًا بِغَيرِ عِلمٍ ۗ كَذٰلِكَ زَيَّنّا لِكُلِّ أُمَّةٍ عَمَلَهُم ثُمَّ إِلىٰ رَبِّهِم مَرجِعُهُم فَيُنَبِّئُهُم بِما كانوا يَعمَلونَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@dcccxcviii{وَأَقسَموا بِاللَّهِ جَهدَ أَيمانِهِم لَئِن جاءَتهُم آيَةٌ لَيُؤمِنُنَّ بِها ۚ قُل إِنَّمَا الآياتُ عِندَ اللَّهِ ۖ وَما يُشعِرُكُم أَنَّها إِذا جاءَت لا يُؤمِنونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@dcccxcix{وَنُقَلِّبُ أَفئِدَتَهُم وَأَبصارَهُم كَما لَم يُؤمِنوا بِهِ أَوَّلَ مَرَّةٍ وَنَذَرُهُم في طُغيانِهِم يَعمَهونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@cm{۞ وَلَو أَنَّنا نَزَّلنا إِلَيهِمُ المَلائِكَةَ وَكَلَّمَهُمُ المَوتىٰ وَحَشَرنا عَلَيهِم كُلَّ شَيءٍ قُبُلًا ما كانوا لِيُؤمِنوا إِلّا أَن يَشاءَ اللَّهُ وَلٰكِنَّ أَكثَرَهُم يَجهَلونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@cmi{وَكَذٰلِكَ جَعَلنا لِكُلِّ نَبِيٍّ عَدُوًّا شَياطينَ الإِنسِ وَالجِنِّ يوحي بَعضُهُم إِلىٰ بَعضٍ زُخرُفَ القَولِ غُرورًا ۚ وَلَو شاءَ رَبُّكَ ما فَعَلوهُ ۖ فَذَرهُم وَما يَفتَرونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@cmii{وَلِتَصغىٰ إِلَيهِ أَفئِدَةُ الَّذينَ لا يُؤمِنونَ بِالآخِرَةِ وَلِيَرضَوهُ وَلِيَقتَرِفوا ما هُم مُقتَرِفونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@cmiii{أَفَغَيرَ اللَّهِ أَبتَغي حَكَمًا وَهُوَ الَّذي أَنزَلَ إِلَيكُمُ الكِتابَ مُفَصَّلًا ۚ وَالَّذينَ آتَيناهُمُ الكِتابَ يَعلَمونَ أَنَّهُ مُنَزَّلٌ مِن رَبِّكَ بِالحَقِّ ۖ فَلا تَكونَنَّ مِنَ المُمتَرينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@cmiv{وَتَمَّت كَلِمَتُ رَبِّكَ صِدقًا وَعَدلًا ۚ لا مُبَدِّلَ لِكَلِماتِهِ ۚ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@cmv{وَإِن تُطِع أَكثَرَ مَن فِي الأَرضِ يُضِلّوكَ عَن سَبيلِ اللَّهِ ۚ إِن يَتَّبِعونَ إِلَّا الظَّنَّ وَإِن هُم إِلّا يَخرُصونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@cmvi{إِنَّ رَبَّكَ هُوَ أَعلَمُ مَن يَضِلُّ عَن سَبيلِهِ ۖ وَهُوَ أَعلَمُ بِالمُهتَدينَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@cmvii{فَكُلوا مِمّا ذُكِرَ اسمُ اللَّهِ عَلَيهِ إِن كُنتُم بِآياتِهِ مُؤمِنينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@cmviii{وَما لَكُم أَلّا تَأكُلوا مِمّا ذُكِرَ اسمُ اللَّهِ عَلَيهِ وَقَد فَصَّلَ لَكُم ما حَرَّمَ عَلَيكُم إِلّا مَا اضطُرِرتُم إِلَيهِ ۗ وَإِنَّ كَثيرًا لَيُضِلّونَ بِأَهوائِهِم بِغَيرِ عِلمٍ ۗ إِنَّ رَبَّكَ هُوَ أَعلَمُ بِالمُعتَدينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@cmix{وَذَروا ظاهِرَ الإِثمِ وَباطِنَهُ ۚ إِنَّ الَّذينَ يَكسِبونَ الإِثمَ سَيُجزَونَ بِما كانوا يَقتَرِفونَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@cmx{وَلا تَأكُلوا مِمّا لَم يُذكَرِ اسمُ اللَّهِ عَلَيهِ وَإِنَّهُ لَفِسقٌ ۗ وَإِنَّ الشَّياطينَ لَيوحونَ إِلىٰ أَولِيائِهِم لِيُجادِلوكُم ۖ وَإِن أَطَعتُموهُم إِنَّكُم لَمُشرِكونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@cmxi{أَوَمَن كانَ مَيتًا فَأَحيَيناهُ وَجَعَلنا لَهُ نورًا يَمشي بِهِ فِي النّاسِ كَمَن مَثَلُهُ فِي الظُّلُماتِ لَيسَ بِخارِجٍ مِنها ۚ كَذٰلِكَ زُيِّنَ لِلكافِرينَ ما كانوا يَعمَلونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@cmxii{وَكَذٰلِكَ جَعَلنا في كُلِّ قَريَةٍ أَكابِرَ مُجرِميها لِيَمكُروا فيها ۖ وَما يَمكُرونَ إِلّا بِأَنفُسِهِم وَما يَشعُرونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@cmxiii{وَإِذا جاءَتهُم آيَةٌ قالوا لَن نُؤمِنَ حَتّىٰ نُؤتىٰ مِثلَ ما أوتِيَ رُسُلُ اللَّهِ ۘ اللَّهُ أَعلَمُ حَيثُ يَجعَلُ رِسالَتَهُ ۗ سَيُصيبُ الَّذينَ أَجرَموا صَغارٌ عِندَ اللَّهِ وَعَذابٌ شَديدٌ بِما كانوا يَمكُرونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@cmxiv{فَمَن يُرِدِ اللَّهُ أَن يَهدِيَهُ يَشرَح صَدرَهُ لِلإِسلامِ ۖ وَمَن يُرِد أَن يُضِلَّهُ يَجعَل صَدرَهُ ضَيِّقًا حَرَجًا كَأَنَّما يَصَّعَّدُ فِي السَّماءِ ۚ كَذٰلِكَ يَجعَلُ اللَّهُ الرِّجسَ عَلَى الَّذينَ لا يُؤمِنونَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@cmxv{وَهٰذا صِراطُ رَبِّكَ مُستَقيمًا ۗ قَد فَصَّلنَا الآياتِ لِقَومٍ يَذَّكَّرونَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@cmxvi{۞ لَهُم دارُ السَّلامِ عِندَ رَبِّهِم ۖ وَهُوَ وَلِيُّهُم بِما كانوا يَعمَلونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@cmxvii{وَيَومَ يَحشُرُهُم جَميعًا يا مَعشَرَ الجِنِّ قَدِ استَكثَرتُم مِنَ الإِنسِ ۖ وَقالَ أَولِياؤُهُم مِنَ الإِنسِ رَبَّنَا استَمتَعَ بَعضُنا بِبَعضٍ وَبَلَغنا أَجَلَنَا الَّذي أَجَّلتَ لَنا ۚ قالَ النّارُ مَثواكُم خالِدينَ فيها إِلّا ما شاءَ اللَّهُ ۗ إِنَّ رَبَّكَ حَكيمٌ عَليمٌ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@cmxviii{وَكَذٰلِكَ نُوَلّي بَعضَ الظّالِمينَ بَعضًا بِما كانوا يَكسِبونَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@cmxix{يا مَعشَرَ الجِنِّ وَالإِنسِ أَلَم يَأتِكُم رُسُلٌ مِنكُم يَقُصّونَ عَلَيكُم آياتي وَيُنذِرونَكُم لِقاءَ يَومِكُم هٰذا ۚ قالوا شَهِدنا عَلىٰ أَنفُسِنا ۖ وَغَرَّتهُمُ الحَياةُ الدُّنيا وَشَهِدوا عَلىٰ أَنفُسِهِم أَنَّهُم كانوا كافِرينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@cmxx{ذٰلِكَ أَن لَم يَكُن رَبُّكَ مُهلِكَ القُرىٰ بِظُلمٍ وَأَهلُها غافِلونَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@cmxxi{وَلِكُلٍّ دَرَجاتٌ مِمّا عَمِلوا ۚ وَما رَبُّكَ بِغافِلٍ عَمّا يَعمَلونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@cmxxii{وَرَبُّكَ الغَنِيُّ ذُو الرَّحمَةِ ۚ إِن يَشَأ يُذهِبكُم وَيَستَخلِف مِن بَعدِكُم ما يَشاءُ كَما أَنشَأَكُم مِن ذُرِّيَّةِ قَومٍ آخَرينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@cmxxiii{إِنَّ ما توعَدونَ لَآتٍ ۖ وَما أَنتُم بِمُعجِزينَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@cmxxiv{قُل يا قَومِ اعمَلوا عَلىٰ مَكانَتِكُم إِنّي عامِلٌ ۖ فَسَوفَ تَعلَمونَ مَن تَكونُ لَهُ عاقِبَةُ الدّارِ ۗ إِنَّهُ لا يُفلِحُ الظّالِمونَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@cmxxv{وَجَعَلوا لِلَّهِ مِمّا ذَرَأَ مِنَ الحَرثِ وَالأَنعامِ نَصيبًا فَقالوا هٰذا لِلَّهِ بِزَعمِهِم وَهٰذا لِشُرَكائِنا ۖ فَما كانَ لِشُرَكائِهِم فَلا يَصِلُ إِلَى اللَّهِ ۖ وَما كانَ لِلَّهِ فَهُوَ يَصِلُ إِلىٰ شُرَكائِهِم ۗ ساءَ ما يَحكُمونَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@cmxxvi{وَكَذٰلِكَ زَيَّنَ لِكَثيرٍ مِنَ المُشرِكينَ قَتلَ أَولادِهِم شُرَكاؤُهُم لِيُردوهُم وَلِيَلبِسوا عَلَيهِم دينَهُم ۖ وَلَو شاءَ اللَّهُ ما فَعَلوهُ ۖ فَذَرهُم وَما يَفتَرونَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@cmxxvii{وَقالوا هٰذِهِ أَنعامٌ وَحَرثٌ حِجرٌ لا يَطعَمُها إِلّا مَن نَشاءُ بِزَعمِهِم وَأَنعامٌ حُرِّمَت ظُهورُها وَأَنعامٌ لا يَذكُرونَ اسمَ اللَّهِ عَلَيهَا افتِراءً عَلَيهِ ۚ سَيَجزيهِم بِما كانوا يَفتَرونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@cmxxviii{وَقالوا ما في بُطونِ هٰذِهِ الأَنعامِ خالِصَةٌ لِذُكورِنا وَمُحَرَّمٌ عَلىٰ أَزواجِنا ۖ وَإِن يَكُن مَيتَةً فَهُم فيهِ شُرَكاءُ ۚ سَيَجزيهِم وَصفَهُم ۚ إِنَّهُ حَكيمٌ عَليمٌ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@cmxxix{قَد خَسِرَ الَّذينَ قَتَلوا أَولادَهُم سَفَهًا بِغَيرِ عِلمٍ وَحَرَّموا ما رَزَقَهُمُ اللَّهُ افتِراءً عَلَى اللَّهِ ۚ قَد ضَلّوا وَما كانوا مُهتَدينَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@cmxxx{۞ وَهُوَ الَّذي أَنشَأَ جَنّاتٍ مَعروشاتٍ وَغَيرَ مَعروشاتٍ وَالنَّخلَ وَالزَّرعَ مُختَلِفًا أُكُلُهُ وَالزَّيتونَ وَالرُّمّانَ مُتَشابِهًا وَغَيرَ مُتَشابِهٍ ۚ كُلوا مِن ثَمَرِهِ إِذا أَثمَرَ وَآتوا حَقَّهُ يَومَ حَصادِهِ ۖ وَلا تُسرِفوا ۚ إِنَّهُ لا يُحِبُّ المُسرِفينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@cmxxxi{وَمِنَ الأَنعامِ حَمولَةً وَفَرشًا ۚ كُلوا مِمّا رَزَقَكُمُ اللَّهُ وَلا تَتَّبِعوا خُطُواتِ الشَّيطانِ ۚ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@cmxxxii{ثَمانِيَةَ أَزواجٍ ۖ مِنَ الضَّأنِ اثنَينِ وَمِنَ المَعزِ اثنَينِ ۗ قُل آلذَّكَرَينِ حَرَّمَ أَمِ الأُنثَيَينِ أَمَّا اشتَمَلَت عَلَيهِ أَرحامُ الأُنثَيَينِ ۖ نَبِّئوني بِعِلمٍ إِن كُنتُم صادِقينَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@cmxxxiii{وَمِنَ الإِبِلِ اثنَينِ وَمِنَ البَقَرِ اثنَينِ ۗ قُل آلذَّكَرَينِ حَرَّمَ أَمِ الأُنثَيَينِ أَمَّا اشتَمَلَت عَلَيهِ أَرحامُ الأُنثَيَينِ ۖ أَم كُنتُم شُهَداءَ إِذ وَصّاكُمُ اللَّهُ بِهٰذا ۚ فَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا لِيُضِلَّ النّاسَ بِغَيرِ عِلمٍ ۗ إِنَّ اللَّهَ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@cmxxxiv{قُل لا أَجِدُ في ما أوحِيَ إِلَيَّ مُحَرَّمًا عَلىٰ طاعِمٍ يَطعَمُهُ إِلّا أَن يَكونَ مَيتَةً أَو دَمًا مَسفوحًا أَو لَحمَ خِنزيرٍ فَإِنَّهُ رِجسٌ أَو فِسقًا أُهِلَّ لِغَيرِ اللَّهِ بِهِ ۚ فَمَنِ اضطُرَّ غَيرَ باغٍ وَلا عادٍ فَإِنَّ رَبَّكَ غَفورٌ رَحيمٌ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@cmxxxv{وَعَلَى الَّذينَ هادوا حَرَّمنا كُلَّ ذي ظُفُرٍ ۖ وَمِنَ البَقَرِ وَالغَنَمِ حَرَّمنا عَلَيهِم شُحومَهُما إِلّا ما حَمَلَت ظُهورُهُما أَوِ الحَوايا أَو مَا اختَلَطَ بِعَظمٍ ۚ ذٰلِكَ جَزَيناهُم بِبَغيِهِم ۖ وَإِنّا لَصادِقونَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@cmxxxvi{فَإِن كَذَّبوكَ فَقُل رَبُّكُم ذو رَحمَةٍ واسِعَةٍ وَلا يُرَدُّ بَأسُهُ عَنِ القَومِ المُجرِمينَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@cmxxxvii{سَيَقولُ الَّذينَ أَشرَكوا لَو شاءَ اللَّهُ ما أَشرَكنا وَلا آباؤُنا وَلا حَرَّمنا مِن شَيءٍ ۚ كَذٰلِكَ كَذَّبَ الَّذينَ مِن قَبلِهِم حَتّىٰ ذاقوا بَأسَنا ۗ قُل هَل عِندَكُم مِن عِلمٍ فَتُخرِجوهُ لَنا ۖ إِن تَتَّبِعونَ إِلَّا الظَّنَّ وَإِن أَنتُم إِلّا تَخرُصونَ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@cmxxxviii{قُل فَلِلَّهِ الحُجَّةُ البالِغَةُ ۖ فَلَو شاءَ لَهَداكُم أَجمَعينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@cmxxxix{قُل هَلُمَّ شُهَداءَكُمُ الَّذينَ يَشهَدونَ أَنَّ اللَّهَ حَرَّمَ هٰذا ۖ فَإِن شَهِدوا فَلا تَشهَد مَعَهُم ۚ وَلا تَتَّبِع أَهواءَ الَّذينَ كَذَّبوا بِآياتِنا وَالَّذينَ لا يُؤمِنونَ بِالآخِرَةِ وَهُم بِرَبِّهِم يَعدِلونَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@cmxl{۞ قُل تَعالَوا أَتلُ ما حَرَّمَ رَبُّكُم عَلَيكُم ۖ أَلّا تُشرِكوا بِهِ شَيئًا ۖ وَبِالوالِدَينِ إِحسانًا ۖ وَلا تَقتُلوا أَولادَكُم مِن إِملاقٍ ۖ نَحنُ نَرزُقُكُم وَإِيّاهُم ۖ وَلا تَقرَبُوا الفَواحِشَ ما ظَهَرَ مِنها وَما بَطَنَ ۖ وَلا تَقتُلُوا النَّفسَ الَّتي حَرَّمَ اللَّهُ إِلّا بِالحَقِّ ۚ ذٰلِكُم وَصّاكُم بِهِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@cmxli{وَلا تَقرَبوا مالَ اليَتيمِ إِلّا بِالَّتي هِيَ أَحسَنُ حَتّىٰ يَبلُغَ أَشُدَّهُ ۖ وَأَوفُوا الكَيلَ وَالميزانَ بِالقِسطِ ۖ لا نُكَلِّفُ نَفسًا إِلّا وُسعَها ۖ وَإِذا قُلتُم فَاعدِلوا وَلَو كانَ ذا قُربىٰ ۖ وَبِعَهدِ اللَّهِ أَوفوا ۚ ذٰلِكُم وَصّاكُم بِهِ لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@cmxlii{وَأَنَّ هٰذا صِراطي مُستَقيمًا فَاتَّبِعوهُ ۖ وَلا تَتَّبِعُوا السُّبُلَ فَتَفَرَّقَ بِكُم عَن سَبيلِهِ ۚ ذٰلِكُم وَصّاكُم بِهِ لَعَلَّكُم تَتَّقونَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@cmxliii{ثُمَّ آتَينا موسَى الكِتابَ تَمامًا عَلَى الَّذي أَحسَنَ وَتَفصيلًا لِكُلِّ شَيءٍ وَهُدًى وَرَحمَةً لَعَلَّهُم بِلِقاءِ رَبِّهِم يُؤمِنونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@cmxliv{وَهٰذا كِتابٌ أَنزَلناهُ مُبارَكٌ فَاتَّبِعوهُ وَاتَّقوا لَعَلَّكُم تُرحَمونَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@cmxlv{أَن تَقولوا إِنَّما أُنزِلَ الكِتابُ عَلىٰ طائِفَتَينِ مِن قَبلِنا وَإِن كُنّا عَن دِراسَتِهِم لَغافِلينَ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@cmxlvi{أَو تَقولوا لَو أَنّا أُنزِلَ عَلَينَا الكِتابُ لَكُنّا أَهدىٰ مِنهُم ۚ فَقَد جاءَكُم بَيِّنَةٌ مِن رَبِّكُم وَهُدًى وَرَحمَةٌ ۚ فَمَن أَظلَمُ مِمَّن كَذَّبَ بِآياتِ اللَّهِ وَصَدَفَ عَنها ۗ سَنَجزِي الَّذينَ يَصدِفونَ عَن آياتِنا سوءَ العَذابِ بِما كانوا يَصدِفونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@cmxlvii{هَل يَنظُرونَ إِلّا أَن تَأتِيَهُمُ المَلائِكَةُ أَو يَأتِيَ رَبُّكَ أَو يَأتِيَ بَعضُ آياتِ رَبِّكَ ۗ يَومَ يَأتي بَعضُ آياتِ رَبِّكَ لا يَنفَعُ نَفسًا إيمانُها لَم تَكُن آمَنَت مِن قَبلُ أَو كَسَبَت في إيمانِها خَيرًا ۗ قُلِ انتَظِروا إِنّا مُنتَظِرونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@cmxlviii{إِنَّ الَّذينَ فَرَّقوا دينَهُم وَكانوا شِيَعًا لَستَ مِنهُم في شَيءٍ ۚ إِنَّما أَمرُهُم إِلَى اللَّهِ ثُمَّ يُنَبِّئُهُم بِما كانوا يَفعَلونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@cmxlix{مَن جاءَ بِالحَسَنَةِ فَلَهُ عَشرُ أَمثالِها ۖ وَمَن جاءَ بِالسَّيِّئَةِ فَلا يُجزىٰ إِلّا مِثلَها وَهُم لا يُظلَمونَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@cml{قُل إِنَّني هَداني رَبّي إِلىٰ صِراطٍ مُستَقيمٍ دينًا قِيَمًا مِلَّةَ إِبراهيمَ حَنيفًا ۚ وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@cmli{قُل إِنَّ صَلاتي وَنُسُكي وَمَحيايَ وَمَماتي لِلَّهِ رَبِّ العالَمينَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@cmlii{لا شَريكَ لَهُ ۖ وَبِذٰلِكَ أُمِرتُ وَأَنا أَوَّلُ المُسلِمينَ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@cmliii{قُل أَغَيرَ اللَّهِ أَبغي رَبًّا وَهُوَ رَبُّ كُلِّ شَيءٍ ۚ وَلا تَكسِبُ كُلُّ نَفسٍ إِلّا عَلَيها ۚ وَلا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ ۚ ثُمَّ إِلىٰ رَبِّكُم مَرجِعُكُم فَيُنَبِّئُكُم بِما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@cmliv{وَهُوَ الَّذي جَعَلَكُم خَلائِفَ الأَرضِ وَرَفَعَ بَعضَكُم فَوقَ بَعضٍ دَرَجاتٍ لِيَبلُوَكُم في ما آتاكُم ۗ إِنَّ رَبَّكَ سَريعُ العِقابِ وَإِنَّهُ لَغَفورٌ رَحيمٌ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@cmlv{\basmalah المص\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@cmlvi{كِتابٌ أُنزِلَ إِلَيكَ فَلا يَكُن في صَدرِكَ حَرَجٌ مِنهُ لِتُنذِرَ بِهِ وَذِكرىٰ لِلمُؤمِنينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@cmlvii{اتَّبِعوا ما أُنزِلَ إِلَيكُم مِن رَبِّكُم وَلا تَتَّبِعوا مِن دونِهِ أَولِياءَ ۗ قَليلًا ما تَذَكَّرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@cmlviii{وَكَم مِن قَريَةٍ أَهلَكناها فَجاءَها بَأسُنا بَياتًا أَو هُم قائِلونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@cmlix{فَما كانَ دَعواهُم إِذ جاءَهُم بَأسُنا إِلّا أَن قالوا إِنّا كُنّا ظالِمينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@cmlx{فَلَنَسأَلَنَّ الَّذينَ أُرسِلَ إِلَيهِم وَلَنَسأَلَنَّ المُرسَلينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@cmlxi{فَلَنَقُصَّنَّ عَلَيهِم بِعِلمٍ ۖ وَما كُنّا غائِبينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@cmlxii{وَالوَزنُ يَومَئِذٍ الحَقُّ ۚ فَمَن ثَقُلَت مَوازينُهُ فَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@cmlxiii{وَمَن خَفَّت مَوازينُهُ فَأُولٰئِكَ الَّذينَ خَسِروا أَنفُسَهُم بِما كانوا بِآياتِنا يَظلِمونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@cmlxiv{وَلَقَد مَكَّنّاكُم فِي الأَرضِ وَجَعَلنا لَكُم فيها مَعايِشَ ۗ قَليلًا ما تَشكُرونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@cmlxv{وَلَقَد خَلَقناكُم ثُمَّ صَوَّرناكُم ثُمَّ قُلنا لِلمَلائِكَةِ اسجُدوا لِآدَمَ فَسَجَدوا إِلّا إِبليسَ لَم يَكُن مِنَ السّاجِدينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@cmlxvi{قالَ ما مَنَعَكَ أَلّا تَسجُدَ إِذ أَمَرتُكَ ۖ قالَ أَنا خَيرٌ مِنهُ خَلَقتَني مِن نارٍ وَخَلَقتَهُ مِن طينٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@cmlxvii{قالَ فَاهبِط مِنها فَما يَكونُ لَكَ أَن تَتَكَبَّرَ فيها فَاخرُج إِنَّكَ مِنَ الصّاغِرينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@cmlxviii{قالَ أَنظِرني إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@cmlxix{قالَ إِنَّكَ مِنَ المُنظَرينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@cmlxx{قالَ فَبِما أَغوَيتَني لَأَقعُدَنَّ لَهُم صِراطَكَ المُستَقيمَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@cmlxxi{ثُمَّ لَآتِيَنَّهُم مِن بَينِ أَيديهِم وَمِن خَلفِهِم وَعَن أَيمانِهِم وَعَن شَمائِلِهِم ۖ وَلا تَجِدُ أَكثَرَهُم شاكِرينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@cmlxxii{قالَ اخرُج مِنها مَذءومًا مَدحورًا ۖ لَمَن تَبِعَكَ مِنهُم لَأَملَأَنَّ جَهَنَّمَ مِنكُم أَجمَعينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@cmlxxiii{وَيا آدَمُ اسكُن أَنتَ وَزَوجُكَ الجَنَّةَ فَكُلا مِن حَيثُ شِئتُما وَلا تَقرَبا هٰذِهِ الشَّجَرَةَ فَتَكونا مِنَ الظّالِمينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@cmlxxiv{فَوَسوَسَ لَهُمَا الشَّيطانُ لِيُبدِيَ لَهُما ما وورِيَ عَنهُما مِن سَوآتِهِما وَقالَ ما نَهاكُما رَبُّكُما عَن هٰذِهِ الشَّجَرَةِ إِلّا أَن تَكونا مَلَكَينِ أَو تَكونا مِنَ الخالِدينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@cmlxxv{وَقاسَمَهُما إِنّي لَكُما لَمِنَ النّاصِحينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@cmlxxvi{فَدَلّاهُما بِغُرورٍ ۚ فَلَمّا ذاقَا الشَّجَرَةَ بَدَت لَهُما سَوآتُهُما وَطَفِقا يَخصِفانِ عَلَيهِما مِن وَرَقِ الجَنَّةِ ۖ وَناداهُما رَبُّهُما أَلَم أَنهَكُما عَن تِلكُمَا الشَّجَرَةِ وَأَقُل لَكُما إِنَّ الشَّيطانَ لَكُما عَدُوٌّ مُبينٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@cmlxxvii{قالا رَبَّنا ظَلَمنا أَنفُسَنا وَإِن لَم تَغفِر لَنا وَتَرحَمنا لَنَكونَنَّ مِنَ الخاسِرينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@cmlxxviii{قالَ اهبِطوا بَعضُكُم لِبَعضٍ عَدُوٌّ ۖ وَلَكُم فِي الأَرضِ مُستَقَرٌّ وَمَتاعٌ إِلىٰ حينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@cmlxxix{قالَ فيها تَحيَونَ وَفيها تَموتونَ وَمِنها تُخرَجونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@cmlxxx{يا بَني آدَمَ قَد أَنزَلنا عَلَيكُم لِباسًا يُواري سَوآتِكُم وَريشًا ۖ وَلِباسُ التَّقوىٰ ذٰلِكَ خَيرٌ ۚ ذٰلِكَ مِن آياتِ اللَّهِ لَعَلَّهُم يَذَّكَّرونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@cmlxxxi{يا بَني آدَمَ لا يَفتِنَنَّكُمُ الشَّيطانُ كَما أَخرَجَ أَبَوَيكُم مِنَ الجَنَّةِ يَنزِعُ عَنهُما لِباسَهُما لِيُرِيَهُما سَوآتِهِما ۗ إِنَّهُ يَراكُم هُوَ وَقَبيلُهُ مِن حَيثُ لا تَرَونَهُم ۗ إِنّا جَعَلنَا الشَّياطينَ أَولِياءَ لِلَّذينَ لا يُؤمِنونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@cmlxxxii{وَإِذا فَعَلوا فاحِشَةً قالوا وَجَدنا عَلَيها آباءَنا وَاللَّهُ أَمَرَنا بِها ۗ قُل إِنَّ اللَّهَ لا يَأمُرُ بِالفَحشاءِ ۖ أَتَقولونَ عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@cmlxxxiii{قُل أَمَرَ رَبّي بِالقِسطِ ۖ وَأَقيموا وُجوهَكُم عِندَ كُلِّ مَسجِدٍ وَادعوهُ مُخلِصينَ لَهُ الدّينَ ۚ كَما بَدَأَكُم تَعودونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@cmlxxxiv{فَريقًا هَدىٰ وَفَريقًا حَقَّ عَلَيهِمُ الضَّلالَةُ ۗ إِنَّهُمُ اتَّخَذُوا الشَّياطينَ أَولِياءَ مِن دونِ اللَّهِ وَيَحسَبونَ أَنَّهُم مُهتَدونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@cmlxxxv{۞ يا بَني آدَمَ خُذوا زينَتَكُم عِندَ كُلِّ مَسجِدٍ وَكُلوا وَاشرَبوا وَلا تُسرِفوا ۚ إِنَّهُ لا يُحِبُّ المُسرِفينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@cmlxxxvi{قُل مَن حَرَّمَ زينَةَ اللَّهِ الَّتي أَخرَجَ لِعِبادِهِ وَالطَّيِّباتِ مِنَ الرِّزقِ ۚ قُل هِيَ لِلَّذينَ آمَنوا فِي الحَياةِ الدُّنيا خالِصَةً يَومَ القِيامَةِ ۗ كَذٰلِكَ نُفَصِّلُ الآياتِ لِقَومٍ يَعلَمونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@cmlxxxvii{قُل إِنَّما حَرَّمَ رَبِّيَ الفَواحِشَ ما ظَهَرَ مِنها وَما بَطَنَ وَالإِثمَ وَالبَغيَ بِغَيرِ الحَقِّ وَأَن تُشرِكوا بِاللَّهِ ما لَم يُنَزِّل بِهِ سُلطانًا وَأَن تَقولوا عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@cmlxxxviii{وَلِكُلِّ أُمَّةٍ أَجَلٌ ۖ فَإِذا جاءَ أَجَلُهُم لا يَستَأخِرونَ ساعَةً ۖ وَلا يَستَقدِمونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@cmlxxxix{يا بَني آدَمَ إِمّا يَأتِيَنَّكُم رُسُلٌ مِنكُم يَقُصّونَ عَلَيكُم آياتي ۙ فَمَنِ اتَّقىٰ وَأَصلَحَ فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@cmxc{وَالَّذينَ كَذَّبوا بِآياتِنا وَاستَكبَروا عَنها أُولٰئِكَ أَصحابُ النّارِ ۖ هُم فيها خالِدونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@cmxci{فَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو كَذَّبَ بِآياتِهِ ۚ أُولٰئِكَ يَنالُهُم نَصيبُهُم مِنَ الكِتابِ ۖ حَتّىٰ إِذا جاءَتهُم رُسُلُنا يَتَوَفَّونَهُم قالوا أَينَ ما كُنتُم تَدعونَ مِن دونِ اللَّهِ ۖ قالوا ضَلّوا عَنّا وَشَهِدوا عَلىٰ أَنفُسِهِم أَنَّهُم كانوا كافِرينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@cmxcii{قالَ ادخُلوا في أُمَمٍ قَد خَلَت مِن قَبلِكُم مِنَ الجِنِّ وَالإِنسِ فِي النّارِ ۖ كُلَّما دَخَلَت أُمَّةٌ لَعَنَت أُختَها ۖ حَتّىٰ إِذَا ادّارَكوا فيها جَميعًا قالَت أُخراهُم لِأولاهُم رَبَّنا هٰؤُلاءِ أَضَلّونا فَآتِهِم عَذابًا ضِعفًا مِنَ النّارِ ۖ قالَ لِكُلٍّ ضِعفٌ وَلٰكِن لا تَعلَمونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@cmxciii{وَقالَت أولاهُم لِأُخراهُم فَما كانَ لَكُم عَلَينا مِن فَضلٍ فَذوقُوا العَذابَ بِما كُنتُم تَكسِبونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@cmxciv{إِنَّ الَّذينَ كَذَّبوا بِآياتِنا وَاستَكبَروا عَنها لا تُفَتَّحُ لَهُم أَبوابُ السَّماءِ وَلا يَدخُلونَ الجَنَّةَ حَتّىٰ يَلِجَ الجَمَلُ في سَمِّ الخِياطِ ۚ وَكَذٰلِكَ نَجزِي المُجرِمينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@cmxcv{لَهُم مِن جَهَنَّمَ مِهادٌ وَمِن فَوقِهِم غَواشٍ ۚ وَكَذٰلِكَ نَجزِي الظّالِمينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@cmxcvi{وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لا نُكَلِّفُ نَفسًا إِلّا وُسعَها أُولٰئِكَ أَصحابُ الجَنَّةِ ۖ هُم فيها خالِدونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@cmxcvii{وَنَزَعنا ما في صُدورِهِم مِن غِلٍّ تَجري مِن تَحتِهِمُ الأَنهارُ ۖ وَقالُوا الحَمدُ لِلَّهِ الَّذي هَدانا لِهٰذا وَما كُنّا لِنَهتَدِيَ لَولا أَن هَدانَا اللَّهُ ۖ لَقَد جاءَت رُسُلُ رَبِّنا بِالحَقِّ ۖ وَنودوا أَن تِلكُمُ الجَنَّةُ أورِثتُموها بِما كُنتُم تَعمَلونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@cmxcviii{وَنادىٰ أَصحابُ الجَنَّةِ أَصحابَ النّارِ أَن قَد وَجَدنا ما وَعَدَنا رَبُّنا حَقًّا فَهَل وَجَدتُم ما وَعَدَ رَبُّكُم حَقًّا ۖ قالوا نَعَم ۚ فَأَذَّنَ مُؤَذِّنٌ بَينَهُم أَن لَعنَةُ اللَّهِ عَلَى الظّالِمينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@cmxcix{الَّذينَ يَصُدّونَ عَن سَبيلِ اللَّهِ وَيَبغونَها عِوَجًا وَهُم بِالآخِرَةِ كافِرونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@m{وَبَينَهُما حِجابٌ ۚ وَعَلَى الأَعرافِ رِجالٌ يَعرِفونَ كُلًّا بِسيماهُم ۚ وَنادَوا أَصحابَ الجَنَّةِ أَن سَلامٌ عَلَيكُم ۚ لَم يَدخُلوها وَهُم يَطمَعونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mi{۞ وَإِذا صُرِفَت أَبصارُهُم تِلقاءَ أَصحابِ النّارِ قالوا رَبَّنا لا تَجعَلنا مَعَ القَومِ الظّالِمينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mii{وَنادىٰ أَصحابُ الأَعرافِ رِجالًا يَعرِفونَهُم بِسيماهُم قالوا ما أَغنىٰ عَنكُم جَمعُكُم وَما كُنتُم تَستَكبِرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@miii{أَهٰؤُلاءِ الَّذينَ أَقسَمتُم لا يَنالُهُمُ اللَّهُ بِرَحمَةٍ ۚ ادخُلُوا الجَنَّةَ لا خَوفٌ عَلَيكُم وَلا أَنتُم تَحزَنونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@miv{وَنادىٰ أَصحابُ النّارِ أَصحابَ الجَنَّةِ أَن أَفيضوا عَلَينا مِنَ الماءِ أَو مِمّا رَزَقَكُمُ اللَّهُ ۚ قالوا إِنَّ اللَّهَ حَرَّمَهُما عَلَى الكافِرينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mv{الَّذينَ اتَّخَذوا دينَهُم لَهوًا وَلَعِبًا وَغَرَّتهُمُ الحَياةُ الدُّنيا ۚ فَاليَومَ نَنساهُم كَما نَسوا لِقاءَ يَومِهِم هٰذا وَما كانوا بِآياتِنا يَجحَدونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mvi{وَلَقَد جِئناهُم بِكِتابٍ فَصَّلناهُ عَلىٰ عِلمٍ هُدًى وَرَحمَةً لِقَومٍ يُؤمِنونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mvii{هَل يَنظُرونَ إِلّا تَأويلَهُ ۚ يَومَ يَأتي تَأويلُهُ يَقولُ الَّذينَ نَسوهُ مِن قَبلُ قَد جاءَت رُسُلُ رَبِّنا بِالحَقِّ فَهَل لَنا مِن شُفَعاءَ فَيَشفَعوا لَنا أَو نُرَدُّ فَنَعمَلَ غَيرَ الَّذي كُنّا نَعمَلُ ۚ قَد خَسِروا أَنفُسَهُم وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mviii{إِنَّ رَبَّكُمُ اللَّهُ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ في سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ يُغشِي اللَّيلَ النَّهارَ يَطلُبُهُ حَثيثًا وَالشَّمسَ وَالقَمَرَ وَالنُّجومَ مُسَخَّراتٍ بِأَمرِهِ ۗ أَلا لَهُ الخَلقُ وَالأَمرُ ۗ تَبارَكَ اللَّهُ رَبُّ العالَمينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mix{ادعوا رَبَّكُم تَضَرُّعًا وَخُفيَةً ۚ إِنَّهُ لا يُحِبُّ المُعتَدينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mx{وَلا تُفسِدوا فِي الأَرضِ بَعدَ إِصلاحِها وَادعوهُ خَوفًا وَطَمَعًا ۚ إِنَّ رَحمَتَ اللَّهِ قَريبٌ مِنَ المُحسِنينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mxi{وَهُوَ الَّذي يُرسِلُ الرِّياحَ بُشرًا بَينَ يَدَي رَحمَتِهِ ۖ حَتّىٰ إِذا أَقَلَّت سَحابًا ثِقالًا سُقناهُ لِبَلَدٍ مَيِّتٍ فَأَنزَلنا بِهِ الماءَ فَأَخرَجنا بِهِ مِن كُلِّ الثَّمَراتِ ۚ كَذٰلِكَ نُخرِجُ المَوتىٰ لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mxii{وَالبَلَدُ الطَّيِّبُ يَخرُجُ نَباتُهُ بِإِذنِ رَبِّهِ ۖ وَالَّذي خَبُثَ لا يَخرُجُ إِلّا نَكِدًا ۚ كَذٰلِكَ نُصَرِّفُ الآياتِ لِقَومٍ يَشكُرونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mxiii{لَقَد أَرسَلنا نوحًا إِلىٰ قَومِهِ فَقالَ يا قَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ إِنّي أَخافُ عَلَيكُم عَذابَ يَومٍ عَظيمٍ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mxiv{قالَ المَلَأُ مِن قَومِهِ إِنّا لَنَراكَ في ضَلالٍ مُبينٍ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mxv{قالَ يا قَومِ لَيسَ بي ضَلالَةٌ وَلٰكِنّي رَسولٌ مِن رَبِّ العالَمينَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mxvi{أُبَلِّغُكُم رِسالاتِ رَبّي وَأَنصَحُ لَكُم وَأَعلَمُ مِنَ اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mxvii{أَوَعَجِبتُم أَن جاءَكُم ذِكرٌ مِن رَبِّكُم عَلىٰ رَجُلٍ مِنكُم لِيُنذِرَكُم وَلِتَتَّقوا وَلَعَلَّكُم تُرحَمونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mxviii{فَكَذَّبوهُ فَأَنجَيناهُ وَالَّذينَ مَعَهُ فِي الفُلكِ وَأَغرَقنَا الَّذينَ كَذَّبوا بِآياتِنا ۚ إِنَّهُم كانوا قَومًا عَمينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mxix{۞ وَإِلىٰ عادٍ أَخاهُم هودًا ۗ قالَ يا قَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ ۚ أَفَلا تَتَّقونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mxx{قالَ المَلَأُ الَّذينَ كَفَروا مِن قَومِهِ إِنّا لَنَراكَ في سَفاهَةٍ وَإِنّا لَنَظُنُّكَ مِنَ الكاذِبينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mxxi{قالَ يا قَومِ لَيسَ بي سَفاهَةٌ وَلٰكِنّي رَسولٌ مِن رَبِّ العالَمينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mxxii{أُبَلِّغُكُم رِسالاتِ رَبّي وَأَنا لَكُم ناصِحٌ أَمينٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mxxiii{أَوَعَجِبتُم أَن جاءَكُم ذِكرٌ مِن رَبِّكُم عَلىٰ رَجُلٍ مِنكُم لِيُنذِرَكُم ۚ وَاذكُروا إِذ جَعَلَكُم خُلَفاءَ مِن بَعدِ قَومِ نوحٍ وَزادَكُم فِي الخَلقِ بَسطَةً ۖ فَاذكُروا آلاءَ اللَّهِ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mxxiv{قالوا أَجِئتَنا لِنَعبُدَ اللَّهَ وَحدَهُ وَنَذَرَ ما كانَ يَعبُدُ آباؤُنا ۖ فَأتِنا بِما تَعِدُنا إِن كُنتَ مِنَ الصّادِقينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mxxv{قالَ قَد وَقَعَ عَلَيكُم مِن رَبِّكُم رِجسٌ وَغَضَبٌ ۖ أَتُجادِلونَني في أَسماءٍ سَمَّيتُموها أَنتُم وَآباؤُكُم ما نَزَّلَ اللَّهُ بِها مِن سُلطانٍ ۚ فَانتَظِروا إِنّي مَعَكُم مِنَ المُنتَظِرينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mxxvi{فَأَنجَيناهُ وَالَّذينَ مَعَهُ بِرَحمَةٍ مِنّا وَقَطَعنا دابِرَ الَّذينَ كَذَّبوا بِآياتِنا ۖ وَما كانوا مُؤمِنينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mxxvii{وَإِلىٰ ثَمودَ أَخاهُم صالِحًا ۗ قالَ يا قَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ ۖ قَد جاءَتكُم بَيِّنَةٌ مِن رَبِّكُم ۖ هٰذِهِ ناقَةُ اللَّهِ لَكُم آيَةً ۖ فَذَروها تَأكُل في أَرضِ اللَّهِ ۖ وَلا تَمَسّوها بِسوءٍ فَيَأخُذَكُم عَذابٌ أَليمٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mxxviii{وَاذكُروا إِذ جَعَلَكُم خُلَفاءَ مِن بَعدِ عادٍ وَبَوَّأَكُم فِي الأَرضِ تَتَّخِذونَ مِن سُهولِها قُصورًا وَتَنحِتونَ الجِبالَ بُيوتًا ۖ فَاذكُروا آلاءَ اللَّهِ وَلا تَعثَوا فِي الأَرضِ مُفسِدينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mxxix{قالَ المَلَأُ الَّذينَ استَكبَروا مِن قَومِهِ لِلَّذينَ استُضعِفوا لِمَن آمَنَ مِنهُم أَتَعلَمونَ أَنَّ صالِحًا مُرسَلٌ مِن رَبِّهِ ۚ قالوا إِنّا بِما أُرسِلَ بِهِ مُؤمِنونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mxxx{قالَ الَّذينَ استَكبَروا إِنّا بِالَّذي آمَنتُم بِهِ كافِرونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mxxxi{فَعَقَرُوا النّاقَةَ وَعَتَوا عَن أَمرِ رَبِّهِم وَقالوا يا صالِحُ ائتِنا بِما تَعِدُنا إِن كُنتَ مِنَ المُرسَلينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mxxxii{فَأَخَذَتهُمُ الرَّجفَةُ فَأَصبَحوا في دارِهِم جاثِمينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mxxxiii{فَتَوَلّىٰ عَنهُم وَقالَ يا قَومِ لَقَد أَبلَغتُكُم رِسالَةَ رَبّي وَنَصَحتُ لَكُم وَلٰكِن لا تُحِبّونَ النّاصِحينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mxxxiv{وَلوطًا إِذ قالَ لِقَومِهِ أَتَأتونَ الفاحِشَةَ ما سَبَقَكُم بِها مِن أَحَدٍ مِنَ العالَمينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mxxxv{إِنَّكُم لَتَأتونَ الرِّجالَ شَهوَةً مِن دونِ النِّساءِ ۚ بَل أَنتُم قَومٌ مُسرِفونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mxxxvi{وَما كانَ جَوابَ قَومِهِ إِلّا أَن قالوا أَخرِجوهُم مِن قَريَتِكُم ۖ إِنَّهُم أُناسٌ يَتَطَهَّرونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mxxxvii{فَأَنجَيناهُ وَأَهلَهُ إِلَّا امرَأَتَهُ كانَت مِنَ الغابِرينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mxxxviii{وَأَمطَرنا عَلَيهِم مَطَرًا ۖ فَانظُر كَيفَ كانَ عاقِبَةُ المُجرِمينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mxxxix{وَإِلىٰ مَديَنَ أَخاهُم شُعَيبًا ۗ قالَ يا قَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ ۖ قَد جاءَتكُم بَيِّنَةٌ مِن رَبِّكُم ۖ فَأَوفُوا الكَيلَ وَالميزانَ وَلا تَبخَسُوا النّاسَ أَشياءَهُم وَلا تُفسِدوا فِي الأَرضِ بَعدَ إِصلاحِها ۚ ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mxl{وَلا تَقعُدوا بِكُلِّ صِراطٍ توعِدونَ وَتَصُدّونَ عَن سَبيلِ اللَّهِ مَن آمَنَ بِهِ وَتَبغونَها عِوَجًا ۚ وَاذكُروا إِذ كُنتُم قَليلًا فَكَثَّرَكُم ۖ وَانظُروا كَيفَ كانَ عاقِبَةُ المُفسِدينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mxli{وَإِن كانَ طائِفَةٌ مِنكُم آمَنوا بِالَّذي أُرسِلتُ بِهِ وَطائِفَةٌ لَم يُؤمِنوا فَاصبِروا حَتّىٰ يَحكُمَ اللَّهُ بَينَنا ۚ وَهُوَ خَيرُ الحاكِمينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mxlii{۞ قالَ المَلَأُ الَّذينَ استَكبَروا مِن قَومِهِ لَنُخرِجَنَّكَ يا شُعَيبُ وَالَّذينَ آمَنوا مَعَكَ مِن قَريَتِنا أَو لَتَعودُنَّ في مِلَّتِنا ۚ قالَ أَوَلَو كُنّا كارِهينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mxliii{قَدِ افتَرَينا عَلَى اللَّهِ كَذِبًا إِن عُدنا في مِلَّتِكُم بَعدَ إِذ نَجّانَا اللَّهُ مِنها ۚ وَما يَكونُ لَنا أَن نَعودَ فيها إِلّا أَن يَشاءَ اللَّهُ رَبُّنا ۚ وَسِعَ رَبُّنا كُلَّ شَيءٍ عِلمًا ۚ عَلَى اللَّهِ تَوَكَّلنا ۚ رَبَّنَا افتَح بَينَنا وَبَينَ قَومِنا بِالحَقِّ وَأَنتَ خَيرُ الفاتِحينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mxliv{وَقالَ المَلَأُ الَّذينَ كَفَروا مِن قَومِهِ لَئِنِ اتَّبَعتُم شُعَيبًا إِنَّكُم إِذًا لَخاسِرونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mxlv{فَأَخَذَتهُمُ الرَّجفَةُ فَأَصبَحوا في دارِهِم جاثِمينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mxlvi{الَّذينَ كَذَّبوا شُعَيبًا كَأَن لَم يَغنَوا فيهَا ۚ الَّذينَ كَذَّبوا شُعَيبًا كانوا هُمُ الخاسِرينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mxlvii{فَتَوَلّىٰ عَنهُم وَقالَ يا قَومِ لَقَد أَبلَغتُكُم رِسالاتِ رَبّي وَنَصَحتُ لَكُم ۖ فَكَيفَ آسىٰ عَلىٰ قَومٍ كافِرينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mxlviii{وَما أَرسَلنا في قَريَةٍ مِن نَبِيٍّ إِلّا أَخَذنا أَهلَها بِالبَأساءِ وَالضَّرّاءِ لَعَلَّهُم يَضَّرَّعونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mxlix{ثُمَّ بَدَّلنا مَكانَ السَّيِّئَةِ الحَسَنَةَ حَتّىٰ عَفَوا وَقالوا قَد مَسَّ آباءَنَا الضَّرّاءُ وَالسَّرّاءُ فَأَخَذناهُم بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@ml{وَلَو أَنَّ أَهلَ القُرىٰ آمَنوا وَاتَّقَوا لَفَتَحنا عَلَيهِم بَرَكاتٍ مِنَ السَّماءِ وَالأَرضِ وَلٰكِن كَذَّبوا فَأَخَذناهُم بِما كانوا يَكسِبونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mli{أَفَأَمِنَ أَهلُ القُرىٰ أَن يَأتِيَهُم بَأسُنا بَياتًا وَهُم نائِمونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mlii{أَوَأَمِنَ أَهلُ القُرىٰ أَن يَأتِيَهُم بَأسُنا ضُحًى وَهُم يَلعَبونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mliii{أَفَأَمِنوا مَكرَ اللَّهِ ۚ فَلا يَأمَنُ مَكرَ اللَّهِ إِلَّا القَومُ الخاسِرونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mliv{أَوَلَم يَهدِ لِلَّذينَ يَرِثونَ الأَرضَ مِن بَعدِ أَهلِها أَن لَو نَشاءُ أَصَبناهُم بِذُنوبِهِم ۚ وَنَطبَعُ عَلىٰ قُلوبِهِم فَهُم لا يَسمَعونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mlv{تِلكَ القُرىٰ نَقُصُّ عَلَيكَ مِن أَنبائِها ۚ وَلَقَد جاءَتهُم رُسُلُهُم بِالبَيِّناتِ فَما كانوا لِيُؤمِنوا بِما كَذَّبوا مِن قَبلُ ۚ كَذٰلِكَ يَطبَعُ اللَّهُ عَلىٰ قُلوبِ الكافِرينَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mlvi{وَما وَجَدنا لِأَكثَرِهِم مِن عَهدٍ ۖ وَإِن وَجَدنا أَكثَرَهُم لَفاسِقينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mlvii{ثُمَّ بَعَثنا مِن بَعدِهِم موسىٰ بِآياتِنا إِلىٰ فِرعَونَ وَمَلَئِهِ فَظَلَموا بِها ۖ فَانظُر كَيفَ كانَ عاقِبَةُ المُفسِدينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mlviii{وَقالَ موسىٰ يا فِرعَونُ إِنّي رَسولٌ مِن رَبِّ العالَمينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mlix{حَقيقٌ عَلىٰ أَن لا أَقولَ عَلَى اللَّهِ إِلَّا الحَقَّ ۚ قَد جِئتُكُم بِبَيِّنَةٍ مِن رَبِّكُم فَأَرسِل مَعِيَ بَني إِسرائيلَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mlx{قالَ إِن كُنتَ جِئتَ بِآيَةٍ فَأتِ بِها إِن كُنتَ مِنَ الصّادِقينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mlxi{فَأَلقىٰ عَصاهُ فَإِذا هِيَ ثُعبانٌ مُبينٌ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mlxii{وَنَزَعَ يَدَهُ فَإِذا هِيَ بَيضاءُ لِلنّاظِرينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mlxiii{قالَ المَلَأُ مِن قَومِ فِرعَونَ إِنَّ هٰذا لَساحِرٌ عَليمٌ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mlxiv{يُريدُ أَن يُخرِجَكُم مِن أَرضِكُم ۖ فَماذا تَأمُرونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mlxv{قالوا أَرجِه وَأَخاهُ وَأَرسِل فِي المَدائِنِ حاشِرينَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mlxvi{يَأتوكَ بِكُلِّ ساحِرٍ عَليمٍ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mlxvii{وَجاءَ السَّحَرَةُ فِرعَونَ قالوا إِنَّ لَنا لَأَجرًا إِن كُنّا نَحنُ الغالِبينَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mlxviii{قالَ نَعَم وَإِنَّكُم لَمِنَ المُقَرَّبينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mlxix{قالوا يا موسىٰ إِمّا أَن تُلقِيَ وَإِمّا أَن نَكونَ نَحنُ المُلقينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mlxx{قالَ أَلقوا ۖ فَلَمّا أَلقَوا سَحَروا أَعيُنَ النّاسِ وَاستَرهَبوهُم وَجاءوا بِسِحرٍ عَظيمٍ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mlxxi{۞ وَأَوحَينا إِلىٰ موسىٰ أَن أَلقِ عَصاكَ ۖ فَإِذا هِيَ تَلقَفُ ما يَأفِكونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mlxxii{فَوَقَعَ الحَقُّ وَبَطَلَ ما كانوا يَعمَلونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mlxxiii{فَغُلِبوا هُنالِكَ وَانقَلَبوا صاغِرينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mlxxiv{وَأُلقِيَ السَّحَرَةُ ساجِدينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mlxxv{قالوا آمَنّا بِرَبِّ العالَمينَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mlxxvi{رَبِّ موسىٰ وَهارونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mlxxvii{قالَ فِرعَونُ آمَنتُم بِهِ قَبلَ أَن آذَنَ لَكُم ۖ إِنَّ هٰذا لَمَكرٌ مَكَرتُموهُ فِي المَدينَةِ لِتُخرِجوا مِنها أَهلَها ۖ فَسَوفَ تَعلَمونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mlxxviii{لَأُقَطِّعَنَّ أَيدِيَكُم وَأَرجُلَكُم مِن خِلافٍ ثُمَّ لَأُصَلِّبَنَّكُم أَجمَعينَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mlxxix{قالوا إِنّا إِلىٰ رَبِّنا مُنقَلِبونَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mlxxx{وَما تَنقِمُ مِنّا إِلّا أَن آمَنّا بِآياتِ رَبِّنا لَمّا جاءَتنا ۚ رَبَّنا أَفرِغ عَلَينا صَبرًا وَتَوَفَّنا مُسلِمينَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mlxxxi{وَقالَ المَلَأُ مِن قَومِ فِرعَونَ أَتَذَرُ موسىٰ وَقَومَهُ لِيُفسِدوا فِي الأَرضِ وَيَذَرَكَ وَآلِهَتَكَ ۚ قالَ سَنُقَتِّلُ أَبناءَهُم وَنَستَحيي نِساءَهُم وَإِنّا فَوقَهُم قاهِرونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mlxxxii{قالَ موسىٰ لِقَومِهِ استَعينوا بِاللَّهِ وَاصبِروا ۖ إِنَّ الأَرضَ لِلَّهِ يورِثُها مَن يَشاءُ مِن عِبادِهِ ۖ وَالعاقِبَةُ لِلمُتَّقينَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mlxxxiii{قالوا أوذينا مِن قَبلِ أَن تَأتِيَنا وَمِن بَعدِ ما جِئتَنا ۚ قالَ عَسىٰ رَبُّكُم أَن يُهلِكَ عَدُوَّكُم وَيَستَخلِفَكُم فِي الأَرضِ فَيَنظُرَ كَيفَ تَعمَلونَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mlxxxiv{وَلَقَد أَخَذنا آلَ فِرعَونَ بِالسِّنينَ وَنَقصٍ مِنَ الثَّمَراتِ لَعَلَّهُم يَذَّكَّرونَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mlxxxv{فَإِذا جاءَتهُمُ الحَسَنَةُ قالوا لَنا هٰذِهِ ۖ وَإِن تُصِبهُم سَيِّئَةٌ يَطَّيَّروا بِموسىٰ وَمَن مَعَهُ ۗ أَلا إِنَّما طائِرُهُم عِندَ اللَّهِ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mlxxxvi{وَقالوا مَهما تَأتِنا بِهِ مِن آيَةٍ لِتَسحَرَنا بِها فَما نَحنُ لَكَ بِمُؤمِنينَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mlxxxvii{فَأَرسَلنا عَلَيهِمُ الطّوفانَ وَالجَرادَ وَالقُمَّلَ وَالضَّفادِعَ وَالدَّمَ آياتٍ مُفَصَّلاتٍ فَاستَكبَروا وَكانوا قَومًا مُجرِمينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mlxxxviii{وَلَمّا وَقَعَ عَلَيهِمُ الرِّجزُ قالوا يا موسَى ادعُ لَنا رَبَّكَ بِما عَهِدَ عِندَكَ ۖ لَئِن كَشَفتَ عَنَّا الرِّجزَ لَنُؤمِنَنَّ لَكَ وَلَنُرسِلَنَّ مَعَكَ بَني إِسرائيلَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mlxxxix{فَلَمّا كَشَفنا عَنهُمُ الرِّجزَ إِلىٰ أَجَلٍ هُم بالِغوهُ إِذا هُم يَنكُثونَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mxc{فَانتَقَمنا مِنهُم فَأَغرَقناهُم فِي اليَمِّ بِأَنَّهُم كَذَّبوا بِآياتِنا وَكانوا عَنها غافِلينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@mxci{وَأَورَثنَا القَومَ الَّذينَ كانوا يُستَضعَفونَ مَشارِقَ الأَرضِ وَمَغارِبَهَا الَّتي بارَكنا فيها ۖ وَتَمَّت كَلِمَتُ رَبِّكَ الحُسنىٰ عَلىٰ بَني إِسرائيلَ بِما صَبَروا ۖ وَدَمَّرنا ما كانَ يَصنَعُ فِرعَونُ وَقَومُهُ وَما كانوا يَعرِشونَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@mxcii{وَجاوَزنا بِبَني إِسرائيلَ البَحرَ فَأَتَوا عَلىٰ قَومٍ يَعكُفونَ عَلىٰ أَصنامٍ لَهُم ۚ قالوا يا موسَى اجعَل لَنا إِلٰهًا كَما لَهُم آلِهَةٌ ۚ قالَ إِنَّكُم قَومٌ تَجهَلونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@mxciii{إِنَّ هٰؤُلاءِ مُتَبَّرٌ ما هُم فيهِ وَباطِلٌ ما كانوا يَعمَلونَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@mxciv{قالَ أَغَيرَ اللَّهِ أَبغيكُم إِلٰهًا وَهُوَ فَضَّلَكُم عَلَى العالَمينَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@mxcv{وَإِذ أَنجَيناكُم مِن آلِ فِرعَونَ يَسومونَكُم سوءَ العَذابِ ۖ يُقَتِّلونَ أَبناءَكُم وَيَستَحيونَ نِساءَكُم ۚ وَفي ذٰلِكُم بَلاءٌ مِن رَبِّكُم عَظيمٌ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@mxcvi{۞ وَواعَدنا موسىٰ ثَلاثينَ لَيلَةً وَأَتمَمناها بِعَشرٍ فَتَمَّ ميقاتُ رَبِّهِ أَربَعينَ لَيلَةً ۚ وَقالَ موسىٰ لِأَخيهِ هارونَ اخلُفني في قَومي وَأَصلِح وَلا تَتَّبِع سَبيلَ المُفسِدينَ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@mxcvii{وَلَمّا جاءَ موسىٰ لِميقاتِنا وَكَلَّمَهُ رَبُّهُ قالَ رَبِّ أَرِني أَنظُر إِلَيكَ ۚ قالَ لَن تَراني وَلٰكِنِ انظُر إِلَى الجَبَلِ فَإِنِ استَقَرَّ مَكانَهُ فَسَوفَ تَراني ۚ فَلَمّا تَجَلّىٰ رَبُّهُ لِلجَبَلِ جَعَلَهُ دَكًّا وَخَرَّ موسىٰ صَعِقًا ۚ فَلَمّا أَفاقَ قالَ سُبحانَكَ تُبتُ إِلَيكَ وَأَنا أَوَّلُ المُؤمِنينَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@mxcviii{قالَ يا موسىٰ إِنِّي اصطَفَيتُكَ عَلَى النّاسِ بِرِسالاتي وَبِكَلامي فَخُذ ما آتَيتُكَ وَكُن مِنَ الشّاكِرينَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@mxcix{وَكَتَبنا لَهُ فِي الأَلواحِ مِن كُلِّ شَيءٍ مَوعِظَةً وَتَفصيلًا لِكُلِّ شَيءٍ فَخُذها بِقُوَّةٍ وَأمُر قَومَكَ يَأخُذوا بِأَحسَنِها ۚ سَأُريكُم دارَ الفاسِقينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@mc{سَأَصرِفُ عَن آياتِيَ الَّذينَ يَتَكَبَّرونَ فِي الأَرضِ بِغَيرِ الحَقِّ وَإِن يَرَوا كُلَّ آيَةٍ لا يُؤمِنوا بِها وَإِن يَرَوا سَبيلَ الرُّشدِ لا يَتَّخِذوهُ سَبيلًا وَإِن يَرَوا سَبيلَ الغَيِّ يَتَّخِذوهُ سَبيلًا ۚ ذٰلِكَ بِأَنَّهُم كَذَّبوا بِآياتِنا وَكانوا عَنها غافِلينَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@mci{وَالَّذينَ كَذَّبوا بِآياتِنا وَلِقاءِ الآخِرَةِ حَبِطَت أَعمالُهُم ۚ هَل يُجزَونَ إِلّا ما كانوا يَعمَلونَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@mcii{وَاتَّخَذَ قَومُ موسىٰ مِن بَعدِهِ مِن حُلِيِّهِم عِجلًا جَسَدًا لَهُ خُوارٌ ۚ أَلَم يَرَوا أَنَّهُ لا يُكَلِّمُهُم وَلا يَهديهِم سَبيلًا ۘ اتَّخَذوهُ وَكانوا ظالِمينَ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@mciii{وَلَمّا سُقِطَ في أَيديهِم وَرَأَوا أَنَّهُم قَد ضَلّوا قالوا لَئِن لَم يَرحَمنا رَبُّنا وَيَغفِر لَنا لَنَكونَنَّ مِنَ الخاسِرينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@mciv{وَلَمّا رَجَعَ موسىٰ إِلىٰ قَومِهِ غَضبانَ أَسِفًا قالَ بِئسَما خَلَفتُموني مِن بَعدي ۖ أَعَجِلتُم أَمرَ رَبِّكُم ۖ وَأَلقَى الأَلواحَ وَأَخَذَ بِرَأسِ أَخيهِ يَجُرُّهُ إِلَيهِ ۚ قالَ ابنَ أُمَّ إِنَّ القَومَ استَضعَفوني وَكادوا يَقتُلونَني فَلا تُشمِت بِيَ الأَعداءَ وَلا تَجعَلني مَعَ القَومِ الظّالِمينَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@mcv{قالَ رَبِّ اغفِر لي وَلِأَخي وَأَدخِلنا في رَحمَتِكَ ۖ وَأَنتَ أَرحَمُ الرّاحِمينَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@mcvi{إِنَّ الَّذينَ اتَّخَذُوا العِجلَ سَيَنالُهُم غَضَبٌ مِن رَبِّهِم وَذِلَّةٌ فِي الحَياةِ الدُّنيا ۚ وَكَذٰلِكَ نَجزِي المُفتَرينَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@mcvii{وَالَّذينَ عَمِلُوا السَّيِّئَاتِ ثُمَّ تابوا مِن بَعدِها وَآمَنوا إِنَّ رَبَّكَ مِن بَعدِها لَغَفورٌ رَحيمٌ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@mcviii{وَلَمّا سَكَتَ عَن موسَى الغَضَبُ أَخَذَ الأَلواحَ ۖ وَفي نُسخَتِها هُدًى وَرَحمَةٌ لِلَّذينَ هُم لِرَبِّهِم يَرهَبونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@mcix{وَاختارَ موسىٰ قَومَهُ سَبعينَ رَجُلًا لِميقاتِنا ۖ فَلَمّا أَخَذَتهُمُ الرَّجفَةُ قالَ رَبِّ لَو شِئتَ أَهلَكتَهُم مِن قَبلُ وَإِيّايَ ۖ أَتُهلِكُنا بِما فَعَلَ السُّفَهاءُ مِنّا ۖ إِن هِيَ إِلّا فِتنَتُكَ تُضِلُّ بِها مَن تَشاءُ وَتَهدي مَن تَشاءُ ۖ أَنتَ وَلِيُّنا فَاغفِر لَنا وَارحَمنا ۖ وَأَنتَ خَيرُ الغافِرينَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@mcx{۞ وَاكتُب لَنا في هٰذِهِ الدُّنيا حَسَنَةً وَفِي الآخِرَةِ إِنّا هُدنا إِلَيكَ ۚ قالَ عَذابي أُصيبُ بِهِ مَن أَشاءُ ۖ وَرَحمَتي وَسِعَت كُلَّ شَيءٍ ۚ فَسَأَكتُبُها لِلَّذينَ يَتَّقونَ وَيُؤتونَ الزَّكاةَ وَالَّذينَ هُم بِآياتِنا يُؤمِنونَ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@mcxi{الَّذينَ يَتَّبِعونَ الرَّسولَ النَّبِيَّ الأُمِّيَّ الَّذي يَجِدونَهُ مَكتوبًا عِندَهُم فِي التَّوراةِ وَالإِنجيلِ يَأمُرُهُم بِالمَعروفِ وَيَنهاهُم عَنِ المُنكَرِ وَيُحِلُّ لَهُمُ الطَّيِّباتِ وَيُحَرِّمُ عَلَيهِمُ الخَبائِثَ وَيَضَعُ عَنهُم إِصرَهُم وَالأَغلالَ الَّتي كانَت عَلَيهِم ۚ فَالَّذينَ آمَنوا بِهِ وَعَزَّروهُ وَنَصَروهُ وَاتَّبَعُوا النّورَ الَّذي أُنزِلَ مَعَهُ ۙ أُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@mcxii{قُل يا أَيُّهَا النّاسُ إِنّي رَسولُ اللَّهِ إِلَيكُم جَميعًا الَّذي لَهُ مُلكُ السَّماواتِ وَالأَرضِ ۖ لا إِلٰهَ إِلّا هُوَ يُحيي وَيُميتُ ۖ فَآمِنوا بِاللَّهِ وَرَسولِهِ النَّبِيِّ الأُمِّيِّ الَّذي يُؤمِنُ بِاللَّهِ وَكَلِماتِهِ وَاتَّبِعوهُ لَعَلَّكُم تَهتَدونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@mcxiii{وَمِن قَومِ موسىٰ أُمَّةٌ يَهدونَ بِالحَقِّ وَبِهِ يَعدِلونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@mcxiv{وَقَطَّعناهُمُ اثنَتَي عَشرَةَ أَسباطًا أُمَمًا ۚ وَأَوحَينا إِلىٰ موسىٰ إِذِ استَسقاهُ قَومُهُ أَنِ اضرِب بِعَصاكَ الحَجَرَ ۖ فَانبَجَسَت مِنهُ اثنَتا عَشرَةَ عَينًا ۖ قَد عَلِمَ كُلُّ أُناسٍ مَشرَبَهُم ۚ وَظَلَّلنا عَلَيهِمُ الغَمامَ وَأَنزَلنا عَلَيهِمُ المَنَّ وَالسَّلوىٰ ۖ كُلوا مِن طَيِّباتِ ما رَزَقناكُم ۚ وَما ظَلَمونا وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@mcxv{وَإِذ قيلَ لَهُمُ اسكُنوا هٰذِهِ القَريَةَ وَكُلوا مِنها حَيثُ شِئتُم وَقولوا حِطَّةٌ وَادخُلُوا البابَ سُجَّدًا نَغفِر لَكُم خَطيئَاتِكُم ۚ سَنَزيدُ المُحسِنينَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@mcxvi{فَبَدَّلَ الَّذينَ ظَلَموا مِنهُم قَولًا غَيرَ الَّذي قيلَ لَهُم فَأَرسَلنا عَلَيهِم رِجزًا مِنَ السَّماءِ بِما كانوا يَظلِمونَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@mcxvii{وَاسأَلهُم عَنِ القَريَةِ الَّتي كانَت حاضِرَةَ البَحرِ إِذ يَعدونَ فِي السَّبتِ إِذ تَأتيهِم حيتانُهُم يَومَ سَبتِهِم شُرَّعًا وَيَومَ لا يَسبِتونَ ۙ لا تَأتيهِم ۚ كَذٰلِكَ نَبلوهُم بِما كانوا يَفسُقونَ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@mcxviii{وَإِذ قالَت أُمَّةٌ مِنهُم لِمَ تَعِظونَ قَومًا ۙ اللَّهُ مُهلِكُهُم أَو مُعَذِّبُهُم عَذابًا شَديدًا ۖ قالوا مَعذِرَةً إِلىٰ رَبِّكُم وَلَعَلَّهُم يَتَّقونَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@mcxix{فَلَمّا نَسوا ما ذُكِّروا بِهِ أَنجَينَا الَّذينَ يَنهَونَ عَنِ السّوءِ وَأَخَذنَا الَّذينَ ظَلَموا بِعَذابٍ بَئيسٍ بِما كانوا يَفسُقونَ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@mcxx{فَلَمّا عَتَوا عَن ما نُهوا عَنهُ قُلنا لَهُم كونوا قِرَدَةً خاسِئينَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@mcxxi{وَإِذ تَأَذَّنَ رَبُّكَ لَيَبعَثَنَّ عَلَيهِم إِلىٰ يَومِ القِيامَةِ مَن يَسومُهُم سوءَ العَذابِ ۗ إِنَّ رَبَّكَ لَسَريعُ العِقابِ ۖ وَإِنَّهُ لَغَفورٌ رَحيمٌ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@mcxxii{وَقَطَّعناهُم فِي الأَرضِ أُمَمًا ۖ مِنهُمُ الصّالِحونَ وَمِنهُم دونَ ذٰلِكَ ۖ وَبَلَوناهُم بِالحَسَناتِ وَالسَّيِّئَاتِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@mcxxiii{فَخَلَفَ مِن بَعدِهِم خَلفٌ وَرِثُوا الكِتابَ يَأخُذونَ عَرَضَ هٰذَا الأَدنىٰ وَيَقولونَ سَيُغفَرُ لَنا وَإِن يَأتِهِم عَرَضٌ مِثلُهُ يَأخُذوهُ ۚ أَلَم يُؤخَذ عَلَيهِم ميثاقُ الكِتابِ أَن لا يَقولوا عَلَى اللَّهِ إِلَّا الحَقَّ وَدَرَسوا ما فيهِ ۗ وَالدّارُ الآخِرَةُ خَيرٌ لِلَّذينَ يَتَّقونَ ۗ أَفَلا تَعقِلونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@mcxxiv{وَالَّذينَ يُمَسِّكونَ بِالكِتابِ وَأَقامُوا الصَّلاةَ إِنّا لا نُضيعُ أَجرَ المُصلِحينَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@mcxxv{۞ وَإِذ نَتَقنَا الجَبَلَ فَوقَهُم كَأَنَّهُ ظُلَّةٌ وَظَنّوا أَنَّهُ واقِعٌ بِهِم خُذوا ما آتَيناكُم بِقُوَّةٍ وَاذكُروا ما فيهِ لَعَلَّكُم تَتَّقونَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@mcxxvi{وَإِذ أَخَذَ رَبُّكَ مِن بَني آدَمَ مِن ظُهورِهِم ذُرِّيَّتَهُم وَأَشهَدَهُم عَلىٰ أَنفُسِهِم أَلَستُ بِرَبِّكُم ۖ قالوا بَلىٰ ۛ شَهِدنا ۛ أَن تَقولوا يَومَ القِيامَةِ إِنّا كُنّا عَن هٰذا غافِلينَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@mcxxvii{أَو تَقولوا إِنَّما أَشرَكَ آباؤُنا مِن قَبلُ وَكُنّا ذُرِّيَّةً مِن بَعدِهِم ۖ أَفَتُهلِكُنا بِما فَعَلَ المُبطِلونَ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@mcxxviii{وَكَذٰلِكَ نُفَصِّلُ الآياتِ وَلَعَلَّهُم يَرجِعونَ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@mcxxix{وَاتلُ عَلَيهِم نَبَأَ الَّذي آتَيناهُ آياتِنا فَانسَلَخَ مِنها فَأَتبَعَهُ الشَّيطانُ فَكانَ مِنَ الغاوينَ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@mcxxx{وَلَو شِئنا لَرَفَعناهُ بِها وَلٰكِنَّهُ أَخلَدَ إِلَى الأَرضِ وَاتَّبَعَ هَواهُ ۚ فَمَثَلُهُ كَمَثَلِ الكَلبِ إِن تَحمِل عَلَيهِ يَلهَث أَو تَترُكهُ يَلهَث ۚ ذٰلِكَ مَثَلُ القَومِ الَّذينَ كَذَّبوا بِآياتِنا ۚ فَاقصُصِ القَصَصَ لَعَلَّهُم يَتَفَكَّرونَ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@mcxxxi{ساءَ مَثَلًا القَومُ الَّذينَ كَذَّبوا بِآياتِنا وَأَنفُسَهُم كانوا يَظلِمونَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@mcxxxii{مَن يَهدِ اللَّهُ فَهُوَ المُهتَدي ۖ وَمَن يُضلِل فَأُولٰئِكَ هُمُ الخاسِرونَ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@mcxxxiii{وَلَقَد ذَرَأنا لِجَهَنَّمَ كَثيرًا مِنَ الجِنِّ وَالإِنسِ ۖ لَهُم قُلوبٌ لا يَفقَهونَ بِها وَلَهُم أَعيُنٌ لا يُبصِرونَ بِها وَلَهُم آذانٌ لا يَسمَعونَ بِها ۚ أُولٰئِكَ كَالأَنعامِ بَل هُم أَضَلُّ ۚ أُولٰئِكَ هُمُ الغافِلونَ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@mcxxxiv{وَلِلَّهِ الأَسماءُ الحُسنىٰ فَادعوهُ بِها ۖ وَذَرُوا الَّذينَ يُلحِدونَ في أَسمائِهِ ۚ سَيُجزَونَ ما كانوا يَعمَلونَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@mcxxxv{وَمِمَّن خَلَقنا أُمَّةٌ يَهدونَ بِالحَقِّ وَبِهِ يَعدِلونَ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@mcxxxvi{وَالَّذينَ كَذَّبوا بِآياتِنا سَنَستَدرِجُهُم مِن حَيثُ لا يَعلَمونَ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@mcxxxvii{وَأُملي لَهُم ۚ إِنَّ كَيدي مَتينٌ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@mcxxxviii{أَوَلَم يَتَفَكَّروا ۗ ما بِصاحِبِهِم مِن جِنَّةٍ ۚ إِن هُوَ إِلّا نَذيرٌ مُبينٌ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@mcxxxix{أَوَلَم يَنظُروا في مَلَكوتِ السَّماواتِ وَالأَرضِ وَما خَلَقَ اللَّهُ مِن شَيءٍ وَأَن عَسىٰ أَن يَكونَ قَدِ اقتَرَبَ أَجَلُهُم ۖ فَبِأَيِّ حَديثٍ بَعدَهُ يُؤمِنونَ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@mcxl{مَن يُضلِلِ اللَّهُ فَلا هادِيَ لَهُ ۚ وَيَذَرُهُم في طُغيانِهِم يَعمَهونَ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@mcxli{يَسأَلونَكَ عَنِ السّاعَةِ أَيّانَ مُرساها ۖ قُل إِنَّما عِلمُها عِندَ رَبّي ۖ لا يُجَلّيها لِوَقتِها إِلّا هُوَ ۚ ثَقُلَت فِي السَّماواتِ وَالأَرضِ ۚ لا تَأتيكُم إِلّا بَغتَةً ۗ يَسأَلونَكَ كَأَنَّكَ حَفِيٌّ عَنها ۖ قُل إِنَّما عِلمُها عِندَ اللَّهِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@mcxlii{قُل لا أَملِكُ لِنَفسي نَفعًا وَلا ضَرًّا إِلّا ما شاءَ اللَّهُ ۚ وَلَو كُنتُ أَعلَمُ الغَيبَ لَاستَكثَرتُ مِنَ الخَيرِ وَما مَسَّنِيَ السّوءُ ۚ إِن أَنا إِلّا نَذيرٌ وَبَشيرٌ لِقَومٍ يُؤمِنونَ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@mcxliii{۞ هُوَ الَّذي خَلَقَكُم مِن نَفسٍ واحِدَةٍ وَجَعَلَ مِنها زَوجَها لِيَسكُنَ إِلَيها ۖ فَلَمّا تَغَشّاها حَمَلَت حَملًا خَفيفًا فَمَرَّت بِهِ ۖ فَلَمّا أَثقَلَت دَعَوَا اللَّهَ رَبَّهُما لَئِن آتَيتَنا صالِحًا لَنَكونَنَّ مِنَ الشّاكِرينَ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@mcxliv{فَلَمّا آتاهُما صالِحًا جَعَلا لَهُ شُرَكاءَ فيما آتاهُما ۚ فَتَعالَى اللَّهُ عَمّا يُشرِكونَ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@mcxlv{أَيُشرِكونَ ما لا يَخلُقُ شَيئًا وَهُم يُخلَقونَ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@mcxlvi{وَلا يَستَطيعونَ لَهُم نَصرًا وَلا أَنفُسَهُم يَنصُرونَ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@mcxlvii{وَإِن تَدعوهُم إِلَى الهُدىٰ لا يَتَّبِعوكُم ۚ سَواءٌ عَلَيكُم أَدَعَوتُموهُم أَم أَنتُم صامِتونَ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@mcxlviii{إِنَّ الَّذينَ تَدعونَ مِن دونِ اللَّهِ عِبادٌ أَمثالُكُم ۖ فَادعوهُم فَليَستَجيبوا لَكُم إِن كُنتُم صادِقينَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@mcxlix{أَلَهُم أَرجُلٌ يَمشونَ بِها ۖ أَم لَهُم أَيدٍ يَبطِشونَ بِها ۖ أَم لَهُم أَعيُنٌ يُبصِرونَ بِها ۖ أَم لَهُم آذانٌ يَسمَعونَ بِها ۗ قُلِ ادعوا شُرَكاءَكُم ثُمَّ كيدونِ فَلا تُنظِرونِ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@mcl{إِنَّ وَلِيِّيَ اللَّهُ الَّذي نَزَّلَ الكِتابَ ۖ وَهُوَ يَتَوَلَّى الصّالِحينَ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@mcli{وَالَّذينَ تَدعونَ مِن دونِهِ لا يَستَطيعونَ نَصرَكُم وَلا أَنفُسَهُم يَنصُرونَ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@mclii{وَإِن تَدعوهُم إِلَى الهُدىٰ لا يَسمَعوا ۖ وَتَراهُم يَنظُرونَ إِلَيكَ وَهُم لا يُبصِرونَ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@mcliii{خُذِ العَفوَ وَأمُر بِالعُرفِ وَأَعرِض عَنِ الجاهِلينَ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@mcliv{وَإِمّا يَنزَغَنَّكَ مِنَ الشَّيطانِ نَزغٌ فَاستَعِذ بِاللَّهِ ۚ إِنَّهُ سَميعٌ عَليمٌ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@mclv{إِنَّ الَّذينَ اتَّقَوا إِذا مَسَّهُم طائِفٌ مِنَ الشَّيطانِ تَذَكَّروا فَإِذا هُم مُبصِرونَ\qt@no{﴿٢٠١﴾}}
\qt@newcmd\qurantext@mclvi{وَإِخوانُهُم يَمُدّونَهُم فِي الغَيِّ ثُمَّ لا يُقصِرونَ\qt@no{﴿٢٠٢﴾}}
\qt@newcmd\qurantext@mclvii{وَإِذا لَم تَأتِهِم بِآيَةٍ قالوا لَولَا اجتَبَيتَها ۚ قُل إِنَّما أَتَّبِعُ ما يوحىٰ إِلَيَّ مِن رَبّي ۚ هٰذا بَصائِرُ مِن رَبِّكُم وَهُدًى وَرَحمَةٌ لِقَومٍ يُؤمِنونَ\qt@no{﴿٢٠٣﴾}}
\qt@newcmd\qurantext@mclviii{وَإِذا قُرِئَ القُرآنُ فَاستَمِعوا لَهُ وَأَنصِتوا لَعَلَّكُم تُرحَمونَ\qt@no{﴿٢٠٤﴾}}
\qt@newcmd\qurantext@mclix{وَاذكُر رَبَّكَ في نَفسِكَ تَضَرُّعًا وَخيفَةً وَدونَ الجَهرِ مِنَ القَولِ بِالغُدُوِّ وَالآصالِ وَلا تَكُن مِنَ الغافِلينَ\qt@no{﴿٢٠٥﴾}}
\qt@newcmd\qurantext@mclx{إِنَّ الَّذينَ عِندَ رَبِّكَ لا يَستَكبِرونَ عَن عِبادَتِهِ وَيُسَبِّحونَهُ وَلَهُ يَسجُدونَ ۩\qt@no{﴿٢٠٦﴾}}
\qt@newcmd\qurantext@mclxi{\basmalah يَسأَلونَكَ عَنِ الأَنفالِ ۖ قُلِ الأَنفالُ لِلَّهِ وَالرَّسولِ ۖ فَاتَّقُوا اللَّهَ وَأَصلِحوا ذاتَ بَينِكُم ۖ وَأَطيعُوا اللَّهَ وَرَسولَهُ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mclxii{إِنَّمَا المُؤمِنونَ الَّذينَ إِذا ذُكِرَ اللَّهُ وَجِلَت قُلوبُهُم وَإِذا تُلِيَت عَلَيهِم آياتُهُ زادَتهُم إيمانًا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mclxiii{الَّذينَ يُقيمونَ الصَّلاةَ وَمِمّا رَزَقناهُم يُنفِقونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mclxiv{أُولٰئِكَ هُمُ المُؤمِنونَ حَقًّا ۚ لَهُم دَرَجاتٌ عِندَ رَبِّهِم وَمَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mclxv{كَما أَخرَجَكَ رَبُّكَ مِن بَيتِكَ بِالحَقِّ وَإِنَّ فَريقًا مِنَ المُؤمِنينَ لَكارِهونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mclxvi{يُجادِلونَكَ فِي الحَقِّ بَعدَما تَبَيَّنَ كَأَنَّما يُساقونَ إِلَى المَوتِ وَهُم يَنظُرونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mclxvii{وَإِذ يَعِدُكُمُ اللَّهُ إِحدَى الطّائِفَتَينِ أَنَّها لَكُم وَتَوَدّونَ أَنَّ غَيرَ ذاتِ الشَّوكَةِ تَكونُ لَكُم وَيُريدُ اللَّهُ أَن يُحِقَّ الحَقَّ بِكَلِماتِهِ وَيَقطَعَ دابِرَ الكافِرينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mclxviii{لِيُحِقَّ الحَقَّ وَيُبطِلَ الباطِلَ وَلَو كَرِهَ المُجرِمونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mclxix{إِذ تَستَغيثونَ رَبَّكُم فَاستَجابَ لَكُم أَنّي مُمِدُّكُم بِأَلفٍ مِنَ المَلائِكَةِ مُردِفينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mclxx{وَما جَعَلَهُ اللَّهُ إِلّا بُشرىٰ وَلِتَطمَئِنَّ بِهِ قُلوبُكُم ۚ وَمَا النَّصرُ إِلّا مِن عِندِ اللَّهِ ۚ إِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mclxxi{إِذ يُغَشّيكُمُ النُّعاسَ أَمَنَةً مِنهُ وَيُنَزِّلُ عَلَيكُم مِنَ السَّماءِ ماءً لِيُطَهِّرَكُم بِهِ وَيُذهِبَ عَنكُم رِجزَ الشَّيطانِ وَلِيَربِطَ عَلىٰ قُلوبِكُم وَيُثَبِّتَ بِهِ الأَقدامَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mclxxii{إِذ يوحي رَبُّكَ إِلَى المَلائِكَةِ أَنّي مَعَكُم فَثَبِّتُوا الَّذينَ آمَنوا ۚ سَأُلقي في قُلوبِ الَّذينَ كَفَرُوا الرُّعبَ فَاضرِبوا فَوقَ الأَعناقِ وَاضرِبوا مِنهُم كُلَّ بَنانٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mclxxiii{ذٰلِكَ بِأَنَّهُم شاقُّوا اللَّهَ وَرَسولَهُ ۚ وَمَن يُشاقِقِ اللَّهَ وَرَسولَهُ فَإِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mclxxiv{ذٰلِكُم فَذوقوهُ وَأَنَّ لِلكافِرينَ عَذابَ النّارِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mclxxv{يا أَيُّهَا الَّذينَ آمَنوا إِذا لَقيتُمُ الَّذينَ كَفَروا زَحفًا فَلا تُوَلّوهُمُ الأَدبارَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mclxxvi{وَمَن يُوَلِّهِم يَومَئِذٍ دُبُرَهُ إِلّا مُتَحَرِّفًا لِقِتالٍ أَو مُتَحَيِّزًا إِلىٰ فِئَةٍ فَقَد باءَ بِغَضَبٍ مِنَ اللَّهِ وَمَأواهُ جَهَنَّمُ ۖ وَبِئسَ المَصيرُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mclxxvii{فَلَم تَقتُلوهُم وَلٰكِنَّ اللَّهَ قَتَلَهُم ۚ وَما رَمَيتَ إِذ رَمَيتَ وَلٰكِنَّ اللَّهَ رَمىٰ ۚ وَلِيُبلِيَ المُؤمِنينَ مِنهُ بَلاءً حَسَنًا ۚ إِنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mclxxviii{ذٰلِكُم وَأَنَّ اللَّهَ موهِنُ كَيدِ الكافِرينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mclxxix{إِن تَستَفتِحوا فَقَد جاءَكُمُ الفَتحُ ۖ وَإِن تَنتَهوا فَهُوَ خَيرٌ لَكُم ۖ وَإِن تَعودوا نَعُد وَلَن تُغنِيَ عَنكُم فِئَتُكُم شَيئًا وَلَو كَثُرَت وَأَنَّ اللَّهَ مَعَ المُؤمِنينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mclxxx{يا أَيُّهَا الَّذينَ آمَنوا أَطيعُوا اللَّهَ وَرَسولَهُ وَلا تَوَلَّوا عَنهُ وَأَنتُم تَسمَعونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mclxxxi{وَلا تَكونوا كَالَّذينَ قالوا سَمِعنا وَهُم لا يَسمَعونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mclxxxii{۞ إِنَّ شَرَّ الدَّوابِّ عِندَ اللَّهِ الصُّمُّ البُكمُ الَّذينَ لا يَعقِلونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mclxxxiii{وَلَو عَلِمَ اللَّهُ فيهِم خَيرًا لَأَسمَعَهُم ۖ وَلَو أَسمَعَهُم لَتَوَلَّوا وَهُم مُعرِضونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mclxxxiv{يا أَيُّهَا الَّذينَ آمَنُوا استَجيبوا لِلَّهِ وَلِلرَّسولِ إِذا دَعاكُم لِما يُحييكُم ۖ وَاعلَموا أَنَّ اللَّهَ يَحولُ بَينَ المَرءِ وَقَلبِهِ وَأَنَّهُ إِلَيهِ تُحشَرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mclxxxv{وَاتَّقوا فِتنَةً لا تُصيبَنَّ الَّذينَ ظَلَموا مِنكُم خاصَّةً ۖ وَاعلَموا أَنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mclxxxvi{وَاذكُروا إِذ أَنتُم قَليلٌ مُستَضعَفونَ فِي الأَرضِ تَخافونَ أَن يَتَخَطَّفَكُمُ النّاسُ فَآواكُم وَأَيَّدَكُم بِنَصرِهِ وَرَزَقَكُم مِنَ الطَّيِّباتِ لَعَلَّكُم تَشكُرونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mclxxxvii{يا أَيُّهَا الَّذينَ آمَنوا لا تَخونُوا اللَّهَ وَالرَّسولَ وَتَخونوا أَماناتِكُم وَأَنتُم تَعلَمونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mclxxxviii{وَاعلَموا أَنَّما أَموالُكُم وَأَولادُكُم فِتنَةٌ وَأَنَّ اللَّهَ عِندَهُ أَجرٌ عَظيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mclxxxix{يا أَيُّهَا الَّذينَ آمَنوا إِن تَتَّقُوا اللَّهَ يَجعَل لَكُم فُرقانًا وَيُكَفِّر عَنكُم سَيِّئَاتِكُم وَيَغفِر لَكُم ۗ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcxc{وَإِذ يَمكُرُ بِكَ الَّذينَ كَفَروا لِيُثبِتوكَ أَو يَقتُلوكَ أَو يُخرِجوكَ ۚ وَيَمكُرونَ وَيَمكُرُ اللَّهُ ۖ وَاللَّهُ خَيرُ الماكِرينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcxci{وَإِذا تُتلىٰ عَلَيهِم آياتُنا قالوا قَد سَمِعنا لَو نَشاءُ لَقُلنا مِثلَ هٰذا ۙ إِن هٰذا إِلّا أَساطيرُ الأَوَّلينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcxcii{وَإِذ قالُوا اللَّهُمَّ إِن كانَ هٰذا هُوَ الحَقَّ مِن عِندِكَ فَأَمطِر عَلَينا حِجارَةً مِنَ السَّماءِ أَوِ ائتِنا بِعَذابٍ أَليمٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcxciii{وَما كانَ اللَّهُ لِيُعَذِّبَهُم وَأَنتَ فيهِم ۚ وَما كانَ اللَّهُ مُعَذِّبَهُم وَهُم يَستَغفِرونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcxciv{وَما لَهُم أَلّا يُعَذِّبَهُمُ اللَّهُ وَهُم يَصُدّونَ عَنِ المَسجِدِ الحَرامِ وَما كانوا أَولِياءَهُ ۚ إِن أَولِياؤُهُ إِلَّا المُتَّقونَ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcxcv{وَما كانَ صَلاتُهُم عِندَ البَيتِ إِلّا مُكاءً وَتَصدِيَةً ۚ فَذوقُوا العَذابَ بِما كُنتُم تَكفُرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcxcvi{إِنَّ الَّذينَ كَفَروا يُنفِقونَ أَموالَهُم لِيَصُدّوا عَن سَبيلِ اللَّهِ ۚ فَسَيُنفِقونَها ثُمَّ تَكونُ عَلَيهِم حَسرَةً ثُمَّ يُغلَبونَ ۗ وَالَّذينَ كَفَروا إِلىٰ جَهَنَّمَ يُحشَرونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcxcvii{لِيَميزَ اللَّهُ الخَبيثَ مِنَ الطَّيِّبِ وَيَجعَلَ الخَبيثَ بَعضَهُ عَلىٰ بَعضٍ فَيَركُمَهُ جَميعًا فَيَجعَلَهُ في جَهَنَّمَ ۚ أُولٰئِكَ هُمُ الخاسِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcxcviii{قُل لِلَّذينَ كَفَروا إِن يَنتَهوا يُغفَر لَهُم ما قَد سَلَفَ وَإِن يَعودوا فَقَد مَضَت سُنَّتُ الأَوَّلينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcxcix{وَقاتِلوهُم حَتّىٰ لا تَكونَ فِتنَةٌ وَيَكونَ الدّينُ كُلُّهُ لِلَّهِ ۚ فَإِنِ انتَهَوا فَإِنَّ اللَّهَ بِما يَعمَلونَ بَصيرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcc{وَإِن تَوَلَّوا فَاعلَموا أَنَّ اللَّهَ مَولاكُم ۚ نِعمَ المَولىٰ وَنِعمَ النَّصيرُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcci{۞ وَاعلَموا أَنَّما غَنِمتُم مِن شَيءٍ فَأَنَّ لِلَّهِ خُمُسَهُ وَلِلرَّسولِ وَلِذِي القُربىٰ وَاليَتامىٰ وَالمَساكينِ وَابنِ السَّبيلِ إِن كُنتُم آمَنتُم بِاللَّهِ وَما أَنزَلنا عَلىٰ عَبدِنا يَومَ الفُرقانِ يَومَ التَقَى الجَمعانِ ۗ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mccii{إِذ أَنتُم بِالعُدوَةِ الدُّنيا وَهُم بِالعُدوَةِ القُصوىٰ وَالرَّكبُ أَسفَلَ مِنكُم ۚ وَلَو تَواعَدتُم لَاختَلَفتُم فِي الميعادِ ۙ وَلٰكِن لِيَقضِيَ اللَّهُ أَمرًا كانَ مَفعولًا لِيَهلِكَ مَن هَلَكَ عَن بَيِّنَةٍ وَيَحيىٰ مَن حَيَّ عَن بَيِّنَةٍ ۗ وَإِنَّ اللَّهَ لَسَميعٌ عَليمٌ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcciii{إِذ يُريكَهُمُ اللَّهُ في مَنامِكَ قَليلًا ۖ وَلَو أَراكَهُم كَثيرًا لَفَشِلتُم وَلَتَنازَعتُم فِي الأَمرِ وَلٰكِنَّ اللَّهَ سَلَّمَ ۗ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcciv{وَإِذ يُريكُموهُم إِذِ التَقَيتُم في أَعيُنِكُم قَليلًا وَيُقَلِّلُكُم في أَعيُنِهِم لِيَقضِيَ اللَّهُ أَمرًا كانَ مَفعولًا ۗ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mccv{يا أَيُّهَا الَّذينَ آمَنوا إِذا لَقيتُم فِئَةً فَاثبُتوا وَاذكُرُوا اللَّهَ كَثيرًا لَعَلَّكُم تُفلِحونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mccvi{وَأَطيعُوا اللَّهَ وَرَسولَهُ وَلا تَنازَعوا فَتَفشَلوا وَتَذهَبَ ريحُكُم ۖ وَاصبِروا ۚ إِنَّ اللَّهَ مَعَ الصّابِرينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mccvii{وَلا تَكونوا كَالَّذينَ خَرَجوا مِن دِيارِهِم بَطَرًا وَرِئَاءَ النّاسِ وَيَصُدّونَ عَن سَبيلِ اللَّهِ ۚ وَاللَّهُ بِما يَعمَلونَ مُحيطٌ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mccviii{وَإِذ زَيَّنَ لَهُمُ الشَّيطانُ أَعمالَهُم وَقالَ لا غالِبَ لَكُمُ اليَومَ مِنَ النّاسِ وَإِنّي جارٌ لَكُم ۖ فَلَمّا تَراءَتِ الفِئَتانِ نَكَصَ عَلىٰ عَقِبَيهِ وَقالَ إِنّي بَريءٌ مِنكُم إِنّي أَرىٰ ما لا تَرَونَ إِنّي أَخافُ اللَّهَ ۚ وَاللَّهُ شَديدُ العِقابِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mccix{إِذ يَقولُ المُنافِقونَ وَالَّذينَ في قُلوبِهِم مَرَضٌ غَرَّ هٰؤُلاءِ دينُهُم ۗ وَمَن يَتَوَكَّل عَلَى اللَّهِ فَإِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mccx{وَلَو تَرىٰ إِذ يَتَوَفَّى الَّذينَ كَفَرُوا ۙ المَلائِكَةُ يَضرِبونَ وُجوهَهُم وَأَدبارَهُم وَذوقوا عَذابَ الحَريقِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mccxi{ذٰلِكَ بِما قَدَّمَت أَيديكُم وَأَنَّ اللَّهَ لَيسَ بِظَلّامٍ لِلعَبيدِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mccxii{كَدَأبِ آلِ فِرعَونَ ۙ وَالَّذينَ مِن قَبلِهِم ۚ كَفَروا بِآياتِ اللَّهِ فَأَخَذَهُمُ اللَّهُ بِذُنوبِهِم ۗ إِنَّ اللَّهَ قَوِيٌّ شَديدُ العِقابِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mccxiii{ذٰلِكَ بِأَنَّ اللَّهَ لَم يَكُ مُغَيِّرًا نِعمَةً أَنعَمَها عَلىٰ قَومٍ حَتّىٰ يُغَيِّروا ما بِأَنفُسِهِم ۙ وَأَنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mccxiv{كَدَأبِ آلِ فِرعَونَ ۙ وَالَّذينَ مِن قَبلِهِم ۚ كَذَّبوا بِآياتِ رَبِّهِم فَأَهلَكناهُم بِذُنوبِهِم وَأَغرَقنا آلَ فِرعَونَ ۚ وَكُلٌّ كانوا ظالِمينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mccxv{إِنَّ شَرَّ الدَّوابِّ عِندَ اللَّهِ الَّذينَ كَفَروا فَهُم لا يُؤمِنونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mccxvi{الَّذينَ عاهَدتَ مِنهُم ثُمَّ يَنقُضونَ عَهدَهُم في كُلِّ مَرَّةٍ وَهُم لا يَتَّقونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mccxvii{فَإِمّا تَثقَفَنَّهُم فِي الحَربِ فَشَرِّد بِهِم مَن خَلفَهُم لَعَلَّهُم يَذَّكَّرونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mccxviii{وَإِمّا تَخافَنَّ مِن قَومٍ خِيانَةً فَانبِذ إِلَيهِم عَلىٰ سَواءٍ ۚ إِنَّ اللَّهَ لا يُحِبُّ الخائِنينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mccxix{وَلا يَحسَبَنَّ الَّذينَ كَفَروا سَبَقوا ۚ إِنَّهُم لا يُعجِزونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mccxx{وَأَعِدّوا لَهُم مَا استَطَعتُم مِن قُوَّةٍ وَمِن رِباطِ الخَيلِ تُرهِبونَ بِهِ عَدُوَّ اللَّهِ وَعَدُوَّكُم وَآخَرينَ مِن دونِهِم لا تَعلَمونَهُمُ اللَّهُ يَعلَمُهُم ۚ وَما تُنفِقوا مِن شَيءٍ في سَبيلِ اللَّهِ يُوَفَّ إِلَيكُم وَأَنتُم لا تُظلَمونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mccxxi{۞ وَإِن جَنَحوا لِلسَّلمِ فَاجنَح لَها وَتَوَكَّل عَلَى اللَّهِ ۚ إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mccxxii{وَإِن يُريدوا أَن يَخدَعوكَ فَإِنَّ حَسبَكَ اللَّهُ ۚ هُوَ الَّذي أَيَّدَكَ بِنَصرِهِ وَبِالمُؤمِنينَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mccxxiii{وَأَلَّفَ بَينَ قُلوبِهِم ۚ لَو أَنفَقتَ ما فِي الأَرضِ جَميعًا ما أَلَّفتَ بَينَ قُلوبِهِم وَلٰكِنَّ اللَّهَ أَلَّفَ بَينَهُم ۚ إِنَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mccxxiv{يا أَيُّهَا النَّبِيُّ حَسبُكَ اللَّهُ وَمَنِ اتَّبَعَكَ مِنَ المُؤمِنينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mccxxv{يا أَيُّهَا النَّبِيُّ حَرِّضِ المُؤمِنينَ عَلَى القِتالِ ۚ إِن يَكُن مِنكُم عِشرونَ صابِرونَ يَغلِبوا مِائَتَينِ ۚ وَإِن يَكُن مِنكُم مِائَةٌ يَغلِبوا أَلفًا مِنَ الَّذينَ كَفَروا بِأَنَّهُم قَومٌ لا يَفقَهونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mccxxvi{الآنَ خَفَّفَ اللَّهُ عَنكُم وَعَلِمَ أَنَّ فيكُم ضَعفًا ۚ فَإِن يَكُن مِنكُم مِائَةٌ صابِرَةٌ يَغلِبوا مِائَتَينِ ۚ وَإِن يَكُن مِنكُم أَلفٌ يَغلِبوا أَلفَينِ بِإِذنِ اللَّهِ ۗ وَاللَّهُ مَعَ الصّابِرينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mccxxvii{ما كانَ لِنَبِيٍّ أَن يَكونَ لَهُ أَسرىٰ حَتّىٰ يُثخِنَ فِي الأَرضِ ۚ تُريدونَ عَرَضَ الدُّنيا وَاللَّهُ يُريدُ الآخِرَةَ ۗ وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mccxxviii{لَولا كِتابٌ مِنَ اللَّهِ سَبَقَ لَمَسَّكُم فيما أَخَذتُم عَذابٌ عَظيمٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mccxxix{فَكُلوا مِمّا غَنِمتُم حَلالًا طَيِّبًا ۚ وَاتَّقُوا اللَّهَ ۚ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mccxxx{يا أَيُّهَا النَّبِيُّ قُل لِمَن في أَيديكُم مِنَ الأَسرىٰ إِن يَعلَمِ اللَّهُ في قُلوبِكُم خَيرًا يُؤتِكُم خَيرًا مِمّا أُخِذَ مِنكُم وَيَغفِر لَكُم ۗ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mccxxxi{وَإِن يُريدوا خِيانَتَكَ فَقَد خانُوا اللَّهَ مِن قَبلُ فَأَمكَنَ مِنهُم ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mccxxxii{إِنَّ الَّذينَ آمَنوا وَهاجَروا وَجاهَدوا بِأَموالِهِم وَأَنفُسِهِم في سَبيلِ اللَّهِ وَالَّذينَ آوَوا وَنَصَروا أُولٰئِكَ بَعضُهُم أَولِياءُ بَعضٍ ۚ وَالَّذينَ آمَنوا وَلَم يُهاجِروا ما لَكُم مِن وَلايَتِهِم مِن شَيءٍ حَتّىٰ يُهاجِروا ۚ وَإِنِ استَنصَروكُم فِي الدّينِ فَعَلَيكُمُ النَّصرُ إِلّا عَلىٰ قَومٍ بَينَكُم وَبَينَهُم ميثاقٌ ۗ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mccxxxiii{وَالَّذينَ كَفَروا بَعضُهُم أَولِياءُ بَعضٍ ۚ إِلّا تَفعَلوهُ تَكُن فِتنَةٌ فِي الأَرضِ وَفَسادٌ كَبيرٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mccxxxiv{وَالَّذينَ آمَنوا وَهاجَروا وَجاهَدوا في سَبيلِ اللَّهِ وَالَّذينَ آوَوا وَنَصَروا أُولٰئِكَ هُمُ المُؤمِنونَ حَقًّا ۚ لَهُم مَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mccxxxv{وَالَّذينَ آمَنوا مِن بَعدُ وَهاجَروا وَجاهَدوا مَعَكُم فَأُولٰئِكَ مِنكُم ۚ وَأُولُو الأَرحامِ بَعضُهُم أَولىٰ بِبَعضٍ في كِتابِ اللَّهِ ۗ إِنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mccxxxvi{بَراءَةٌ مِنَ اللَّهِ وَرَسولِهِ إِلَى الَّذينَ عاهَدتُم مِنَ المُشرِكينَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mccxxxvii{فَسيحوا فِي الأَرضِ أَربَعَةَ أَشهُرٍ وَاعلَموا أَنَّكُم غَيرُ مُعجِزِي اللَّهِ ۙ وَأَنَّ اللَّهَ مُخزِي الكافِرينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mccxxxviii{وَأَذانٌ مِنَ اللَّهِ وَرَسولِهِ إِلَى النّاسِ يَومَ الحَجِّ الأَكبَرِ أَنَّ اللَّهَ بَريءٌ مِنَ المُشرِكينَ ۙ وَرَسولُهُ ۚ فَإِن تُبتُم فَهُوَ خَيرٌ لَكُم ۖ وَإِن تَوَلَّيتُم فَاعلَموا أَنَّكُم غَيرُ مُعجِزِي اللَّهِ ۗ وَبَشِّرِ الَّذينَ كَفَروا بِعَذابٍ أَليمٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mccxxxix{إِلَّا الَّذينَ عاهَدتُم مِنَ المُشرِكينَ ثُمَّ لَم يَنقُصوكُم شَيئًا وَلَم يُظاهِروا عَلَيكُم أَحَدًا فَأَتِمّوا إِلَيهِم عَهدَهُم إِلىٰ مُدَّتِهِم ۚ إِنَّ اللَّهَ يُحِبُّ المُتَّقينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mccxl{فَإِذَا انسَلَخَ الأَشهُرُ الحُرُمُ فَاقتُلُوا المُشرِكينَ حَيثُ وَجَدتُموهُم وَخُذوهُم وَاحصُروهُم وَاقعُدوا لَهُم كُلَّ مَرصَدٍ ۚ فَإِن تابوا وَأَقامُوا الصَّلاةَ وَآتَوُا الزَّكاةَ فَخَلّوا سَبيلَهُم ۚ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mccxli{وَإِن أَحَدٌ مِنَ المُشرِكينَ استَجارَكَ فَأَجِرهُ حَتّىٰ يَسمَعَ كَلامَ اللَّهِ ثُمَّ أَبلِغهُ مَأمَنَهُ ۚ ذٰلِكَ بِأَنَّهُم قَومٌ لا يَعلَمونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mccxlii{كَيفَ يَكونُ لِلمُشرِكينَ عَهدٌ عِندَ اللَّهِ وَعِندَ رَسولِهِ إِلَّا الَّذينَ عاهَدتُم عِندَ المَسجِدِ الحَرامِ ۖ فَمَا استَقاموا لَكُم فَاستَقيموا لَهُم ۚ إِنَّ اللَّهَ يُحِبُّ المُتَّقينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mccxliii{كَيفَ وَإِن يَظهَروا عَلَيكُم لا يَرقُبوا فيكُم إِلًّا وَلا ذِمَّةً ۚ يُرضونَكُم بِأَفواهِهِم وَتَأبىٰ قُلوبُهُم وَأَكثَرُهُم فاسِقونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mccxliv{اشتَرَوا بِآياتِ اللَّهِ ثَمَنًا قَليلًا فَصَدّوا عَن سَبيلِهِ ۚ إِنَّهُم ساءَ ما كانوا يَعمَلونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mccxlv{لا يَرقُبونَ في مُؤمِنٍ إِلًّا وَلا ذِمَّةً ۚ وَأُولٰئِكَ هُمُ المُعتَدونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mccxlvi{فَإِن تابوا وَأَقامُوا الصَّلاةَ وَآتَوُا الزَّكاةَ فَإِخوانُكُم فِي الدّينِ ۗ وَنُفَصِّلُ الآياتِ لِقَومٍ يَعلَمونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mccxlvii{وَإِن نَكَثوا أَيمانَهُم مِن بَعدِ عَهدِهِم وَطَعَنوا في دينِكُم فَقاتِلوا أَئِمَّةَ الكُفرِ ۙ إِنَّهُم لا أَيمانَ لَهُم لَعَلَّهُم يَنتَهونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mccxlviii{أَلا تُقاتِلونَ قَومًا نَكَثوا أَيمانَهُم وَهَمّوا بِإِخراجِ الرَّسولِ وَهُم بَدَءوكُم أَوَّلَ مَرَّةٍ ۚ أَتَخشَونَهُم ۚ فَاللَّهُ أَحَقُّ أَن تَخشَوهُ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mccxlix{قاتِلوهُم يُعَذِّبهُمُ اللَّهُ بِأَيديكُم وَيُخزِهِم وَيَنصُركُم عَلَيهِم وَيَشفِ صُدورَ قَومٍ مُؤمِنينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mccl{وَيُذهِب غَيظَ قُلوبِهِم ۗ وَيَتوبُ اللَّهُ عَلىٰ مَن يَشاءُ ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mccli{أَم حَسِبتُم أَن تُترَكوا وَلَمّا يَعلَمِ اللَّهُ الَّذينَ جاهَدوا مِنكُم وَلَم يَتَّخِذوا مِن دونِ اللَّهِ وَلا رَسولِهِ وَلَا المُؤمِنينَ وَليجَةً ۚ وَاللَّهُ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mcclii{ما كانَ لِلمُشرِكينَ أَن يَعمُروا مَساجِدَ اللَّهِ شاهِدينَ عَلىٰ أَنفُسِهِم بِالكُفرِ ۚ أُولٰئِكَ حَبِطَت أَعمالُهُم وَفِي النّارِ هُم خالِدونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mccliii{إِنَّما يَعمُرُ مَساجِدَ اللَّهِ مَن آمَنَ بِاللَّهِ وَاليَومِ الآخِرِ وَأَقامَ الصَّلاةَ وَآتَى الزَّكاةَ وَلَم يَخشَ إِلَّا اللَّهَ ۖ فَعَسىٰ أُولٰئِكَ أَن يَكونوا مِنَ المُهتَدينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mccliv{۞ أَجَعَلتُم سِقايَةَ الحاجِّ وَعِمارَةَ المَسجِدِ الحَرامِ كَمَن آمَنَ بِاللَّهِ وَاليَومِ الآخِرِ وَجاهَدَ في سَبيلِ اللَّهِ ۚ لا يَستَوونَ عِندَ اللَّهِ ۗ وَاللَّهُ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mcclv{الَّذينَ آمَنوا وَهاجَروا وَجاهَدوا في سَبيلِ اللَّهِ بِأَموالِهِم وَأَنفُسِهِم أَعظَمُ دَرَجَةً عِندَ اللَّهِ ۚ وَأُولٰئِكَ هُمُ الفائِزونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mcclvi{يُبَشِّرُهُم رَبُّهُم بِرَحمَةٍ مِنهُ وَرِضوانٍ وَجَنّاتٍ لَهُم فيها نَعيمٌ مُقيمٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mcclvii{خالِدينَ فيها أَبَدًا ۚ إِنَّ اللَّهَ عِندَهُ أَجرٌ عَظيمٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mcclviii{يا أَيُّهَا الَّذينَ آمَنوا لا تَتَّخِذوا آباءَكُم وَإِخوانَكُم أَولِياءَ إِنِ استَحَبُّوا الكُفرَ عَلَى الإيمانِ ۚ وَمَن يَتَوَلَّهُم مِنكُم فَأُولٰئِكَ هُمُ الظّالِمونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mcclix{قُل إِن كانَ آباؤُكُم وَأَبناؤُكُم وَإِخوانُكُم وَأَزواجُكُم وَعَشيرَتُكُم وَأَموالٌ اقتَرَفتُموها وَتِجارَةٌ تَخشَونَ كَسادَها وَمَساكِنُ تَرضَونَها أَحَبَّ إِلَيكُم مِنَ اللَّهِ وَرَسولِهِ وَجِهادٍ في سَبيلِهِ فَتَرَبَّصوا حَتّىٰ يَأتِيَ اللَّهُ بِأَمرِهِ ۗ وَاللَّهُ لا يَهدِي القَومَ الفاسِقينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mcclx{لَقَد نَصَرَكُمُ اللَّهُ في مَواطِنَ كَثيرَةٍ ۙ وَيَومَ حُنَينٍ ۙ إِذ أَعجَبَتكُم كَثرَتُكُم فَلَم تُغنِ عَنكُم شَيئًا وَضاقَت عَلَيكُمُ الأَرضُ بِما رَحُبَت ثُمَّ وَلَّيتُم مُدبِرينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcclxi{ثُمَّ أَنزَلَ اللَّهُ سَكينَتَهُ عَلىٰ رَسولِهِ وَعَلَى المُؤمِنينَ وَأَنزَلَ جُنودًا لَم تَرَوها وَعَذَّبَ الَّذينَ كَفَروا ۚ وَذٰلِكَ جَزاءُ الكافِرينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mcclxii{ثُمَّ يَتوبُ اللَّهُ مِن بَعدِ ذٰلِكَ عَلىٰ مَن يَشاءُ ۗ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mcclxiii{يا أَيُّهَا الَّذينَ آمَنوا إِنَّمَا المُشرِكونَ نَجَسٌ فَلا يَقرَبُوا المَسجِدَ الحَرامَ بَعدَ عامِهِم هٰذا ۚ وَإِن خِفتُم عَيلَةً فَسَوفَ يُغنيكُمُ اللَّهُ مِن فَضلِهِ إِن شاءَ ۚ إِنَّ اللَّهَ عَليمٌ حَكيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mcclxiv{قاتِلُوا الَّذينَ لا يُؤمِنونَ بِاللَّهِ وَلا بِاليَومِ الآخِرِ وَلا يُحَرِّمونَ ما حَرَّمَ اللَّهُ وَرَسولُهُ وَلا يَدينونَ دينَ الحَقِّ مِنَ الَّذينَ أوتُوا الكِتابَ حَتّىٰ يُعطُوا الجِزيَةَ عَن يَدٍ وَهُم صاغِرونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcclxv{وَقالَتِ اليَهودُ عُزَيرٌ ابنُ اللَّهِ وَقالَتِ النَّصارَى المَسيحُ ابنُ اللَّهِ ۖ ذٰلِكَ قَولُهُم بِأَفواهِهِم ۖ يُضاهِئونَ قَولَ الَّذينَ كَفَروا مِن قَبلُ ۚ قاتَلَهُمُ اللَّهُ ۚ أَنّىٰ يُؤفَكونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcclxvi{اتَّخَذوا أَحبارَهُم وَرُهبانَهُم أَربابًا مِن دونِ اللَّهِ وَالمَسيحَ ابنَ مَريَمَ وَما أُمِروا إِلّا لِيَعبُدوا إِلٰهًا واحِدًا ۖ لا إِلٰهَ إِلّا هُوَ ۚ سُبحانَهُ عَمّا يُشرِكونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcclxvii{يُريدونَ أَن يُطفِئوا نورَ اللَّهِ بِأَفواهِهِم وَيَأبَى اللَّهُ إِلّا أَن يُتِمَّ نورَهُ وَلَو كَرِهَ الكافِرونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcclxviii{هُوَ الَّذي أَرسَلَ رَسولَهُ بِالهُدىٰ وَدينِ الحَقِّ لِيُظهِرَهُ عَلَى الدّينِ كُلِّهِ وَلَو كَرِهَ المُشرِكونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcclxix{۞ يا أَيُّهَا الَّذينَ آمَنوا إِنَّ كَثيرًا مِنَ الأَحبارِ وَالرُّهبانِ لَيَأكُلونَ أَموالَ النّاسِ بِالباطِلِ وَيَصُدّونَ عَن سَبيلِ اللَّهِ ۗ وَالَّذينَ يَكنِزونَ الذَّهَبَ وَالفِضَّةَ وَلا يُنفِقونَها في سَبيلِ اللَّهِ فَبَشِّرهُم بِعَذابٍ أَليمٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcclxx{يَومَ يُحمىٰ عَلَيها في نارِ جَهَنَّمَ فَتُكوىٰ بِها جِباهُهُم وَجُنوبُهُم وَظُهورُهُم ۖ هٰذا ما كَنَزتُم لِأَنفُسِكُم فَذوقوا ما كُنتُم تَكنِزونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcclxxi{إِنَّ عِدَّةَ الشُّهورِ عِندَ اللَّهِ اثنا عَشَرَ شَهرًا في كِتابِ اللَّهِ يَومَ خَلَقَ السَّماواتِ وَالأَرضَ مِنها أَربَعَةٌ حُرُمٌ ۚ ذٰلِكَ الدّينُ القَيِّمُ ۚ فَلا تَظلِموا فيهِنَّ أَنفُسَكُم ۚ وَقاتِلُوا المُشرِكينَ كافَّةً كَما يُقاتِلونَكُم كافَّةً ۚ وَاعلَموا أَنَّ اللَّهَ مَعَ المُتَّقينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcclxxii{إِنَّمَا النَّسيءُ زِيادَةٌ فِي الكُفرِ ۖ يُضَلُّ بِهِ الَّذينَ كَفَروا يُحِلّونَهُ عامًا وَيُحَرِّمونَهُ عامًا لِيُواطِئوا عِدَّةَ ما حَرَّمَ اللَّهُ فَيُحِلّوا ما حَرَّمَ اللَّهُ ۚ زُيِّنَ لَهُم سوءُ أَعمالِهِم ۗ وَاللَّهُ لا يَهدِي القَومَ الكافِرينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcclxxiii{يا أَيُّهَا الَّذينَ آمَنوا ما لَكُم إِذا قيلَ لَكُمُ انفِروا في سَبيلِ اللَّهِ اثّاقَلتُم إِلَى الأَرضِ ۚ أَرَضيتُم بِالحَياةِ الدُّنيا مِنَ الآخِرَةِ ۚ فَما مَتاعُ الحَياةِ الدُّنيا فِي الآخِرَةِ إِلّا قَليلٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcclxxiv{إِلّا تَنفِروا يُعَذِّبكُم عَذابًا أَليمًا وَيَستَبدِل قَومًا غَيرَكُم وَلا تَضُرّوهُ شَيئًا ۗ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcclxxv{إِلّا تَنصُروهُ فَقَد نَصَرَهُ اللَّهُ إِذ أَخرَجَهُ الَّذينَ كَفَروا ثانِيَ اثنَينِ إِذ هُما فِي الغارِ إِذ يَقولُ لِصاحِبِهِ لا تَحزَن إِنَّ اللَّهَ مَعَنا ۖ فَأَنزَلَ اللَّهُ سَكينَتَهُ عَلَيهِ وَأَيَّدَهُ بِجُنودٍ لَم تَرَوها وَجَعَلَ كَلِمَةَ الَّذينَ كَفَرُوا السُّفلىٰ ۗ وَكَلِمَةُ اللَّهِ هِيَ العُليا ۗ وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcclxxvi{انفِروا خِفافًا وَثِقالًا وَجاهِدوا بِأَموالِكُم وَأَنفُسِكُم في سَبيلِ اللَّهِ ۚ ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mcclxxvii{لَو كانَ عَرَضًا قَريبًا وَسَفَرًا قاصِدًا لَاتَّبَعوكَ وَلٰكِن بَعُدَت عَلَيهِمُ الشُّقَّةُ ۚ وَسَيَحلِفونَ بِاللَّهِ لَوِ استَطَعنا لَخَرَجنا مَعَكُم يُهلِكونَ أَنفُسَهُم وَاللَّهُ يَعلَمُ إِنَّهُم لَكاذِبونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcclxxviii{عَفَا اللَّهُ عَنكَ لِمَ أَذِنتَ لَهُم حَتّىٰ يَتَبَيَّنَ لَكَ الَّذينَ صَدَقوا وَتَعلَمَ الكاذِبينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcclxxix{لا يَستَأذِنُكَ الَّذينَ يُؤمِنونَ بِاللَّهِ وَاليَومِ الآخِرِ أَن يُجاهِدوا بِأَموالِهِم وَأَنفُسِهِم ۗ وَاللَّهُ عَليمٌ بِالمُتَّقينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mcclxxx{إِنَّما يَستَأذِنُكَ الَّذينَ لا يُؤمِنونَ بِاللَّهِ وَاليَومِ الآخِرِ وَارتابَت قُلوبُهُم فَهُم في رَيبِهِم يَتَرَدَّدونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mcclxxxi{۞ وَلَو أَرادُوا الخُروجَ لَأَعَدّوا لَهُ عُدَّةً وَلٰكِن كَرِهَ اللَّهُ انبِعاثَهُم فَثَبَّطَهُم وَقيلَ اقعُدوا مَعَ القاعِدينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mcclxxxii{لَو خَرَجوا فيكُم ما زادوكُم إِلّا خَبالًا وَلَأَوضَعوا خِلالَكُم يَبغونَكُمُ الفِتنَةَ وَفيكُم سَمّاعونَ لَهُم ۗ وَاللَّهُ عَليمٌ بِالظّالِمينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mcclxxxiii{لَقَدِ ابتَغَوُا الفِتنَةَ مِن قَبلُ وَقَلَّبوا لَكَ الأُمورَ حَتّىٰ جاءَ الحَقُّ وَظَهَرَ أَمرُ اللَّهِ وَهُم كارِهونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mcclxxxiv{وَمِنهُم مَن يَقولُ ائذَن لي وَلا تَفتِنّي ۚ أَلا فِي الفِتنَةِ سَقَطوا ۗ وَإِنَّ جَهَنَّمَ لَمُحيطَةٌ بِالكافِرينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mcclxxxv{إِن تُصِبكَ حَسَنَةٌ تَسُؤهُم ۖ وَإِن تُصِبكَ مُصيبَةٌ يَقولوا قَد أَخَذنا أَمرَنا مِن قَبلُ وَيَتَوَلَّوا وَهُم فَرِحونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mcclxxxvi{قُل لَن يُصيبَنا إِلّا ما كَتَبَ اللَّهُ لَنا هُوَ مَولانا ۚ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mcclxxxvii{قُل هَل تَرَبَّصونَ بِنا إِلّا إِحدَى الحُسنَيَينِ ۖ وَنَحنُ نَتَرَبَّصُ بِكُم أَن يُصيبَكُمُ اللَّهُ بِعَذابٍ مِن عِندِهِ أَو بِأَيدينا ۖ فَتَرَبَّصوا إِنّا مَعَكُم مُتَرَبِّصونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mcclxxxviii{قُل أَنفِقوا طَوعًا أَو كَرهًا لَن يُتَقَبَّلَ مِنكُم ۖ إِنَّكُم كُنتُم قَومًا فاسِقينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mcclxxxix{وَما مَنَعَهُم أَن تُقبَلَ مِنهُم نَفَقاتُهُم إِلّا أَنَّهُم كَفَروا بِاللَّهِ وَبِرَسولِهِ وَلا يَأتونَ الصَّلاةَ إِلّا وَهُم كُسالىٰ وَلا يُنفِقونَ إِلّا وَهُم كارِهونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mccxc{فَلا تُعجِبكَ أَموالُهُم وَلا أَولادُهُم ۚ إِنَّما يُريدُ اللَّهُ لِيُعَذِّبَهُم بِها فِي الحَياةِ الدُّنيا وَتَزهَقَ أَنفُسُهُم وَهُم كافِرونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mccxci{وَيَحلِفونَ بِاللَّهِ إِنَّهُم لَمِنكُم وَما هُم مِنكُم وَلٰكِنَّهُم قَومٌ يَفرَقونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mccxcii{لَو يَجِدونَ مَلجَأً أَو مَغاراتٍ أَو مُدَّخَلًا لَوَلَّوا إِلَيهِ وَهُم يَجمَحونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mccxciii{وَمِنهُم مَن يَلمِزُكَ فِي الصَّدَقاتِ فَإِن أُعطوا مِنها رَضوا وَإِن لَم يُعطَوا مِنها إِذا هُم يَسخَطونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mccxciv{وَلَو أَنَّهُم رَضوا ما آتاهُمُ اللَّهُ وَرَسولُهُ وَقالوا حَسبُنَا اللَّهُ سَيُؤتينَا اللَّهُ مِن فَضلِهِ وَرَسولُهُ إِنّا إِلَى اللَّهِ راغِبونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mccxcv{۞ إِنَّمَا الصَّدَقاتُ لِلفُقَراءِ وَالمَساكينِ وَالعامِلينَ عَلَيها وَالمُؤَلَّفَةِ قُلوبُهُم وَفِي الرِّقابِ وَالغارِمينَ وَفي سَبيلِ اللَّهِ وَابنِ السَّبيلِ ۖ فَريضَةً مِنَ اللَّهِ ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mccxcvi{وَمِنهُمُ الَّذينَ يُؤذونَ النَّبِيَّ وَيَقولونَ هُوَ أُذُنٌ ۚ قُل أُذُنُ خَيرٍ لَكُم يُؤمِنُ بِاللَّهِ وَيُؤمِنُ لِلمُؤمِنينَ وَرَحمَةٌ لِلَّذينَ آمَنوا مِنكُم ۚ وَالَّذينَ يُؤذونَ رَسولَ اللَّهِ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mccxcvii{يَحلِفونَ بِاللَّهِ لَكُم لِيُرضوكُم وَاللَّهُ وَرَسولُهُ أَحَقُّ أَن يُرضوهُ إِن كانوا مُؤمِنينَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mccxcviii{أَلَم يَعلَموا أَنَّهُ مَن يُحادِدِ اللَّهَ وَرَسولَهُ فَأَنَّ لَهُ نارَ جَهَنَّمَ خالِدًا فيها ۚ ذٰلِكَ الخِزيُ العَظيمُ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mccxcix{يَحذَرُ المُنافِقونَ أَن تُنَزَّلَ عَلَيهِم سورَةٌ تُنَبِّئُهُم بِما في قُلوبِهِم ۚ قُلِ استَهزِئوا إِنَّ اللَّهَ مُخرِجٌ ما تَحذَرونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mccc{وَلَئِن سَأَلتَهُم لَيَقولُنَّ إِنَّما كُنّا نَخوضُ وَنَلعَبُ ۚ قُل أَبِاللَّهِ وَآياتِهِ وَرَسولِهِ كُنتُم تَستَهزِئونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mccci{لا تَعتَذِروا قَد كَفَرتُم بَعدَ إيمانِكُم ۚ إِن نَعفُ عَن طائِفَةٍ مِنكُم نُعَذِّب طائِفَةً بِأَنَّهُم كانوا مُجرِمينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mcccii{المُنافِقونَ وَالمُنافِقاتُ بَعضُهُم مِن بَعضٍ ۚ يَأمُرونَ بِالمُنكَرِ وَيَنهَونَ عَنِ المَعروفِ وَيَقبِضونَ أَيدِيَهُم ۚ نَسُوا اللَّهَ فَنَسِيَهُم ۗ إِنَّ المُنافِقينَ هُمُ الفاسِقونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mccciii{وَعَدَ اللَّهُ المُنافِقينَ وَالمُنافِقاتِ وَالكُفّارَ نارَ جَهَنَّمَ خالِدينَ فيها ۚ هِيَ حَسبُهُم ۚ وَلَعَنَهُمُ اللَّهُ ۖ وَلَهُم عَذابٌ مُقيمٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mccciv{كَالَّذينَ مِن قَبلِكُم كانوا أَشَدَّ مِنكُم قُوَّةً وَأَكثَرَ أَموالًا وَأَولادًا فَاستَمتَعوا بِخَلاقِهِم فَاستَمتَعتُم بِخَلاقِكُم كَمَا استَمتَعَ الَّذينَ مِن قَبلِكُم بِخَلاقِهِم وَخُضتُم كَالَّذي خاضوا ۚ أُولٰئِكَ حَبِطَت أَعمالُهُم فِي الدُّنيا وَالآخِرَةِ ۖ وَأُولٰئِكَ هُمُ الخاسِرونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mcccv{أَلَم يَأتِهِم نَبَأُ الَّذينَ مِن قَبلِهِم قَومِ نوحٍ وَعادٍ وَثَمودَ وَقَومِ إِبراهيمَ وَأَصحابِ مَديَنَ وَالمُؤتَفِكاتِ ۚ أَتَتهُم رُسُلُهُم بِالبَيِّناتِ ۖ فَما كانَ اللَّهُ لِيَظلِمَهُم وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mcccvi{وَالمُؤمِنونَ وَالمُؤمِناتُ بَعضُهُم أَولِياءُ بَعضٍ ۚ يَأمُرونَ بِالمَعروفِ وَيَنهَونَ عَنِ المُنكَرِ وَيُقيمونَ الصَّلاةَ وَيُؤتونَ الزَّكاةَ وَيُطيعونَ اللَّهَ وَرَسولَهُ ۚ أُولٰئِكَ سَيَرحَمُهُمُ اللَّهُ ۗ إِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mcccvii{وَعَدَ اللَّهُ المُؤمِنينَ وَالمُؤمِناتِ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها وَمَساكِنَ طَيِّبَةً في جَنّاتِ عَدنٍ ۚ وَرِضوانٌ مِنَ اللَّهِ أَكبَرُ ۚ ذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mcccviii{يا أَيُّهَا النَّبِيُّ جاهِدِ الكُفّارَ وَالمُنافِقينَ وَاغلُظ عَلَيهِم ۚ وَمَأواهُم جَهَنَّمُ ۖ وَبِئسَ المَصيرُ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mcccix{يَحلِفونَ بِاللَّهِ ما قالوا وَلَقَد قالوا كَلِمَةَ الكُفرِ وَكَفَروا بَعدَ إِسلامِهِم وَهَمّوا بِما لَم يَنالوا ۚ وَما نَقَموا إِلّا أَن أَغناهُمُ اللَّهُ وَرَسولُهُ مِن فَضلِهِ ۚ فَإِن يَتوبوا يَكُ خَيرًا لَهُم ۖ وَإِن يَتَوَلَّوا يُعَذِّبهُمُ اللَّهُ عَذابًا أَليمًا فِي الدُّنيا وَالآخِرَةِ ۚ وَما لَهُم فِي الأَرضِ مِن وَلِيٍّ وَلا نَصيرٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mcccx{۞ وَمِنهُم مَن عاهَدَ اللَّهَ لَئِن آتانا مِن فَضلِهِ لَنَصَّدَّقَنَّ وَلَنَكونَنَّ مِنَ الصّالِحينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mcccxi{فَلَمّا آتاهُم مِن فَضلِهِ بَخِلوا بِهِ وَتَوَلَّوا وَهُم مُعرِضونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mcccxii{فَأَعقَبَهُم نِفاقًا في قُلوبِهِم إِلىٰ يَومِ يَلقَونَهُ بِما أَخلَفُوا اللَّهَ ما وَعَدوهُ وَبِما كانوا يَكذِبونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mcccxiii{أَلَم يَعلَموا أَنَّ اللَّهَ يَعلَمُ سِرَّهُم وَنَجواهُم وَأَنَّ اللَّهَ عَلّامُ الغُيوبِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mcccxiv{الَّذينَ يَلمِزونَ المُطَّوِّعينَ مِنَ المُؤمِنينَ فِي الصَّدَقاتِ وَالَّذينَ لا يَجِدونَ إِلّا جُهدَهُم فَيَسخَرونَ مِنهُم ۙ سَخِرَ اللَّهُ مِنهُم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mcccxv{استَغفِر لَهُم أَو لا تَستَغفِر لَهُم إِن تَستَغفِر لَهُم سَبعينَ مَرَّةً فَلَن يَغفِرَ اللَّهُ لَهُم ۚ ذٰلِكَ بِأَنَّهُم كَفَروا بِاللَّهِ وَرَسولِهِ ۗ وَاللَّهُ لا يَهدِي القَومَ الفاسِقينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mcccxvi{فَرِحَ المُخَلَّفونَ بِمَقعَدِهِم خِلافَ رَسولِ اللَّهِ وَكَرِهوا أَن يُجاهِدوا بِأَموالِهِم وَأَنفُسِهِم في سَبيلِ اللَّهِ وَقالوا لا تَنفِروا فِي الحَرِّ ۗ قُل نارُ جَهَنَّمَ أَشَدُّ حَرًّا ۚ لَو كانوا يَفقَهونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mcccxvii{فَليَضحَكوا قَليلًا وَليَبكوا كَثيرًا جَزاءً بِما كانوا يَكسِبونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mcccxviii{فَإِن رَجَعَكَ اللَّهُ إِلىٰ طائِفَةٍ مِنهُم فَاستَأذَنوكَ لِلخُروجِ فَقُل لَن تَخرُجوا مَعِيَ أَبَدًا وَلَن تُقاتِلوا مَعِيَ عَدُوًّا ۖ إِنَّكُم رَضيتُم بِالقُعودِ أَوَّلَ مَرَّةٍ فَاقعُدوا مَعَ الخالِفينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mcccxix{وَلا تُصَلِّ عَلىٰ أَحَدٍ مِنهُم ماتَ أَبَدًا وَلا تَقُم عَلىٰ قَبرِهِ ۖ إِنَّهُم كَفَروا بِاللَّهِ وَرَسولِهِ وَماتوا وَهُم فاسِقونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mcccxx{وَلا تُعجِبكَ أَموالُهُم وَأَولادُهُم ۚ إِنَّما يُريدُ اللَّهُ أَن يُعَذِّبَهُم بِها فِي الدُّنيا وَتَزهَقَ أَنفُسُهُم وَهُم كافِرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mcccxxi{وَإِذا أُنزِلَت سورَةٌ أَن آمِنوا بِاللَّهِ وَجاهِدوا مَعَ رَسولِهِ استَأذَنَكَ أُولُو الطَّولِ مِنهُم وَقالوا ذَرنا نَكُن مَعَ القاعِدينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mcccxxii{رَضوا بِأَن يَكونوا مَعَ الخَوالِفِ وَطُبِعَ عَلىٰ قُلوبِهِم فَهُم لا يَفقَهونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mcccxxiii{لٰكِنِ الرَّسولُ وَالَّذينَ آمَنوا مَعَهُ جاهَدوا بِأَموالِهِم وَأَنفُسِهِم ۚ وَأُولٰئِكَ لَهُمُ الخَيراتُ ۖ وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mcccxxiv{أَعَدَّ اللَّهُ لَهُم جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها ۚ ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mcccxxv{وَجاءَ المُعَذِّرونَ مِنَ الأَعرابِ لِيُؤذَنَ لَهُم وَقَعَدَ الَّذينَ كَذَبُوا اللَّهَ وَرَسولَهُ ۚ سَيُصيبُ الَّذينَ كَفَروا مِنهُم عَذابٌ أَليمٌ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mcccxxvi{لَيسَ عَلَى الضُّعَفاءِ وَلا عَلَى المَرضىٰ وَلا عَلَى الَّذينَ لا يَجِدونَ ما يُنفِقونَ حَرَجٌ إِذا نَصَحوا لِلَّهِ وَرَسولِهِ ۚ ما عَلَى المُحسِنينَ مِن سَبيلٍ ۚ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mcccxxvii{وَلا عَلَى الَّذينَ إِذا ما أَتَوكَ لِتَحمِلَهُم قُلتَ لا أَجِدُ ما أَحمِلُكُم عَلَيهِ تَوَلَّوا وَأَعيُنُهُم تَفيضُ مِنَ الدَّمعِ حَزَنًا أَلّا يَجِدوا ما يُنفِقونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mcccxxviii{۞ إِنَّمَا السَّبيلُ عَلَى الَّذينَ يَستَأذِنونَكَ وَهُم أَغنِياءُ ۚ رَضوا بِأَن يَكونوا مَعَ الخَوالِفِ وَطَبَعَ اللَّهُ عَلىٰ قُلوبِهِم فَهُم لا يَعلَمونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mcccxxix{يَعتَذِرونَ إِلَيكُم إِذا رَجَعتُم إِلَيهِم ۚ قُل لا تَعتَذِروا لَن نُؤمِنَ لَكُم قَد نَبَّأَنَا اللَّهُ مِن أَخبارِكُم ۚ وَسَيَرَى اللَّهُ عَمَلَكُم وَرَسولُهُ ثُمَّ تُرَدّونَ إِلىٰ عالِمِ الغَيبِ وَالشَّهادَةِ فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mcccxxx{سَيَحلِفونَ بِاللَّهِ لَكُم إِذَا انقَلَبتُم إِلَيهِم لِتُعرِضوا عَنهُم ۖ فَأَعرِضوا عَنهُم ۖ إِنَّهُم رِجسٌ ۖ وَمَأواهُم جَهَنَّمُ جَزاءً بِما كانوا يَكسِبونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mcccxxxi{يَحلِفونَ لَكُم لِتَرضَوا عَنهُم ۖ فَإِن تَرضَوا عَنهُم فَإِنَّ اللَّهَ لا يَرضىٰ عَنِ القَومِ الفاسِقينَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mcccxxxii{الأَعرابُ أَشَدُّ كُفرًا وَنِفاقًا وَأَجدَرُ أَلّا يَعلَموا حُدودَ ما أَنزَلَ اللَّهُ عَلىٰ رَسولِهِ ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcccxxxiii{وَمِنَ الأَعرابِ مَن يَتَّخِذُ ما يُنفِقُ مَغرَمًا وَيَتَرَبَّصُ بِكُمُ الدَّوائِرَ ۚ عَلَيهِم دائِرَةُ السَّوءِ ۗ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mcccxxxiv{وَمِنَ الأَعرابِ مَن يُؤمِنُ بِاللَّهِ وَاليَومِ الآخِرِ وَيَتَّخِذُ ما يُنفِقُ قُرُباتٍ عِندَ اللَّهِ وَصَلَواتِ الرَّسولِ ۚ أَلا إِنَّها قُربَةٌ لَهُم ۚ سَيُدخِلُهُمُ اللَّهُ في رَحمَتِهِ ۗ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mcccxxxv{وَالسّابِقونَ الأَوَّلونَ مِنَ المُهاجِرينَ وَالأَنصارِ وَالَّذينَ اتَّبَعوهُم بِإِحسانٍ رَضِيَ اللَّهُ عَنهُم وَرَضوا عَنهُ وَأَعَدَّ لَهُم جَنّاتٍ تَجري تَحتَهَا الأَنهارُ خالِدينَ فيها أَبَدًا ۚ ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mcccxxxvi{وَمِمَّن حَولَكُم مِنَ الأَعرابِ مُنافِقونَ ۖ وَمِن أَهلِ المَدينَةِ ۖ مَرَدوا عَلَى النِّفاقِ لا تَعلَمُهُم ۖ نَحنُ نَعلَمُهُم ۚ سَنُعَذِّبُهُم مَرَّتَينِ ثُمَّ يُرَدّونَ إِلىٰ عَذابٍ عَظيمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mcccxxxvii{وَآخَرونَ اعتَرَفوا بِذُنوبِهِم خَلَطوا عَمَلًا صالِحًا وَآخَرَ سَيِّئًا عَسَى اللَّهُ أَن يَتوبَ عَلَيهِم ۚ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mcccxxxviii{خُذ مِن أَموالِهِم صَدَقَةً تُطَهِّرُهُم وَتُزَكّيهِم بِها وَصَلِّ عَلَيهِم ۖ إِنَّ صَلاتَكَ سَكَنٌ لَهُم ۗ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mcccxxxix{أَلَم يَعلَموا أَنَّ اللَّهَ هُوَ يَقبَلُ التَّوبَةَ عَن عِبادِهِ وَيَأخُذُ الصَّدَقاتِ وَأَنَّ اللَّهَ هُوَ التَّوّابُ الرَّحيمُ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mcccxl{وَقُلِ اعمَلوا فَسَيَرَى اللَّهُ عَمَلَكُم وَرَسولُهُ وَالمُؤمِنونَ ۖ وَسَتُرَدّونَ إِلىٰ عالِمِ الغَيبِ وَالشَّهادَةِ فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mcccxli{وَآخَرونَ مُرجَونَ لِأَمرِ اللَّهِ إِمّا يُعَذِّبُهُم وَإِمّا يَتوبُ عَلَيهِم ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mcccxlii{وَالَّذينَ اتَّخَذوا مَسجِدًا ضِرارًا وَكُفرًا وَتَفريقًا بَينَ المُؤمِنينَ وَإِرصادًا لِمَن حارَبَ اللَّهَ وَرَسولَهُ مِن قَبلُ ۚ وَلَيَحلِفُنَّ إِن أَرَدنا إِلَّا الحُسنىٰ ۖ وَاللَّهُ يَشهَدُ إِنَّهُم لَكاذِبونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mcccxliii{لا تَقُم فيهِ أَبَدًا ۚ لَمَسجِدٌ أُسِّسَ عَلَى التَّقوىٰ مِن أَوَّلِ يَومٍ أَحَقُّ أَن تَقومَ فيهِ ۚ فيهِ رِجالٌ يُحِبّونَ أَن يَتَطَهَّروا ۚ وَاللَّهُ يُحِبُّ المُطَّهِّرينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mcccxliv{أَفَمَن أَسَّسَ بُنيانَهُ عَلىٰ تَقوىٰ مِنَ اللَّهِ وَرِضوانٍ خَيرٌ أَم مَن أَسَّسَ بُنيانَهُ عَلىٰ شَفا جُرُفٍ هارٍ فَانهارَ بِهِ في نارِ جَهَنَّمَ ۗ وَاللَّهُ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mcccxlv{لا يَزالُ بُنيانُهُمُ الَّذي بَنَوا ريبَةً في قُلوبِهِم إِلّا أَن تَقَطَّعَ قُلوبُهُم ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mcccxlvi{۞ إِنَّ اللَّهَ اشتَرىٰ مِنَ المُؤمِنينَ أَنفُسَهُم وَأَموالَهُم بِأَنَّ لَهُمُ الجَنَّةَ ۚ يُقاتِلونَ في سَبيلِ اللَّهِ فَيَقتُلونَ وَيُقتَلونَ ۖ وَعدًا عَلَيهِ حَقًّا فِي التَّوراةِ وَالإِنجيلِ وَالقُرآنِ ۚ وَمَن أَوفىٰ بِعَهدِهِ مِنَ اللَّهِ ۚ فَاستَبشِروا بِبَيعِكُمُ الَّذي بايَعتُم بِهِ ۚ وَذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mcccxlvii{التّائِبونَ العابِدونَ الحامِدونَ السّائِحونَ الرّاكِعونَ السّاجِدونَ الآمِرونَ بِالمَعروفِ وَالنّاهونَ عَنِ المُنكَرِ وَالحافِظونَ لِحُدودِ اللَّهِ ۗ وَبَشِّرِ المُؤمِنينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mcccxlviii{ما كانَ لِلنَّبِيِّ وَالَّذينَ آمَنوا أَن يَستَغفِروا لِلمُشرِكينَ وَلَو كانوا أُولي قُربىٰ مِن بَعدِ ما تَبَيَّنَ لَهُم أَنَّهُم أَصحابُ الجَحيمِ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mcccxlix{وَما كانَ استِغفارُ إِبراهيمَ لِأَبيهِ إِلّا عَن مَوعِدَةٍ وَعَدَها إِيّاهُ فَلَمّا تَبَيَّنَ لَهُ أَنَّهُ عَدُوٌّ لِلَّهِ تَبَرَّأَ مِنهُ ۚ إِنَّ إِبراهيمَ لَأَوّاهٌ حَليمٌ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mcccl{وَما كانَ اللَّهُ لِيُضِلَّ قَومًا بَعدَ إِذ هَداهُم حَتّىٰ يُبَيِّنَ لَهُم ما يَتَّقونَ ۚ إِنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mcccli{إِنَّ اللَّهَ لَهُ مُلكُ السَّماواتِ وَالأَرضِ ۖ يُحيي وَيُميتُ ۚ وَما لَكُم مِن دونِ اللَّهِ مِن وَلِيٍّ وَلا نَصيرٍ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mccclii{لَقَد تابَ اللَّهُ عَلَى النَّبِيِّ وَالمُهاجِرينَ وَالأَنصارِ الَّذينَ اتَّبَعوهُ في ساعَةِ العُسرَةِ مِن بَعدِ ما كادَ يَزيغُ قُلوبُ فَريقٍ مِنهُم ثُمَّ تابَ عَلَيهِم ۚ إِنَّهُ بِهِم رَءوفٌ رَحيمٌ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mcccliii{وَعَلَى الثَّلاثَةِ الَّذينَ خُلِّفوا حَتّىٰ إِذا ضاقَت عَلَيهِمُ الأَرضُ بِما رَحُبَت وَضاقَت عَلَيهِم أَنفُسُهُم وَظَنّوا أَن لا مَلجَأَ مِنَ اللَّهِ إِلّا إِلَيهِ ثُمَّ تابَ عَلَيهِم لِيَتوبوا ۚ إِنَّ اللَّهَ هُوَ التَّوّابُ الرَّحيمُ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mcccliv{يا أَيُّهَا الَّذينَ آمَنُوا اتَّقُوا اللَّهَ وَكونوا مَعَ الصّادِقينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mccclv{ما كانَ لِأَهلِ المَدينَةِ وَمَن حَولَهُم مِنَ الأَعرابِ أَن يَتَخَلَّفوا عَن رَسولِ اللَّهِ وَلا يَرغَبوا بِأَنفُسِهِم عَن نَفسِهِ ۚ ذٰلِكَ بِأَنَّهُم لا يُصيبُهُم ظَمَأٌ وَلا نَصَبٌ وَلا مَخمَصَةٌ في سَبيلِ اللَّهِ وَلا يَطَئونَ مَوطِئًا يَغيظُ الكُفّارَ وَلا يَنالونَ مِن عَدُوٍّ نَيلًا إِلّا كُتِبَ لَهُم بِهِ عَمَلٌ صالِحٌ ۚ إِنَّ اللَّهَ لا يُضيعُ أَجرَ المُحسِنينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mccclvi{وَلا يُنفِقونَ نَفَقَةً صَغيرَةً وَلا كَبيرَةً وَلا يَقطَعونَ وادِيًا إِلّا كُتِبَ لَهُم لِيَجزِيَهُمُ اللَّهُ أَحسَنَ ما كانوا يَعمَلونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mccclvii{۞ وَما كانَ المُؤمِنونَ لِيَنفِروا كافَّةً ۚ فَلَولا نَفَرَ مِن كُلِّ فِرقَةٍ مِنهُم طائِفَةٌ لِيَتَفَقَّهوا فِي الدّينِ وَلِيُنذِروا قَومَهُم إِذا رَجَعوا إِلَيهِم لَعَلَّهُم يَحذَرونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mccclviii{يا أَيُّهَا الَّذينَ آمَنوا قاتِلُوا الَّذينَ يَلونَكُم مِنَ الكُفّارِ وَليَجِدوا فيكُم غِلظَةً ۚ وَاعلَموا أَنَّ اللَّهَ مَعَ المُتَّقينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mccclix{وَإِذا ما أُنزِلَت سورَةٌ فَمِنهُم مَن يَقولُ أَيُّكُم زادَتهُ هٰذِهِ إيمانًا ۚ فَأَمَّا الَّذينَ آمَنوا فَزادَتهُم إيمانًا وَهُم يَستَبشِرونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mccclx{وَأَمَّا الَّذينَ في قُلوبِهِم مَرَضٌ فَزادَتهُم رِجسًا إِلىٰ رِجسِهِم وَماتوا وَهُم كافِرونَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mccclxi{أَوَلا يَرَونَ أَنَّهُم يُفتَنونَ في كُلِّ عامٍ مَرَّةً أَو مَرَّتَينِ ثُمَّ لا يَتوبونَ وَلا هُم يَذَّكَّرونَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mccclxii{وَإِذا ما أُنزِلَت سورَةٌ نَظَرَ بَعضُهُم إِلىٰ بَعضٍ هَل يَراكُم مِن أَحَدٍ ثُمَّ انصَرَفوا ۚ صَرَفَ اللَّهُ قُلوبَهُم بِأَنَّهُم قَومٌ لا يَفقَهونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mccclxiii{لَقَد جاءَكُم رَسولٌ مِن أَنفُسِكُم عَزيزٌ عَلَيهِ ما عَنِتُّم حَريصٌ عَلَيكُم بِالمُؤمِنينَ رَءوفٌ رَحيمٌ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mccclxiv{فَإِن تَوَلَّوا فَقُل حَسبِيَ اللَّهُ لا إِلٰهَ إِلّا هُوَ ۖ عَلَيهِ تَوَكَّلتُ ۖ وَهُوَ رَبُّ العَرشِ العَظيمِ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mccclxv{\basmalah الر ۚ تِلكَ آياتُ الكِتابِ الحَكيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mccclxvi{أَكانَ لِلنّاسِ عَجَبًا أَن أَوحَينا إِلىٰ رَجُلٍ مِنهُم أَن أَنذِرِ النّاسَ وَبَشِّرِ الَّذينَ آمَنوا أَنَّ لَهُم قَدَمَ صِدقٍ عِندَ رَبِّهِم ۗ قالَ الكافِرونَ إِنَّ هٰذا لَساحِرٌ مُبينٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mccclxvii{إِنَّ رَبَّكُمُ اللَّهُ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ في سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ ۖ يُدَبِّرُ الأَمرَ ۖ ما مِن شَفيعٍ إِلّا مِن بَعدِ إِذنِهِ ۚ ذٰلِكُمُ اللَّهُ رَبُّكُم فَاعبُدوهُ ۚ أَفَلا تَذَكَّرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mccclxviii{إِلَيهِ مَرجِعُكُم جَميعًا ۖ وَعدَ اللَّهِ حَقًّا ۚ إِنَّهُ يَبدَأُ الخَلقَ ثُمَّ يُعيدُهُ لِيَجزِيَ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ بِالقِسطِ ۚ وَالَّذينَ كَفَروا لَهُم شَرابٌ مِن حَميمٍ وَعَذابٌ أَليمٌ بِما كانوا يَكفُرونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mccclxix{هُوَ الَّذي جَعَلَ الشَّمسَ ضِياءً وَالقَمَرَ نورًا وَقَدَّرَهُ مَنازِلَ لِتَعلَموا عَدَدَ السِّنينَ وَالحِسابَ ۚ ما خَلَقَ اللَّهُ ذٰلِكَ إِلّا بِالحَقِّ ۚ يُفَصِّلُ الآياتِ لِقَومٍ يَعلَمونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mccclxx{إِنَّ فِي اختِلافِ اللَّيلِ وَالنَّهارِ وَما خَلَقَ اللَّهُ فِي السَّماواتِ وَالأَرضِ لَآياتٍ لِقَومٍ يَتَّقونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mccclxxi{إِنَّ الَّذينَ لا يَرجونَ لِقاءَنا وَرَضوا بِالحَياةِ الدُّنيا وَاطمَأَنّوا بِها وَالَّذينَ هُم عَن آياتِنا غافِلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mccclxxii{أُولٰئِكَ مَأواهُمُ النّارُ بِما كانوا يَكسِبونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mccclxxiii{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ يَهديهِم رَبُّهُم بِإيمانِهِم ۖ تَجري مِن تَحتِهِمُ الأَنهارُ في جَنّاتِ النَّعيمِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mccclxxiv{دَعواهُم فيها سُبحانَكَ اللَّهُمَّ وَتَحِيَّتُهُم فيها سَلامٌ ۚ وَآخِرُ دَعواهُم أَنِ الحَمدُ لِلَّهِ رَبِّ العالَمينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mccclxxv{۞ وَلَو يُعَجِّلُ اللَّهُ لِلنّاسِ الشَّرَّ استِعجالَهُم بِالخَيرِ لَقُضِيَ إِلَيهِم أَجَلُهُم ۖ فَنَذَرُ الَّذينَ لا يَرجونَ لِقاءَنا في طُغيانِهِم يَعمَهونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mccclxxvi{وَإِذا مَسَّ الإِنسانَ الضُّرُّ دَعانا لِجَنبِهِ أَو قاعِدًا أَو قائِمًا فَلَمّا كَشَفنا عَنهُ ضُرَّهُ مَرَّ كَأَن لَم يَدعُنا إِلىٰ ضُرٍّ مَسَّهُ ۚ كَذٰلِكَ زُيِّنَ لِلمُسرِفينَ ما كانوا يَعمَلونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mccclxxvii{وَلَقَد أَهلَكنَا القُرونَ مِن قَبلِكُم لَمّا ظَلَموا ۙ وَجاءَتهُم رُسُلُهُم بِالبَيِّناتِ وَما كانوا لِيُؤمِنوا ۚ كَذٰلِكَ نَجزِي القَومَ المُجرِمينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mccclxxviii{ثُمَّ جَعَلناكُم خَلائِفَ فِي الأَرضِ مِن بَعدِهِم لِنَنظُرَ كَيفَ تَعمَلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mccclxxix{وَإِذا تُتلىٰ عَلَيهِم آياتُنا بَيِّناتٍ ۙ قالَ الَّذينَ لا يَرجونَ لِقاءَنَا ائتِ بِقُرآنٍ غَيرِ هٰذا أَو بَدِّلهُ ۚ قُل ما يَكونُ لي أَن أُبَدِّلَهُ مِن تِلقاءِ نَفسي ۖ إِن أَتَّبِعُ إِلّا ما يوحىٰ إِلَيَّ ۖ إِنّي أَخافُ إِن عَصَيتُ رَبّي عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mccclxxx{قُل لَو شاءَ اللَّهُ ما تَلَوتُهُ عَلَيكُم وَلا أَدراكُم بِهِ ۖ فَقَد لَبِثتُ فيكُم عُمُرًا مِن قَبلِهِ ۚ أَفَلا تَعقِلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mccclxxxi{فَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو كَذَّبَ بِآياتِهِ ۚ إِنَّهُ لا يُفلِحُ المُجرِمونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mccclxxxii{وَيَعبُدونَ مِن دونِ اللَّهِ ما لا يَضُرُّهُم وَلا يَنفَعُهُم وَيَقولونَ هٰؤُلاءِ شُفَعاؤُنا عِندَ اللَّهِ ۚ قُل أَتُنَبِّئونَ اللَّهَ بِما لا يَعلَمُ فِي السَّماواتِ وَلا فِي الأَرضِ ۚ سُبحانَهُ وَتَعالىٰ عَمّا يُشرِكونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mccclxxxiii{وَما كانَ النّاسُ إِلّا أُمَّةً واحِدَةً فَاختَلَفوا ۚ وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ لَقُضِيَ بَينَهُم فيما فيهِ يَختَلِفونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mccclxxxiv{وَيَقولونَ لَولا أُنزِلَ عَلَيهِ آيَةٌ مِن رَبِّهِ ۖ فَقُل إِنَّمَا الغَيبُ لِلَّهِ فَانتَظِروا إِنّي مَعَكُم مِنَ المُنتَظِرينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mccclxxxv{وَإِذا أَذَقنَا النّاسَ رَحمَةً مِن بَعدِ ضَرّاءَ مَسَّتهُم إِذا لَهُم مَكرٌ في آياتِنا ۚ قُلِ اللَّهُ أَسرَعُ مَكرًا ۚ إِنَّ رُسُلَنا يَكتُبونَ ما تَمكُرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mccclxxxvi{هُوَ الَّذي يُسَيِّرُكُم فِي البَرِّ وَالبَحرِ ۖ حَتّىٰ إِذا كُنتُم فِي الفُلكِ وَجَرَينَ بِهِم بِريحٍ طَيِّبَةٍ وَفَرِحوا بِها جاءَتها ريحٌ عاصِفٌ وَجاءَهُمُ المَوجُ مِن كُلِّ مَكانٍ وَظَنّوا أَنَّهُم أُحيطَ بِهِم ۙ دَعَوُا اللَّهَ مُخلِصينَ لَهُ الدّينَ لَئِن أَنجَيتَنا مِن هٰذِهِ لَنَكونَنَّ مِنَ الشّاكِرينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mccclxxxvii{فَلَمّا أَنجاهُم إِذا هُم يَبغونَ فِي الأَرضِ بِغَيرِ الحَقِّ ۗ يا أَيُّهَا النّاسُ إِنَّما بَغيُكُم عَلىٰ أَنفُسِكُم ۖ مَتاعَ الحَياةِ الدُّنيا ۖ ثُمَّ إِلَينا مَرجِعُكُم فَنُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mccclxxxviii{إِنَّما مَثَلُ الحَياةِ الدُّنيا كَماءٍ أَنزَلناهُ مِنَ السَّماءِ فَاختَلَطَ بِهِ نَباتُ الأَرضِ مِمّا يَأكُلُ النّاسُ وَالأَنعامُ حَتّىٰ إِذا أَخَذَتِ الأَرضُ زُخرُفَها وَازَّيَّنَت وَظَنَّ أَهلُها أَنَّهُم قادِرونَ عَلَيها أَتاها أَمرُنا لَيلًا أَو نَهارًا فَجَعَلناها حَصيدًا كَأَن لَم تَغنَ بِالأَمسِ ۚ كَذٰلِكَ نُفَصِّلُ الآياتِ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mccclxxxix{وَاللَّهُ يَدعو إِلىٰ دارِ السَّلامِ وَيَهدي مَن يَشاءُ إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcccxc{۞ لِلَّذينَ أَحسَنُوا الحُسنىٰ وَزِيادَةٌ ۖ وَلا يَرهَقُ وُجوهَهُم قَتَرٌ وَلا ذِلَّةٌ ۚ أُولٰئِكَ أَصحابُ الجَنَّةِ ۖ هُم فيها خالِدونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mcccxci{وَالَّذينَ كَسَبُوا السَّيِّئَاتِ جَزاءُ سَيِّئَةٍ بِمِثلِها وَتَرهَقُهُم ذِلَّةٌ ۖ ما لَهُم مِنَ اللَّهِ مِن عاصِمٍ ۖ كَأَنَّما أُغشِيَت وُجوهُهُم قِطَعًا مِنَ اللَّيلِ مُظلِمًا ۚ أُولٰئِكَ أَصحابُ النّارِ ۖ هُم فيها خالِدونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mcccxcii{وَيَومَ نَحشُرُهُم جَميعًا ثُمَّ نَقولُ لِلَّذينَ أَشرَكوا مَكانَكُم أَنتُم وَشُرَكاؤُكُم ۚ فَزَيَّلنا بَينَهُم ۖ وَقالَ شُرَكاؤُهُم ما كُنتُم إِيّانا تَعبُدونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mcccxciii{فَكَفىٰ بِاللَّهِ شَهيدًا بَينَنا وَبَينَكُم إِن كُنّا عَن عِبادَتِكُم لَغافِلينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcccxciv{هُنالِكَ تَبلو كُلُّ نَفسٍ ما أَسلَفَت ۚ وَرُدّوا إِلَى اللَّهِ مَولاهُمُ الحَقِّ ۖ وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcccxcv{قُل مَن يَرزُقُكُم مِنَ السَّماءِ وَالأَرضِ أَمَّن يَملِكُ السَّمعَ وَالأَبصارَ وَمَن يُخرِجُ الحَيَّ مِنَ المَيِّتِ وَيُخرِجُ المَيِّتَ مِنَ الحَيِّ وَمَن يُدَبِّرُ الأَمرَ ۚ فَسَيَقولونَ اللَّهُ ۚ فَقُل أَفَلا تَتَّقونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcccxcvi{فَذٰلِكُمُ اللَّهُ رَبُّكُمُ الحَقُّ ۖ فَماذا بَعدَ الحَقِّ إِلَّا الضَّلالُ ۖ فَأَنّىٰ تُصرَفونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcccxcvii{كَذٰلِكَ حَقَّت كَلِمَتُ رَبِّكَ عَلَى الَّذينَ فَسَقوا أَنَّهُم لا يُؤمِنونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcccxcviii{قُل هَل مِن شُرَكائِكُم مَن يَبدَأُ الخَلقَ ثُمَّ يُعيدُهُ ۚ قُلِ اللَّهُ يَبدَأُ الخَلقَ ثُمَّ يُعيدُهُ ۖ فَأَنّىٰ تُؤفَكونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcccxcix{قُل هَل مِن شُرَكائِكُم مَن يَهدي إِلَى الحَقِّ ۚ قُلِ اللَّهُ يَهدي لِلحَقِّ ۗ أَفَمَن يَهدي إِلَى الحَقِّ أَحَقُّ أَن يُتَّبَعَ أَمَّن لا يَهِدّي إِلّا أَن يُهدىٰ ۖ فَما لَكُم كَيفَ تَحكُمونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcd{وَما يَتَّبِعُ أَكثَرُهُم إِلّا ظَنًّا ۚ إِنَّ الظَّنَّ لا يُغني مِنَ الحَقِّ شَيئًا ۚ إِنَّ اللَّهَ عَليمٌ بِما يَفعَلونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcdi{وَما كانَ هٰذَا القُرآنُ أَن يُفتَرىٰ مِن دونِ اللَّهِ وَلٰكِن تَصديقَ الَّذي بَينَ يَدَيهِ وَتَفصيلَ الكِتابِ لا رَيبَ فيهِ مِن رَبِّ العالَمينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcdii{أَم يَقولونَ افتَراهُ ۖ قُل فَأتوا بِسورَةٍ مِثلِهِ وَادعوا مَنِ استَطَعتُم مِن دونِ اللَّهِ إِن كُنتُم صادِقينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcdiii{بَل كَذَّبوا بِما لَم يُحيطوا بِعِلمِهِ وَلَمّا يَأتِهِم تَأويلُهُ ۚ كَذٰلِكَ كَذَّبَ الَّذينَ مِن قَبلِهِم ۖ فَانظُر كَيفَ كانَ عاقِبَةُ الظّالِمينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcdiv{وَمِنهُم مَن يُؤمِنُ بِهِ وَمِنهُم مَن لا يُؤمِنُ بِهِ ۚ وَرَبُّكَ أَعلَمُ بِالمُفسِدينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcdv{وَإِن كَذَّبوكَ فَقُل لي عَمَلي وَلَكُم عَمَلُكُم ۖ أَنتُم بَريئونَ مِمّا أَعمَلُ وَأَنا بَريءٌ مِمّا تَعمَلونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mcdvi{وَمِنهُم مَن يَستَمِعونَ إِلَيكَ ۚ أَفَأَنتَ تُسمِعُ الصُّمَّ وَلَو كانوا لا يَعقِلونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcdvii{وَمِنهُم مَن يَنظُرُ إِلَيكَ ۚ أَفَأَنتَ تَهدِي العُميَ وَلَو كانوا لا يُبصِرونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcdviii{إِنَّ اللَّهَ لا يَظلِمُ النّاسَ شَيئًا وَلٰكِنَّ النّاسَ أَنفُسَهُم يَظلِمونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mcdix{وَيَومَ يَحشُرُهُم كَأَن لَم يَلبَثوا إِلّا ساعَةً مِنَ النَّهارِ يَتَعارَفونَ بَينَهُم ۚ قَد خَسِرَ الَّذينَ كَذَّبوا بِلِقاءِ اللَّهِ وَما كانوا مُهتَدينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mcdx{وَإِمّا نُرِيَنَّكَ بَعضَ الَّذي نَعِدُهُم أَو نَتَوَفَّيَنَّكَ فَإِلَينا مَرجِعُهُم ثُمَّ اللَّهُ شَهيدٌ عَلىٰ ما يَفعَلونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mcdxi{وَلِكُلِّ أُمَّةٍ رَسولٌ ۖ فَإِذا جاءَ رَسولُهُم قُضِيَ بَينَهُم بِالقِسطِ وَهُم لا يُظلَمونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mcdxii{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صادِقينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mcdxiii{قُل لا أَملِكُ لِنَفسي ضَرًّا وَلا نَفعًا إِلّا ما شاءَ اللَّهُ ۗ لِكُلِّ أُمَّةٍ أَجَلٌ ۚ إِذا جاءَ أَجَلُهُم فَلا يَستَأخِرونَ ساعَةً ۖ وَلا يَستَقدِمونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mcdxiv{قُل أَرَأَيتُم إِن أَتاكُم عَذابُهُ بَياتًا أَو نَهارًا ماذا يَستَعجِلُ مِنهُ المُجرِمونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mcdxv{أَثُمَّ إِذا ما وَقَعَ آمَنتُم بِهِ ۚ آلآنَ وَقَد كُنتُم بِهِ تَستَعجِلونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mcdxvi{ثُمَّ قيلَ لِلَّذينَ ظَلَموا ذوقوا عَذابَ الخُلدِ هَل تُجزَونَ إِلّا بِما كُنتُم تَكسِبونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mcdxvii{۞ وَيَستَنبِئونَكَ أَحَقٌّ هُوَ ۖ قُل إي وَرَبّي إِنَّهُ لَحَقٌّ ۖ وَما أَنتُم بِمُعجِزينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mcdxviii{وَلَو أَنَّ لِكُلِّ نَفسٍ ظَلَمَت ما فِي الأَرضِ لَافتَدَت بِهِ ۗ وَأَسَرُّوا النَّدامَةَ لَمّا رَأَوُا العَذابَ ۖ وَقُضِيَ بَينَهُم بِالقِسطِ ۚ وَهُم لا يُظلَمونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mcdxix{أَلا إِنَّ لِلَّهِ ما فِي السَّماواتِ وَالأَرضِ ۗ أَلا إِنَّ وَعدَ اللَّهِ حَقٌّ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mcdxx{هُوَ يُحيي وَيُميتُ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mcdxxi{يا أَيُّهَا النّاسُ قَد جاءَتكُم مَوعِظَةٌ مِن رَبِّكُم وَشِفاءٌ لِما فِي الصُّدورِ وَهُدًى وَرَحمَةٌ لِلمُؤمِنينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mcdxxii{قُل بِفَضلِ اللَّهِ وَبِرَحمَتِهِ فَبِذٰلِكَ فَليَفرَحوا هُوَ خَيرٌ مِمّا يَجمَعونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mcdxxiii{قُل أَرَأَيتُم ما أَنزَلَ اللَّهُ لَكُم مِن رِزقٍ فَجَعَلتُم مِنهُ حَرامًا وَحَلالًا قُل آللَّهُ أَذِنَ لَكُم ۖ أَم عَلَى اللَّهِ تَفتَرونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mcdxxiv{وَما ظَنُّ الَّذينَ يَفتَرونَ عَلَى اللَّهِ الكَذِبَ يَومَ القِيامَةِ ۗ إِنَّ اللَّهَ لَذو فَضلٍ عَلَى النّاسِ وَلٰكِنَّ أَكثَرَهُم لا يَشكُرونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mcdxxv{وَما تَكونُ في شَأنٍ وَما تَتلو مِنهُ مِن قُرآنٍ وَلا تَعمَلونَ مِن عَمَلٍ إِلّا كُنّا عَلَيكُم شُهودًا إِذ تُفيضونَ فيهِ ۚ وَما يَعزُبُ عَن رَبِّكَ مِن مِثقالِ ذَرَّةٍ فِي الأَرضِ وَلا فِي السَّماءِ وَلا أَصغَرَ مِن ذٰلِكَ وَلا أَكبَرَ إِلّا في كِتابٍ مُبينٍ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mcdxxvi{أَلا إِنَّ أَولِياءَ اللَّهِ لا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mcdxxvii{الَّذينَ آمَنوا وَكانوا يَتَّقونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mcdxxviii{لَهُمُ البُشرىٰ فِي الحَياةِ الدُّنيا وَفِي الآخِرَةِ ۚ لا تَبديلَ لِكَلِماتِ اللَّهِ ۚ ذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mcdxxix{وَلا يَحزُنكَ قَولُهُم ۘ إِنَّ العِزَّةَ لِلَّهِ جَميعًا ۚ هُوَ السَّميعُ العَليمُ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mcdxxx{أَلا إِنَّ لِلَّهِ مَن فِي السَّماواتِ وَمَن فِي الأَرضِ ۗ وَما يَتَّبِعُ الَّذينَ يَدعونَ مِن دونِ اللَّهِ شُرَكاءَ ۚ إِن يَتَّبِعونَ إِلَّا الظَّنَّ وَإِن هُم إِلّا يَخرُصونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mcdxxxi{هُوَ الَّذي جَعَلَ لَكُمُ اللَّيلَ لِتَسكُنوا فيهِ وَالنَّهارَ مُبصِرًا ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يَسمَعونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mcdxxxii{قالُوا اتَّخَذَ اللَّهُ وَلَدًا ۗ سُبحانَهُ ۖ هُوَ الغَنِيُّ ۖ لَهُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۚ إِن عِندَكُم مِن سُلطانٍ بِهٰذا ۚ أَتَقولونَ عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mcdxxxiii{قُل إِنَّ الَّذينَ يَفتَرونَ عَلَى اللَّهِ الكَذِبَ لا يُفلِحونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mcdxxxiv{مَتاعٌ فِي الدُّنيا ثُمَّ إِلَينا مَرجِعُهُم ثُمَّ نُذيقُهُمُ العَذابَ الشَّديدَ بِما كانوا يَكفُرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mcdxxxv{۞ وَاتلُ عَلَيهِم نَبَأَ نوحٍ إِذ قالَ لِقَومِهِ يا قَومِ إِن كانَ كَبُرَ عَلَيكُم مَقامي وَتَذكيري بِآياتِ اللَّهِ فَعَلَى اللَّهِ تَوَكَّلتُ فَأَجمِعوا أَمرَكُم وَشُرَكاءَكُم ثُمَّ لا يَكُن أَمرُكُم عَلَيكُم غُمَّةً ثُمَّ اقضوا إِلَيَّ وَلا تُنظِرونِ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mcdxxxvi{فَإِن تَوَلَّيتُم فَما سَأَلتُكُم مِن أَجرٍ ۖ إِن أَجرِيَ إِلّا عَلَى اللَّهِ ۖ وَأُمِرتُ أَن أَكونَ مِنَ المُسلِمينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mcdxxxvii{فَكَذَّبوهُ فَنَجَّيناهُ وَمَن مَعَهُ فِي الفُلكِ وَجَعَلناهُم خَلائِفَ وَأَغرَقنَا الَّذينَ كَذَّبوا بِآياتِنا ۖ فَانظُر كَيفَ كانَ عاقِبَةُ المُنذَرينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mcdxxxviii{ثُمَّ بَعَثنا مِن بَعدِهِ رُسُلًا إِلىٰ قَومِهِم فَجاءوهُم بِالبَيِّناتِ فَما كانوا لِيُؤمِنوا بِما كَذَّبوا بِهِ مِن قَبلُ ۚ كَذٰلِكَ نَطبَعُ عَلىٰ قُلوبِ المُعتَدينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mcdxxxix{ثُمَّ بَعَثنا مِن بَعدِهِم موسىٰ وَهارونَ إِلىٰ فِرعَونَ وَمَلَئِهِ بِآياتِنا فَاستَكبَروا وَكانوا قَومًا مُجرِمينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mcdxl{فَلَمّا جاءَهُمُ الحَقُّ مِن عِندِنا قالوا إِنَّ هٰذا لَسِحرٌ مُبينٌ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mcdxli{قالَ موسىٰ أَتَقولونَ لِلحَقِّ لَمّا جاءَكُم ۖ أَسِحرٌ هٰذا وَلا يُفلِحُ السّاحِرونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mcdxlii{قالوا أَجِئتَنا لِتَلفِتَنا عَمّا وَجَدنا عَلَيهِ آباءَنا وَتَكونَ لَكُمَا الكِبرِياءُ فِي الأَرضِ وَما نَحنُ لَكُما بِمُؤمِنينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mcdxliii{وَقالَ فِرعَونُ ائتوني بِكُلِّ ساحِرٍ عَليمٍ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mcdxliv{فَلَمّا جاءَ السَّحَرَةُ قالَ لَهُم موسىٰ أَلقوا ما أَنتُم مُلقونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mcdxlv{فَلَمّا أَلقَوا قالَ موسىٰ ما جِئتُم بِهِ السِّحرُ ۖ إِنَّ اللَّهَ سَيُبطِلُهُ ۖ إِنَّ اللَّهَ لا يُصلِحُ عَمَلَ المُفسِدينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mcdxlvi{وَيُحِقُّ اللَّهُ الحَقَّ بِكَلِماتِهِ وَلَو كَرِهَ المُجرِمونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mcdxlvii{فَما آمَنَ لِموسىٰ إِلّا ذُرِّيَّةٌ مِن قَومِهِ عَلىٰ خَوفٍ مِن فِرعَونَ وَمَلَئِهِم أَن يَفتِنَهُم ۚ وَإِنَّ فِرعَونَ لَعالٍ فِي الأَرضِ وَإِنَّهُ لَمِنَ المُسرِفينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mcdxlviii{وَقالَ موسىٰ يا قَومِ إِن كُنتُم آمَنتُم بِاللَّهِ فَعَلَيهِ تَوَكَّلوا إِن كُنتُم مُسلِمينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mcdxlix{فَقالوا عَلَى اللَّهِ تَوَكَّلنا رَبَّنا لا تَجعَلنا فِتنَةً لِلقَومِ الظّالِمينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mcdl{وَنَجِّنا بِرَحمَتِكَ مِنَ القَومِ الكافِرينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mcdli{وَأَوحَينا إِلىٰ موسىٰ وَأَخيهِ أَن تَبَوَّآ لِقَومِكُما بِمِصرَ بُيوتًا وَاجعَلوا بُيوتَكُم قِبلَةً وَأَقيمُوا الصَّلاةَ ۗ وَبَشِّرِ المُؤمِنينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mcdlii{وَقالَ موسىٰ رَبَّنا إِنَّكَ آتَيتَ فِرعَونَ وَمَلَأَهُ زينَةً وَأَموالًا فِي الحَياةِ الدُّنيا رَبَّنا لِيُضِلّوا عَن سَبيلِكَ ۖ رَبَّنَا اطمِس عَلىٰ أَموالِهِم وَاشدُد عَلىٰ قُلوبِهِم فَلا يُؤمِنوا حَتّىٰ يَرَوُا العَذابَ الأَليمَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mcdliii{قالَ قَد أُجيبَت دَعوَتُكُما فَاستَقيما وَلا تَتَّبِعانِّ سَبيلَ الَّذينَ لا يَعلَمونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mcdliv{۞ وَجاوَزنا بِبَني إِسرائيلَ البَحرَ فَأَتبَعَهُم فِرعَونُ وَجُنودُهُ بَغيًا وَعَدوًا ۖ حَتّىٰ إِذا أَدرَكَهُ الغَرَقُ قالَ آمَنتُ أَنَّهُ لا إِلٰهَ إِلَّا الَّذي آمَنَت بِهِ بَنو إِسرائيلَ وَأَنا مِنَ المُسلِمينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mcdlv{آلآنَ وَقَد عَصَيتَ قَبلُ وَكُنتَ مِنَ المُفسِدينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mcdlvi{فَاليَومَ نُنَجّيكَ بِبَدَنِكَ لِتَكونَ لِمَن خَلفَكَ آيَةً ۚ وَإِنَّ كَثيرًا مِنَ النّاسِ عَن آياتِنا لَغافِلونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mcdlvii{وَلَقَد بَوَّأنا بَني إِسرائيلَ مُبَوَّأَ صِدقٍ وَرَزَقناهُم مِنَ الطَّيِّباتِ فَمَا اختَلَفوا حَتّىٰ جاءَهُمُ العِلمُ ۚ إِنَّ رَبَّكَ يَقضي بَينَهُم يَومَ القِيامَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mcdlviii{فَإِن كُنتَ في شَكٍّ مِمّا أَنزَلنا إِلَيكَ فَاسأَلِ الَّذينَ يَقرَءونَ الكِتابَ مِن قَبلِكَ ۚ لَقَد جاءَكَ الحَقُّ مِن رَبِّكَ فَلا تَكونَنَّ مِنَ المُمتَرينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mcdlix{وَلا تَكونَنَّ مِنَ الَّذينَ كَذَّبوا بِآياتِ اللَّهِ فَتَكونَ مِنَ الخاسِرينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mcdlx{إِنَّ الَّذينَ حَقَّت عَلَيهِم كَلِمَتُ رَبِّكَ لا يُؤمِنونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mcdlxi{وَلَو جاءَتهُم كُلُّ آيَةٍ حَتّىٰ يَرَوُا العَذابَ الأَليمَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcdlxii{فَلَولا كانَت قَريَةٌ آمَنَت فَنَفَعَها إيمانُها إِلّا قَومَ يونُسَ لَمّا آمَنوا كَشَفنا عَنهُم عَذابَ الخِزيِ فِي الحَياةِ الدُّنيا وَمَتَّعناهُم إِلىٰ حينٍ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mcdlxiii{وَلَو شاءَ رَبُّكَ لَآمَنَ مَن فِي الأَرضِ كُلُّهُم جَميعًا ۚ أَفَأَنتَ تُكرِهُ النّاسَ حَتّىٰ يَكونوا مُؤمِنينَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mcdlxiv{وَما كانَ لِنَفسٍ أَن تُؤمِنَ إِلّا بِإِذنِ اللَّهِ ۚ وَيَجعَلُ الرِّجسَ عَلَى الَّذينَ لا يَعقِلونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mcdlxv{قُلِ انظُروا ماذا فِي السَّماواتِ وَالأَرضِ ۚ وَما تُغنِي الآياتُ وَالنُّذُرُ عَن قَومٍ لا يُؤمِنونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mcdlxvi{فَهَل يَنتَظِرونَ إِلّا مِثلَ أَيّامِ الَّذينَ خَلَوا مِن قَبلِهِم ۚ قُل فَانتَظِروا إِنّي مَعَكُم مِنَ المُنتَظِرينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mcdlxvii{ثُمَّ نُنَجّي رُسُلَنا وَالَّذينَ آمَنوا ۚ كَذٰلِكَ حَقًّا عَلَينا نُنجِ المُؤمِنينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mcdlxviii{قُل يا أَيُّهَا النّاسُ إِن كُنتُم في شَكٍّ مِن ديني فَلا أَعبُدُ الَّذينَ تَعبُدونَ مِن دونِ اللَّهِ وَلٰكِن أَعبُدُ اللَّهَ الَّذي يَتَوَفّاكُم ۖ وَأُمِرتُ أَن أَكونَ مِنَ المُؤمِنينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mcdlxix{وَأَن أَقِم وَجهَكَ لِلدّينِ حَنيفًا وَلا تَكونَنَّ مِنَ المُشرِكينَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mcdlxx{وَلا تَدعُ مِن دونِ اللَّهِ ما لا يَنفَعُكَ وَلا يَضُرُّكَ ۖ فَإِن فَعَلتَ فَإِنَّكَ إِذًا مِنَ الظّالِمينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mcdlxxi{وَإِن يَمسَسكَ اللَّهُ بِضُرٍّ فَلا كاشِفَ لَهُ إِلّا هُوَ ۖ وَإِن يُرِدكَ بِخَيرٍ فَلا رادَّ لِفَضلِهِ ۚ يُصيبُ بِهِ مَن يَشاءُ مِن عِبادِهِ ۚ وَهُوَ الغَفورُ الرَّحيمُ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mcdlxxii{قُل يا أَيُّهَا النّاسُ قَد جاءَكُمُ الحَقُّ مِن رَبِّكُم ۖ فَمَنِ اهتَدىٰ فَإِنَّما يَهتَدي لِنَفسِهِ ۖ وَمَن ضَلَّ فَإِنَّما يَضِلُّ عَلَيها ۖ وَما أَنا عَلَيكُم بِوَكيلٍ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mcdlxxiii{وَاتَّبِع ما يوحىٰ إِلَيكَ وَاصبِر حَتّىٰ يَحكُمَ اللَّهُ ۚ وَهُوَ خَيرُ الحاكِمينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mcdlxxiv{\basmalah الر ۚ كِتابٌ أُحكِمَت آياتُهُ ثُمَّ فُصِّلَت مِن لَدُن حَكيمٍ خَبيرٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mcdlxxv{أَلّا تَعبُدوا إِلَّا اللَّهَ ۚ إِنَّني لَكُم مِنهُ نَذيرٌ وَبَشيرٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mcdlxxvi{وَأَنِ استَغفِروا رَبَّكُم ثُمَّ توبوا إِلَيهِ يُمَتِّعكُم مَتاعًا حَسَنًا إِلىٰ أَجَلٍ مُسَمًّى وَيُؤتِ كُلَّ ذي فَضلٍ فَضلَهُ ۖ وَإِن تَوَلَّوا فَإِنّي أَخافُ عَلَيكُم عَذابَ يَومٍ كَبيرٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mcdlxxvii{إِلَى اللَّهِ مَرجِعُكُم ۖ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mcdlxxviii{أَلا إِنَّهُم يَثنونَ صُدورَهُم لِيَستَخفوا مِنهُ ۚ أَلا حينَ يَستَغشونَ ثِيابَهُم يَعلَمُ ما يُسِرّونَ وَما يُعلِنونَ ۚ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mcdlxxix{۞ وَما مِن دابَّةٍ فِي الأَرضِ إِلّا عَلَى اللَّهِ رِزقُها وَيَعلَمُ مُستَقَرَّها وَمُستَودَعَها ۚ كُلٌّ في كِتابٍ مُبينٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mcdlxxx{وَهُوَ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ في سِتَّةِ أَيّامٍ وَكانَ عَرشُهُ عَلَى الماءِ لِيَبلُوَكُم أَيُّكُم أَحسَنُ عَمَلًا ۗ وَلَئِن قُلتَ إِنَّكُم مَبعوثونَ مِن بَعدِ المَوتِ لَيَقولَنَّ الَّذينَ كَفَروا إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mcdlxxxi{وَلَئِن أَخَّرنا عَنهُمُ العَذابَ إِلىٰ أُمَّةٍ مَعدودَةٍ لَيَقولُنَّ ما يَحبِسُهُ ۗ أَلا يَومَ يَأتيهِم لَيسَ مَصروفًا عَنهُم وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mcdlxxxii{وَلَئِن أَذَقنَا الإِنسانَ مِنّا رَحمَةً ثُمَّ نَزَعناها مِنهُ إِنَّهُ لَيَئوسٌ كَفورٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mcdlxxxiii{وَلَئِن أَذَقناهُ نَعماءَ بَعدَ ضَرّاءَ مَسَّتهُ لَيَقولَنَّ ذَهَبَ السَّيِّئَاتُ عَنّي ۚ إِنَّهُ لَفَرِحٌ فَخورٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mcdlxxxiv{إِلَّا الَّذينَ صَبَروا وَعَمِلُوا الصّالِحاتِ أُولٰئِكَ لَهُم مَغفِرَةٌ وَأَجرٌ كَبيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mcdlxxxv{فَلَعَلَّكَ تارِكٌ بَعضَ ما يوحىٰ إِلَيكَ وَضائِقٌ بِهِ صَدرُكَ أَن يَقولوا لَولا أُنزِلَ عَلَيهِ كَنزٌ أَو جاءَ مَعَهُ مَلَكٌ ۚ إِنَّما أَنتَ نَذيرٌ ۚ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ وَكيلٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mcdlxxxvi{أَم يَقولونَ افتَراهُ ۖ قُل فَأتوا بِعَشرِ سُوَرٍ مِثلِهِ مُفتَرَياتٍ وَادعوا مَنِ استَطَعتُم مِن دونِ اللَّهِ إِن كُنتُم صادِقينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mcdlxxxvii{فَإِلَّم يَستَجيبوا لَكُم فَاعلَموا أَنَّما أُنزِلَ بِعِلمِ اللَّهِ وَأَن لا إِلٰهَ إِلّا هُوَ ۖ فَهَل أَنتُم مُسلِمونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mcdlxxxviii{مَن كانَ يُريدُ الحَياةَ الدُّنيا وَزينَتَها نُوَفِّ إِلَيهِم أَعمالَهُم فيها وَهُم فيها لا يُبخَسونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mcdlxxxix{أُولٰئِكَ الَّذينَ لَيسَ لَهُم فِي الآخِرَةِ إِلَّا النّارُ ۖ وَحَبِطَ ما صَنَعوا فيها وَباطِلٌ ما كانوا يَعمَلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mcdxc{أَفَمَن كانَ عَلىٰ بَيِّنَةٍ مِن رَبِّهِ وَيَتلوهُ شاهِدٌ مِنهُ وَمِن قَبلِهِ كِتابُ موسىٰ إِمامًا وَرَحمَةً ۚ أُولٰئِكَ يُؤمِنونَ بِهِ ۚ وَمَن يَكفُر بِهِ مِنَ الأَحزابِ فَالنّارُ مَوعِدُهُ ۚ فَلا تَكُ في مِريَةٍ مِنهُ ۚ إِنَّهُ الحَقُّ مِن رَبِّكَ وَلٰكِنَّ أَكثَرَ النّاسِ لا يُؤمِنونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mcdxci{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا ۚ أُولٰئِكَ يُعرَضونَ عَلىٰ رَبِّهِم وَيَقولُ الأَشهادُ هٰؤُلاءِ الَّذينَ كَذَبوا عَلىٰ رَبِّهِم ۚ أَلا لَعنَةُ اللَّهِ عَلَى الظّالِمينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mcdxcii{الَّذينَ يَصُدّونَ عَن سَبيلِ اللَّهِ وَيَبغونَها عِوَجًا وَهُم بِالآخِرَةِ هُم كافِرونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mcdxciii{أُولٰئِكَ لَم يَكونوا مُعجِزينَ فِي الأَرضِ وَما كانَ لَهُم مِن دونِ اللَّهِ مِن أَولِياءَ ۘ يُضاعَفُ لَهُمُ العَذابُ ۚ ما كانوا يَستَطيعونَ السَّمعَ وَما كانوا يُبصِرونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mcdxciv{أُولٰئِكَ الَّذينَ خَسِروا أَنفُسَهُم وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mcdxcv{لا جَرَمَ أَنَّهُم فِي الآخِرَةِ هُمُ الأَخسَرونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mcdxcvi{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ وَأَخبَتوا إِلىٰ رَبِّهِم أُولٰئِكَ أَصحابُ الجَنَّةِ ۖ هُم فيها خالِدونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mcdxcvii{۞ مَثَلُ الفَريقَينِ كَالأَعمىٰ وَالأَصَمِّ وَالبَصيرِ وَالسَّميعِ ۚ هَل يَستَوِيانِ مَثَلًا ۚ أَفَلا تَذَكَّرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mcdxcviii{وَلَقَد أَرسَلنا نوحًا إِلىٰ قَومِهِ إِنّي لَكُم نَذيرٌ مُبينٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcdxcix{أَن لا تَعبُدوا إِلَّا اللَّهَ ۖ إِنّي أَخافُ عَلَيكُم عَذابَ يَومٍ أَليمٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@md{فَقالَ المَلَأُ الَّذينَ كَفَروا مِن قَومِهِ ما نَراكَ إِلّا بَشَرًا مِثلَنا وَما نَراكَ اتَّبَعَكَ إِلَّا الَّذينَ هُم أَراذِلُنا بادِيَ الرَّأيِ وَما نَرىٰ لَكُم عَلَينا مِن فَضلٍ بَل نَظُنُّكُم كاذِبينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdi{قالَ يا قَومِ أَرَأَيتُم إِن كُنتُ عَلىٰ بَيِّنَةٍ مِن رَبّي وَآتاني رَحمَةً مِن عِندِهِ فَعُمِّيَت عَلَيكُم أَنُلزِمُكُموها وَأَنتُم لَها كارِهونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdii{وَيا قَومِ لا أَسأَلُكُم عَلَيهِ مالًا ۖ إِن أَجرِيَ إِلّا عَلَى اللَّهِ ۚ وَما أَنا بِطارِدِ الَّذينَ آمَنوا ۚ إِنَّهُم مُلاقو رَبِّهِم وَلٰكِنّي أَراكُم قَومًا تَجهَلونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdiii{وَيا قَومِ مَن يَنصُرُني مِنَ اللَّهِ إِن طَرَدتُهُم ۚ أَفَلا تَذَكَّرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdiv{وَلا أَقولُ لَكُم عِندي خَزائِنُ اللَّهِ وَلا أَعلَمُ الغَيبَ وَلا أَقولُ إِنّي مَلَكٌ وَلا أَقولُ لِلَّذينَ تَزدَري أَعيُنُكُم لَن يُؤتِيَهُمُ اللَّهُ خَيرًا ۖ اللَّهُ أَعلَمُ بِما في أَنفُسِهِم ۖ إِنّي إِذًا لَمِنَ الظّالِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdv{قالوا يا نوحُ قَد جادَلتَنا فَأَكثَرتَ جِدالَنا فَأتِنا بِما تَعِدُنا إِن كُنتَ مِنَ الصّادِقينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdvi{قالَ إِنَّما يَأتيكُم بِهِ اللَّهُ إِن شاءَ وَما أَنتُم بِمُعجِزينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdvii{وَلا يَنفَعُكُم نُصحي إِن أَرَدتُ أَن أَنصَحَ لَكُم إِن كانَ اللَّهُ يُريدُ أَن يُغوِيَكُم ۚ هُوَ رَبُّكُم وَإِلَيهِ تُرجَعونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdviii{أَم يَقولونَ افتَراهُ ۖ قُل إِنِ افتَرَيتُهُ فَعَلَيَّ إِجرامي وَأَنا بَريءٌ مِمّا تُجرِمونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdix{وَأوحِيَ إِلىٰ نوحٍ أَنَّهُ لَن يُؤمِنَ مِن قَومِكَ إِلّا مَن قَد آمَنَ فَلا تَبتَئِس بِما كانوا يَفعَلونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdx{وَاصنَعِ الفُلكَ بِأَعيُنِنا وَوَحيِنا وَلا تُخاطِبني فِي الَّذينَ ظَلَموا ۚ إِنَّهُم مُغرَقونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdxi{وَيَصنَعُ الفُلكَ وَكُلَّما مَرَّ عَلَيهِ مَلَأٌ مِن قَومِهِ سَخِروا مِنهُ ۚ قالَ إِن تَسخَروا مِنّا فَإِنّا نَسخَرُ مِنكُم كَما تَسخَرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdxii{فَسَوفَ تَعلَمونَ مَن يَأتيهِ عَذابٌ يُخزيهِ وَيَحِلُّ عَلَيهِ عَذابٌ مُقيمٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdxiii{حَتّىٰ إِذا جاءَ أَمرُنا وَفارَ التَّنّورُ قُلنَا احمِل فيها مِن كُلٍّ زَوجَينِ اثنَينِ وَأَهلَكَ إِلّا مَن سَبَقَ عَلَيهِ القَولُ وَمَن آمَنَ ۚ وَما آمَنَ مَعَهُ إِلّا قَليلٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdxiv{۞ وَقالَ اركَبوا فيها بِسمِ اللَّهِ مَجراها وَمُرساها ۚ إِنَّ رَبّي لَغَفورٌ رَحيمٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdxv{وَهِيَ تَجري بِهِم في مَوجٍ كَالجِبالِ وَنادىٰ نوحٌ ابنَهُ وَكانَ في مَعزِلٍ يا بُنَيَّ اركَب مَعَنا وَلا تَكُن مَعَ الكافِرينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdxvi{قالَ سَآوي إِلىٰ جَبَلٍ يَعصِمُني مِنَ الماءِ ۚ قالَ لا عاصِمَ اليَومَ مِن أَمرِ اللَّهِ إِلّا مَن رَحِمَ ۚ وَحالَ بَينَهُمَا المَوجُ فَكانَ مِنَ المُغرَقينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdxvii{وَقيلَ يا أَرضُ ابلَعي ماءَكِ وَيا سَماءُ أَقلِعي وَغيضَ الماءُ وَقُضِيَ الأَمرُ وَاستَوَت عَلَى الجودِيِّ ۖ وَقيلَ بُعدًا لِلقَومِ الظّالِمينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdxviii{وَنادىٰ نوحٌ رَبَّهُ فَقالَ رَبِّ إِنَّ ابني مِن أَهلي وَإِنَّ وَعدَكَ الحَقُّ وَأَنتَ أَحكَمُ الحاكِمينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdxix{قالَ يا نوحُ إِنَّهُ لَيسَ مِن أَهلِكَ ۖ إِنَّهُ عَمَلٌ غَيرُ صالِحٍ ۖ فَلا تَسأَلنِ ما لَيسَ لَكَ بِهِ عِلمٌ ۖ إِنّي أَعِظُكَ أَن تَكونَ مِنَ الجاهِلينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdxx{قالَ رَبِّ إِنّي أَعوذُ بِكَ أَن أَسأَلَكَ ما لَيسَ لي بِهِ عِلمٌ ۖ وَإِلّا تَغفِر لي وَتَرحَمني أَكُن مِنَ الخاسِرينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdxxi{قيلَ يا نوحُ اهبِط بِسَلامٍ مِنّا وَبَرَكاتٍ عَلَيكَ وَعَلىٰ أُمَمٍ مِمَّن مَعَكَ ۚ وَأُمَمٌ سَنُمَتِّعُهُم ثُمَّ يَمَسُّهُم مِنّا عَذابٌ أَليمٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdxxii{تِلكَ مِن أَنباءِ الغَيبِ نوحيها إِلَيكَ ۖ ما كُنتَ تَعلَمُها أَنتَ وَلا قَومُكَ مِن قَبلِ هٰذا ۖ فَاصبِر ۖ إِنَّ العاقِبَةَ لِلمُتَّقينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdxxiii{وَإِلىٰ عادٍ أَخاهُم هودًا ۚ قالَ يا قَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ ۖ إِن أَنتُم إِلّا مُفتَرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdxxiv{يا قَومِ لا أَسأَلُكُم عَلَيهِ أَجرًا ۖ إِن أَجرِيَ إِلّا عَلَى الَّذي فَطَرَني ۚ أَفَلا تَعقِلونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdxxv{وَيا قَومِ استَغفِروا رَبَّكُم ثُمَّ توبوا إِلَيهِ يُرسِلِ السَّماءَ عَلَيكُم مِدرارًا وَيَزِدكُم قُوَّةً إِلىٰ قُوَّتِكُم وَلا تَتَوَلَّوا مُجرِمينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdxxvi{قالوا يا هودُ ما جِئتَنا بِبَيِّنَةٍ وَما نَحنُ بِتارِكي آلِهَتِنا عَن قَولِكَ وَما نَحنُ لَكَ بِمُؤمِنينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mdxxvii{إِن نَقولُ إِلَّا اعتَراكَ بَعضُ آلِهَتِنا بِسوءٍ ۗ قالَ إِنّي أُشهِدُ اللَّهَ وَاشهَدوا أَنّي بَريءٌ مِمّا تُشرِكونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mdxxviii{مِن دونِهِ ۖ فَكيدوني جَميعًا ثُمَّ لا تُنظِرونِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mdxxix{إِنّي تَوَكَّلتُ عَلَى اللَّهِ رَبّي وَرَبِّكُم ۚ ما مِن دابَّةٍ إِلّا هُوَ آخِذٌ بِناصِيَتِها ۚ إِنَّ رَبّي عَلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mdxxx{فَإِن تَوَلَّوا فَقَد أَبلَغتُكُم ما أُرسِلتُ بِهِ إِلَيكُم ۚ وَيَستَخلِفُ رَبّي قَومًا غَيرَكُم وَلا تَضُرّونَهُ شَيئًا ۚ إِنَّ رَبّي عَلىٰ كُلِّ شَيءٍ حَفيظٌ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mdxxxi{وَلَمّا جاءَ أَمرُنا نَجَّينا هودًا وَالَّذينَ آمَنوا مَعَهُ بِرَحمَةٍ مِنّا وَنَجَّيناهُم مِن عَذابٍ غَليظٍ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mdxxxii{وَتِلكَ عادٌ ۖ جَحَدوا بِآياتِ رَبِّهِم وَعَصَوا رُسُلَهُ وَاتَّبَعوا أَمرَ كُلِّ جَبّارٍ عَنيدٍ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mdxxxiii{وَأُتبِعوا في هٰذِهِ الدُّنيا لَعنَةً وَيَومَ القِيامَةِ ۗ أَلا إِنَّ عادًا كَفَروا رَبَّهُم ۗ أَلا بُعدًا لِعادٍ قَومِ هودٍ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mdxxxiv{۞ وَإِلىٰ ثَمودَ أَخاهُم صالِحًا ۚ قالَ يا قَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ ۖ هُوَ أَنشَأَكُم مِنَ الأَرضِ وَاستَعمَرَكُم فيها فَاستَغفِروهُ ثُمَّ توبوا إِلَيهِ ۚ إِنَّ رَبّي قَريبٌ مُجيبٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mdxxxv{قالوا يا صالِحُ قَد كُنتَ فينا مَرجُوًّا قَبلَ هٰذا ۖ أَتَنهانا أَن نَعبُدَ ما يَعبُدُ آباؤُنا وَإِنَّنا لَفي شَكٍّ مِمّا تَدعونا إِلَيهِ مُريبٍ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mdxxxvi{قالَ يا قَومِ أَرَأَيتُم إِن كُنتُ عَلىٰ بَيِّنَةٍ مِن رَبّي وَآتاني مِنهُ رَحمَةً فَمَن يَنصُرُني مِنَ اللَّهِ إِن عَصَيتُهُ ۖ فَما تَزيدونَني غَيرَ تَخسيرٍ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mdxxxvii{وَيا قَومِ هٰذِهِ ناقَةُ اللَّهِ لَكُم آيَةً فَذَروها تَأكُل في أَرضِ اللَّهِ وَلا تَمَسّوها بِسوءٍ فَيَأخُذَكُم عَذابٌ قَريبٌ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mdxxxviii{فَعَقَروها فَقالَ تَمَتَّعوا في دارِكُم ثَلاثَةَ أَيّامٍ ۖ ذٰلِكَ وَعدٌ غَيرُ مَكذوبٍ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mdxxxix{فَلَمّا جاءَ أَمرُنا نَجَّينا صالِحًا وَالَّذينَ آمَنوا مَعَهُ بِرَحمَةٍ مِنّا وَمِن خِزيِ يَومِئِذٍ ۗ إِنَّ رَبَّكَ هُوَ القَوِيُّ العَزيزُ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mdxl{وَأَخَذَ الَّذينَ ظَلَمُوا الصَّيحَةُ فَأَصبَحوا في دِيارِهِم جاثِمينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mdxli{كَأَن لَم يَغنَوا فيها ۗ أَلا إِنَّ ثَمودَ كَفَروا رَبَّهُم ۗ أَلا بُعدًا لِثَمودَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mdxlii{وَلَقَد جاءَت رُسُلُنا إِبراهيمَ بِالبُشرىٰ قالوا سَلامًا ۖ قالَ سَلامٌ ۖ فَما لَبِثَ أَن جاءَ بِعِجلٍ حَنيذٍ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mdxliii{فَلَمّا رَأىٰ أَيدِيَهُم لا تَصِلُ إِلَيهِ نَكِرَهُم وَأَوجَسَ مِنهُم خيفَةً ۚ قالوا لا تَخَف إِنّا أُرسِلنا إِلىٰ قَومِ لوطٍ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mdxliv{وَامرَأَتُهُ قائِمَةٌ فَضَحِكَت فَبَشَّرناها بِإِسحاقَ وَمِن وَراءِ إِسحاقَ يَعقوبَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mdxlv{قالَت يا وَيلَتىٰ أَأَلِدُ وَأَنا عَجوزٌ وَهٰذا بَعلي شَيخًا ۖ إِنَّ هٰذا لَشَيءٌ عَجيبٌ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mdxlvi{قالوا أَتَعجَبينَ مِن أَمرِ اللَّهِ ۖ رَحمَتُ اللَّهِ وَبَرَكاتُهُ عَلَيكُم أَهلَ البَيتِ ۚ إِنَّهُ حَميدٌ مَجيدٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mdxlvii{فَلَمّا ذَهَبَ عَن إِبراهيمَ الرَّوعُ وَجاءَتهُ البُشرىٰ يُجادِلُنا في قَومِ لوطٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mdxlviii{إِنَّ إِبراهيمَ لَحَليمٌ أَوّاهٌ مُنيبٌ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mdxlix{يا إِبراهيمُ أَعرِض عَن هٰذا ۖ إِنَّهُ قَد جاءَ أَمرُ رَبِّكَ ۖ وَإِنَّهُم آتيهِم عَذابٌ غَيرُ مَردودٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mdl{وَلَمّا جاءَت رُسُلُنا لوطًا سيءَ بِهِم وَضاقَ بِهِم ذَرعًا وَقالَ هٰذا يَومٌ عَصيبٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mdli{وَجاءَهُ قَومُهُ يُهرَعونَ إِلَيهِ وَمِن قَبلُ كانوا يَعمَلونَ السَّيِّئَاتِ ۚ قالَ يا قَومِ هٰؤُلاءِ بَناتي هُنَّ أَطهَرُ لَكُم ۖ فَاتَّقُوا اللَّهَ وَلا تُخزونِ في ضَيفي ۖ أَلَيسَ مِنكُم رَجُلٌ رَشيدٌ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mdlii{قالوا لَقَد عَلِمتَ ما لَنا في بَناتِكَ مِن حَقٍّ وَإِنَّكَ لَتَعلَمُ ما نُريدُ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mdliii{قالَ لَو أَنَّ لي بِكُم قُوَّةً أَو آوي إِلىٰ رُكنٍ شَديدٍ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mdliv{قالوا يا لوطُ إِنّا رُسُلُ رَبِّكَ لَن يَصِلوا إِلَيكَ ۖ فَأَسرِ بِأَهلِكَ بِقِطعٍ مِنَ اللَّيلِ وَلا يَلتَفِت مِنكُم أَحَدٌ إِلَّا امرَأَتَكَ ۖ إِنَّهُ مُصيبُها ما أَصابَهُم ۚ إِنَّ مَوعِدَهُمُ الصُّبحُ ۚ أَلَيسَ الصُّبحُ بِقَريبٍ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mdlv{فَلَمّا جاءَ أَمرُنا جَعَلنا عالِيَها سافِلَها وَأَمطَرنا عَلَيها حِجارَةً مِن سِجّيلٍ مَنضودٍ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mdlvi{مُسَوَّمَةً عِندَ رَبِّكَ ۖ وَما هِيَ مِنَ الظّالِمينَ بِبَعيدٍ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mdlvii{۞ وَإِلىٰ مَديَنَ أَخاهُم شُعَيبًا ۚ قالَ يا قَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ ۖ وَلا تَنقُصُوا المِكيالَ وَالميزانَ ۚ إِنّي أَراكُم بِخَيرٍ وَإِنّي أَخافُ عَلَيكُم عَذابَ يَومٍ مُحيطٍ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mdlviii{وَيا قَومِ أَوفُوا المِكيالَ وَالميزانَ بِالقِسطِ ۖ وَلا تَبخَسُوا النّاسَ أَشياءَهُم وَلا تَعثَوا فِي الأَرضِ مُفسِدينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mdlix{بَقِيَّتُ اللَّهِ خَيرٌ لَكُم إِن كُنتُم مُؤمِنينَ ۚ وَما أَنا عَلَيكُم بِحَفيظٍ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mdlx{قالوا يا شُعَيبُ أَصَلاتُكَ تَأمُرُكَ أَن نَترُكَ ما يَعبُدُ آباؤُنا أَو أَن نَفعَلَ في أَموالِنا ما نَشاءُ ۖ إِنَّكَ لَأَنتَ الحَليمُ الرَّشيدُ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mdlxi{قالَ يا قَومِ أَرَأَيتُم إِن كُنتُ عَلىٰ بَيِّنَةٍ مِن رَبّي وَرَزَقَني مِنهُ رِزقًا حَسَنًا ۚ وَما أُريدُ أَن أُخالِفَكُم إِلىٰ ما أَنهاكُم عَنهُ ۚ إِن أُريدُ إِلَّا الإِصلاحَ مَا استَطَعتُ ۚ وَما تَوفيقي إِلّا بِاللَّهِ ۚ عَلَيهِ تَوَكَّلتُ وَإِلَيهِ أُنيبُ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mdlxii{وَيا قَومِ لا يَجرِمَنَّكُم شِقاقي أَن يُصيبَكُم مِثلُ ما أَصابَ قَومَ نوحٍ أَو قَومَ هودٍ أَو قَومَ صالِحٍ ۚ وَما قَومُ لوطٍ مِنكُم بِبَعيدٍ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mdlxiii{وَاستَغفِروا رَبَّكُم ثُمَّ توبوا إِلَيهِ ۚ إِنَّ رَبّي رَحيمٌ وَدودٌ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mdlxiv{قالوا يا شُعَيبُ ما نَفقَهُ كَثيرًا مِمّا تَقولُ وَإِنّا لَنَراكَ فينا ضَعيفًا ۖ وَلَولا رَهطُكَ لَرَجَمناكَ ۖ وَما أَنتَ عَلَينا بِعَزيزٍ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mdlxv{قالَ يا قَومِ أَرَهطي أَعَزُّ عَلَيكُم مِنَ اللَّهِ وَاتَّخَذتُموهُ وَراءَكُم ظِهرِيًّا ۖ إِنَّ رَبّي بِما تَعمَلونَ مُحيطٌ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mdlxvi{وَيا قَومِ اعمَلوا عَلىٰ مَكانَتِكُم إِنّي عامِلٌ ۖ سَوفَ تَعلَمونَ مَن يَأتيهِ عَذابٌ يُخزيهِ وَمَن هُوَ كاذِبٌ ۖ وَارتَقِبوا إِنّي مَعَكُم رَقيبٌ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mdlxvii{وَلَمّا جاءَ أَمرُنا نَجَّينا شُعَيبًا وَالَّذينَ آمَنوا مَعَهُ بِرَحمَةٍ مِنّا وَأَخَذَتِ الَّذينَ ظَلَمُوا الصَّيحَةُ فَأَصبَحوا في دِيارِهِم جاثِمينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mdlxviii{كَأَن لَم يَغنَوا فيها ۗ أَلا بُعدًا لِمَديَنَ كَما بَعِدَت ثَمودُ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mdlxix{وَلَقَد أَرسَلنا موسىٰ بِآياتِنا وَسُلطانٍ مُبينٍ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mdlxx{إِلىٰ فِرعَونَ وَمَلَئِهِ فَاتَّبَعوا أَمرَ فِرعَونَ ۖ وَما أَمرُ فِرعَونَ بِرَشيدٍ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mdlxxi{يَقدُمُ قَومَهُ يَومَ القِيامَةِ فَأَورَدَهُمُ النّارَ ۖ وَبِئسَ الوِردُ المَورودُ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mdlxxii{وَأُتبِعوا في هٰذِهِ لَعنَةً وَيَومَ القِيامَةِ ۚ بِئسَ الرِّفدُ المَرفودُ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mdlxxiii{ذٰلِكَ مِن أَنباءِ القُرىٰ نَقُصُّهُ عَلَيكَ ۖ مِنها قائِمٌ وَحَصيدٌ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mdlxxiv{وَما ظَلَمناهُم وَلٰكِن ظَلَموا أَنفُسَهُم ۖ فَما أَغنَت عَنهُم آلِهَتُهُمُ الَّتي يَدعونَ مِن دونِ اللَّهِ مِن شَيءٍ لَمّا جاءَ أَمرُ رَبِّكَ ۖ وَما زادوهُم غَيرَ تَتبيبٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mdlxxv{وَكَذٰلِكَ أَخذُ رَبِّكَ إِذا أَخَذَ القُرىٰ وَهِيَ ظالِمَةٌ ۚ إِنَّ أَخذَهُ أَليمٌ شَديدٌ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mdlxxvi{إِنَّ في ذٰلِكَ لَآيَةً لِمَن خافَ عَذابَ الآخِرَةِ ۚ ذٰلِكَ يَومٌ مَجموعٌ لَهُ النّاسُ وَذٰلِكَ يَومٌ مَشهودٌ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mdlxxvii{وَما نُؤَخِّرُهُ إِلّا لِأَجَلٍ مَعدودٍ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mdlxxviii{يَومَ يَأتِ لا تَكَلَّمُ نَفسٌ إِلّا بِإِذنِهِ ۚ فَمِنهُم شَقِيٌّ وَسَعيدٌ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mdlxxix{فَأَمَّا الَّذينَ شَقوا فَفِي النّارِ لَهُم فيها زَفيرٌ وَشَهيقٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mdlxxx{خالِدينَ فيها ما دامَتِ السَّماواتُ وَالأَرضُ إِلّا ما شاءَ رَبُّكَ ۚ إِنَّ رَبَّكَ فَعّالٌ لِما يُريدُ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mdlxxxi{۞ وَأَمَّا الَّذينَ سُعِدوا فَفِي الجَنَّةِ خالِدينَ فيها ما دامَتِ السَّماواتُ وَالأَرضُ إِلّا ما شاءَ رَبُّكَ ۖ عَطاءً غَيرَ مَجذوذٍ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mdlxxxii{فَلا تَكُ في مِريَةٍ مِمّا يَعبُدُ هٰؤُلاءِ ۚ ما يَعبُدونَ إِلّا كَما يَعبُدُ آباؤُهُم مِن قَبلُ ۚ وَإِنّا لَمُوَفّوهُم نَصيبَهُم غَيرَ مَنقوصٍ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mdlxxxiii{وَلَقَد آتَينا موسَى الكِتابَ فَاختُلِفَ فيهِ ۚ وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ لَقُضِيَ بَينَهُم ۚ وَإِنَّهُم لَفي شَكٍّ مِنهُ مُريبٍ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mdlxxxiv{وَإِنَّ كُلًّا لَمّا لَيُوَفِّيَنَّهُم رَبُّكَ أَعمالَهُم ۚ إِنَّهُ بِما يَعمَلونَ خَبيرٌ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mdlxxxv{فَاستَقِم كَما أُمِرتَ وَمَن تابَ مَعَكَ وَلا تَطغَوا ۚ إِنَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mdlxxxvi{وَلا تَركَنوا إِلَى الَّذينَ ظَلَموا فَتَمَسَّكُمُ النّارُ وَما لَكُم مِن دونِ اللَّهِ مِن أَولِياءَ ثُمَّ لا تُنصَرونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mdlxxxvii{وَأَقِمِ الصَّلاةَ طَرَفَيِ النَّهارِ وَزُلَفًا مِنَ اللَّيلِ ۚ إِنَّ الحَسَناتِ يُذهِبنَ السَّيِّئَاتِ ۚ ذٰلِكَ ذِكرىٰ لِلذّاكِرينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mdlxxxviii{وَاصبِر فَإِنَّ اللَّهَ لا يُضيعُ أَجرَ المُحسِنينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mdlxxxix{فَلَولا كانَ مِنَ القُرونِ مِن قَبلِكُم أُولو بَقِيَّةٍ يَنهَونَ عَنِ الفَسادِ فِي الأَرضِ إِلّا قَليلًا مِمَّن أَنجَينا مِنهُم ۗ وَاتَّبَعَ الَّذينَ ظَلَموا ما أُترِفوا فيهِ وَكانوا مُجرِمينَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mdxc{وَما كانَ رَبُّكَ لِيُهلِكَ القُرىٰ بِظُلمٍ وَأَهلُها مُصلِحونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mdxci{وَلَو شاءَ رَبُّكَ لَجَعَلَ النّاسَ أُمَّةً واحِدَةً ۖ وَلا يَزالونَ مُختَلِفينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mdxcii{إِلّا مَن رَحِمَ رَبُّكَ ۚ وَلِذٰلِكَ خَلَقَهُم ۗ وَتَمَّت كَلِمَةُ رَبِّكَ لَأَملَأَنَّ جَهَنَّمَ مِنَ الجِنَّةِ وَالنّاسِ أَجمَعينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mdxciii{وَكُلًّا نَقُصُّ عَلَيكَ مِن أَنباءِ الرُّسُلِ ما نُثَبِّتُ بِهِ فُؤادَكَ ۚ وَجاءَكَ في هٰذِهِ الحَقُّ وَمَوعِظَةٌ وَذِكرىٰ لِلمُؤمِنينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mdxciv{وَقُل لِلَّذينَ لا يُؤمِنونَ اعمَلوا عَلىٰ مَكانَتِكُم إِنّا عامِلونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mdxcv{وَانتَظِروا إِنّا مُنتَظِرونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mdxcvi{وَلِلَّهِ غَيبُ السَّماواتِ وَالأَرضِ وَإِلَيهِ يُرجَعُ الأَمرُ كُلُّهُ فَاعبُدهُ وَتَوَكَّل عَلَيهِ ۚ وَما رَبُّكَ بِغافِلٍ عَمّا تَعمَلونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mdxcvii{\basmalah الر ۚ تِلكَ آياتُ الكِتابِ المُبينِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdxcviii{إِنّا أَنزَلناهُ قُرآنًا عَرَبِيًّا لَعَلَّكُم تَعقِلونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdxcix{نَحنُ نَقُصُّ عَلَيكَ أَحسَنَ القَصَصِ بِما أَوحَينا إِلَيكَ هٰذَا القُرآنَ وَإِن كُنتَ مِن قَبلِهِ لَمِنَ الغافِلينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdc{إِذ قالَ يوسُفُ لِأَبيهِ يا أَبَتِ إِنّي رَأَيتُ أَحَدَ عَشَرَ كَوكَبًا وَالشَّمسَ وَالقَمَرَ رَأَيتُهُم لي ساجِدينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdci{قالَ يا بُنَيَّ لا تَقصُص رُؤياكَ عَلىٰ إِخوَتِكَ فَيَكيدوا لَكَ كَيدًا ۖ إِنَّ الشَّيطانَ لِلإِنسانِ عَدُوٌّ مُبينٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdcii{وَكَذٰلِكَ يَجتَبيكَ رَبُّكَ وَيُعَلِّمُكَ مِن تَأويلِ الأَحاديثِ وَيُتِمُّ نِعمَتَهُ عَلَيكَ وَعَلىٰ آلِ يَعقوبَ كَما أَتَمَّها عَلىٰ أَبَوَيكَ مِن قَبلُ إِبراهيمَ وَإِسحاقَ ۚ إِنَّ رَبَّكَ عَليمٌ حَكيمٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdciii{۞ لَقَد كانَ في يوسُفَ وَإِخوَتِهِ آياتٌ لِلسّائِلينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdciv{إِذ قالوا لَيوسُفُ وَأَخوهُ أَحَبُّ إِلىٰ أَبينا مِنّا وَنَحنُ عُصبَةٌ إِنَّ أَبانا لَفي ضَلالٍ مُبينٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdcv{اقتُلوا يوسُفَ أَوِ اطرَحوهُ أَرضًا يَخلُ لَكُم وَجهُ أَبيكُم وَتَكونوا مِن بَعدِهِ قَومًا صالِحينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdcvi{قالَ قائِلٌ مِنهُم لا تَقتُلوا يوسُفَ وَأَلقوهُ في غَيابَتِ الجُبِّ يَلتَقِطهُ بَعضُ السَّيّارَةِ إِن كُنتُم فاعِلينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdcvii{قالوا يا أَبانا ما لَكَ لا تَأمَنّا عَلىٰ يوسُفَ وَإِنّا لَهُ لَناصِحونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdcviii{أَرسِلهُ مَعَنا غَدًا يَرتَع وَيَلعَب وَإِنّا لَهُ لَحافِظونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdcix{قالَ إِنّي لَيَحزُنُني أَن تَذهَبوا بِهِ وَأَخافُ أَن يَأكُلَهُ الذِّئبُ وَأَنتُم عَنهُ غافِلونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdcx{قالوا لَئِن أَكَلَهُ الذِّئبُ وَنَحنُ عُصبَةٌ إِنّا إِذًا لَخاسِرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdcxi{فَلَمّا ذَهَبوا بِهِ وَأَجمَعوا أَن يَجعَلوهُ في غَيابَتِ الجُبِّ ۚ وَأَوحَينا إِلَيهِ لَتُنَبِّئَنَّهُم بِأَمرِهِم هٰذا وَهُم لا يَشعُرونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdcxii{وَجاءوا أَباهُم عِشاءً يَبكونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdcxiii{قالوا يا أَبانا إِنّا ذَهَبنا نَستَبِقُ وَتَرَكنا يوسُفَ عِندَ مَتاعِنا فَأَكَلَهُ الذِّئبُ ۖ وَما أَنتَ بِمُؤمِنٍ لَنا وَلَو كُنّا صادِقينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdcxiv{وَجاءوا عَلىٰ قَميصِهِ بِدَمٍ كَذِبٍ ۚ قالَ بَل سَوَّلَت لَكُم أَنفُسُكُم أَمرًا ۖ فَصَبرٌ جَميلٌ ۖ وَاللَّهُ المُستَعانُ عَلىٰ ما تَصِفونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdcxv{وَجاءَت سَيّارَةٌ فَأَرسَلوا وارِدَهُم فَأَدلىٰ دَلوَهُ ۖ قالَ يا بُشرىٰ هٰذا غُلامٌ ۚ وَأَسَرّوهُ بِضاعَةً ۚ وَاللَّهُ عَليمٌ بِما يَعمَلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdcxvi{وَشَرَوهُ بِثَمَنٍ بَخسٍ دَراهِمَ مَعدودَةٍ وَكانوا فيهِ مِنَ الزّاهِدينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdcxvii{وَقالَ الَّذِي اشتَراهُ مِن مِصرَ لِامرَأَتِهِ أَكرِمي مَثواهُ عَسىٰ أَن يَنفَعَنا أَو نَتَّخِذَهُ وَلَدًا ۚ وَكَذٰلِكَ مَكَّنّا لِيوسُفَ فِي الأَرضِ وَلِنُعَلِّمَهُ مِن تَأويلِ الأَحاديثِ ۚ وَاللَّهُ غالِبٌ عَلىٰ أَمرِهِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdcxviii{وَلَمّا بَلَغَ أَشُدَّهُ آتَيناهُ حُكمًا وَعِلمًا ۚ وَكَذٰلِكَ نَجزِي المُحسِنينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdcxix{وَراوَدَتهُ الَّتي هُوَ في بَيتِها عَن نَفسِهِ وَغَلَّقَتِ الأَبوابَ وَقالَت هَيتَ لَكَ ۚ قالَ مَعاذَ اللَّهِ ۖ إِنَّهُ رَبّي أَحسَنَ مَثوايَ ۖ إِنَّهُ لا يُفلِحُ الظّالِمونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdcxx{وَلَقَد هَمَّت بِهِ ۖ وَهَمَّ بِها لَولا أَن رَأىٰ بُرهانَ رَبِّهِ ۚ كَذٰلِكَ لِنَصرِفَ عَنهُ السّوءَ وَالفَحشاءَ ۚ إِنَّهُ مِن عِبادِنَا المُخلَصينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdcxxi{وَاستَبَقَا البابَ وَقَدَّت قَميصَهُ مِن دُبُرٍ وَأَلفَيا سَيِّدَها لَدَى البابِ ۚ قالَت ما جَزاءُ مَن أَرادَ بِأَهلِكَ سوءًا إِلّا أَن يُسجَنَ أَو عَذابٌ أَليمٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdcxxii{قالَ هِيَ راوَدَتني عَن نَفسي ۚ وَشَهِدَ شاهِدٌ مِن أَهلِها إِن كانَ قَميصُهُ قُدَّ مِن قُبُلٍ فَصَدَقَت وَهُوَ مِنَ الكاذِبينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdcxxiii{وَإِن كانَ قَميصُهُ قُدَّ مِن دُبُرٍ فَكَذَبَت وَهُوَ مِنَ الصّادِقينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdcxxiv{فَلَمّا رَأىٰ قَميصَهُ قُدَّ مِن دُبُرٍ قالَ إِنَّهُ مِن كَيدِكُنَّ ۖ إِنَّ كَيدَكُنَّ عَظيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdcxxv{يوسُفُ أَعرِض عَن هٰذا ۚ وَاستَغفِري لِذَنبِكِ ۖ إِنَّكِ كُنتِ مِنَ الخاطِئينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdcxxvi{۞ وَقالَ نِسوَةٌ فِي المَدينَةِ امرَأَتُ العَزيزِ تُراوِدُ فَتاها عَن نَفسِهِ ۖ قَد شَغَفَها حُبًّا ۖ إِنّا لَنَراها في ضَلالٍ مُبينٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdcxxvii{فَلَمّا سَمِعَت بِمَكرِهِنَّ أَرسَلَت إِلَيهِنَّ وَأَعتَدَت لَهُنَّ مُتَّكَأً وَآتَت كُلَّ واحِدَةٍ مِنهُنَّ سِكّينًا وَقالَتِ اخرُج عَلَيهِنَّ ۖ فَلَمّا رَأَينَهُ أَكبَرنَهُ وَقَطَّعنَ أَيدِيَهُنَّ وَقُلنَ حاشَ لِلَّهِ ما هٰذا بَشَرًا إِن هٰذا إِلّا مَلَكٌ كَريمٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdcxxviii{قالَت فَذٰلِكُنَّ الَّذي لُمتُنَّني فيهِ ۖ وَلَقَد راوَدتُهُ عَن نَفسِهِ فَاستَعصَمَ ۖ وَلَئِن لَم يَفعَل ما آمُرُهُ لَيُسجَنَنَّ وَلَيَكونًا مِنَ الصّاغِرينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdcxxix{قالَ رَبِّ السِّجنُ أَحَبُّ إِلَيَّ مِمّا يَدعونَني إِلَيهِ ۖ وَإِلّا تَصرِف عَنّي كَيدَهُنَّ أَصبُ إِلَيهِنَّ وَأَكُن مِنَ الجاهِلينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdcxxx{فَاستَجابَ لَهُ رَبُّهُ فَصَرَفَ عَنهُ كَيدَهُنَّ ۚ إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdcxxxi{ثُمَّ بَدا لَهُم مِن بَعدِ ما رَأَوُا الآياتِ لَيَسجُنُنَّهُ حَتّىٰ حينٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdcxxxii{وَدَخَلَ مَعَهُ السِّجنَ فَتَيانِ ۖ قالَ أَحَدُهُما إِنّي أَراني أَعصِرُ خَمرًا ۖ وَقالَ الآخَرُ إِنّي أَراني أَحمِلُ فَوقَ رَأسي خُبزًا تَأكُلُ الطَّيرُ مِنهُ ۖ نَبِّئنا بِتَأويلِهِ ۖ إِنّا نَراكَ مِنَ المُحسِنينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdcxxxiii{قالَ لا يَأتيكُما طَعامٌ تُرزَقانِهِ إِلّا نَبَّأتُكُما بِتَأويلِهِ قَبلَ أَن يَأتِيَكُما ۚ ذٰلِكُما مِمّا عَلَّمَني رَبّي ۚ إِنّي تَرَكتُ مِلَّةَ قَومٍ لا يُؤمِنونَ بِاللَّهِ وَهُم بِالآخِرَةِ هُم كافِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdcxxxiv{وَاتَّبَعتُ مِلَّةَ آبائي إِبراهيمَ وَإِسحاقَ وَيَعقوبَ ۚ ما كانَ لَنا أَن نُشرِكَ بِاللَّهِ مِن شَيءٍ ۚ ذٰلِكَ مِن فَضلِ اللَّهِ عَلَينا وَعَلَى النّاسِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَشكُرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdcxxxv{يا صاحِبَيِ السِّجنِ أَأَربابٌ مُتَفَرِّقونَ خَيرٌ أَمِ اللَّهُ الواحِدُ القَهّارُ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdcxxxvi{ما تَعبُدونَ مِن دونِهِ إِلّا أَسماءً سَمَّيتُموها أَنتُم وَآباؤُكُم ما أَنزَلَ اللَّهُ بِها مِن سُلطانٍ ۚ إِنِ الحُكمُ إِلّا لِلَّهِ ۚ أَمَرَ أَلّا تَعبُدوا إِلّا إِيّاهُ ۚ ذٰلِكَ الدّينُ القَيِّمُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdcxxxvii{يا صاحِبَيِ السِّجنِ أَمّا أَحَدُكُما فَيَسقي رَبَّهُ خَمرًا ۖ وَأَمَّا الآخَرُ فَيُصلَبُ فَتَأكُلُ الطَّيرُ مِن رَأسِهِ ۚ قُضِيَ الأَمرُ الَّذي فيهِ تَستَفتِيانِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdcxxxviii{وَقالَ لِلَّذي ظَنَّ أَنَّهُ ناجٍ مِنهُمَا اذكُرني عِندَ رَبِّكَ فَأَنساهُ الشَّيطانُ ذِكرَ رَبِّهِ فَلَبِثَ فِي السِّجنِ بِضعَ سِنينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdcxxxix{وَقالَ المَلِكُ إِنّي أَرىٰ سَبعَ بَقَراتٍ سِمانٍ يَأكُلُهُنَّ سَبعٌ عِجافٌ وَسَبعَ سُنبُلاتٍ خُضرٍ وَأُخَرَ يابِساتٍ ۖ يا أَيُّهَا المَلَأُ أَفتوني في رُؤيايَ إِن كُنتُم لِلرُّؤيا تَعبُرونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdcxl{قالوا أَضغاثُ أَحلامٍ ۖ وَما نَحنُ بِتَأويلِ الأَحلامِ بِعالِمينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdcxli{وَقالَ الَّذي نَجا مِنهُما وَادَّكَرَ بَعدَ أُمَّةٍ أَنا أُنَبِّئُكُم بِتَأويلِهِ فَأَرسِلونِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdcxlii{يوسُفُ أَيُّهَا الصِّدّيقُ أَفتِنا في سَبعِ بَقَراتٍ سِمانٍ يَأكُلُهُنَّ سَبعٌ عِجافٌ وَسَبعِ سُنبُلاتٍ خُضرٍ وَأُخَرَ يابِساتٍ لَعَلّي أَرجِعُ إِلَى النّاسِ لَعَلَّهُم يَعلَمونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdcxliii{قالَ تَزرَعونَ سَبعَ سِنينَ دَأَبًا فَما حَصَدتُم فَذَروهُ في سُنبُلِهِ إِلّا قَليلًا مِمّا تَأكُلونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdcxliv{ثُمَّ يَأتي مِن بَعدِ ذٰلِكَ سَبعٌ شِدادٌ يَأكُلنَ ما قَدَّمتُم لَهُنَّ إِلّا قَليلًا مِمّا تُحصِنونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdcxlv{ثُمَّ يَأتي مِن بَعدِ ذٰلِكَ عامٌ فيهِ يُغاثُ النّاسُ وَفيهِ يَعصِرونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdcxlvi{وَقالَ المَلِكُ ائتوني بِهِ ۖ فَلَمّا جاءَهُ الرَّسولُ قالَ ارجِع إِلىٰ رَبِّكَ فَاسأَلهُ ما بالُ النِّسوَةِ اللّاتي قَطَّعنَ أَيدِيَهُنَّ ۚ إِنَّ رَبّي بِكَيدِهِنَّ عَليمٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdcxlvii{قالَ ما خَطبُكُنَّ إِذ راوَدتُنَّ يوسُفَ عَن نَفسِهِ ۚ قُلنَ حاشَ لِلَّهِ ما عَلِمنا عَلَيهِ مِن سوءٍ ۚ قالَتِ امرَأَتُ العَزيزِ الآنَ حَصحَصَ الحَقُّ أَنا راوَدتُهُ عَن نَفسِهِ وَإِنَّهُ لَمِنَ الصّادِقينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdcxlviii{ذٰلِكَ لِيَعلَمَ أَنّي لَم أَخُنهُ بِالغَيبِ وَأَنَّ اللَّهَ لا يَهدي كَيدَ الخائِنينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdcxlix{۞ وَما أُبَرِّئُ نَفسي ۚ إِنَّ النَّفسَ لَأَمّارَةٌ بِالسّوءِ إِلّا ما رَحِمَ رَبّي ۚ إِنَّ رَبّي غَفورٌ رَحيمٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mdcl{وَقالَ المَلِكُ ائتوني بِهِ أَستَخلِصهُ لِنَفسي ۖ فَلَمّا كَلَّمَهُ قالَ إِنَّكَ اليَومَ لَدَينا مَكينٌ أَمينٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mdcli{قالَ اجعَلني عَلىٰ خَزائِنِ الأَرضِ ۖ إِنّي حَفيظٌ عَليمٌ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mdclii{وَكَذٰلِكَ مَكَّنّا لِيوسُفَ فِي الأَرضِ يَتَبَوَّأُ مِنها حَيثُ يَشاءُ ۚ نُصيبُ بِرَحمَتِنا مَن نَشاءُ ۖ وَلا نُضيعُ أَجرَ المُحسِنينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mdcliii{وَلَأَجرُ الآخِرَةِ خَيرٌ لِلَّذينَ آمَنوا وَكانوا يَتَّقونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mdcliv{وَجاءَ إِخوَةُ يوسُفَ فَدَخَلوا عَلَيهِ فَعَرَفَهُم وَهُم لَهُ مُنكِرونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mdclv{وَلَمّا جَهَّزَهُم بِجَهازِهِم قالَ ائتوني بِأَخٍ لَكُم مِن أَبيكُم ۚ أَلا تَرَونَ أَنّي أوفِي الكَيلَ وَأَنا خَيرُ المُنزِلينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mdclvi{فَإِن لَم تَأتوني بِهِ فَلا كَيلَ لَكُم عِندي وَلا تَقرَبونِ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mdclvii{قالوا سَنُراوِدُ عَنهُ أَباهُ وَإِنّا لَفاعِلونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mdclviii{وَقالَ لِفِتيانِهِ اجعَلوا بِضاعَتَهُم في رِحالِهِم لَعَلَّهُم يَعرِفونَها إِذَا انقَلَبوا إِلىٰ أَهلِهِم لَعَلَّهُم يَرجِعونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mdclix{فَلَمّا رَجَعوا إِلىٰ أَبيهِم قالوا يا أَبانا مُنِعَ مِنَّا الكَيلُ فَأَرسِل مَعَنا أَخانا نَكتَل وَإِنّا لَهُ لَحافِظونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mdclx{قالَ هَل آمَنُكُم عَلَيهِ إِلّا كَما أَمِنتُكُم عَلىٰ أَخيهِ مِن قَبلُ ۖ فَاللَّهُ خَيرٌ حافِظًا ۖ وَهُوَ أَرحَمُ الرّاحِمينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mdclxi{وَلَمّا فَتَحوا مَتاعَهُم وَجَدوا بِضاعَتَهُم رُدَّت إِلَيهِم ۖ قالوا يا أَبانا ما نَبغي ۖ هٰذِهِ بِضاعَتُنا رُدَّت إِلَينا ۖ وَنَميرُ أَهلَنا وَنَحفَظُ أَخانا وَنَزدادُ كَيلَ بَعيرٍ ۖ ذٰلِكَ كَيلٌ يَسيرٌ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mdclxii{قالَ لَن أُرسِلَهُ مَعَكُم حَتّىٰ تُؤتونِ مَوثِقًا مِنَ اللَّهِ لَتَأتُنَّني بِهِ إِلّا أَن يُحاطَ بِكُم ۖ فَلَمّا آتَوهُ مَوثِقَهُم قالَ اللَّهُ عَلىٰ ما نَقولُ وَكيلٌ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mdclxiii{وَقالَ يا بَنِيَّ لا تَدخُلوا مِن بابٍ واحِدٍ وَادخُلوا مِن أَبوابٍ مُتَفَرِّقَةٍ ۖ وَما أُغني عَنكُم مِنَ اللَّهِ مِن شَيءٍ ۖ إِنِ الحُكمُ إِلّا لِلَّهِ ۖ عَلَيهِ تَوَكَّلتُ ۖ وَعَلَيهِ فَليَتَوَكَّلِ المُتَوَكِّلونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mdclxiv{وَلَمّا دَخَلوا مِن حَيثُ أَمَرَهُم أَبوهُم ما كانَ يُغني عَنهُم مِنَ اللَّهِ مِن شَيءٍ إِلّا حاجَةً في نَفسِ يَعقوبَ قَضاها ۚ وَإِنَّهُ لَذو عِلمٍ لِما عَلَّمناهُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mdclxv{وَلَمّا دَخَلوا عَلىٰ يوسُفَ آوىٰ إِلَيهِ أَخاهُ ۖ قالَ إِنّي أَنا أَخوكَ فَلا تَبتَئِس بِما كانوا يَعمَلونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mdclxvi{فَلَمّا جَهَّزَهُم بِجَهازِهِم جَعَلَ السِّقايَةَ في رَحلِ أَخيهِ ثُمَّ أَذَّنَ مُؤَذِّنٌ أَيَّتُهَا العيرُ إِنَّكُم لَسارِقونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mdclxvii{قالوا وَأَقبَلوا عَلَيهِم ماذا تَفقِدونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mdclxviii{قالوا نَفقِدُ صُواعَ المَلِكِ وَلِمَن جاءَ بِهِ حِملُ بَعيرٍ وَأَنا بِهِ زَعيمٌ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mdclxix{قالوا تَاللَّهِ لَقَد عَلِمتُم ما جِئنا لِنُفسِدَ فِي الأَرضِ وَما كُنّا سارِقينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mdclxx{قالوا فَما جَزاؤُهُ إِن كُنتُم كاذِبينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mdclxxi{قالوا جَزاؤُهُ مَن وُجِدَ في رَحلِهِ فَهُوَ جَزاؤُهُ ۚ كَذٰلِكَ نَجزِي الظّالِمينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mdclxxii{فَبَدَأَ بِأَوعِيَتِهِم قَبلَ وِعاءِ أَخيهِ ثُمَّ استَخرَجَها مِن وِعاءِ أَخيهِ ۚ كَذٰلِكَ كِدنا لِيوسُفَ ۖ ما كانَ لِيَأخُذَ أَخاهُ في دينِ المَلِكِ إِلّا أَن يَشاءَ اللَّهُ ۚ نَرفَعُ دَرَجاتٍ مَن نَشاءُ ۗ وَفَوقَ كُلِّ ذي عِلمٍ عَليمٌ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mdclxxiii{۞ قالوا إِن يَسرِق فَقَد سَرَقَ أَخٌ لَهُ مِن قَبلُ ۚ فَأَسَرَّها يوسُفُ في نَفسِهِ وَلَم يُبدِها لَهُم ۚ قالَ أَنتُم شَرٌّ مَكانًا ۖ وَاللَّهُ أَعلَمُ بِما تَصِفونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mdclxxiv{قالوا يا أَيُّهَا العَزيزُ إِنَّ لَهُ أَبًا شَيخًا كَبيرًا فَخُذ أَحَدَنا مَكانَهُ ۖ إِنّا نَراكَ مِنَ المُحسِنينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mdclxxv{قالَ مَعاذَ اللَّهِ أَن نَأخُذَ إِلّا مَن وَجَدنا مَتاعَنا عِندَهُ إِنّا إِذًا لَظالِمونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mdclxxvi{فَلَمَّا استَيأَسوا مِنهُ خَلَصوا نَجِيًّا ۖ قالَ كَبيرُهُم أَلَم تَعلَموا أَنَّ أَباكُم قَد أَخَذَ عَلَيكُم مَوثِقًا مِنَ اللَّهِ وَمِن قَبلُ ما فَرَّطتُم في يوسُفَ ۖ فَلَن أَبرَحَ الأَرضَ حَتّىٰ يَأذَنَ لي أَبي أَو يَحكُمَ اللَّهُ لي ۖ وَهُوَ خَيرُ الحاكِمينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mdclxxvii{ارجِعوا إِلىٰ أَبيكُم فَقولوا يا أَبانا إِنَّ ابنَكَ سَرَقَ وَما شَهِدنا إِلّا بِما عَلِمنا وَما كُنّا لِلغَيبِ حافِظينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mdclxxviii{وَاسأَلِ القَريَةَ الَّتي كُنّا فيها وَالعيرَ الَّتي أَقبَلنا فيها ۖ وَإِنّا لَصادِقونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mdclxxix{قالَ بَل سَوَّلَت لَكُم أَنفُسُكُم أَمرًا ۖ فَصَبرٌ جَميلٌ ۖ عَسَى اللَّهُ أَن يَأتِيَني بِهِم جَميعًا ۚ إِنَّهُ هُوَ العَليمُ الحَكيمُ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mdclxxx{وَتَوَلّىٰ عَنهُم وَقالَ يا أَسَفىٰ عَلىٰ يوسُفَ وَابيَضَّت عَيناهُ مِنَ الحُزنِ فَهُوَ كَظيمٌ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mdclxxxi{قالوا تَاللَّهِ تَفتَأُ تَذكُرُ يوسُفَ حَتّىٰ تَكونَ حَرَضًا أَو تَكونَ مِنَ الهالِكينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mdclxxxii{قالَ إِنَّما أَشكو بَثّي وَحُزني إِلَى اللَّهِ وَأَعلَمُ مِنَ اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mdclxxxiii{يا بَنِيَّ اذهَبوا فَتَحَسَّسوا مِن يوسُفَ وَأَخيهِ وَلا تَيأَسوا مِن رَوحِ اللَّهِ ۖ إِنَّهُ لا يَيأَسُ مِن رَوحِ اللَّهِ إِلَّا القَومُ الكافِرونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mdclxxxiv{فَلَمّا دَخَلوا عَلَيهِ قالوا يا أَيُّهَا العَزيزُ مَسَّنا وَأَهلَنَا الضُّرُّ وَجِئنا بِبِضاعَةٍ مُزجاةٍ فَأَوفِ لَنَا الكَيلَ وَتَصَدَّق عَلَينا ۖ إِنَّ اللَّهَ يَجزِي المُتَصَدِّقينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mdclxxxv{قالَ هَل عَلِمتُم ما فَعَلتُم بِيوسُفَ وَأَخيهِ إِذ أَنتُم جاهِلونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mdclxxxvi{قالوا أَإِنَّكَ لَأَنتَ يوسُفُ ۖ قالَ أَنا يوسُفُ وَهٰذا أَخي ۖ قَد مَنَّ اللَّهُ عَلَينا ۖ إِنَّهُ مَن يَتَّقِ وَيَصبِر فَإِنَّ اللَّهَ لا يُضيعُ أَجرَ المُحسِنينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mdclxxxvii{قالوا تَاللَّهِ لَقَد آثَرَكَ اللَّهُ عَلَينا وَإِن كُنّا لَخاطِئينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mdclxxxviii{قالَ لا تَثريبَ عَلَيكُمُ اليَومَ ۖ يَغفِرُ اللَّهُ لَكُم ۖ وَهُوَ أَرحَمُ الرّاحِمينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mdclxxxix{اذهَبوا بِقَميصي هٰذا فَأَلقوهُ عَلىٰ وَجهِ أَبي يَأتِ بَصيرًا وَأتوني بِأَهلِكُم أَجمَعينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mdcxc{وَلَمّا فَصَلَتِ العيرُ قالَ أَبوهُم إِنّي لَأَجِدُ ريحَ يوسُفَ ۖ لَولا أَن تُفَنِّدونِ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mdcxci{قالوا تَاللَّهِ إِنَّكَ لَفي ضَلالِكَ القَديمِ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mdcxcii{فَلَمّا أَن جاءَ البَشيرُ أَلقاهُ عَلىٰ وَجهِهِ فَارتَدَّ بَصيرًا ۖ قالَ أَلَم أَقُل لَكُم إِنّي أَعلَمُ مِنَ اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mdcxciii{قالوا يا أَبانَا استَغفِر لَنا ذُنوبَنا إِنّا كُنّا خاطِئينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mdcxciv{قالَ سَوفَ أَستَغفِرُ لَكُم رَبّي ۖ إِنَّهُ هُوَ الغَفورُ الرَّحيمُ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mdcxcv{فَلَمّا دَخَلوا عَلىٰ يوسُفَ آوىٰ إِلَيهِ أَبَوَيهِ وَقالَ ادخُلوا مِصرَ إِن شاءَ اللَّهُ آمِنينَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mdcxcvi{وَرَفَعَ أَبَوَيهِ عَلَى العَرشِ وَخَرّوا لَهُ سُجَّدًا ۖ وَقالَ يا أَبَتِ هٰذا تَأويلُ رُؤيايَ مِن قَبلُ قَد جَعَلَها رَبّي حَقًّا ۖ وَقَد أَحسَنَ بي إِذ أَخرَجَني مِنَ السِّجنِ وَجاءَ بِكُم مِنَ البَدوِ مِن بَعدِ أَن نَزَغَ الشَّيطانُ بَيني وَبَينَ إِخوَتي ۚ إِنَّ رَبّي لَطيفٌ لِما يَشاءُ ۚ إِنَّهُ هُوَ العَليمُ الحَكيمُ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mdcxcvii{۞ رَبِّ قَد آتَيتَني مِنَ المُلكِ وَعَلَّمتَني مِن تَأويلِ الأَحاديثِ ۚ فاطِرَ السَّماواتِ وَالأَرضِ أَنتَ وَلِيّي فِي الدُّنيا وَالآخِرَةِ ۖ تَوَفَّني مُسلِمًا وَأَلحِقني بِالصّالِحينَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mdcxcviii{ذٰلِكَ مِن أَنباءِ الغَيبِ نوحيهِ إِلَيكَ ۖ وَما كُنتَ لَدَيهِم إِذ أَجمَعوا أَمرَهُم وَهُم يَمكُرونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mdcxcix{وَما أَكثَرُ النّاسِ وَلَو حَرَصتَ بِمُؤمِنينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mdcc{وَما تَسأَلُهُم عَلَيهِ مِن أَجرٍ ۚ إِن هُوَ إِلّا ذِكرٌ لِلعالَمينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mdcci{وَكَأَيِّن مِن آيَةٍ فِي السَّماواتِ وَالأَرضِ يَمُرّونَ عَلَيها وَهُم عَنها مُعرِضونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mdccii{وَما يُؤمِنُ أَكثَرُهُم بِاللَّهِ إِلّا وَهُم مُشرِكونَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mdcciii{أَفَأَمِنوا أَن تَأتِيَهُم غاشِيَةٌ مِن عَذابِ اللَّهِ أَو تَأتِيَهُمُ السّاعَةُ بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mdcciv{قُل هٰذِهِ سَبيلي أَدعو إِلَى اللَّهِ ۚ عَلىٰ بَصيرَةٍ أَنا وَمَنِ اتَّبَعَني ۖ وَسُبحانَ اللَّهِ وَما أَنا مِنَ المُشرِكينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mdccv{وَما أَرسَلنا مِن قَبلِكَ إِلّا رِجالًا نوحي إِلَيهِم مِن أَهلِ القُرىٰ ۗ أَفَلَم يَسيروا فِي الأَرضِ فَيَنظُروا كَيفَ كانَ عاقِبَةُ الَّذينَ مِن قَبلِهِم ۗ وَلَدارُ الآخِرَةِ خَيرٌ لِلَّذينَ اتَّقَوا ۗ أَفَلا تَعقِلونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mdccvi{حَتّىٰ إِذَا استَيأَسَ الرُّسُلُ وَظَنّوا أَنَّهُم قَد كُذِبوا جاءَهُم نَصرُنا فَنُجِّيَ مَن نَشاءُ ۖ وَلا يُرَدُّ بَأسُنا عَنِ القَومِ المُجرِمينَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mdccvii{لَقَد كانَ في قَصَصِهِم عِبرَةٌ لِأُولِي الأَلبابِ ۗ ما كانَ حَديثًا يُفتَرىٰ وَلٰكِن تَصديقَ الَّذي بَينَ يَدَيهِ وَتَفصيلَ كُلِّ شَيءٍ وَهُدًى وَرَحمَةً لِقَومٍ يُؤمِنونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mdccviii{\basmalah المر ۚ تِلكَ آياتُ الكِتابِ ۗ وَالَّذي أُنزِلَ إِلَيكَ مِن رَبِّكَ الحَقُّ وَلٰكِنَّ أَكثَرَ النّاسِ لا يُؤمِنونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdccix{اللَّهُ الَّذي رَفَعَ السَّماواتِ بِغَيرِ عَمَدٍ تَرَونَها ۖ ثُمَّ استَوىٰ عَلَى العَرشِ ۖ وَسَخَّرَ الشَّمسَ وَالقَمَرَ ۖ كُلٌّ يَجري لِأَجَلٍ مُسَمًّى ۚ يُدَبِّرُ الأَمرَ يُفَصِّلُ الآياتِ لَعَلَّكُم بِلِقاءِ رَبِّكُم توقِنونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdccx{وَهُوَ الَّذي مَدَّ الأَرضَ وَجَعَلَ فيها رَواسِيَ وَأَنهارًا ۖ وَمِن كُلِّ الثَّمَراتِ جَعَلَ فيها زَوجَينِ اثنَينِ ۖ يُغشِي اللَّيلَ النَّهارَ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdccxi{وَفِي الأَرضِ قِطَعٌ مُتَجاوِراتٌ وَجَنّاتٌ مِن أَعنابٍ وَزَرعٌ وَنَخيلٌ صِنوانٌ وَغَيرُ صِنوانٍ يُسقىٰ بِماءٍ واحِدٍ وَنُفَضِّلُ بَعضَها عَلىٰ بَعضٍ فِي الأُكُلِ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يَعقِلونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdccxii{۞ وَإِن تَعجَب فَعَجَبٌ قَولُهُم أَإِذا كُنّا تُرابًا أَإِنّا لَفي خَلقٍ جَديدٍ ۗ أُولٰئِكَ الَّذينَ كَفَروا بِرَبِّهِم ۖ وَأُولٰئِكَ الأَغلالُ في أَعناقِهِم ۖ وَأُولٰئِكَ أَصحابُ النّارِ ۖ هُم فيها خالِدونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdccxiii{وَيَستَعجِلونَكَ بِالسَّيِّئَةِ قَبلَ الحَسَنَةِ وَقَد خَلَت مِن قَبلِهِمُ المَثُلاتُ ۗ وَإِنَّ رَبَّكَ لَذو مَغفِرَةٍ لِلنّاسِ عَلىٰ ظُلمِهِم ۖ وَإِنَّ رَبَّكَ لَشَديدُ العِقابِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdccxiv{وَيَقولُ الَّذينَ كَفَروا لَولا أُنزِلَ عَلَيهِ آيَةٌ مِن رَبِّهِ ۗ إِنَّما أَنتَ مُنذِرٌ ۖ وَلِكُلِّ قَومٍ هادٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdccxv{اللَّهُ يَعلَمُ ما تَحمِلُ كُلُّ أُنثىٰ وَما تَغيضُ الأَرحامُ وَما تَزدادُ ۖ وَكُلُّ شَيءٍ عِندَهُ بِمِقدارٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdccxvi{عالِمُ الغَيبِ وَالشَّهادَةِ الكَبيرُ المُتَعالِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdccxvii{سَواءٌ مِنكُم مَن أَسَرَّ القَولَ وَمَن جَهَرَ بِهِ وَمَن هُوَ مُستَخفٍ بِاللَّيلِ وَسارِبٌ بِالنَّهارِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdccxviii{لَهُ مُعَقِّباتٌ مِن بَينِ يَدَيهِ وَمِن خَلفِهِ يَحفَظونَهُ مِن أَمرِ اللَّهِ ۗ إِنَّ اللَّهَ لا يُغَيِّرُ ما بِقَومٍ حَتّىٰ يُغَيِّروا ما بِأَنفُسِهِم ۗ وَإِذا أَرادَ اللَّهُ بِقَومٍ سوءًا فَلا مَرَدَّ لَهُ ۚ وَما لَهُم مِن دونِهِ مِن والٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdccxix{هُوَ الَّذي يُريكُمُ البَرقَ خَوفًا وَطَمَعًا وَيُنشِئُ السَّحابَ الثِّقالَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdccxx{وَيُسَبِّحُ الرَّعدُ بِحَمدِهِ وَالمَلائِكَةُ مِن خيفَتِهِ وَيُرسِلُ الصَّواعِقَ فَيُصيبُ بِها مَن يَشاءُ وَهُم يُجادِلونَ فِي اللَّهِ وَهُوَ شَديدُ المِحالِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdccxxi{لَهُ دَعوَةُ الحَقِّ ۖ وَالَّذينَ يَدعونَ مِن دونِهِ لا يَستَجيبونَ لَهُم بِشَيءٍ إِلّا كَباسِطِ كَفَّيهِ إِلَى الماءِ لِيَبلُغَ فاهُ وَما هُوَ بِبالِغِهِ ۚ وَما دُعاءُ الكافِرينَ إِلّا في ضَلالٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdccxxii{وَلِلَّهِ يَسجُدُ مَن فِي السَّماواتِ وَالأَرضِ طَوعًا وَكَرهًا وَظِلالُهُم بِالغُدُوِّ وَالآصالِ ۩\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdccxxiii{قُل مَن رَبُّ السَّماواتِ وَالأَرضِ قُلِ اللَّهُ ۚ قُل أَفَاتَّخَذتُم مِن دونِهِ أَولِياءَ لا يَملِكونَ لِأَنفُسِهِم نَفعًا وَلا ضَرًّا ۚ قُل هَل يَستَوِي الأَعمىٰ وَالبَصيرُ أَم هَل تَستَوِي الظُّلُماتُ وَالنّورُ ۗ أَم جَعَلوا لِلَّهِ شُرَكاءَ خَلَقوا كَخَلقِهِ فَتَشابَهَ الخَلقُ عَلَيهِم ۚ قُلِ اللَّهُ خالِقُ كُلِّ شَيءٍ وَهُوَ الواحِدُ القَهّارُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdccxxiv{أَنزَلَ مِنَ السَّماءِ ماءً فَسالَت أَودِيَةٌ بِقَدَرِها فَاحتَمَلَ السَّيلُ زَبَدًا رابِيًا ۚ وَمِمّا يوقِدونَ عَلَيهِ فِي النّارِ ابتِغاءَ حِليَةٍ أَو مَتاعٍ زَبَدٌ مِثلُهُ ۚ كَذٰلِكَ يَضرِبُ اللَّهُ الحَقَّ وَالباطِلَ ۚ فَأَمَّا الزَّبَدُ فَيَذهَبُ جُفاءً ۖ وَأَمّا ما يَنفَعُ النّاسَ فَيَمكُثُ فِي الأَرضِ ۚ كَذٰلِكَ يَضرِبُ اللَّهُ الأَمثالَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdccxxv{لِلَّذينَ استَجابوا لِرَبِّهِمُ الحُسنىٰ ۚ وَالَّذينَ لَم يَستَجيبوا لَهُ لَو أَنَّ لَهُم ما فِي الأَرضِ جَميعًا وَمِثلَهُ مَعَهُ لَافتَدَوا بِهِ ۚ أُولٰئِكَ لَهُم سوءُ الحِسابِ وَمَأواهُم جَهَنَّمُ ۖ وَبِئسَ المِهادُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdccxxvi{۞ أَفَمَن يَعلَمُ أَنَّما أُنزِلَ إِلَيكَ مِن رَبِّكَ الحَقُّ كَمَن هُوَ أَعمىٰ ۚ إِنَّما يَتَذَكَّرُ أُولُو الأَلبابِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdccxxvii{الَّذينَ يوفونَ بِعَهدِ اللَّهِ وَلا يَنقُضونَ الميثاقَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdccxxviii{وَالَّذينَ يَصِلونَ ما أَمَرَ اللَّهُ بِهِ أَن يوصَلَ وَيَخشَونَ رَبَّهُم وَيَخافونَ سوءَ الحِسابِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdccxxix{وَالَّذينَ صَبَرُوا ابتِغاءَ وَجهِ رَبِّهِم وَأَقامُوا الصَّلاةَ وَأَنفَقوا مِمّا رَزَقناهُم سِرًّا وَعَلانِيَةً وَيَدرَءونَ بِالحَسَنَةِ السَّيِّئَةَ أُولٰئِكَ لَهُم عُقبَى الدّارِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdccxxx{جَنّاتُ عَدنٍ يَدخُلونَها وَمَن صَلَحَ مِن آبائِهِم وَأَزواجِهِم وَذُرِّيّاتِهِم ۖ وَالمَلائِكَةُ يَدخُلونَ عَلَيهِم مِن كُلِّ بابٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdccxxxi{سَلامٌ عَلَيكُم بِما صَبَرتُم ۚ فَنِعمَ عُقبَى الدّارِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdccxxxii{وَالَّذينَ يَنقُضونَ عَهدَ اللَّهِ مِن بَعدِ ميثاقِهِ وَيَقطَعونَ ما أَمَرَ اللَّهُ بِهِ أَن يوصَلَ وَيُفسِدونَ فِي الأَرضِ ۙ أُولٰئِكَ لَهُمُ اللَّعنَةُ وَلَهُم سوءُ الدّارِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdccxxxiii{اللَّهُ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ ۚ وَفَرِحوا بِالحَياةِ الدُّنيا وَمَا الحَياةُ الدُّنيا فِي الآخِرَةِ إِلّا مَتاعٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdccxxxiv{وَيَقولُ الَّذينَ كَفَروا لَولا أُنزِلَ عَلَيهِ آيَةٌ مِن رَبِّهِ ۗ قُل إِنَّ اللَّهَ يُضِلُّ مَن يَشاءُ وَيَهدي إِلَيهِ مَن أَنابَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdccxxxv{الَّذينَ آمَنوا وَتَطمَئِنُّ قُلوبُهُم بِذِكرِ اللَّهِ ۗ أَلا بِذِكرِ اللَّهِ تَطمَئِنُّ القُلوبُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdccxxxvi{الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ طوبىٰ لَهُم وَحُسنُ مَآبٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdccxxxvii{كَذٰلِكَ أَرسَلناكَ في أُمَّةٍ قَد خَلَت مِن قَبلِها أُمَمٌ لِتَتلُوَ عَلَيهِمُ الَّذي أَوحَينا إِلَيكَ وَهُم يَكفُرونَ بِالرَّحمٰنِ ۚ قُل هُوَ رَبّي لا إِلٰهَ إِلّا هُوَ عَلَيهِ تَوَكَّلتُ وَإِلَيهِ مَتابِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdccxxxviii{وَلَو أَنَّ قُرآنًا سُيِّرَت بِهِ الجِبالُ أَو قُطِّعَت بِهِ الأَرضُ أَو كُلِّمَ بِهِ المَوتىٰ ۗ بَل لِلَّهِ الأَمرُ جَميعًا ۗ أَفَلَم يَيأَسِ الَّذينَ آمَنوا أَن لَو يَشاءُ اللَّهُ لَهَدَى النّاسَ جَميعًا ۗ وَلا يَزالُ الَّذينَ كَفَروا تُصيبُهُم بِما صَنَعوا قارِعَةٌ أَو تَحُلُّ قَريبًا مِن دارِهِم حَتّىٰ يَأتِيَ وَعدُ اللَّهِ ۚ إِنَّ اللَّهَ لا يُخلِفُ الميعادَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdccxxxix{وَلَقَدِ استُهزِئَ بِرُسُلٍ مِن قَبلِكَ فَأَملَيتُ لِلَّذينَ كَفَروا ثُمَّ أَخَذتُهُم ۖ فَكَيفَ كانَ عِقابِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdccxl{أَفَمَن هُوَ قائِمٌ عَلىٰ كُلِّ نَفسٍ بِما كَسَبَت ۗ وَجَعَلوا لِلَّهِ شُرَكاءَ قُل سَمّوهُم ۚ أَم تُنَبِّئونَهُ بِما لا يَعلَمُ فِي الأَرضِ أَم بِظاهِرٍ مِنَ القَولِ ۗ بَل زُيِّنَ لِلَّذينَ كَفَروا مَكرُهُم وَصُدّوا عَنِ السَّبيلِ ۗ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن هادٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdccxli{لَهُم عَذابٌ فِي الحَياةِ الدُّنيا ۖ وَلَعَذابُ الآخِرَةِ أَشَقُّ ۖ وَما لَهُم مِنَ اللَّهِ مِن واقٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdccxlii{۞ مَثَلُ الجَنَّةِ الَّتي وُعِدَ المُتَّقونَ ۖ تَجري مِن تَحتِهَا الأَنهارُ ۖ أُكُلُها دائِمٌ وَظِلُّها ۚ تِلكَ عُقبَى الَّذينَ اتَّقَوا ۖ وَعُقبَى الكافِرينَ النّارُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdccxliii{وَالَّذينَ آتَيناهُمُ الكِتابَ يَفرَحونَ بِما أُنزِلَ إِلَيكَ ۖ وَمِنَ الأَحزابِ مَن يُنكِرُ بَعضَهُ ۚ قُل إِنَّما أُمِرتُ أَن أَعبُدَ اللَّهَ وَلا أُشرِكَ بِهِ ۚ إِلَيهِ أَدعو وَإِلَيهِ مَآبِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdccxliv{وَكَذٰلِكَ أَنزَلناهُ حُكمًا عَرَبِيًّا ۚ وَلَئِنِ اتَّبَعتَ أَهواءَهُم بَعدَما جاءَكَ مِنَ العِلمِ ما لَكَ مِنَ اللَّهِ مِن وَلِيٍّ وَلا واقٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdccxlv{وَلَقَد أَرسَلنا رُسُلًا مِن قَبلِكَ وَجَعَلنا لَهُم أَزواجًا وَذُرِّيَّةً ۚ وَما كانَ لِرَسولٍ أَن يَأتِيَ بِآيَةٍ إِلّا بِإِذنِ اللَّهِ ۗ لِكُلِّ أَجَلٍ كِتابٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdccxlvi{يَمحُو اللَّهُ ما يَشاءُ وَيُثبِتُ ۖ وَعِندَهُ أُمُّ الكِتابِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdccxlvii{وَإِن ما نُرِيَنَّكَ بَعضَ الَّذي نَعِدُهُم أَو نَتَوَفَّيَنَّكَ فَإِنَّما عَلَيكَ البَلاغُ وَعَلَينَا الحِسابُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdccxlviii{أَوَلَم يَرَوا أَنّا نَأتِي الأَرضَ نَنقُصُها مِن أَطرافِها ۚ وَاللَّهُ يَحكُمُ لا مُعَقِّبَ لِحُكمِهِ ۚ وَهُوَ سَريعُ الحِسابِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdccxlix{وَقَد مَكَرَ الَّذينَ مِن قَبلِهِم فَلِلَّهِ المَكرُ جَميعًا ۖ يَعلَمُ ما تَكسِبُ كُلُّ نَفسٍ ۗ وَسَيَعلَمُ الكُفّارُ لِمَن عُقبَى الدّارِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdccl{وَيَقولُ الَّذينَ كَفَروا لَستَ مُرسَلًا ۚ قُل كَفىٰ بِاللَّهِ شَهيدًا بَيني وَبَينَكُم وَمَن عِندَهُ عِلمُ الكِتابِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdccli{\basmalah الر ۚ كِتابٌ أَنزَلناهُ إِلَيكَ لِتُخرِجَ النّاسَ مِنَ الظُّلُماتِ إِلَى النّورِ بِإِذنِ رَبِّهِم إِلىٰ صِراطِ العَزيزِ الحَميدِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdcclii{اللَّهِ الَّذي لَهُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۗ وَوَيلٌ لِلكافِرينَ مِن عَذابٍ شَديدٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdccliii{الَّذينَ يَستَحِبّونَ الحَياةَ الدُّنيا عَلَى الآخِرَةِ وَيَصُدّونَ عَن سَبيلِ اللَّهِ وَيَبغونَها عِوَجًا ۚ أُولٰئِكَ في ضَلالٍ بَعيدٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdccliv{وَما أَرسَلنا مِن رَسولٍ إِلّا بِلِسانِ قَومِهِ لِيُبَيِّنَ لَهُم ۖ فَيُضِلُّ اللَّهُ مَن يَشاءُ وَيَهدي مَن يَشاءُ ۚ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdcclv{وَلَقَد أَرسَلنا موسىٰ بِآياتِنا أَن أَخرِج قَومَكَ مِنَ الظُّلُماتِ إِلَى النّورِ وَذَكِّرهُم بِأَيّامِ اللَّهِ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِكُلِّ صَبّارٍ شَكورٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdcclvi{وَإِذ قالَ موسىٰ لِقَومِهِ اذكُروا نِعمَةَ اللَّهِ عَلَيكُم إِذ أَنجاكُم مِن آلِ فِرعَونَ يَسومونَكُم سوءَ العَذابِ وَيُذَبِّحونَ أَبناءَكُم وَيَستَحيونَ نِساءَكُم ۚ وَفي ذٰلِكُم بَلاءٌ مِن رَبِّكُم عَظيمٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdcclvii{وَإِذ تَأَذَّنَ رَبُّكُم لَئِن شَكَرتُم لَأَزيدَنَّكُم ۖ وَلَئِن كَفَرتُم إِنَّ عَذابي لَشَديدٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdcclviii{وَقالَ موسىٰ إِن تَكفُروا أَنتُم وَمَن فِي الأَرضِ جَميعًا فَإِنَّ اللَّهَ لَغَنِيٌّ حَميدٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdcclix{أَلَم يَأتِكُم نَبَأُ الَّذينَ مِن قَبلِكُم قَومِ نوحٍ وَعادٍ وَثَمودَ ۛ وَالَّذينَ مِن بَعدِهِم ۛ لا يَعلَمُهُم إِلَّا اللَّهُ ۚ جاءَتهُم رُسُلُهُم بِالبَيِّناتِ فَرَدّوا أَيدِيَهُم في أَفواهِهِم وَقالوا إِنّا كَفَرنا بِما أُرسِلتُم بِهِ وَإِنّا لَفي شَكٍّ مِمّا تَدعونَنا إِلَيهِ مُريبٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdcclx{۞ قالَت رُسُلُهُم أَفِي اللَّهِ شَكٌّ فاطِرِ السَّماواتِ وَالأَرضِ ۖ يَدعوكُم لِيَغفِرَ لَكُم مِن ذُنوبِكُم وَيُؤَخِّرَكُم إِلىٰ أَجَلٍ مُسَمًّى ۚ قالوا إِن أَنتُم إِلّا بَشَرٌ مِثلُنا تُريدونَ أَن تَصُدّونا عَمّا كانَ يَعبُدُ آباؤُنا فَأتونا بِسُلطانٍ مُبينٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdcclxi{قالَت لَهُم رُسُلُهُم إِن نَحنُ إِلّا بَشَرٌ مِثلُكُم وَلٰكِنَّ اللَّهَ يَمُنُّ عَلىٰ مَن يَشاءُ مِن عِبادِهِ ۖ وَما كانَ لَنا أَن نَأتِيَكُم بِسُلطانٍ إِلّا بِإِذنِ اللَّهِ ۚ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdcclxii{وَما لَنا أَلّا نَتَوَكَّلَ عَلَى اللَّهِ وَقَد هَدانا سُبُلَنا ۚ وَلَنَصبِرَنَّ عَلىٰ ما آذَيتُمونا ۚ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُتَوَكِّلونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdcclxiii{وَقالَ الَّذينَ كَفَروا لِرُسُلِهِم لَنُخرِجَنَّكُم مِن أَرضِنا أَو لَتَعودُنَّ في مِلَّتِنا ۖ فَأَوحىٰ إِلَيهِم رَبُّهُم لَنُهلِكَنَّ الظّالِمينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdcclxiv{وَلَنُسكِنَنَّكُمُ الأَرضَ مِن بَعدِهِم ۚ ذٰلِكَ لِمَن خافَ مَقامي وَخافَ وَعيدِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdcclxv{وَاستَفتَحوا وَخابَ كُلُّ جَبّارٍ عَنيدٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdcclxvi{مِن وَرائِهِ جَهَنَّمُ وَيُسقىٰ مِن ماءٍ صَديدٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdcclxvii{يَتَجَرَّعُهُ وَلا يَكادُ يُسيغُهُ وَيَأتيهِ المَوتُ مِن كُلِّ مَكانٍ وَما هُوَ بِمَيِّتٍ ۖ وَمِن وَرائِهِ عَذابٌ غَليظٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdcclxviii{مَثَلُ الَّذينَ كَفَروا بِرَبِّهِم ۖ أَعمالُهُم كَرَمادٍ اشتَدَّت بِهِ الرّيحُ في يَومٍ عاصِفٍ ۖ لا يَقدِرونَ مِمّا كَسَبوا عَلىٰ شَيءٍ ۚ ذٰلِكَ هُوَ الضَّلالُ البَعيدُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdcclxix{أَلَم تَرَ أَنَّ اللَّهَ خَلَقَ السَّماواتِ وَالأَرضَ بِالحَقِّ ۚ إِن يَشَأ يُذهِبكُم وَيَأتِ بِخَلقٍ جَديدٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdcclxx{وَما ذٰلِكَ عَلَى اللَّهِ بِعَزيزٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdcclxxi{وَبَرَزوا لِلَّهِ جَميعًا فَقالَ الضُّعَفاءُ لِلَّذينَ استَكبَروا إِنّا كُنّا لَكُم تَبَعًا فَهَل أَنتُم مُغنونَ عَنّا مِن عَذابِ اللَّهِ مِن شَيءٍ ۚ قالوا لَو هَدانَا اللَّهُ لَهَدَيناكُم ۖ سَواءٌ عَلَينا أَجَزِعنا أَم صَبَرنا ما لَنا مِن مَحيصٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdcclxxii{وَقالَ الشَّيطانُ لَمّا قُضِيَ الأَمرُ إِنَّ اللَّهَ وَعَدَكُم وَعدَ الحَقِّ وَوَعَدتُكُم فَأَخلَفتُكُم ۖ وَما كانَ لِيَ عَلَيكُم مِن سُلطانٍ إِلّا أَن دَعَوتُكُم فَاستَجَبتُم لي ۖ فَلا تَلوموني وَلوموا أَنفُسَكُم ۖ ما أَنا بِمُصرِخِكُم وَما أَنتُم بِمُصرِخِيَّ ۖ إِنّي كَفَرتُ بِما أَشرَكتُمونِ مِن قَبلُ ۗ إِنَّ الظّالِمينَ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdcclxxiii{وَأُدخِلَ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها بِإِذنِ رَبِّهِم ۖ تَحِيَّتُهُم فيها سَلامٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdcclxxiv{أَلَم تَرَ كَيفَ ضَرَبَ اللَّهُ مَثَلًا كَلِمَةً طَيِّبَةً كَشَجَرَةٍ طَيِّبَةٍ أَصلُها ثابِتٌ وَفَرعُها فِي السَّماءِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdcclxxv{تُؤتي أُكُلَها كُلَّ حينٍ بِإِذنِ رَبِّها ۗ وَيَضرِبُ اللَّهُ الأَمثالَ لِلنّاسِ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdcclxxvi{وَمَثَلُ كَلِمَةٍ خَبيثَةٍ كَشَجَرَةٍ خَبيثَةٍ اجتُثَّت مِن فَوقِ الأَرضِ ما لَها مِن قَرارٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdcclxxvii{يُثَبِّتُ اللَّهُ الَّذينَ آمَنوا بِالقَولِ الثّابِتِ فِي الحَياةِ الدُّنيا وَفِي الآخِرَةِ ۖ وَيُضِلُّ اللَّهُ الظّالِمينَ ۚ وَيَفعَلُ اللَّهُ ما يَشاءُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdcclxxviii{۞ أَلَم تَرَ إِلَى الَّذينَ بَدَّلوا نِعمَتَ اللَّهِ كُفرًا وَأَحَلّوا قَومَهُم دارَ البَوارِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdcclxxix{جَهَنَّمَ يَصلَونَها ۖ وَبِئسَ القَرارُ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdcclxxx{وَجَعَلوا لِلَّهِ أَندادًا لِيُضِلّوا عَن سَبيلِهِ ۗ قُل تَمَتَّعوا فَإِنَّ مَصيرَكُم إِلَى النّارِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdcclxxxi{قُل لِعِبادِيَ الَّذينَ آمَنوا يُقيمُوا الصَّلاةَ وَيُنفِقوا مِمّا رَزَقناهُم سِرًّا وَعَلانِيَةً مِن قَبلِ أَن يَأتِيَ يَومٌ لا بَيعٌ فيهِ وَلا خِلالٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdcclxxxii{اللَّهُ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ وَأَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجَ بِهِ مِنَ الثَّمَراتِ رِزقًا لَكُم ۖ وَسَخَّرَ لَكُمُ الفُلكَ لِتَجرِيَ فِي البَحرِ بِأَمرِهِ ۖ وَسَخَّرَ لَكُمُ الأَنهارَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdcclxxxiii{وَسَخَّرَ لَكُمُ الشَّمسَ وَالقَمَرَ دائِبَينِ ۖ وَسَخَّرَ لَكُمُ اللَّيلَ وَالنَّهارَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdcclxxxiv{وَآتاكُم مِن كُلِّ ما سَأَلتُموهُ ۚ وَإِن تَعُدّوا نِعمَتَ اللَّهِ لا تُحصوها ۗ إِنَّ الإِنسانَ لَظَلومٌ كَفّارٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdcclxxxv{وَإِذ قالَ إِبراهيمُ رَبِّ اجعَل هٰذَا البَلَدَ آمِنًا وَاجنُبني وَبَنِيَّ أَن نَعبُدَ الأَصنامَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdcclxxxvi{رَبِّ إِنَّهُنَّ أَضلَلنَ كَثيرًا مِنَ النّاسِ ۖ فَمَن تَبِعَني فَإِنَّهُ مِنّي ۖ وَمَن عَصاني فَإِنَّكَ غَفورٌ رَحيمٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdcclxxxvii{رَبَّنا إِنّي أَسكَنتُ مِن ذُرِّيَّتي بِوادٍ غَيرِ ذي زَرعٍ عِندَ بَيتِكَ المُحَرَّمِ رَبَّنا لِيُقيمُوا الصَّلاةَ فَاجعَل أَفئِدَةً مِنَ النّاسِ تَهوي إِلَيهِم وَارزُقهُم مِنَ الثَّمَراتِ لَعَلَّهُم يَشكُرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdcclxxxviii{رَبَّنا إِنَّكَ تَعلَمُ ما نُخفي وَما نُعلِنُ ۗ وَما يَخفىٰ عَلَى اللَّهِ مِن شَيءٍ فِي الأَرضِ وَلا فِي السَّماءِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdcclxxxix{الحَمدُ لِلَّهِ الَّذي وَهَبَ لي عَلَى الكِبَرِ إِسماعيلَ وَإِسحاقَ ۚ إِنَّ رَبّي لَسَميعُ الدُّعاءِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdccxc{رَبِّ اجعَلني مُقيمَ الصَّلاةِ وَمِن ذُرِّيَّتي ۚ رَبَّنا وَتَقَبَّل دُعاءِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdccxci{رَبَّنَا اغفِر لي وَلِوالِدَيَّ وَلِلمُؤمِنينَ يَومَ يَقومُ الحِسابُ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdccxcii{وَلا تَحسَبَنَّ اللَّهَ غافِلًا عَمّا يَعمَلُ الظّالِمونَ ۚ إِنَّما يُؤَخِّرُهُم لِيَومٍ تَشخَصُ فيهِ الأَبصارُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdccxciii{مُهطِعينَ مُقنِعي رُءوسِهِم لا يَرتَدُّ إِلَيهِم طَرفُهُم ۖ وَأَفئِدَتُهُم هَواءٌ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdccxciv{وَأَنذِرِ النّاسَ يَومَ يَأتيهِمُ العَذابُ فَيَقولُ الَّذينَ ظَلَموا رَبَّنا أَخِّرنا إِلىٰ أَجَلٍ قَريبٍ نُجِب دَعوَتَكَ وَنَتَّبِعِ الرُّسُلَ ۗ أَوَلَم تَكونوا أَقسَمتُم مِن قَبلُ ما لَكُم مِن زَوالٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdccxcv{وَسَكَنتُم في مَساكِنِ الَّذينَ ظَلَموا أَنفُسَهُم وَتَبَيَّنَ لَكُم كَيفَ فَعَلنا بِهِم وَضَرَبنا لَكُمُ الأَمثالَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdccxcvi{وَقَد مَكَروا مَكرَهُم وَعِندَ اللَّهِ مَكرُهُم وَإِن كانَ مَكرُهُم لِتَزولَ مِنهُ الجِبالُ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdccxcvii{فَلا تَحسَبَنَّ اللَّهَ مُخلِفَ وَعدِهِ رُسُلَهُ ۗ إِنَّ اللَّهَ عَزيزٌ ذُو انتِقامٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdccxcviii{يَومَ تُبَدَّلُ الأَرضُ غَيرَ الأَرضِ وَالسَّماواتُ ۖ وَبَرَزوا لِلَّهِ الواحِدِ القَهّارِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdccxcix{وَتَرَى المُجرِمينَ يَومَئِذٍ مُقَرَّنينَ فِي الأَصفادِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdccc{سَرابيلُهُم مِن قَطِرانٍ وَتَغشىٰ وُجوهَهُمُ النّارُ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdccci{لِيَجزِيَ اللَّهُ كُلَّ نَفسٍ ما كَسَبَت ۚ إِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdcccii{هٰذا بَلاغٌ لِلنّاسِ وَلِيُنذَروا بِهِ وَلِيَعلَموا أَنَّما هُوَ إِلٰهٌ واحِدٌ وَلِيَذَّكَّرَ أُولُو الأَلبابِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdccciii{\basmalah الر ۚ تِلكَ آياتُ الكِتابِ وَقُرآنٍ مُبينٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdccciv{رُبَما يَوَدُّ الَّذينَ كَفَروا لَو كانوا مُسلِمينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdcccv{ذَرهُم يَأكُلوا وَيَتَمَتَّعوا وَيُلهِهِمُ الأَمَلُ ۖ فَسَوفَ يَعلَمونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdcccvi{وَما أَهلَكنا مِن قَريَةٍ إِلّا وَلَها كِتابٌ مَعلومٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdcccvii{ما تَسبِقُ مِن أُمَّةٍ أَجَلَها وَما يَستَأخِرونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdcccviii{وَقالوا يا أَيُّهَا الَّذي نُزِّلَ عَلَيهِ الذِّكرُ إِنَّكَ لَمَجنونٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdcccix{لَو ما تَأتينا بِالمَلائِكَةِ إِن كُنتَ مِنَ الصّادِقينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdcccx{ما نُنَزِّلُ المَلائِكَةَ إِلّا بِالحَقِّ وَما كانوا إِذًا مُنظَرينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdcccxi{إِنّا نَحنُ نَزَّلنَا الذِّكرَ وَإِنّا لَهُ لَحافِظونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdcccxii{وَلَقَد أَرسَلنا مِن قَبلِكَ في شِيَعِ الأَوَّلينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdcccxiii{وَما يَأتيهِم مِن رَسولٍ إِلّا كانوا بِهِ يَستَهزِئونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdcccxiv{كَذٰلِكَ نَسلُكُهُ في قُلوبِ المُجرِمينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdcccxv{لا يُؤمِنونَ بِهِ ۖ وَقَد خَلَت سُنَّةُ الأَوَّلينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdcccxvi{وَلَو فَتَحنا عَلَيهِم بابًا مِنَ السَّماءِ فَظَلّوا فيهِ يَعرُجونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdcccxvii{لَقالوا إِنَّما سُكِّرَت أَبصارُنا بَل نَحنُ قَومٌ مَسحورونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdcccxviii{وَلَقَد جَعَلنا فِي السَّماءِ بُروجًا وَزَيَّنّاها لِلنّاظِرينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdcccxix{وَحَفِظناها مِن كُلِّ شَيطانٍ رَجيمٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdcccxx{إِلّا مَنِ استَرَقَ السَّمعَ فَأَتبَعَهُ شِهابٌ مُبينٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdcccxxi{وَالأَرضَ مَدَدناها وَأَلقَينا فيها رَواسِيَ وَأَنبَتنا فيها مِن كُلِّ شَيءٍ مَوزونٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdcccxxii{وَجَعَلنا لَكُم فيها مَعايِشَ وَمَن لَستُم لَهُ بِرازِقينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdcccxxiii{وَإِن مِن شَيءٍ إِلّا عِندَنا خَزائِنُهُ وَما نُنَزِّلُهُ إِلّا بِقَدَرٍ مَعلومٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdcccxxiv{وَأَرسَلنَا الرِّياحَ لَواقِحَ فَأَنزَلنا مِنَ السَّماءِ ماءً فَأَسقَيناكُموهُ وَما أَنتُم لَهُ بِخازِنينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdcccxxv{وَإِنّا لَنَحنُ نُحيي وَنُميتُ وَنَحنُ الوارِثونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdcccxxvi{وَلَقَد عَلِمنَا المُستَقدِمينَ مِنكُم وَلَقَد عَلِمنَا المُستَأخِرينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdcccxxvii{وَإِنَّ رَبَّكَ هُوَ يَحشُرُهُم ۚ إِنَّهُ حَكيمٌ عَليمٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdcccxxviii{وَلَقَد خَلَقنَا الإِنسانَ مِن صَلصالٍ مِن حَمَإٍ مَسنونٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdcccxxix{وَالجانَّ خَلَقناهُ مِن قَبلُ مِن نارِ السَّمومِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdcccxxx{وَإِذ قالَ رَبُّكَ لِلمَلائِكَةِ إِنّي خالِقٌ بَشَرًا مِن صَلصالٍ مِن حَمَإٍ مَسنونٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdcccxxxi{فَإِذا سَوَّيتُهُ وَنَفَختُ فيهِ مِن روحي فَقَعوا لَهُ ساجِدينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdcccxxxii{فَسَجَدَ المَلائِكَةُ كُلُّهُم أَجمَعونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdcccxxxiii{إِلّا إِبليسَ أَبىٰ أَن يَكونَ مَعَ السّاجِدينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdcccxxxiv{قالَ يا إِبليسُ ما لَكَ أَلّا تَكونَ مَعَ السّاجِدينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdcccxxxv{قالَ لَم أَكُن لِأَسجُدَ لِبَشَرٍ خَلَقتَهُ مِن صَلصالٍ مِن حَمَإٍ مَسنونٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdcccxxxvi{قالَ فَاخرُج مِنها فَإِنَّكَ رَجيمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdcccxxxvii{وَإِنَّ عَلَيكَ اللَّعنَةَ إِلىٰ يَومِ الدّينِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdcccxxxviii{قالَ رَبِّ فَأَنظِرني إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdcccxxxix{قالَ فَإِنَّكَ مِنَ المُنظَرينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdcccxl{إِلىٰ يَومِ الوَقتِ المَعلومِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdcccxli{قالَ رَبِّ بِما أَغوَيتَني لَأُزَيِّنَنَّ لَهُم فِي الأَرضِ وَلَأُغوِيَنَّهُم أَجمَعينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdcccxlii{إِلّا عِبادَكَ مِنهُمُ المُخلَصينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdcccxliii{قالَ هٰذا صِراطٌ عَلَيَّ مُستَقيمٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdcccxliv{إِنَّ عِبادي لَيسَ لَكَ عَلَيهِم سُلطانٌ إِلّا مَنِ اتَّبَعَكَ مِنَ الغاوينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdcccxlv{وَإِنَّ جَهَنَّمَ لَمَوعِدُهُم أَجمَعينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdcccxlvi{لَها سَبعَةُ أَبوابٍ لِكُلِّ بابٍ مِنهُم جُزءٌ مَقسومٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdcccxlvii{إِنَّ المُتَّقينَ في جَنّاتٍ وَعُيونٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdcccxlviii{ادخُلوها بِسَلامٍ آمِنينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdcccxlix{وَنَزَعنا ما في صُدورِهِم مِن غِلٍّ إِخوانًا عَلىٰ سُرُرٍ مُتَقابِلينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdcccl{لا يَمَسُّهُم فيها نَصَبٌ وَما هُم مِنها بِمُخرَجينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdcccli{۞ نَبِّئ عِبادي أَنّي أَنَا الغَفورُ الرَّحيمُ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdccclii{وَأَنَّ عَذابي هُوَ العَذابُ الأَليمُ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdcccliii{وَنَبِّئهُم عَن ضَيفِ إِبراهيمَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdcccliv{إِذ دَخَلوا عَلَيهِ فَقالوا سَلامًا قالَ إِنّا مِنكُم وَجِلونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdccclv{قالوا لا تَوجَل إِنّا نُبَشِّرُكَ بِغُلامٍ عَليمٍ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mdccclvi{قالَ أَبَشَّرتُموني عَلىٰ أَن مَسَّنِيَ الكِبَرُ فَبِمَ تُبَشِّرونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mdccclvii{قالوا بَشَّرناكَ بِالحَقِّ فَلا تَكُن مِنَ القانِطينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mdccclviii{قالَ وَمَن يَقنَطُ مِن رَحمَةِ رَبِّهِ إِلَّا الضّالّونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mdccclix{قالَ فَما خَطبُكُم أَيُّهَا المُرسَلونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mdccclx{قالوا إِنّا أُرسِلنا إِلىٰ قَومٍ مُجرِمينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mdccclxi{إِلّا آلَ لوطٍ إِنّا لَمُنَجّوهُم أَجمَعينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mdccclxii{إِلَّا امرَأَتَهُ قَدَّرنا ۙ إِنَّها لَمِنَ الغابِرينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mdccclxiii{فَلَمّا جاءَ آلَ لوطٍ المُرسَلونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mdccclxiv{قالَ إِنَّكُم قَومٌ مُنكَرونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mdccclxv{قالوا بَل جِئناكَ بِما كانوا فيهِ يَمتَرونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mdccclxvi{وَأَتَيناكَ بِالحَقِّ وَإِنّا لَصادِقونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mdccclxvii{فَأَسرِ بِأَهلِكَ بِقِطعٍ مِنَ اللَّيلِ وَاتَّبِع أَدبارَهُم وَلا يَلتَفِت مِنكُم أَحَدٌ وَامضوا حَيثُ تُؤمَرونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mdccclxviii{وَقَضَينا إِلَيهِ ذٰلِكَ الأَمرَ أَنَّ دابِرَ هٰؤُلاءِ مَقطوعٌ مُصبِحينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mdccclxix{وَجاءَ أَهلُ المَدينَةِ يَستَبشِرونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mdccclxx{قالَ إِنَّ هٰؤُلاءِ ضَيفي فَلا تَفضَحونِ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mdccclxxi{وَاتَّقُوا اللَّهَ وَلا تُخزونِ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mdccclxxii{قالوا أَوَلَم نَنهَكَ عَنِ العالَمينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mdccclxxiii{قالَ هٰؤُلاءِ بَناتي إِن كُنتُم فاعِلينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mdccclxxiv{لَعَمرُكَ إِنَّهُم لَفي سَكرَتِهِم يَعمَهونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mdccclxxv{فَأَخَذَتهُمُ الصَّيحَةُ مُشرِقينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mdccclxxvi{فَجَعَلنا عالِيَها سافِلَها وَأَمطَرنا عَلَيهِم حِجارَةً مِن سِجّيلٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mdccclxxvii{إِنَّ في ذٰلِكَ لَآياتٍ لِلمُتَوَسِّمينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mdccclxxviii{وَإِنَّها لَبِسَبيلٍ مُقيمٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mdccclxxix{إِنَّ في ذٰلِكَ لَآيَةً لِلمُؤمِنينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mdccclxxx{وَإِن كانَ أَصحابُ الأَيكَةِ لَظالِمينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mdccclxxxi{فَانتَقَمنا مِنهُم وَإِنَّهُما لَبِإِمامٍ مُبينٍ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mdccclxxxii{وَلَقَد كَذَّبَ أَصحابُ الحِجرِ المُرسَلينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mdccclxxxiii{وَآتَيناهُم آياتِنا فَكانوا عَنها مُعرِضينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mdccclxxxiv{وَكانوا يَنحِتونَ مِنَ الجِبالِ بُيوتًا آمِنينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mdccclxxxv{فَأَخَذَتهُمُ الصَّيحَةُ مُصبِحينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mdccclxxxvi{فَما أَغنىٰ عَنهُم ما كانوا يَكسِبونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mdccclxxxvii{وَما خَلَقنَا السَّماواتِ وَالأَرضَ وَما بَينَهُما إِلّا بِالحَقِّ ۗ وَإِنَّ السّاعَةَ لَآتِيَةٌ ۖ فَاصفَحِ الصَّفحَ الجَميلَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mdccclxxxviii{إِنَّ رَبَّكَ هُوَ الخَلّاقُ العَليمُ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mdccclxxxix{وَلَقَد آتَيناكَ سَبعًا مِنَ المَثاني وَالقُرآنَ العَظيمَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mdcccxc{لا تَمُدَّنَّ عَينَيكَ إِلىٰ ما مَتَّعنا بِهِ أَزواجًا مِنهُم وَلا تَحزَن عَلَيهِم وَاخفِض جَناحَكَ لِلمُؤمِنينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mdcccxci{وَقُل إِنّي أَنَا النَّذيرُ المُبينُ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mdcccxcii{كَما أَنزَلنا عَلَى المُقتَسِمينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mdcccxciii{الَّذينَ جَعَلُوا القُرآنَ عِضينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mdcccxciv{فَوَرَبِّكَ لَنَسأَلَنَّهُم أَجمَعينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mdcccxcv{عَمّا كانوا يَعمَلونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mdcccxcvi{فَاصدَع بِما تُؤمَرُ وَأَعرِض عَنِ المُشرِكينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mdcccxcvii{إِنّا كَفَيناكَ المُستَهزِئينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mdcccxcviii{الَّذينَ يَجعَلونَ مَعَ اللَّهِ إِلٰهًا آخَرَ ۚ فَسَوفَ يَعلَمونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mdcccxcix{وَلَقَد نَعلَمُ أَنَّكَ يَضيقُ صَدرُكَ بِما يَقولونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcm{فَسَبِّح بِحَمدِ رَبِّكَ وَكُن مِنَ السّاجِدينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mcmi{وَاعبُد رَبَّكَ حَتّىٰ يَأتِيَكَ اليَقينُ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mcmii{\basmalah أَتىٰ أَمرُ اللَّهِ فَلا تَستَعجِلوهُ ۚ سُبحانَهُ وَتَعالىٰ عَمّا يُشرِكونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mcmiii{يُنَزِّلُ المَلائِكَةَ بِالرّوحِ مِن أَمرِهِ عَلىٰ مَن يَشاءُ مِن عِبادِهِ أَن أَنذِروا أَنَّهُ لا إِلٰهَ إِلّا أَنا فَاتَّقونِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mcmiv{خَلَقَ السَّماواتِ وَالأَرضَ بِالحَقِّ ۚ تَعالىٰ عَمّا يُشرِكونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mcmv{خَلَقَ الإِنسانَ مِن نُطفَةٍ فَإِذا هُوَ خَصيمٌ مُبينٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mcmvi{وَالأَنعامَ خَلَقَها ۗ لَكُم فيها دِفءٌ وَمَنافِعُ وَمِنها تَأكُلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mcmvii{وَلَكُم فيها جَمالٌ حينَ تُريحونَ وَحينَ تَسرَحونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mcmviii{وَتَحمِلُ أَثقالَكُم إِلىٰ بَلَدٍ لَم تَكونوا بالِغيهِ إِلّا بِشِقِّ الأَنفُسِ ۚ إِنَّ رَبَّكُم لَرَءوفٌ رَحيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mcmix{وَالخَيلَ وَالبِغالَ وَالحَميرَ لِتَركَبوها وَزينَةً ۚ وَيَخلُقُ ما لا تَعلَمونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mcmx{وَعَلَى اللَّهِ قَصدُ السَّبيلِ وَمِنها جائِرٌ ۚ وَلَو شاءَ لَهَداكُم أَجمَعينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mcmxi{هُوَ الَّذي أَنزَلَ مِنَ السَّماءِ ماءً ۖ لَكُم مِنهُ شَرابٌ وَمِنهُ شَجَرٌ فيهِ تُسيمونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mcmxii{يُنبِتُ لَكُم بِهِ الزَّرعَ وَالزَّيتونَ وَالنَّخيلَ وَالأَعنابَ وَمِن كُلِّ الثَّمَراتِ ۗ إِنَّ في ذٰلِكَ لَآيَةً لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mcmxiii{وَسَخَّرَ لَكُمُ اللَّيلَ وَالنَّهارَ وَالشَّمسَ وَالقَمَرَ ۖ وَالنُّجومُ مُسَخَّراتٌ بِأَمرِهِ ۗ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يَعقِلونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mcmxiv{وَما ذَرَأَ لَكُم فِي الأَرضِ مُختَلِفًا أَلوانُهُ ۗ إِنَّ في ذٰلِكَ لَآيَةً لِقَومٍ يَذَّكَّرونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mcmxv{وَهُوَ الَّذي سَخَّرَ البَحرَ لِتَأكُلوا مِنهُ لَحمًا طَرِيًّا وَتَستَخرِجوا مِنهُ حِليَةً تَلبَسونَها وَتَرَى الفُلكَ مَواخِرَ فيهِ وَلِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mcmxvi{وَأَلقىٰ فِي الأَرضِ رَواسِيَ أَن تَميدَ بِكُم وَأَنهارًا وَسُبُلًا لَعَلَّكُم تَهتَدونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mcmxvii{وَعَلاماتٍ ۚ وَبِالنَّجمِ هُم يَهتَدونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mcmxviii{أَفَمَن يَخلُقُ كَمَن لا يَخلُقُ ۗ أَفَلا تَذَكَّرونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mcmxix{وَإِن تَعُدّوا نِعمَةَ اللَّهِ لا تُحصوها ۗ إِنَّ اللَّهَ لَغَفورٌ رَحيمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mcmxx{وَاللَّهُ يَعلَمُ ما تُسِرّونَ وَما تُعلِنونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mcmxxi{وَالَّذينَ يَدعونَ مِن دونِ اللَّهِ لا يَخلُقونَ شَيئًا وَهُم يُخلَقونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mcmxxii{أَمواتٌ غَيرُ أَحياءٍ ۖ وَما يَشعُرونَ أَيّانَ يُبعَثونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mcmxxiii{إِلٰهُكُم إِلٰهٌ واحِدٌ ۚ فَالَّذينَ لا يُؤمِنونَ بِالآخِرَةِ قُلوبُهُم مُنكِرَةٌ وَهُم مُستَكبِرونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mcmxxiv{لا جَرَمَ أَنَّ اللَّهَ يَعلَمُ ما يُسِرّونَ وَما يُعلِنونَ ۚ إِنَّهُ لا يُحِبُّ المُستَكبِرينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mcmxxv{وَإِذا قيلَ لَهُم ماذا أَنزَلَ رَبُّكُم ۙ قالوا أَساطيرُ الأَوَّلينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mcmxxvi{لِيَحمِلوا أَوزارَهُم كامِلَةً يَومَ القِيامَةِ ۙ وَمِن أَوزارِ الَّذينَ يُضِلّونَهُم بِغَيرِ عِلمٍ ۗ أَلا ساءَ ما يَزِرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcmxxvii{قَد مَكَرَ الَّذينَ مِن قَبلِهِم فَأَتَى اللَّهُ بُنيانَهُم مِنَ القَواعِدِ فَخَرَّ عَلَيهِمُ السَّقفُ مِن فَوقِهِم وَأَتاهُمُ العَذابُ مِن حَيثُ لا يَشعُرونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mcmxxviii{ثُمَّ يَومَ القِيامَةِ يُخزيهِم وَيَقولُ أَينَ شُرَكائِيَ الَّذينَ كُنتُم تُشاقّونَ فيهِم ۚ قالَ الَّذينَ أوتُوا العِلمَ إِنَّ الخِزيَ اليَومَ وَالسّوءَ عَلَى الكافِرينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mcmxxix{الَّذينَ تَتَوَفّاهُمُ المَلائِكَةُ ظالِمي أَنفُسِهِم ۖ فَأَلقَوُا السَّلَمَ ما كُنّا نَعمَلُ مِن سوءٍ ۚ بَلىٰ إِنَّ اللَّهَ عَليمٌ بِما كُنتُم تَعمَلونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mcmxxx{فَادخُلوا أَبوابَ جَهَنَّمَ خالِدينَ فيها ۖ فَلَبِئسَ مَثوَى المُتَكَبِّرينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcmxxxi{۞ وَقيلَ لِلَّذينَ اتَّقَوا ماذا أَنزَلَ رَبُّكُم ۚ قالوا خَيرًا ۗ لِلَّذينَ أَحسَنوا في هٰذِهِ الدُّنيا حَسَنَةٌ ۚ وَلَدارُ الآخِرَةِ خَيرٌ ۚ وَلَنِعمَ دارُ المُتَّقينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcmxxxii{جَنّاتُ عَدنٍ يَدخُلونَها تَجري مِن تَحتِهَا الأَنهارُ ۖ لَهُم فيها ما يَشاءونَ ۚ كَذٰلِكَ يَجزِي اللَّهُ المُتَّقينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcmxxxiii{الَّذينَ تَتَوَفّاهُمُ المَلائِكَةُ طَيِّبينَ ۙ يَقولونَ سَلامٌ عَلَيكُمُ ادخُلُوا الجَنَّةَ بِما كُنتُم تَعمَلونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcmxxxiv{هَل يَنظُرونَ إِلّا أَن تَأتِيَهُمُ المَلائِكَةُ أَو يَأتِيَ أَمرُ رَبِّكَ ۚ كَذٰلِكَ فَعَلَ الَّذينَ مِن قَبلِهِم ۚ وَما ظَلَمَهُمُ اللَّهُ وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcmxxxv{فَأَصابَهُم سَيِّئَاتُ ما عَمِلوا وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcmxxxvi{وَقالَ الَّذينَ أَشرَكوا لَو شاءَ اللَّهُ ما عَبَدنا مِن دونِهِ مِن شَيءٍ نَحنُ وَلا آباؤُنا وَلا حَرَّمنا مِن دونِهِ مِن شَيءٍ ۚ كَذٰلِكَ فَعَلَ الَّذينَ مِن قَبلِهِم ۚ فَهَل عَلَى الرُّسُلِ إِلَّا البَلاغُ المُبينُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcmxxxvii{وَلَقَد بَعَثنا في كُلِّ أُمَّةٍ رَسولًا أَنِ اعبُدُوا اللَّهَ وَاجتَنِبُوا الطّاغوتَ ۖ فَمِنهُم مَن هَدَى اللَّهُ وَمِنهُم مَن حَقَّت عَلَيهِ الضَّلالَةُ ۚ فَسيروا فِي الأَرضِ فَانظُروا كَيفَ كانَ عاقِبَةُ المُكَذِّبينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcmxxxviii{إِن تَحرِص عَلىٰ هُداهُم فَإِنَّ اللَّهَ لا يَهدي مَن يُضِلُّ ۖ وَما لَهُم مِن ناصِرينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcmxxxix{وَأَقسَموا بِاللَّهِ جَهدَ أَيمانِهِم ۙ لا يَبعَثُ اللَّهُ مَن يَموتُ ۚ بَلىٰ وَعدًا عَلَيهِ حَقًّا وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcmxl{لِيُبَيِّنَ لَهُمُ الَّذي يَختَلِفونَ فيهِ وَلِيَعلَمَ الَّذينَ كَفَروا أَنَّهُم كانوا كاذِبينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcmxli{إِنَّما قَولُنا لِشَيءٍ إِذا أَرَدناهُ أَن نَقولَ لَهُ كُن فَيَكونُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcmxlii{وَالَّذينَ هاجَروا فِي اللَّهِ مِن بَعدِ ما ظُلِموا لَنُبَوِّئَنَّهُم فِي الدُّنيا حَسَنَةً ۖ وَلَأَجرُ الآخِرَةِ أَكبَرُ ۚ لَو كانوا يَعلَمونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mcmxliii{الَّذينَ صَبَروا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcmxliv{وَما أَرسَلنا مِن قَبلِكَ إِلّا رِجالًا نوحي إِلَيهِم ۚ فَاسأَلوا أَهلَ الذِّكرِ إِن كُنتُم لا تَعلَمونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcmxlv{بِالبَيِّناتِ وَالزُّبُرِ ۗ وَأَنزَلنا إِلَيكَ الذِّكرَ لِتُبَيِّنَ لِلنّاسِ ما نُزِّلَ إِلَيهِم وَلَعَلَّهُم يَتَفَكَّرونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mcmxlvi{أَفَأَمِنَ الَّذينَ مَكَرُوا السَّيِّئَاتِ أَن يَخسِفَ اللَّهُ بِهِمُ الأَرضَ أَو يَأتِيَهُمُ العَذابُ مِن حَيثُ لا يَشعُرونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mcmxlvii{أَو يَأخُذَهُم في تَقَلُّبِهِم فَما هُم بِمُعجِزينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mcmxlviii{أَو يَأخُذَهُم عَلىٰ تَخَوُّفٍ فَإِنَّ رَبَّكُم لَرَءوفٌ رَحيمٌ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mcmxlix{أَوَلَم يَرَوا إِلىٰ ما خَلَقَ اللَّهُ مِن شَيءٍ يَتَفَيَّأُ ظِلالُهُ عَنِ اليَمينِ وَالشَّمائِلِ سُجَّدًا لِلَّهِ وَهُم داخِرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mcml{وَلِلَّهِ يَسجُدُ ما فِي السَّماواتِ وَما فِي الأَرضِ مِن دابَّةٍ وَالمَلائِكَةُ وَهُم لا يَستَكبِرونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mcmli{يَخافونَ رَبَّهُم مِن فَوقِهِم وَيَفعَلونَ ما يُؤمَرونَ ۩\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mcmlii{۞ وَقالَ اللَّهُ لا تَتَّخِذوا إِلٰهَينِ اثنَينِ ۖ إِنَّما هُوَ إِلٰهٌ واحِدٌ ۖ فَإِيّايَ فَارهَبونِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mcmliii{وَلَهُ ما فِي السَّماواتِ وَالأَرضِ وَلَهُ الدّينُ واصِبًا ۚ أَفَغَيرَ اللَّهِ تَتَّقونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mcmliv{وَما بِكُم مِن نِعمَةٍ فَمِنَ اللَّهِ ۖ ثُمَّ إِذا مَسَّكُمُ الضُّرُّ فَإِلَيهِ تَجأَرونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mcmlv{ثُمَّ إِذا كَشَفَ الضُّرَّ عَنكُم إِذا فَريقٌ مِنكُم بِرَبِّهِم يُشرِكونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mcmlvi{لِيَكفُروا بِما آتَيناهُم ۚ فَتَمَتَّعوا ۖ فَسَوفَ تَعلَمونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mcmlvii{وَيَجعَلونَ لِما لا يَعلَمونَ نَصيبًا مِمّا رَزَقناهُم ۗ تَاللَّهِ لَتُسأَلُنَّ عَمّا كُنتُم تَفتَرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mcmlviii{وَيَجعَلونَ لِلَّهِ البَناتِ سُبحانَهُ ۙ وَلَهُم ما يَشتَهونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mcmlix{وَإِذا بُشِّرَ أَحَدُهُم بِالأُنثىٰ ظَلَّ وَجهُهُ مُسوَدًّا وَهُوَ كَظيمٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mcmlx{يَتَوارىٰ مِنَ القَومِ مِن سوءِ ما بُشِّرَ بِهِ ۚ أَيُمسِكُهُ عَلىٰ هونٍ أَم يَدُسُّهُ فِي التُّرابِ ۗ أَلا ساءَ ما يَحكُمونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mcmlxi{لِلَّذينَ لا يُؤمِنونَ بِالآخِرَةِ مَثَلُ السَّوءِ ۖ وَلِلَّهِ المَثَلُ الأَعلىٰ ۚ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mcmlxii{وَلَو يُؤاخِذُ اللَّهُ النّاسَ بِظُلمِهِم ما تَرَكَ عَلَيها مِن دابَّةٍ وَلٰكِن يُؤَخِّرُهُم إِلىٰ أَجَلٍ مُسَمًّى ۖ فَإِذا جاءَ أَجَلُهُم لا يَستَأخِرونَ ساعَةً ۖ وَلا يَستَقدِمونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mcmlxiii{وَيَجعَلونَ لِلَّهِ ما يَكرَهونَ وَتَصِفُ أَلسِنَتُهُمُ الكَذِبَ أَنَّ لَهُمُ الحُسنىٰ ۖ لا جَرَمَ أَنَّ لَهُمُ النّارَ وَأَنَّهُم مُفرَطونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mcmlxiv{تَاللَّهِ لَقَد أَرسَلنا إِلىٰ أُمَمٍ مِن قَبلِكَ فَزَيَّنَ لَهُمُ الشَّيطانُ أَعمالَهُم فَهُوَ وَلِيُّهُمُ اليَومَ وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mcmlxv{وَما أَنزَلنا عَلَيكَ الكِتابَ إِلّا لِتُبَيِّنَ لَهُمُ الَّذِي اختَلَفوا فيهِ ۙ وَهُدًى وَرَحمَةً لِقَومٍ يُؤمِنونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mcmlxvi{وَاللَّهُ أَنزَلَ مِنَ السَّماءِ ماءً فَأَحيا بِهِ الأَرضَ بَعدَ مَوتِها ۚ إِنَّ في ذٰلِكَ لَآيَةً لِقَومٍ يَسمَعونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mcmlxvii{وَإِنَّ لَكُم فِي الأَنعامِ لَعِبرَةً ۖ نُسقيكُم مِمّا في بُطونِهِ مِن بَينِ فَرثٍ وَدَمٍ لَبَنًا خالِصًا سائِغًا لِلشّارِبينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mcmlxviii{وَمِن ثَمَراتِ النَّخيلِ وَالأَعنابِ تَتَّخِذونَ مِنهُ سَكَرًا وَرِزقًا حَسَنًا ۗ إِنَّ في ذٰلِكَ لَآيَةً لِقَومٍ يَعقِلونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mcmlxix{وَأَوحىٰ رَبُّكَ إِلَى النَّحلِ أَنِ اتَّخِذي مِنَ الجِبالِ بُيوتًا وَمِنَ الشَّجَرِ وَمِمّا يَعرِشونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mcmlxx{ثُمَّ كُلي مِن كُلِّ الثَّمَراتِ فَاسلُكي سُبُلَ رَبِّكِ ذُلُلًا ۚ يَخرُجُ مِن بُطونِها شَرابٌ مُختَلِفٌ أَلوانُهُ فيهِ شِفاءٌ لِلنّاسِ ۗ إِنَّ في ذٰلِكَ لَآيَةً لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mcmlxxi{وَاللَّهُ خَلَقَكُم ثُمَّ يَتَوَفّاكُم ۚ وَمِنكُم مَن يُرَدُّ إِلىٰ أَرذَلِ العُمُرِ لِكَي لا يَعلَمَ بَعدَ عِلمٍ شَيئًا ۚ إِنَّ اللَّهَ عَليمٌ قَديرٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mcmlxxii{وَاللَّهُ فَضَّلَ بَعضَكُم عَلىٰ بَعضٍ فِي الرِّزقِ ۚ فَمَا الَّذينَ فُضِّلوا بِرادّي رِزقِهِم عَلىٰ ما مَلَكَت أَيمانُهُم فَهُم فيهِ سَواءٌ ۚ أَفَبِنِعمَةِ اللَّهِ يَجحَدونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mcmlxxiii{وَاللَّهُ جَعَلَ لَكُم مِن أَنفُسِكُم أَزواجًا وَجَعَلَ لَكُم مِن أَزواجِكُم بَنينَ وَحَفَدَةً وَرَزَقَكُم مِنَ الطَّيِّباتِ ۚ أَفَبِالباطِلِ يُؤمِنونَ وَبِنِعمَتِ اللَّهِ هُم يَكفُرونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mcmlxxiv{وَيَعبُدونَ مِن دونِ اللَّهِ ما لا يَملِكُ لَهُم رِزقًا مِنَ السَّماواتِ وَالأَرضِ شَيئًا وَلا يَستَطيعونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mcmlxxv{فَلا تَضرِبوا لِلَّهِ الأَمثالَ ۚ إِنَّ اللَّهَ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mcmlxxvi{۞ ضَرَبَ اللَّهُ مَثَلًا عَبدًا مَملوكًا لا يَقدِرُ عَلىٰ شَيءٍ وَمَن رَزَقناهُ مِنّا رِزقًا حَسَنًا فَهُوَ يُنفِقُ مِنهُ سِرًّا وَجَهرًا ۖ هَل يَستَوونَ ۚ الحَمدُ لِلَّهِ ۚ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mcmlxxvii{وَضَرَبَ اللَّهُ مَثَلًا رَجُلَينِ أَحَدُهُما أَبكَمُ لا يَقدِرُ عَلىٰ شَيءٍ وَهُوَ كَلٌّ عَلىٰ مَولاهُ أَينَما يُوَجِّههُ لا يَأتِ بِخَيرٍ ۖ هَل يَستَوي هُوَ وَمَن يَأمُرُ بِالعَدلِ ۙ وَهُوَ عَلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mcmlxxviii{وَلِلَّهِ غَيبُ السَّماواتِ وَالأَرضِ ۚ وَما أَمرُ السّاعَةِ إِلّا كَلَمحِ البَصَرِ أَو هُوَ أَقرَبُ ۚ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mcmlxxix{وَاللَّهُ أَخرَجَكُم مِن بُطونِ أُمَّهاتِكُم لا تَعلَمونَ شَيئًا وَجَعَلَ لَكُمُ السَّمعَ وَالأَبصارَ وَالأَفئِدَةَ ۙ لَعَلَّكُم تَشكُرونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mcmlxxx{أَلَم يَرَوا إِلَى الطَّيرِ مُسَخَّراتٍ في جَوِّ السَّماءِ ما يُمسِكُهُنَّ إِلَّا اللَّهُ ۗ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mcmlxxxi{وَاللَّهُ جَعَلَ لَكُم مِن بُيوتِكُم سَكَنًا وَجَعَلَ لَكُم مِن جُلودِ الأَنعامِ بُيوتًا تَستَخِفّونَها يَومَ ظَعنِكُم وَيَومَ إِقامَتِكُم ۙ وَمِن أَصوافِها وَأَوبارِها وَأَشعارِها أَثاثًا وَمَتاعًا إِلىٰ حينٍ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mcmlxxxii{وَاللَّهُ جَعَلَ لَكُم مِمّا خَلَقَ ظِلالًا وَجَعَلَ لَكُم مِنَ الجِبالِ أَكنانًا وَجَعَلَ لَكُم سَرابيلَ تَقيكُمُ الحَرَّ وَسَرابيلَ تَقيكُم بَأسَكُم ۚ كَذٰلِكَ يُتِمُّ نِعمَتَهُ عَلَيكُم لَعَلَّكُم تُسلِمونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mcmlxxxiii{فَإِن تَوَلَّوا فَإِنَّما عَلَيكَ البَلاغُ المُبينُ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mcmlxxxiv{يَعرِفونَ نِعمَتَ اللَّهِ ثُمَّ يُنكِرونَها وَأَكثَرُهُمُ الكافِرونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mcmlxxxv{وَيَومَ نَبعَثُ مِن كُلِّ أُمَّةٍ شَهيدًا ثُمَّ لا يُؤذَنُ لِلَّذينَ كَفَروا وَلا هُم يُستَعتَبونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mcmlxxxvi{وَإِذا رَأَى الَّذينَ ظَلَمُوا العَذابَ فَلا يُخَفَّفُ عَنهُم وَلا هُم يُنظَرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mcmlxxxvii{وَإِذا رَأَى الَّذينَ أَشرَكوا شُرَكاءَهُم قالوا رَبَّنا هٰؤُلاءِ شُرَكاؤُنَا الَّذينَ كُنّا نَدعو مِن دونِكَ ۖ فَأَلقَوا إِلَيهِمُ القَولَ إِنَّكُم لَكاذِبونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mcmlxxxviii{وَأَلقَوا إِلَى اللَّهِ يَومَئِذٍ السَّلَمَ ۖ وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mcmlxxxix{الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ زِدناهُم عَذابًا فَوقَ العَذابِ بِما كانوا يُفسِدونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mcmxc{وَيَومَ نَبعَثُ في كُلِّ أُمَّةٍ شَهيدًا عَلَيهِم مِن أَنفُسِهِم ۖ وَجِئنا بِكَ شَهيدًا عَلىٰ هٰؤُلاءِ ۚ وَنَزَّلنا عَلَيكَ الكِتابَ تِبيانًا لِكُلِّ شَيءٍ وَهُدًى وَرَحمَةً وَبُشرىٰ لِلمُسلِمينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mcmxci{۞ إِنَّ اللَّهَ يَأمُرُ بِالعَدلِ وَالإِحسانِ وَإيتاءِ ذِي القُربىٰ وَيَنهىٰ عَنِ الفَحشاءِ وَالمُنكَرِ وَالبَغيِ ۚ يَعِظُكُم لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mcmxcii{وَأَوفوا بِعَهدِ اللَّهِ إِذا عاهَدتُم وَلا تَنقُضُوا الأَيمانَ بَعدَ تَوكيدِها وَقَد جَعَلتُمُ اللَّهَ عَلَيكُم كَفيلًا ۚ إِنَّ اللَّهَ يَعلَمُ ما تَفعَلونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mcmxciii{وَلا تَكونوا كَالَّتي نَقَضَت غَزلَها مِن بَعدِ قُوَّةٍ أَنكاثًا تَتَّخِذونَ أَيمانَكُم دَخَلًا بَينَكُم أَن تَكونَ أُمَّةٌ هِيَ أَربىٰ مِن أُمَّةٍ ۚ إِنَّما يَبلوكُمُ اللَّهُ بِهِ ۚ وَلَيُبَيِّنَنَّ لَكُم يَومَ القِيامَةِ ما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mcmxciv{وَلَو شاءَ اللَّهُ لَجَعَلَكُم أُمَّةً واحِدَةً وَلٰكِن يُضِلُّ مَن يَشاءُ وَيَهدي مَن يَشاءُ ۚ وَلَتُسأَلُنَّ عَمّا كُنتُم تَعمَلونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mcmxcv{وَلا تَتَّخِذوا أَيمانَكُم دَخَلًا بَينَكُم فَتَزِلَّ قَدَمٌ بَعدَ ثُبوتِها وَتَذوقُوا السّوءَ بِما صَدَدتُم عَن سَبيلِ اللَّهِ ۖ وَلَكُم عَذابٌ عَظيمٌ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mcmxcvi{وَلا تَشتَروا بِعَهدِ اللَّهِ ثَمَنًا قَليلًا ۚ إِنَّما عِندَ اللَّهِ هُوَ خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mcmxcvii{ما عِندَكُم يَنفَدُ ۖ وَما عِندَ اللَّهِ باقٍ ۗ وَلَنَجزِيَنَّ الَّذينَ صَبَروا أَجرَهُم بِأَحسَنِ ما كانوا يَعمَلونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mcmxcviii{مَن عَمِلَ صالِحًا مِن ذَكَرٍ أَو أُنثىٰ وَهُوَ مُؤمِنٌ فَلَنُحيِيَنَّهُ حَياةً طَيِّبَةً ۖ وَلَنَجزِيَنَّهُم أَجرَهُم بِأَحسَنِ ما كانوا يَعمَلونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcmxcix{فَإِذا قَرَأتَ القُرآنَ فَاستَعِذ بِاللَّهِ مِنَ الشَّيطانِ الرَّجيمِ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mm{إِنَّهُ لَيسَ لَهُ سُلطانٌ عَلَى الَّذينَ آمَنوا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmi{إِنَّما سُلطانُهُ عَلَى الَّذينَ يَتَوَلَّونَهُ وَالَّذينَ هُم بِهِ مُشرِكونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmii{وَإِذا بَدَّلنا آيَةً مَكانَ آيَةٍ ۙ وَاللَّهُ أَعلَمُ بِما يُنَزِّلُ قالوا إِنَّما أَنتَ مُفتَرٍ ۚ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmiii{قُل نَزَّلَهُ روحُ القُدُسِ مِن رَبِّكَ بِالحَقِّ لِيُثَبِّتَ الَّذينَ آمَنوا وَهُدًى وَبُشرىٰ لِلمُسلِمينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmiv{وَلَقَد نَعلَمُ أَنَّهُم يَقولونَ إِنَّما يُعَلِّمُهُ بَشَرٌ ۗ لِسانُ الَّذي يُلحِدونَ إِلَيهِ أَعجَمِيٌّ وَهٰذا لِسانٌ عَرَبِيٌّ مُبينٌ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmv{إِنَّ الَّذينَ لا يُؤمِنونَ بِآياتِ اللَّهِ لا يَهديهِمُ اللَّهُ وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmvi{إِنَّما يَفتَرِي الكَذِبَ الَّذينَ لا يُؤمِنونَ بِآياتِ اللَّهِ ۖ وَأُولٰئِكَ هُمُ الكاذِبونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmvii{مَن كَفَرَ بِاللَّهِ مِن بَعدِ إيمانِهِ إِلّا مَن أُكرِهَ وَقَلبُهُ مُطمَئِنٌّ بِالإيمانِ وَلٰكِن مَن شَرَحَ بِالكُفرِ صَدرًا فَعَلَيهِم غَضَبٌ مِنَ اللَّهِ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmviii{ذٰلِكَ بِأَنَّهُمُ استَحَبُّوا الحَياةَ الدُّنيا عَلَى الآخِرَةِ وَأَنَّ اللَّهَ لا يَهدِي القَومَ الكافِرينَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmix{أُولٰئِكَ الَّذينَ طَبَعَ اللَّهُ عَلىٰ قُلوبِهِم وَسَمعِهِم وَأَبصارِهِم ۖ وَأُولٰئِكَ هُمُ الغافِلونَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmx{لا جَرَمَ أَنَّهُم فِي الآخِرَةِ هُمُ الخاسِرونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmxi{ثُمَّ إِنَّ رَبَّكَ لِلَّذينَ هاجَروا مِن بَعدِ ما فُتِنوا ثُمَّ جاهَدوا وَصَبَروا إِنَّ رَبَّكَ مِن بَعدِها لَغَفورٌ رَحيمٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmxii{۞ يَومَ تَأتي كُلُّ نَفسٍ تُجادِلُ عَن نَفسِها وَتُوَفّىٰ كُلُّ نَفسٍ ما عَمِلَت وَهُم لا يُظلَمونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmxiii{وَضَرَبَ اللَّهُ مَثَلًا قَريَةً كانَت آمِنَةً مُطمَئِنَّةً يَأتيها رِزقُها رَغَدًا مِن كُلِّ مَكانٍ فَكَفَرَت بِأَنعُمِ اللَّهِ فَأَذاقَهَا اللَّهُ لِباسَ الجوعِ وَالخَوفِ بِما كانوا يَصنَعونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmxiv{وَلَقَد جاءَهُم رَسولٌ مِنهُم فَكَذَّبوهُ فَأَخَذَهُمُ العَذابُ وَهُم ظالِمونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmxv{فَكُلوا مِمّا رَزَقَكُمُ اللَّهُ حَلالًا طَيِّبًا وَاشكُروا نِعمَتَ اللَّهِ إِن كُنتُم إِيّاهُ تَعبُدونَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmxvi{إِنَّما حَرَّمَ عَلَيكُمُ المَيتَةَ وَالدَّمَ وَلَحمَ الخِنزيرِ وَما أُهِلَّ لِغَيرِ اللَّهِ بِهِ ۖ فَمَنِ اضطُرَّ غَيرَ باغٍ وَلا عادٍ فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmxvii{وَلا تَقولوا لِما تَصِفُ أَلسِنَتُكُمُ الكَذِبَ هٰذا حَلالٌ وَهٰذا حَرامٌ لِتَفتَروا عَلَى اللَّهِ الكَذِبَ ۚ إِنَّ الَّذينَ يَفتَرونَ عَلَى اللَّهِ الكَذِبَ لا يُفلِحونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmxviii{مَتاعٌ قَليلٌ وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmxix{وَعَلَى الَّذينَ هادوا حَرَّمنا ما قَصَصنا عَلَيكَ مِن قَبلُ ۖ وَما ظَلَمناهُم وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmxx{ثُمَّ إِنَّ رَبَّكَ لِلَّذينَ عَمِلُوا السّوءَ بِجَهالَةٍ ثُمَّ تابوا مِن بَعدِ ذٰلِكَ وَأَصلَحوا إِنَّ رَبَّكَ مِن بَعدِها لَغَفورٌ رَحيمٌ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmxxi{إِنَّ إِبراهيمَ كانَ أُمَّةً قانِتًا لِلَّهِ حَنيفًا وَلَم يَكُ مِنَ المُشرِكينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmxxii{شاكِرًا لِأَنعُمِهِ ۚ اجتَباهُ وَهَداهُ إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmxxiii{وَآتَيناهُ فِي الدُّنيا حَسَنَةً ۖ وَإِنَّهُ فِي الآخِرَةِ لَمِنَ الصّالِحينَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmxxiv{ثُمَّ أَوحَينا إِلَيكَ أَنِ اتَّبِع مِلَّةَ إِبراهيمَ حَنيفًا ۖ وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmxxv{إِنَّما جُعِلَ السَّبتُ عَلَى الَّذينَ اختَلَفوا فيهِ ۚ وَإِنَّ رَبَّكَ لَيَحكُمُ بَينَهُم يَومَ القِيامَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmxxvi{ادعُ إِلىٰ سَبيلِ رَبِّكَ بِالحِكمَةِ وَالمَوعِظَةِ الحَسَنَةِ ۖ وَجادِلهُم بِالَّتي هِيَ أَحسَنُ ۚ إِنَّ رَبَّكَ هُوَ أَعلَمُ بِمَن ضَلَّ عَن سَبيلِهِ ۖ وَهُوَ أَعلَمُ بِالمُهتَدينَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmxxvii{وَإِن عاقَبتُم فَعاقِبوا بِمِثلِ ما عوقِبتُم بِهِ ۖ وَلَئِن صَبَرتُم لَهُوَ خَيرٌ لِلصّابِرينَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmxxviii{وَاصبِر وَما صَبرُكَ إِلّا بِاللَّهِ ۚ وَلا تَحزَن عَلَيهِم وَلا تَكُ في ضَيقٍ مِمّا يَمكُرونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmxxix{إِنَّ اللَّهَ مَعَ الَّذينَ اتَّقَوا وَالَّذينَ هُم مُحسِنونَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmxxx{\basmalah سُبحانَ الَّذي أَسرىٰ بِعَبدِهِ لَيلًا مِنَ المَسجِدِ الحَرامِ إِلَى المَسجِدِ الأَقصَى الَّذي بارَكنا حَولَهُ لِنُرِيَهُ مِن آياتِنا ۚ إِنَّهُ هُوَ السَّميعُ البَصيرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmxxxi{وَآتَينا موسَى الكِتابَ وَجَعَلناهُ هُدًى لِبَني إِسرائيلَ أَلّا تَتَّخِذوا مِن دوني وَكيلًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmxxxii{ذُرِّيَّةَ مَن حَمَلنا مَعَ نوحٍ ۚ إِنَّهُ كانَ عَبدًا شَكورًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmxxxiii{وَقَضَينا إِلىٰ بَني إِسرائيلَ فِي الكِتابِ لَتُفسِدُنَّ فِي الأَرضِ مَرَّتَينِ وَلَتَعلُنَّ عُلُوًّا كَبيرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmxxxiv{فَإِذا جاءَ وَعدُ أولاهُما بَعَثنا عَلَيكُم عِبادًا لَنا أُولي بَأسٍ شَديدٍ فَجاسوا خِلالَ الدِّيارِ ۚ وَكانَ وَعدًا مَفعولًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmxxxv{ثُمَّ رَدَدنا لَكُمُ الكَرَّةَ عَلَيهِم وَأَمدَدناكُم بِأَموالٍ وَبَنينَ وَجَعَلناكُم أَكثَرَ نَفيرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmxxxvi{إِن أَحسَنتُم أَحسَنتُم لِأَنفُسِكُم ۖ وَإِن أَسَأتُم فَلَها ۚ فَإِذا جاءَ وَعدُ الآخِرَةِ لِيَسوءوا وُجوهَكُم وَلِيَدخُلُوا المَسجِدَ كَما دَخَلوهُ أَوَّلَ مَرَّةٍ وَلِيُتَبِّروا ما عَلَوا تَتبيرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmxxxvii{عَسىٰ رَبُّكُم أَن يَرحَمَكُم ۚ وَإِن عُدتُم عُدنا ۘ وَجَعَلنا جَهَنَّمَ لِلكافِرينَ حَصيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmxxxviii{إِنَّ هٰذَا القُرآنَ يَهدي لِلَّتي هِيَ أَقوَمُ وَيُبَشِّرُ المُؤمِنينَ الَّذينَ يَعمَلونَ الصّالِحاتِ أَنَّ لَهُم أَجرًا كَبيرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmxxxix{وَأَنَّ الَّذينَ لا يُؤمِنونَ بِالآخِرَةِ أَعتَدنا لَهُم عَذابًا أَليمًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmxl{وَيَدعُ الإِنسانُ بِالشَّرِّ دُعاءَهُ بِالخَيرِ ۖ وَكانَ الإِنسانُ عَجولًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmxli{وَجَعَلنَا اللَّيلَ وَالنَّهارَ آيَتَينِ ۖ فَمَحَونا آيَةَ اللَّيلِ وَجَعَلنا آيَةَ النَّهارِ مُبصِرَةً لِتَبتَغوا فَضلًا مِن رَبِّكُم وَلِتَعلَموا عَدَدَ السِّنينَ وَالحِسابَ ۚ وَكُلَّ شَيءٍ فَصَّلناهُ تَفصيلًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmxlii{وَكُلَّ إِنسانٍ أَلزَمناهُ طائِرَهُ في عُنُقِهِ ۖ وَنُخرِجُ لَهُ يَومَ القِيامَةِ كِتابًا يَلقاهُ مَنشورًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmxliii{اقرَأ كِتابَكَ كَفىٰ بِنَفسِكَ اليَومَ عَلَيكَ حَسيبًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmxliv{مَنِ اهتَدىٰ فَإِنَّما يَهتَدي لِنَفسِهِ ۖ وَمَن ضَلَّ فَإِنَّما يَضِلُّ عَلَيها ۚ وَلا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ ۗ وَما كُنّا مُعَذِّبينَ حَتّىٰ نَبعَثَ رَسولًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmxlv{وَإِذا أَرَدنا أَن نُهلِكَ قَريَةً أَمَرنا مُترَفيها فَفَسَقوا فيها فَحَقَّ عَلَيهَا القَولُ فَدَمَّرناها تَدميرًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmxlvi{وَكَم أَهلَكنا مِنَ القُرونِ مِن بَعدِ نوحٍ ۗ وَكَفىٰ بِرَبِّكَ بِذُنوبِ عِبادِهِ خَبيرًا بَصيرًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmxlvii{مَن كانَ يُريدُ العاجِلَةَ عَجَّلنا لَهُ فيها ما نَشاءُ لِمَن نُريدُ ثُمَّ جَعَلنا لَهُ جَهَنَّمَ يَصلاها مَذمومًا مَدحورًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmxlviii{وَمَن أَرادَ الآخِرَةَ وَسَعىٰ لَها سَعيَها وَهُوَ مُؤمِنٌ فَأُولٰئِكَ كانَ سَعيُهُم مَشكورًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmxlix{كُلًّا نُمِدُّ هٰؤُلاءِ وَهٰؤُلاءِ مِن عَطاءِ رَبِّكَ ۚ وَما كانَ عَطاءُ رَبِّكَ مَحظورًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mml{انظُر كَيفَ فَضَّلنا بَعضَهُم عَلىٰ بَعضٍ ۚ وَلَلآخِرَةُ أَكبَرُ دَرَجاتٍ وَأَكبَرُ تَفضيلًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmli{لا تَجعَل مَعَ اللَّهِ إِلٰهًا آخَرَ فَتَقعُدَ مَذمومًا مَخذولًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmlii{۞ وَقَضىٰ رَبُّكَ أَلّا تَعبُدوا إِلّا إِيّاهُ وَبِالوالِدَينِ إِحسانًا ۚ إِمّا يَبلُغَنَّ عِندَكَ الكِبَرَ أَحَدُهُما أَو كِلاهُما فَلا تَقُل لَهُما أُفٍّ وَلا تَنهَرهُما وَقُل لَهُما قَولًا كَريمًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmliii{وَاخفِض لَهُما جَناحَ الذُّلِّ مِنَ الرَّحمَةِ وَقُل رَبِّ ارحَمهُما كَما رَبَّياني صَغيرًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmliv{رَبُّكُم أَعلَمُ بِما في نُفوسِكُم ۚ إِن تَكونوا صالِحينَ فَإِنَّهُ كانَ لِلأَوّابينَ غَفورًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmlv{وَآتِ ذَا القُربىٰ حَقَّهُ وَالمِسكينَ وَابنَ السَّبيلِ وَلا تُبَذِّر تَبذيرًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmlvi{إِنَّ المُبَذِّرينَ كانوا إِخوانَ الشَّياطينِ ۖ وَكانَ الشَّيطانُ لِرَبِّهِ كَفورًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmlvii{وَإِمّا تُعرِضَنَّ عَنهُمُ ابتِغاءَ رَحمَةٍ مِن رَبِّكَ تَرجوها فَقُل لَهُم قَولًا مَيسورًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmlviii{وَلا تَجعَل يَدَكَ مَغلولَةً إِلىٰ عُنُقِكَ وَلا تَبسُطها كُلَّ البَسطِ فَتَقعُدَ مَلومًا مَحسورًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmlix{إِنَّ رَبَّكَ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ ۚ إِنَّهُ كانَ بِعِبادِهِ خَبيرًا بَصيرًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmlx{وَلا تَقتُلوا أَولادَكُم خَشيَةَ إِملاقٍ ۖ نَحنُ نَرزُقُهُم وَإِيّاكُم ۚ إِنَّ قَتلَهُم كانَ خِطئًا كَبيرًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmlxi{وَلا تَقرَبُوا الزِّنا ۖ إِنَّهُ كانَ فاحِشَةً وَساءَ سَبيلًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmlxii{وَلا تَقتُلُوا النَّفسَ الَّتي حَرَّمَ اللَّهُ إِلّا بِالحَقِّ ۗ وَمَن قُتِلَ مَظلومًا فَقَد جَعَلنا لِوَلِيِّهِ سُلطانًا فَلا يُسرِف فِي القَتلِ ۖ إِنَّهُ كانَ مَنصورًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmlxiii{وَلا تَقرَبوا مالَ اليَتيمِ إِلّا بِالَّتي هِيَ أَحسَنُ حَتّىٰ يَبلُغَ أَشُدَّهُ ۚ وَأَوفوا بِالعَهدِ ۖ إِنَّ العَهدَ كانَ مَسئولًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmlxiv{وَأَوفُوا الكَيلَ إِذا كِلتُم وَزِنوا بِالقِسطاسِ المُستَقيمِ ۚ ذٰلِكَ خَيرٌ وَأَحسَنُ تَأويلًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmlxv{وَلا تَقفُ ما لَيسَ لَكَ بِهِ عِلمٌ ۚ إِنَّ السَّمعَ وَالبَصَرَ وَالفُؤادَ كُلُّ أُولٰئِكَ كانَ عَنهُ مَسئولًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmlxvi{وَلا تَمشِ فِي الأَرضِ مَرَحًا ۖ إِنَّكَ لَن تَخرِقَ الأَرضَ وَلَن تَبلُغَ الجِبالَ طولًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmlxvii{كُلُّ ذٰلِكَ كانَ سَيِّئُهُ عِندَ رَبِّكَ مَكروهًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmlxviii{ذٰلِكَ مِمّا أَوحىٰ إِلَيكَ رَبُّكَ مِنَ الحِكمَةِ ۗ وَلا تَجعَل مَعَ اللَّهِ إِلٰهًا آخَرَ فَتُلقىٰ في جَهَنَّمَ مَلومًا مَدحورًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmlxix{أَفَأَصفاكُم رَبُّكُم بِالبَنينَ وَاتَّخَذَ مِنَ المَلائِكَةِ إِناثًا ۚ إِنَّكُم لَتَقولونَ قَولًا عَظيمًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmlxx{وَلَقَد صَرَّفنا في هٰذَا القُرآنِ لِيَذَّكَّروا وَما يَزيدُهُم إِلّا نُفورًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmlxxi{قُل لَو كانَ مَعَهُ آلِهَةٌ كَما يَقولونَ إِذًا لَابتَغَوا إِلىٰ ذِي العَرشِ سَبيلًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmlxxii{سُبحانَهُ وَتَعالىٰ عَمّا يَقولونَ عُلُوًّا كَبيرًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmlxxiii{تُسَبِّحُ لَهُ السَّماواتُ السَّبعُ وَالأَرضُ وَمَن فيهِنَّ ۚ وَإِن مِن شَيءٍ إِلّا يُسَبِّحُ بِحَمدِهِ وَلٰكِن لا تَفقَهونَ تَسبيحَهُم ۗ إِنَّهُ كانَ حَليمًا غَفورًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmlxxiv{وَإِذا قَرَأتَ القُرآنَ جَعَلنا بَينَكَ وَبَينَ الَّذينَ لا يُؤمِنونَ بِالآخِرَةِ حِجابًا مَستورًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmlxxv{وَجَعَلنا عَلىٰ قُلوبِهِم أَكِنَّةً أَن يَفقَهوهُ وَفي آذانِهِم وَقرًا ۚ وَإِذا ذَكَرتَ رَبَّكَ فِي القُرآنِ وَحدَهُ وَلَّوا عَلىٰ أَدبارِهِم نُفورًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmlxxvi{نَحنُ أَعلَمُ بِما يَستَمِعونَ بِهِ إِذ يَستَمِعونَ إِلَيكَ وَإِذ هُم نَجوىٰ إِذ يَقولُ الظّالِمونَ إِن تَتَّبِعونَ إِلّا رَجُلًا مَسحورًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmlxxvii{انظُر كَيفَ ضَرَبوا لَكَ الأَمثالَ فَضَلّوا فَلا يَستَطيعونَ سَبيلًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmlxxviii{وَقالوا أَإِذا كُنّا عِظامًا وَرُفاتًا أَإِنّا لَمَبعوثونَ خَلقًا جَديدًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmlxxix{۞ قُل كونوا حِجارَةً أَو حَديدًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmlxxx{أَو خَلقًا مِمّا يَكبُرُ في صُدورِكُم ۚ فَسَيَقولونَ مَن يُعيدُنا ۖ قُلِ الَّذي فَطَرَكُم أَوَّلَ مَرَّةٍ ۚ فَسَيُنغِضونَ إِلَيكَ رُءوسَهُم وَيَقولونَ مَتىٰ هُوَ ۖ قُل عَسىٰ أَن يَكونَ قَريبًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmlxxxi{يَومَ يَدعوكُم فَتَستَجيبونَ بِحَمدِهِ وَتَظُنّونَ إِن لَبِثتُم إِلّا قَليلًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmlxxxii{وَقُل لِعِبادي يَقولُوا الَّتي هِيَ أَحسَنُ ۚ إِنَّ الشَّيطانَ يَنزَغُ بَينَهُم ۚ إِنَّ الشَّيطانَ كانَ لِلإِنسانِ عَدُوًّا مُبينًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmlxxxiii{رَبُّكُم أَعلَمُ بِكُم ۖ إِن يَشَأ يَرحَمكُم أَو إِن يَشَأ يُعَذِّبكُم ۚ وَما أَرسَلناكَ عَلَيهِم وَكيلًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmlxxxiv{وَرَبُّكَ أَعلَمُ بِمَن فِي السَّماواتِ وَالأَرضِ ۗ وَلَقَد فَضَّلنا بَعضَ النَّبِيّينَ عَلىٰ بَعضٍ ۖ وَآتَينا داوودَ زَبورًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmlxxxv{قُلِ ادعُوا الَّذينَ زَعَمتُم مِن دونِهِ فَلا يَملِكونَ كَشفَ الضُّرِّ عَنكُم وَلا تَحويلًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmlxxxvi{أُولٰئِكَ الَّذينَ يَدعونَ يَبتَغونَ إِلىٰ رَبِّهِمُ الوَسيلَةَ أَيُّهُم أَقرَبُ وَيَرجونَ رَحمَتَهُ وَيَخافونَ عَذابَهُ ۚ إِنَّ عَذابَ رَبِّكَ كانَ مَحذورًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmlxxxvii{وَإِن مِن قَريَةٍ إِلّا نَحنُ مُهلِكوها قَبلَ يَومِ القِيامَةِ أَو مُعَذِّبوها عَذابًا شَديدًا ۚ كانَ ذٰلِكَ فِي الكِتابِ مَسطورًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmlxxxviii{وَما مَنَعَنا أَن نُرسِلَ بِالآياتِ إِلّا أَن كَذَّبَ بِهَا الأَوَّلونَ ۚ وَآتَينا ثَمودَ النّاقَةَ مُبصِرَةً فَظَلَموا بِها ۚ وَما نُرسِلُ بِالآياتِ إِلّا تَخويفًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmlxxxix{وَإِذ قُلنا لَكَ إِنَّ رَبَّكَ أَحاطَ بِالنّاسِ ۚ وَما جَعَلنَا الرُّؤيَا الَّتي أَرَيناكَ إِلّا فِتنَةً لِلنّاسِ وَالشَّجَرَةَ المَلعونَةَ فِي القُرآنِ ۚ وَنُخَوِّفُهُم فَما يَزيدُهُم إِلّا طُغيانًا كَبيرًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmxc{وَإِذ قُلنا لِلمَلائِكَةِ اسجُدوا لِآدَمَ فَسَجَدوا إِلّا إِبليسَ قالَ أَأَسجُدُ لِمَن خَلَقتَ طينًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmxci{قالَ أَرَأَيتَكَ هٰذَا الَّذي كَرَّمتَ عَلَيَّ لَئِن أَخَّرتَنِ إِلىٰ يَومِ القِيامَةِ لَأَحتَنِكَنَّ ذُرِّيَّتَهُ إِلّا قَليلًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmxcii{قالَ اذهَب فَمَن تَبِعَكَ مِنهُم فَإِنَّ جَهَنَّمَ جَزاؤُكُم جَزاءً مَوفورًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmxciii{وَاستَفزِز مَنِ استَطَعتَ مِنهُم بِصَوتِكَ وَأَجلِب عَلَيهِم بِخَيلِكَ وَرَجِلِكَ وَشارِكهُم فِي الأَموالِ وَالأَولادِ وَعِدهُم ۚ وَما يَعِدُهُمُ الشَّيطانُ إِلّا غُرورًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmxciv{إِنَّ عِبادي لَيسَ لَكَ عَلَيهِم سُلطانٌ ۚ وَكَفىٰ بِرَبِّكَ وَكيلًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmxcv{رَبُّكُمُ الَّذي يُزجي لَكُمُ الفُلكَ فِي البَحرِ لِتَبتَغوا مِن فَضلِهِ ۚ إِنَّهُ كانَ بِكُم رَحيمًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmxcvi{وَإِذا مَسَّكُمُ الضُّرُّ فِي البَحرِ ضَلَّ مَن تَدعونَ إِلّا إِيّاهُ ۖ فَلَمّا نَجّاكُم إِلَى البَرِّ أَعرَضتُم ۚ وَكانَ الإِنسانُ كَفورًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmxcvii{أَفَأَمِنتُم أَن يَخسِفَ بِكُم جانِبَ البَرِّ أَو يُرسِلَ عَلَيكُم حاصِبًا ثُمَّ لا تَجِدوا لَكُم وَكيلًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmxcviii{أَم أَمِنتُم أَن يُعيدَكُم فيهِ تارَةً أُخرىٰ فَيُرسِلَ عَلَيكُم قاصِفًا مِنَ الرّيحِ فَيُغرِقَكُم بِما كَفَرتُم ۙ ثُمَّ لا تَجِدوا لَكُم عَلَينا بِهِ تَبيعًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmxcix{۞ وَلَقَد كَرَّمنا بَني آدَمَ وَحَمَلناهُم فِي البَرِّ وَالبَحرِ وَرَزَقناهُم مِنَ الطَّيِّباتِ وَفَضَّلناهُم عَلىٰ كَثيرٍ مِمَّن خَلَقنا تَفضيلًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmc{يَومَ نَدعو كُلَّ أُناسٍ بِإِمامِهِم ۖ فَمَن أوتِيَ كِتابَهُ بِيَمينِهِ فَأُولٰئِكَ يَقرَءونَ كِتابَهُم وَلا يُظلَمونَ فَتيلًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmci{وَمَن كانَ في هٰذِهِ أَعمىٰ فَهُوَ فِي الآخِرَةِ أَعمىٰ وَأَضَلُّ سَبيلًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcii{وَإِن كادوا لَيَفتِنونَكَ عَنِ الَّذي أَوحَينا إِلَيكَ لِتَفتَرِيَ عَلَينا غَيرَهُ ۖ وَإِذًا لَاتَّخَذوكَ خَليلًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmciii{وَلَولا أَن ثَبَّتناكَ لَقَد كِدتَ تَركَنُ إِلَيهِم شَيئًا قَليلًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmciv{إِذًا لَأَذَقناكَ ضِعفَ الحَياةِ وَضِعفَ المَماتِ ثُمَّ لا تَجِدُ لَكَ عَلَينا نَصيرًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcv{وَإِن كادوا لَيَستَفِزّونَكَ مِنَ الأَرضِ لِيُخرِجوكَ مِنها ۖ وَإِذًا لا يَلبَثونَ خِلافَكَ إِلّا قَليلًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcvi{سُنَّةَ مَن قَد أَرسَلنا قَبلَكَ مِن رُسُلِنا ۖ وَلا تَجِدُ لِسُنَّتِنا تَحويلًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcvii{أَقِمِ الصَّلاةَ لِدُلوكِ الشَّمسِ إِلىٰ غَسَقِ اللَّيلِ وَقُرآنَ الفَجرِ ۖ إِنَّ قُرآنَ الفَجرِ كانَ مَشهودًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmcviii{وَمِنَ اللَّيلِ فَتَهَجَّد بِهِ نافِلَةً لَكَ عَسىٰ أَن يَبعَثَكَ رَبُّكَ مَقامًا مَحمودًا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmcix{وَقُل رَبِّ أَدخِلني مُدخَلَ صِدقٍ وَأَخرِجني مُخرَجَ صِدقٍ وَاجعَل لي مِن لَدُنكَ سُلطانًا نَصيرًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmcx{وَقُل جاءَ الحَقُّ وَزَهَقَ الباطِلُ ۚ إِنَّ الباطِلَ كانَ زَهوقًا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmcxi{وَنُنَزِّلُ مِنَ القُرآنِ ما هُوَ شِفاءٌ وَرَحمَةٌ لِلمُؤمِنينَ ۙ وَلا يَزيدُ الظّالِمينَ إِلّا خَسارًا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmcxii{وَإِذا أَنعَمنا عَلَى الإِنسانِ أَعرَضَ وَنَأىٰ بِجانِبِهِ ۖ وَإِذا مَسَّهُ الشَّرُّ كانَ يَئوسًا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmcxiii{قُل كُلٌّ يَعمَلُ عَلىٰ شاكِلَتِهِ فَرَبُّكُم أَعلَمُ بِمَن هُوَ أَهدىٰ سَبيلًا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmcxiv{وَيَسأَلونَكَ عَنِ الرّوحِ ۖ قُلِ الرّوحُ مِن أَمرِ رَبّي وَما أوتيتُم مِنَ العِلمِ إِلّا قَليلًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmcxv{وَلَئِن شِئنا لَنَذهَبَنَّ بِالَّذي أَوحَينا إِلَيكَ ثُمَّ لا تَجِدُ لَكَ بِهِ عَلَينا وَكيلًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmcxvi{إِلّا رَحمَةً مِن رَبِّكَ ۚ إِنَّ فَضلَهُ كانَ عَلَيكَ كَبيرًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmcxvii{قُل لَئِنِ اجتَمَعَتِ الإِنسُ وَالجِنُّ عَلىٰ أَن يَأتوا بِمِثلِ هٰذَا القُرآنِ لا يَأتونَ بِمِثلِهِ وَلَو كانَ بَعضُهُم لِبَعضٍ ظَهيرًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmcxviii{وَلَقَد صَرَّفنا لِلنّاسِ في هٰذَا القُرآنِ مِن كُلِّ مَثَلٍ فَأَبىٰ أَكثَرُ النّاسِ إِلّا كُفورًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmcxix{وَقالوا لَن نُؤمِنَ لَكَ حَتّىٰ تَفجُرَ لَنا مِنَ الأَرضِ يَنبوعًا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmcxx{أَو تَكونَ لَكَ جَنَّةٌ مِن نَخيلٍ وَعِنَبٍ فَتُفَجِّرَ الأَنهارَ خِلالَها تَفجيرًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmcxxi{أَو تُسقِطَ السَّماءَ كَما زَعَمتَ عَلَينا كِسَفًا أَو تَأتِيَ بِاللَّهِ وَالمَلائِكَةِ قَبيلًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmcxxii{أَو يَكونَ لَكَ بَيتٌ مِن زُخرُفٍ أَو تَرقىٰ فِي السَّماءِ وَلَن نُؤمِنَ لِرُقِيِّكَ حَتّىٰ تُنَزِّلَ عَلَينا كِتابًا نَقرَؤُهُ ۗ قُل سُبحانَ رَبّي هَل كُنتُ إِلّا بَشَرًا رَسولًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmcxxiii{وَما مَنَعَ النّاسَ أَن يُؤمِنوا إِذ جاءَهُمُ الهُدىٰ إِلّا أَن قالوا أَبَعَثَ اللَّهُ بَشَرًا رَسولًا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmcxxiv{قُل لَو كانَ فِي الأَرضِ مَلائِكَةٌ يَمشونَ مُطمَئِنّينَ لَنَزَّلنا عَلَيهِم مِنَ السَّماءِ مَلَكًا رَسولًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmcxxv{قُل كَفىٰ بِاللَّهِ شَهيدًا بَيني وَبَينَكُم ۚ إِنَّهُ كانَ بِعِبادِهِ خَبيرًا بَصيرًا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmcxxvi{وَمَن يَهدِ اللَّهُ فَهُوَ المُهتَدِ ۖ وَمَن يُضلِل فَلَن تَجِدَ لَهُم أَولِياءَ مِن دونِهِ ۖ وَنَحشُرُهُم يَومَ القِيامَةِ عَلىٰ وُجوهِهِم عُميًا وَبُكمًا وَصُمًّا ۖ مَأواهُم جَهَنَّمُ ۖ كُلَّما خَبَت زِدناهُم سَعيرًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmcxxvii{ذٰلِكَ جَزاؤُهُم بِأَنَّهُم كَفَروا بِآياتِنا وَقالوا أَإِذا كُنّا عِظامًا وَرُفاتًا أَإِنّا لَمَبعوثونَ خَلقًا جَديدًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmcxxviii{۞ أَوَلَم يَرَوا أَنَّ اللَّهَ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ قادِرٌ عَلىٰ أَن يَخلُقَ مِثلَهُم وَجَعَلَ لَهُم أَجَلًا لا رَيبَ فيهِ فَأَبَى الظّالِمونَ إِلّا كُفورًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmcxxix{قُل لَو أَنتُم تَملِكونَ خَزائِنَ رَحمَةِ رَبّي إِذًا لَأَمسَكتُم خَشيَةَ الإِنفاقِ ۚ وَكانَ الإِنسانُ قَتورًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmcxxx{وَلَقَد آتَينا موسىٰ تِسعَ آياتٍ بَيِّناتٍ ۖ فَاسأَل بَني إِسرائيلَ إِذ جاءَهُم فَقالَ لَهُ فِرعَونُ إِنّي لَأَظُنُّكَ يا موسىٰ مَسحورًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmcxxxi{قالَ لَقَد عَلِمتَ ما أَنزَلَ هٰؤُلاءِ إِلّا رَبُّ السَّماواتِ وَالأَرضِ بَصائِرَ وَإِنّي لَأَظُنُّكَ يا فِرعَونُ مَثبورًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmcxxxii{فَأَرادَ أَن يَستَفِزَّهُم مِنَ الأَرضِ فَأَغرَقناهُ وَمَن مَعَهُ جَميعًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmcxxxiii{وَقُلنا مِن بَعدِهِ لِبَني إِسرائيلَ اسكُنُوا الأَرضَ فَإِذا جاءَ وَعدُ الآخِرَةِ جِئنا بِكُم لَفيفًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmcxxxiv{وَبِالحَقِّ أَنزَلناهُ وَبِالحَقِّ نَزَلَ ۗ وَما أَرسَلناكَ إِلّا مُبَشِّرًا وَنَذيرًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmcxxxv{وَقُرآنًا فَرَقناهُ لِتَقرَأَهُ عَلَى النّاسِ عَلىٰ مُكثٍ وَنَزَّلناهُ تَنزيلًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmcxxxvi{قُل آمِنوا بِهِ أَو لا تُؤمِنوا ۚ إِنَّ الَّذينَ أوتُوا العِلمَ مِن قَبلِهِ إِذا يُتلىٰ عَلَيهِم يَخِرّونَ لِلأَذقانِ سُجَّدًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmcxxxvii{وَيَقولونَ سُبحانَ رَبِّنا إِن كانَ وَعدُ رَبِّنا لَمَفعولًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmcxxxviii{وَيَخِرّونَ لِلأَذقانِ يَبكونَ وَيَزيدُهُم خُشوعًا ۩\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmcxxxix{قُلِ ادعُوا اللَّهَ أَوِ ادعُوا الرَّحمٰنَ ۖ أَيًّا ما تَدعوا فَلَهُ الأَسماءُ الحُسنىٰ ۚ وَلا تَجهَر بِصَلاتِكَ وَلا تُخافِت بِها وَابتَغِ بَينَ ذٰلِكَ سَبيلًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmcxl{وَقُلِ الحَمدُ لِلَّهِ الَّذي لَم يَتَّخِذ وَلَدًا وَلَم يَكُن لَهُ شَريكٌ فِي المُلكِ وَلَم يَكُن لَهُ وَلِيٌّ مِنَ الذُّلِّ ۖ وَكَبِّرهُ تَكبيرًا\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmcxli{\basmalah الحَمدُ لِلَّهِ الَّذي أَنزَلَ عَلىٰ عَبدِهِ الكِتابَ وَلَم يَجعَل لَهُ عِوَجًا ۜ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcxlii{قَيِّمًا لِيُنذِرَ بَأسًا شَديدًا مِن لَدُنهُ وَيُبَشِّرَ المُؤمِنينَ الَّذينَ يَعمَلونَ الصّالِحاتِ أَنَّ لَهُم أَجرًا حَسَنًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcxliii{ماكِثينَ فيهِ أَبَدًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmcxliv{وَيُنذِرَ الَّذينَ قالُوا اتَّخَذَ اللَّهُ وَلَدًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcxlv{ما لَهُم بِهِ مِن عِلمٍ وَلا لِآبائِهِم ۚ كَبُرَت كَلِمَةً تَخرُجُ مِن أَفواهِهِم ۚ إِن يَقولونَ إِلّا كَذِبًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcxlvi{فَلَعَلَّكَ باخِعٌ نَفسَكَ عَلىٰ آثارِهِم إِن لَم يُؤمِنوا بِهٰذَا الحَديثِ أَسَفًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcxlvii{إِنّا جَعَلنا ما عَلَى الأَرضِ زينَةً لَها لِنَبلُوَهُم أَيُّهُم أَحسَنُ عَمَلًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcxlviii{وَإِنّا لَجاعِلونَ ما عَلَيها صَعيدًا جُرُزًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcxlix{أَم حَسِبتَ أَنَّ أَصحابَ الكَهفِ وَالرَّقيمِ كانوا مِن آياتِنا عَجَبًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcl{إِذ أَوَى الفِتيَةُ إِلَى الكَهفِ فَقالوا رَبَّنا آتِنا مِن لَدُنكَ رَحمَةً وَهَيِّئ لَنا مِن أَمرِنا رَشَدًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcli{فَضَرَبنا عَلىٰ آذانِهِم فِي الكَهفِ سِنينَ عَدَدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmclii{ثُمَّ بَعَثناهُم لِنَعلَمَ أَيُّ الحِزبَينِ أَحصىٰ لِما لَبِثوا أَمَدًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcliii{نَحنُ نَقُصُّ عَلَيكَ نَبَأَهُم بِالحَقِّ ۚ إِنَّهُم فِتيَةٌ آمَنوا بِرَبِّهِم وَزِدناهُم هُدًى\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcliv{وَرَبَطنا عَلىٰ قُلوبِهِم إِذ قاموا فَقالوا رَبُّنا رَبُّ السَّماواتِ وَالأَرضِ لَن نَدعُوَ مِن دونِهِ إِلٰهًا ۖ لَقَد قُلنا إِذًا شَطَطًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmclv{هٰؤُلاءِ قَومُنَا اتَّخَذوا مِن دونِهِ آلِهَةً ۖ لَولا يَأتونَ عَلَيهِم بِسُلطانٍ بَيِّنٍ ۖ فَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmclvi{وَإِذِ اعتَزَلتُموهُم وَما يَعبُدونَ إِلَّا اللَّهَ فَأووا إِلَى الكَهفِ يَنشُر لَكُم رَبُّكُم مِن رَحمَتِهِ وَيُهَيِّئ لَكُم مِن أَمرِكُم مِرفَقًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmclvii{۞ وَتَرَى الشَّمسَ إِذا طَلَعَت تَزاوَرُ عَن كَهفِهِم ذاتَ اليَمينِ وَإِذا غَرَبَت تَقرِضُهُم ذاتَ الشِّمالِ وَهُم في فَجوَةٍ مِنهُ ۚ ذٰلِكَ مِن آياتِ اللَّهِ ۗ مَن يَهدِ اللَّهُ فَهُوَ المُهتَدِ ۖ وَمَن يُضلِل فَلَن تَجِدَ لَهُ وَلِيًّا مُرشِدًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmclviii{وَتَحسَبُهُم أَيقاظًا وَهُم رُقودٌ ۚ وَنُقَلِّبُهُم ذاتَ اليَمينِ وَذاتَ الشِّمالِ ۖ وَكَلبُهُم باسِطٌ ذِراعَيهِ بِالوَصيدِ ۚ لَوِ اطَّلَعتَ عَلَيهِم لَوَلَّيتَ مِنهُم فِرارًا وَلَمُلِئتَ مِنهُم رُعبًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmclix{وَكَذٰلِكَ بَعَثناهُم لِيَتَساءَلوا بَينَهُم ۚ قالَ قائِلٌ مِنهُم كَم لَبِثتُم ۖ قالوا لَبِثنا يَومًا أَو بَعضَ يَومٍ ۚ قالوا رَبُّكُم أَعلَمُ بِما لَبِثتُم فَابعَثوا أَحَدَكُم بِوَرِقِكُم هٰذِهِ إِلَى المَدينَةِ فَليَنظُر أَيُّها أَزكىٰ طَعامًا فَليَأتِكُم بِرِزقٍ مِنهُ وَليَتَلَطَّف وَلا يُشعِرَنَّ بِكُم أَحَدًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmclx{إِنَّهُم إِن يَظهَروا عَلَيكُم يَرجُموكُم أَو يُعيدوكُم في مِلَّتِهِم وَلَن تُفلِحوا إِذًا أَبَدًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmclxi{وَكَذٰلِكَ أَعثَرنا عَلَيهِم لِيَعلَموا أَنَّ وَعدَ اللَّهِ حَقٌّ وَأَنَّ السّاعَةَ لا رَيبَ فيها إِذ يَتَنازَعونَ بَينَهُم أَمرَهُم ۖ فَقالُوا ابنوا عَلَيهِم بُنيانًا ۖ رَبُّهُم أَعلَمُ بِهِم ۚ قالَ الَّذينَ غَلَبوا عَلىٰ أَمرِهِم لَنَتَّخِذَنَّ عَلَيهِم مَسجِدًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmclxii{سَيَقولونَ ثَلاثَةٌ رابِعُهُم كَلبُهُم وَيَقولونَ خَمسَةٌ سادِسُهُم كَلبُهُم رَجمًا بِالغَيبِ ۖ وَيَقولونَ سَبعَةٌ وَثامِنُهُم كَلبُهُم ۚ قُل رَبّي أَعلَمُ بِعِدَّتِهِم ما يَعلَمُهُم إِلّا قَليلٌ ۗ فَلا تُمارِ فيهِم إِلّا مِراءً ظاهِرًا وَلا تَستَفتِ فيهِم مِنهُم أَحَدًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmclxiii{وَلا تَقولَنَّ لِشَيءٍ إِنّي فاعِلٌ ذٰلِكَ غَدًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmclxiv{إِلّا أَن يَشاءَ اللَّهُ ۚ وَاذكُر رَبَّكَ إِذا نَسيتَ وَقُل عَسىٰ أَن يَهدِيَنِ رَبّي لِأَقرَبَ مِن هٰذا رَشَدًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmclxv{وَلَبِثوا في كَهفِهِم ثَلاثَ مِائَةٍ سِنينَ وَازدادوا تِسعًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmclxvi{قُلِ اللَّهُ أَعلَمُ بِما لَبِثوا ۖ لَهُ غَيبُ السَّماواتِ وَالأَرضِ ۖ أَبصِر بِهِ وَأَسمِع ۚ ما لَهُم مِن دونِهِ مِن وَلِيٍّ وَلا يُشرِكُ في حُكمِهِ أَحَدًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmclxvii{وَاتلُ ما أوحِيَ إِلَيكَ مِن كِتابِ رَبِّكَ ۖ لا مُبَدِّلَ لِكَلِماتِهِ وَلَن تَجِدَ مِن دونِهِ مُلتَحَدًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmclxviii{وَاصبِر نَفسَكَ مَعَ الَّذينَ يَدعونَ رَبَّهُم بِالغَداةِ وَالعَشِيِّ يُريدونَ وَجهَهُ ۖ وَلا تَعدُ عَيناكَ عَنهُم تُريدُ زينَةَ الحَياةِ الدُّنيا ۖ وَلا تُطِع مَن أَغفَلنا قَلبَهُ عَن ذِكرِنا وَاتَّبَعَ هَواهُ وَكانَ أَمرُهُ فُرُطًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmclxix{وَقُلِ الحَقُّ مِن رَبِّكُم ۖ فَمَن شاءَ فَليُؤمِن وَمَن شاءَ فَليَكفُر ۚ إِنّا أَعتَدنا لِلظّالِمينَ نارًا أَحاطَ بِهِم سُرادِقُها ۚ وَإِن يَستَغيثوا يُغاثوا بِماءٍ كَالمُهلِ يَشوِي الوُجوهَ ۚ بِئسَ الشَّرابُ وَساءَت مُرتَفَقًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmclxx{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ إِنّا لا نُضيعُ أَجرَ مَن أَحسَنَ عَمَلًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmclxxi{أُولٰئِكَ لَهُم جَنّاتُ عَدنٍ تَجري مِن تَحتِهِمُ الأَنهارُ يُحَلَّونَ فيها مِن أَساوِرَ مِن ذَهَبٍ وَيَلبَسونَ ثِيابًا خُضرًا مِن سُندُسٍ وَإِستَبرَقٍ مُتَّكِئينَ فيها عَلَى الأَرائِكِ ۚ نِعمَ الثَّوابُ وَحَسُنَت مُرتَفَقًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmclxxii{۞ وَاضرِب لَهُم مَثَلًا رَجُلَينِ جَعَلنا لِأَحَدِهِما جَنَّتَينِ مِن أَعنابٍ وَحَفَفناهُما بِنَخلٍ وَجَعَلنا بَينَهُما زَرعًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmclxxiii{كِلتَا الجَنَّتَينِ آتَت أُكُلَها وَلَم تَظلِم مِنهُ شَيئًا ۚ وَفَجَّرنا خِلالَهُما نَهَرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmclxxiv{وَكانَ لَهُ ثَمَرٌ فَقالَ لِصاحِبِهِ وَهُوَ يُحاوِرُهُ أَنا أَكثَرُ مِنكَ مالًا وَأَعَزُّ نَفَرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmclxxv{وَدَخَلَ جَنَّتَهُ وَهُوَ ظالِمٌ لِنَفسِهِ قالَ ما أَظُنُّ أَن تَبيدَ هٰذِهِ أَبَدًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmclxxvi{وَما أَظُنُّ السّاعَةَ قائِمَةً وَلَئِن رُدِدتُ إِلىٰ رَبّي لَأَجِدَنَّ خَيرًا مِنها مُنقَلَبًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmclxxvii{قالَ لَهُ صاحِبُهُ وَهُوَ يُحاوِرُهُ أَكَفَرتَ بِالَّذي خَلَقَكَ مِن تُرابٍ ثُمَّ مِن نُطفَةٍ ثُمَّ سَوّاكَ رَجُلًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmclxxviii{لٰكِنّا هُوَ اللَّهُ رَبّي وَلا أُشرِكُ بِرَبّي أَحَدًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmclxxix{وَلَولا إِذ دَخَلتَ جَنَّتَكَ قُلتَ ما شاءَ اللَّهُ لا قُوَّةَ إِلّا بِاللَّهِ ۚ إِن تَرَنِ أَنا أَقَلَّ مِنكَ مالًا وَوَلَدًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmclxxx{فَعَسىٰ رَبّي أَن يُؤتِيَنِ خَيرًا مِن جَنَّتِكَ وَيُرسِلَ عَلَيها حُسبانًا مِنَ السَّماءِ فَتُصبِحَ صَعيدًا زَلَقًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmclxxxi{أَو يُصبِحَ ماؤُها غَورًا فَلَن تَستَطيعَ لَهُ طَلَبًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmclxxxii{وَأُحيطَ بِثَمَرِهِ فَأَصبَحَ يُقَلِّبُ كَفَّيهِ عَلىٰ ما أَنفَقَ فيها وَهِيَ خاوِيَةٌ عَلىٰ عُروشِها وَيَقولُ يا لَيتَني لَم أُشرِك بِرَبّي أَحَدًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmclxxxiii{وَلَم تَكُن لَهُ فِئَةٌ يَنصُرونَهُ مِن دونِ اللَّهِ وَما كانَ مُنتَصِرًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmclxxxiv{هُنالِكَ الوَلايَةُ لِلَّهِ الحَقِّ ۚ هُوَ خَيرٌ ثَوابًا وَخَيرٌ عُقبًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmclxxxv{وَاضرِب لَهُم مَثَلَ الحَياةِ الدُّنيا كَماءٍ أَنزَلناهُ مِنَ السَّماءِ فَاختَلَطَ بِهِ نَباتُ الأَرضِ فَأَصبَحَ هَشيمًا تَذروهُ الرِّياحُ ۗ وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ مُقتَدِرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmclxxxvi{المالُ وَالبَنونَ زينَةُ الحَياةِ الدُّنيا ۖ وَالباقِياتُ الصّالِحاتُ خَيرٌ عِندَ رَبِّكَ ثَوابًا وَخَيرٌ أَمَلًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmclxxxvii{وَيَومَ نُسَيِّرُ الجِبالَ وَتَرَى الأَرضَ بارِزَةً وَحَشَرناهُم فَلَم نُغادِر مِنهُم أَحَدًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmclxxxviii{وَعُرِضوا عَلىٰ رَبِّكَ صَفًّا لَقَد جِئتُمونا كَما خَلَقناكُم أَوَّلَ مَرَّةٍ ۚ بَل زَعَمتُم أَلَّن نَجعَلَ لَكُم مَوعِدًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmclxxxix{وَوُضِعَ الكِتابُ فَتَرَى المُجرِمينَ مُشفِقينَ مِمّا فيهِ وَيَقولونَ يا وَيلَتَنا مالِ هٰذَا الكِتابِ لا يُغادِرُ صَغيرَةً وَلا كَبيرَةً إِلّا أَحصاها ۚ وَوَجَدوا ما عَمِلوا حاضِرًا ۗ وَلا يَظلِمُ رَبُّكَ أَحَدًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcxc{وَإِذ قُلنا لِلمَلائِكَةِ اسجُدوا لِآدَمَ فَسَجَدوا إِلّا إِبليسَ كانَ مِنَ الجِنِّ فَفَسَقَ عَن أَمرِ رَبِّهِ ۗ أَفَتَتَّخِذونَهُ وَذُرِّيَّتَهُ أَولِياءَ مِن دوني وَهُم لَكُم عَدُوٌّ ۚ بِئسَ لِلظّالِمينَ بَدَلًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcxci{۞ ما أَشهَدتُهُم خَلقَ السَّماواتِ وَالأَرضِ وَلا خَلقَ أَنفُسِهِم وَما كُنتُ مُتَّخِذَ المُضِلّينَ عَضُدًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcxcii{وَيَومَ يَقولُ نادوا شُرَكائِيَ الَّذينَ زَعَمتُم فَدَعَوهُم فَلَم يَستَجيبوا لَهُم وَجَعَلنا بَينَهُم مَوبِقًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcxciii{وَرَأَى المُجرِمونَ النّارَ فَظَنّوا أَنَّهُم مُواقِعوها وَلَم يَجِدوا عَنها مَصرِفًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcxciv{وَلَقَد صَرَّفنا في هٰذَا القُرآنِ لِلنّاسِ مِن كُلِّ مَثَلٍ ۚ وَكانَ الإِنسانُ أَكثَرَ شَيءٍ جَدَلًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcxcv{وَما مَنَعَ النّاسَ أَن يُؤمِنوا إِذ جاءَهُمُ الهُدىٰ وَيَستَغفِروا رَبَّهُم إِلّا أَن تَأتِيَهُم سُنَّةُ الأَوَّلينَ أَو يَأتِيَهُمُ العَذابُ قُبُلًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcxcvi{وَما نُرسِلُ المُرسَلينَ إِلّا مُبَشِّرينَ وَمُنذِرينَ ۚ وَيُجادِلُ الَّذينَ كَفَروا بِالباطِلِ لِيُدحِضوا بِهِ الحَقَّ ۖ وَاتَّخَذوا آياتي وَما أُنذِروا هُزُوًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcxcvii{وَمَن أَظلَمُ مِمَّن ذُكِّرَ بِآياتِ رَبِّهِ فَأَعرَضَ عَنها وَنَسِيَ ما قَدَّمَت يَداهُ ۚ إِنّا جَعَلنا عَلىٰ قُلوبِهِم أَكِنَّةً أَن يَفقَهوهُ وَفي آذانِهِم وَقرًا ۖ وَإِن تَدعُهُم إِلَى الهُدىٰ فَلَن يَهتَدوا إِذًا أَبَدًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcxcviii{وَرَبُّكَ الغَفورُ ذُو الرَّحمَةِ ۖ لَو يُؤاخِذُهُم بِما كَسَبوا لَعَجَّلَ لَهُمُ العَذابَ ۚ بَل لَهُم مَوعِدٌ لَن يَجِدوا مِن دونِهِ مَوئِلًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcxcix{وَتِلكَ القُرىٰ أَهلَكناهُم لَمّا ظَلَموا وَجَعَلنا لِمَهلِكِهِم مَوعِدًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcc{وَإِذ قالَ موسىٰ لِفَتاهُ لا أَبرَحُ حَتّىٰ أَبلُغَ مَجمَعَ البَحرَينِ أَو أَمضِيَ حُقُبًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcci{فَلَمّا بَلَغا مَجمَعَ بَينِهِما نَسِيا حوتَهُما فَاتَّخَذَ سَبيلَهُ فِي البَحرِ سَرَبًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmccii{فَلَمّا جاوَزا قالَ لِفَتاهُ آتِنا غَداءَنا لَقَد لَقينا مِن سَفَرِنا هٰذا نَصَبًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcciii{قالَ أَرَأَيتَ إِذ أَوَينا إِلَى الصَّخرَةِ فَإِنّي نَسيتُ الحوتَ وَما أَنسانيهُ إِلَّا الشَّيطانُ أَن أَذكُرَهُ ۚ وَاتَّخَذَ سَبيلَهُ فِي البَحرِ عَجَبًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcciv{قالَ ذٰلِكَ ما كُنّا نَبغِ ۚ فَارتَدّا عَلىٰ آثارِهِما قَصَصًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmccv{فَوَجَدا عَبدًا مِن عِبادِنا آتَيناهُ رَحمَةً مِن عِندِنا وَعَلَّمناهُ مِن لَدُنّا عِلمًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmccvi{قالَ لَهُ موسىٰ هَل أَتَّبِعُكَ عَلىٰ أَن تُعَلِّمَنِ مِمّا عُلِّمتَ رُشدًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmccvii{قالَ إِنَّكَ لَن تَستَطيعَ مَعِيَ صَبرًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmccviii{وَكَيفَ تَصبِرُ عَلىٰ ما لَم تُحِط بِهِ خُبرًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmccix{قالَ سَتَجِدُني إِن شاءَ اللَّهُ صابِرًا وَلا أَعصي لَكَ أَمرًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmccx{قالَ فَإِنِ اتَّبَعتَني فَلا تَسأَلني عَن شَيءٍ حَتّىٰ أُحدِثَ لَكَ مِنهُ ذِكرًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmccxi{فَانطَلَقا حَتّىٰ إِذا رَكِبا فِي السَّفينَةِ خَرَقَها ۖ قالَ أَخَرَقتَها لِتُغرِقَ أَهلَها لَقَد جِئتَ شَيئًا إِمرًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmccxii{قالَ أَلَم أَقُل إِنَّكَ لَن تَستَطيعَ مَعِيَ صَبرًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmccxiii{قالَ لا تُؤاخِذني بِما نَسيتُ وَلا تُرهِقني مِن أَمري عُسرًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmccxiv{فَانطَلَقا حَتّىٰ إِذا لَقِيا غُلامًا فَقَتَلَهُ قالَ أَقَتَلتَ نَفسًا زَكِيَّةً بِغَيرِ نَفسٍ لَقَد جِئتَ شَيئًا نُكرًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmccxv{۞ قالَ أَلَم أَقُل لَكَ إِنَّكَ لَن تَستَطيعَ مَعِيَ صَبرًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmccxvi{قالَ إِن سَأَلتُكَ عَن شَيءٍ بَعدَها فَلا تُصاحِبني ۖ قَد بَلَغتَ مِن لَدُنّي عُذرًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmccxvii{فَانطَلَقا حَتّىٰ إِذا أَتَيا أَهلَ قَريَةٍ استَطعَما أَهلَها فَأَبَوا أَن يُضَيِّفوهُما فَوَجَدا فيها جِدارًا يُريدُ أَن يَنقَضَّ فَأَقامَهُ ۖ قالَ لَو شِئتَ لَاتَّخَذتَ عَلَيهِ أَجرًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmccxviii{قالَ هٰذا فِراقُ بَيني وَبَينِكَ ۚ سَأُنَبِّئُكَ بِتَأويلِ ما لَم تَستَطِع عَلَيهِ صَبرًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmccxix{أَمَّا السَّفينَةُ فَكانَت لِمَساكينَ يَعمَلونَ فِي البَحرِ فَأَرَدتُ أَن أَعيبَها وَكانَ وَراءَهُم مَلِكٌ يَأخُذُ كُلَّ سَفينَةٍ غَصبًا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmccxx{وَأَمَّا الغُلامُ فَكانَ أَبَواهُ مُؤمِنَينِ فَخَشينا أَن يُرهِقَهُما طُغيانًا وَكُفرًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmccxxi{فَأَرَدنا أَن يُبدِلَهُما رَبُّهُما خَيرًا مِنهُ زَكاةً وَأَقرَبَ رُحمًا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmccxxii{وَأَمَّا الجِدارُ فَكانَ لِغُلامَينِ يَتيمَينِ فِي المَدينَةِ وَكانَ تَحتَهُ كَنزٌ لَهُما وَكانَ أَبوهُما صالِحًا فَأَرادَ رَبُّكَ أَن يَبلُغا أَشُدَّهُما وَيَستَخرِجا كَنزَهُما رَحمَةً مِن رَبِّكَ ۚ وَما فَعَلتُهُ عَن أَمري ۚ ذٰلِكَ تَأويلُ ما لَم تَسطِع عَلَيهِ صَبرًا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmccxxiii{وَيَسأَلونَكَ عَن ذِي القَرنَينِ ۖ قُل سَأَتلو عَلَيكُم مِنهُ ذِكرًا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmccxxiv{إِنّا مَكَّنّا لَهُ فِي الأَرضِ وَآتَيناهُ مِن كُلِّ شَيءٍ سَبَبًا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmccxxv{فَأَتبَعَ سَبَبًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmccxxvi{حَتّىٰ إِذا بَلَغَ مَغرِبَ الشَّمسِ وَجَدَها تَغرُبُ في عَينٍ حَمِئَةٍ وَوَجَدَ عِندَها قَومًا ۗ قُلنا يا ذَا القَرنَينِ إِمّا أَن تُعَذِّبَ وَإِمّا أَن تَتَّخِذَ فيهِم حُسنًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmccxxvii{قالَ أَمّا مَن ظَلَمَ فَسَوفَ نُعَذِّبُهُ ثُمَّ يُرَدُّ إِلىٰ رَبِّهِ فَيُعَذِّبُهُ عَذابًا نُكرًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmccxxviii{وَأَمّا مَن آمَنَ وَعَمِلَ صالِحًا فَلَهُ جَزاءً الحُسنىٰ ۖ وَسَنَقولُ لَهُ مِن أَمرِنا يُسرًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmccxxix{ثُمَّ أَتبَعَ سَبَبًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmccxxx{حَتّىٰ إِذا بَلَغَ مَطلِعَ الشَّمسِ وَجَدَها تَطلُعُ عَلىٰ قَومٍ لَم نَجعَل لَهُم مِن دونِها سِترًا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmccxxxi{كَذٰلِكَ وَقَد أَحَطنا بِما لَدَيهِ خُبرًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmccxxxii{ثُمَّ أَتبَعَ سَبَبًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmccxxxiii{حَتّىٰ إِذا بَلَغَ بَينَ السَّدَّينِ وَجَدَ مِن دونِهِما قَومًا لا يَكادونَ يَفقَهونَ قَولًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmccxxxiv{قالوا يا ذَا القَرنَينِ إِنَّ يَأجوجَ وَمَأجوجَ مُفسِدونَ فِي الأَرضِ فَهَل نَجعَلُ لَكَ خَرجًا عَلىٰ أَن تَجعَلَ بَينَنا وَبَينَهُم سَدًّا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmccxxxv{قالَ ما مَكَّنّي فيهِ رَبّي خَيرٌ فَأَعينوني بِقُوَّةٍ أَجعَل بَينَكُم وَبَينَهُم رَدمًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmccxxxvi{آتوني زُبَرَ الحَديدِ ۖ حَتّىٰ إِذا ساوىٰ بَينَ الصَّدَفَينِ قالَ انفُخوا ۖ حَتّىٰ إِذا جَعَلَهُ نارًا قالَ آتوني أُفرِغ عَلَيهِ قِطرًا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmccxxxvii{فَمَا اسطاعوا أَن يَظهَروهُ وَمَا استَطاعوا لَهُ نَقبًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmccxxxviii{قالَ هٰذا رَحمَةٌ مِن رَبّي ۖ فَإِذا جاءَ وَعدُ رَبّي جَعَلَهُ دَكّاءَ ۖ وَكانَ وَعدُ رَبّي حَقًّا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmccxxxix{۞ وَتَرَكنا بَعضَهُم يَومَئِذٍ يَموجُ في بَعضٍ ۖ وَنُفِخَ فِي الصّورِ فَجَمَعناهُم جَمعًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmccxl{وَعَرَضنا جَهَنَّمَ يَومَئِذٍ لِلكافِرينَ عَرضًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmccxli{الَّذينَ كانَت أَعيُنُهُم في غِطاءٍ عَن ذِكري وَكانوا لا يَستَطيعونَ سَمعًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmccxlii{أَفَحَسِبَ الَّذينَ كَفَروا أَن يَتَّخِذوا عِبادي مِن دوني أَولِياءَ ۚ إِنّا أَعتَدنا جَهَنَّمَ لِلكافِرينَ نُزُلًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmccxliii{قُل هَل نُنَبِّئُكُم بِالأَخسَرينَ أَعمالًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmccxliv{الَّذينَ ضَلَّ سَعيُهُم فِي الحَياةِ الدُّنيا وَهُم يَحسَبونَ أَنَّهُم يُحسِنونَ صُنعًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmccxlv{أُولٰئِكَ الَّذينَ كَفَروا بِآياتِ رَبِّهِم وَلِقائِهِ فَحَبِطَت أَعمالُهُم فَلا نُقيمُ لَهُم يَومَ القِيامَةِ وَزنًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmccxlvi{ذٰلِكَ جَزاؤُهُم جَهَنَّمُ بِما كَفَروا وَاتَّخَذوا آياتي وَرُسُلي هُزُوًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmccxlvii{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ كانَت لَهُم جَنّاتُ الفِردَوسِ نُزُلًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmccxlviii{خالِدينَ فيها لا يَبغونَ عَنها حِوَلًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmccxlix{قُل لَو كانَ البَحرُ مِدادًا لِكَلِماتِ رَبّي لَنَفِدَ البَحرُ قَبلَ أَن تَنفَدَ كَلِماتُ رَبّي وَلَو جِئنا بِمِثلِهِ مَدَدًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmccl{قُل إِنَّما أَنا بَشَرٌ مِثلُكُم يوحىٰ إِلَيَّ أَنَّما إِلٰهُكُم إِلٰهٌ واحِدٌ ۖ فَمَن كانَ يَرجو لِقاءَ رَبِّهِ فَليَعمَل عَمَلًا صالِحًا وَلا يُشرِك بِعِبادَةِ رَبِّهِ أَحَدًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmccli{\basmalah كهيعص\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcclii{ذِكرُ رَحمَتِ رَبِّكَ عَبدَهُ زَكَرِيّا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmccliii{إِذ نادىٰ رَبَّهُ نِداءً خَفِيًّا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmccliv{قالَ رَبِّ إِنّي وَهَنَ العَظمُ مِنّي وَاشتَعَلَ الرَّأسُ شَيبًا وَلَم أَكُن بِدُعائِكَ رَبِّ شَقِيًّا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcclv{وَإِنّي خِفتُ المَوالِيَ مِن وَرائي وَكانَتِ امرَأَتي عاقِرًا فَهَب لي مِن لَدُنكَ وَلِيًّا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcclvi{يَرِثُني وَيَرِثُ مِن آلِ يَعقوبَ ۖ وَاجعَلهُ رَبِّ رَضِيًّا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcclvii{يا زَكَرِيّا إِنّا نُبَشِّرُكَ بِغُلامٍ اسمُهُ يَحيىٰ لَم نَجعَل لَهُ مِن قَبلُ سَمِيًّا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcclviii{قالَ رَبِّ أَنّىٰ يَكونُ لي غُلامٌ وَكانَتِ امرَأَتي عاقِرًا وَقَد بَلَغتُ مِنَ الكِبَرِ عِتِيًّا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcclix{قالَ كَذٰلِكَ قالَ رَبُّكَ هُوَ عَلَيَّ هَيِّنٌ وَقَد خَلَقتُكَ مِن قَبلُ وَلَم تَكُ شَيئًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcclx{قالَ رَبِّ اجعَل لي آيَةً ۚ قالَ آيَتُكَ أَلّا تُكَلِّمَ النّاسَ ثَلاثَ لَيالٍ سَوِيًّا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcclxi{فَخَرَجَ عَلىٰ قَومِهِ مِنَ المِحرابِ فَأَوحىٰ إِلَيهِم أَن سَبِّحوا بُكرَةً وَعَشِيًّا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmcclxii{يا يَحيىٰ خُذِ الكِتابَ بِقُوَّةٍ ۖ وَآتَيناهُ الحُكمَ صَبِيًّا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcclxiii{وَحَنانًا مِن لَدُنّا وَزَكاةً ۖ وَكانَ تَقِيًّا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcclxiv{وَبَرًّا بِوالِدَيهِ وَلَم يَكُن جَبّارًا عَصِيًّا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmcclxv{وَسَلامٌ عَلَيهِ يَومَ وُلِدَ وَيَومَ يَموتُ وَيَومَ يُبعَثُ حَيًّا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmcclxvi{وَاذكُر فِي الكِتابِ مَريَمَ إِذِ انتَبَذَت مِن أَهلِها مَكانًا شَرقِيًّا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmcclxvii{فَاتَّخَذَت مِن دونِهِم حِجابًا فَأَرسَلنا إِلَيها روحَنا فَتَمَثَّلَ لَها بَشَرًا سَوِيًّا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmcclxviii{قالَت إِنّي أَعوذُ بِالرَّحمٰنِ مِنكَ إِن كُنتَ تَقِيًّا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmcclxix{قالَ إِنَّما أَنا رَسولُ رَبِّكِ لِأَهَبَ لَكِ غُلامًا زَكِيًّا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmcclxx{قالَت أَنّىٰ يَكونُ لي غُلامٌ وَلَم يَمسَسني بَشَرٌ وَلَم أَكُ بَغِيًّا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmcclxxi{قالَ كَذٰلِكِ قالَ رَبُّكِ هُوَ عَلَيَّ هَيِّنٌ ۖ وَلِنَجعَلَهُ آيَةً لِلنّاسِ وَرَحمَةً مِنّا ۚ وَكانَ أَمرًا مَقضِيًّا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmcclxxii{۞ فَحَمَلَتهُ فَانتَبَذَت بِهِ مَكانًا قَصِيًّا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmcclxxiii{فَأَجاءَهَا المَخاضُ إِلىٰ جِذعِ النَّخلَةِ قالَت يا لَيتَني مِتُّ قَبلَ هٰذا وَكُنتُ نَسيًا مَنسِيًّا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmcclxxiv{فَناداها مِن تَحتِها أَلّا تَحزَني قَد جَعَلَ رَبُّكِ تَحتَكِ سَرِيًّا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmcclxxv{وَهُزّي إِلَيكِ بِجِذعِ النَّخلَةِ تُساقِط عَلَيكِ رُطَبًا جَنِيًّا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmcclxxvi{فَكُلي وَاشرَبي وَقَرّي عَينًا ۖ فَإِمّا تَرَيِنَّ مِنَ البَشَرِ أَحَدًا فَقولي إِنّي نَذَرتُ لِلرَّحمٰنِ صَومًا فَلَن أُكَلِّمَ اليَومَ إِنسِيًّا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmcclxxvii{فَأَتَت بِهِ قَومَها تَحمِلُهُ ۖ قالوا يا مَريَمُ لَقَد جِئتِ شَيئًا فَرِيًّا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmcclxxviii{يا أُختَ هارونَ ما كانَ أَبوكِ امرَأَ سَوءٍ وَما كانَت أُمُّكِ بَغِيًّا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmcclxxix{فَأَشارَت إِلَيهِ ۖ قالوا كَيفَ نُكَلِّمُ مَن كانَ فِي المَهدِ صَبِيًّا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmcclxxx{قالَ إِنّي عَبدُ اللَّهِ آتانِيَ الكِتابَ وَجَعَلَني نَبِيًّا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmcclxxxi{وَجَعَلَني مُبارَكًا أَينَ ما كُنتُ وَأَوصاني بِالصَّلاةِ وَالزَّكاةِ ما دُمتُ حَيًّا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmcclxxxii{وَبَرًّا بِوالِدَتي وَلَم يَجعَلني جَبّارًا شَقِيًّا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmcclxxxiii{وَالسَّلامُ عَلَيَّ يَومَ وُلِدتُ وَيَومَ أَموتُ وَيَومَ أُبعَثُ حَيًّا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmcclxxxiv{ذٰلِكَ عيسَى ابنُ مَريَمَ ۚ قَولَ الحَقِّ الَّذي فيهِ يَمتَرونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmcclxxxv{ما كانَ لِلَّهِ أَن يَتَّخِذَ مِن وَلَدٍ ۖ سُبحانَهُ ۚ إِذا قَضىٰ أَمرًا فَإِنَّما يَقولُ لَهُ كُن فَيَكونُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmcclxxxvi{وَإِنَّ اللَّهَ رَبّي وَرَبُّكُم فَاعبُدوهُ ۚ هٰذا صِراطٌ مُستَقيمٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmcclxxxvii{فَاختَلَفَ الأَحزابُ مِن بَينِهِم ۖ فَوَيلٌ لِلَّذينَ كَفَروا مِن مَشهَدِ يَومٍ عَظيمٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmcclxxxviii{أَسمِع بِهِم وَأَبصِر يَومَ يَأتونَنا ۖ لٰكِنِ الظّالِمونَ اليَومَ في ضَلالٍ مُبينٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmcclxxxix{وَأَنذِرهُم يَومَ الحَسرَةِ إِذ قُضِيَ الأَمرُ وَهُم في غَفلَةٍ وَهُم لا يُؤمِنونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmccxc{إِنّا نَحنُ نَرِثُ الأَرضَ وَمَن عَلَيها وَإِلَينا يُرجَعونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmccxci{وَاذكُر فِي الكِتابِ إِبراهيمَ ۚ إِنَّهُ كانَ صِدّيقًا نَبِيًّا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmccxcii{إِذ قالَ لِأَبيهِ يا أَبَتِ لِمَ تَعبُدُ ما لا يَسمَعُ وَلا يُبصِرُ وَلا يُغني عَنكَ شَيئًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmccxciii{يا أَبَتِ إِنّي قَد جاءَني مِنَ العِلمِ ما لَم يَأتِكَ فَاتَّبِعني أَهدِكَ صِراطًا سَوِيًّا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmccxciv{يا أَبَتِ لا تَعبُدِ الشَّيطانَ ۖ إِنَّ الشَّيطانَ كانَ لِلرَّحمٰنِ عَصِيًّا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmccxcv{يا أَبَتِ إِنّي أَخافُ أَن يَمَسَّكَ عَذابٌ مِنَ الرَّحمٰنِ فَتَكونَ لِلشَّيطانِ وَلِيًّا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmccxcvi{قالَ أَراغِبٌ أَنتَ عَن آلِهَتي يا إِبراهيمُ ۖ لَئِن لَم تَنتَهِ لَأَرجُمَنَّكَ ۖ وَاهجُرني مَلِيًّا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmccxcvii{قالَ سَلامٌ عَلَيكَ ۖ سَأَستَغفِرُ لَكَ رَبّي ۖ إِنَّهُ كانَ بي حَفِيًّا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmccxcviii{وَأَعتَزِلُكُم وَما تَدعونَ مِن دونِ اللَّهِ وَأَدعو رَبّي عَسىٰ أَلّا أَكونَ بِدُعاءِ رَبّي شَقِيًّا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmccxcix{فَلَمَّا اعتَزَلَهُم وَما يَعبُدونَ مِن دونِ اللَّهِ وَهَبنا لَهُ إِسحاقَ وَيَعقوبَ ۖ وَكُلًّا جَعَلنا نَبِيًّا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmccc{وَوَهَبنا لَهُم مِن رَحمَتِنا وَجَعَلنا لَهُم لِسانَ صِدقٍ عَلِيًّا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmccci{وَاذكُر فِي الكِتابِ موسىٰ ۚ إِنَّهُ كانَ مُخلَصًا وَكانَ رَسولًا نَبِيًّا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcccii{وَنادَيناهُ مِن جانِبِ الطّورِ الأَيمَنِ وَقَرَّبناهُ نَجِيًّا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmccciii{وَوَهَبنا لَهُ مِن رَحمَتِنا أَخاهُ هارونَ نَبِيًّا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmccciv{وَاذكُر فِي الكِتابِ إِسماعيلَ ۚ إِنَّهُ كانَ صادِقَ الوَعدِ وَكانَ رَسولًا نَبِيًّا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcccv{وَكانَ يَأمُرُ أَهلَهُ بِالصَّلاةِ وَالزَّكاةِ وَكانَ عِندَ رَبِّهِ مَرضِيًّا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcccvi{وَاذكُر فِي الكِتابِ إِدريسَ ۚ إِنَّهُ كانَ صِدّيقًا نَبِيًّا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcccvii{وَرَفَعناهُ مَكانًا عَلِيًّا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcccviii{أُولٰئِكَ الَّذينَ أَنعَمَ اللَّهُ عَلَيهِم مِنَ النَّبِيّينَ مِن ذُرِّيَّةِ آدَمَ وَمِمَّن حَمَلنا مَعَ نوحٍ وَمِن ذُرِّيَّةِ إِبراهيمَ وَإِسرائيلَ وَمِمَّن هَدَينا وَاجتَبَينا ۚ إِذا تُتلىٰ عَلَيهِم آياتُ الرَّحمٰنِ خَرّوا سُجَّدًا وَبُكِيًّا ۩\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcccix{۞ فَخَلَفَ مِن بَعدِهِم خَلفٌ أَضاعُوا الصَّلاةَ وَاتَّبَعُوا الشَّهَواتِ ۖ فَسَوفَ يَلقَونَ غَيًّا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcccx{إِلّا مَن تابَ وَآمَنَ وَعَمِلَ صالِحًا فَأُولٰئِكَ يَدخُلونَ الجَنَّةَ وَلا يُظلَمونَ شَيئًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcccxi{جَنّاتِ عَدنٍ الَّتي وَعَدَ الرَّحمٰنُ عِبادَهُ بِالغَيبِ ۚ إِنَّهُ كانَ وَعدُهُ مَأتِيًّا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcccxii{لا يَسمَعونَ فيها لَغوًا إِلّا سَلامًا ۖ وَلَهُم رِزقُهُم فيها بُكرَةً وَعَشِيًّا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcccxiii{تِلكَ الجَنَّةُ الَّتي نورِثُ مِن عِبادِنا مَن كانَ تَقِيًّا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcccxiv{وَما نَتَنَزَّلُ إِلّا بِأَمرِ رَبِّكَ ۖ لَهُ ما بَينَ أَيدينا وَما خَلفَنا وَما بَينَ ذٰلِكَ ۚ وَما كانَ رَبُّكَ نَسِيًّا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcccxv{رَبُّ السَّماواتِ وَالأَرضِ وَما بَينَهُما فَاعبُدهُ وَاصطَبِر لِعِبادَتِهِ ۚ هَل تَعلَمُ لَهُ سَمِيًّا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcccxvi{وَيَقولُ الإِنسانُ أَإِذا ما مِتُّ لَسَوفَ أُخرَجُ حَيًّا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcccxvii{أَوَلا يَذكُرُ الإِنسانُ أَنّا خَلَقناهُ مِن قَبلُ وَلَم يَكُ شَيئًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmcccxviii{فَوَرَبِّكَ لَنَحشُرَنَّهُم وَالشَّياطينَ ثُمَّ لَنُحضِرَنَّهُم حَولَ جَهَنَّمَ جِثِيًّا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmcccxix{ثُمَّ لَنَنزِعَنَّ مِن كُلِّ شيعَةٍ أَيُّهُم أَشَدُّ عَلَى الرَّحمٰنِ عِتِيًّا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmcccxx{ثُمَّ لَنَحنُ أَعلَمُ بِالَّذينَ هُم أَولىٰ بِها صِلِيًّا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmcccxxi{وَإِن مِنكُم إِلّا وارِدُها ۚ كانَ عَلىٰ رَبِّكَ حَتمًا مَقضِيًّا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmcccxxii{ثُمَّ نُنَجِّي الَّذينَ اتَّقَوا وَنَذَرُ الظّالِمينَ فيها جِثِيًّا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcccxxiii{وَإِذا تُتلىٰ عَلَيهِم آياتُنا بَيِّناتٍ قالَ الَّذينَ كَفَروا لِلَّذينَ آمَنوا أَيُّ الفَريقَينِ خَيرٌ مَقامًا وَأَحسَنُ نَدِيًّا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmcccxxiv{وَكَم أَهلَكنا قَبلَهُم مِن قَرنٍ هُم أَحسَنُ أَثاثًا وَرِئيًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmcccxxv{قُل مَن كانَ فِي الضَّلالَةِ فَليَمدُد لَهُ الرَّحمٰنُ مَدًّا ۚ حَتّىٰ إِذا رَأَوا ما يوعَدونَ إِمَّا العَذابَ وَإِمَّا السّاعَةَ فَسَيَعلَمونَ مَن هُوَ شَرٌّ مَكانًا وَأَضعَفُ جُندًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcccxxvi{وَيَزيدُ اللَّهُ الَّذينَ اهتَدَوا هُدًى ۗ وَالباقِياتُ الصّالِحاتُ خَيرٌ عِندَ رَبِّكَ ثَوابًا وَخَيرٌ مَرَدًّا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcccxxvii{أَفَرَأَيتَ الَّذي كَفَرَ بِآياتِنا وَقالَ لَأوتَيَنَّ مالًا وَوَلَدًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcccxxviii{أَطَّلَعَ الغَيبَ أَمِ اتَّخَذَ عِندَ الرَّحمٰنِ عَهدًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmcccxxix{كَلّا ۚ سَنَكتُبُ ما يَقولُ وَنَمُدُّ لَهُ مِنَ العَذابِ مَدًّا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmcccxxx{وَنَرِثُهُ ما يَقولُ وَيَأتينا فَردًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmcccxxxi{وَاتَّخَذوا مِن دونِ اللَّهِ آلِهَةً لِيَكونوا لَهُم عِزًّا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmcccxxxii{كَلّا ۚ سَيَكفُرونَ بِعِبادَتِهِم وَيَكونونَ عَلَيهِم ضِدًّا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmcccxxxiii{أَلَم تَرَ أَنّا أَرسَلنَا الشَّياطينَ عَلَى الكافِرينَ تَؤُزُّهُم أَزًّا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmcccxxxiv{فَلا تَعجَل عَلَيهِم ۖ إِنَّما نَعُدُّ لَهُم عَدًّا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmcccxxxv{يَومَ نَحشُرُ المُتَّقينَ إِلَى الرَّحمٰنِ وَفدًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmcccxxxvi{وَنَسوقُ المُجرِمينَ إِلىٰ جَهَنَّمَ وِردًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmcccxxxvii{لا يَملِكونَ الشَّفاعَةَ إِلّا مَنِ اتَّخَذَ عِندَ الرَّحمٰنِ عَهدًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmcccxxxviii{وَقالُوا اتَّخَذَ الرَّحمٰنُ وَلَدًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmcccxxxix{لَقَد جِئتُم شَيئًا إِدًّا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmcccxl{تَكادُ السَّماواتُ يَتَفَطَّرنَ مِنهُ وَتَنشَقُّ الأَرضُ وَتَخِرُّ الجِبالُ هَدًّا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmcccxli{أَن دَعَوا لِلرَّحمٰنِ وَلَدًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmcccxlii{وَما يَنبَغي لِلرَّحمٰنِ أَن يَتَّخِذَ وَلَدًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmcccxliii{إِن كُلُّ مَن فِي السَّماواتِ وَالأَرضِ إِلّا آتِي الرَّحمٰنِ عَبدًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmcccxliv{لَقَد أَحصاهُم وَعَدَّهُم عَدًّا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmcccxlv{وَكُلُّهُم آتيهِ يَومَ القِيامَةِ فَردًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmcccxlvi{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ سَيَجعَلُ لَهُمُ الرَّحمٰنُ وُدًّا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmcccxlvii{فَإِنَّما يَسَّرناهُ بِلِسانِكَ لِتُبَشِّرَ بِهِ المُتَّقينَ وَتُنذِرَ بِهِ قَومًا لُدًّا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmcccxlviii{وَكَم أَهلَكنا قَبلَهُم مِن قَرنٍ هَل تُحِسُّ مِنهُم مِن أَحَدٍ أَو تَسمَعُ لَهُم رِكزًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmcccxlix{\basmalah طه\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcccl{ما أَنزَلنا عَلَيكَ القُرآنَ لِتَشقىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcccli{إِلّا تَذكِرَةً لِمَن يَخشىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmccclii{تَنزيلًا مِمَّن خَلَقَ الأَرضَ وَالسَّماواتِ العُلَى\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcccliii{الرَّحمٰنُ عَلَى العَرشِ استَوىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcccliv{لَهُ ما فِي السَّماواتِ وَما فِي الأَرضِ وَما بَينَهُما وَما تَحتَ الثَّرىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmccclv{وَإِن تَجهَر بِالقَولِ فَإِنَّهُ يَعلَمُ السِّرَّ وَأَخفَى\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmccclvi{اللَّهُ لا إِلٰهَ إِلّا هُوَ ۖ لَهُ الأَسماءُ الحُسنىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmccclvii{وَهَل أَتاكَ حَديثُ موسىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmccclviii{إِذ رَأىٰ نارًا فَقالَ لِأَهلِهِ امكُثوا إِنّي آنَستُ نارًا لَعَلّي آتيكُم مِنها بِقَبَسٍ أَو أَجِدُ عَلَى النّارِ هُدًى\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmccclix{فَلَمّا أَتاها نودِيَ يا موسىٰ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmccclx{إِنّي أَنا رَبُّكَ فَاخلَع نَعلَيكَ ۖ إِنَّكَ بِالوادِ المُقَدَّسِ طُوًى\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmccclxi{وَأَنَا اختَرتُكَ فَاستَمِع لِما يوحىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmccclxii{إِنَّني أَنَا اللَّهُ لا إِلٰهَ إِلّا أَنا فَاعبُدني وَأَقِمِ الصَّلاةَ لِذِكري\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmccclxiii{إِنَّ السّاعَةَ آتِيَةٌ أَكادُ أُخفيها لِتُجزىٰ كُلُّ نَفسٍ بِما تَسعىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmccclxiv{فَلا يَصُدَّنَّكَ عَنها مَن لا يُؤمِنُ بِها وَاتَّبَعَ هَواهُ فَتَردىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmccclxv{وَما تِلكَ بِيَمينِكَ يا موسىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmccclxvi{قالَ هِيَ عَصايَ أَتَوَكَّأُ عَلَيها وَأَهُشُّ بِها عَلىٰ غَنَمي وَلِيَ فيها مَآرِبُ أُخرىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmccclxvii{قالَ أَلقِها يا موسىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmccclxviii{فَأَلقاها فَإِذا هِيَ حَيَّةٌ تَسعىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmccclxix{قالَ خُذها وَلا تَخَف ۖ سَنُعيدُها سيرَتَهَا الأولىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmccclxx{وَاضمُم يَدَكَ إِلىٰ جَناحِكَ تَخرُج بَيضاءَ مِن غَيرِ سوءٍ آيَةً أُخرىٰ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmccclxxi{لِنُرِيَكَ مِن آياتِنَا الكُبرَى\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmccclxxii{اذهَب إِلىٰ فِرعَونَ إِنَّهُ طَغىٰ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmccclxxiii{قالَ رَبِّ اشرَح لي صَدري\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmccclxxiv{وَيَسِّر لي أَمري\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmccclxxv{وَاحلُل عُقدَةً مِن لِساني\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmccclxxvi{يَفقَهوا قَولي\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmccclxxvii{وَاجعَل لي وَزيرًا مِن أَهلي\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmccclxxviii{هارونَ أَخِي\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmccclxxix{اشدُد بِهِ أَزري\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmccclxxx{وَأَشرِكهُ في أَمري\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmccclxxxi{كَي نُسَبِّحَكَ كَثيرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmccclxxxii{وَنَذكُرَكَ كَثيرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmccclxxxiii{إِنَّكَ كُنتَ بِنا بَصيرًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmccclxxxiv{قالَ قَد أوتيتَ سُؤلَكَ يا موسىٰ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmccclxxxv{وَلَقَد مَنَنّا عَلَيكَ مَرَّةً أُخرىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmccclxxxvi{إِذ أَوحَينا إِلىٰ أُمِّكَ ما يوحىٰ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmccclxxxvii{أَنِ اقذِفيهِ فِي التّابوتِ فَاقذِفيهِ فِي اليَمِّ فَليُلقِهِ اليَمُّ بِالسّاحِلِ يَأخُذهُ عَدُوٌّ لي وَعَدُوٌّ لَهُ ۚ وَأَلقَيتُ عَلَيكَ مَحَبَّةً مِنّي وَلِتُصنَعَ عَلىٰ عَيني\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmccclxxxviii{إِذ تَمشي أُختُكَ فَتَقولُ هَل أَدُلُّكُم عَلىٰ مَن يَكفُلُهُ ۖ فَرَجَعناكَ إِلىٰ أُمِّكَ كَي تَقَرَّ عَينُها وَلا تَحزَنَ ۚ وَقَتَلتَ نَفسًا فَنَجَّيناكَ مِنَ الغَمِّ وَفَتَنّاكَ فُتونًا ۚ فَلَبِثتَ سِنينَ في أَهلِ مَديَنَ ثُمَّ جِئتَ عَلىٰ قَدَرٍ يا موسىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmccclxxxix{وَاصطَنَعتُكَ لِنَفسِي\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmcccxc{اذهَب أَنتَ وَأَخوكَ بِآياتي وَلا تَنِيا في ذِكرِي\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmcccxci{اذهَبا إِلىٰ فِرعَونَ إِنَّهُ طَغىٰ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmcccxcii{فَقولا لَهُ قَولًا لَيِّنًا لَعَلَّهُ يَتَذَكَّرُ أَو يَخشىٰ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmcccxciii{قالا رَبَّنا إِنَّنا نَخافُ أَن يَفرُطَ عَلَينا أَو أَن يَطغىٰ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmcccxciv{قالَ لا تَخافا ۖ إِنَّني مَعَكُما أَسمَعُ وَأَرىٰ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmcccxcv{فَأتِياهُ فَقولا إِنّا رَسولا رَبِّكَ فَأَرسِل مَعَنا بَني إِسرائيلَ وَلا تُعَذِّبهُم ۖ قَد جِئناكَ بِآيَةٍ مِن رَبِّكَ ۖ وَالسَّلامُ عَلىٰ مَنِ اتَّبَعَ الهُدىٰ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmcccxcvi{إِنّا قَد أوحِيَ إِلَينا أَنَّ العَذابَ عَلىٰ مَن كَذَّبَ وَتَوَلّىٰ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmcccxcvii{قالَ فَمَن رَبُّكُما يا موسىٰ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcccxcviii{قالَ رَبُّنَا الَّذي أَعطىٰ كُلَّ شَيءٍ خَلقَهُ ثُمَّ هَدىٰ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcccxcix{قالَ فَما بالُ القُرونِ الأولىٰ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcd{قالَ عِلمُها عِندَ رَبّي في كِتابٍ ۖ لا يَضِلُّ رَبّي وَلا يَنسَى\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcdi{الَّذي جَعَلَ لَكُمُ الأَرضَ مَهدًا وَسَلَكَ لَكُم فيها سُبُلًا وَأَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجنا بِهِ أَزواجًا مِن نَباتٍ شَتّىٰ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcdii{كُلوا وَارعَوا أَنعامَكُم ۗ إِنَّ في ذٰلِكَ لَآياتٍ لِأُولِي النُّهىٰ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcdiii{۞ مِنها خَلَقناكُم وَفيها نُعيدُكُم وَمِنها نُخرِجُكُم تارَةً أُخرىٰ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcdiv{وَلَقَد أَرَيناهُ آياتِنا كُلَّها فَكَذَّبَ وَأَبىٰ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcdv{قالَ أَجِئتَنا لِتُخرِجَنا مِن أَرضِنا بِسِحرِكَ يا موسىٰ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcdvi{فَلَنَأتِيَنَّكَ بِسِحرٍ مِثلِهِ فَاجعَل بَينَنا وَبَينَكَ مَوعِدًا لا نُخلِفُهُ نَحنُ وَلا أَنتَ مَكانًا سُوًى\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcdvii{قالَ مَوعِدُكُم يَومُ الزّينَةِ وَأَن يُحشَرَ النّاسُ ضُحًى\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcdviii{فَتَوَلّىٰ فِرعَونُ فَجَمَعَ كَيدَهُ ثُمَّ أَتىٰ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcdix{قالَ لَهُم موسىٰ وَيلَكُم لا تَفتَروا عَلَى اللَّهِ كَذِبًا فَيُسحِتَكُم بِعَذابٍ ۖ وَقَد خابَ مَنِ افتَرىٰ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcdx{فَتَنازَعوا أَمرَهُم بَينَهُم وَأَسَرُّوا النَّجوىٰ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcdxi{قالوا إِن هٰذانِ لَساحِرانِ يُريدانِ أَن يُخرِجاكُم مِن أَرضِكُم بِسِحرِهِما وَيَذهَبا بِطَريقَتِكُمُ المُثلىٰ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcdxii{فَأَجمِعوا كَيدَكُم ثُمَّ ائتوا صَفًّا ۚ وَقَد أَفلَحَ اليَومَ مَنِ استَعلىٰ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcdxiii{قالوا يا موسىٰ إِمّا أَن تُلقِيَ وَإِمّا أَن نَكونَ أَوَّلَ مَن أَلقىٰ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcdxiv{قالَ بَل أَلقوا ۖ فَإِذا حِبالُهُم وَعِصِيُّهُم يُخَيَّلُ إِلَيهِ مِن سِحرِهِم أَنَّها تَسعىٰ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcdxv{فَأَوجَسَ في نَفسِهِ خيفَةً موسىٰ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmcdxvi{قُلنا لا تَخَف إِنَّكَ أَنتَ الأَعلىٰ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmcdxvii{وَأَلقِ ما في يَمينِكَ تَلقَف ما صَنَعوا ۖ إِنَّما صَنَعوا كَيدُ ساحِرٍ ۖ وَلا يُفلِحُ السّاحِرُ حَيثُ أَتىٰ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmcdxviii{فَأُلقِيَ السَّحَرَةُ سُجَّدًا قالوا آمَنّا بِرَبِّ هارونَ وَموسىٰ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmcdxix{قالَ آمَنتُم لَهُ قَبلَ أَن آذَنَ لَكُم ۖ إِنَّهُ لَكَبيرُكُمُ الَّذي عَلَّمَكُمُ السِّحرَ ۖ فَلَأُقَطِّعَنَّ أَيدِيَكُم وَأَرجُلَكُم مِن خِلافٍ وَلَأُصَلِّبَنَّكُم في جُذوعِ النَّخلِ وَلَتَعلَمُنَّ أَيُّنا أَشَدُّ عَذابًا وَأَبقىٰ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmcdxx{قالوا لَن نُؤثِرَكَ عَلىٰ ما جاءَنا مِنَ البَيِّناتِ وَالَّذي فَطَرَنا ۖ فَاقضِ ما أَنتَ قاضٍ ۖ إِنَّما تَقضي هٰذِهِ الحَياةَ الدُّنيا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcdxxi{إِنّا آمَنّا بِرَبِّنا لِيَغفِرَ لَنا خَطايانا وَما أَكرَهتَنا عَلَيهِ مِنَ السِّحرِ ۗ وَاللَّهُ خَيرٌ وَأَبقىٰ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmcdxxii{إِنَّهُ مَن يَأتِ رَبَّهُ مُجرِمًا فَإِنَّ لَهُ جَهَنَّمَ لا يَموتُ فيها وَلا يَحيىٰ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmcdxxiii{وَمَن يَأتِهِ مُؤمِنًا قَد عَمِلَ الصّالِحاتِ فَأُولٰئِكَ لَهُمُ الدَّرَجاتُ العُلىٰ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcdxxiv{جَنّاتُ عَدنٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها ۚ وَذٰلِكَ جَزاءُ مَن تَزَكّىٰ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcdxxv{وَلَقَد أَوحَينا إِلىٰ موسىٰ أَن أَسرِ بِعِبادي فَاضرِب لَهُم طَريقًا فِي البَحرِ يَبَسًا لا تَخافُ دَرَكًا وَلا تَخشىٰ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcdxxvi{فَأَتبَعَهُم فِرعَونُ بِجُنودِهِ فَغَشِيَهُم مِنَ اليَمِّ ما غَشِيَهُم\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmcdxxvii{وَأَضَلَّ فِرعَونُ قَومَهُ وَما هَدىٰ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmcdxxviii{يا بَني إِسرائيلَ قَد أَنجَيناكُم مِن عَدُوِّكُم وَواعَدناكُم جانِبَ الطّورِ الأَيمَنَ وَنَزَّلنا عَلَيكُمُ المَنَّ وَالسَّلوىٰ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmcdxxix{كُلوا مِن طَيِّباتِ ما رَزَقناكُم وَلا تَطغَوا فيهِ فَيَحِلَّ عَلَيكُم غَضَبي ۖ وَمَن يَحلِل عَلَيهِ غَضَبي فَقَد هَوىٰ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmcdxxx{وَإِنّي لَغَفّارٌ لِمَن تابَ وَآمَنَ وَعَمِلَ صالِحًا ثُمَّ اهتَدىٰ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmcdxxxi{۞ وَما أَعجَلَكَ عَن قَومِكَ يا موسىٰ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmcdxxxii{قالَ هُم أُولاءِ عَلىٰ أَثَري وَعَجِلتُ إِلَيكَ رَبِّ لِتَرضىٰ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmcdxxxiii{قالَ فَإِنّا قَد فَتَنّا قَومَكَ مِن بَعدِكَ وَأَضَلَّهُمُ السّامِرِيُّ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmcdxxxiv{فَرَجَعَ موسىٰ إِلىٰ قَومِهِ غَضبانَ أَسِفًا ۚ قالَ يا قَومِ أَلَم يَعِدكُم رَبُّكُم وَعدًا حَسَنًا ۚ أَفَطالَ عَلَيكُمُ العَهدُ أَم أَرَدتُم أَن يَحِلَّ عَلَيكُم غَضَبٌ مِن رَبِّكُم فَأَخلَفتُم مَوعِدي\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmcdxxxv{قالوا ما أَخلَفنا مَوعِدَكَ بِمَلكِنا وَلٰكِنّا حُمِّلنا أَوزارًا مِن زينَةِ القَومِ فَقَذَفناها فَكَذٰلِكَ أَلقَى السّامِرِيُّ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmcdxxxvi{فَأَخرَجَ لَهُم عِجلًا جَسَدًا لَهُ خُوارٌ فَقالوا هٰذا إِلٰهُكُم وَإِلٰهُ موسىٰ فَنَسِيَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmcdxxxvii{أَفَلا يَرَونَ أَلّا يَرجِعُ إِلَيهِم قَولًا وَلا يَملِكُ لَهُم ضَرًّا وَلا نَفعًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmcdxxxviii{وَلَقَد قالَ لَهُم هارونُ مِن قَبلُ يا قَومِ إِنَّما فُتِنتُم بِهِ ۖ وَإِنَّ رَبَّكُمُ الرَّحمٰنُ فَاتَّبِعوني وَأَطيعوا أَمري\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmcdxxxix{قالوا لَن نَبرَحَ عَلَيهِ عاكِفينَ حَتّىٰ يَرجِعَ إِلَينا موسىٰ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmcdxl{قالَ يا هارونُ ما مَنَعَكَ إِذ رَأَيتَهُم ضَلّوا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmcdxli{أَلّا تَتَّبِعَنِ ۖ أَفَعَصَيتَ أَمري\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmcdxlii{قالَ يَا ابنَ أُمَّ لا تَأخُذ بِلِحيَتي وَلا بِرَأسي ۖ إِنّي خَشيتُ أَن تَقولَ فَرَّقتَ بَينَ بَني إِسرائيلَ وَلَم تَرقُب قَولي\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmcdxliii{قالَ فَما خَطبُكَ يا سامِرِيُّ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmcdxliv{قالَ بَصُرتُ بِما لَم يَبصُروا بِهِ فَقَبَضتُ قَبضَةً مِن أَثَرِ الرَّسولِ فَنَبَذتُها وَكَذٰلِكَ سَوَّلَت لي نَفسي\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmcdxlv{قالَ فَاذهَب فَإِنَّ لَكَ فِي الحَياةِ أَن تَقولَ لا مِساسَ ۖ وَإِنَّ لَكَ مَوعِدًا لَن تُخلَفَهُ ۖ وَانظُر إِلىٰ إِلٰهِكَ الَّذي ظَلتَ عَلَيهِ عاكِفًا ۖ لَنُحَرِّقَنَّهُ ثُمَّ لَنَنسِفَنَّهُ فِي اليَمِّ نَسفًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmcdxlvi{إِنَّما إِلٰهُكُمُ اللَّهُ الَّذي لا إِلٰهَ إِلّا هُوَ ۚ وَسِعَ كُلَّ شَيءٍ عِلمًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmcdxlvii{كَذٰلِكَ نَقُصُّ عَلَيكَ مِن أَنباءِ ما قَد سَبَقَ ۚ وَقَد آتَيناكَ مِن لَدُنّا ذِكرًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmcdxlviii{مَن أَعرَضَ عَنهُ فَإِنَّهُ يَحمِلُ يَومَ القِيامَةِ وِزرًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmcdxlix{خالِدينَ فيهِ ۖ وَساءَ لَهُم يَومَ القِيامَةِ حِملًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmcdl{يَومَ يُنفَخُ فِي الصّورِ ۚ وَنَحشُرُ المُجرِمينَ يَومَئِذٍ زُرقًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmcdli{يَتَخافَتونَ بَينَهُم إِن لَبِثتُم إِلّا عَشرًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmcdlii{نَحنُ أَعلَمُ بِما يَقولونَ إِذ يَقولُ أَمثَلُهُم طَريقَةً إِن لَبِثتُم إِلّا يَومًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmcdliii{وَيَسأَلونَكَ عَنِ الجِبالِ فَقُل يَنسِفُها رَبّي نَسفًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmcdliv{فَيَذَرُها قاعًا صَفصَفًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmcdlv{لا تَرىٰ فيها عِوَجًا وَلا أَمتًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmcdlvi{يَومَئِذٍ يَتَّبِعونَ الدّاعِيَ لا عِوَجَ لَهُ ۖ وَخَشَعَتِ الأَصواتُ لِلرَّحمٰنِ فَلا تَسمَعُ إِلّا هَمسًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmcdlvii{يَومَئِذٍ لا تَنفَعُ الشَّفاعَةُ إِلّا مَن أَذِنَ لَهُ الرَّحمٰنُ وَرَضِيَ لَهُ قَولًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmcdlviii{يَعلَمُ ما بَينَ أَيديهِم وَما خَلفَهُم وَلا يُحيطونَ بِهِ عِلمًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmcdlix{۞ وَعَنَتِ الوُجوهُ لِلحَيِّ القَيّومِ ۖ وَقَد خابَ مَن حَمَلَ ظُلمًا\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmcdlx{وَمَن يَعمَل مِنَ الصّالِحاتِ وَهُوَ مُؤمِنٌ فَلا يَخافُ ظُلمًا وَلا هَضمًا\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmcdlxi{وَكَذٰلِكَ أَنزَلناهُ قُرآنًا عَرَبِيًّا وَصَرَّفنا فيهِ مِنَ الوَعيدِ لَعَلَّهُم يَتَّقونَ أَو يُحدِثُ لَهُم ذِكرًا\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmcdlxii{فَتَعالَى اللَّهُ المَلِكُ الحَقُّ ۗ وَلا تَعجَل بِالقُرآنِ مِن قَبلِ أَن يُقضىٰ إِلَيكَ وَحيُهُ ۖ وَقُل رَبِّ زِدني عِلمًا\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmcdlxiii{وَلَقَد عَهِدنا إِلىٰ آدَمَ مِن قَبلُ فَنَسِيَ وَلَم نَجِد لَهُ عَزمًا\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmcdlxiv{وَإِذ قُلنا لِلمَلائِكَةِ اسجُدوا لِآدَمَ فَسَجَدوا إِلّا إِبليسَ أَبىٰ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmcdlxv{فَقُلنا يا آدَمُ إِنَّ هٰذا عَدُوٌّ لَكَ وَلِزَوجِكَ فَلا يُخرِجَنَّكُما مِنَ الجَنَّةِ فَتَشقىٰ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmcdlxvi{إِنَّ لَكَ أَلّا تَجوعَ فيها وَلا تَعرىٰ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmcdlxvii{وَأَنَّكَ لا تَظمَأُ فيها وَلا تَضحىٰ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmcdlxviii{فَوَسوَسَ إِلَيهِ الشَّيطانُ قالَ يا آدَمُ هَل أَدُلُّكَ عَلىٰ شَجَرَةِ الخُلدِ وَمُلكٍ لا يَبلىٰ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmcdlxix{فَأَكَلا مِنها فَبَدَت لَهُما سَوآتُهُما وَطَفِقا يَخصِفانِ عَلَيهِما مِن وَرَقِ الجَنَّةِ ۚ وَعَصىٰ آدَمُ رَبَّهُ فَغَوىٰ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmcdlxx{ثُمَّ اجتَباهُ رَبُّهُ فَتابَ عَلَيهِ وَهَدىٰ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmcdlxxi{قالَ اهبِطا مِنها جَميعًا ۖ بَعضُكُم لِبَعضٍ عَدُوٌّ ۖ فَإِمّا يَأتِيَنَّكُم مِنّي هُدًى فَمَنِ اتَّبَعَ هُدايَ فَلا يَضِلُّ وَلا يَشقىٰ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmcdlxxii{وَمَن أَعرَضَ عَن ذِكري فَإِنَّ لَهُ مَعيشَةً ضَنكًا وَنَحشُرُهُ يَومَ القِيامَةِ أَعمىٰ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmcdlxxiii{قالَ رَبِّ لِمَ حَشَرتَني أَعمىٰ وَقَد كُنتُ بَصيرًا\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmcdlxxiv{قالَ كَذٰلِكَ أَتَتكَ آياتُنا فَنَسيتَها ۖ وَكَذٰلِكَ اليَومَ تُنسىٰ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmcdlxxv{وَكَذٰلِكَ نَجزي مَن أَسرَفَ وَلَم يُؤمِن بِآياتِ رَبِّهِ ۚ وَلَعَذابُ الآخِرَةِ أَشَدُّ وَأَبقىٰ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmcdlxxvi{أَفَلَم يَهدِ لَهُم كَم أَهلَكنا قَبلَهُم مِنَ القُرونِ يَمشونَ في مَساكِنِهِم ۗ إِنَّ في ذٰلِكَ لَآياتٍ لِأُولِي النُّهىٰ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmcdlxxvii{وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ لَكانَ لِزامًا وَأَجَلٌ مُسَمًّى\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mmcdlxxviii{فَاصبِر عَلىٰ ما يَقولونَ وَسَبِّح بِحَمدِ رَبِّكَ قَبلَ طُلوعِ الشَّمسِ وَقَبلَ غُروبِها ۖ وَمِن آناءِ اللَّيلِ فَسَبِّح وَأَطرافَ النَّهارِ لَعَلَّكَ تَرضىٰ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mmcdlxxix{وَلا تَمُدَّنَّ عَينَيكَ إِلىٰ ما مَتَّعنا بِهِ أَزواجًا مِنهُم زَهرَةَ الحَياةِ الدُّنيا لِنَفتِنَهُم فيهِ ۚ وَرِزقُ رَبِّكَ خَيرٌ وَأَبقىٰ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mmcdlxxx{وَأمُر أَهلَكَ بِالصَّلاةِ وَاصطَبِر عَلَيها ۖ لا نَسأَلُكَ رِزقًا ۖ نَحنُ نَرزُقُكَ ۗ وَالعاقِبَةُ لِلتَّقوىٰ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mmcdlxxxi{وَقالوا لَولا يَأتينا بِآيَةٍ مِن رَبِّهِ ۚ أَوَلَم تَأتِهِم بَيِّنَةُ ما فِي الصُّحُفِ الأولىٰ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mmcdlxxxii{وَلَو أَنّا أَهلَكناهُم بِعَذابٍ مِن قَبلِهِ لَقالوا رَبَّنا لَولا أَرسَلتَ إِلَينا رَسولًا فَنَتَّبِعَ آياتِكَ مِن قَبلِ أَن نَذِلَّ وَنَخزىٰ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mmcdlxxxiii{قُل كُلٌّ مُتَرَبِّصٌ فَتَرَبَّصوا ۖ فَسَتَعلَمونَ مَن أَصحابُ الصِّراطِ السَّوِيِّ وَمَنِ اهتَدىٰ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mmcdlxxxiv{\basmalah اقتَرَبَ لِلنّاسِ حِسابُهُم وَهُم في غَفلَةٍ مُعرِضونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcdlxxxv{ما يَأتيهِم مِن ذِكرٍ مِن رَبِّهِم مُحدَثٍ إِلَّا استَمَعوهُ وَهُم يَلعَبونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcdlxxxvi{لاهِيَةً قُلوبُهُم ۗ وَأَسَرُّوا النَّجوَى الَّذينَ ظَلَموا هَل هٰذا إِلّا بَشَرٌ مِثلُكُم ۖ أَفَتَأتونَ السِّحرَ وَأَنتُم تُبصِرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmcdlxxxvii{قالَ رَبّي يَعلَمُ القَولَ فِي السَّماءِ وَالأَرضِ ۖ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcdlxxxviii{بَل قالوا أَضغاثُ أَحلامٍ بَلِ افتَراهُ بَل هُوَ شاعِرٌ فَليَأتِنا بِآيَةٍ كَما أُرسِلَ الأَوَّلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcdlxxxix{ما آمَنَت قَبلَهُم مِن قَريَةٍ أَهلَكناها ۖ أَفَهُم يُؤمِنونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcdxc{وَما أَرسَلنا قَبلَكَ إِلّا رِجالًا نوحي إِلَيهِم ۖ فَاسأَلوا أَهلَ الذِّكرِ إِن كُنتُم لا تَعلَمونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcdxci{وَما جَعَلناهُم جَسَدًا لا يَأكُلونَ الطَّعامَ وَما كانوا خالِدينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcdxcii{ثُمَّ صَدَقناهُمُ الوَعدَ فَأَنجَيناهُم وَمَن نَشاءُ وَأَهلَكنَا المُسرِفينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcdxciii{لَقَد أَنزَلنا إِلَيكُم كِتابًا فيهِ ذِكرُكُم ۖ أَفَلا تَعقِلونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcdxciv{وَكَم قَصَمنا مِن قَريَةٍ كانَت ظالِمَةً وَأَنشَأنا بَعدَها قَومًا آخَرينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmcdxcv{فَلَمّا أَحَسّوا بَأسَنا إِذا هُم مِنها يَركُضونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcdxcvi{لا تَركُضوا وَارجِعوا إِلىٰ ما أُترِفتُم فيهِ وَمَساكِنِكُم لَعَلَّكُم تُسأَلونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcdxcvii{قالوا يا وَيلَنا إِنّا كُنّا ظالِمينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmcdxcviii{فَما زالَت تِلكَ دَعواهُم حَتّىٰ جَعَلناهُم حَصيدًا خامِدينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmcdxcix{وَما خَلَقنَا السَّماءَ وَالأَرضَ وَما بَينَهُما لاعِبينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmd{لَو أَرَدنا أَن نَتَّخِذَ لَهوًا لَاتَّخَذناهُ مِن لَدُنّا إِن كُنّا فاعِلينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdi{بَل نَقذِفُ بِالحَقِّ عَلَى الباطِلِ فَيَدمَغُهُ فَإِذا هُوَ زاهِقٌ ۚ وَلَكُمُ الوَيلُ مِمّا تَصِفونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdii{وَلَهُ مَن فِي السَّماواتِ وَالأَرضِ ۚ وَمَن عِندَهُ لا يَستَكبِرونَ عَن عِبادَتِهِ وَلا يَستَحسِرونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdiii{يُسَبِّحونَ اللَّيلَ وَالنَّهارَ لا يَفتُرونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdiv{أَمِ اتَّخَذوا آلِهَةً مِنَ الأَرضِ هُم يُنشِرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdv{لَو كانَ فيهِما آلِهَةٌ إِلَّا اللَّهُ لَفَسَدَتا ۚ فَسُبحانَ اللَّهِ رَبِّ العَرشِ عَمّا يَصِفونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdvi{لا يُسأَلُ عَمّا يَفعَلُ وَهُم يُسأَلونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdvii{أَمِ اتَّخَذوا مِن دونِهِ آلِهَةً ۖ قُل هاتوا بُرهانَكُم ۖ هٰذا ذِكرُ مَن مَعِيَ وَذِكرُ مَن قَبلي ۗ بَل أَكثَرُهُم لا يَعلَمونَ الحَقَّ ۖ فَهُم مُعرِضونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdviii{وَما أَرسَلنا مِن قَبلِكَ مِن رَسولٍ إِلّا نوحي إِلَيهِ أَنَّهُ لا إِلٰهَ إِلّا أَنا فَاعبُدونِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdix{وَقالُوا اتَّخَذَ الرَّحمٰنُ وَلَدًا ۗ سُبحانَهُ ۚ بَل عِبادٌ مُكرَمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdx{لا يَسبِقونَهُ بِالقَولِ وَهُم بِأَمرِهِ يَعمَلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdxi{يَعلَمُ ما بَينَ أَيديهِم وَما خَلفَهُم وَلا يَشفَعونَ إِلّا لِمَنِ ارتَضىٰ وَهُم مِن خَشيَتِهِ مُشفِقونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdxii{۞ وَمَن يَقُل مِنهُم إِنّي إِلٰهٌ مِن دونِهِ فَذٰلِكَ نَجزيهِ جَهَنَّمَ ۚ كَذٰلِكَ نَجزِي الظّالِمينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdxiii{أَوَلَم يَرَ الَّذينَ كَفَروا أَنَّ السَّماواتِ وَالأَرضَ كانَتا رَتقًا فَفَتَقناهُما ۖ وَجَعَلنا مِنَ الماءِ كُلَّ شَيءٍ حَيٍّ ۖ أَفَلا يُؤمِنونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdxiv{وَجَعَلنا فِي الأَرضِ رَواسِيَ أَن تَميدَ بِهِم وَجَعَلنا فيها فِجاجًا سُبُلًا لَعَلَّهُم يَهتَدونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdxv{وَجَعَلنَا السَّماءَ سَقفًا مَحفوظًا ۖ وَهُم عَن آياتِها مُعرِضونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdxvi{وَهُوَ الَّذي خَلَقَ اللَّيلَ وَالنَّهارَ وَالشَّمسَ وَالقَمَرَ ۖ كُلٌّ في فَلَكٍ يَسبَحونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdxvii{وَما جَعَلنا لِبَشَرٍ مِن قَبلِكَ الخُلدَ ۖ أَفَإِن مِتَّ فَهُمُ الخالِدونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdxviii{كُلُّ نَفسٍ ذائِقَةُ المَوتِ ۗ وَنَبلوكُم بِالشَّرِّ وَالخَيرِ فِتنَةً ۖ وَإِلَينا تُرجَعونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdxix{وَإِذا رَآكَ الَّذينَ كَفَروا إِن يَتَّخِذونَكَ إِلّا هُزُوًا أَهٰذَا الَّذي يَذكُرُ آلِهَتَكُم وَهُم بِذِكرِ الرَّحمٰنِ هُم كافِرونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdxx{خُلِقَ الإِنسانُ مِن عَجَلٍ ۚ سَأُريكُم آياتي فَلا تَستَعجِلونِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdxxi{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صادِقينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdxxii{لَو يَعلَمُ الَّذينَ كَفَروا حينَ لا يَكُفّونَ عَن وُجوهِهِمُ النّارَ وَلا عَن ظُهورِهِم وَلا هُم يُنصَرونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdxxiii{بَل تَأتيهِم بَغتَةً فَتَبهَتُهُم فَلا يَستَطيعونَ رَدَّها وَلا هُم يُنظَرونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdxxiv{وَلَقَدِ استُهزِئَ بِرُسُلٍ مِن قَبلِكَ فَحاقَ بِالَّذينَ سَخِروا مِنهُم ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdxxv{قُل مَن يَكلَؤُكُم بِاللَّيلِ وَالنَّهارِ مِنَ الرَّحمٰنِ ۗ بَل هُم عَن ذِكرِ رَبِّهِم مُعرِضونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdxxvi{أَم لَهُم آلِهَةٌ تَمنَعُهُم مِن دونِنا ۚ لا يَستَطيعونَ نَصرَ أَنفُسِهِم وَلا هُم مِنّا يُصحَبونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdxxvii{بَل مَتَّعنا هٰؤُلاءِ وَآباءَهُم حَتّىٰ طالَ عَلَيهِمُ العُمُرُ ۗ أَفَلا يَرَونَ أَنّا نَأتِي الأَرضَ نَنقُصُها مِن أَطرافِها ۚ أَفَهُمُ الغالِبونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdxxviii{قُل إِنَّما أُنذِرُكُم بِالوَحيِ ۚ وَلا يَسمَعُ الصُّمُّ الدُّعاءَ إِذا ما يُنذَرونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdxxix{وَلَئِن مَسَّتهُم نَفحَةٌ مِن عَذابِ رَبِّكَ لَيَقولُنَّ يا وَيلَنا إِنّا كُنّا ظالِمينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdxxx{وَنَضَعُ المَوازينَ القِسطَ لِيَومِ القِيامَةِ فَلا تُظلَمُ نَفسٌ شَيئًا ۖ وَإِن كانَ مِثقالَ حَبَّةٍ مِن خَردَلٍ أَتَينا بِها ۗ وَكَفىٰ بِنا حاسِبينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdxxxi{وَلَقَد آتَينا موسىٰ وَهارونَ الفُرقانَ وَضِياءً وَذِكرًا لِلمُتَّقينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdxxxii{الَّذينَ يَخشَونَ رَبَّهُم بِالغَيبِ وَهُم مِنَ السّاعَةِ مُشفِقونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdxxxiii{وَهٰذا ذِكرٌ مُبارَكٌ أَنزَلناهُ ۚ أَفَأَنتُم لَهُ مُنكِرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdxxxiv{۞ وَلَقَد آتَينا إِبراهيمَ رُشدَهُ مِن قَبلُ وَكُنّا بِهِ عالِمينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdxxxv{إِذ قالَ لِأَبيهِ وَقَومِهِ ما هٰذِهِ التَّماثيلُ الَّتي أَنتُم لَها عاكِفونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdxxxvi{قالوا وَجَدنا آباءَنا لَها عابِدينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdxxxvii{قالَ لَقَد كُنتُم أَنتُم وَآباؤُكُم في ضَلالٍ مُبينٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdxxxviii{قالوا أَجِئتَنا بِالحَقِّ أَم أَنتَ مِنَ اللّاعِبينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdxxxix{قالَ بَل رَبُّكُم رَبُّ السَّماواتِ وَالأَرضِ الَّذي فَطَرَهُنَّ وَأَنا عَلىٰ ذٰلِكُم مِنَ الشّاهِدينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdxl{وَتَاللَّهِ لَأَكيدَنَّ أَصنامَكُم بَعدَ أَن تُوَلّوا مُدبِرينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdxli{فَجَعَلَهُم جُذاذًا إِلّا كَبيرًا لَهُم لَعَلَّهُم إِلَيهِ يَرجِعونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdxlii{قالوا مَن فَعَلَ هٰذا بِآلِهَتِنا إِنَّهُ لَمِنَ الظّالِمينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdxliii{قالوا سَمِعنا فَتًى يَذكُرُهُم يُقالُ لَهُ إِبراهيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdxliv{قالوا فَأتوا بِهِ عَلىٰ أَعيُنِ النّاسِ لَعَلَّهُم يَشهَدونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdxlv{قالوا أَأَنتَ فَعَلتَ هٰذا بِآلِهَتِنا يا إِبراهيمُ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdxlvi{قالَ بَل فَعَلَهُ كَبيرُهُم هٰذا فَاسأَلوهُم إِن كانوا يَنطِقونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdxlvii{فَرَجَعوا إِلىٰ أَنفُسِهِم فَقالوا إِنَّكُم أَنتُمُ الظّالِمونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdxlviii{ثُمَّ نُكِسوا عَلىٰ رُءوسِهِم لَقَد عَلِمتَ ما هٰؤُلاءِ يَنطِقونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmdxlix{قالَ أَفَتَعبُدونَ مِن دونِ اللَّهِ ما لا يَنفَعُكُم شَيئًا وَلا يَضُرُّكُم\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmdl{أُفٍّ لَكُم وَلِما تَعبُدونَ مِن دونِ اللَّهِ ۖ أَفَلا تَعقِلونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmdli{قالوا حَرِّقوهُ وَانصُروا آلِهَتَكُم إِن كُنتُم فاعِلينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmdlii{قُلنا يا نارُ كوني بَردًا وَسَلامًا عَلىٰ إِبراهيمَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmdliii{وَأَرادوا بِهِ كَيدًا فَجَعَلناهُمُ الأَخسَرينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmdliv{وَنَجَّيناهُ وَلوطًا إِلَى الأَرضِ الَّتي بارَكنا فيها لِلعالَمينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmdlv{وَوَهَبنا لَهُ إِسحاقَ وَيَعقوبَ نافِلَةً ۖ وَكُلًّا جَعَلنا صالِحينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmdlvi{وَجَعَلناهُم أَئِمَّةً يَهدونَ بِأَمرِنا وَأَوحَينا إِلَيهِم فِعلَ الخَيراتِ وَإِقامَ الصَّلاةِ وَإيتاءَ الزَّكاةِ ۖ وَكانوا لَنا عابِدينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmdlvii{وَلوطًا آتَيناهُ حُكمًا وَعِلمًا وَنَجَّيناهُ مِنَ القَريَةِ الَّتي كانَت تَعمَلُ الخَبائِثَ ۗ إِنَّهُم كانوا قَومَ سَوءٍ فاسِقينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmdlviii{وَأَدخَلناهُ في رَحمَتِنا ۖ إِنَّهُ مِنَ الصّالِحينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmdlix{وَنوحًا إِذ نادىٰ مِن قَبلُ فَاستَجَبنا لَهُ فَنَجَّيناهُ وَأَهلَهُ مِنَ الكَربِ العَظيمِ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmdlx{وَنَصَرناهُ مِنَ القَومِ الَّذينَ كَذَّبوا بِآياتِنا ۚ إِنَّهُم كانوا قَومَ سَوءٍ فَأَغرَقناهُم أَجمَعينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmdlxi{وَداوودَ وَسُلَيمانَ إِذ يَحكُمانِ فِي الحَرثِ إِذ نَفَشَت فيهِ غَنَمُ القَومِ وَكُنّا لِحُكمِهِم شاهِدينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmdlxii{فَفَهَّمناها سُلَيمانَ ۚ وَكُلًّا آتَينا حُكمًا وَعِلمًا ۚ وَسَخَّرنا مَعَ داوودَ الجِبالَ يُسَبِّحنَ وَالطَّيرَ ۚ وَكُنّا فاعِلينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmdlxiii{وَعَلَّمناهُ صَنعَةَ لَبوسٍ لَكُم لِتُحصِنَكُم مِن بَأسِكُم ۖ فَهَل أَنتُم شاكِرونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmdlxiv{وَلِسُلَيمانَ الرّيحَ عاصِفَةً تَجري بِأَمرِهِ إِلَى الأَرضِ الَّتي بارَكنا فيها ۚ وَكُنّا بِكُلِّ شَيءٍ عالِمينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmdlxv{وَمِنَ الشَّياطينِ مَن يَغوصونَ لَهُ وَيَعمَلونَ عَمَلًا دونَ ذٰلِكَ ۖ وَكُنّا لَهُم حافِظينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmdlxvi{۞ وَأَيّوبَ إِذ نادىٰ رَبَّهُ أَنّي مَسَّنِيَ الضُّرُّ وَأَنتَ أَرحَمُ الرّاحِمينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmdlxvii{فَاستَجَبنا لَهُ فَكَشَفنا ما بِهِ مِن ضُرٍّ ۖ وَآتَيناهُ أَهلَهُ وَمِثلَهُم مَعَهُم رَحمَةً مِن عِندِنا وَذِكرىٰ لِلعابِدينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmdlxviii{وَإِسماعيلَ وَإِدريسَ وَذَا الكِفلِ ۖ كُلٌّ مِنَ الصّابِرينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmdlxix{وَأَدخَلناهُم في رَحمَتِنا ۖ إِنَّهُم مِنَ الصّالِحينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmdlxx{وَذَا النّونِ إِذ ذَهَبَ مُغاضِبًا فَظَنَّ أَن لَن نَقدِرَ عَلَيهِ فَنادىٰ فِي الظُّلُماتِ أَن لا إِلٰهَ إِلّا أَنتَ سُبحانَكَ إِنّي كُنتُ مِنَ الظّالِمينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmdlxxi{فَاستَجَبنا لَهُ وَنَجَّيناهُ مِنَ الغَمِّ ۚ وَكَذٰلِكَ نُنجِي المُؤمِنينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmdlxxii{وَزَكَرِيّا إِذ نادىٰ رَبَّهُ رَبِّ لا تَذَرني فَردًا وَأَنتَ خَيرُ الوارِثينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmdlxxiii{فَاستَجَبنا لَهُ وَوَهَبنا لَهُ يَحيىٰ وَأَصلَحنا لَهُ زَوجَهُ ۚ إِنَّهُم كانوا يُسارِعونَ فِي الخَيراتِ وَيَدعونَنا رَغَبًا وَرَهَبًا ۖ وَكانوا لَنا خاشِعينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmdlxxiv{وَالَّتي أَحصَنَت فَرجَها فَنَفَخنا فيها مِن روحِنا وَجَعَلناها وَابنَها آيَةً لِلعالَمينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmdlxxv{إِنَّ هٰذِهِ أُمَّتُكُم أُمَّةً واحِدَةً وَأَنا رَبُّكُم فَاعبُدونِ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmdlxxvi{وَتَقَطَّعوا أَمرَهُم بَينَهُم ۖ كُلٌّ إِلَينا راجِعونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmdlxxvii{فَمَن يَعمَل مِنَ الصّالِحاتِ وَهُوَ مُؤمِنٌ فَلا كُفرانَ لِسَعيِهِ وَإِنّا لَهُ كاتِبونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmdlxxviii{وَحَرامٌ عَلىٰ قَريَةٍ أَهلَكناها أَنَّهُم لا يَرجِعونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmdlxxix{حَتّىٰ إِذا فُتِحَت يَأجوجُ وَمَأجوجُ وَهُم مِن كُلِّ حَدَبٍ يَنسِلونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmdlxxx{وَاقتَرَبَ الوَعدُ الحَقُّ فَإِذا هِيَ شاخِصَةٌ أَبصارُ الَّذينَ كَفَروا يا وَيلَنا قَد كُنّا في غَفلَةٍ مِن هٰذا بَل كُنّا ظالِمينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmdlxxxi{إِنَّكُم وَما تَعبُدونَ مِن دونِ اللَّهِ حَصَبُ جَهَنَّمَ أَنتُم لَها وارِدونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmdlxxxii{لَو كانَ هٰؤُلاءِ آلِهَةً ما وَرَدوها ۖ وَكُلٌّ فيها خالِدونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmdlxxxiii{لَهُم فيها زَفيرٌ وَهُم فيها لا يَسمَعونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmdlxxxiv{إِنَّ الَّذينَ سَبَقَت لَهُم مِنَّا الحُسنىٰ أُولٰئِكَ عَنها مُبعَدونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmdlxxxv{لا يَسمَعونَ حَسيسَها ۖ وَهُم في مَا اشتَهَت أَنفُسُهُم خالِدونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmdlxxxvi{لا يَحزُنُهُمُ الفَزَعُ الأَكبَرُ وَتَتَلَقّاهُمُ المَلائِكَةُ هٰذا يَومُكُمُ الَّذي كُنتُم توعَدونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmdlxxxvii{يَومَ نَطوِي السَّماءَ كَطَيِّ السِّجِلِّ لِلكُتُبِ ۚ كَما بَدَأنا أَوَّلَ خَلقٍ نُعيدُهُ ۚ وَعدًا عَلَينا ۚ إِنّا كُنّا فاعِلينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmdlxxxviii{وَلَقَد كَتَبنا فِي الزَّبورِ مِن بَعدِ الذِّكرِ أَنَّ الأَرضَ يَرِثُها عِبادِيَ الصّالِحونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmdlxxxix{إِنَّ في هٰذا لَبَلاغًا لِقَومٍ عابِدينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmdxc{وَما أَرسَلناكَ إِلّا رَحمَةً لِلعالَمينَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmdxci{قُل إِنَّما يوحىٰ إِلَيَّ أَنَّما إِلٰهُكُم إِلٰهٌ واحِدٌ ۖ فَهَل أَنتُم مُسلِمونَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmdxcii{فَإِن تَوَلَّوا فَقُل آذَنتُكُم عَلىٰ سَواءٍ ۖ وَإِن أَدري أَقَريبٌ أَم بَعيدٌ ما توعَدونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmdxciii{إِنَّهُ يَعلَمُ الجَهرَ مِنَ القَولِ وَيَعلَمُ ما تَكتُمونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmdxciv{وَإِن أَدري لَعَلَّهُ فِتنَةٌ لَكُم وَمَتاعٌ إِلىٰ حينٍ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmdxcv{قالَ رَبِّ احكُم بِالحَقِّ ۗ وَرَبُّنَا الرَّحمٰنُ المُستَعانُ عَلىٰ ما تَصِفونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmdxcvi{\basmalah يا أَيُّهَا النّاسُ اتَّقوا رَبَّكُم ۚ إِنَّ زَلزَلَةَ السّاعَةِ شَيءٌ عَظيمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdxcvii{يَومَ تَرَونَها تَذهَلُ كُلُّ مُرضِعَةٍ عَمّا أَرضَعَت وَتَضَعُ كُلُّ ذاتِ حَملٍ حَملَها وَتَرَى النّاسَ سُكارىٰ وَما هُم بِسُكارىٰ وَلٰكِنَّ عَذابَ اللَّهِ شَديدٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdxcviii{وَمِنَ النّاسِ مَن يُجادِلُ فِي اللَّهِ بِغَيرِ عِلمٍ وَيَتَّبِعُ كُلَّ شَيطانٍ مَريدٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdxcix{كُتِبَ عَلَيهِ أَنَّهُ مَن تَوَلّاهُ فَأَنَّهُ يُضِلُّهُ وَيَهديهِ إِلىٰ عَذابِ السَّعيرِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdc{يا أَيُّهَا النّاسُ إِن كُنتُم في رَيبٍ مِنَ البَعثِ فَإِنّا خَلَقناكُم مِن تُرابٍ ثُمَّ مِن نُطفَةٍ ثُمَّ مِن عَلَقَةٍ ثُمَّ مِن مُضغَةٍ مُخَلَّقَةٍ وَغَيرِ مُخَلَّقَةٍ لِنُبَيِّنَ لَكُم ۚ وَنُقِرُّ فِي الأَرحامِ ما نَشاءُ إِلىٰ أَجَلٍ مُسَمًّى ثُمَّ نُخرِجُكُم طِفلًا ثُمَّ لِتَبلُغوا أَشُدَّكُم ۖ وَمِنكُم مَن يُتَوَفّىٰ وَمِنكُم مَن يُرَدُّ إِلىٰ أَرذَلِ العُمُرِ لِكَيلا يَعلَمَ مِن بَعدِ عِلمٍ شَيئًا ۚ وَتَرَى الأَرضَ هامِدَةً فَإِذا أَنزَلنا عَلَيهَا الماءَ اهتَزَّت وَرَبَت وَأَنبَتَت مِن كُلِّ زَوجٍ بَهيجٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdci{ذٰلِكَ بِأَنَّ اللَّهَ هُوَ الحَقُّ وَأَنَّهُ يُحيِي المَوتىٰ وَأَنَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdcii{وَأَنَّ السّاعَةَ آتِيَةٌ لا رَيبَ فيها وَأَنَّ اللَّهَ يَبعَثُ مَن فِي القُبورِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdciii{وَمِنَ النّاسِ مَن يُجادِلُ فِي اللَّهِ بِغَيرِ عِلمٍ وَلا هُدًى وَلا كِتابٍ مُنيرٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdciv{ثانِيَ عِطفِهِ لِيُضِلَّ عَن سَبيلِ اللَّهِ ۖ لَهُ فِي الدُّنيا خِزيٌ ۖ وَنُذيقُهُ يَومَ القِيامَةِ عَذابَ الحَريقِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdcv{ذٰلِكَ بِما قَدَّمَت يَداكَ وَأَنَّ اللَّهَ لَيسَ بِظَلّامٍ لِلعَبيدِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdcvi{وَمِنَ النّاسِ مَن يَعبُدُ اللَّهَ عَلىٰ حَرفٍ ۖ فَإِن أَصابَهُ خَيرٌ اطمَأَنَّ بِهِ ۖ وَإِن أَصابَتهُ فِتنَةٌ انقَلَبَ عَلىٰ وَجهِهِ خَسِرَ الدُّنيا وَالآخِرَةَ ۚ ذٰلِكَ هُوَ الخُسرانُ المُبينُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdcvii{يَدعو مِن دونِ اللَّهِ ما لا يَضُرُّهُ وَما لا يَنفَعُهُ ۚ ذٰلِكَ هُوَ الضَّلالُ البَعيدُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdcviii{يَدعو لَمَن ضَرُّهُ أَقرَبُ مِن نَفعِهِ ۚ لَبِئسَ المَولىٰ وَلَبِئسَ العَشيرُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdcix{إِنَّ اللَّهَ يُدخِلُ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ ۚ إِنَّ اللَّهَ يَفعَلُ ما يُريدُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdcx{مَن كانَ يَظُنُّ أَن لَن يَنصُرَهُ اللَّهُ فِي الدُّنيا وَالآخِرَةِ فَليَمدُد بِسَبَبٍ إِلَى السَّماءِ ثُمَّ ليَقطَع فَليَنظُر هَل يُذهِبَنَّ كَيدُهُ ما يَغيظُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdcxi{وَكَذٰلِكَ أَنزَلناهُ آياتٍ بَيِّناتٍ وَأَنَّ اللَّهَ يَهدي مَن يُريدُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdcxii{إِنَّ الَّذينَ آمَنوا وَالَّذينَ هادوا وَالصّابِئينَ وَالنَّصارىٰ وَالمَجوسَ وَالَّذينَ أَشرَكوا إِنَّ اللَّهَ يَفصِلُ بَينَهُم يَومَ القِيامَةِ ۚ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdcxiii{أَلَم تَرَ أَنَّ اللَّهَ يَسجُدُ لَهُ مَن فِي السَّماواتِ وَمَن فِي الأَرضِ وَالشَّمسُ وَالقَمَرُ وَالنُّجومُ وَالجِبالُ وَالشَّجَرُ وَالدَّوابُّ وَكَثيرٌ مِنَ النّاسِ ۖ وَكَثيرٌ حَقَّ عَلَيهِ العَذابُ ۗ وَمَن يُهِنِ اللَّهُ فَما لَهُ مِن مُكرِمٍ ۚ إِنَّ اللَّهَ يَفعَلُ ما يَشاءُ ۩\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdcxiv{۞ هٰذانِ خَصمانِ اختَصَموا في رَبِّهِم ۖ فَالَّذينَ كَفَروا قُطِّعَت لَهُم ثِيابٌ مِن نارٍ يُصَبُّ مِن فَوقِ رُءوسِهِمُ الحَميمُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdcxv{يُصهَرُ بِهِ ما في بُطونِهِم وَالجُلودُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdcxvi{وَلَهُم مَقامِعُ مِن حَديدٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdcxvii{كُلَّما أَرادوا أَن يَخرُجوا مِنها مِن غَمٍّ أُعيدوا فيها وَذوقوا عَذابَ الحَريقِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdcxviii{إِنَّ اللَّهَ يُدخِلُ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ يُحَلَّونَ فيها مِن أَساوِرَ مِن ذَهَبٍ وَلُؤلُؤًا ۖ وَلِباسُهُم فيها حَريرٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdcxix{وَهُدوا إِلَى الطَّيِّبِ مِنَ القَولِ وَهُدوا إِلىٰ صِراطِ الحَميدِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdcxx{إِنَّ الَّذينَ كَفَروا وَيَصُدّونَ عَن سَبيلِ اللَّهِ وَالمَسجِدِ الحَرامِ الَّذي جَعَلناهُ لِلنّاسِ سَواءً العاكِفُ فيهِ وَالبادِ ۚ وَمَن يُرِد فيهِ بِإِلحادٍ بِظُلمٍ نُذِقهُ مِن عَذابٍ أَليمٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdcxxi{وَإِذ بَوَّأنا لِإِبراهيمَ مَكانَ البَيتِ أَن لا تُشرِك بي شَيئًا وَطَهِّر بَيتِيَ لِلطّائِفينَ وَالقائِمينَ وَالرُّكَّعِ السُّجودِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdcxxii{وَأَذِّن فِي النّاسِ بِالحَجِّ يَأتوكَ رِجالًا وَعَلىٰ كُلِّ ضامِرٍ يَأتينَ مِن كُلِّ فَجٍّ عَميقٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdcxxiii{لِيَشهَدوا مَنافِعَ لَهُم وَيَذكُرُوا اسمَ اللَّهِ في أَيّامٍ مَعلوماتٍ عَلىٰ ما رَزَقَهُم مِن بَهيمَةِ الأَنعامِ ۖ فَكُلوا مِنها وَأَطعِمُوا البائِسَ الفَقيرَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdcxxiv{ثُمَّ ليَقضوا تَفَثَهُم وَليوفوا نُذورَهُم وَليَطَّوَّفوا بِالبَيتِ العَتيقِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdcxxv{ذٰلِكَ وَمَن يُعَظِّم حُرُماتِ اللَّهِ فَهُوَ خَيرٌ لَهُ عِندَ رَبِّهِ ۗ وَأُحِلَّت لَكُمُ الأَنعامُ إِلّا ما يُتلىٰ عَلَيكُم ۖ فَاجتَنِبُوا الرِّجسَ مِنَ الأَوثانِ وَاجتَنِبوا قَولَ الزّورِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdcxxvi{حُنَفاءَ لِلَّهِ غَيرَ مُشرِكينَ بِهِ ۚ وَمَن يُشرِك بِاللَّهِ فَكَأَنَّما خَرَّ مِنَ السَّماءِ فَتَخطَفُهُ الطَّيرُ أَو تَهوي بِهِ الرّيحُ في مَكانٍ سَحيقٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdcxxvii{ذٰلِكَ وَمَن يُعَظِّم شَعائِرَ اللَّهِ فَإِنَّها مِن تَقوَى القُلوبِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdcxxviii{لَكُم فيها مَنافِعُ إِلىٰ أَجَلٍ مُسَمًّى ثُمَّ مَحِلُّها إِلَى البَيتِ العَتيقِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdcxxix{وَلِكُلِّ أُمَّةٍ جَعَلنا مَنسَكًا لِيَذكُرُوا اسمَ اللَّهِ عَلىٰ ما رَزَقَهُم مِن بَهيمَةِ الأَنعامِ ۗ فَإِلٰهُكُم إِلٰهٌ واحِدٌ فَلَهُ أَسلِموا ۗ وَبَشِّرِ المُخبِتينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdcxxx{الَّذينَ إِذا ذُكِرَ اللَّهُ وَجِلَت قُلوبُهُم وَالصّابِرينَ عَلىٰ ما أَصابَهُم وَالمُقيمِي الصَّلاةِ وَمِمّا رَزَقناهُم يُنفِقونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdcxxxi{وَالبُدنَ جَعَلناها لَكُم مِن شَعائِرِ اللَّهِ لَكُم فيها خَيرٌ ۖ فَاذكُرُوا اسمَ اللَّهِ عَلَيها صَوافَّ ۖ فَإِذا وَجَبَت جُنوبُها فَكُلوا مِنها وَأَطعِمُوا القانِعَ وَالمُعتَرَّ ۚ كَذٰلِكَ سَخَّرناها لَكُم لَعَلَّكُم تَشكُرونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdcxxxii{لَن يَنالَ اللَّهَ لُحومُها وَلا دِماؤُها وَلٰكِن يَنالُهُ التَّقوىٰ مِنكُم ۚ كَذٰلِكَ سَخَّرَها لَكُم لِتُكَبِّرُوا اللَّهَ عَلىٰ ما هَداكُم ۗ وَبَشِّرِ المُحسِنينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdcxxxiii{۞ إِنَّ اللَّهَ يُدافِعُ عَنِ الَّذينَ آمَنوا ۗ إِنَّ اللَّهَ لا يُحِبُّ كُلَّ خَوّانٍ كَفورٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdcxxxiv{أُذِنَ لِلَّذينَ يُقاتَلونَ بِأَنَّهُم ظُلِموا ۚ وَإِنَّ اللَّهَ عَلىٰ نَصرِهِم لَقَديرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdcxxxv{الَّذينَ أُخرِجوا مِن دِيارِهِم بِغَيرِ حَقٍّ إِلّا أَن يَقولوا رَبُّنَا اللَّهُ ۗ وَلَولا دَفعُ اللَّهِ النّاسَ بَعضَهُم بِبَعضٍ لَهُدِّمَت صَوامِعُ وَبِيَعٌ وَصَلَواتٌ وَمَساجِدُ يُذكَرُ فيهَا اسمُ اللَّهِ كَثيرًا ۗ وَلَيَنصُرَنَّ اللَّهُ مَن يَنصُرُهُ ۗ إِنَّ اللَّهَ لَقَوِيٌّ عَزيزٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdcxxxvi{الَّذينَ إِن مَكَّنّاهُم فِي الأَرضِ أَقامُوا الصَّلاةَ وَآتَوُا الزَّكاةَ وَأَمَروا بِالمَعروفِ وَنَهَوا عَنِ المُنكَرِ ۗ وَلِلَّهِ عاقِبَةُ الأُمورِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdcxxxvii{وَإِن يُكَذِّبوكَ فَقَد كَذَّبَت قَبلَهُم قَومُ نوحٍ وَعادٌ وَثَمودُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdcxxxviii{وَقَومُ إِبراهيمَ وَقَومُ لوطٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdcxxxix{وَأَصحابُ مَديَنَ ۖ وَكُذِّبَ موسىٰ فَأَملَيتُ لِلكافِرينَ ثُمَّ أَخَذتُهُم ۖ فَكَيفَ كانَ نَكيرِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdcxl{فَكَأَيِّن مِن قَريَةٍ أَهلَكناها وَهِيَ ظالِمَةٌ فَهِيَ خاوِيَةٌ عَلىٰ عُروشِها وَبِئرٍ مُعَطَّلَةٍ وَقَصرٍ مَشيدٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdcxli{أَفَلَم يَسيروا فِي الأَرضِ فَتَكونَ لَهُم قُلوبٌ يَعقِلونَ بِها أَو آذانٌ يَسمَعونَ بِها ۖ فَإِنَّها لا تَعمَى الأَبصارُ وَلٰكِن تَعمَى القُلوبُ الَّتي فِي الصُّدورِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdcxlii{وَيَستَعجِلونَكَ بِالعَذابِ وَلَن يُخلِفَ اللَّهُ وَعدَهُ ۚ وَإِنَّ يَومًا عِندَ رَبِّكَ كَأَلفِ سَنَةٍ مِمّا تَعُدّونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdcxliii{وَكَأَيِّن مِن قَريَةٍ أَملَيتُ لَها وَهِيَ ظالِمَةٌ ثُمَّ أَخَذتُها وَإِلَيَّ المَصيرُ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdcxliv{قُل يا أَيُّهَا النّاسُ إِنَّما أَنا لَكُم نَذيرٌ مُبينٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdcxlv{فَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لَهُم مَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdcxlvi{وَالَّذينَ سَعَوا في آياتِنا مُعاجِزينَ أُولٰئِكَ أَصحابُ الجَحيمِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdcxlvii{وَما أَرسَلنا مِن قَبلِكَ مِن رَسولٍ وَلا نَبِيٍّ إِلّا إِذا تَمَنّىٰ أَلقَى الشَّيطانُ في أُمنِيَّتِهِ فَيَنسَخُ اللَّهُ ما يُلقِي الشَّيطانُ ثُمَّ يُحكِمُ اللَّهُ آياتِهِ ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdcxlviii{لِيَجعَلَ ما يُلقِي الشَّيطانُ فِتنَةً لِلَّذينَ في قُلوبِهِم مَرَضٌ وَالقاسِيَةِ قُلوبُهُم ۗ وَإِنَّ الظّالِمينَ لَفي شِقاقٍ بَعيدٍ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdcxlix{وَلِيَعلَمَ الَّذينَ أوتُوا العِلمَ أَنَّهُ الحَقُّ مِن رَبِّكَ فَيُؤمِنوا بِهِ فَتُخبِتَ لَهُ قُلوبُهُم ۗ وَإِنَّ اللَّهَ لَهادِ الَّذينَ آمَنوا إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdcl{وَلا يَزالُ الَّذينَ كَفَروا في مِريَةٍ مِنهُ حَتّىٰ تَأتِيَهُمُ السّاعَةُ بَغتَةً أَو يَأتِيَهُم عَذابُ يَومٍ عَقيمٍ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdcli{المُلكُ يَومَئِذٍ لِلَّهِ يَحكُمُ بَينَهُم ۚ فَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ في جَنّاتِ النَّعيمِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdclii{وَالَّذينَ كَفَروا وَكَذَّبوا بِآياتِنا فَأُولٰئِكَ لَهُم عَذابٌ مُهينٌ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdcliii{وَالَّذينَ هاجَروا في سَبيلِ اللَّهِ ثُمَّ قُتِلوا أَو ماتوا لَيَرزُقَنَّهُمُ اللَّهُ رِزقًا حَسَنًا ۚ وَإِنَّ اللَّهَ لَهُوَ خَيرُ الرّازِقينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdcliv{لَيُدخِلَنَّهُم مُدخَلًا يَرضَونَهُ ۗ وَإِنَّ اللَّهَ لَعَليمٌ حَليمٌ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdclv{۞ ذٰلِكَ وَمَن عاقَبَ بِمِثلِ ما عوقِبَ بِهِ ثُمَّ بُغِيَ عَلَيهِ لَيَنصُرَنَّهُ اللَّهُ ۗ إِنَّ اللَّهَ لَعَفُوٌّ غَفورٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdclvi{ذٰلِكَ بِأَنَّ اللَّهَ يولِجُ اللَّيلَ فِي النَّهارِ وَيولِجُ النَّهارَ فِي اللَّيلِ وَأَنَّ اللَّهَ سَميعٌ بَصيرٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdclvii{ذٰلِكَ بِأَنَّ اللَّهَ هُوَ الحَقُّ وَأَنَّ ما يَدعونَ مِن دونِهِ هُوَ الباطِلُ وَأَنَّ اللَّهَ هُوَ العَلِيُّ الكَبيرُ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdclviii{أَلَم تَرَ أَنَّ اللَّهَ أَنزَلَ مِنَ السَّماءِ ماءً فَتُصبِحُ الأَرضُ مُخضَرَّةً ۗ إِنَّ اللَّهَ لَطيفٌ خَبيرٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdclix{لَهُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۗ وَإِنَّ اللَّهَ لَهُوَ الغَنِيُّ الحَميدُ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdclx{أَلَم تَرَ أَنَّ اللَّهَ سَخَّرَ لَكُم ما فِي الأَرضِ وَالفُلكَ تَجري فِي البَحرِ بِأَمرِهِ وَيُمسِكُ السَّماءَ أَن تَقَعَ عَلَى الأَرضِ إِلّا بِإِذنِهِ ۗ إِنَّ اللَّهَ بِالنّاسِ لَرَءوفٌ رَحيمٌ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmdclxi{وَهُوَ الَّذي أَحياكُم ثُمَّ يُميتُكُم ثُمَّ يُحييكُم ۗ إِنَّ الإِنسانَ لَكَفورٌ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmdclxii{لِكُلِّ أُمَّةٍ جَعَلنا مَنسَكًا هُم ناسِكوهُ ۖ فَلا يُنازِعُنَّكَ فِي الأَمرِ ۚ وَادعُ إِلىٰ رَبِّكَ ۖ إِنَّكَ لَعَلىٰ هُدًى مُستَقيمٍ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmdclxiii{وَإِن جادَلوكَ فَقُلِ اللَّهُ أَعلَمُ بِما تَعمَلونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmdclxiv{اللَّهُ يَحكُمُ بَينَكُم يَومَ القِيامَةِ فيما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmdclxv{أَلَم تَعلَم أَنَّ اللَّهَ يَعلَمُ ما فِي السَّماءِ وَالأَرضِ ۗ إِنَّ ذٰلِكَ في كِتابٍ ۚ إِنَّ ذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmdclxvi{وَيَعبُدونَ مِن دونِ اللَّهِ ما لَم يُنَزِّل بِهِ سُلطانًا وَما لَيسَ لَهُم بِهِ عِلمٌ ۗ وَما لِلظّالِمينَ مِن نَصيرٍ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmdclxvii{وَإِذا تُتلىٰ عَلَيهِم آياتُنا بَيِّناتٍ تَعرِفُ في وُجوهِ الَّذينَ كَفَرُوا المُنكَرَ ۖ يَكادونَ يَسطونَ بِالَّذينَ يَتلونَ عَلَيهِم آياتِنا ۗ قُل أَفَأُنَبِّئُكُم بِشَرٍّ مِن ذٰلِكُمُ ۗ النّارُ وَعَدَهَا اللَّهُ الَّذينَ كَفَروا ۖ وَبِئسَ المَصيرُ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmdclxviii{يا أَيُّهَا النّاسُ ضُرِبَ مَثَلٌ فَاستَمِعوا لَهُ ۚ إِنَّ الَّذينَ تَدعونَ مِن دونِ اللَّهِ لَن يَخلُقوا ذُبابًا وَلَوِ اجتَمَعوا لَهُ ۖ وَإِن يَسلُبهُمُ الذُّبابُ شَيئًا لا يَستَنقِذوهُ مِنهُ ۚ ضَعُفَ الطّالِبُ وَالمَطلوبُ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmdclxix{ما قَدَرُوا اللَّهَ حَقَّ قَدرِهِ ۗ إِنَّ اللَّهَ لَقَوِيٌّ عَزيزٌ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmdclxx{اللَّهُ يَصطَفي مِنَ المَلائِكَةِ رُسُلًا وَمِنَ النّاسِ ۚ إِنَّ اللَّهَ سَميعٌ بَصيرٌ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmdclxxi{يَعلَمُ ما بَينَ أَيديهِم وَما خَلفَهُم ۗ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmdclxxii{يا أَيُّهَا الَّذينَ آمَنُوا اركَعوا وَاسجُدوا وَاعبُدوا رَبَّكُم وَافعَلُوا الخَيرَ لَعَلَّكُم تُفلِحونَ ۩\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmdclxxiii{وَجاهِدوا فِي اللَّهِ حَقَّ جِهادِهِ ۚ هُوَ اجتَباكُم وَما جَعَلَ عَلَيكُم فِي الدّينِ مِن حَرَجٍ ۚ مِلَّةَ أَبيكُم إِبراهيمَ ۚ هُوَ سَمّاكُمُ المُسلِمينَ مِن قَبلُ وَفي هٰذا لِيَكونَ الرَّسولُ شَهيدًا عَلَيكُم وَتَكونوا شُهَداءَ عَلَى النّاسِ ۚ فَأَقيمُوا الصَّلاةَ وَآتُوا الزَّكاةَ وَاعتَصِموا بِاللَّهِ هُوَ مَولاكُم ۖ فَنِعمَ المَولىٰ وَنِعمَ النَّصيرُ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmdclxxiv{\basmalah قَد أَفلَحَ المُؤمِنونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdclxxv{الَّذينَ هُم في صَلاتِهِم خاشِعونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdclxxvi{وَالَّذينَ هُم عَنِ اللَّغوِ مُعرِضونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdclxxvii{وَالَّذينَ هُم لِلزَّكاةِ فاعِلونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdclxxviii{وَالَّذينَ هُم لِفُروجِهِم حافِظونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdclxxix{إِلّا عَلىٰ أَزواجِهِم أَو ما مَلَكَت أَيمانُهُم فَإِنَّهُم غَيرُ مَلومينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdclxxx{فَمَنِ ابتَغىٰ وَراءَ ذٰلِكَ فَأُولٰئِكَ هُمُ العادونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdclxxxi{وَالَّذينَ هُم لِأَماناتِهِم وَعَهدِهِم راعونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdclxxxii{وَالَّذينَ هُم عَلىٰ صَلَواتِهِم يُحافِظونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdclxxxiii{أُولٰئِكَ هُمُ الوارِثونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdclxxxiv{الَّذينَ يَرِثونَ الفِردَوسَ هُم فيها خالِدونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdclxxxv{وَلَقَد خَلَقنَا الإِنسانَ مِن سُلالَةٍ مِن طينٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdclxxxvi{ثُمَّ جَعَلناهُ نُطفَةً في قَرارٍ مَكينٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdclxxxvii{ثُمَّ خَلَقنَا النُّطفَةَ عَلَقَةً فَخَلَقنَا العَلَقَةَ مُضغَةً فَخَلَقنَا المُضغَةَ عِظامًا فَكَسَونَا العِظامَ لَحمًا ثُمَّ أَنشَأناهُ خَلقًا آخَرَ ۚ فَتَبارَكَ اللَّهُ أَحسَنُ الخالِقينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdclxxxviii{ثُمَّ إِنَّكُم بَعدَ ذٰلِكَ لَمَيِّتونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdclxxxix{ثُمَّ إِنَّكُم يَومَ القِيامَةِ تُبعَثونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdcxc{وَلَقَد خَلَقنا فَوقَكُم سَبعَ طَرائِقَ وَما كُنّا عَنِ الخَلقِ غافِلينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdcxci{وَأَنزَلنا مِنَ السَّماءِ ماءً بِقَدَرٍ فَأَسكَنّاهُ فِي الأَرضِ ۖ وَإِنّا عَلىٰ ذَهابٍ بِهِ لَقادِرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdcxcii{فَأَنشَأنا لَكُم بِهِ جَنّاتٍ مِن نَخيلٍ وَأَعنابٍ لَكُم فيها فَواكِهُ كَثيرَةٌ وَمِنها تَأكُلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdcxciii{وَشَجَرَةً تَخرُجُ مِن طورِ سَيناءَ تَنبُتُ بِالدُّهنِ وَصِبغٍ لِلآكِلينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdcxciv{وَإِنَّ لَكُم فِي الأَنعامِ لَعِبرَةً ۖ نُسقيكُم مِمّا في بُطونِها وَلَكُم فيها مَنافِعُ كَثيرَةٌ وَمِنها تَأكُلونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdcxcv{وَعَلَيها وَعَلَى الفُلكِ تُحمَلونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdcxcvi{وَلَقَد أَرسَلنا نوحًا إِلىٰ قَومِهِ فَقالَ يا قَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ ۖ أَفَلا تَتَّقونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdcxcvii{فَقالَ المَلَأُ الَّذينَ كَفَروا مِن قَومِهِ ما هٰذا إِلّا بَشَرٌ مِثلُكُم يُريدُ أَن يَتَفَضَّلَ عَلَيكُم وَلَو شاءَ اللَّهُ لَأَنزَلَ مَلائِكَةً ما سَمِعنا بِهٰذا في آبائِنَا الأَوَّلينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdcxcviii{إِن هُوَ إِلّا رَجُلٌ بِهِ جِنَّةٌ فَتَرَبَّصوا بِهِ حَتّىٰ حينٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdcxcix{قالَ رَبِّ انصُرني بِما كَذَّبونِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdcc{فَأَوحَينا إِلَيهِ أَنِ اصنَعِ الفُلكَ بِأَعيُنِنا وَوَحيِنا فَإِذا جاءَ أَمرُنا وَفارَ التَّنّورُ ۙ فَاسلُك فيها مِن كُلٍّ زَوجَينِ اثنَينِ وَأَهلَكَ إِلّا مَن سَبَقَ عَلَيهِ القَولُ مِنهُم ۖ وَلا تُخاطِبني فِي الَّذينَ ظَلَموا ۖ إِنَّهُم مُغرَقونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdcci{فَإِذَا استَوَيتَ أَنتَ وَمَن مَعَكَ عَلَى الفُلكِ فَقُلِ الحَمدُ لِلَّهِ الَّذي نَجّانا مِنَ القَومِ الظّالِمينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdccii{وَقُل رَبِّ أَنزِلني مُنزَلًا مُبارَكًا وَأَنتَ خَيرُ المُنزِلينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdcciii{إِنَّ في ذٰلِكَ لَآياتٍ وَإِن كُنّا لَمُبتَلينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdcciv{ثُمَّ أَنشَأنا مِن بَعدِهِم قَرنًا آخَرينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdccv{فَأَرسَلنا فيهِم رَسولًا مِنهُم أَنِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ ۖ أَفَلا تَتَّقونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdccvi{وَقالَ المَلَأُ مِن قَومِهِ الَّذينَ كَفَروا وَكَذَّبوا بِلِقاءِ الآخِرَةِ وَأَترَفناهُم فِي الحَياةِ الدُّنيا ما هٰذا إِلّا بَشَرٌ مِثلُكُم يَأكُلُ مِمّا تَأكُلونَ مِنهُ وَيَشرَبُ مِمّا تَشرَبونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdccvii{وَلَئِن أَطَعتُم بَشَرًا مِثلَكُم إِنَّكُم إِذًا لَخاسِرونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdccviii{أَيَعِدُكُم أَنَّكُم إِذا مِتُّم وَكُنتُم تُرابًا وَعِظامًا أَنَّكُم مُخرَجونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdccix{۞ هَيهاتَ هَيهاتَ لِما توعَدونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdccx{إِن هِيَ إِلّا حَياتُنَا الدُّنيا نَموتُ وَنَحيا وَما نَحنُ بِمَبعوثينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdccxi{إِن هُوَ إِلّا رَجُلٌ افتَرىٰ عَلَى اللَّهِ كَذِبًا وَما نَحنُ لَهُ بِمُؤمِنينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdccxii{قالَ رَبِّ انصُرني بِما كَذَّبونِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdccxiii{قالَ عَمّا قَليلٍ لَيُصبِحُنَّ نادِمينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdccxiv{فَأَخَذَتهُمُ الصَّيحَةُ بِالحَقِّ فَجَعَلناهُم غُثاءً ۚ فَبُعدًا لِلقَومِ الظّالِمينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdccxv{ثُمَّ أَنشَأنا مِن بَعدِهِم قُرونًا آخَرينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdccxvi{ما تَسبِقُ مِن أُمَّةٍ أَجَلَها وَما يَستَأخِرونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdccxvii{ثُمَّ أَرسَلنا رُسُلَنا تَترىٰ ۖ كُلَّ ما جاءَ أُمَّةً رَسولُها كَذَّبوهُ ۚ فَأَتبَعنا بَعضَهُم بَعضًا وَجَعَلناهُم أَحاديثَ ۚ فَبُعدًا لِقَومٍ لا يُؤمِنونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdccxviii{ثُمَّ أَرسَلنا موسىٰ وَأَخاهُ هارونَ بِآياتِنا وَسُلطانٍ مُبينٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdccxix{إِلىٰ فِرعَونَ وَمَلَئِهِ فَاستَكبَروا وَكانوا قَومًا عالينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdccxx{فَقالوا أَنُؤمِنُ لِبَشَرَينِ مِثلِنا وَقَومُهُما لَنا عابِدونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdccxxi{فَكَذَّبوهُما فَكانوا مِنَ المُهلَكينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdccxxii{وَلَقَد آتَينا موسَى الكِتابَ لَعَلَّهُم يَهتَدونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdccxxiii{وَجَعَلنَا ابنَ مَريَمَ وَأُمَّهُ آيَةً وَآوَيناهُما إِلىٰ رَبوَةٍ ذاتِ قَرارٍ وَمَعينٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdccxxiv{يا أَيُّهَا الرُّسُلُ كُلوا مِنَ الطَّيِّباتِ وَاعمَلوا صالِحًا ۖ إِنّي بِما تَعمَلونَ عَليمٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdccxxv{وَإِنَّ هٰذِهِ أُمَّتُكُم أُمَّةً واحِدَةً وَأَنا رَبُّكُم فَاتَّقونِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdccxxvi{فَتَقَطَّعوا أَمرَهُم بَينَهُم زُبُرًا ۖ كُلُّ حِزبٍ بِما لَدَيهِم فَرِحونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdccxxvii{فَذَرهُم في غَمرَتِهِم حَتّىٰ حينٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdccxxviii{أَيَحسَبونَ أَنَّما نُمِدُّهُم بِهِ مِن مالٍ وَبَنينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdccxxix{نُسارِعُ لَهُم فِي الخَيراتِ ۚ بَل لا يَشعُرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdccxxx{إِنَّ الَّذينَ هُم مِن خَشيَةِ رَبِّهِم مُشفِقونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdccxxxi{وَالَّذينَ هُم بِآياتِ رَبِّهِم يُؤمِنونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdccxxxii{وَالَّذينَ هُم بِرَبِّهِم لا يُشرِكونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdccxxxiii{وَالَّذينَ يُؤتونَ ما آتَوا وَقُلوبُهُم وَجِلَةٌ أَنَّهُم إِلىٰ رَبِّهِم راجِعونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdccxxxiv{أُولٰئِكَ يُسارِعونَ فِي الخَيراتِ وَهُم لَها سابِقونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdccxxxv{وَلا نُكَلِّفُ نَفسًا إِلّا وُسعَها ۖ وَلَدَينا كِتابٌ يَنطِقُ بِالحَقِّ ۚ وَهُم لا يُظلَمونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdccxxxvi{بَل قُلوبُهُم في غَمرَةٍ مِن هٰذا وَلَهُم أَعمالٌ مِن دونِ ذٰلِكَ هُم لَها عامِلونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdccxxxvii{حَتّىٰ إِذا أَخَذنا مُترَفيهِم بِالعَذابِ إِذا هُم يَجأَرونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdccxxxviii{لا تَجأَرُوا اليَومَ ۖ إِنَّكُم مِنّا لا تُنصَرونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmdccxxxix{قَد كانَت آياتي تُتلىٰ عَلَيكُم فَكُنتُم عَلىٰ أَعقابِكُم تَنكِصونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmdccxl{مُستَكبِرينَ بِهِ سامِرًا تَهجُرونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmdccxli{أَفَلَم يَدَّبَّرُوا القَولَ أَم جاءَهُم ما لَم يَأتِ آباءَهُمُ الأَوَّلينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmdccxlii{أَم لَم يَعرِفوا رَسولَهُم فَهُم لَهُ مُنكِرونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmdccxliii{أَم يَقولونَ بِهِ جِنَّةٌ ۚ بَل جاءَهُم بِالحَقِّ وَأَكثَرُهُم لِلحَقِّ كارِهونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmdccxliv{وَلَوِ اتَّبَعَ الحَقُّ أَهواءَهُم لَفَسَدَتِ السَّماواتُ وَالأَرضُ وَمَن فيهِنَّ ۚ بَل أَتَيناهُم بِذِكرِهِم فَهُم عَن ذِكرِهِم مُعرِضونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmdccxlv{أَم تَسأَلُهُم خَرجًا فَخَراجُ رَبِّكَ خَيرٌ ۖ وَهُوَ خَيرُ الرّازِقينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmdccxlvi{وَإِنَّكَ لَتَدعوهُم إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmdccxlvii{وَإِنَّ الَّذينَ لا يُؤمِنونَ بِالآخِرَةِ عَنِ الصِّراطِ لَناكِبونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmdccxlviii{۞ وَلَو رَحِمناهُم وَكَشَفنا ما بِهِم مِن ضُرٍّ لَلَجّوا في طُغيانِهِم يَعمَهونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmdccxlix{وَلَقَد أَخَذناهُم بِالعَذابِ فَمَا استَكانوا لِرَبِّهِم وَما يَتَضَرَّعونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmdccl{حَتّىٰ إِذا فَتَحنا عَلَيهِم بابًا ذا عَذابٍ شَديدٍ إِذا هُم فيهِ مُبلِسونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmdccli{وَهُوَ الَّذي أَنشَأَ لَكُمُ السَّمعَ وَالأَبصارَ وَالأَفئِدَةَ ۚ قَليلًا ما تَشكُرونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmdcclii{وَهُوَ الَّذي ذَرَأَكُم فِي الأَرضِ وَإِلَيهِ تُحشَرونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmdccliii{وَهُوَ الَّذي يُحيي وَيُميتُ وَلَهُ اختِلافُ اللَّيلِ وَالنَّهارِ ۚ أَفَلا تَعقِلونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmdccliv{بَل قالوا مِثلَ ما قالَ الأَوَّلونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmdcclv{قالوا أَإِذا مِتنا وَكُنّا تُرابًا وَعِظامًا أَإِنّا لَمَبعوثونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmdcclvi{لَقَد وُعِدنا نَحنُ وَآباؤُنا هٰذا مِن قَبلُ إِن هٰذا إِلّا أَساطيرُ الأَوَّلينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmdcclvii{قُل لِمَنِ الأَرضُ وَمَن فيها إِن كُنتُم تَعلَمونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmdcclviii{سَيَقولونَ لِلَّهِ ۚ قُل أَفَلا تَذَكَّرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmdcclix{قُل مَن رَبُّ السَّماواتِ السَّبعِ وَرَبُّ العَرشِ العَظيمِ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmdcclx{سَيَقولونَ لِلَّهِ ۚ قُل أَفَلا تَتَّقونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmdcclxi{قُل مَن بِيَدِهِ مَلَكوتُ كُلِّ شَيءٍ وَهُوَ يُجيرُ وَلا يُجارُ عَلَيهِ إِن كُنتُم تَعلَمونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmdcclxii{سَيَقولونَ لِلَّهِ ۚ قُل فَأَنّىٰ تُسحَرونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmdcclxiii{بَل أَتَيناهُم بِالحَقِّ وَإِنَّهُم لَكاذِبونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmdcclxiv{مَا اتَّخَذَ اللَّهُ مِن وَلَدٍ وَما كانَ مَعَهُ مِن إِلٰهٍ ۚ إِذًا لَذَهَبَ كُلُّ إِلٰهٍ بِما خَلَقَ وَلَعَلا بَعضُهُم عَلىٰ بَعضٍ ۚ سُبحانَ اللَّهِ عَمّا يَصِفونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmdcclxv{عالِمِ الغَيبِ وَالشَّهادَةِ فَتَعالىٰ عَمّا يُشرِكونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmdcclxvi{قُل رَبِّ إِمّا تُرِيَنّي ما يوعَدونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmdcclxvii{رَبِّ فَلا تَجعَلني فِي القَومِ الظّالِمينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmdcclxviii{وَإِنّا عَلىٰ أَن نُرِيَكَ ما نَعِدُهُم لَقادِرونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmdcclxix{ادفَع بِالَّتي هِيَ أَحسَنُ السَّيِّئَةَ ۚ نَحنُ أَعلَمُ بِما يَصِفونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmdcclxx{وَقُل رَبِّ أَعوذُ بِكَ مِن هَمَزاتِ الشَّياطينِ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmdcclxxi{وَأَعوذُ بِكَ رَبِّ أَن يَحضُرونِ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmdcclxxii{حَتّىٰ إِذا جاءَ أَحَدَهُمُ المَوتُ قالَ رَبِّ ارجِعونِ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmdcclxxiii{لَعَلّي أَعمَلُ صالِحًا فيما تَرَكتُ ۚ كَلّا ۚ إِنَّها كَلِمَةٌ هُوَ قائِلُها ۖ وَمِن وَرائِهِم بَرزَخٌ إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmdcclxxiv{فَإِذا نُفِخَ فِي الصّورِ فَلا أَنسابَ بَينَهُم يَومَئِذٍ وَلا يَتَساءَلونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmdcclxxv{فَمَن ثَقُلَت مَوازينُهُ فَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmdcclxxvi{وَمَن خَفَّت مَوازينُهُ فَأُولٰئِكَ الَّذينَ خَسِروا أَنفُسَهُم في جَهَنَّمَ خالِدونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmdcclxxvii{تَلفَحُ وُجوهَهُمُ النّارُ وَهُم فيها كالِحونَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmdcclxxviii{أَلَم تَكُن آياتي تُتلىٰ عَلَيكُم فَكُنتُم بِها تُكَذِّبونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmdcclxxix{قالوا رَبَّنا غَلَبَت عَلَينا شِقوَتُنا وَكُنّا قَومًا ضالّينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmdcclxxx{رَبَّنا أَخرِجنا مِنها فَإِن عُدنا فَإِنّا ظالِمونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmdcclxxxi{قالَ اخسَئوا فيها وَلا تُكَلِّمونِ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmdcclxxxii{إِنَّهُ كانَ فَريقٌ مِن عِبادي يَقولونَ رَبَّنا آمَنّا فَاغفِر لَنا وَارحَمنا وَأَنتَ خَيرُ الرّاحِمينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmdcclxxxiii{فَاتَّخَذتُموهُم سِخرِيًّا حَتّىٰ أَنسَوكُم ذِكري وَكُنتُم مِنهُم تَضحَكونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmdcclxxxiv{إِنّي جَزَيتُهُمُ اليَومَ بِما صَبَروا أَنَّهُم هُمُ الفائِزونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmdcclxxxv{قالَ كَم لَبِثتُم فِي الأَرضِ عَدَدَ سِنينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmdcclxxxvi{قالوا لَبِثنا يَومًا أَو بَعضَ يَومٍ فَاسأَلِ العادّينَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmdcclxxxvii{قالَ إِن لَبِثتُم إِلّا قَليلًا ۖ لَو أَنَّكُم كُنتُم تَعلَمونَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmdcclxxxviii{أَفَحَسِبتُم أَنَّما خَلَقناكُم عَبَثًا وَأَنَّكُم إِلَينا لا تُرجَعونَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmdcclxxxix{فَتَعالَى اللَّهُ المَلِكُ الحَقُّ ۖ لا إِلٰهَ إِلّا هُوَ رَبُّ العَرشِ الكَريمِ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmdccxc{وَمَن يَدعُ مَعَ اللَّهِ إِلٰهًا آخَرَ لا بُرهانَ لَهُ بِهِ فَإِنَّما حِسابُهُ عِندَ رَبِّهِ ۚ إِنَّهُ لا يُفلِحُ الكافِرونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmdccxci{وَقُل رَبِّ اغفِر وَارحَم وَأَنتَ خَيرُ الرّاحِمينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmdccxcii{\basmalah سورَةٌ أَنزَلناها وَفَرَضناها وَأَنزَلنا فيها آياتٍ بَيِّناتٍ لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdccxciii{الزّانِيَةُ وَالزّاني فَاجلِدوا كُلَّ واحِدٍ مِنهُما مِائَةَ جَلدَةٍ ۖ وَلا تَأخُذكُم بِهِما رَأفَةٌ في دينِ اللَّهِ إِن كُنتُم تُؤمِنونَ بِاللَّهِ وَاليَومِ الآخِرِ ۖ وَليَشهَد عَذابَهُما طائِفَةٌ مِنَ المُؤمِنينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdccxciv{الزّاني لا يَنكِحُ إِلّا زانِيَةً أَو مُشرِكَةً وَالزّانِيَةُ لا يَنكِحُها إِلّا زانٍ أَو مُشرِكٌ ۚ وَحُرِّمَ ذٰلِكَ عَلَى المُؤمِنينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdccxcv{وَالَّذينَ يَرمونَ المُحصَناتِ ثُمَّ لَم يَأتوا بِأَربَعَةِ شُهَداءَ فَاجلِدوهُم ثَمانينَ جَلدَةً وَلا تَقبَلوا لَهُم شَهادَةً أَبَدًا ۚ وَأُولٰئِكَ هُمُ الفاسِقونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdccxcvi{إِلَّا الَّذينَ تابوا مِن بَعدِ ذٰلِكَ وَأَصلَحوا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdccxcvii{وَالَّذينَ يَرمونَ أَزواجَهُم وَلَم يَكُن لَهُم شُهَداءُ إِلّا أَنفُسُهُم فَشَهادَةُ أَحَدِهِم أَربَعُ شَهاداتٍ بِاللَّهِ ۙ إِنَّهُ لَمِنَ الصّادِقينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdccxcviii{وَالخامِسَةُ أَنَّ لَعنَتَ اللَّهِ عَلَيهِ إِن كانَ مِنَ الكاذِبينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdccxcix{وَيَدرَأُ عَنهَا العَذابَ أَن تَشهَدَ أَربَعَ شَهاداتٍ بِاللَّهِ ۙ إِنَّهُ لَمِنَ الكاذِبينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdccc{وَالخامِسَةَ أَنَّ غَضَبَ اللَّهِ عَلَيها إِن كانَ مِنَ الصّادِقينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdccci{وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ وَأَنَّ اللَّهَ تَوّابٌ حَكيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdcccii{إِنَّ الَّذينَ جاءوا بِالإِفكِ عُصبَةٌ مِنكُم ۚ لا تَحسَبوهُ شَرًّا لَكُم ۖ بَل هُوَ خَيرٌ لَكُم ۚ لِكُلِّ امرِئٍ مِنهُم مَا اكتَسَبَ مِنَ الإِثمِ ۚ وَالَّذي تَوَلّىٰ كِبرَهُ مِنهُم لَهُ عَذابٌ عَظيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdccciii{لَولا إِذ سَمِعتُموهُ ظَنَّ المُؤمِنونَ وَالمُؤمِناتُ بِأَنفُسِهِم خَيرًا وَقالوا هٰذا إِفكٌ مُبينٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdccciv{لَولا جاءوا عَلَيهِ بِأَربَعَةِ شُهَداءَ ۚ فَإِذ لَم يَأتوا بِالشُّهَداءِ فَأُولٰئِكَ عِندَ اللَّهِ هُمُ الكاذِبونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdcccv{وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ فِي الدُّنيا وَالآخِرَةِ لَمَسَّكُم في ما أَفَضتُم فيهِ عَذابٌ عَظيمٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdcccvi{إِذ تَلَقَّونَهُ بِأَلسِنَتِكُم وَتَقولونَ بِأَفواهِكُم ما لَيسَ لَكُم بِهِ عِلمٌ وَتَحسَبونَهُ هَيِّنًا وَهُوَ عِندَ اللَّهِ عَظيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdcccvii{وَلَولا إِذ سَمِعتُموهُ قُلتُم ما يَكونُ لَنا أَن نَتَكَلَّمَ بِهٰذا سُبحانَكَ هٰذا بُهتانٌ عَظيمٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdcccviii{يَعِظُكُمُ اللَّهُ أَن تَعودوا لِمِثلِهِ أَبَدًا إِن كُنتُم مُؤمِنينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdcccix{وَيُبَيِّنُ اللَّهُ لَكُمُ الآياتِ ۚ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdcccx{إِنَّ الَّذينَ يُحِبّونَ أَن تَشيعَ الفاحِشَةُ فِي الَّذينَ آمَنوا لَهُم عَذابٌ أَليمٌ فِي الدُّنيا وَالآخِرَةِ ۚ وَاللَّهُ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdcccxi{وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ وَأَنَّ اللَّهَ رَءوفٌ رَحيمٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdcccxii{۞ يا أَيُّهَا الَّذينَ آمَنوا لا تَتَّبِعوا خُطُواتِ الشَّيطانِ ۚ وَمَن يَتَّبِع خُطُواتِ الشَّيطانِ فَإِنَّهُ يَأمُرُ بِالفَحشاءِ وَالمُنكَرِ ۚ وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ ما زَكىٰ مِنكُم مِن أَحَدٍ أَبَدًا وَلٰكِنَّ اللَّهَ يُزَكّي مَن يَشاءُ ۗ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdcccxiii{وَلا يَأتَلِ أُولُو الفَضلِ مِنكُم وَالسَّعَةِ أَن يُؤتوا أُولِي القُربىٰ وَالمَساكينَ وَالمُهاجِرينَ في سَبيلِ اللَّهِ ۖ وَليَعفوا وَليَصفَحوا ۗ أَلا تُحِبّونَ أَن يَغفِرَ اللَّهُ لَكُم ۗ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdcccxiv{إِنَّ الَّذينَ يَرمونَ المُحصَناتِ الغافِلاتِ المُؤمِناتِ لُعِنوا فِي الدُّنيا وَالآخِرَةِ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdcccxv{يَومَ تَشهَدُ عَلَيهِم أَلسِنَتُهُم وَأَيديهِم وَأَرجُلُهُم بِما كانوا يَعمَلونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdcccxvi{يَومَئِذٍ يُوَفّيهِمُ اللَّهُ دينَهُمُ الحَقَّ وَيَعلَمونَ أَنَّ اللَّهَ هُوَ الحَقُّ المُبينُ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdcccxvii{الخَبيثاتُ لِلخَبيثينَ وَالخَبيثونَ لِلخَبيثاتِ ۖ وَالطَّيِّباتُ لِلطَّيِّبينَ وَالطَّيِّبونَ لِلطَّيِّباتِ ۚ أُولٰئِكَ مُبَرَّءونَ مِمّا يَقولونَ ۖ لَهُم مَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdcccxviii{يا أَيُّهَا الَّذينَ آمَنوا لا تَدخُلوا بُيوتًا غَيرَ بُيوتِكُم حَتّىٰ تَستَأنِسوا وَتُسَلِّموا عَلىٰ أَهلِها ۚ ذٰلِكُم خَيرٌ لَكُم لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdcccxix{فَإِن لَم تَجِدوا فيها أَحَدًا فَلا تَدخُلوها حَتّىٰ يُؤذَنَ لَكُم ۖ وَإِن قيلَ لَكُمُ ارجِعوا فَارجِعوا ۖ هُوَ أَزكىٰ لَكُم ۚ وَاللَّهُ بِما تَعمَلونَ عَليمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdcccxx{لَيسَ عَلَيكُم جُناحٌ أَن تَدخُلوا بُيوتًا غَيرَ مَسكونَةٍ فيها مَتاعٌ لَكُم ۚ وَاللَّهُ يَعلَمُ ما تُبدونَ وَما تَكتُمونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdcccxxi{قُل لِلمُؤمِنينَ يَغُضّوا مِن أَبصارِهِم وَيَحفَظوا فُروجَهُم ۚ ذٰلِكَ أَزكىٰ لَهُم ۗ إِنَّ اللَّهَ خَبيرٌ بِما يَصنَعونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdcccxxii{وَقُل لِلمُؤمِناتِ يَغضُضنَ مِن أَبصارِهِنَّ وَيَحفَظنَ فُروجَهُنَّ وَلا يُبدينَ زينَتَهُنَّ إِلّا ما ظَهَرَ مِنها ۖ وَليَضرِبنَ بِخُمُرِهِنَّ عَلىٰ جُيوبِهِنَّ ۖ وَلا يُبدينَ زينَتَهُنَّ إِلّا لِبُعولَتِهِنَّ أَو آبائِهِنَّ أَو آباءِ بُعولَتِهِنَّ أَو أَبنائِهِنَّ أَو أَبناءِ بُعولَتِهِنَّ أَو إِخوانِهِنَّ أَو بَني إِخوانِهِنَّ أَو بَني أَخَواتِهِنَّ أَو نِسائِهِنَّ أَو ما مَلَكَت أَيمانُهُنَّ أَوِ التّابِعينَ غَيرِ أُولِي الإِربَةِ مِنَ الرِّجالِ أَوِ الطِّفلِ الَّذينَ لَم يَظهَروا عَلىٰ عَوراتِ النِّساءِ ۖ وَلا يَضرِبنَ بِأَرجُلِهِنَّ لِيُعلَمَ ما يُخفينَ مِن زينَتِهِنَّ ۚ وَتوبوا إِلَى اللَّهِ جَميعًا أَيُّهَ المُؤمِنونَ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdcccxxiii{وَأَنكِحُوا الأَيامىٰ مِنكُم وَالصّالِحينَ مِن عِبادِكُم وَإِمائِكُم ۚ إِن يَكونوا فُقَراءَ يُغنِهِمُ اللَّهُ مِن فَضلِهِ ۗ وَاللَّهُ واسِعٌ عَليمٌ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdcccxxiv{وَليَستَعفِفِ الَّذينَ لا يَجِدونَ نِكاحًا حَتّىٰ يُغنِيَهُمُ اللَّهُ مِن فَضلِهِ ۗ وَالَّذينَ يَبتَغونَ الكِتابَ مِمّا مَلَكَت أَيمانُكُم فَكاتِبوهُم إِن عَلِمتُم فيهِم خَيرًا ۖ وَآتوهُم مِن مالِ اللَّهِ الَّذي آتاكُم ۚ وَلا تُكرِهوا فَتَياتِكُم عَلَى البِغاءِ إِن أَرَدنَ تَحَصُّنًا لِتَبتَغوا عَرَضَ الحَياةِ الدُّنيا ۚ وَمَن يُكرِههُنَّ فَإِنَّ اللَّهَ مِن بَعدِ إِكراهِهِنَّ غَفورٌ رَحيمٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdcccxxv{وَلَقَد أَنزَلنا إِلَيكُم آياتٍ مُبَيِّناتٍ وَمَثَلًا مِنَ الَّذينَ خَلَوا مِن قَبلِكُم وَمَوعِظَةً لِلمُتَّقينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdcccxxvi{۞ اللَّهُ نورُ السَّماواتِ وَالأَرضِ ۚ مَثَلُ نورِهِ كَمِشكاةٍ فيها مِصباحٌ ۖ المِصباحُ في زُجاجَةٍ ۖ الزُّجاجَةُ كَأَنَّها كَوكَبٌ دُرِّيٌّ يوقَدُ مِن شَجَرَةٍ مُبارَكَةٍ زَيتونَةٍ لا شَرقِيَّةٍ وَلا غَربِيَّةٍ يَكادُ زَيتُها يُضيءُ وَلَو لَم تَمسَسهُ نارٌ ۚ نورٌ عَلىٰ نورٍ ۗ يَهدِي اللَّهُ لِنورِهِ مَن يَشاءُ ۚ وَيَضرِبُ اللَّهُ الأَمثالَ لِلنّاسِ ۗ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdcccxxvii{في بُيوتٍ أَذِنَ اللَّهُ أَن تُرفَعَ وَيُذكَرَ فيهَا اسمُهُ يُسَبِّحُ لَهُ فيها بِالغُدُوِّ وَالآصالِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdcccxxviii{رِجالٌ لا تُلهيهِم تِجارَةٌ وَلا بَيعٌ عَن ذِكرِ اللَّهِ وَإِقامِ الصَّلاةِ وَإيتاءِ الزَّكاةِ ۙ يَخافونَ يَومًا تَتَقَلَّبُ فيهِ القُلوبُ وَالأَبصارُ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdcccxxix{لِيَجزِيَهُمُ اللَّهُ أَحسَنَ ما عَمِلوا وَيَزيدَهُم مِن فَضلِهِ ۗ وَاللَّهُ يَرزُقُ مَن يَشاءُ بِغَيرِ حِسابٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdcccxxx{وَالَّذينَ كَفَروا أَعمالُهُم كَسَرابٍ بِقيعَةٍ يَحسَبُهُ الظَّمآنُ ماءً حَتّىٰ إِذا جاءَهُ لَم يَجِدهُ شَيئًا وَوَجَدَ اللَّهَ عِندَهُ فَوَفّاهُ حِسابَهُ ۗ وَاللَّهُ سَريعُ الحِسابِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdcccxxxi{أَو كَظُلُماتٍ في بَحرٍ لُجِّيٍّ يَغشاهُ مَوجٌ مِن فَوقِهِ مَوجٌ مِن فَوقِهِ سَحابٌ ۚ ظُلُماتٌ بَعضُها فَوقَ بَعضٍ إِذا أَخرَجَ يَدَهُ لَم يَكَد يَراها ۗ وَمَن لَم يَجعَلِ اللَّهُ لَهُ نورًا فَما لَهُ مِن نورٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdcccxxxii{أَلَم تَرَ أَنَّ اللَّهَ يُسَبِّحُ لَهُ مَن فِي السَّماواتِ وَالأَرضِ وَالطَّيرُ صافّاتٍ ۖ كُلٌّ قَد عَلِمَ صَلاتَهُ وَتَسبيحَهُ ۗ وَاللَّهُ عَليمٌ بِما يَفعَلونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdcccxxxiii{وَلِلَّهِ مُلكُ السَّماواتِ وَالأَرضِ ۖ وَإِلَى اللَّهِ المَصيرُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdcccxxxiv{أَلَم تَرَ أَنَّ اللَّهَ يُزجي سَحابًا ثُمَّ يُؤَلِّفُ بَينَهُ ثُمَّ يَجعَلُهُ رُكامًا فَتَرَى الوَدقَ يَخرُجُ مِن خِلالِهِ وَيُنَزِّلُ مِنَ السَّماءِ مِن جِبالٍ فيها مِن بَرَدٍ فَيُصيبُ بِهِ مَن يَشاءُ وَيَصرِفُهُ عَن مَن يَشاءُ ۖ يَكادُ سَنا بَرقِهِ يَذهَبُ بِالأَبصارِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdcccxxxv{يُقَلِّبُ اللَّهُ اللَّيلَ وَالنَّهارَ ۚ إِنَّ في ذٰلِكَ لَعِبرَةً لِأُولِي الأَبصارِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdcccxxxvi{وَاللَّهُ خَلَقَ كُلَّ دابَّةٍ مِن ماءٍ ۖ فَمِنهُم مَن يَمشي عَلىٰ بَطنِهِ وَمِنهُم مَن يَمشي عَلىٰ رِجلَينِ وَمِنهُم مَن يَمشي عَلىٰ أَربَعٍ ۚ يَخلُقُ اللَّهُ ما يَشاءُ ۚ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdcccxxxvii{لَقَد أَنزَلنا آياتٍ مُبَيِّناتٍ ۚ وَاللَّهُ يَهدي مَن يَشاءُ إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdcccxxxviii{وَيَقولونَ آمَنّا بِاللَّهِ وَبِالرَّسولِ وَأَطَعنا ثُمَّ يَتَوَلّىٰ فَريقٌ مِنهُم مِن بَعدِ ذٰلِكَ ۚ وَما أُولٰئِكَ بِالمُؤمِنينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdcccxxxix{وَإِذا دُعوا إِلَى اللَّهِ وَرَسولِهِ لِيَحكُمَ بَينَهُم إِذا فَريقٌ مِنهُم مُعرِضونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdcccxl{وَإِن يَكُن لَهُمُ الحَقُّ يَأتوا إِلَيهِ مُذعِنينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdcccxli{أَفي قُلوبِهِم مَرَضٌ أَمِ ارتابوا أَم يَخافونَ أَن يَحيفَ اللَّهُ عَلَيهِم وَرَسولُهُ ۚ بَل أُولٰئِكَ هُمُ الظّالِمونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdcccxlii{إِنَّما كانَ قَولَ المُؤمِنينَ إِذا دُعوا إِلَى اللَّهِ وَرَسولِهِ لِيَحكُمَ بَينَهُم أَن يَقولوا سَمِعنا وَأَطَعنا ۚ وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdcccxliii{وَمَن يُطِعِ اللَّهَ وَرَسولَهُ وَيَخشَ اللَّهَ وَيَتَّقهِ فَأُولٰئِكَ هُمُ الفائِزونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdcccxliv{۞ وَأَقسَموا بِاللَّهِ جَهدَ أَيمانِهِم لَئِن أَمَرتَهُم لَيَخرُجُنَّ ۖ قُل لا تُقسِموا ۖ طاعَةٌ مَعروفَةٌ ۚ إِنَّ اللَّهَ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdcccxlv{قُل أَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ ۖ فَإِن تَوَلَّوا فَإِنَّما عَلَيهِ ما حُمِّلَ وَعَلَيكُم ما حُمِّلتُم ۖ وَإِن تُطيعوهُ تَهتَدوا ۚ وَما عَلَى الرَّسولِ إِلَّا البَلاغُ المُبينُ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdcccxlvi{وَعَدَ اللَّهُ الَّذينَ آمَنوا مِنكُم وَعَمِلُوا الصّالِحاتِ لَيَستَخلِفَنَّهُم فِي الأَرضِ كَمَا استَخلَفَ الَّذينَ مِن قَبلِهِم وَلَيُمَكِّنَنَّ لَهُم دينَهُمُ الَّذِي ارتَضىٰ لَهُم وَلَيُبَدِّلَنَّهُم مِن بَعدِ خَوفِهِم أَمنًا ۚ يَعبُدونَني لا يُشرِكونَ بي شَيئًا ۚ وَمَن كَفَرَ بَعدَ ذٰلِكَ فَأُولٰئِكَ هُمُ الفاسِقونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdcccxlvii{وَأَقيمُوا الصَّلاةَ وَآتُوا الزَّكاةَ وَأَطيعُوا الرَّسولَ لَعَلَّكُم تُرحَمونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdcccxlviii{لا تَحسَبَنَّ الَّذينَ كَفَروا مُعجِزينَ فِي الأَرضِ ۚ وَمَأواهُمُ النّارُ ۖ وَلَبِئسَ المَصيرُ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdcccxlix{يا أَيُّهَا الَّذينَ آمَنوا لِيَستَأذِنكُمُ الَّذينَ مَلَكَت أَيمانُكُم وَالَّذينَ لَم يَبلُغُوا الحُلُمَ مِنكُم ثَلاثَ مَرّاتٍ ۚ مِن قَبلِ صَلاةِ الفَجرِ وَحينَ تَضَعونَ ثِيابَكُم مِنَ الظَّهيرَةِ وَمِن بَعدِ صَلاةِ العِشاءِ ۚ ثَلاثُ عَوراتٍ لَكُم ۚ لَيسَ عَلَيكُم وَلا عَلَيهِم جُناحٌ بَعدَهُنَّ ۚ طَوّافونَ عَلَيكُم بَعضُكُم عَلىٰ بَعضٍ ۚ كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُمُ الآياتِ ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdcccl{وَإِذا بَلَغَ الأَطفالُ مِنكُمُ الحُلُمَ فَليَستَأذِنوا كَمَا استَأذَنَ الَّذينَ مِن قَبلِهِم ۚ كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُم آياتِهِ ۗ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdcccli{وَالقَواعِدُ مِنَ النِّساءِ اللّاتي لا يَرجونَ نِكاحًا فَلَيسَ عَلَيهِنَّ جُناحٌ أَن يَضَعنَ ثِيابَهُنَّ غَيرَ مُتَبَرِّجاتٍ بِزينَةٍ ۖ وَأَن يَستَعفِفنَ خَيرٌ لَهُنَّ ۗ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdccclii{لَيسَ عَلَى الأَعمىٰ حَرَجٌ وَلا عَلَى الأَعرَجِ حَرَجٌ وَلا عَلَى المَريضِ حَرَجٌ وَلا عَلىٰ أَنفُسِكُم أَن تَأكُلوا مِن بُيوتِكُم أَو بُيوتِ آبائِكُم أَو بُيوتِ أُمَّهاتِكُم أَو بُيوتِ إِخوانِكُم أَو بُيوتِ أَخَواتِكُم أَو بُيوتِ أَعمامِكُم أَو بُيوتِ عَمّاتِكُم أَو بُيوتِ أَخوالِكُم أَو بُيوتِ خالاتِكُم أَو ما مَلَكتُم مَفاتِحَهُ أَو صَديقِكُم ۚ لَيسَ عَلَيكُم جُناحٌ أَن تَأكُلوا جَميعًا أَو أَشتاتًا ۚ فَإِذا دَخَلتُم بُيوتًا فَسَلِّموا عَلىٰ أَنفُسِكُم تَحِيَّةً مِن عِندِ اللَّهِ مُبارَكَةً طَيِّبَةً ۚ كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُمُ الآياتِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdcccliii{إِنَّمَا المُؤمِنونَ الَّذينَ آمَنوا بِاللَّهِ وَرَسولِهِ وَإِذا كانوا مَعَهُ عَلىٰ أَمرٍ جامِعٍ لَم يَذهَبوا حَتّىٰ يَستَأذِنوهُ ۚ إِنَّ الَّذينَ يَستَأذِنونَكَ أُولٰئِكَ الَّذينَ يُؤمِنونَ بِاللَّهِ وَرَسولِهِ ۚ فَإِذَا استَأذَنوكَ لِبَعضِ شَأنِهِم فَأذَن لِمَن شِئتَ مِنهُم وَاستَغفِر لَهُمُ اللَّهَ ۚ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdcccliv{لا تَجعَلوا دُعاءَ الرَّسولِ بَينَكُم كَدُعاءِ بَعضِكُم بَعضًا ۚ قَد يَعلَمُ اللَّهُ الَّذينَ يَتَسَلَّلونَ مِنكُم لِواذًا ۚ فَليَحذَرِ الَّذينَ يُخالِفونَ عَن أَمرِهِ أَن تُصيبَهُم فِتنَةٌ أَو يُصيبَهُم عَذابٌ أَليمٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdccclv{أَلا إِنَّ لِلَّهِ ما فِي السَّماواتِ وَالأَرضِ ۖ قَد يَعلَمُ ما أَنتُم عَلَيهِ وَيَومَ يُرجَعونَ إِلَيهِ فَيُنَبِّئُهُم بِما عَمِلوا ۗ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdccclvi{\basmalah تَبارَكَ الَّذي نَزَّلَ الفُرقانَ عَلىٰ عَبدِهِ لِيَكونَ لِلعالَمينَ نَذيرًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdccclvii{الَّذي لَهُ مُلكُ السَّماواتِ وَالأَرضِ وَلَم يَتَّخِذ وَلَدًا وَلَم يَكُن لَهُ شَريكٌ فِي المُلكِ وَخَلَقَ كُلَّ شَيءٍ فَقَدَّرَهُ تَقديرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdccclviii{وَاتَّخَذوا مِن دونِهِ آلِهَةً لا يَخلُقونَ شَيئًا وَهُم يُخلَقونَ وَلا يَملِكونَ لِأَنفُسِهِم ضَرًّا وَلا نَفعًا وَلا يَملِكونَ مَوتًا وَلا حَياةً وَلا نُشورًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdccclix{وَقالَ الَّذينَ كَفَروا إِن هٰذا إِلّا إِفكٌ افتَراهُ وَأَعانَهُ عَلَيهِ قَومٌ آخَرونَ ۖ فَقَد جاءوا ظُلمًا وَزورًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdccclx{وَقالوا أَساطيرُ الأَوَّلينَ اكتَتَبَها فَهِيَ تُملىٰ عَلَيهِ بُكرَةً وَأَصيلًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdccclxi{قُل أَنزَلَهُ الَّذي يَعلَمُ السِّرَّ فِي السَّماواتِ وَالأَرضِ ۚ إِنَّهُ كانَ غَفورًا رَحيمًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdccclxii{وَقالوا مالِ هٰذَا الرَّسولِ يَأكُلُ الطَّعامَ وَيَمشي فِي الأَسواقِ ۙ لَولا أُنزِلَ إِلَيهِ مَلَكٌ فَيَكونَ مَعَهُ نَذيرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdccclxiii{أَو يُلقىٰ إِلَيهِ كَنزٌ أَو تَكونُ لَهُ جَنَّةٌ يَأكُلُ مِنها ۚ وَقالَ الظّالِمونَ إِن تَتَّبِعونَ إِلّا رَجُلًا مَسحورًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdccclxiv{انظُر كَيفَ ضَرَبوا لَكَ الأَمثالَ فَضَلّوا فَلا يَستَطيعونَ سَبيلًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdccclxv{تَبارَكَ الَّذي إِن شاءَ جَعَلَ لَكَ خَيرًا مِن ذٰلِكَ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ وَيَجعَل لَكَ قُصورًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdccclxvi{بَل كَذَّبوا بِالسّاعَةِ ۖ وَأَعتَدنا لِمَن كَذَّبَ بِالسّاعَةِ سَعيرًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdccclxvii{إِذا رَأَتهُم مِن مَكانٍ بَعيدٍ سَمِعوا لَها تَغَيُّظًا وَزَفيرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdccclxviii{وَإِذا أُلقوا مِنها مَكانًا ضَيِّقًا مُقَرَّنينَ دَعَوا هُنالِكَ ثُبورًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdccclxix{لا تَدعُوا اليَومَ ثُبورًا واحِدًا وَادعوا ثُبورًا كَثيرًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdccclxx{قُل أَذٰلِكَ خَيرٌ أَم جَنَّةُ الخُلدِ الَّتي وُعِدَ المُتَّقونَ ۚ كانَت لَهُم جَزاءً وَمَصيرًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdccclxxi{لَهُم فيها ما يَشاءونَ خالِدينَ ۚ كانَ عَلىٰ رَبِّكَ وَعدًا مَسئولًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdccclxxii{وَيَومَ يَحشُرُهُم وَما يَعبُدونَ مِن دونِ اللَّهِ فَيَقولُ أَأَنتُم أَضلَلتُم عِبادي هٰؤُلاءِ أَم هُم ضَلُّوا السَّبيلَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdccclxxiii{قالوا سُبحانَكَ ما كانَ يَنبَغي لَنا أَن نَتَّخِذَ مِن دونِكَ مِن أَولِياءَ وَلٰكِن مَتَّعتَهُم وَآباءَهُم حَتّىٰ نَسُوا الذِّكرَ وَكانوا قَومًا بورًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdccclxxiv{فَقَد كَذَّبوكُم بِما تَقولونَ فَما تَستَطيعونَ صَرفًا وَلا نَصرًا ۚ وَمَن يَظلِم مِنكُم نُذِقهُ عَذابًا كَبيرًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdccclxxv{وَما أَرسَلنا قَبلَكَ مِنَ المُرسَلينَ إِلّا إِنَّهُم لَيَأكُلونَ الطَّعامَ وَيَمشونَ فِي الأَسواقِ ۗ وَجَعَلنا بَعضَكُم لِبَعضٍ فِتنَةً أَتَصبِرونَ ۗ وَكانَ رَبُّكَ بَصيرًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdccclxxvi{۞ وَقالَ الَّذينَ لا يَرجونَ لِقاءَنا لَولا أُنزِلَ عَلَينَا المَلائِكَةُ أَو نَرىٰ رَبَّنا ۗ لَقَدِ استَكبَروا في أَنفُسِهِم وَعَتَوا عُتُوًّا كَبيرًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdccclxxvii{يَومَ يَرَونَ المَلائِكَةَ لا بُشرىٰ يَومَئِذٍ لِلمُجرِمينَ وَيَقولونَ حِجرًا مَحجورًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdccclxxviii{وَقَدِمنا إِلىٰ ما عَمِلوا مِن عَمَلٍ فَجَعَلناهُ هَباءً مَنثورًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdccclxxix{أَصحابُ الجَنَّةِ يَومَئِذٍ خَيرٌ مُستَقَرًّا وَأَحسَنُ مَقيلًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdccclxxx{وَيَومَ تَشَقَّقُ السَّماءُ بِالغَمامِ وَنُزِّلَ المَلائِكَةُ تَنزيلًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdccclxxxi{المُلكُ يَومَئِذٍ الحَقُّ لِلرَّحمٰنِ ۚ وَكانَ يَومًا عَلَى الكافِرينَ عَسيرًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdccclxxxii{وَيَومَ يَعَضُّ الظّالِمُ عَلىٰ يَدَيهِ يَقولُ يا لَيتَنِي اتَّخَذتُ مَعَ الرَّسولِ سَبيلًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdccclxxxiii{يا وَيلَتىٰ لَيتَني لَم أَتَّخِذ فُلانًا خَليلًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdccclxxxiv{لَقَد أَضَلَّني عَنِ الذِّكرِ بَعدَ إِذ جاءَني ۗ وَكانَ الشَّيطانُ لِلإِنسانِ خَذولًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdccclxxxv{وَقالَ الرَّسولُ يا رَبِّ إِنَّ قَومِي اتَّخَذوا هٰذَا القُرآنَ مَهجورًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdccclxxxvi{وَكَذٰلِكَ جَعَلنا لِكُلِّ نَبِيٍّ عَدُوًّا مِنَ المُجرِمينَ ۗ وَكَفىٰ بِرَبِّكَ هادِيًا وَنَصيرًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdccclxxxvii{وَقالَ الَّذينَ كَفَروا لَولا نُزِّلَ عَلَيهِ القُرآنُ جُملَةً واحِدَةً ۚ كَذٰلِكَ لِنُثَبِّتَ بِهِ فُؤادَكَ ۖ وَرَتَّلناهُ تَرتيلًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdccclxxxviii{وَلا يَأتونَكَ بِمَثَلٍ إِلّا جِئناكَ بِالحَقِّ وَأَحسَنَ تَفسيرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdccclxxxix{الَّذينَ يُحشَرونَ عَلىٰ وُجوهِهِم إِلىٰ جَهَنَّمَ أُولٰئِكَ شَرٌّ مَكانًا وَأَضَلُّ سَبيلًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdcccxc{وَلَقَد آتَينا موسَى الكِتابَ وَجَعَلنا مَعَهُ أَخاهُ هارونَ وَزيرًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdcccxci{فَقُلنَا اذهَبا إِلَى القَومِ الَّذينَ كَذَّبوا بِآياتِنا فَدَمَّرناهُم تَدميرًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdcccxcii{وَقَومَ نوحٍ لَمّا كَذَّبُوا الرُّسُلَ أَغرَقناهُم وَجَعَلناهُم لِلنّاسِ آيَةً ۖ وَأَعتَدنا لِلظّالِمينَ عَذابًا أَليمًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdcccxciii{وَعادًا وَثَمودَ وَأَصحابَ الرَّسِّ وَقُرونًا بَينَ ذٰلِكَ كَثيرًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdcccxciv{وَكُلًّا ضَرَبنا لَهُ الأَمثالَ ۖ وَكُلًّا تَبَّرنا تَتبيرًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdcccxcv{وَلَقَد أَتَوا عَلَى القَريَةِ الَّتي أُمطِرَت مَطَرَ السَّوءِ ۚ أَفَلَم يَكونوا يَرَونَها ۚ بَل كانوا لا يَرجونَ نُشورًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdcccxcvi{وَإِذا رَأَوكَ إِن يَتَّخِذونَكَ إِلّا هُزُوًا أَهٰذَا الَّذي بَعَثَ اللَّهُ رَسولًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdcccxcvii{إِن كادَ لَيُضِلُّنا عَن آلِهَتِنا لَولا أَن صَبَرنا عَلَيها ۚ وَسَوفَ يَعلَمونَ حينَ يَرَونَ العَذابَ مَن أَضَلُّ سَبيلًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdcccxcviii{أَرَأَيتَ مَنِ اتَّخَذَ إِلٰهَهُ هَواهُ أَفَأَنتَ تَكونُ عَلَيهِ وَكيلًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdcccxcix{أَم تَحسَبُ أَنَّ أَكثَرَهُم يَسمَعونَ أَو يَعقِلونَ ۚ إِن هُم إِلّا كَالأَنعامِ ۖ بَل هُم أَضَلُّ سَبيلًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmcm{أَلَم تَرَ إِلىٰ رَبِّكَ كَيفَ مَدَّ الظِّلَّ وَلَو شاءَ لَجَعَلَهُ ساكِنًا ثُمَّ جَعَلنَا الشَّمسَ عَلَيهِ دَليلًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmcmi{ثُمَّ قَبَضناهُ إِلَينا قَبضًا يَسيرًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmcmii{وَهُوَ الَّذي جَعَلَ لَكُمُ اللَّيلَ لِباسًا وَالنَّومَ سُباتًا وَجَعَلَ النَّهارَ نُشورًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmcmiii{وَهُوَ الَّذي أَرسَلَ الرِّياحَ بُشرًا بَينَ يَدَي رَحمَتِهِ ۚ وَأَنزَلنا مِنَ السَّماءِ ماءً طَهورًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmcmiv{لِنُحيِيَ بِهِ بَلدَةً مَيتًا وَنُسقِيَهُ مِمّا خَلَقنا أَنعامًا وَأَناسِيَّ كَثيرًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcmv{وَلَقَد صَرَّفناهُ بَينَهُم لِيَذَّكَّروا فَأَبىٰ أَكثَرُ النّاسِ إِلّا كُفورًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcmvi{وَلَو شِئنا لَبَعَثنا في كُلِّ قَريَةٍ نَذيرًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcmvii{فَلا تُطِعِ الكافِرينَ وَجاهِدهُم بِهِ جِهادًا كَبيرًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcmviii{۞ وَهُوَ الَّذي مَرَجَ البَحرَينِ هٰذا عَذبٌ فُراتٌ وَهٰذا مِلحٌ أُجاجٌ وَجَعَلَ بَينَهُما بَرزَخًا وَحِجرًا مَحجورًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcmix{وَهُوَ الَّذي خَلَقَ مِنَ الماءِ بَشَرًا فَجَعَلَهُ نَسَبًا وَصِهرًا ۗ وَكانَ رَبُّكَ قَديرًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcmx{وَيَعبُدونَ مِن دونِ اللَّهِ ما لا يَنفَعُهُم وَلا يَضُرُّهُم ۗ وَكانَ الكافِرُ عَلىٰ رَبِّهِ ظَهيرًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcmxi{وَما أَرسَلناكَ إِلّا مُبَشِّرًا وَنَذيرًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcmxii{قُل ما أَسأَلُكُم عَلَيهِ مِن أَجرٍ إِلّا مَن شاءَ أَن يَتَّخِذَ إِلىٰ رَبِّهِ سَبيلًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcmxiii{وَتَوَكَّل عَلَى الحَيِّ الَّذي لا يَموتُ وَسَبِّح بِحَمدِهِ ۚ وَكَفىٰ بِهِ بِذُنوبِ عِبادِهِ خَبيرًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcmxiv{الَّذي خَلَقَ السَّماواتِ وَالأَرضَ وَما بَينَهُما في سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ ۚ الرَّحمٰنُ فَاسأَل بِهِ خَبيرًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcmxv{وَإِذا قيلَ لَهُمُ اسجُدوا لِلرَّحمٰنِ قالوا وَمَا الرَّحمٰنُ أَنَسجُدُ لِما تَأمُرُنا وَزادَهُم نُفورًا ۩\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcmxvi{تَبارَكَ الَّذي جَعَلَ فِي السَّماءِ بُروجًا وَجَعَلَ فيها سِراجًا وَقَمَرًا مُنيرًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcmxvii{وَهُوَ الَّذي جَعَلَ اللَّيلَ وَالنَّهارَ خِلفَةً لِمَن أَرادَ أَن يَذَّكَّرَ أَو أَرادَ شُكورًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcmxviii{وَعِبادُ الرَّحمٰنِ الَّذينَ يَمشونَ عَلَى الأَرضِ هَونًا وَإِذا خاطَبَهُمُ الجاهِلونَ قالوا سَلامًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcmxix{وَالَّذينَ يَبيتونَ لِرَبِّهِم سُجَّدًا وَقِيامًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcmxx{وَالَّذينَ يَقولونَ رَبَّنَا اصرِف عَنّا عَذابَ جَهَنَّمَ ۖ إِنَّ عَذابَها كانَ غَرامًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcmxxi{إِنَّها ساءَت مُستَقَرًّا وَمُقامًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcmxxii{وَالَّذينَ إِذا أَنفَقوا لَم يُسرِفوا وَلَم يَقتُروا وَكانَ بَينَ ذٰلِكَ قَوامًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmcmxxiii{وَالَّذينَ لا يَدعونَ مَعَ اللَّهِ إِلٰهًا آخَرَ وَلا يَقتُلونَ النَّفسَ الَّتي حَرَّمَ اللَّهُ إِلّا بِالحَقِّ وَلا يَزنونَ ۚ وَمَن يَفعَل ذٰلِكَ يَلقَ أَثامًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmcmxxiv{يُضاعَف لَهُ العَذابُ يَومَ القِيامَةِ وَيَخلُد فيهِ مُهانًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmcmxxv{إِلّا مَن تابَ وَآمَنَ وَعَمِلَ عَمَلًا صالِحًا فَأُولٰئِكَ يُبَدِّلُ اللَّهُ سَيِّئَاتِهِم حَسَناتٍ ۗ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmcmxxvi{وَمَن تابَ وَعَمِلَ صالِحًا فَإِنَّهُ يَتوبُ إِلَى اللَّهِ مَتابًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmcmxxvii{وَالَّذينَ لا يَشهَدونَ الزّورَ وَإِذا مَرّوا بِاللَّغوِ مَرّوا كِرامًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcmxxviii{وَالَّذينَ إِذا ذُكِّروا بِآياتِ رَبِّهِم لَم يَخِرّوا عَلَيها صُمًّا وَعُميانًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmcmxxix{وَالَّذينَ يَقولونَ رَبَّنا هَب لَنا مِن أَزواجِنا وَذُرِّيّاتِنا قُرَّةَ أَعيُنٍ وَاجعَلنا لِلمُتَّقينَ إِمامًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmcmxxx{أُولٰئِكَ يُجزَونَ الغُرفَةَ بِما صَبَروا وَيُلَقَّونَ فيها تَحِيَّةً وَسَلامًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcmxxxi{خالِدينَ فيها ۚ حَسُنَت مُستَقَرًّا وَمُقامًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcmxxxii{قُل ما يَعبَأُ بِكُم رَبّي لَولا دُعاؤُكُم ۖ فَقَد كَذَّبتُم فَسَوفَ يَكونُ لِزامًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcmxxxiii{\basmalah طسم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcmxxxiv{تِلكَ آياتُ الكِتابِ المُبينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcmxxxv{لَعَلَّكَ باخِعٌ نَفسَكَ أَلّا يَكونوا مُؤمِنينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmcmxxxvi{إِن نَشَأ نُنَزِّل عَلَيهِم مِنَ السَّماءِ آيَةً فَظَلَّت أَعناقُهُم لَها خاضِعينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcmxxxvii{وَما يَأتيهِم مِن ذِكرٍ مِنَ الرَّحمٰنِ مُحدَثٍ إِلّا كانوا عَنهُ مُعرِضينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcmxxxviii{فَقَد كَذَّبوا فَسَيَأتيهِم أَنباءُ ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcmxxxix{أَوَلَم يَرَوا إِلَى الأَرضِ كَم أَنبَتنا فيها مِن كُلِّ زَوجٍ كَريمٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcmxl{إِنَّ في ذٰلِكَ لَآيَةً ۖ وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcmxli{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcmxlii{وَإِذ نادىٰ رَبُّكَ موسىٰ أَنِ ائتِ القَومَ الظّالِمينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcmxliii{قَومَ فِرعَونَ ۚ أَلا يَتَّقونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmcmxliv{قالَ رَبِّ إِنّي أَخافُ أَن يُكَذِّبونِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcmxlv{وَيَضيقُ صَدري وَلا يَنطَلِقُ لِساني فَأَرسِل إِلىٰ هارونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcmxlvi{وَلَهُم عَلَيَّ ذَنبٌ فَأَخافُ أَن يَقتُلونِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmcmxlvii{قالَ كَلّا ۖ فَاذهَبا بِآياتِنا ۖ إِنّا مَعَكُم مُستَمِعونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmcmxlviii{فَأتِيا فِرعَونَ فَقولا إِنّا رَسولُ رَبِّ العالَمينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmcmxlix{أَن أَرسِل مَعَنا بَني إِسرائيلَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmcml{قالَ أَلَم نُرَبِّكَ فينا وَليدًا وَلَبِثتَ فينا مِن عُمُرِكَ سِنينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmcmli{وَفَعَلتَ فَعلَتَكَ الَّتي فَعَلتَ وَأَنتَ مِنَ الكافِرينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmcmlii{قالَ فَعَلتُها إِذًا وَأَنا مِنَ الضّالّينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmcmliii{فَفَرَرتُ مِنكُم لَمّا خِفتُكُم فَوَهَبَ لي رَبّي حُكمًا وَجَعَلَني مِنَ المُرسَلينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmcmliv{وَتِلكَ نِعمَةٌ تَمُنُّها عَلَيَّ أَن عَبَّدتَ بَني إِسرائيلَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmcmlv{قالَ فِرعَونُ وَما رَبُّ العالَمينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmcmlvi{قالَ رَبُّ السَّماواتِ وَالأَرضِ وَما بَينَهُما ۖ إِن كُنتُم موقِنينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmcmlvii{قالَ لِمَن حَولَهُ أَلا تَستَمِعونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmcmlviii{قالَ رَبُّكُم وَرَبُّ آبائِكُمُ الأَوَّلينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmcmlix{قالَ إِنَّ رَسولَكُمُ الَّذي أُرسِلَ إِلَيكُم لَمَجنونٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmcmlx{قالَ رَبُّ المَشرِقِ وَالمَغرِبِ وَما بَينَهُما ۖ إِن كُنتُم تَعقِلونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmcmlxi{قالَ لَئِنِ اتَّخَذتَ إِلٰهًا غَيري لَأَجعَلَنَّكَ مِنَ المَسجونينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmcmlxii{قالَ أَوَلَو جِئتُكَ بِشَيءٍ مُبينٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmcmlxiii{قالَ فَأتِ بِهِ إِن كُنتَ مِنَ الصّادِقينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmcmlxiv{فَأَلقىٰ عَصاهُ فَإِذا هِيَ ثُعبانٌ مُبينٌ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmcmlxv{وَنَزَعَ يَدَهُ فَإِذا هِيَ بَيضاءُ لِلنّاظِرينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmcmlxvi{قالَ لِلمَلَإِ حَولَهُ إِنَّ هٰذا لَساحِرٌ عَليمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmcmlxvii{يُريدُ أَن يُخرِجَكُم مِن أَرضِكُم بِسِحرِهِ فَماذا تَأمُرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmcmlxviii{قالوا أَرجِه وَأَخاهُ وَابعَث فِي المَدائِنِ حاشِرينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmcmlxix{يَأتوكَ بِكُلِّ سَحّارٍ عَليمٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmcmlxx{فَجُمِعَ السَّحَرَةُ لِميقاتِ يَومٍ مَعلومٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmcmlxxi{وَقيلَ لِلنّاسِ هَل أَنتُم مُجتَمِعونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmcmlxxii{لَعَلَّنا نَتَّبِعُ السَّحَرَةَ إِن كانوا هُمُ الغالِبينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmcmlxxiii{فَلَمّا جاءَ السَّحَرَةُ قالوا لِفِرعَونَ أَئِنَّ لَنا لَأَجرًا إِن كُنّا نَحنُ الغالِبينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmcmlxxiv{قالَ نَعَم وَإِنَّكُم إِذًا لَمِنَ المُقَرَّبينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmcmlxxv{قالَ لَهُم موسىٰ أَلقوا ما أَنتُم مُلقونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmcmlxxvi{فَأَلقَوا حِبالَهُم وَعِصِيَّهُم وَقالوا بِعِزَّةِ فِرعَونَ إِنّا لَنَحنُ الغالِبونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmcmlxxvii{فَأَلقىٰ موسىٰ عَصاهُ فَإِذا هِيَ تَلقَفُ ما يَأفِكونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmcmlxxviii{فَأُلقِيَ السَّحَرَةُ ساجِدينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmcmlxxix{قالوا آمَنّا بِرَبِّ العالَمينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmcmlxxx{رَبِّ موسىٰ وَهارونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmcmlxxxi{قالَ آمَنتُم لَهُ قَبلَ أَن آذَنَ لَكُم ۖ إِنَّهُ لَكَبيرُكُمُ الَّذي عَلَّمَكُمُ السِّحرَ فَلَسَوفَ تَعلَمونَ ۚ لَأُقَطِّعَنَّ أَيدِيَكُم وَأَرجُلَكُم مِن خِلافٍ وَلَأُصَلِّبَنَّكُم أَجمَعينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcmlxxxii{قالوا لا ضَيرَ ۖ إِنّا إِلىٰ رَبِّنا مُنقَلِبونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcmlxxxiii{إِنّا نَطمَعُ أَن يَغفِرَ لَنا رَبُّنا خَطايانا أَن كُنّا أَوَّلَ المُؤمِنينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcmlxxxiv{۞ وَأَوحَينا إِلىٰ موسىٰ أَن أَسرِ بِعِبادي إِنَّكُم مُتَّبَعونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcmlxxxv{فَأَرسَلَ فِرعَونُ فِي المَدائِنِ حاشِرينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcmlxxxvi{إِنَّ هٰؤُلاءِ لَشِرذِمَةٌ قَليلونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcmlxxxvii{وَإِنَّهُم لَنا لَغائِظونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcmlxxxviii{وَإِنّا لَجَميعٌ حاذِرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcmlxxxix{فَأَخرَجناهُم مِن جَنّاتٍ وَعُيونٍ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcmxc{وَكُنوزٍ وَمَقامٍ كَريمٍ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcmxci{كَذٰلِكَ وَأَورَثناها بَني إِسرائيلَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcmxcii{فَأَتبَعوهُم مُشرِقينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcmxciii{فَلَمّا تَراءَى الجَمعانِ قالَ أَصحابُ موسىٰ إِنّا لَمُدرَكونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcmxciv{قالَ كَلّا ۖ إِنَّ مَعِيَ رَبّي سَيَهدينِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcmxcv{فَأَوحَينا إِلىٰ موسىٰ أَنِ اضرِب بِعَصاكَ البَحرَ ۖ فَانفَلَقَ فَكانَ كُلُّ فِرقٍ كَالطَّودِ العَظيمِ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcmxcvi{وَأَزلَفنا ثَمَّ الآخَرينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcmxcvii{وَأَنجَينا موسىٰ وَمَن مَعَهُ أَجمَعينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcmxcviii{ثُمَّ أَغرَقنَا الآخَرينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcmxcix{إِنَّ في ذٰلِكَ لَآيَةً ۖ وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmm{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmi{وَاتلُ عَلَيهِم نَبَأَ إِبراهيمَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmii{إِذ قالَ لِأَبيهِ وَقَومِهِ ما تَعبُدونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmiii{قالوا نَعبُدُ أَصنامًا فَنَظَلُّ لَها عاكِفينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmiv{قالَ هَل يَسمَعونَكُم إِذ تَدعونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmv{أَو يَنفَعونَكُم أَو يَضُرّونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmvi{قالوا بَل وَجَدنا آباءَنا كَذٰلِكَ يَفعَلونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmvii{قالَ أَفَرَأَيتُم ما كُنتُم تَعبُدونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmviii{أَنتُم وَآباؤُكُمُ الأَقدَمونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmix{فَإِنَّهُم عَدُوٌّ لي إِلّا رَبَّ العالَمينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmx{الَّذي خَلَقَني فَهُوَ يَهدينِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmxi{وَالَّذي هُوَ يُطعِمُني وَيَسقينِ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmxii{وَإِذا مَرِضتُ فَهُوَ يَشفينِ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmxiii{وَالَّذي يُميتُني ثُمَّ يُحيينِ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmxiv{وَالَّذي أَطمَعُ أَن يَغفِرَ لي خَطيئَتي يَومَ الدّينِ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmxv{رَبِّ هَب لي حُكمًا وَأَلحِقني بِالصّالِحينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmxvi{وَاجعَل لي لِسانَ صِدقٍ فِي الآخِرينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmxvii{وَاجعَلني مِن وَرَثَةِ جَنَّةِ النَّعيمِ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmxviii{وَاغفِر لِأَبي إِنَّهُ كانَ مِنَ الضّالّينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmxix{وَلا تُخزِني يَومَ يُبعَثونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmxx{يَومَ لا يَنفَعُ مالٌ وَلا بَنونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmxxi{إِلّا مَن أَتَى اللَّهَ بِقَلبٍ سَليمٍ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmxxii{وَأُزلِفَتِ الجَنَّةُ لِلمُتَّقينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmxxiii{وَبُرِّزَتِ الجَحيمُ لِلغاوينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmxxiv{وَقيلَ لَهُم أَينَ ما كُنتُم تَعبُدونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmxxv{مِن دونِ اللَّهِ هَل يَنصُرونَكُم أَو يَنتَصِرونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmxxvi{فَكُبكِبوا فيها هُم وَالغاوونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmmxxvii{وَجُنودُ إِبليسَ أَجمَعونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmmxxviii{قالوا وَهُم فيها يَختَصِمونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmmxxix{تَاللَّهِ إِن كُنّا لَفي ضَلالٍ مُبينٍ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmmxxx{إِذ نُسَوّيكُم بِرَبِّ العالَمينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmmxxxi{وَما أَضَلَّنا إِلَّا المُجرِمونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmmxxxii{فَما لَنا مِن شافِعينَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmmxxxiii{وَلا صَديقٍ حَميمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmmxxxiv{فَلَو أَنَّ لَنا كَرَّةً فَنَكونَ مِنَ المُؤمِنينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmmxxxv{إِنَّ في ذٰلِكَ لَآيَةً ۖ وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmmxxxvi{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmmxxxvii{كَذَّبَت قَومُ نوحٍ المُرسَلينَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmmxxxviii{إِذ قالَ لَهُم أَخوهُم نوحٌ أَلا تَتَّقونَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmmxxxix{إِنّي لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmmxl{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmmxli{وَما أَسأَلُكُم عَلَيهِ مِن أَجرٍ ۖ إِن أَجرِيَ إِلّا عَلىٰ رَبِّ العالَمينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmmxlii{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmmxliii{۞ قالوا أَنُؤمِنُ لَكَ وَاتَّبَعَكَ الأَرذَلونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmmxliv{قالَ وَما عِلمي بِما كانوا يَعمَلونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmmxlv{إِن حِسابُهُم إِلّا عَلىٰ رَبّي ۖ لَو تَشعُرونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmmxlvi{وَما أَنا بِطارِدِ المُؤمِنينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmmxlvii{إِن أَنا إِلّا نَذيرٌ مُبينٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmmxlviii{قالوا لَئِن لَم تَنتَهِ يا نوحُ لَتَكونَنَّ مِنَ المَرجومينَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmmxlix{قالَ رَبِّ إِنَّ قَومي كَذَّبونِ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmml{فَافتَح بَيني وَبَينَهُم فَتحًا وَنَجِّني وَمَن مَعِيَ مِنَ المُؤمِنينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmmli{فَأَنجَيناهُ وَمَن مَعَهُ فِي الفُلكِ المَشحونِ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmmlii{ثُمَّ أَغرَقنا بَعدُ الباقينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmmliii{إِنَّ في ذٰلِكَ لَآيَةً ۖ وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmmliv{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmmlv{كَذَّبَت عادٌ المُرسَلينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmmlvi{إِذ قالَ لَهُم أَخوهُم هودٌ أَلا تَتَّقونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmmlvii{إِنّي لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmmlviii{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmmlix{وَما أَسأَلُكُم عَلَيهِ مِن أَجرٍ ۖ إِن أَجرِيَ إِلّا عَلىٰ رَبِّ العالَمينَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmmlx{أَتَبنونَ بِكُلِّ ريعٍ آيَةً تَعبَثونَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmmlxi{وَتَتَّخِذونَ مَصانِعَ لَعَلَّكُم تَخلُدونَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mmmlxii{وَإِذا بَطَشتُم بَطَشتُم جَبّارينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mmmlxiii{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mmmlxiv{وَاتَّقُوا الَّذي أَمَدَّكُم بِما تَعلَمونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mmmlxv{أَمَدَّكُم بِأَنعامٍ وَبَنينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mmmlxvi{وَجَنّاتٍ وَعُيونٍ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mmmlxvii{إِنّي أَخافُ عَلَيكُم عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mmmlxviii{قالوا سَواءٌ عَلَينا أَوَعَظتَ أَم لَم تَكُن مِنَ الواعِظينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@mmmlxix{إِن هٰذا إِلّا خُلُقُ الأَوَّلينَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@mmmlxx{وَما نَحنُ بِمُعَذَّبينَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@mmmlxxi{فَكَذَّبوهُ فَأَهلَكناهُم ۗ إِنَّ في ذٰلِكَ لَآيَةً ۖ وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@mmmlxxii{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@mmmlxxiii{كَذَّبَت ثَمودُ المُرسَلينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@mmmlxxiv{إِذ قالَ لَهُم أَخوهُم صالِحٌ أَلا تَتَّقونَ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@mmmlxxv{إِنّي لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@mmmlxxvi{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@mmmlxxvii{وَما أَسأَلُكُم عَلَيهِ مِن أَجرٍ ۖ إِن أَجرِيَ إِلّا عَلىٰ رَبِّ العالَمينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@mmmlxxviii{أَتُترَكونَ في ما هاهُنا آمِنينَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@mmmlxxix{في جَنّاتٍ وَعُيونٍ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@mmmlxxx{وَزُروعٍ وَنَخلٍ طَلعُها هَضيمٌ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@mmmlxxxi{وَتَنحِتونَ مِنَ الجِبالِ بُيوتًا فارِهينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@mmmlxxxii{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@mmmlxxxiii{وَلا تُطيعوا أَمرَ المُسرِفينَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@mmmlxxxiv{الَّذينَ يُفسِدونَ فِي الأَرضِ وَلا يُصلِحونَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@mmmlxxxv{قالوا إِنَّما أَنتَ مِنَ المُسَحَّرينَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@mmmlxxxvi{ما أَنتَ إِلّا بَشَرٌ مِثلُنا فَأتِ بِآيَةٍ إِن كُنتَ مِنَ الصّادِقينَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@mmmlxxxvii{قالَ هٰذِهِ ناقَةٌ لَها شِربٌ وَلَكُم شِربُ يَومٍ مَعلومٍ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@mmmlxxxviii{وَلا تَمَسّوها بِسوءٍ فَيَأخُذَكُم عَذابُ يَومٍ عَظيمٍ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@mmmlxxxix{فَعَقَروها فَأَصبَحوا نادِمينَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@mmmxc{فَأَخَذَهُمُ العَذابُ ۗ إِنَّ في ذٰلِكَ لَآيَةً ۖ وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@mmmxci{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@mmmxcii{كَذَّبَت قَومُ لوطٍ المُرسَلينَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@mmmxciii{إِذ قالَ لَهُم أَخوهُم لوطٌ أَلا تَتَّقونَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@mmmxciv{إِنّي لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@mmmxcv{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@mmmxcvi{وَما أَسأَلُكُم عَلَيهِ مِن أَجرٍ ۖ إِن أَجرِيَ إِلّا عَلىٰ رَبِّ العالَمينَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@mmmxcvii{أَتَأتونَ الذُّكرانَ مِنَ العالَمينَ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@mmmxcviii{وَتَذَرونَ ما خَلَقَ لَكُم رَبُّكُم مِن أَزواجِكُم ۚ بَل أَنتُم قَومٌ عادونَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@mmmxcix{قالوا لَئِن لَم تَنتَهِ يا لوطُ لَتَكونَنَّ مِنَ المُخرَجينَ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@mmmc{قالَ إِنّي لِعَمَلِكُم مِنَ القالينَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@mmmci{رَبِّ نَجِّني وَأَهلي مِمّا يَعمَلونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@mmmcii{فَنَجَّيناهُ وَأَهلَهُ أَجمَعينَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@mmmciii{إِلّا عَجوزًا فِي الغابِرينَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@mmmciv{ثُمَّ دَمَّرنَا الآخَرينَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@mmmcv{وَأَمطَرنا عَلَيهِم مَطَرًا ۖ فَساءَ مَطَرُ المُنذَرينَ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@mmmcvi{إِنَّ في ذٰلِكَ لَآيَةً ۖ وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@mmmcvii{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@mmmcviii{كَذَّبَ أَصحابُ الأَيكَةِ المُرسَلينَ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@mmmcix{إِذ قالَ لَهُم شُعَيبٌ أَلا تَتَّقونَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@mmmcx{إِنّي لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@mmmcxi{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@mmmcxii{وَما أَسأَلُكُم عَلَيهِ مِن أَجرٍ ۖ إِن أَجرِيَ إِلّا عَلىٰ رَبِّ العالَمينَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@mmmcxiii{۞ أَوفُوا الكَيلَ وَلا تَكونوا مِنَ المُخسِرينَ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@mmmcxiv{وَزِنوا بِالقِسطاسِ المُستَقيمِ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@mmmcxv{وَلا تَبخَسُوا النّاسَ أَشياءَهُم وَلا تَعثَوا فِي الأَرضِ مُفسِدينَ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@mmmcxvi{وَاتَّقُوا الَّذي خَلَقَكُم وَالجِبِلَّةَ الأَوَّلينَ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@mmmcxvii{قالوا إِنَّما أَنتَ مِنَ المُسَحَّرينَ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@mmmcxviii{وَما أَنتَ إِلّا بَشَرٌ مِثلُنا وَإِن نَظُنُّكَ لَمِنَ الكاذِبينَ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@mmmcxix{فَأَسقِط عَلَينا كِسَفًا مِنَ السَّماءِ إِن كُنتَ مِنَ الصّادِقينَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@mmmcxx{قالَ رَبّي أَعلَمُ بِما تَعمَلونَ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@mmmcxxi{فَكَذَّبوهُ فَأَخَذَهُم عَذابُ يَومِ الظُّلَّةِ ۚ إِنَّهُ كانَ عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@mmmcxxii{إِنَّ في ذٰلِكَ لَآيَةً ۖ وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@mmmcxxiii{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@mmmcxxiv{وَإِنَّهُ لَتَنزيلُ رَبِّ العالَمينَ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@mmmcxxv{نَزَلَ بِهِ الرّوحُ الأَمينُ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@mmmcxxvi{عَلىٰ قَلبِكَ لِتَكونَ مِنَ المُنذِرينَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@mmmcxxvii{بِلِسانٍ عَرَبِيٍّ مُبينٍ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@mmmcxxviii{وَإِنَّهُ لَفي زُبُرِ الأَوَّلينَ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@mmmcxxix{أَوَلَم يَكُن لَهُم آيَةً أَن يَعلَمَهُ عُلَماءُ بَني إِسرائيلَ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@mmmcxxx{وَلَو نَزَّلناهُ عَلىٰ بَعضِ الأَعجَمينَ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@mmmcxxxi{فَقَرَأَهُ عَلَيهِم ما كانوا بِهِ مُؤمِنينَ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@mmmcxxxii{كَذٰلِكَ سَلَكناهُ في قُلوبِ المُجرِمينَ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@mmmcxxxiii{لا يُؤمِنونَ بِهِ حَتّىٰ يَرَوُا العَذابَ الأَليمَ\qt@no{﴿٢٠١﴾}}
\qt@newcmd\qurantext@mmmcxxxiv{فَيَأتِيَهُم بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿٢٠٢﴾}}
\qt@newcmd\qurantext@mmmcxxxv{فَيَقولوا هَل نَحنُ مُنظَرونَ\qt@no{﴿٢٠٣﴾}}
\qt@newcmd\qurantext@mmmcxxxvi{أَفَبِعَذابِنا يَستَعجِلونَ\qt@no{﴿٢٠٤﴾}}
\qt@newcmd\qurantext@mmmcxxxvii{أَفَرَأَيتَ إِن مَتَّعناهُم سِنينَ\qt@no{﴿٢٠٥﴾}}
\qt@newcmd\qurantext@mmmcxxxviii{ثُمَّ جاءَهُم ما كانوا يوعَدونَ\qt@no{﴿٢٠٦﴾}}
\qt@newcmd\qurantext@mmmcxxxix{ما أَغنىٰ عَنهُم ما كانوا يُمَتَّعونَ\qt@no{﴿٢٠٧﴾}}
\qt@newcmd\qurantext@mmmcxl{وَما أَهلَكنا مِن قَريَةٍ إِلّا لَها مُنذِرونَ\qt@no{﴿٢٠٨﴾}}
\qt@newcmd\qurantext@mmmcxli{ذِكرىٰ وَما كُنّا ظالِمينَ\qt@no{﴿٢٠٩﴾}}
\qt@newcmd\qurantext@mmmcxlii{وَما تَنَزَّلَت بِهِ الشَّياطينُ\qt@no{﴿٢١٠﴾}}
\qt@newcmd\qurantext@mmmcxliii{وَما يَنبَغي لَهُم وَما يَستَطيعونَ\qt@no{﴿٢١١﴾}}
\qt@newcmd\qurantext@mmmcxliv{إِنَّهُم عَنِ السَّمعِ لَمَعزولونَ\qt@no{﴿٢١٢﴾}}
\qt@newcmd\qurantext@mmmcxlv{فَلا تَدعُ مَعَ اللَّهِ إِلٰهًا آخَرَ فَتَكونَ مِنَ المُعَذَّبينَ\qt@no{﴿٢١٣﴾}}
\qt@newcmd\qurantext@mmmcxlvi{وَأَنذِر عَشيرَتَكَ الأَقرَبينَ\qt@no{﴿٢١٤﴾}}
\qt@newcmd\qurantext@mmmcxlvii{وَاخفِض جَناحَكَ لِمَنِ اتَّبَعَكَ مِنَ المُؤمِنينَ\qt@no{﴿٢١٥﴾}}
\qt@newcmd\qurantext@mmmcxlviii{فَإِن عَصَوكَ فَقُل إِنّي بَريءٌ مِمّا تَعمَلونَ\qt@no{﴿٢١٦﴾}}
\qt@newcmd\qurantext@mmmcxlix{وَتَوَكَّل عَلَى العَزيزِ الرَّحيمِ\qt@no{﴿٢١٧﴾}}
\qt@newcmd\qurantext@mmmcl{الَّذي يَراكَ حينَ تَقومُ\qt@no{﴿٢١٨﴾}}
\qt@newcmd\qurantext@mmmcli{وَتَقَلُّبَكَ فِي السّاجِدينَ\qt@no{﴿٢١٩﴾}}
\qt@newcmd\qurantext@mmmclii{إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٢٢٠﴾}}
\qt@newcmd\qurantext@mmmcliii{هَل أُنَبِّئُكُم عَلىٰ مَن تَنَزَّلُ الشَّياطينُ\qt@no{﴿٢٢١﴾}}
\qt@newcmd\qurantext@mmmcliv{تَنَزَّلُ عَلىٰ كُلِّ أَفّاكٍ أَثيمٍ\qt@no{﴿٢٢٢﴾}}
\qt@newcmd\qurantext@mmmclv{يُلقونَ السَّمعَ وَأَكثَرُهُم كاذِبونَ\qt@no{﴿٢٢٣﴾}}
\qt@newcmd\qurantext@mmmclvi{وَالشُّعَراءُ يَتَّبِعُهُمُ الغاوونَ\qt@no{﴿٢٢٤﴾}}
\qt@newcmd\qurantext@mmmclvii{أَلَم تَرَ أَنَّهُم في كُلِّ وادٍ يَهيمونَ\qt@no{﴿٢٢٥﴾}}
\qt@newcmd\qurantext@mmmclviii{وَأَنَّهُم يَقولونَ ما لا يَفعَلونَ\qt@no{﴿٢٢٦﴾}}
\qt@newcmd\qurantext@mmmclix{إِلَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ وَذَكَرُوا اللَّهَ كَثيرًا وَانتَصَروا مِن بَعدِ ما ظُلِموا ۗ وَسَيَعلَمُ الَّذينَ ظَلَموا أَيَّ مُنقَلَبٍ يَنقَلِبونَ\qt@no{﴿٢٢٧﴾}}
\qt@newcmd\qurantext@mmmclx{\basmalah طس ۚ تِلكَ آياتُ القُرآنِ وَكِتابٍ مُبينٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmclxi{هُدًى وَبُشرىٰ لِلمُؤمِنينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmclxii{الَّذينَ يُقيمونَ الصَّلاةَ وَيُؤتونَ الزَّكاةَ وَهُم بِالآخِرَةِ هُم يوقِنونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmclxiii{إِنَّ الَّذينَ لا يُؤمِنونَ بِالآخِرَةِ زَيَّنّا لَهُم أَعمالَهُم فَهُم يَعمَهونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmclxiv{أُولٰئِكَ الَّذينَ لَهُم سوءُ العَذابِ وَهُم فِي الآخِرَةِ هُمُ الأَخسَرونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmclxv{وَإِنَّكَ لَتُلَقَّى القُرآنَ مِن لَدُن حَكيمٍ عَليمٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmclxvi{إِذ قالَ موسىٰ لِأَهلِهِ إِنّي آنَستُ نارًا سَآتيكُم مِنها بِخَبَرٍ أَو آتيكُم بِشِهابٍ قَبَسٍ لَعَلَّكُم تَصطَلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmclxvii{فَلَمّا جاءَها نودِيَ أَن بورِكَ مَن فِي النّارِ وَمَن حَولَها وَسُبحانَ اللَّهِ رَبِّ العالَمينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmclxviii{يا موسىٰ إِنَّهُ أَنَا اللَّهُ العَزيزُ الحَكيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmclxix{وَأَلقِ عَصاكَ ۚ فَلَمّا رَآها تَهتَزُّ كَأَنَّها جانٌّ وَلّىٰ مُدبِرًا وَلَم يُعَقِّب ۚ يا موسىٰ لا تَخَف إِنّي لا يَخافُ لَدَيَّ المُرسَلونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmclxx{إِلّا مَن ظَلَمَ ثُمَّ بَدَّلَ حُسنًا بَعدَ سوءٍ فَإِنّي غَفورٌ رَحيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmclxxi{وَأَدخِل يَدَكَ في جَيبِكَ تَخرُج بَيضاءَ مِن غَيرِ سوءٍ ۖ في تِسعِ آياتٍ إِلىٰ فِرعَونَ وَقَومِهِ ۚ إِنَّهُم كانوا قَومًا فاسِقينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmclxxii{فَلَمّا جاءَتهُم آياتُنا مُبصِرَةً قالوا هٰذا سِحرٌ مُبينٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmclxxiii{وَجَحَدوا بِها وَاستَيقَنَتها أَنفُسُهُم ظُلمًا وَعُلُوًّا ۚ فَانظُر كَيفَ كانَ عاقِبَةُ المُفسِدينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmclxxiv{وَلَقَد آتَينا داوودَ وَسُلَيمانَ عِلمًا ۖ وَقالَا الحَمدُ لِلَّهِ الَّذي فَضَّلَنا عَلىٰ كَثيرٍ مِن عِبادِهِ المُؤمِنينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmclxxv{وَوَرِثَ سُلَيمانُ داوودَ ۖ وَقالَ يا أَيُّهَا النّاسُ عُلِّمنا مَنطِقَ الطَّيرِ وَأوتينا مِن كُلِّ شَيءٍ ۖ إِنَّ هٰذا لَهُوَ الفَضلُ المُبينُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmclxxvi{وَحُشِرَ لِسُلَيمانَ جُنودُهُ مِنَ الجِنِّ وَالإِنسِ وَالطَّيرِ فَهُم يوزَعونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmclxxvii{حَتّىٰ إِذا أَتَوا عَلىٰ وادِ النَّملِ قالَت نَملَةٌ يا أَيُّهَا النَّملُ ادخُلوا مَساكِنَكُم لا يَحطِمَنَّكُم سُلَيمانُ وَجُنودُهُ وَهُم لا يَشعُرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmclxxviii{فَتَبَسَّمَ ضاحِكًا مِن قَولِها وَقالَ رَبِّ أَوزِعني أَن أَشكُرَ نِعمَتَكَ الَّتي أَنعَمتَ عَلَيَّ وَعَلىٰ والِدَيَّ وَأَن أَعمَلَ صالِحًا تَرضاهُ وَأَدخِلني بِرَحمَتِكَ في عِبادِكَ الصّالِحينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmclxxix{وَتَفَقَّدَ الطَّيرَ فَقالَ ما لِيَ لا أَرَى الهُدهُدَ أَم كانَ مِنَ الغائِبينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmclxxx{لَأُعَذِّبَنَّهُ عَذابًا شَديدًا أَو لَأَذبَحَنَّهُ أَو لَيَأتِيَنّي بِسُلطانٍ مُبينٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmclxxxi{فَمَكَثَ غَيرَ بَعيدٍ فَقالَ أَحَطتُ بِما لَم تُحِط بِهِ وَجِئتُكَ مِن سَبَإٍ بِنَبَإٍ يَقينٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmclxxxii{إِنّي وَجَدتُ امرَأَةً تَملِكُهُم وَأوتِيَت مِن كُلِّ شَيءٍ وَلَها عَرشٌ عَظيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmclxxxiii{وَجَدتُها وَقَومَها يَسجُدونَ لِلشَّمسِ مِن دونِ اللَّهِ وَزَيَّنَ لَهُمُ الشَّيطانُ أَعمالَهُم فَصَدَّهُم عَنِ السَّبيلِ فَهُم لا يَهتَدونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmclxxxiv{أَلّا يَسجُدوا لِلَّهِ الَّذي يُخرِجُ الخَبءَ فِي السَّماواتِ وَالأَرضِ وَيَعلَمُ ما تُخفونَ وَما تُعلِنونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmclxxxv{اللَّهُ لا إِلٰهَ إِلّا هُوَ رَبُّ العَرشِ العَظيمِ ۩\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmclxxxvi{۞ قالَ سَنَنظُرُ أَصَدَقتَ أَم كُنتَ مِنَ الكاذِبينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmclxxxvii{اذهَب بِكِتابي هٰذا فَأَلقِه إِلَيهِم ثُمَّ تَوَلَّ عَنهُم فَانظُر ماذا يَرجِعونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmclxxxviii{قالَت يا أَيُّهَا المَلَأُ إِنّي أُلقِيَ إِلَيَّ كِتابٌ كَريمٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmclxxxix{إِنَّهُ مِن سُلَيمانَ وَإِنَّهُ بِسمِ اللَّهِ الرَّحمٰنِ الرَّحيمِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmcxc{أَلّا تَعلوا عَلَيَّ وَأتوني مُسلِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmcxci{قالَت يا أَيُّهَا المَلَأُ أَفتوني في أَمري ما كُنتُ قاطِعَةً أَمرًا حَتّىٰ تَشهَدونِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmcxcii{قالوا نَحنُ أُولو قُوَّةٍ وَأُولو بَأسٍ شَديدٍ وَالأَمرُ إِلَيكِ فَانظُري ماذا تَأمُرينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmcxciii{قالَت إِنَّ المُلوكَ إِذا دَخَلوا قَريَةً أَفسَدوها وَجَعَلوا أَعِزَّةَ أَهلِها أَذِلَّةً ۖ وَكَذٰلِكَ يَفعَلونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmcxciv{وَإِنّي مُرسِلَةٌ إِلَيهِم بِهَدِيَّةٍ فَناظِرَةٌ بِمَ يَرجِعُ المُرسَلونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmcxcv{فَلَمّا جاءَ سُلَيمانَ قالَ أَتُمِدّونَنِ بِمالٍ فَما آتانِيَ اللَّهُ خَيرٌ مِمّا آتاكُم بَل أَنتُم بِهَدِيَّتِكُم تَفرَحونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmcxcvi{ارجِع إِلَيهِم فَلَنَأتِيَنَّهُم بِجُنودٍ لا قِبَلَ لَهُم بِها وَلَنُخرِجَنَّهُم مِنها أَذِلَّةً وَهُم صاغِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmcxcvii{قالَ يا أَيُّهَا المَلَأُ أَيُّكُم يَأتيني بِعَرشِها قَبلَ أَن يَأتوني مُسلِمينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmcxcviii{قالَ عِفريتٌ مِنَ الجِنِّ أَنا آتيكَ بِهِ قَبلَ أَن تَقومَ مِن مَقامِكَ ۖ وَإِنّي عَلَيهِ لَقَوِيٌّ أَمينٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmcxcix{قالَ الَّذي عِندَهُ عِلمٌ مِنَ الكِتابِ أَنا آتيكَ بِهِ قَبلَ أَن يَرتَدَّ إِلَيكَ طَرفُكَ ۚ فَلَمّا رَآهُ مُستَقِرًّا عِندَهُ قالَ هٰذا مِن فَضلِ رَبّي لِيَبلُوَني أَأَشكُرُ أَم أَكفُرُ ۖ وَمَن شَكَرَ فَإِنَّما يَشكُرُ لِنَفسِهِ ۖ وَمَن كَفَرَ فَإِنَّ رَبّي غَنِيٌّ كَريمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmcc{قالَ نَكِّروا لَها عَرشَها نَنظُر أَتَهتَدي أَم تَكونُ مِنَ الَّذينَ لا يَهتَدونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmcci{فَلَمّا جاءَت قيلَ أَهٰكَذا عَرشُكِ ۖ قالَت كَأَنَّهُ هُوَ ۚ وَأوتينَا العِلمَ مِن قَبلِها وَكُنّا مُسلِمينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmccii{وَصَدَّها ما كانَت تَعبُدُ مِن دونِ اللَّهِ ۖ إِنَّها كانَت مِن قَومٍ كافِرينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmcciii{قيلَ لَهَا ادخُلِي الصَّرحَ ۖ فَلَمّا رَأَتهُ حَسِبَتهُ لُجَّةً وَكَشَفَت عَن ساقَيها ۚ قالَ إِنَّهُ صَرحٌ مُمَرَّدٌ مِن قَواريرَ ۗ قالَت رَبِّ إِنّي ظَلَمتُ نَفسي وَأَسلَمتُ مَعَ سُلَيمانَ لِلَّهِ رَبِّ العالَمينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmcciv{وَلَقَد أَرسَلنا إِلىٰ ثَمودَ أَخاهُم صالِحًا أَنِ اعبُدُوا اللَّهَ فَإِذا هُم فَريقانِ يَختَصِمونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmccv{قالَ يا قَومِ لِمَ تَستَعجِلونَ بِالسَّيِّئَةِ قَبلَ الحَسَنَةِ ۖ لَولا تَستَغفِرونَ اللَّهَ لَعَلَّكُم تُرحَمونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmccvi{قالُوا اطَّيَّرنا بِكَ وَبِمَن مَعَكَ ۚ قالَ طائِرُكُم عِندَ اللَّهِ ۖ بَل أَنتُم قَومٌ تُفتَنونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmccvii{وَكانَ فِي المَدينَةِ تِسعَةُ رَهطٍ يُفسِدونَ فِي الأَرضِ وَلا يُصلِحونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmccviii{قالوا تَقاسَموا بِاللَّهِ لَنُبَيِّتَنَّهُ وَأَهلَهُ ثُمَّ لَنَقولَنَّ لِوَلِيِّهِ ما شَهِدنا مَهلِكَ أَهلِهِ وَإِنّا لَصادِقونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmccix{وَمَكَروا مَكرًا وَمَكَرنا مَكرًا وَهُم لا يَشعُرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmccx{فَانظُر كَيفَ كانَ عاقِبَةُ مَكرِهِم أَنّا دَمَّرناهُم وَقَومَهُم أَجمَعينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmccxi{فَتِلكَ بُيوتُهُم خاوِيَةً بِما ظَلَموا ۗ إِنَّ في ذٰلِكَ لَآيَةً لِقَومٍ يَعلَمونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmccxii{وَأَنجَينَا الَّذينَ آمَنوا وَكانوا يَتَّقونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmccxiii{وَلوطًا إِذ قالَ لِقَومِهِ أَتَأتونَ الفاحِشَةَ وَأَنتُم تُبصِرونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmccxiv{أَئِنَّكُم لَتَأتونَ الرِّجالَ شَهوَةً مِن دونِ النِّساءِ ۚ بَل أَنتُم قَومٌ تَجهَلونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmccxv{۞ فَما كانَ جَوابَ قَومِهِ إِلّا أَن قالوا أَخرِجوا آلَ لوطٍ مِن قَريَتِكُم ۖ إِنَّهُم أُناسٌ يَتَطَهَّرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmccxvi{فَأَنجَيناهُ وَأَهلَهُ إِلَّا امرَأَتَهُ قَدَّرناها مِنَ الغابِرينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmccxvii{وَأَمطَرنا عَلَيهِم مَطَرًا ۖ فَساءَ مَطَرُ المُنذَرينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmccxviii{قُلِ الحَمدُ لِلَّهِ وَسَلامٌ عَلىٰ عِبادِهِ الَّذينَ اصطَفىٰ ۗ آللَّهُ خَيرٌ أَمّا يُشرِكونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmccxix{أَمَّن خَلَقَ السَّماواتِ وَالأَرضَ وَأَنزَلَ لَكُم مِنَ السَّماءِ ماءً فَأَنبَتنا بِهِ حَدائِقَ ذاتَ بَهجَةٍ ما كانَ لَكُم أَن تُنبِتوا شَجَرَها ۗ أَإِلٰهٌ مَعَ اللَّهِ ۚ بَل هُم قَومٌ يَعدِلونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmccxx{أَمَّن جَعَلَ الأَرضَ قَرارًا وَجَعَلَ خِلالَها أَنهارًا وَجَعَلَ لَها رَواسِيَ وَجَعَلَ بَينَ البَحرَينِ حاجِزًا ۗ أَإِلٰهٌ مَعَ اللَّهِ ۚ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmccxxi{أَمَّن يُجيبُ المُضطَرَّ إِذا دَعاهُ وَيَكشِفُ السّوءَ وَيَجعَلُكُم خُلَفاءَ الأَرضِ ۗ أَإِلٰهٌ مَعَ اللَّهِ ۚ قَليلًا ما تَذَكَّرونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmccxxii{أَمَّن يَهديكُم في ظُلُماتِ البَرِّ وَالبَحرِ وَمَن يُرسِلُ الرِّياحَ بُشرًا بَينَ يَدَي رَحمَتِهِ ۗ أَإِلٰهٌ مَعَ اللَّهِ ۚ تَعالَى اللَّهُ عَمّا يُشرِكونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmccxxiii{أَمَّن يَبدَأُ الخَلقَ ثُمَّ يُعيدُهُ وَمَن يَرزُقُكُم مِنَ السَّماءِ وَالأَرضِ ۗ أَإِلٰهٌ مَعَ اللَّهِ ۚ قُل هاتوا بُرهانَكُم إِن كُنتُم صادِقينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmccxxiv{قُل لا يَعلَمُ مَن فِي السَّماواتِ وَالأَرضِ الغَيبَ إِلَّا اللَّهُ ۚ وَما يَشعُرونَ أَيّانَ يُبعَثونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmccxxv{بَلِ ادّارَكَ عِلمُهُم فِي الآخِرَةِ ۚ بَل هُم في شَكٍّ مِنها ۖ بَل هُم مِنها عَمونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmccxxvi{وَقالَ الَّذينَ كَفَروا أَإِذا كُنّا تُرابًا وَآباؤُنا أَئِنّا لَمُخرَجونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmccxxvii{لَقَد وُعِدنا هٰذا نَحنُ وَآباؤُنا مِن قَبلُ إِن هٰذا إِلّا أَساطيرُ الأَوَّلينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmccxxviii{قُل سيروا فِي الأَرضِ فَانظُروا كَيفَ كانَ عاقِبَةُ المُجرِمينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmccxxix{وَلا تَحزَن عَلَيهِم وَلا تَكُن في ضَيقٍ مِمّا يَمكُرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmccxxx{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صادِقينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmccxxxi{قُل عَسىٰ أَن يَكونَ رَدِفَ لَكُم بَعضُ الَّذي تَستَعجِلونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmccxxxii{وَإِنَّ رَبَّكَ لَذو فَضلٍ عَلَى النّاسِ وَلٰكِنَّ أَكثَرَهُم لا يَشكُرونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmccxxxiii{وَإِنَّ رَبَّكَ لَيَعلَمُ ما تُكِنُّ صُدورُهُم وَما يُعلِنونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmccxxxiv{وَما مِن غائِبَةٍ فِي السَّماءِ وَالأَرضِ إِلّا في كِتابٍ مُبينٍ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmccxxxv{إِنَّ هٰذَا القُرآنَ يَقُصُّ عَلىٰ بَني إِسرائيلَ أَكثَرَ الَّذي هُم فيهِ يَختَلِفونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmccxxxvi{وَإِنَّهُ لَهُدًى وَرَحمَةٌ لِلمُؤمِنينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmccxxxvii{إِنَّ رَبَّكَ يَقضي بَينَهُم بِحُكمِهِ ۚ وَهُوَ العَزيزُ العَليمُ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmccxxxviii{فَتَوَكَّل عَلَى اللَّهِ ۖ إِنَّكَ عَلَى الحَقِّ المُبينِ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmccxxxix{إِنَّكَ لا تُسمِعُ المَوتىٰ وَلا تُسمِعُ الصُّمَّ الدُّعاءَ إِذا وَلَّوا مُدبِرينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmccxl{وَما أَنتَ بِهادِي العُميِ عَن ضَلالَتِهِم ۖ إِن تُسمِعُ إِلّا مَن يُؤمِنُ بِآياتِنا فَهُم مُسلِمونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmccxli{۞ وَإِذا وَقَعَ القَولُ عَلَيهِم أَخرَجنا لَهُم دابَّةً مِنَ الأَرضِ تُكَلِّمُهُم أَنَّ النّاسَ كانوا بِآياتِنا لا يوقِنونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmccxlii{وَيَومَ نَحشُرُ مِن كُلِّ أُمَّةٍ فَوجًا مِمَّن يُكَذِّبُ بِآياتِنا فَهُم يوزَعونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmccxliii{حَتّىٰ إِذا جاءوا قالَ أَكَذَّبتُم بِآياتي وَلَم تُحيطوا بِها عِلمًا أَمّاذا كُنتُم تَعمَلونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmccxliv{وَوَقَعَ القَولُ عَلَيهِم بِما ظَلَموا فَهُم لا يَنطِقونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmccxlv{أَلَم يَرَوا أَنّا جَعَلنَا اللَّيلَ لِيَسكُنوا فيهِ وَالنَّهارَ مُبصِرًا ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmccxlvi{وَيَومَ يُنفَخُ فِي الصّورِ فَفَزِعَ مَن فِي السَّماواتِ وَمَن فِي الأَرضِ إِلّا مَن شاءَ اللَّهُ ۚ وَكُلٌّ أَتَوهُ داخِرينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmccxlvii{وَتَرَى الجِبالَ تَحسَبُها جامِدَةً وَهِيَ تَمُرُّ مَرَّ السَّحابِ ۚ صُنعَ اللَّهِ الَّذي أَتقَنَ كُلَّ شَيءٍ ۚ إِنَّهُ خَبيرٌ بِما تَفعَلونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmccxlviii{مَن جاءَ بِالحَسَنَةِ فَلَهُ خَيرٌ مِنها وَهُم مِن فَزَعٍ يَومَئِذٍ آمِنونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmccxlix{وَمَن جاءَ بِالسَّيِّئَةِ فَكُبَّت وُجوهُهُم فِي النّارِ هَل تُجزَونَ إِلّا ما كُنتُم تَعمَلونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmccl{إِنَّما أُمِرتُ أَن أَعبُدَ رَبَّ هٰذِهِ البَلدَةِ الَّذي حَرَّمَها وَلَهُ كُلُّ شَيءٍ ۖ وَأُمِرتُ أَن أَكونَ مِنَ المُسلِمينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmccli{وَأَن أَتلُوَ القُرآنَ ۖ فَمَنِ اهتَدىٰ فَإِنَّما يَهتَدي لِنَفسِهِ ۖ وَمَن ضَلَّ فَقُل إِنَّما أَنا مِنَ المُنذِرينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmcclii{وَقُلِ الحَمدُ لِلَّهِ سَيُريكُم آياتِهِ فَتَعرِفونَها ۚ وَما رَبُّكَ بِغافِلٍ عَمّا تَعمَلونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmccliii{\basmalah طسم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmccliv{تِلكَ آياتُ الكِتابِ المُبينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcclv{نَتلو عَلَيكَ مِن نَبَإِ موسىٰ وَفِرعَونَ بِالحَقِّ لِقَومٍ يُؤمِنونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcclvi{إِنَّ فِرعَونَ عَلا فِي الأَرضِ وَجَعَلَ أَهلَها شِيَعًا يَستَضعِفُ طائِفَةً مِنهُم يُذَبِّحُ أَبناءَهُم وَيَستَحيي نِساءَهُم ۚ إِنَّهُ كانَ مِنَ المُفسِدينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcclvii{وَنُريدُ أَن نَمُنَّ عَلَى الَّذينَ استُضعِفوا فِي الأَرضِ وَنَجعَلَهُم أَئِمَّةً وَنَجعَلَهُمُ الوارِثينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcclviii{وَنُمَكِّنَ لَهُم فِي الأَرضِ وَنُرِيَ فِرعَونَ وَهامانَ وَجُنودَهُما مِنهُم ما كانوا يَحذَرونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcclix{وَأَوحَينا إِلىٰ أُمِّ موسىٰ أَن أَرضِعيهِ ۖ فَإِذا خِفتِ عَلَيهِ فَأَلقيهِ فِي اليَمِّ وَلا تَخافي وَلا تَحزَني ۖ إِنّا رادّوهُ إِلَيكِ وَجاعِلوهُ مِنَ المُرسَلينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcclx{فَالتَقَطَهُ آلُ فِرعَونَ لِيَكونَ لَهُم عَدُوًّا وَحَزَنًا ۗ إِنَّ فِرعَونَ وَهامانَ وَجُنودَهُما كانوا خاطِئينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcclxi{وَقالَتِ امرَأَتُ فِرعَونَ قُرَّتُ عَينٍ لي وَلَكَ ۖ لا تَقتُلوهُ عَسىٰ أَن يَنفَعَنا أَو نَتَّخِذَهُ وَلَدًا وَهُم لا يَشعُرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcclxii{وَأَصبَحَ فُؤادُ أُمِّ موسىٰ فارِغًا ۖ إِن كادَت لَتُبدي بِهِ لَولا أَن رَبَطنا عَلىٰ قَلبِها لِتَكونَ مِنَ المُؤمِنينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcclxiii{وَقالَت لِأُختِهِ قُصّيهِ ۖ فَبَصُرَت بِهِ عَن جُنُبٍ وَهُم لا يَشعُرونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcclxiv{۞ وَحَرَّمنا عَلَيهِ المَراضِعَ مِن قَبلُ فَقالَت هَل أَدُلُّكُم عَلىٰ أَهلِ بَيتٍ يَكفُلونَهُ لَكُم وَهُم لَهُ ناصِحونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcclxv{فَرَدَدناهُ إِلىٰ أُمِّهِ كَي تَقَرَّ عَينُها وَلا تَحزَنَ وَلِتَعلَمَ أَنَّ وَعدَ اللَّهِ حَقٌّ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcclxvi{وَلَمّا بَلَغَ أَشُدَّهُ وَاستَوىٰ آتَيناهُ حُكمًا وَعِلمًا ۚ وَكَذٰلِكَ نَجزِي المُحسِنينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcclxvii{وَدَخَلَ المَدينَةَ عَلىٰ حينِ غَفلَةٍ مِن أَهلِها فَوَجَدَ فيها رَجُلَينِ يَقتَتِلانِ هٰذا مِن شيعَتِهِ وَهٰذا مِن عَدُوِّهِ ۖ فَاستَغاثَهُ الَّذي مِن شيعَتِهِ عَلَى الَّذي مِن عَدُوِّهِ فَوَكَزَهُ موسىٰ فَقَضىٰ عَلَيهِ ۖ قالَ هٰذا مِن عَمَلِ الشَّيطانِ ۖ إِنَّهُ عَدُوٌّ مُضِلٌّ مُبينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcclxviii{قالَ رَبِّ إِنّي ظَلَمتُ نَفسي فَاغفِر لي فَغَفَرَ لَهُ ۚ إِنَّهُ هُوَ الغَفورُ الرَّحيمُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcclxix{قالَ رَبِّ بِما أَنعَمتَ عَلَيَّ فَلَن أَكونَ ظَهيرًا لِلمُجرِمينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcclxx{فَأَصبَحَ فِي المَدينَةِ خائِفًا يَتَرَقَّبُ فَإِذَا الَّذِي استَنصَرَهُ بِالأَمسِ يَستَصرِخُهُ ۚ قالَ لَهُ موسىٰ إِنَّكَ لَغَوِيٌّ مُبينٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcclxxi{فَلَمّا أَن أَرادَ أَن يَبطِشَ بِالَّذي هُوَ عَدُوٌّ لَهُما قالَ يا موسىٰ أَتُريدُ أَن تَقتُلَني كَما قَتَلتَ نَفسًا بِالأَمسِ ۖ إِن تُريدُ إِلّا أَن تَكونَ جَبّارًا فِي الأَرضِ وَما تُريدُ أَن تَكونَ مِنَ المُصلِحينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcclxxii{وَجاءَ رَجُلٌ مِن أَقصَى المَدينَةِ يَسعىٰ قالَ يا موسىٰ إِنَّ المَلَأَ يَأتَمِرونَ بِكَ لِيَقتُلوكَ فَاخرُج إِنّي لَكَ مِنَ النّاصِحينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcclxxiii{فَخَرَجَ مِنها خائِفًا يَتَرَقَّبُ ۖ قالَ رَبِّ نَجِّني مِنَ القَومِ الظّالِمينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcclxxiv{وَلَمّا تَوَجَّهَ تِلقاءَ مَديَنَ قالَ عَسىٰ رَبّي أَن يَهدِيَني سَواءَ السَّبيلِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcclxxv{وَلَمّا وَرَدَ ماءَ مَديَنَ وَجَدَ عَلَيهِ أُمَّةً مِنَ النّاسِ يَسقونَ وَوَجَدَ مِن دونِهِمُ امرَأَتَينِ تَذودانِ ۖ قالَ ما خَطبُكُما ۖ قالَتا لا نَسقي حَتّىٰ يُصدِرَ الرِّعاءُ ۖ وَأَبونا شَيخٌ كَبيرٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcclxxvi{فَسَقىٰ لَهُما ثُمَّ تَوَلّىٰ إِلَى الظِّلِّ فَقالَ رَبِّ إِنّي لِما أَنزَلتَ إِلَيَّ مِن خَيرٍ فَقيرٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcclxxvii{فَجاءَتهُ إِحداهُما تَمشي عَلَى استِحياءٍ قالَت إِنَّ أَبي يَدعوكَ لِيَجزِيَكَ أَجرَ ما سَقَيتَ لَنا ۚ فَلَمّا جاءَهُ وَقَصَّ عَلَيهِ القَصَصَ قالَ لا تَخَف ۖ نَجَوتَ مِنَ القَومِ الظّالِمينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcclxxviii{قالَت إِحداهُما يا أَبَتِ استَأجِرهُ ۖ إِنَّ خَيرَ مَنِ استَأجَرتَ القَوِيُّ الأَمينُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcclxxix{قالَ إِنّي أُريدُ أَن أُنكِحَكَ إِحدَى ابنَتَيَّ هاتَينِ عَلىٰ أَن تَأجُرَني ثَمانِيَ حِجَجٍ ۖ فَإِن أَتمَمتَ عَشرًا فَمِن عِندِكَ ۖ وَما أُريدُ أَن أَشُقَّ عَلَيكَ ۚ سَتَجِدُني إِن شاءَ اللَّهُ مِنَ الصّالِحينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcclxxx{قالَ ذٰلِكَ بَيني وَبَينَكَ ۖ أَيَّمَا الأَجَلَينِ قَضَيتُ فَلا عُدوانَ عَلَيَّ ۖ وَاللَّهُ عَلىٰ ما نَقولُ وَكيلٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcclxxxi{۞ فَلَمّا قَضىٰ موسَى الأَجَلَ وَسارَ بِأَهلِهِ آنَسَ مِن جانِبِ الطّورِ نارًا قالَ لِأَهلِهِ امكُثوا إِنّي آنَستُ نارًا لَعَلّي آتيكُم مِنها بِخَبَرٍ أَو جَذوَةٍ مِنَ النّارِ لَعَلَّكُم تَصطَلونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmcclxxxii{فَلَمّا أَتاها نودِيَ مِن شاطِئِ الوادِ الأَيمَنِ فِي البُقعَةِ المُبارَكَةِ مِنَ الشَّجَرَةِ أَن يا موسىٰ إِنّي أَنَا اللَّهُ رَبُّ العالَمينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmcclxxxiii{وَأَن أَلقِ عَصاكَ ۖ فَلَمّا رَآها تَهتَزُّ كَأَنَّها جانٌّ وَلّىٰ مُدبِرًا وَلَم يُعَقِّب ۚ يا موسىٰ أَقبِل وَلا تَخَف ۖ إِنَّكَ مِنَ الآمِنينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmcclxxxiv{اسلُك يَدَكَ في جَيبِكَ تَخرُج بَيضاءَ مِن غَيرِ سوءٍ وَاضمُم إِلَيكَ جَناحَكَ مِنَ الرَّهبِ ۖ فَذانِكَ بُرهانانِ مِن رَبِّكَ إِلىٰ فِرعَونَ وَمَلَئِهِ ۚ إِنَّهُم كانوا قَومًا فاسِقينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmcclxxxv{قالَ رَبِّ إِنّي قَتَلتُ مِنهُم نَفسًا فَأَخافُ أَن يَقتُلونِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmcclxxxvi{وَأَخي هارونُ هُوَ أَفصَحُ مِنّي لِسانًا فَأَرسِلهُ مَعِيَ رِدءًا يُصَدِّقُني ۖ إِنّي أَخافُ أَن يُكَذِّبونِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmcclxxxvii{قالَ سَنَشُدُّ عَضُدَكَ بِأَخيكَ وَنَجعَلُ لَكُما سُلطانًا فَلا يَصِلونَ إِلَيكُما ۚ بِآياتِنا أَنتُما وَمَنِ اتَّبَعَكُمَا الغالِبونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmcclxxxviii{فَلَمّا جاءَهُم موسىٰ بِآياتِنا بَيِّناتٍ قالوا ما هٰذا إِلّا سِحرٌ مُفتَرًى وَما سَمِعنا بِهٰذا في آبائِنَا الأَوَّلينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmcclxxxix{وَقالَ موسىٰ رَبّي أَعلَمُ بِمَن جاءَ بِالهُدىٰ مِن عِندِهِ وَمَن تَكونُ لَهُ عاقِبَةُ الدّارِ ۖ إِنَّهُ لا يُفلِحُ الظّالِمونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmccxc{وَقالَ فِرعَونُ يا أَيُّهَا المَلَأُ ما عَلِمتُ لَكُم مِن إِلٰهٍ غَيري فَأَوقِد لي يا هامانُ عَلَى الطّينِ فَاجعَل لي صَرحًا لَعَلّي أَطَّلِعُ إِلىٰ إِلٰهِ موسىٰ وَإِنّي لَأَظُنُّهُ مِنَ الكاذِبينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmccxci{وَاستَكبَرَ هُوَ وَجُنودُهُ فِي الأَرضِ بِغَيرِ الحَقِّ وَظَنّوا أَنَّهُم إِلَينا لا يُرجَعونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmccxcii{فَأَخَذناهُ وَجُنودَهُ فَنَبَذناهُم فِي اليَمِّ ۖ فَانظُر كَيفَ كانَ عاقِبَةُ الظّالِمينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmccxciii{وَجَعَلناهُم أَئِمَّةً يَدعونَ إِلَى النّارِ ۖ وَيَومَ القِيامَةِ لا يُنصَرونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmccxciv{وَأَتبَعناهُم في هٰذِهِ الدُّنيا لَعنَةً ۖ وَيَومَ القِيامَةِ هُم مِنَ المَقبوحينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmccxcv{وَلَقَد آتَينا موسَى الكِتابَ مِن بَعدِ ما أَهلَكنَا القُرونَ الأولىٰ بَصائِرَ لِلنّاسِ وَهُدًى وَرَحمَةً لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmccxcvi{وَما كُنتَ بِجانِبِ الغَربِيِّ إِذ قَضَينا إِلىٰ موسَى الأَمرَ وَما كُنتَ مِنَ الشّاهِدينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmccxcvii{وَلٰكِنّا أَنشَأنا قُرونًا فَتَطاوَلَ عَلَيهِمُ العُمُرُ ۚ وَما كُنتَ ثاوِيًا في أَهلِ مَديَنَ تَتلو عَلَيهِم آياتِنا وَلٰكِنّا كُنّا مُرسِلينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmccxcviii{وَما كُنتَ بِجانِبِ الطّورِ إِذ نادَينا وَلٰكِن رَحمَةً مِن رَبِّكَ لِتُنذِرَ قَومًا ما أَتاهُم مِن نَذيرٍ مِن قَبلِكَ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmccxcix{وَلَولا أَن تُصيبَهُم مُصيبَةٌ بِما قَدَّمَت أَيديهِم فَيَقولوا رَبَّنا لَولا أَرسَلتَ إِلَينا رَسولًا فَنَتَّبِعَ آياتِكَ وَنَكونَ مِنَ المُؤمِنينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmccc{فَلَمّا جاءَهُمُ الحَقُّ مِن عِندِنا قالوا لَولا أوتِيَ مِثلَ ما أوتِيَ موسىٰ ۚ أَوَلَم يَكفُروا بِما أوتِيَ موسىٰ مِن قَبلُ ۖ قالوا سِحرانِ تَظاهَرا وَقالوا إِنّا بِكُلٍّ كافِرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmccci{قُل فَأتوا بِكِتابٍ مِن عِندِ اللَّهِ هُوَ أَهدىٰ مِنهُما أَتَّبِعهُ إِن كُنتُم صادِقينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmcccii{فَإِن لَم يَستَجيبوا لَكَ فَاعلَم أَنَّما يَتَّبِعونَ أَهواءَهُم ۚ وَمَن أَضَلُّ مِمَّنِ اتَّبَعَ هَواهُ بِغَيرِ هُدًى مِنَ اللَّهِ ۚ إِنَّ اللَّهَ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmccciii{۞ وَلَقَد وَصَّلنا لَهُمُ القَولَ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmccciv{الَّذينَ آتَيناهُمُ الكِتابَ مِن قَبلِهِ هُم بِهِ يُؤمِنونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmcccv{وَإِذا يُتلىٰ عَلَيهِم قالوا آمَنّا بِهِ إِنَّهُ الحَقُّ مِن رَبِّنا إِنّا كُنّا مِن قَبلِهِ مُسلِمينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmcccvi{أُولٰئِكَ يُؤتَونَ أَجرَهُم مَرَّتَينِ بِما صَبَروا وَيَدرَءونَ بِالحَسَنَةِ السَّيِّئَةَ وَمِمّا رَزَقناهُم يُنفِقونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmcccvii{وَإِذا سَمِعُوا اللَّغوَ أَعرَضوا عَنهُ وَقالوا لَنا أَعمالُنا وَلَكُم أَعمالُكُم سَلامٌ عَلَيكُم لا نَبتَغِي الجاهِلينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmcccviii{إِنَّكَ لا تَهدي مَن أَحبَبتَ وَلٰكِنَّ اللَّهَ يَهدي مَن يَشاءُ ۚ وَهُوَ أَعلَمُ بِالمُهتَدينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmcccix{وَقالوا إِن نَتَّبِعِ الهُدىٰ مَعَكَ نُتَخَطَّف مِن أَرضِنا ۚ أَوَلَم نُمَكِّن لَهُم حَرَمًا آمِنًا يُجبىٰ إِلَيهِ ثَمَراتُ كُلِّ شَيءٍ رِزقًا مِن لَدُنّا وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmcccx{وَكَم أَهلَكنا مِن قَريَةٍ بَطِرَت مَعيشَتَها ۖ فَتِلكَ مَساكِنُهُم لَم تُسكَن مِن بَعدِهِم إِلّا قَليلًا ۖ وَكُنّا نَحنُ الوارِثينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmcccxi{وَما كانَ رَبُّكَ مُهلِكَ القُرىٰ حَتّىٰ يَبعَثَ في أُمِّها رَسولًا يَتلو عَلَيهِم آياتِنا ۚ وَما كُنّا مُهلِكِي القُرىٰ إِلّا وَأَهلُها ظالِمونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmcccxii{وَما أوتيتُم مِن شَيءٍ فَمَتاعُ الحَياةِ الدُّنيا وَزينَتُها ۚ وَما عِندَ اللَّهِ خَيرٌ وَأَبقىٰ ۚ أَفَلا تَعقِلونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmcccxiii{أَفَمَن وَعَدناهُ وَعدًا حَسَنًا فَهُوَ لاقيهِ كَمَن مَتَّعناهُ مَتاعَ الحَياةِ الدُّنيا ثُمَّ هُوَ يَومَ القِيامَةِ مِنَ المُحضَرينَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmcccxiv{وَيَومَ يُناديهِم فَيَقولُ أَينَ شُرَكائِيَ الَّذينَ كُنتُم تَزعُمونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmcccxv{قالَ الَّذينَ حَقَّ عَلَيهِمُ القَولُ رَبَّنا هٰؤُلاءِ الَّذينَ أَغوَينا أَغوَيناهُم كَما غَوَينا ۖ تَبَرَّأنا إِلَيكَ ۖ ما كانوا إِيّانا يَعبُدونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmcccxvi{وَقيلَ ادعوا شُرَكاءَكُم فَدَعَوهُم فَلَم يَستَجيبوا لَهُم وَرَأَوُا العَذابَ ۚ لَو أَنَّهُم كانوا يَهتَدونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmcccxvii{وَيَومَ يُناديهِم فَيَقولُ ماذا أَجَبتُمُ المُرسَلينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmcccxviii{فَعَمِيَت عَلَيهِمُ الأَنباءُ يَومَئِذٍ فَهُم لا يَتَساءَلونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmcccxix{فَأَمّا مَن تابَ وَآمَنَ وَعَمِلَ صالِحًا فَعَسىٰ أَن يَكونَ مِنَ المُفلِحينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmcccxx{وَرَبُّكَ يَخلُقُ ما يَشاءُ وَيَختارُ ۗ ما كانَ لَهُمُ الخِيَرَةُ ۚ سُبحانَ اللَّهِ وَتَعالىٰ عَمّا يُشرِكونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmcccxxi{وَرَبُّكَ يَعلَمُ ما تُكِنُّ صُدورُهُم وَما يُعلِنونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmcccxxii{وَهُوَ اللَّهُ لا إِلٰهَ إِلّا هُوَ ۖ لَهُ الحَمدُ فِي الأولىٰ وَالآخِرَةِ ۖ وَلَهُ الحُكمُ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmcccxxiii{قُل أَرَأَيتُم إِن جَعَلَ اللَّهُ عَلَيكُمُ اللَّيلَ سَرمَدًا إِلىٰ يَومِ القِيامَةِ مَن إِلٰهٌ غَيرُ اللَّهِ يَأتيكُم بِضِياءٍ ۖ أَفَلا تَسمَعونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmcccxxiv{قُل أَرَأَيتُم إِن جَعَلَ اللَّهُ عَلَيكُمُ النَّهارَ سَرمَدًا إِلىٰ يَومِ القِيامَةِ مَن إِلٰهٌ غَيرُ اللَّهِ يَأتيكُم بِلَيلٍ تَسكُنونَ فيهِ ۖ أَفَلا تُبصِرونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmcccxxv{وَمِن رَحمَتِهِ جَعَلَ لَكُمُ اللَّيلَ وَالنَّهارَ لِتَسكُنوا فيهِ وَلِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmcccxxvi{وَيَومَ يُناديهِم فَيَقولُ أَينَ شُرَكائِيَ الَّذينَ كُنتُم تَزعُمونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmcccxxvii{وَنَزَعنا مِن كُلِّ أُمَّةٍ شَهيدًا فَقُلنا هاتوا بُرهانَكُم فَعَلِموا أَنَّ الحَقَّ لِلَّهِ وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmcccxxviii{۞ إِنَّ قارونَ كانَ مِن قَومِ موسىٰ فَبَغىٰ عَلَيهِم ۖ وَآتَيناهُ مِنَ الكُنوزِ ما إِنَّ مَفاتِحَهُ لَتَنوءُ بِالعُصبَةِ أُولِي القُوَّةِ إِذ قالَ لَهُ قَومُهُ لا تَفرَح ۖ إِنَّ اللَّهَ لا يُحِبُّ الفَرِحينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmcccxxix{وَابتَغِ فيما آتاكَ اللَّهُ الدّارَ الآخِرَةَ ۖ وَلا تَنسَ نَصيبَكَ مِنَ الدُّنيا ۖ وَأَحسِن كَما أَحسَنَ اللَّهُ إِلَيكَ ۖ وَلا تَبغِ الفَسادَ فِي الأَرضِ ۖ إِنَّ اللَّهَ لا يُحِبُّ المُفسِدينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmcccxxx{قالَ إِنَّما أوتيتُهُ عَلىٰ عِلمٍ عِندي ۚ أَوَلَم يَعلَم أَنَّ اللَّهَ قَد أَهلَكَ مِن قَبلِهِ مِنَ القُرونِ مَن هُوَ أَشَدُّ مِنهُ قُوَّةً وَأَكثَرُ جَمعًا ۚ وَلا يُسأَلُ عَن ذُنوبِهِمُ المُجرِمونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmcccxxxi{فَخَرَجَ عَلىٰ قَومِهِ في زينَتِهِ ۖ قالَ الَّذينَ يُريدونَ الحَياةَ الدُّنيا يا لَيتَ لَنا مِثلَ ما أوتِيَ قارونُ إِنَّهُ لَذو حَظٍّ عَظيمٍ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmcccxxxii{وَقالَ الَّذينَ أوتُوا العِلمَ وَيلَكُم ثَوابُ اللَّهِ خَيرٌ لِمَن آمَنَ وَعَمِلَ صالِحًا وَلا يُلَقّاها إِلَّا الصّابِرونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmcccxxxiii{فَخَسَفنا بِهِ وَبِدارِهِ الأَرضَ فَما كانَ لَهُ مِن فِئَةٍ يَنصُرونَهُ مِن دونِ اللَّهِ وَما كانَ مِنَ المُنتَصِرينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmcccxxxiv{وَأَصبَحَ الَّذينَ تَمَنَّوا مَكانَهُ بِالأَمسِ يَقولونَ وَيكَأَنَّ اللَّهَ يَبسُطُ الرِّزقَ لِمَن يَشاءُ مِن عِبادِهِ وَيَقدِرُ ۖ لَولا أَن مَنَّ اللَّهُ عَلَينا لَخَسَفَ بِنا ۖ وَيكَأَنَّهُ لا يُفلِحُ الكافِرونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmcccxxxv{تِلكَ الدّارُ الآخِرَةُ نَجعَلُها لِلَّذينَ لا يُريدونَ عُلُوًّا فِي الأَرضِ وَلا فَسادًا ۚ وَالعاقِبَةُ لِلمُتَّقينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmcccxxxvi{مَن جاءَ بِالحَسَنَةِ فَلَهُ خَيرٌ مِنها ۖ وَمَن جاءَ بِالسَّيِّئَةِ فَلا يُجزَى الَّذينَ عَمِلُوا السَّيِّئَاتِ إِلّا ما كانوا يَعمَلونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmcccxxxvii{إِنَّ الَّذي فَرَضَ عَلَيكَ القُرآنَ لَرادُّكَ إِلىٰ مَعادٍ ۚ قُل رَبّي أَعلَمُ مَن جاءَ بِالهُدىٰ وَمَن هُوَ في ضَلالٍ مُبينٍ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmcccxxxviii{وَما كُنتَ تَرجو أَن يُلقىٰ إِلَيكَ الكِتابُ إِلّا رَحمَةً مِن رَبِّكَ ۖ فَلا تَكونَنَّ ظَهيرًا لِلكافِرينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmcccxxxix{وَلا يَصُدُّنَّكَ عَن آياتِ اللَّهِ بَعدَ إِذ أُنزِلَت إِلَيكَ ۖ وَادعُ إِلىٰ رَبِّكَ ۖ وَلا تَكونَنَّ مِنَ المُشرِكينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmcccxl{وَلا تَدعُ مَعَ اللَّهِ إِلٰهًا آخَرَ ۘ لا إِلٰهَ إِلّا هُوَ ۚ كُلُّ شَيءٍ هالِكٌ إِلّا وَجهَهُ ۚ لَهُ الحُكمُ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmcccxli{\basmalah الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcccxlii{أَحَسِبَ النّاسُ أَن يُترَكوا أَن يَقولوا آمَنّا وَهُم لا يُفتَنونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcccxliii{وَلَقَد فَتَنَّا الَّذينَ مِن قَبلِهِم ۖ فَلَيَعلَمَنَّ اللَّهُ الَّذينَ صَدَقوا وَلَيَعلَمَنَّ الكاذِبينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcccxliv{أَم حَسِبَ الَّذينَ يَعمَلونَ السَّيِّئَاتِ أَن يَسبِقونا ۚ ساءَ ما يَحكُمونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcccxlv{مَن كانَ يَرجو لِقاءَ اللَّهِ فَإِنَّ أَجَلَ اللَّهِ لَآتٍ ۚ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcccxlvi{وَمَن جاهَدَ فَإِنَّما يُجاهِدُ لِنَفسِهِ ۚ إِنَّ اللَّهَ لَغَنِيٌّ عَنِ العالَمينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcccxlvii{وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لَنُكَفِّرَنَّ عَنهُم سَيِّئَاتِهِم وَلَنَجزِيَنَّهُم أَحسَنَ الَّذي كانوا يَعمَلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcccxlviii{وَوَصَّينَا الإِنسانَ بِوالِدَيهِ حُسنًا ۖ وَإِن جاهَداكَ لِتُشرِكَ بي ما لَيسَ لَكَ بِهِ عِلمٌ فَلا تُطِعهُما ۚ إِلَيَّ مَرجِعُكُم فَأُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcccxlix{وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لَنُدخِلَنَّهُم فِي الصّالِحينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcccl{وَمِنَ النّاسِ مَن يَقولُ آمَنّا بِاللَّهِ فَإِذا أوذِيَ فِي اللَّهِ جَعَلَ فِتنَةَ النّاسِ كَعَذابِ اللَّهِ وَلَئِن جاءَ نَصرٌ مِن رَبِّكَ لَيَقولُنَّ إِنّا كُنّا مَعَكُم ۚ أَوَلَيسَ اللَّهُ بِأَعلَمَ بِما في صُدورِ العالَمينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcccli{وَلَيَعلَمَنَّ اللَّهُ الَّذينَ آمَنوا وَلَيَعلَمَنَّ المُنافِقينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmccclii{وَقالَ الَّذينَ كَفَروا لِلَّذينَ آمَنُوا اتَّبِعوا سَبيلَنا وَلنَحمِل خَطاياكُم وَما هُم بِحامِلينَ مِن خَطاياهُم مِن شَيءٍ ۖ إِنَّهُم لَكاذِبونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcccliii{وَلَيَحمِلُنَّ أَثقالَهُم وَأَثقالًا مَعَ أَثقالِهِم ۖ وَلَيُسأَلُنَّ يَومَ القِيامَةِ عَمّا كانوا يَفتَرونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcccliv{وَلَقَد أَرسَلنا نوحًا إِلىٰ قَومِهِ فَلَبِثَ فيهِم أَلفَ سَنَةٍ إِلّا خَمسينَ عامًا فَأَخَذَهُمُ الطّوفانُ وَهُم ظالِمونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmccclv{فَأَنجَيناهُ وَأَصحابَ السَّفينَةِ وَجَعَلناها آيَةً لِلعالَمينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmccclvi{وَإِبراهيمَ إِذ قالَ لِقَومِهِ اعبُدُوا اللَّهَ وَاتَّقوهُ ۖ ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmccclvii{إِنَّما تَعبُدونَ مِن دونِ اللَّهِ أَوثانًا وَتَخلُقونَ إِفكًا ۚ إِنَّ الَّذينَ تَعبُدونَ مِن دونِ اللَّهِ لا يَملِكونَ لَكُم رِزقًا فَابتَغوا عِندَ اللَّهِ الرِّزقَ وَاعبُدوهُ وَاشكُروا لَهُ ۖ إِلَيهِ تُرجَعونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmccclviii{وَإِن تُكَذِّبوا فَقَد كَذَّبَ أُمَمٌ مِن قَبلِكُم ۖ وَما عَلَى الرَّسولِ إِلَّا البَلاغُ المُبينُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmccclix{أَوَلَم يَرَوا كَيفَ يُبدِئُ اللَّهُ الخَلقَ ثُمَّ يُعيدُهُ ۚ إِنَّ ذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmccclx{قُل سيروا فِي الأَرضِ فَانظُروا كَيفَ بَدَأَ الخَلقَ ۚ ثُمَّ اللَّهُ يُنشِئُ النَّشأَةَ الآخِرَةَ ۚ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmccclxi{يُعَذِّبُ مَن يَشاءُ وَيَرحَمُ مَن يَشاءُ ۖ وَإِلَيهِ تُقلَبونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmccclxii{وَما أَنتُم بِمُعجِزينَ فِي الأَرضِ وَلا فِي السَّماءِ ۖ وَما لَكُم مِن دونِ اللَّهِ مِن وَلِيٍّ وَلا نَصيرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmccclxiii{وَالَّذينَ كَفَروا بِآياتِ اللَّهِ وَلِقائِهِ أُولٰئِكَ يَئِسوا مِن رَحمَتي وَأُولٰئِكَ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmccclxiv{فَما كانَ جَوابَ قَومِهِ إِلّا أَن قالُوا اقتُلوهُ أَو حَرِّقوهُ فَأَنجاهُ اللَّهُ مِنَ النّارِ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmccclxv{وَقالَ إِنَّمَا اتَّخَذتُم مِن دونِ اللَّهِ أَوثانًا مَوَدَّةَ بَينِكُم فِي الحَياةِ الدُّنيا ۖ ثُمَّ يَومَ القِيامَةِ يَكفُرُ بَعضُكُم بِبَعضٍ وَيَلعَنُ بَعضُكُم بَعضًا وَمَأواكُمُ النّارُ وَما لَكُم مِن ناصِرينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmccclxvi{۞ فَآمَنَ لَهُ لوطٌ ۘ وَقالَ إِنّي مُهاجِرٌ إِلىٰ رَبّي ۖ إِنَّهُ هُوَ العَزيزُ الحَكيمُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmccclxvii{وَوَهَبنا لَهُ إِسحاقَ وَيَعقوبَ وَجَعَلنا في ذُرِّيَّتِهِ النُّبُوَّةَ وَالكِتابَ وَآتَيناهُ أَجرَهُ فِي الدُّنيا ۖ وَإِنَّهُ فِي الآخِرَةِ لَمِنَ الصّالِحينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmccclxviii{وَلوطًا إِذ قالَ لِقَومِهِ إِنَّكُم لَتَأتونَ الفاحِشَةَ ما سَبَقَكُم بِها مِن أَحَدٍ مِنَ العالَمينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmccclxix{أَئِنَّكُم لَتَأتونَ الرِّجالَ وَتَقطَعونَ السَّبيلَ وَتَأتونَ في ناديكُمُ المُنكَرَ ۖ فَما كانَ جَوابَ قَومِهِ إِلّا أَن قالُوا ائتِنا بِعَذابِ اللَّهِ إِن كُنتَ مِنَ الصّادِقينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmccclxx{قالَ رَبِّ انصُرني عَلَى القَومِ المُفسِدينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmccclxxi{وَلَمّا جاءَت رُسُلُنا إِبراهيمَ بِالبُشرىٰ قالوا إِنّا مُهلِكو أَهلِ هٰذِهِ القَريَةِ ۖ إِنَّ أَهلَها كانوا ظالِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmccclxxii{قالَ إِنَّ فيها لوطًا ۚ قالوا نَحنُ أَعلَمُ بِمَن فيها ۖ لَنُنَجِّيَنَّهُ وَأَهلَهُ إِلَّا امرَأَتَهُ كانَت مِنَ الغابِرينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmccclxxiii{وَلَمّا أَن جاءَت رُسُلُنا لوطًا سيءَ بِهِم وَضاقَ بِهِم ذَرعًا وَقالوا لا تَخَف وَلا تَحزَن ۖ إِنّا مُنَجّوكَ وَأَهلَكَ إِلَّا امرَأَتَكَ كانَت مِنَ الغابِرينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmccclxxiv{إِنّا مُنزِلونَ عَلىٰ أَهلِ هٰذِهِ القَريَةِ رِجزًا مِنَ السَّماءِ بِما كانوا يَفسُقونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmccclxxv{وَلَقَد تَرَكنا مِنها آيَةً بَيِّنَةً لِقَومٍ يَعقِلونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmccclxxvi{وَإِلىٰ مَديَنَ أَخاهُم شُعَيبًا فَقالَ يا قَومِ اعبُدُوا اللَّهَ وَارجُوا اليَومَ الآخِرَ وَلا تَعثَوا فِي الأَرضِ مُفسِدينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmccclxxvii{فَكَذَّبوهُ فَأَخَذَتهُمُ الرَّجفَةُ فَأَصبَحوا في دارِهِم جاثِمينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmccclxxviii{وَعادًا وَثَمودَ وَقَد تَبَيَّنَ لَكُم مِن مَساكِنِهِم ۖ وَزَيَّنَ لَهُمُ الشَّيطانُ أَعمالَهُم فَصَدَّهُم عَنِ السَّبيلِ وَكانوا مُستَبصِرينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmccclxxix{وَقارونَ وَفِرعَونَ وَهامانَ ۖ وَلَقَد جاءَهُم موسىٰ بِالبَيِّناتِ فَاستَكبَروا فِي الأَرضِ وَما كانوا سابِقينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmccclxxx{فَكُلًّا أَخَذنا بِذَنبِهِ ۖ فَمِنهُم مَن أَرسَلنا عَلَيهِ حاصِبًا وَمِنهُم مَن أَخَذَتهُ الصَّيحَةُ وَمِنهُم مَن خَسَفنا بِهِ الأَرضَ وَمِنهُم مَن أَغرَقنا ۚ وَما كانَ اللَّهُ لِيَظلِمَهُم وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmccclxxxi{مَثَلُ الَّذينَ اتَّخَذوا مِن دونِ اللَّهِ أَولِياءَ كَمَثَلِ العَنكَبوتِ اتَّخَذَت بَيتًا ۖ وَإِنَّ أَوهَنَ البُيوتِ لَبَيتُ العَنكَبوتِ ۖ لَو كانوا يَعلَمونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmccclxxxii{إِنَّ اللَّهَ يَعلَمُ ما يَدعونَ مِن دونِهِ مِن شَيءٍ ۚ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmccclxxxiii{وَتِلكَ الأَمثالُ نَضرِبُها لِلنّاسِ ۖ وَما يَعقِلُها إِلَّا العالِمونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmccclxxxiv{خَلَقَ اللَّهُ السَّماواتِ وَالأَرضَ بِالحَقِّ ۚ إِنَّ في ذٰلِكَ لَآيَةً لِلمُؤمِنينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmccclxxxv{اتلُ ما أوحِيَ إِلَيكَ مِنَ الكِتابِ وَأَقِمِ الصَّلاةَ ۖ إِنَّ الصَّلاةَ تَنهىٰ عَنِ الفَحشاءِ وَالمُنكَرِ ۗ وَلَذِكرُ اللَّهِ أَكبَرُ ۗ وَاللَّهُ يَعلَمُ ما تَصنَعونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmccclxxxvi{۞ وَلا تُجادِلوا أَهلَ الكِتابِ إِلّا بِالَّتي هِيَ أَحسَنُ إِلَّا الَّذينَ ظَلَموا مِنهُم ۖ وَقولوا آمَنّا بِالَّذي أُنزِلَ إِلَينا وَأُنزِلَ إِلَيكُم وَإِلٰهُنا وَإِلٰهُكُم واحِدٌ وَنَحنُ لَهُ مُسلِمونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmccclxxxvii{وَكَذٰلِكَ أَنزَلنا إِلَيكَ الكِتابَ ۚ فَالَّذينَ آتَيناهُمُ الكِتابَ يُؤمِنونَ بِهِ ۖ وَمِن هٰؤُلاءِ مَن يُؤمِنُ بِهِ ۚ وَما يَجحَدُ بِآياتِنا إِلَّا الكافِرونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmccclxxxviii{وَما كُنتَ تَتلو مِن قَبلِهِ مِن كِتابٍ وَلا تَخُطُّهُ بِيَمينِكَ ۖ إِذًا لَارتابَ المُبطِلونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmccclxxxix{بَل هُوَ آياتٌ بَيِّناتٌ في صُدورِ الَّذينَ أوتُوا العِلمَ ۚ وَما يَجحَدُ بِآياتِنا إِلَّا الظّالِمونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmcccxc{وَقالوا لَولا أُنزِلَ عَلَيهِ آياتٌ مِن رَبِّهِ ۖ قُل إِنَّمَا الآياتُ عِندَ اللَّهِ وَإِنَّما أَنا نَذيرٌ مُبينٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmcccxci{أَوَلَم يَكفِهِم أَنّا أَنزَلنا عَلَيكَ الكِتابَ يُتلىٰ عَلَيهِم ۚ إِنَّ في ذٰلِكَ لَرَحمَةً وَذِكرىٰ لِقَومٍ يُؤمِنونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmcccxcii{قُل كَفىٰ بِاللَّهِ بَيني وَبَينَكُم شَهيدًا ۖ يَعلَمُ ما فِي السَّماواتِ وَالأَرضِ ۗ وَالَّذينَ آمَنوا بِالباطِلِ وَكَفَروا بِاللَّهِ أُولٰئِكَ هُمُ الخاسِرونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmcccxciii{وَيَستَعجِلونَكَ بِالعَذابِ ۚ وَلَولا أَجَلٌ مُسَمًّى لَجاءَهُمُ العَذابُ وَلَيَأتِيَنَّهُم بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmcccxciv{يَستَعجِلونَكَ بِالعَذابِ وَإِنَّ جَهَنَّمَ لَمُحيطَةٌ بِالكافِرينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmcccxcv{يَومَ يَغشاهُمُ العَذابُ مِن فَوقِهِم وَمِن تَحتِ أَرجُلِهِم وَيَقولُ ذوقوا ما كُنتُم تَعمَلونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmcccxcvi{يا عِبادِيَ الَّذينَ آمَنوا إِنَّ أَرضي واسِعَةٌ فَإِيّايَ فَاعبُدونِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmcccxcvii{كُلُّ نَفسٍ ذائِقَةُ المَوتِ ۖ ثُمَّ إِلَينا تُرجَعونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmcccxcviii{وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لَنُبَوِّئَنَّهُم مِنَ الجَنَّةِ غُرَفًا تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها ۚ نِعمَ أَجرُ العامِلينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmcccxcix{الَّذينَ صَبَروا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmcd{وَكَأَيِّن مِن دابَّةٍ لا تَحمِلُ رِزقَهَا اللَّهُ يَرزُقُها وَإِيّاكُم ۚ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmcdi{وَلَئِن سَأَلتَهُم مَن خَلَقَ السَّماواتِ وَالأَرضَ وَسَخَّرَ الشَّمسَ وَالقَمَرَ لَيَقولُنَّ اللَّهُ ۖ فَأَنّىٰ يُؤفَكونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmcdii{اللَّهُ يَبسُطُ الرِّزقَ لِمَن يَشاءُ مِن عِبادِهِ وَيَقدِرُ لَهُ ۚ إِنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmcdiii{وَلَئِن سَأَلتَهُم مَن نَزَّلَ مِنَ السَّماءِ ماءً فَأَحيا بِهِ الأَرضَ مِن بَعدِ مَوتِها لَيَقولُنَّ اللَّهُ ۚ قُلِ الحَمدُ لِلَّهِ ۚ بَل أَكثَرُهُم لا يَعقِلونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmcdiv{وَما هٰذِهِ الحَياةُ الدُّنيا إِلّا لَهوٌ وَلَعِبٌ ۚ وَإِنَّ الدّارَ الآخِرَةَ لَهِيَ الحَيَوانُ ۚ لَو كانوا يَعلَمونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmcdv{فَإِذا رَكِبوا فِي الفُلكِ دَعَوُا اللَّهَ مُخلِصينَ لَهُ الدّينَ فَلَمّا نَجّاهُم إِلَى البَرِّ إِذا هُم يُشرِكونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmcdvi{لِيَكفُروا بِما آتَيناهُم وَلِيَتَمَتَّعوا ۖ فَسَوفَ يَعلَمونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmcdvii{أَوَلَم يَرَوا أَنّا جَعَلنا حَرَمًا آمِنًا وَيُتَخَطَّفُ النّاسُ مِن حَولِهِم ۚ أَفَبِالباطِلِ يُؤمِنونَ وَبِنِعمَةِ اللَّهِ يَكفُرونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmcdviii{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو كَذَّبَ بِالحَقِّ لَمّا جاءَهُ ۚ أَلَيسَ في جَهَنَّمَ مَثوًى لِلكافِرينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmcdix{وَالَّذينَ جاهَدوا فينا لَنَهدِيَنَّهُم سُبُلَنا ۚ وَإِنَّ اللَّهَ لَمَعَ المُحسِنينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmcdx{\basmalah الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcdxi{غُلِبَتِ الرّومُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcdxii{في أَدنَى الأَرضِ وَهُم مِن بَعدِ غَلَبِهِم سَيَغلِبونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcdxiii{في بِضعِ سِنينَ ۗ لِلَّهِ الأَمرُ مِن قَبلُ وَمِن بَعدُ ۚ وَيَومَئِذٍ يَفرَحُ المُؤمِنونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcdxiv{بِنَصرِ اللَّهِ ۚ يَنصُرُ مَن يَشاءُ ۖ وَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcdxv{وَعدَ اللَّهِ ۖ لا يُخلِفُ اللَّهُ وَعدَهُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcdxvi{يَعلَمونَ ظاهِرًا مِنَ الحَياةِ الدُّنيا وَهُم عَنِ الآخِرَةِ هُم غافِلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcdxvii{أَوَلَم يَتَفَكَّروا في أَنفُسِهِم ۗ ما خَلَقَ اللَّهُ السَّماواتِ وَالأَرضَ وَما بَينَهُما إِلّا بِالحَقِّ وَأَجَلٍ مُسَمًّى ۗ وَإِنَّ كَثيرًا مِنَ النّاسِ بِلِقاءِ رَبِّهِم لَكافِرونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcdxviii{أَوَلَم يَسيروا فِي الأَرضِ فَيَنظُروا كَيفَ كانَ عاقِبَةُ الَّذينَ مِن قَبلِهِم ۚ كانوا أَشَدَّ مِنهُم قُوَّةً وَأَثارُوا الأَرضَ وَعَمَروها أَكثَرَ مِمّا عَمَروها وَجاءَتهُم رُسُلُهُم بِالبَيِّناتِ ۖ فَما كانَ اللَّهُ لِيَظلِمَهُم وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcdxix{ثُمَّ كانَ عاقِبَةَ الَّذينَ أَساءُوا السّوأىٰ أَن كَذَّبوا بِآياتِ اللَّهِ وَكانوا بِها يَستَهزِئونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcdxx{اللَّهُ يَبدَأُ الخَلقَ ثُمَّ يُعيدُهُ ثُمَّ إِلَيهِ تُرجَعونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcdxxi{وَيَومَ تَقومُ السّاعَةُ يُبلِسُ المُجرِمونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcdxxii{وَلَم يَكُن لَهُم مِن شُرَكائِهِم شُفَعاءُ وَكانوا بِشُرَكائِهِم كافِرينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcdxxiii{وَيَومَ تَقومُ السّاعَةُ يَومَئِذٍ يَتَفَرَّقونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcdxxiv{فَأَمَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ فَهُم في رَوضَةٍ يُحبَرونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcdxxv{وَأَمَّا الَّذينَ كَفَروا وَكَذَّبوا بِآياتِنا وَلِقاءِ الآخِرَةِ فَأُولٰئِكَ فِي العَذابِ مُحضَرونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcdxxvi{فَسُبحانَ اللَّهِ حينَ تُمسونَ وَحينَ تُصبِحونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcdxxvii{وَلَهُ الحَمدُ فِي السَّماواتِ وَالأَرضِ وَعَشِيًّا وَحينَ تُظهِرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcdxxviii{يُخرِجُ الحَيَّ مِنَ المَيِّتِ وَيُخرِجُ المَيِّتَ مِنَ الحَيِّ وَيُحيِي الأَرضَ بَعدَ مَوتِها ۚ وَكَذٰلِكَ تُخرَجونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcdxxix{وَمِن آياتِهِ أَن خَلَقَكُم مِن تُرابٍ ثُمَّ إِذا أَنتُم بَشَرٌ تَنتَشِرونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcdxxx{وَمِن آياتِهِ أَن خَلَقَ لَكُم مِن أَنفُسِكُم أَزواجًا لِتَسكُنوا إِلَيها وَجَعَلَ بَينَكُم مَوَدَّةً وَرَحمَةً ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcdxxxi{وَمِن آياتِهِ خَلقُ السَّماواتِ وَالأَرضِ وَاختِلافُ أَلسِنَتِكُم وَأَلوانِكُم ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِلعالِمينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcdxxxii{وَمِن آياتِهِ مَنامُكُم بِاللَّيلِ وَالنَّهارِ وَابتِغاؤُكُم مِن فَضلِهِ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يَسمَعونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcdxxxiii{وَمِن آياتِهِ يُريكُمُ البَرقَ خَوفًا وَطَمَعًا وَيُنَزِّلُ مِنَ السَّماءِ ماءً فَيُحيي بِهِ الأَرضَ بَعدَ مَوتِها ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يَعقِلونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcdxxxiv{وَمِن آياتِهِ أَن تَقومَ السَّماءُ وَالأَرضُ بِأَمرِهِ ۚ ثُمَّ إِذا دَعاكُم دَعوَةً مِنَ الأَرضِ إِذا أَنتُم تَخرُجونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcdxxxv{وَلَهُ مَن فِي السَّماواتِ وَالأَرضِ ۖ كُلٌّ لَهُ قانِتونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcdxxxvi{وَهُوَ الَّذي يَبدَأُ الخَلقَ ثُمَّ يُعيدُهُ وَهُوَ أَهوَنُ عَلَيهِ ۚ وَلَهُ المَثَلُ الأَعلىٰ فِي السَّماواتِ وَالأَرضِ ۚ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcdxxxvii{ضَرَبَ لَكُم مَثَلًا مِن أَنفُسِكُم ۖ هَل لَكُم مِن ما مَلَكَت أَيمانُكُم مِن شُرَكاءَ في ما رَزَقناكُم فَأَنتُم فيهِ سَواءٌ تَخافونَهُم كَخيفَتِكُم أَنفُسَكُم ۚ كَذٰلِكَ نُفَصِّلُ الآياتِ لِقَومٍ يَعقِلونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcdxxxviii{بَلِ اتَّبَعَ الَّذينَ ظَلَموا أَهواءَهُم بِغَيرِ عِلمٍ ۖ فَمَن يَهدي مَن أَضَلَّ اللَّهُ ۖ وَما لَهُم مِن ناصِرينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmcdxxxix{فَأَقِم وَجهَكَ لِلدّينِ حَنيفًا ۚ فِطرَتَ اللَّهِ الَّتي فَطَرَ النّاسَ عَلَيها ۚ لا تَبديلَ لِخَلقِ اللَّهِ ۚ ذٰلِكَ الدّينُ القَيِّمُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmcdxl{۞ مُنيبينَ إِلَيهِ وَاتَّقوهُ وَأَقيمُوا الصَّلاةَ وَلا تَكونوا مِنَ المُشرِكينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmcdxli{مِنَ الَّذينَ فَرَّقوا دينَهُم وَكانوا شِيَعًا ۖ كُلُّ حِزبٍ بِما لَدَيهِم فَرِحونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmcdxlii{وَإِذا مَسَّ النّاسَ ضُرٌّ دَعَوا رَبَّهُم مُنيبينَ إِلَيهِ ثُمَّ إِذا أَذاقَهُم مِنهُ رَحمَةً إِذا فَريقٌ مِنهُم بِرَبِّهِم يُشرِكونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmcdxliii{لِيَكفُروا بِما آتَيناهُم ۚ فَتَمَتَّعوا فَسَوفَ تَعلَمونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmcdxliv{أَم أَنزَلنا عَلَيهِم سُلطانًا فَهُوَ يَتَكَلَّمُ بِما كانوا بِهِ يُشرِكونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmcdxlv{وَإِذا أَذَقنَا النّاسَ رَحمَةً فَرِحوا بِها ۖ وَإِن تُصِبهُم سَيِّئَةٌ بِما قَدَّمَت أَيديهِم إِذا هُم يَقنَطونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmcdxlvi{أَوَلَم يَرَوا أَنَّ اللَّهَ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmcdxlvii{فَآتِ ذَا القُربىٰ حَقَّهُ وَالمِسكينَ وَابنَ السَّبيلِ ۚ ذٰلِكَ خَيرٌ لِلَّذينَ يُريدونَ وَجهَ اللَّهِ ۖ وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmcdxlviii{وَما آتَيتُم مِن رِبًا لِيَربُوَ في أَموالِ النّاسِ فَلا يَربو عِندَ اللَّهِ ۖ وَما آتَيتُم مِن زَكاةٍ تُريدونَ وَجهَ اللَّهِ فَأُولٰئِكَ هُمُ المُضعِفونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmcdxlix{اللَّهُ الَّذي خَلَقَكُم ثُمَّ رَزَقَكُم ثُمَّ يُميتُكُم ثُمَّ يُحييكُم ۖ هَل مِن شُرَكائِكُم مَن يَفعَلُ مِن ذٰلِكُم مِن شَيءٍ ۚ سُبحانَهُ وَتَعالىٰ عَمّا يُشرِكونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmcdl{ظَهَرَ الفَسادُ فِي البَرِّ وَالبَحرِ بِما كَسَبَت أَيدِي النّاسِ لِيُذيقَهُم بَعضَ الَّذي عَمِلوا لَعَلَّهُم يَرجِعونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmcdli{قُل سيروا فِي الأَرضِ فَانظُروا كَيفَ كانَ عاقِبَةُ الَّذينَ مِن قَبلُ ۚ كانَ أَكثَرُهُم مُشرِكينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmcdlii{فَأَقِم وَجهَكَ لِلدّينِ القَيِّمِ مِن قَبلِ أَن يَأتِيَ يَومٌ لا مَرَدَّ لَهُ مِنَ اللَّهِ ۖ يَومَئِذٍ يَصَّدَّعونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmcdliii{مَن كَفَرَ فَعَلَيهِ كُفرُهُ ۖ وَمَن عَمِلَ صالِحًا فَلِأَنفُسِهِم يَمهَدونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmcdliv{لِيَجزِيَ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ مِن فَضلِهِ ۚ إِنَّهُ لا يُحِبُّ الكافِرينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmcdlv{وَمِن آياتِهِ أَن يُرسِلَ الرِّياحَ مُبَشِّراتٍ وَلِيُذيقَكُم مِن رَحمَتِهِ وَلِتَجرِيَ الفُلكُ بِأَمرِهِ وَلِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmcdlvi{وَلَقَد أَرسَلنا مِن قَبلِكَ رُسُلًا إِلىٰ قَومِهِم فَجاءوهُم بِالبَيِّناتِ فَانتَقَمنا مِنَ الَّذينَ أَجرَموا ۖ وَكانَ حَقًّا عَلَينا نَصرُ المُؤمِنينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmcdlvii{اللَّهُ الَّذي يُرسِلُ الرِّياحَ فَتُثيرُ سَحابًا فَيَبسُطُهُ فِي السَّماءِ كَيفَ يَشاءُ وَيَجعَلُهُ كِسَفًا فَتَرَى الوَدقَ يَخرُجُ مِن خِلالِهِ ۖ فَإِذا أَصابَ بِهِ مَن يَشاءُ مِن عِبادِهِ إِذا هُم يَستَبشِرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmcdlviii{وَإِن كانوا مِن قَبلِ أَن يُنَزَّلَ عَلَيهِم مِن قَبلِهِ لَمُبلِسينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmcdlix{فَانظُر إِلىٰ آثارِ رَحمَتِ اللَّهِ كَيفَ يُحيِي الأَرضَ بَعدَ مَوتِها ۚ إِنَّ ذٰلِكَ لَمُحيِي المَوتىٰ ۖ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmcdlx{وَلَئِن أَرسَلنا ريحًا فَرَأَوهُ مُصفَرًّا لَظَلّوا مِن بَعدِهِ يَكفُرونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmcdlxi{فَإِنَّكَ لا تُسمِعُ المَوتىٰ وَلا تُسمِعُ الصُّمَّ الدُّعاءَ إِذا وَلَّوا مُدبِرينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmcdlxii{وَما أَنتَ بِهادِ العُميِ عَن ضَلالَتِهِم ۖ إِن تُسمِعُ إِلّا مَن يُؤمِنُ بِآياتِنا فَهُم مُسلِمونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmcdlxiii{۞ اللَّهُ الَّذي خَلَقَكُم مِن ضَعفٍ ثُمَّ جَعَلَ مِن بَعدِ ضَعفٍ قُوَّةً ثُمَّ جَعَلَ مِن بَعدِ قُوَّةٍ ضَعفًا وَشَيبَةً ۚ يَخلُقُ ما يَشاءُ ۖ وَهُوَ العَليمُ القَديرُ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmcdlxiv{وَيَومَ تَقومُ السّاعَةُ يُقسِمُ المُجرِمونَ ما لَبِثوا غَيرَ ساعَةٍ ۚ كَذٰلِكَ كانوا يُؤفَكونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmcdlxv{وَقالَ الَّذينَ أوتُوا العِلمَ وَالإيمانَ لَقَد لَبِثتُم في كِتابِ اللَّهِ إِلىٰ يَومِ البَعثِ ۖ فَهٰذا يَومُ البَعثِ وَلٰكِنَّكُم كُنتُم لا تَعلَمونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmcdlxvi{فَيَومَئِذٍ لا يَنفَعُ الَّذينَ ظَلَموا مَعذِرَتُهُم وَلا هُم يُستَعتَبونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmcdlxvii{وَلَقَد ضَرَبنا لِلنّاسِ في هٰذَا القُرآنِ مِن كُلِّ مَثَلٍ ۚ وَلَئِن جِئتَهُم بِآيَةٍ لَيَقولَنَّ الَّذينَ كَفَروا إِن أَنتُم إِلّا مُبطِلونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmcdlxviii{كَذٰلِكَ يَطبَعُ اللَّهُ عَلىٰ قُلوبِ الَّذينَ لا يَعلَمونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmcdlxix{فَاصبِر إِنَّ وَعدَ اللَّهِ حَقٌّ ۖ وَلا يَستَخِفَّنَّكَ الَّذينَ لا يوقِنونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmcdlxx{\basmalah الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcdlxxi{تِلكَ آياتُ الكِتابِ الحَكيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcdlxxii{هُدًى وَرَحمَةً لِلمُحسِنينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcdlxxiii{الَّذينَ يُقيمونَ الصَّلاةَ وَيُؤتونَ الزَّكاةَ وَهُم بِالآخِرَةِ هُم يوقِنونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcdlxxiv{أُولٰئِكَ عَلىٰ هُدًى مِن رَبِّهِم ۖ وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcdlxxv{وَمِنَ النّاسِ مَن يَشتَري لَهوَ الحَديثِ لِيُضِلَّ عَن سَبيلِ اللَّهِ بِغَيرِ عِلمٍ وَيَتَّخِذَها هُزُوًا ۚ أُولٰئِكَ لَهُم عَذابٌ مُهينٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcdlxxvi{وَإِذا تُتلىٰ عَلَيهِ آياتُنا وَلّىٰ مُستَكبِرًا كَأَن لَم يَسمَعها كَأَنَّ في أُذُنَيهِ وَقرًا ۖ فَبَشِّرهُ بِعَذابٍ أَليمٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcdlxxvii{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لَهُم جَنّاتُ النَّعيمِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcdlxxviii{خالِدينَ فيها ۖ وَعدَ اللَّهِ حَقًّا ۚ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcdlxxix{خَلَقَ السَّماواتِ بِغَيرِ عَمَدٍ تَرَونَها ۖ وَأَلقىٰ فِي الأَرضِ رَواسِيَ أَن تَميدَ بِكُم وَبَثَّ فيها مِن كُلِّ دابَّةٍ ۚ وَأَنزَلنا مِنَ السَّماءِ ماءً فَأَنبَتنا فيها مِن كُلِّ زَوجٍ كَريمٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcdlxxx{هٰذا خَلقُ اللَّهِ فَأَروني ماذا خَلَقَ الَّذينَ مِن دونِهِ ۚ بَلِ الظّالِمونَ في ضَلالٍ مُبينٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcdlxxxi{وَلَقَد آتَينا لُقمانَ الحِكمَةَ أَنِ اشكُر لِلَّهِ ۚ وَمَن يَشكُر فَإِنَّما يَشكُرُ لِنَفسِهِ ۖ وَمَن كَفَرَ فَإِنَّ اللَّهَ غَنِيٌّ حَميدٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcdlxxxii{وَإِذ قالَ لُقمانُ لِابنِهِ وَهُوَ يَعِظُهُ يا بُنَيَّ لا تُشرِك بِاللَّهِ ۖ إِنَّ الشِّركَ لَظُلمٌ عَظيمٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcdlxxxiii{وَوَصَّينَا الإِنسانَ بِوالِدَيهِ حَمَلَتهُ أُمُّهُ وَهنًا عَلىٰ وَهنٍ وَفِصالُهُ في عامَينِ أَنِ اشكُر لي وَلِوالِدَيكَ إِلَيَّ المَصيرُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcdlxxxiv{وَإِن جاهَداكَ عَلىٰ أَن تُشرِكَ بي ما لَيسَ لَكَ بِهِ عِلمٌ فَلا تُطِعهُما ۖ وَصاحِبهُما فِي الدُّنيا مَعروفًا ۖ وَاتَّبِع سَبيلَ مَن أَنابَ إِلَيَّ ۚ ثُمَّ إِلَيَّ مَرجِعُكُم فَأُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcdlxxxv{يا بُنَيَّ إِنَّها إِن تَكُ مِثقالَ حَبَّةٍ مِن خَردَلٍ فَتَكُن في صَخرَةٍ أَو فِي السَّماواتِ أَو فِي الأَرضِ يَأتِ بِهَا اللَّهُ ۚ إِنَّ اللَّهَ لَطيفٌ خَبيرٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcdlxxxvi{يا بُنَيَّ أَقِمِ الصَّلاةَ وَأمُر بِالمَعروفِ وَانهَ عَنِ المُنكَرِ وَاصبِر عَلىٰ ما أَصابَكَ ۖ إِنَّ ذٰلِكَ مِن عَزمِ الأُمورِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcdlxxxvii{وَلا تُصَعِّر خَدَّكَ لِلنّاسِ وَلا تَمشِ فِي الأَرضِ مَرَحًا ۖ إِنَّ اللَّهَ لا يُحِبُّ كُلَّ مُختالٍ فَخورٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcdlxxxviii{وَاقصِد في مَشيِكَ وَاغضُض مِن صَوتِكَ ۚ إِنَّ أَنكَرَ الأَصواتِ لَصَوتُ الحَميرِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcdlxxxix{أَلَم تَرَوا أَنَّ اللَّهَ سَخَّرَ لَكُم ما فِي السَّماواتِ وَما فِي الأَرضِ وَأَسبَغَ عَلَيكُم نِعَمَهُ ظاهِرَةً وَباطِنَةً ۗ وَمِنَ النّاسِ مَن يُجادِلُ فِي اللَّهِ بِغَيرِ عِلمٍ وَلا هُدًى وَلا كِتابٍ مُنيرٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcdxc{وَإِذا قيلَ لَهُمُ اتَّبِعوا ما أَنزَلَ اللَّهُ قالوا بَل نَتَّبِعُ ما وَجَدنا عَلَيهِ آباءَنا ۚ أَوَلَو كانَ الشَّيطانُ يَدعوهُم إِلىٰ عَذابِ السَّعيرِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcdxci{۞ وَمَن يُسلِم وَجهَهُ إِلَى اللَّهِ وَهُوَ مُحسِنٌ فَقَدِ استَمسَكَ بِالعُروَةِ الوُثقىٰ ۗ وَإِلَى اللَّهِ عاقِبَةُ الأُمورِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcdxcii{وَمَن كَفَرَ فَلا يَحزُنكَ كُفرُهُ ۚ إِلَينا مَرجِعُهُم فَنُنَبِّئُهُم بِما عَمِلوا ۚ إِنَّ اللَّهَ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcdxciii{نُمَتِّعُهُم قَليلًا ثُمَّ نَضطَرُّهُم إِلىٰ عَذابٍ غَليظٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcdxciv{وَلَئِن سَأَلتَهُم مَن خَلَقَ السَّماواتِ وَالأَرضَ لَيَقولُنَّ اللَّهُ ۚ قُلِ الحَمدُ لِلَّهِ ۚ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcdxcv{لِلَّهِ ما فِي السَّماواتِ وَالأَرضِ ۚ إِنَّ اللَّهَ هُوَ الغَنِيُّ الحَميدُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcdxcvi{وَلَو أَنَّما فِي الأَرضِ مِن شَجَرَةٍ أَقلامٌ وَالبَحرُ يَمُدُّهُ مِن بَعدِهِ سَبعَةُ أَبحُرٍ ما نَفِدَت كَلِماتُ اللَّهِ ۗ إِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcdxcvii{ما خَلقُكُم وَلا بَعثُكُم إِلّا كَنَفسٍ واحِدَةٍ ۗ إِنَّ اللَّهَ سَميعٌ بَصيرٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcdxcviii{أَلَم تَرَ أَنَّ اللَّهَ يولِجُ اللَّيلَ فِي النَّهارِ وَيولِجُ النَّهارَ فِي اللَّيلِ وَسَخَّرَ الشَّمسَ وَالقَمَرَ كُلٌّ يَجري إِلىٰ أَجَلٍ مُسَمًّى وَأَنَّ اللَّهَ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmcdxcix{ذٰلِكَ بِأَنَّ اللَّهَ هُوَ الحَقُّ وَأَنَّ ما يَدعونَ مِن دونِهِ الباطِلُ وَأَنَّ اللَّهَ هُوَ العَلِيُّ الكَبيرُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmd{أَلَم تَرَ أَنَّ الفُلكَ تَجري فِي البَحرِ بِنِعمَتِ اللَّهِ لِيُرِيَكُم مِن آياتِهِ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِكُلِّ صَبّارٍ شَكورٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdi{وَإِذا غَشِيَهُم مَوجٌ كَالظُّلَلِ دَعَوُا اللَّهَ مُخلِصينَ لَهُ الدّينَ فَلَمّا نَجّاهُم إِلَى البَرِّ فَمِنهُم مُقتَصِدٌ ۚ وَما يَجحَدُ بِآياتِنا إِلّا كُلُّ خَتّارٍ كَفورٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdii{يا أَيُّهَا النّاسُ اتَّقوا رَبَّكُم وَاخشَوا يَومًا لا يَجزي والِدٌ عَن وَلَدِهِ وَلا مَولودٌ هُوَ جازٍ عَن والِدِهِ شَيئًا ۚ إِنَّ وَعدَ اللَّهِ حَقٌّ ۖ فَلا تَغُرَّنَّكُمُ الحَياةُ الدُّنيا وَلا يَغُرَّنَّكُم بِاللَّهِ الغَرورُ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdiii{إِنَّ اللَّهَ عِندَهُ عِلمُ السّاعَةِ وَيُنَزِّلُ الغَيثَ وَيَعلَمُ ما فِي الأَرحامِ ۖ وَما تَدري نَفسٌ ماذا تَكسِبُ غَدًا ۖ وَما تَدري نَفسٌ بِأَيِّ أَرضٍ تَموتُ ۚ إِنَّ اللَّهَ عَليمٌ خَبيرٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdiv{\basmalah الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdv{تَنزيلُ الكِتابِ لا رَيبَ فيهِ مِن رَبِّ العالَمينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdvi{أَم يَقولونَ افتَراهُ ۚ بَل هُوَ الحَقُّ مِن رَبِّكَ لِتُنذِرَ قَومًا ما أَتاهُم مِن نَذيرٍ مِن قَبلِكَ لَعَلَّهُم يَهتَدونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdvii{اللَّهُ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ وَما بَينَهُما في سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ ۖ ما لَكُم مِن دونِهِ مِن وَلِيٍّ وَلا شَفيعٍ ۚ أَفَلا تَتَذَكَّرونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdviii{يُدَبِّرُ الأَمرَ مِنَ السَّماءِ إِلَى الأَرضِ ثُمَّ يَعرُجُ إِلَيهِ في يَومٍ كانَ مِقدارُهُ أَلفَ سَنَةٍ مِمّا تَعُدّونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdix{ذٰلِكَ عالِمُ الغَيبِ وَالشَّهادَةِ العَزيزُ الرَّحيمُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdx{الَّذي أَحسَنَ كُلَّ شَيءٍ خَلَقَهُ ۖ وَبَدَأَ خَلقَ الإِنسانِ مِن طينٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdxi{ثُمَّ جَعَلَ نَسلَهُ مِن سُلالَةٍ مِن ماءٍ مَهينٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdxii{ثُمَّ سَوّاهُ وَنَفَخَ فيهِ مِن روحِهِ ۖ وَجَعَلَ لَكُمُ السَّمعَ وَالأَبصارَ وَالأَفئِدَةَ ۚ قَليلًا ما تَشكُرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdxiii{وَقالوا أَإِذا ضَلَلنا فِي الأَرضِ أَإِنّا لَفي خَلقٍ جَديدٍ ۚ بَل هُم بِلِقاءِ رَبِّهِم كافِرونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdxiv{۞ قُل يَتَوَفّاكُم مَلَكُ المَوتِ الَّذي وُكِّلَ بِكُم ثُمَّ إِلىٰ رَبِّكُم تُرجَعونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdxv{وَلَو تَرىٰ إِذِ المُجرِمونَ ناكِسو رُءوسِهِم عِندَ رَبِّهِم رَبَّنا أَبصَرنا وَسَمِعنا فَارجِعنا نَعمَل صالِحًا إِنّا موقِنونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdxvi{وَلَو شِئنا لَآتَينا كُلَّ نَفسٍ هُداها وَلٰكِن حَقَّ القَولُ مِنّي لَأَملَأَنَّ جَهَنَّمَ مِنَ الجِنَّةِ وَالنّاسِ أَجمَعينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdxvii{فَذوقوا بِما نَسيتُم لِقاءَ يَومِكُم هٰذا إِنّا نَسيناكُم ۖ وَذوقوا عَذابَ الخُلدِ بِما كُنتُم تَعمَلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdxviii{إِنَّما يُؤمِنُ بِآياتِنَا الَّذينَ إِذا ذُكِّروا بِها خَرّوا سُجَّدًا وَسَبَّحوا بِحَمدِ رَبِّهِم وَهُم لا يَستَكبِرونَ ۩\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdxix{تَتَجافىٰ جُنوبُهُم عَنِ المَضاجِعِ يَدعونَ رَبَّهُم خَوفًا وَطَمَعًا وَمِمّا رَزَقناهُم يُنفِقونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdxx{فَلا تَعلَمُ نَفسٌ ما أُخفِيَ لَهُم مِن قُرَّةِ أَعيُنٍ جَزاءً بِما كانوا يَعمَلونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdxxi{أَفَمَن كانَ مُؤمِنًا كَمَن كانَ فاسِقًا ۚ لا يَستَوونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdxxii{أَمَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ فَلَهُم جَنّاتُ المَأوىٰ نُزُلًا بِما كانوا يَعمَلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdxxiii{وَأَمَّا الَّذينَ فَسَقوا فَمَأواهُمُ النّارُ ۖ كُلَّما أَرادوا أَن يَخرُجوا مِنها أُعيدوا فيها وَقيلَ لَهُم ذوقوا عَذابَ النّارِ الَّذي كُنتُم بِهِ تُكَذِّبونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdxxiv{وَلَنُذيقَنَّهُم مِنَ العَذابِ الأَدنىٰ دونَ العَذابِ الأَكبَرِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdxxv{وَمَن أَظلَمُ مِمَّن ذُكِّرَ بِآياتِ رَبِّهِ ثُمَّ أَعرَضَ عَنها ۚ إِنّا مِنَ المُجرِمينَ مُنتَقِمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdxxvi{وَلَقَد آتَينا موسَى الكِتابَ فَلا تَكُن في مِريَةٍ مِن لِقائِهِ ۖ وَجَعَلناهُ هُدًى لِبَني إِسرائيلَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdxxvii{وَجَعَلنا مِنهُم أَئِمَّةً يَهدونَ بِأَمرِنا لَمّا صَبَروا ۖ وَكانوا بِآياتِنا يوقِنونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdxxviii{إِنَّ رَبَّكَ هُوَ يَفصِلُ بَينَهُم يَومَ القِيامَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdxxix{أَوَلَم يَهدِ لَهُم كَم أَهلَكنا مِن قَبلِهِم مِنَ القُرونِ يَمشونَ في مَساكِنِهِم ۚ إِنَّ في ذٰلِكَ لَآياتٍ ۖ أَفَلا يَسمَعونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdxxx{أَوَلَم يَرَوا أَنّا نَسوقُ الماءَ إِلَى الأَرضِ الجُرُزِ فَنُخرِجُ بِهِ زَرعًا تَأكُلُ مِنهُ أَنعامُهُم وَأَنفُسُهُم ۖ أَفَلا يُبصِرونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdxxxi{وَيَقولونَ مَتىٰ هٰذَا الفَتحُ إِن كُنتُم صادِقينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdxxxii{قُل يَومَ الفَتحِ لا يَنفَعُ الَّذينَ كَفَروا إيمانُهُم وَلا هُم يُنظَرونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdxxxiii{فَأَعرِض عَنهُم وَانتَظِر إِنَّهُم مُنتَظِرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdxxxiv{\basmalah يا أَيُّهَا النَّبِيُّ اتَّقِ اللَّهَ وَلا تُطِعِ الكافِرينَ وَالمُنافِقينَ ۗ إِنَّ اللَّهَ كانَ عَليمًا حَكيمًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdxxxv{وَاتَّبِع ما يوحىٰ إِلَيكَ مِن رَبِّكَ ۚ إِنَّ اللَّهَ كانَ بِما تَعمَلونَ خَبيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdxxxvi{وَتَوَكَّل عَلَى اللَّهِ ۚ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdxxxvii{ما جَعَلَ اللَّهُ لِرَجُلٍ مِن قَلبَينِ في جَوفِهِ ۚ وَما جَعَلَ أَزواجَكُمُ اللّائي تُظاهِرونَ مِنهُنَّ أُمَّهاتِكُم ۚ وَما جَعَلَ أَدعِياءَكُم أَبناءَكُم ۚ ذٰلِكُم قَولُكُم بِأَفواهِكُم ۖ وَاللَّهُ يَقولُ الحَقَّ وَهُوَ يَهدِي السَّبيلَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdxxxviii{ادعوهُم لِآبائِهِم هُوَ أَقسَطُ عِندَ اللَّهِ ۚ فَإِن لَم تَعلَموا آباءَهُم فَإِخوانُكُم فِي الدّينِ وَمَواليكُم ۚ وَلَيسَ عَلَيكُم جُناحٌ فيما أَخطَأتُم بِهِ وَلٰكِن ما تَعَمَّدَت قُلوبُكُم ۚ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdxxxix{النَّبِيُّ أَولىٰ بِالمُؤمِنينَ مِن أَنفُسِهِم ۖ وَأَزواجُهُ أُمَّهاتُهُم ۗ وَأُولُو الأَرحامِ بَعضُهُم أَولىٰ بِبَعضٍ في كِتابِ اللَّهِ مِنَ المُؤمِنينَ وَالمُهاجِرينَ إِلّا أَن تَفعَلوا إِلىٰ أَولِيائِكُم مَعروفًا ۚ كانَ ذٰلِكَ فِي الكِتابِ مَسطورًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdxl{وَإِذ أَخَذنا مِنَ النَّبِيّينَ ميثاقَهُم وَمِنكَ وَمِن نوحٍ وَإِبراهيمَ وَموسىٰ وَعيسَى ابنِ مَريَمَ ۖ وَأَخَذنا مِنهُم ميثاقًا غَليظًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdxli{لِيَسأَلَ الصّادِقينَ عَن صِدقِهِم ۚ وَأَعَدَّ لِلكافِرينَ عَذابًا أَليمًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdxlii{يا أَيُّهَا الَّذينَ آمَنُوا اذكُروا نِعمَةَ اللَّهِ عَلَيكُم إِذ جاءَتكُم جُنودٌ فَأَرسَلنا عَلَيهِم ريحًا وَجُنودًا لَم تَرَوها ۚ وَكانَ اللَّهُ بِما تَعمَلونَ بَصيرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdxliii{إِذ جاءوكُم مِن فَوقِكُم وَمِن أَسفَلَ مِنكُم وَإِذ زاغَتِ الأَبصارُ وَبَلَغَتِ القُلوبُ الحَناجِرَ وَتَظُنّونَ بِاللَّهِ الظُّنونا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdxliv{هُنالِكَ ابتُلِيَ المُؤمِنونَ وَزُلزِلوا زِلزالًا شَديدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdxlv{وَإِذ يَقولُ المُنافِقونَ وَالَّذينَ في قُلوبِهِم مَرَضٌ ما وَعَدَنَا اللَّهُ وَرَسولُهُ إِلّا غُرورًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdxlvi{وَإِذ قالَت طائِفَةٌ مِنهُم يا أَهلَ يَثرِبَ لا مُقامَ لَكُم فَارجِعوا ۚ وَيَستَأذِنُ فَريقٌ مِنهُمُ النَّبِيَّ يَقولونَ إِنَّ بُيوتَنا عَورَةٌ وَما هِيَ بِعَورَةٍ ۖ إِن يُريدونَ إِلّا فِرارًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdxlvii{وَلَو دُخِلَت عَلَيهِم مِن أَقطارِها ثُمَّ سُئِلُوا الفِتنَةَ لَآتَوها وَما تَلَبَّثوا بِها إِلّا يَسيرًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdxlviii{وَلَقَد كانوا عاهَدُوا اللَّهَ مِن قَبلُ لا يُوَلّونَ الأَدبارَ ۚ وَكانَ عَهدُ اللَّهِ مَسئولًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdxlix{قُل لَن يَنفَعَكُمُ الفِرارُ إِن فَرَرتُم مِنَ المَوتِ أَوِ القَتلِ وَإِذًا لا تُمَتَّعونَ إِلّا قَليلًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdl{قُل مَن ذَا الَّذي يَعصِمُكُم مِنَ اللَّهِ إِن أَرادَ بِكُم سوءًا أَو أَرادَ بِكُم رَحمَةً ۚ وَلا يَجِدونَ لَهُم مِن دونِ اللَّهِ وَلِيًّا وَلا نَصيرًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdli{۞ قَد يَعلَمُ اللَّهُ المُعَوِّقينَ مِنكُم وَالقائِلينَ لِإِخوانِهِم هَلُمَّ إِلَينا ۖ وَلا يَأتونَ البَأسَ إِلّا قَليلًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdlii{أَشِحَّةً عَلَيكُم ۖ فَإِذا جاءَ الخَوفُ رَأَيتَهُم يَنظُرونَ إِلَيكَ تَدورُ أَعيُنُهُم كَالَّذي يُغشىٰ عَلَيهِ مِنَ المَوتِ ۖ فَإِذا ذَهَبَ الخَوفُ سَلَقوكُم بِأَلسِنَةٍ حِدادٍ أَشِحَّةً عَلَى الخَيرِ ۚ أُولٰئِكَ لَم يُؤمِنوا فَأَحبَطَ اللَّهُ أَعمالَهُم ۚ وَكانَ ذٰلِكَ عَلَى اللَّهِ يَسيرًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdliii{يَحسَبونَ الأَحزابَ لَم يَذهَبوا ۖ وَإِن يَأتِ الأَحزابُ يَوَدّوا لَو أَنَّهُم بادونَ فِي الأَعرابِ يَسأَلونَ عَن أَنبائِكُم ۖ وَلَو كانوا فيكُم ما قاتَلوا إِلّا قَليلًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdliv{لَقَد كانَ لَكُم في رَسولِ اللَّهِ أُسوَةٌ حَسَنَةٌ لِمَن كانَ يَرجُو اللَّهَ وَاليَومَ الآخِرَ وَذَكَرَ اللَّهَ كَثيرًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdlv{وَلَمّا رَأَى المُؤمِنونَ الأَحزابَ قالوا هٰذا ما وَعَدَنَا اللَّهُ وَرَسولُهُ وَصَدَقَ اللَّهُ وَرَسولُهُ ۚ وَما زادَهُم إِلّا إيمانًا وَتَسليمًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdlvi{مِنَ المُؤمِنينَ رِجالٌ صَدَقوا ما عاهَدُوا اللَّهَ عَلَيهِ ۖ فَمِنهُم مَن قَضىٰ نَحبَهُ وَمِنهُم مَن يَنتَظِرُ ۖ وَما بَدَّلوا تَبديلًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdlvii{لِيَجزِيَ اللَّهُ الصّادِقينَ بِصِدقِهِم وَيُعَذِّبَ المُنافِقينَ إِن شاءَ أَو يَتوبَ عَلَيهِم ۚ إِنَّ اللَّهَ كانَ غَفورًا رَحيمًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdlviii{وَرَدَّ اللَّهُ الَّذينَ كَفَروا بِغَيظِهِم لَم يَنالوا خَيرًا ۚ وَكَفَى اللَّهُ المُؤمِنينَ القِتالَ ۚ وَكانَ اللَّهُ قَوِيًّا عَزيزًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdlix{وَأَنزَلَ الَّذينَ ظاهَروهُم مِن أَهلِ الكِتابِ مِن صَياصيهِم وَقَذَفَ في قُلوبِهِمُ الرُّعبَ فَريقًا تَقتُلونَ وَتَأسِرونَ فَريقًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdlx{وَأَورَثَكُم أَرضَهُم وَدِيارَهُم وَأَموالَهُم وَأَرضًا لَم تَطَئوها ۚ وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdlxi{يا أَيُّهَا النَّبِيُّ قُل لِأَزواجِكَ إِن كُنتُنَّ تُرِدنَ الحَياةَ الدُّنيا وَزينَتَها فَتَعالَينَ أُمَتِّعكُنَّ وَأُسَرِّحكُنَّ سَراحًا جَميلًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdlxii{وَإِن كُنتُنَّ تُرِدنَ اللَّهَ وَرَسولَهُ وَالدّارَ الآخِرَةَ فَإِنَّ اللَّهَ أَعَدَّ لِلمُحسِناتِ مِنكُنَّ أَجرًا عَظيمًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdlxiii{يا نِساءَ النَّبِيِّ مَن يَأتِ مِنكُنَّ بِفاحِشَةٍ مُبَيِّنَةٍ يُضاعَف لَهَا العَذابُ ضِعفَينِ ۚ وَكانَ ذٰلِكَ عَلَى اللَّهِ يَسيرًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdlxiv{۞ وَمَن يَقنُت مِنكُنَّ لِلَّهِ وَرَسولِهِ وَتَعمَل صالِحًا نُؤتِها أَجرَها مَرَّتَينِ وَأَعتَدنا لَها رِزقًا كَريمًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdlxv{يا نِساءَ النَّبِيِّ لَستُنَّ كَأَحَدٍ مِنَ النِّساءِ ۚ إِنِ اتَّقَيتُنَّ فَلا تَخضَعنَ بِالقَولِ فَيَطمَعَ الَّذي في قَلبِهِ مَرَضٌ وَقُلنَ قَولًا مَعروفًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdlxvi{وَقَرنَ في بُيوتِكُنَّ وَلا تَبَرَّجنَ تَبَرُّجَ الجاهِلِيَّةِ الأولىٰ ۖ وَأَقِمنَ الصَّلاةَ وَآتينَ الزَّكاةَ وَأَطِعنَ اللَّهَ وَرَسولَهُ ۚ إِنَّما يُريدُ اللَّهُ لِيُذهِبَ عَنكُمُ الرِّجسَ أَهلَ البَيتِ وَيُطَهِّرَكُم تَطهيرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdlxvii{وَاذكُرنَ ما يُتلىٰ في بُيوتِكُنَّ مِن آياتِ اللَّهِ وَالحِكمَةِ ۚ إِنَّ اللَّهَ كانَ لَطيفًا خَبيرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdlxviii{إِنَّ المُسلِمينَ وَالمُسلِماتِ وَالمُؤمِنينَ وَالمُؤمِناتِ وَالقانِتينَ وَالقانِتاتِ وَالصّادِقينَ وَالصّادِقاتِ وَالصّابِرينَ وَالصّابِراتِ وَالخاشِعينَ وَالخاشِعاتِ وَالمُتَصَدِّقينَ وَالمُتَصَدِّقاتِ وَالصّائِمينَ وَالصّائِماتِ وَالحافِظينَ فُروجَهُم وَالحافِظاتِ وَالذّاكِرينَ اللَّهَ كَثيرًا وَالذّاكِراتِ أَعَدَّ اللَّهُ لَهُم مَغفِرَةً وَأَجرًا عَظيمًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdlxix{وَما كانَ لِمُؤمِنٍ وَلا مُؤمِنَةٍ إِذا قَضَى اللَّهُ وَرَسولُهُ أَمرًا أَن يَكونَ لَهُمُ الخِيَرَةُ مِن أَمرِهِم ۗ وَمَن يَعصِ اللَّهَ وَرَسولَهُ فَقَد ضَلَّ ضَلالًا مُبينًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdlxx{وَإِذ تَقولُ لِلَّذي أَنعَمَ اللَّهُ عَلَيهِ وَأَنعَمتَ عَلَيهِ أَمسِك عَلَيكَ زَوجَكَ وَاتَّقِ اللَّهَ وَتُخفي في نَفسِكَ مَا اللَّهُ مُبديهِ وَتَخشَى النّاسَ وَاللَّهُ أَحَقُّ أَن تَخشاهُ ۖ فَلَمّا قَضىٰ زَيدٌ مِنها وَطَرًا زَوَّجناكَها لِكَي لا يَكونَ عَلَى المُؤمِنينَ حَرَجٌ في أَزواجِ أَدعِيائِهِم إِذا قَضَوا مِنهُنَّ وَطَرًا ۚ وَكانَ أَمرُ اللَّهِ مَفعولًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdlxxi{ما كانَ عَلَى النَّبِيِّ مِن حَرَجٍ فيما فَرَضَ اللَّهُ لَهُ ۖ سُنَّةَ اللَّهِ فِي الَّذينَ خَلَوا مِن قَبلُ ۚ وَكانَ أَمرُ اللَّهِ قَدَرًا مَقدورًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdlxxii{الَّذينَ يُبَلِّغونَ رِسالاتِ اللَّهِ وَيَخشَونَهُ وَلا يَخشَونَ أَحَدًا إِلَّا اللَّهَ ۗ وَكَفىٰ بِاللَّهِ حَسيبًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdlxxiii{ما كانَ مُحَمَّدٌ أَبا أَحَدٍ مِن رِجالِكُم وَلٰكِن رَسولَ اللَّهِ وَخاتَمَ النَّبِيّينَ ۗ وَكانَ اللَّهُ بِكُلِّ شَيءٍ عَليمًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdlxxiv{يا أَيُّهَا الَّذينَ آمَنُوا اذكُرُوا اللَّهَ ذِكرًا كَثيرًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdlxxv{وَسَبِّحوهُ بُكرَةً وَأَصيلًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdlxxvi{هُوَ الَّذي يُصَلّي عَلَيكُم وَمَلائِكَتُهُ لِيُخرِجَكُم مِنَ الظُّلُماتِ إِلَى النّورِ ۚ وَكانَ بِالمُؤمِنينَ رَحيمًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdlxxvii{تَحِيَّتُهُم يَومَ يَلقَونَهُ سَلامٌ ۚ وَأَعَدَّ لَهُم أَجرًا كَريمًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdlxxviii{يا أَيُّهَا النَّبِيُّ إِنّا أَرسَلناكَ شاهِدًا وَمُبَشِّرًا وَنَذيرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdlxxix{وَداعِيًا إِلَى اللَّهِ بِإِذنِهِ وَسِراجًا مُنيرًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdlxxx{وَبَشِّرِ المُؤمِنينَ بِأَنَّ لَهُم مِنَ اللَّهِ فَضلًا كَبيرًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdlxxxi{وَلا تُطِعِ الكافِرينَ وَالمُنافِقينَ وَدَع أَذاهُم وَتَوَكَّل عَلَى اللَّهِ ۚ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdlxxxii{يا أَيُّهَا الَّذينَ آمَنوا إِذا نَكَحتُمُ المُؤمِناتِ ثُمَّ طَلَّقتُموهُنَّ مِن قَبلِ أَن تَمَسّوهُنَّ فَما لَكُم عَلَيهِنَّ مِن عِدَّةٍ تَعتَدّونَها ۖ فَمَتِّعوهُنَّ وَسَرِّحوهُنَّ سَراحًا جَميلًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdlxxxiii{يا أَيُّهَا النَّبِيُّ إِنّا أَحلَلنا لَكَ أَزواجَكَ اللّاتي آتَيتَ أُجورَهُنَّ وَما مَلَكَت يَمينُكَ مِمّا أَفاءَ اللَّهُ عَلَيكَ وَبَناتِ عَمِّكَ وَبَناتِ عَمّاتِكَ وَبَناتِ خالِكَ وَبَناتِ خالاتِكَ اللّاتي هاجَرنَ مَعَكَ وَامرَأَةً مُؤمِنَةً إِن وَهَبَت نَفسَها لِلنَّبِيِّ إِن أَرادَ النَّبِيُّ أَن يَستَنكِحَها خالِصَةً لَكَ مِن دونِ المُؤمِنينَ ۗ قَد عَلِمنا ما فَرَضنا عَلَيهِم في أَزواجِهِم وَما مَلَكَت أَيمانُهُم لِكَيلا يَكونَ عَلَيكَ حَرَجٌ ۗ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdlxxxiv{۞ تُرجي مَن تَشاءُ مِنهُنَّ وَتُؤوي إِلَيكَ مَن تَشاءُ ۖ وَمَنِ ابتَغَيتَ مِمَّن عَزَلتَ فَلا جُناحَ عَلَيكَ ۚ ذٰلِكَ أَدنىٰ أَن تَقَرَّ أَعيُنُهُنَّ وَلا يَحزَنَّ وَيَرضَينَ بِما آتَيتَهُنَّ كُلُّهُنَّ ۚ وَاللَّهُ يَعلَمُ ما في قُلوبِكُم ۚ وَكانَ اللَّهُ عَليمًا حَليمًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdlxxxv{لا يَحِلُّ لَكَ النِّساءُ مِن بَعدُ وَلا أَن تَبَدَّلَ بِهِنَّ مِن أَزواجٍ وَلَو أَعجَبَكَ حُسنُهُنَّ إِلّا ما مَلَكَت يَمينُكَ ۗ وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ رَقيبًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdlxxxvi{يا أَيُّهَا الَّذينَ آمَنوا لا تَدخُلوا بُيوتَ النَّبِيِّ إِلّا أَن يُؤذَنَ لَكُم إِلىٰ طَعامٍ غَيرَ ناظِرينَ إِناهُ وَلٰكِن إِذا دُعيتُم فَادخُلوا فَإِذا طَعِمتُم فَانتَشِروا وَلا مُستَأنِسينَ لِحَديثٍ ۚ إِنَّ ذٰلِكُم كانَ يُؤذِي النَّبِيَّ فَيَستَحيي مِنكُم ۖ وَاللَّهُ لا يَستَحيي مِنَ الحَقِّ ۚ وَإِذا سَأَلتُموهُنَّ مَتاعًا فَاسأَلوهُنَّ مِن وَراءِ حِجابٍ ۚ ذٰلِكُم أَطهَرُ لِقُلوبِكُم وَقُلوبِهِنَّ ۚ وَما كانَ لَكُم أَن تُؤذوا رَسولَ اللَّهِ وَلا أَن تَنكِحوا أَزواجَهُ مِن بَعدِهِ أَبَدًا ۚ إِنَّ ذٰلِكُم كانَ عِندَ اللَّهِ عَظيمًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdlxxxvii{إِن تُبدوا شَيئًا أَو تُخفوهُ فَإِنَّ اللَّهَ كانَ بِكُلِّ شَيءٍ عَليمًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdlxxxviii{لا جُناحَ عَلَيهِنَّ في آبائِهِنَّ وَلا أَبنائِهِنَّ وَلا إِخوانِهِنَّ وَلا أَبناءِ إِخوانِهِنَّ وَلا أَبناءِ أَخَواتِهِنَّ وَلا نِسائِهِنَّ وَلا ما مَلَكَت أَيمانُهُنَّ ۗ وَاتَّقينَ اللَّهَ ۚ إِنَّ اللَّهَ كانَ عَلىٰ كُلِّ شَيءٍ شَهيدًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmdlxxxix{إِنَّ اللَّهَ وَمَلائِكَتَهُ يُصَلّونَ عَلَى النَّبِيِّ ۚ يا أَيُّهَا الَّذينَ آمَنوا صَلّوا عَلَيهِ وَسَلِّموا تَسليمًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmdxc{إِنَّ الَّذينَ يُؤذونَ اللَّهَ وَرَسولَهُ لَعَنَهُمُ اللَّهُ فِي الدُّنيا وَالآخِرَةِ وَأَعَدَّ لَهُم عَذابًا مُهينًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmdxci{وَالَّذينَ يُؤذونَ المُؤمِنينَ وَالمُؤمِناتِ بِغَيرِ مَا اكتَسَبوا فَقَدِ احتَمَلوا بُهتانًا وَإِثمًا مُبينًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmdxcii{يا أَيُّهَا النَّبِيُّ قُل لِأَزواجِكَ وَبَناتِكَ وَنِساءِ المُؤمِنينَ يُدنينَ عَلَيهِنَّ مِن جَلابيبِهِنَّ ۚ ذٰلِكَ أَدنىٰ أَن يُعرَفنَ فَلا يُؤذَينَ ۗ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmdxciii{۞ لَئِن لَم يَنتَهِ المُنافِقونَ وَالَّذينَ في قُلوبِهِم مَرَضٌ وَالمُرجِفونَ فِي المَدينَةِ لَنُغرِيَنَّكَ بِهِم ثُمَّ لا يُجاوِرونَكَ فيها إِلّا قَليلًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmdxciv{مَلعونينَ ۖ أَينَما ثُقِفوا أُخِذوا وَقُتِّلوا تَقتيلًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmdxcv{سُنَّةَ اللَّهِ فِي الَّذينَ خَلَوا مِن قَبلُ ۖ وَلَن تَجِدَ لِسُنَّةِ اللَّهِ تَبديلًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmdxcvi{يَسأَلُكَ النّاسُ عَنِ السّاعَةِ ۖ قُل إِنَّما عِلمُها عِندَ اللَّهِ ۚ وَما يُدريكَ لَعَلَّ السّاعَةَ تَكونُ قَريبًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmdxcvii{إِنَّ اللَّهَ لَعَنَ الكافِرينَ وَأَعَدَّ لَهُم سَعيرًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmdxcviii{خالِدينَ فيها أَبَدًا ۖ لا يَجِدونَ وَلِيًّا وَلا نَصيرًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmdxcix{يَومَ تُقَلَّبُ وُجوهُهُم فِي النّارِ يَقولونَ يا لَيتَنا أَطَعنَا اللَّهَ وَأَطَعنَا الرَّسولا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmdc{وَقالوا رَبَّنا إِنّا أَطَعنا سادَتَنا وَكُبَراءَنا فَأَضَلّونَا السَّبيلا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmdci{رَبَّنا آتِهِم ضِعفَينِ مِنَ العَذابِ وَالعَنهُم لَعنًا كَبيرًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmdcii{يا أَيُّهَا الَّذينَ آمَنوا لا تَكونوا كَالَّذينَ آذَوا موسىٰ فَبَرَّأَهُ اللَّهُ مِمّا قالوا ۚ وَكانَ عِندَ اللَّهِ وَجيهًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmdciii{يا أَيُّهَا الَّذينَ آمَنُوا اتَّقُوا اللَّهَ وَقولوا قَولًا سَديدًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmdciv{يُصلِح لَكُم أَعمالَكُم وَيَغفِر لَكُم ذُنوبَكُم ۗ وَمَن يُطِعِ اللَّهَ وَرَسولَهُ فَقَد فازَ فَوزًا عَظيمًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmdcv{إِنّا عَرَضنَا الأَمانَةَ عَلَى السَّماواتِ وَالأَرضِ وَالجِبالِ فَأَبَينَ أَن يَحمِلنَها وَأَشفَقنَ مِنها وَحَمَلَهَا الإِنسانُ ۖ إِنَّهُ كانَ ظَلومًا جَهولًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmdcvi{لِيُعَذِّبَ اللَّهُ المُنافِقينَ وَالمُنافِقاتِ وَالمُشرِكينَ وَالمُشرِكاتِ وَيَتوبَ اللَّهُ عَلَى المُؤمِنينَ وَالمُؤمِناتِ ۗ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmdcvii{\basmalah الحَمدُ لِلَّهِ الَّذي لَهُ ما فِي السَّماواتِ وَما فِي الأَرضِ وَلَهُ الحَمدُ فِي الآخِرَةِ ۚ وَهُوَ الحَكيمُ الخَبيرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdcviii{يَعلَمُ ما يَلِجُ فِي الأَرضِ وَما يَخرُجُ مِنها وَما يَنزِلُ مِنَ السَّماءِ وَما يَعرُجُ فيها ۚ وَهُوَ الرَّحيمُ الغَفورُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdcix{وَقالَ الَّذينَ كَفَروا لا تَأتينَا السّاعَةُ ۖ قُل بَلىٰ وَرَبّي لَتَأتِيَنَّكُم عالِمِ الغَيبِ ۖ لا يَعزُبُ عَنهُ مِثقالُ ذَرَّةٍ فِي السَّماواتِ وَلا فِي الأَرضِ وَلا أَصغَرُ مِن ذٰلِكَ وَلا أَكبَرُ إِلّا في كِتابٍ مُبينٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdcx{لِيَجزِيَ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ ۚ أُولٰئِكَ لَهُم مَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdcxi{وَالَّذينَ سَعَوا في آياتِنا مُعاجِزينَ أُولٰئِكَ لَهُم عَذابٌ مِن رِجزٍ أَليمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdcxii{وَيَرَى الَّذينَ أوتُوا العِلمَ الَّذي أُنزِلَ إِلَيكَ مِن رَبِّكَ هُوَ الحَقَّ وَيَهدي إِلىٰ صِراطِ العَزيزِ الحَميدِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdcxiii{وَقالَ الَّذينَ كَفَروا هَل نَدُلُّكُم عَلىٰ رَجُلٍ يُنَبِّئُكُم إِذا مُزِّقتُم كُلَّ مُمَزَّقٍ إِنَّكُم لَفي خَلقٍ جَديدٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdcxiv{أَفتَرىٰ عَلَى اللَّهِ كَذِبًا أَم بِهِ جِنَّةٌ ۗ بَلِ الَّذينَ لا يُؤمِنونَ بِالآخِرَةِ فِي العَذابِ وَالضَّلالِ البَعيدِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdcxv{أَفَلَم يَرَوا إِلىٰ ما بَينَ أَيديهِم وَما خَلفَهُم مِنَ السَّماءِ وَالأَرضِ ۚ إِن نَشَأ نَخسِف بِهِمُ الأَرضَ أَو نُسقِط عَلَيهِم كِسَفًا مِنَ السَّماءِ ۚ إِنَّ في ذٰلِكَ لَآيَةً لِكُلِّ عَبدٍ مُنيبٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdcxvi{۞ وَلَقَد آتَينا داوودَ مِنّا فَضلًا ۖ يا جِبالُ أَوِّبي مَعَهُ وَالطَّيرَ ۖ وَأَلَنّا لَهُ الحَديدَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdcxvii{أَنِ اعمَل سابِغاتٍ وَقَدِّر فِي السَّردِ ۖ وَاعمَلوا صالِحًا ۖ إِنّي بِما تَعمَلونَ بَصيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdcxviii{وَلِسُلَيمانَ الرّيحَ غُدُوُّها شَهرٌ وَرَواحُها شَهرٌ ۖ وَأَسَلنا لَهُ عَينَ القِطرِ ۖ وَمِنَ الجِنِّ مَن يَعمَلُ بَينَ يَدَيهِ بِإِذنِ رَبِّهِ ۖ وَمَن يَزِغ مِنهُم عَن أَمرِنا نُذِقهُ مِن عَذابِ السَّعيرِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdcxix{يَعمَلونَ لَهُ ما يَشاءُ مِن مَحاريبَ وَتَماثيلَ وَجِفانٍ كَالجَوابِ وَقُدورٍ راسِياتٍ ۚ اعمَلوا آلَ داوودَ شُكرًا ۚ وَقَليلٌ مِن عِبادِيَ الشَّكورُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdcxx{فَلَمّا قَضَينا عَلَيهِ المَوتَ ما دَلَّهُم عَلىٰ مَوتِهِ إِلّا دابَّةُ الأَرضِ تَأكُلُ مِنسَأَتَهُ ۖ فَلَمّا خَرَّ تَبَيَّنَتِ الجِنُّ أَن لَو كانوا يَعلَمونَ الغَيبَ ما لَبِثوا فِي العَذابِ المُهينِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdcxxi{لَقَد كانَ لِسَبَإٍ في مَسكَنِهِم آيَةٌ ۖ جَنَّتانِ عَن يَمينٍ وَشِمالٍ ۖ كُلوا مِن رِزقِ رَبِّكُم وَاشكُروا لَهُ ۚ بَلدَةٌ طَيِّبَةٌ وَرَبٌّ غَفورٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdcxxii{فَأَعرَضوا فَأَرسَلنا عَلَيهِم سَيلَ العَرِمِ وَبَدَّلناهُم بِجَنَّتَيهِم جَنَّتَينِ ذَواتَي أُكُلٍ خَمطٍ وَأَثلٍ وَشَيءٍ مِن سِدرٍ قَليلٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdcxxiii{ذٰلِكَ جَزَيناهُم بِما كَفَروا ۖ وَهَل نُجازي إِلَّا الكَفورَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdcxxiv{وَجَعَلنا بَينَهُم وَبَينَ القُرَى الَّتي بارَكنا فيها قُرًى ظاهِرَةً وَقَدَّرنا فيهَا السَّيرَ ۖ سيروا فيها لَيالِيَ وَأَيّامًا آمِنينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdcxxv{فَقالوا رَبَّنا باعِد بَينَ أَسفارِنا وَظَلَموا أَنفُسَهُم فَجَعَلناهُم أَحاديثَ وَمَزَّقناهُم كُلَّ مُمَزَّقٍ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِكُلِّ صَبّارٍ شَكورٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdcxxvi{وَلَقَد صَدَّقَ عَلَيهِم إِبليسُ ظَنَّهُ فَاتَّبَعوهُ إِلّا فَريقًا مِنَ المُؤمِنينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdcxxvii{وَما كانَ لَهُ عَلَيهِم مِن سُلطانٍ إِلّا لِنَعلَمَ مَن يُؤمِنُ بِالآخِرَةِ مِمَّن هُوَ مِنها في شَكٍّ ۗ وَرَبُّكَ عَلىٰ كُلِّ شَيءٍ حَفيظٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdcxxviii{قُلِ ادعُوا الَّذينَ زَعَمتُم مِن دونِ اللَّهِ ۖ لا يَملِكونَ مِثقالَ ذَرَّةٍ فِي السَّماواتِ وَلا فِي الأَرضِ وَما لَهُم فيهِما مِن شِركٍ وَما لَهُ مِنهُم مِن ظَهيرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdcxxix{وَلا تَنفَعُ الشَّفاعَةُ عِندَهُ إِلّا لِمَن أَذِنَ لَهُ ۚ حَتّىٰ إِذا فُزِّعَ عَن قُلوبِهِم قالوا ماذا قالَ رَبُّكُم ۖ قالُوا الحَقَّ ۖ وَهُوَ العَلِيُّ الكَبيرُ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdcxxx{۞ قُل مَن يَرزُقُكُم مِنَ السَّماواتِ وَالأَرضِ ۖ قُلِ اللَّهُ ۖ وَإِنّا أَو إِيّاكُم لَعَلىٰ هُدًى أَو في ضَلالٍ مُبينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdcxxxi{قُل لا تُسأَلونَ عَمّا أَجرَمنا وَلا نُسأَلُ عَمّا تَعمَلونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdcxxxii{قُل يَجمَعُ بَينَنا رَبُّنا ثُمَّ يَفتَحُ بَينَنا بِالحَقِّ وَهُوَ الفَتّاحُ العَليمُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdcxxxiii{قُل أَرونِيَ الَّذينَ أَلحَقتُم بِهِ شُرَكاءَ ۖ كَلّا ۚ بَل هُوَ اللَّهُ العَزيزُ الحَكيمُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdcxxxiv{وَما أَرسَلناكَ إِلّا كافَّةً لِلنّاسِ بَشيرًا وَنَذيرًا وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdcxxxv{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صادِقينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdcxxxvi{قُل لَكُم ميعادُ يَومٍ لا تَستَأخِرونَ عَنهُ ساعَةً وَلا تَستَقدِمونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdcxxxvii{وَقالَ الَّذينَ كَفَروا لَن نُؤمِنَ بِهٰذَا القُرآنِ وَلا بِالَّذي بَينَ يَدَيهِ ۗ وَلَو تَرىٰ إِذِ الظّالِمونَ مَوقوفونَ عِندَ رَبِّهِم يَرجِعُ بَعضُهُم إِلىٰ بَعضٍ القَولَ يَقولُ الَّذينَ استُضعِفوا لِلَّذينَ استَكبَروا لَولا أَنتُم لَكُنّا مُؤمِنينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdcxxxviii{قالَ الَّذينَ استَكبَروا لِلَّذينَ استُضعِفوا أَنَحنُ صَدَدناكُم عَنِ الهُدىٰ بَعدَ إِذ جاءَكُم ۖ بَل كُنتُم مُجرِمينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdcxxxix{وَقالَ الَّذينَ استُضعِفوا لِلَّذينَ استَكبَروا بَل مَكرُ اللَّيلِ وَالنَّهارِ إِذ تَأمُرونَنا أَن نَكفُرَ بِاللَّهِ وَنَجعَلَ لَهُ أَندادًا ۚ وَأَسَرُّوا النَّدامَةَ لَمّا رَأَوُا العَذابَ وَجَعَلنَا الأَغلالَ في أَعناقِ الَّذينَ كَفَروا ۚ هَل يُجزَونَ إِلّا ما كانوا يَعمَلونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdcxl{وَما أَرسَلنا في قَريَةٍ مِن نَذيرٍ إِلّا قالَ مُترَفوها إِنّا بِما أُرسِلتُم بِهِ كافِرونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdcxli{وَقالوا نَحنُ أَكثَرُ أَموالًا وَأَولادًا وَما نَحنُ بِمُعَذَّبينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdcxlii{قُل إِنَّ رَبّي يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdcxliii{وَما أَموالُكُم وَلا أَولادُكُم بِالَّتي تُقَرِّبُكُم عِندَنا زُلفىٰ إِلّا مَن آمَنَ وَعَمِلَ صالِحًا فَأُولٰئِكَ لَهُم جَزاءُ الضِّعفِ بِما عَمِلوا وَهُم فِي الغُرُفاتِ آمِنونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdcxliv{وَالَّذينَ يَسعَونَ في آياتِنا مُعاجِزينَ أُولٰئِكَ فِي العَذابِ مُحضَرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdcxlv{قُل إِنَّ رَبّي يَبسُطُ الرِّزقَ لِمَن يَشاءُ مِن عِبادِهِ وَيَقدِرُ لَهُ ۚ وَما أَنفَقتُم مِن شَيءٍ فَهُوَ يُخلِفُهُ ۖ وَهُوَ خَيرُ الرّازِقينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdcxlvi{وَيَومَ يَحشُرُهُم جَميعًا ثُمَّ يَقولُ لِلمَلائِكَةِ أَهٰؤُلاءِ إِيّاكُم كانوا يَعبُدونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdcxlvii{قالوا سُبحانَكَ أَنتَ وَلِيُّنا مِن دونِهِم ۖ بَل كانوا يَعبُدونَ الجِنَّ ۖ أَكثَرُهُم بِهِم مُؤمِنونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdcxlviii{فَاليَومَ لا يَملِكُ بَعضُكُم لِبَعضٍ نَفعًا وَلا ضَرًّا وَنَقولُ لِلَّذينَ ظَلَموا ذوقوا عَذابَ النّارِ الَّتي كُنتُم بِها تُكَذِّبونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdcxlix{وَإِذا تُتلىٰ عَلَيهِم آياتُنا بَيِّناتٍ قالوا ما هٰذا إِلّا رَجُلٌ يُريدُ أَن يَصُدَّكُم عَمّا كانَ يَعبُدُ آباؤُكُم وَقالوا ما هٰذا إِلّا إِفكٌ مُفتَرًى ۚ وَقالَ الَّذينَ كَفَروا لِلحَقِّ لَمّا جاءَهُم إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdcl{وَما آتَيناهُم مِن كُتُبٍ يَدرُسونَها ۖ وَما أَرسَلنا إِلَيهِم قَبلَكَ مِن نَذيرٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdcli{وَكَذَّبَ الَّذينَ مِن قَبلِهِم وَما بَلَغوا مِعشارَ ما آتَيناهُم فَكَذَّبوا رُسُلي ۖ فَكَيفَ كانَ نَكيرِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdclii{۞ قُل إِنَّما أَعِظُكُم بِواحِدَةٍ ۖ أَن تَقوموا لِلَّهِ مَثنىٰ وَفُرادىٰ ثُمَّ تَتَفَكَّروا ۚ ما بِصاحِبِكُم مِن جِنَّةٍ ۚ إِن هُوَ إِلّا نَذيرٌ لَكُم بَينَ يَدَي عَذابٍ شَديدٍ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdcliii{قُل ما سَأَلتُكُم مِن أَجرٍ فَهُوَ لَكُم ۖ إِن أَجرِيَ إِلّا عَلَى اللَّهِ ۖ وَهُوَ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdcliv{قُل إِنَّ رَبّي يَقذِفُ بِالحَقِّ عَلّامُ الغُيوبِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdclv{قُل جاءَ الحَقُّ وَما يُبدِئُ الباطِلُ وَما يُعيدُ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdclvi{قُل إِن ضَلَلتُ فَإِنَّما أَضِلُّ عَلىٰ نَفسي ۖ وَإِنِ اهتَدَيتُ فَبِما يوحي إِلَيَّ رَبّي ۚ إِنَّهُ سَميعٌ قَريبٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdclvii{وَلَو تَرىٰ إِذ فَزِعوا فَلا فَوتَ وَأُخِذوا مِن مَكانٍ قَريبٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdclviii{وَقالوا آمَنّا بِهِ وَأَنّىٰ لَهُمُ التَّناوُشُ مِن مَكانٍ بَعيدٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdclix{وَقَد كَفَروا بِهِ مِن قَبلُ ۖ وَيَقذِفونَ بِالغَيبِ مِن مَكانٍ بَعيدٍ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdclx{وَحيلَ بَينَهُم وَبَينَ ما يَشتَهونَ كَما فُعِلَ بِأَشياعِهِم مِن قَبلُ ۚ إِنَّهُم كانوا في شَكٍّ مُريبٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdclxi{\basmalah الحَمدُ لِلَّهِ فاطِرِ السَّماواتِ وَالأَرضِ جاعِلِ المَلائِكَةِ رُسُلًا أُولي أَجنِحَةٍ مَثنىٰ وَثُلاثَ وَرُباعَ ۚ يَزيدُ فِي الخَلقِ ما يَشاءُ ۚ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdclxii{ما يَفتَحِ اللَّهُ لِلنّاسِ مِن رَحمَةٍ فَلا مُمسِكَ لَها ۖ وَما يُمسِك فَلا مُرسِلَ لَهُ مِن بَعدِهِ ۚ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdclxiii{يا أَيُّهَا النّاسُ اذكُروا نِعمَتَ اللَّهِ عَلَيكُم ۚ هَل مِن خالِقٍ غَيرُ اللَّهِ يَرزُقُكُم مِنَ السَّماءِ وَالأَرضِ ۚ لا إِلٰهَ إِلّا هُوَ ۖ فَأَنّىٰ تُؤفَكونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdclxiv{وَإِن يُكَذِّبوكَ فَقَد كُذِّبَت رُسُلٌ مِن قَبلِكَ ۚ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdclxv{يا أَيُّهَا النّاسُ إِنَّ وَعدَ اللَّهِ حَقٌّ ۖ فَلا تَغُرَّنَّكُمُ الحَياةُ الدُّنيا ۖ وَلا يَغُرَّنَّكُم بِاللَّهِ الغَرورُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdclxvi{إِنَّ الشَّيطانَ لَكُم عَدُوٌّ فَاتَّخِذوهُ عَدُوًّا ۚ إِنَّما يَدعو حِزبَهُ لِيَكونوا مِن أَصحابِ السَّعيرِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdclxvii{الَّذينَ كَفَروا لَهُم عَذابٌ شَديدٌ ۖ وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لَهُم مَغفِرَةٌ وَأَجرٌ كَبيرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdclxviii{أَفَمَن زُيِّنَ لَهُ سوءُ عَمَلِهِ فَرَآهُ حَسَنًا ۖ فَإِنَّ اللَّهَ يُضِلُّ مَن يَشاءُ وَيَهدي مَن يَشاءُ ۖ فَلا تَذهَب نَفسُكَ عَلَيهِم حَسَراتٍ ۚ إِنَّ اللَّهَ عَليمٌ بِما يَصنَعونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdclxix{وَاللَّهُ الَّذي أَرسَلَ الرِّياحَ فَتُثيرُ سَحابًا فَسُقناهُ إِلىٰ بَلَدٍ مَيِّتٍ فَأَحيَينا بِهِ الأَرضَ بَعدَ مَوتِها ۚ كَذٰلِكَ النُّشورُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdclxx{مَن كانَ يُريدُ العِزَّةَ فَلِلَّهِ العِزَّةُ جَميعًا ۚ إِلَيهِ يَصعَدُ الكَلِمُ الطَّيِّبُ وَالعَمَلُ الصّالِحُ يَرفَعُهُ ۚ وَالَّذينَ يَمكُرونَ السَّيِّئَاتِ لَهُم عَذابٌ شَديدٌ ۖ وَمَكرُ أُولٰئِكَ هُوَ يَبورُ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdclxxi{وَاللَّهُ خَلَقَكُم مِن تُرابٍ ثُمَّ مِن نُطفَةٍ ثُمَّ جَعَلَكُم أَزواجًا ۚ وَما تَحمِلُ مِن أُنثىٰ وَلا تَضَعُ إِلّا بِعِلمِهِ ۚ وَما يُعَمَّرُ مِن مُعَمَّرٍ وَلا يُنقَصُ مِن عُمُرِهِ إِلّا في كِتابٍ ۚ إِنَّ ذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdclxxii{وَما يَستَوِي البَحرانِ هٰذا عَذبٌ فُراتٌ سائِغٌ شَرابُهُ وَهٰذا مِلحٌ أُجاجٌ ۖ وَمِن كُلٍّ تَأكُلونَ لَحمًا طَرِيًّا وَتَستَخرِجونَ حِليَةً تَلبَسونَها ۖ وَتَرَى الفُلكَ فيهِ مَواخِرَ لِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdclxxiii{يولِجُ اللَّيلَ فِي النَّهارِ وَيولِجُ النَّهارَ فِي اللَّيلِ وَسَخَّرَ الشَّمسَ وَالقَمَرَ كُلٌّ يَجري لِأَجَلٍ مُسَمًّى ۚ ذٰلِكُمُ اللَّهُ رَبُّكُم لَهُ المُلكُ ۚ وَالَّذينَ تَدعونَ مِن دونِهِ ما يَملِكونَ مِن قِطميرٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdclxxiv{إِن تَدعوهُم لا يَسمَعوا دُعاءَكُم وَلَو سَمِعوا مَا استَجابوا لَكُم ۖ وَيَومَ القِيامَةِ يَكفُرونَ بِشِركِكُم ۚ وَلا يُنَبِّئُكَ مِثلُ خَبيرٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdclxxv{۞ يا أَيُّهَا النّاسُ أَنتُمُ الفُقَراءُ إِلَى اللَّهِ ۖ وَاللَّهُ هُوَ الغَنِيُّ الحَميدُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdclxxvi{إِن يَشَأ يُذهِبكُم وَيَأتِ بِخَلقٍ جَديدٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdclxxvii{وَما ذٰلِكَ عَلَى اللَّهِ بِعَزيزٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdclxxviii{وَلا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ ۚ وَإِن تَدعُ مُثقَلَةٌ إِلىٰ حِملِها لا يُحمَل مِنهُ شَيءٌ وَلَو كانَ ذا قُربىٰ ۗ إِنَّما تُنذِرُ الَّذينَ يَخشَونَ رَبَّهُم بِالغَيبِ وَأَقامُوا الصَّلاةَ ۚ وَمَن تَزَكّىٰ فَإِنَّما يَتَزَكّىٰ لِنَفسِهِ ۚ وَإِلَى اللَّهِ المَصيرُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdclxxix{وَما يَستَوِي الأَعمىٰ وَالبَصيرُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdclxxx{وَلَا الظُّلُماتُ وَلَا النّورُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdclxxxi{وَلَا الظِّلُّ وَلَا الحَرورُ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdclxxxii{وَما يَستَوِي الأَحياءُ وَلَا الأَمواتُ ۚ إِنَّ اللَّهَ يُسمِعُ مَن يَشاءُ ۖ وَما أَنتَ بِمُسمِعٍ مَن فِي القُبورِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdclxxxiii{إِن أَنتَ إِلّا نَذيرٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdclxxxiv{إِنّا أَرسَلناكَ بِالحَقِّ بَشيرًا وَنَذيرًا ۚ وَإِن مِن أُمَّةٍ إِلّا خَلا فيها نَذيرٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdclxxxv{وَإِن يُكَذِّبوكَ فَقَد كَذَّبَ الَّذينَ مِن قَبلِهِم جاءَتهُم رُسُلُهُم بِالبَيِّناتِ وَبِالزُّبُرِ وَبِالكِتابِ المُنيرِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdclxxxvi{ثُمَّ أَخَذتُ الَّذينَ كَفَروا ۖ فَكَيفَ كانَ نَكيرِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdclxxxvii{أَلَم تَرَ أَنَّ اللَّهَ أَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجنا بِهِ ثَمَراتٍ مُختَلِفًا أَلوانُها ۚ وَمِنَ الجِبالِ جُدَدٌ بيضٌ وَحُمرٌ مُختَلِفٌ أَلوانُها وَغَرابيبُ سودٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdclxxxviii{وَمِنَ النّاسِ وَالدَّوابِّ وَالأَنعامِ مُختَلِفٌ أَلوانُهُ كَذٰلِكَ ۗ إِنَّما يَخشَى اللَّهَ مِن عِبادِهِ العُلَماءُ ۗ إِنَّ اللَّهَ عَزيزٌ غَفورٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdclxxxix{إِنَّ الَّذينَ يَتلونَ كِتابَ اللَّهِ وَأَقامُوا الصَّلاةَ وَأَنفَقوا مِمّا رَزَقناهُم سِرًّا وَعَلانِيَةً يَرجونَ تِجارَةً لَن تَبورَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdcxc{لِيُوَفِّيَهُم أُجورَهُم وَيَزيدَهُم مِن فَضلِهِ ۚ إِنَّهُ غَفورٌ شَكورٌ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdcxci{وَالَّذي أَوحَينا إِلَيكَ مِنَ الكِتابِ هُوَ الحَقُّ مُصَدِّقًا لِما بَينَ يَدَيهِ ۗ إِنَّ اللَّهَ بِعِبادِهِ لَخَبيرٌ بَصيرٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdcxcii{ثُمَّ أَورَثنَا الكِتابَ الَّذينَ اصطَفَينا مِن عِبادِنا ۖ فَمِنهُم ظالِمٌ لِنَفسِهِ وَمِنهُم مُقتَصِدٌ وَمِنهُم سابِقٌ بِالخَيراتِ بِإِذنِ اللَّهِ ۚ ذٰلِكَ هُوَ الفَضلُ الكَبيرُ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdcxciii{جَنّاتُ عَدنٍ يَدخُلونَها يُحَلَّونَ فيها مِن أَساوِرَ مِن ذَهَبٍ وَلُؤلُؤًا ۖ وَلِباسُهُم فيها حَريرٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdcxciv{وَقالُوا الحَمدُ لِلَّهِ الَّذي أَذهَبَ عَنَّا الحَزَنَ ۖ إِنَّ رَبَّنا لَغَفورٌ شَكورٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdcxcv{الَّذي أَحَلَّنا دارَ المُقامَةِ مِن فَضلِهِ لا يَمَسُّنا فيها نَصَبٌ وَلا يَمَسُّنا فيها لُغوبٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdcxcvi{وَالَّذينَ كَفَروا لَهُم نارُ جَهَنَّمَ لا يُقضىٰ عَلَيهِم فَيَموتوا وَلا يُخَفَّفُ عَنهُم مِن عَذابِها ۚ كَذٰلِكَ نَجزي كُلَّ كَفورٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdcxcvii{وَهُم يَصطَرِخونَ فيها رَبَّنا أَخرِجنا نَعمَل صالِحًا غَيرَ الَّذي كُنّا نَعمَلُ ۚ أَوَلَم نُعَمِّركُم ما يَتَذَكَّرُ فيهِ مَن تَذَكَّرَ وَجاءَكُمُ النَّذيرُ ۖ فَذوقوا فَما لِلظّالِمينَ مِن نَصيرٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdcxcviii{إِنَّ اللَّهَ عالِمُ غَيبِ السَّماواتِ وَالأَرضِ ۚ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdcxcix{هُوَ الَّذي جَعَلَكُم خَلائِفَ فِي الأَرضِ ۚ فَمَن كَفَرَ فَعَلَيهِ كُفرُهُ ۖ وَلا يَزيدُ الكافِرينَ كُفرُهُم عِندَ رَبِّهِم إِلّا مَقتًا ۖ وَلا يَزيدُ الكافِرينَ كُفرُهُم إِلّا خَسارًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdcc{قُل أَرَأَيتُم شُرَكاءَكُمُ الَّذينَ تَدعونَ مِن دونِ اللَّهِ أَروني ماذا خَلَقوا مِنَ الأَرضِ أَم لَهُم شِركٌ فِي السَّماواتِ أَم آتَيناهُم كِتابًا فَهُم عَلىٰ بَيِّنَتٍ مِنهُ ۚ بَل إِن يَعِدُ الظّالِمونَ بَعضُهُم بَعضًا إِلّا غُرورًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdcci{۞ إِنَّ اللَّهَ يُمسِكُ السَّماواتِ وَالأَرضَ أَن تَزولا ۚ وَلَئِن زالَتا إِن أَمسَكَهُما مِن أَحَدٍ مِن بَعدِهِ ۚ إِنَّهُ كانَ حَليمًا غَفورًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdccii{وَأَقسَموا بِاللَّهِ جَهدَ أَيمانِهِم لَئِن جاءَهُم نَذيرٌ لَيَكونُنَّ أَهدىٰ مِن إِحدَى الأُمَمِ ۖ فَلَمّا جاءَهُم نَذيرٌ ما زادَهُم إِلّا نُفورًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdcciii{استِكبارًا فِي الأَرضِ وَمَكرَ السَّيِّئِ ۚ وَلا يَحيقُ المَكرُ السَّيِّئُ إِلّا بِأَهلِهِ ۚ فَهَل يَنظُرونَ إِلّا سُنَّتَ الأَوَّلينَ ۚ فَلَن تَجِدَ لِسُنَّتِ اللَّهِ تَبديلًا ۖ وَلَن تَجِدَ لِسُنَّتِ اللَّهِ تَحويلًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdcciv{أَوَلَم يَسيروا فِي الأَرضِ فَيَنظُروا كَيفَ كانَ عاقِبَةُ الَّذينَ مِن قَبلِهِم وَكانوا أَشَدَّ مِنهُم قُوَّةً ۚ وَما كانَ اللَّهُ لِيُعجِزَهُ مِن شَيءٍ فِي السَّماواتِ وَلا فِي الأَرضِ ۚ إِنَّهُ كانَ عَليمًا قَديرًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdccv{وَلَو يُؤاخِذُ اللَّهُ النّاسَ بِما كَسَبوا ما تَرَكَ عَلىٰ ظَهرِها مِن دابَّةٍ وَلٰكِن يُؤَخِّرُهُم إِلىٰ أَجَلٍ مُسَمًّى ۖ فَإِذا جاءَ أَجَلُهُم فَإِنَّ اللَّهَ كانَ بِعِبادِهِ بَصيرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdccvi{\basmalah يس\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdccvii{وَالقُرآنِ الحَكيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdccviii{إِنَّكَ لَمِنَ المُرسَلينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdccix{عَلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdccx{تَنزيلَ العَزيزِ الرَّحيمِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdccxi{لِتُنذِرَ قَومًا ما أُنذِرَ آباؤُهُم فَهُم غافِلونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdccxii{لَقَد حَقَّ القَولُ عَلىٰ أَكثَرِهِم فَهُم لا يُؤمِنونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdccxiii{إِنّا جَعَلنا في أَعناقِهِم أَغلالًا فَهِيَ إِلَى الأَذقانِ فَهُم مُقمَحونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdccxiv{وَجَعَلنا مِن بَينِ أَيديهِم سَدًّا وَمِن خَلفِهِم سَدًّا فَأَغشَيناهُم فَهُم لا يُبصِرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdccxv{وَسَواءٌ عَلَيهِم أَأَنذَرتَهُم أَم لَم تُنذِرهُم لا يُؤمِنونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdccxvi{إِنَّما تُنذِرُ مَنِ اتَّبَعَ الذِّكرَ وَخَشِيَ الرَّحمٰنَ بِالغَيبِ ۖ فَبَشِّرهُ بِمَغفِرَةٍ وَأَجرٍ كَريمٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdccxvii{إِنّا نَحنُ نُحيِي المَوتىٰ وَنَكتُبُ ما قَدَّموا وَآثارَهُم ۚ وَكُلَّ شَيءٍ أَحصَيناهُ في إِمامٍ مُبينٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdccxviii{وَاضرِب لَهُم مَثَلًا أَصحابَ القَريَةِ إِذ جاءَهَا المُرسَلونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdccxix{إِذ أَرسَلنا إِلَيهِمُ اثنَينِ فَكَذَّبوهُما فَعَزَّزنا بِثالِثٍ فَقالوا إِنّا إِلَيكُم مُرسَلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdccxx{قالوا ما أَنتُم إِلّا بَشَرٌ مِثلُنا وَما أَنزَلَ الرَّحمٰنُ مِن شَيءٍ إِن أَنتُم إِلّا تَكذِبونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdccxxi{قالوا رَبُّنا يَعلَمُ إِنّا إِلَيكُم لَمُرسَلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdccxxii{وَما عَلَينا إِلَّا البَلاغُ المُبينُ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdccxxiii{قالوا إِنّا تَطَيَّرنا بِكُم ۖ لَئِن لَم تَنتَهوا لَنَرجُمَنَّكُم وَلَيَمَسَّنَّكُم مِنّا عَذابٌ أَليمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdccxxiv{قالوا طائِرُكُم مَعَكُم ۚ أَئِن ذُكِّرتُم ۚ بَل أَنتُم قَومٌ مُسرِفونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdccxxv{وَجاءَ مِن أَقصَى المَدينَةِ رَجُلٌ يَسعىٰ قالَ يا قَومِ اتَّبِعُوا المُرسَلينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdccxxvi{اتَّبِعوا مَن لا يَسأَلُكُم أَجرًا وَهُم مُهتَدونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdccxxvii{وَما لِيَ لا أَعبُدُ الَّذي فَطَرَني وَإِلَيهِ تُرجَعونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdccxxviii{أَأَتَّخِذُ مِن دونِهِ آلِهَةً إِن يُرِدنِ الرَّحمٰنُ بِضُرٍّ لا تُغنِ عَنّي شَفاعَتُهُم شَيئًا وَلا يُنقِذونِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdccxxix{إِنّي إِذًا لَفي ضَلالٍ مُبينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdccxxx{إِنّي آمَنتُ بِرَبِّكُم فَاسمَعونِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdccxxxi{قيلَ ادخُلِ الجَنَّةَ ۖ قالَ يا لَيتَ قَومي يَعلَمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdccxxxii{بِما غَفَرَ لي رَبّي وَجَعَلَني مِنَ المُكرَمينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdccxxxiii{۞ وَما أَنزَلنا عَلىٰ قَومِهِ مِن بَعدِهِ مِن جُندٍ مِنَ السَّماءِ وَما كُنّا مُنزِلينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdccxxxiv{إِن كانَت إِلّا صَيحَةً واحِدَةً فَإِذا هُم خامِدونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdccxxxv{يا حَسرَةً عَلَى العِبادِ ۚ ما يَأتيهِم مِن رَسولٍ إِلّا كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdccxxxvi{أَلَم يَرَوا كَم أَهلَكنا قَبلَهُم مِنَ القُرونِ أَنَّهُم إِلَيهِم لا يَرجِعونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdccxxxvii{وَإِن كُلٌّ لَمّا جَميعٌ لَدَينا مُحضَرونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdccxxxviii{وَآيَةٌ لَهُمُ الأَرضُ المَيتَةُ أَحيَيناها وَأَخرَجنا مِنها حَبًّا فَمِنهُ يَأكُلونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdccxxxix{وَجَعَلنا فيها جَنّاتٍ مِن نَخيلٍ وَأَعنابٍ وَفَجَّرنا فيها مِنَ العُيونِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdccxl{لِيَأكُلوا مِن ثَمَرِهِ وَما عَمِلَتهُ أَيديهِم ۖ أَفَلا يَشكُرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdccxli{سُبحانَ الَّذي خَلَقَ الأَزواجَ كُلَّها مِمّا تُنبِتُ الأَرضُ وَمِن أَنفُسِهِم وَمِمّا لا يَعلَمونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdccxlii{وَآيَةٌ لَهُمُ اللَّيلُ نَسلَخُ مِنهُ النَّهارَ فَإِذا هُم مُظلِمونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdccxliii{وَالشَّمسُ تَجري لِمُستَقَرٍّ لَها ۚ ذٰلِكَ تَقديرُ العَزيزِ العَليمِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdccxliv{وَالقَمَرَ قَدَّرناهُ مَنازِلَ حَتّىٰ عادَ كَالعُرجونِ القَديمِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdccxlv{لَا الشَّمسُ يَنبَغي لَها أَن تُدرِكَ القَمَرَ وَلَا اللَّيلُ سابِقُ النَّهارِ ۚ وَكُلٌّ في فَلَكٍ يَسبَحونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdccxlvi{وَآيَةٌ لَهُم أَنّا حَمَلنا ذُرِّيَّتَهُم فِي الفُلكِ المَشحونِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdccxlvii{وَخَلَقنا لَهُم مِن مِثلِهِ ما يَركَبونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdccxlviii{وَإِن نَشَأ نُغرِقهُم فَلا صَريخَ لَهُم وَلا هُم يُنقَذونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdccxlix{إِلّا رَحمَةً مِنّا وَمَتاعًا إِلىٰ حينٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdccl{وَإِذا قيلَ لَهُمُ اتَّقوا ما بَينَ أَيديكُم وَما خَلفَكُم لَعَلَّكُم تُرحَمونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdccli{وَما تَأتيهِم مِن آيَةٍ مِن آياتِ رَبِّهِم إِلّا كانوا عَنها مُعرِضينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdcclii{وَإِذا قيلَ لَهُم أَنفِقوا مِمّا رَزَقَكُمُ اللَّهُ قالَ الَّذينَ كَفَروا لِلَّذينَ آمَنوا أَنُطعِمُ مَن لَو يَشاءُ اللَّهُ أَطعَمَهُ إِن أَنتُم إِلّا في ضَلالٍ مُبينٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdccliii{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صادِقينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdccliv{ما يَنظُرونَ إِلّا صَيحَةً واحِدَةً تَأخُذُهُم وَهُم يَخِصِّمونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdcclv{فَلا يَستَطيعونَ تَوصِيَةً وَلا إِلىٰ أَهلِهِم يَرجِعونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdcclvi{وَنُفِخَ فِي الصّورِ فَإِذا هُم مِنَ الأَجداثِ إِلىٰ رَبِّهِم يَنسِلونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdcclvii{قالوا يا وَيلَنا مَن بَعَثَنا مِن مَرقَدِنا ۜ ۗ هٰذا ما وَعَدَ الرَّحمٰنُ وَصَدَقَ المُرسَلونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdcclviii{إِن كانَت إِلّا صَيحَةً واحِدَةً فَإِذا هُم جَميعٌ لَدَينا مُحضَرونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdcclix{فَاليَومَ لا تُظلَمُ نَفسٌ شَيئًا وَلا تُجزَونَ إِلّا ما كُنتُم تَعمَلونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdcclx{إِنَّ أَصحابَ الجَنَّةِ اليَومَ في شُغُلٍ فاكِهونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmdcclxi{هُم وَأَزواجُهُم في ظِلالٍ عَلَى الأَرائِكِ مُتَّكِئونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmdcclxii{لَهُم فيها فاكِهَةٌ وَلَهُم ما يَدَّعونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmdcclxiii{سَلامٌ قَولًا مِن رَبٍّ رَحيمٍ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmdcclxiv{وَامتازُوا اليَومَ أَيُّهَا المُجرِمونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmdcclxv{۞ أَلَم أَعهَد إِلَيكُم يا بَني آدَمَ أَن لا تَعبُدُوا الشَّيطانَ ۖ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmdcclxvi{وَأَنِ اعبُدوني ۚ هٰذا صِراطٌ مُستَقيمٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmdcclxvii{وَلَقَد أَضَلَّ مِنكُم جِبِلًّا كَثيرًا ۖ أَفَلَم تَكونوا تَعقِلونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmdcclxviii{هٰذِهِ جَهَنَّمُ الَّتي كُنتُم توعَدونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmdcclxix{اصلَوهَا اليَومَ بِما كُنتُم تَكفُرونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmdcclxx{اليَومَ نَختِمُ عَلىٰ أَفواهِهِم وَتُكَلِّمُنا أَيديهِم وَتَشهَدُ أَرجُلُهُم بِما كانوا يَكسِبونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmdcclxxi{وَلَو نَشاءُ لَطَمَسنا عَلىٰ أَعيُنِهِم فَاستَبَقُوا الصِّراطَ فَأَنّىٰ يُبصِرونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmdcclxxii{وَلَو نَشاءُ لَمَسَخناهُم عَلىٰ مَكانَتِهِم فَمَا استَطاعوا مُضِيًّا وَلا يَرجِعونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmdcclxxiii{وَمَن نُعَمِّرهُ نُنَكِّسهُ فِي الخَلقِ ۖ أَفَلا يَعقِلونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmdcclxxiv{وَما عَلَّمناهُ الشِّعرَ وَما يَنبَغي لَهُ ۚ إِن هُوَ إِلّا ذِكرٌ وَقُرآنٌ مُبينٌ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmdcclxxv{لِيُنذِرَ مَن كانَ حَيًّا وَيَحِقَّ القَولُ عَلَى الكافِرينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmdcclxxvi{أَوَلَم يَرَوا أَنّا خَلَقنا لَهُم مِمّا عَمِلَت أَيدينا أَنعامًا فَهُم لَها مالِكونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmdcclxxvii{وَذَلَّلناها لَهُم فَمِنها رَكوبُهُم وَمِنها يَأكُلونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmdcclxxviii{وَلَهُم فيها مَنافِعُ وَمَشارِبُ ۖ أَفَلا يَشكُرونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmdcclxxix{وَاتَّخَذوا مِن دونِ اللَّهِ آلِهَةً لَعَلَّهُم يُنصَرونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmdcclxxx{لا يَستَطيعونَ نَصرَهُم وَهُم لَهُم جُندٌ مُحضَرونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmdcclxxxi{فَلا يَحزُنكَ قَولُهُم ۘ إِنّا نَعلَمُ ما يُسِرّونَ وَما يُعلِنونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmdcclxxxii{أَوَلَم يَرَ الإِنسانُ أَنّا خَلَقناهُ مِن نُطفَةٍ فَإِذا هُوَ خَصيمٌ مُبينٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmdcclxxxiii{وَضَرَبَ لَنا مَثَلًا وَنَسِيَ خَلقَهُ ۖ قالَ مَن يُحيِي العِظامَ وَهِيَ رَميمٌ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmdcclxxxiv{قُل يُحييهَا الَّذي أَنشَأَها أَوَّلَ مَرَّةٍ ۖ وَهُوَ بِكُلِّ خَلقٍ عَليمٌ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmdcclxxxv{الَّذي جَعَلَ لَكُم مِنَ الشَّجَرِ الأَخضَرِ نارًا فَإِذا أَنتُم مِنهُ توقِدونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmdcclxxxvi{أَوَلَيسَ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ بِقادِرٍ عَلىٰ أَن يَخلُقَ مِثلَهُم ۚ بَلىٰ وَهُوَ الخَلّاقُ العَليمُ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmdcclxxxvii{إِنَّما أَمرُهُ إِذا أَرادَ شَيئًا أَن يَقولَ لَهُ كُن فَيَكونُ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmdcclxxxviii{فَسُبحانَ الَّذي بِيَدِهِ مَلَكوتُ كُلِّ شَيءٍ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmdcclxxxix{\basmalah وَالصّافّاتِ صَفًّا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdccxc{فَالزّاجِراتِ زَجرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdccxci{فَالتّالِياتِ ذِكرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdccxcii{إِنَّ إِلٰهَكُم لَواحِدٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdccxciii{رَبُّ السَّماواتِ وَالأَرضِ وَما بَينَهُما وَرَبُّ المَشارِقِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdccxciv{إِنّا زَيَّنَّا السَّماءَ الدُّنيا بِزينَةٍ الكَواكِبِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdccxcv{وَحِفظًا مِن كُلِّ شَيطانٍ مارِدٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdccxcvi{لا يَسَّمَّعونَ إِلَى المَلَإِ الأَعلىٰ وَيُقذَفونَ مِن كُلِّ جانِبٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdccxcvii{دُحورًا ۖ وَلَهُم عَذابٌ واصِبٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdccxcviii{إِلّا مَن خَطِفَ الخَطفَةَ فَأَتبَعَهُ شِهابٌ ثاقِبٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdccxcix{فَاستَفتِهِم أَهُم أَشَدُّ خَلقًا أَم مَن خَلَقنا ۚ إِنّا خَلَقناهُم مِن طينٍ لازِبٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdccc{بَل عَجِبتَ وَيَسخَرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdccci{وَإِذا ذُكِّروا لا يَذكُرونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdcccii{وَإِذا رَأَوا آيَةً يَستَسخِرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdccciii{وَقالوا إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdccciv{أَإِذا مِتنا وَكُنّا تُرابًا وَعِظامًا أَإِنّا لَمَبعوثونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdcccv{أَوَآباؤُنَا الأَوَّلونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdcccvi{قُل نَعَم وَأَنتُم داخِرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdcccvii{فَإِنَّما هِيَ زَجرَةٌ واحِدَةٌ فَإِذا هُم يَنظُرونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdcccviii{وَقالوا يا وَيلَنا هٰذا يَومُ الدّينِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdcccix{هٰذا يَومُ الفَصلِ الَّذي كُنتُم بِهِ تُكَذِّبونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdcccx{۞ احشُرُوا الَّذينَ ظَلَموا وَأَزواجَهُم وَما كانوا يَعبُدونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdcccxi{مِن دونِ اللَّهِ فَاهدوهُم إِلىٰ صِراطِ الجَحيمِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdcccxii{وَقِفوهُم ۖ إِنَّهُم مَسئولونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdcccxiii{ما لَكُم لا تَناصَرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdcccxiv{بَل هُمُ اليَومَ مُستَسلِمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdcccxv{وَأَقبَلَ بَعضُهُم عَلىٰ بَعضٍ يَتَساءَلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdcccxvi{قالوا إِنَّكُم كُنتُم تَأتونَنا عَنِ اليَمينِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdcccxvii{قالوا بَل لَم تَكونوا مُؤمِنينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdcccxviii{وَما كانَ لَنا عَلَيكُم مِن سُلطانٍ ۖ بَل كُنتُم قَومًا طاغينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdcccxix{فَحَقَّ عَلَينا قَولُ رَبِّنا ۖ إِنّا لَذائِقونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdcccxx{فَأَغوَيناكُم إِنّا كُنّا غاوينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdcccxxi{فَإِنَّهُم يَومَئِذٍ فِي العَذابِ مُشتَرِكونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdcccxxii{إِنّا كَذٰلِكَ نَفعَلُ بِالمُجرِمينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdcccxxiii{إِنَّهُم كانوا إِذا قيلَ لَهُم لا إِلٰهَ إِلَّا اللَّهُ يَستَكبِرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdcccxxiv{وَيَقولونَ أَئِنّا لَتارِكو آلِهَتِنا لِشاعِرٍ مَجنونٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdcccxxv{بَل جاءَ بِالحَقِّ وَصَدَّقَ المُرسَلينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdcccxxvi{إِنَّكُم لَذائِقُو العَذابِ الأَليمِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdcccxxvii{وَما تُجزَونَ إِلّا ما كُنتُم تَعمَلونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdcccxxviii{إِلّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdcccxxix{أُولٰئِكَ لَهُم رِزقٌ مَعلومٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdcccxxx{فَواكِهُ ۖ وَهُم مُكرَمونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdcccxxxi{في جَنّاتِ النَّعيمِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdcccxxxii{عَلىٰ سُرُرٍ مُتَقابِلينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdcccxxxiii{يُطافُ عَلَيهِم بِكَأسٍ مِن مَعينٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdcccxxxiv{بَيضاءَ لَذَّةٍ لِلشّارِبينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdcccxxxv{لا فيها غَولٌ وَلا هُم عَنها يُنزَفونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdcccxxxvi{وَعِندَهُم قاصِراتُ الطَّرفِ عينٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdcccxxxvii{كَأَنَّهُنَّ بَيضٌ مَكنونٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdcccxxxviii{فَأَقبَلَ بَعضُهُم عَلىٰ بَعضٍ يَتَساءَلونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdcccxxxix{قالَ قائِلٌ مِنهُم إِنّي كانَ لي قَرينٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdcccxl{يَقولُ أَإِنَّكَ لَمِنَ المُصَدِّقينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdcccxli{أَإِذا مِتنا وَكُنّا تُرابًا وَعِظامًا أَإِنّا لَمَدينونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdcccxlii{قالَ هَل أَنتُم مُطَّلِعونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdcccxliii{فَاطَّلَعَ فَرَآهُ في سَواءِ الجَحيمِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmdcccxliv{قالَ تَاللَّهِ إِن كِدتَ لَتُردينِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmdcccxlv{وَلَولا نِعمَةُ رَبّي لَكُنتُ مِنَ المُحضَرينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmdcccxlvi{أَفَما نَحنُ بِمَيِّتينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmdcccxlvii{إِلّا مَوتَتَنَا الأولىٰ وَما نَحنُ بِمُعَذَّبينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmdcccxlviii{إِنَّ هٰذا لَهُوَ الفَوزُ العَظيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmdcccxlix{لِمِثلِ هٰذا فَليَعمَلِ العامِلونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmdcccl{أَذٰلِكَ خَيرٌ نُزُلًا أَم شَجَرَةُ الزَّقّومِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmdcccli{إِنّا جَعَلناها فِتنَةً لِلظّالِمينَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmdccclii{إِنَّها شَجَرَةٌ تَخرُجُ في أَصلِ الجَحيمِ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmdcccliii{طَلعُها كَأَنَّهُ رُءوسُ الشَّياطينِ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmdcccliv{فَإِنَّهُم لَآكِلونَ مِنها فَمالِئونَ مِنهَا البُطونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmdccclv{ثُمَّ إِنَّ لَهُم عَلَيها لَشَوبًا مِن حَميمٍ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmdccclvi{ثُمَّ إِنَّ مَرجِعَهُم لَإِلَى الجَحيمِ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmdccclvii{إِنَّهُم أَلفَوا آباءَهُم ضالّينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmdccclviii{فَهُم عَلىٰ آثارِهِم يُهرَعونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmdccclix{وَلَقَد ضَلَّ قَبلَهُم أَكثَرُ الأَوَّلينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmdccclx{وَلَقَد أَرسَلنا فيهِم مُنذِرينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmdccclxi{فَانظُر كَيفَ كانَ عاقِبَةُ المُنذَرينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmdccclxii{إِلّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmdccclxiii{وَلَقَد نادانا نوحٌ فَلَنِعمَ المُجيبونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmdccclxiv{وَنَجَّيناهُ وَأَهلَهُ مِنَ الكَربِ العَظيمِ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmdccclxv{وَجَعَلنا ذُرِّيَّتَهُ هُمُ الباقينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmdccclxvi{وَتَرَكنا عَلَيهِ فِي الآخِرينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmdccclxvii{سَلامٌ عَلىٰ نوحٍ فِي العالَمينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmdccclxviii{إِنّا كَذٰلِكَ نَجزِي المُحسِنينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmdccclxix{إِنَّهُ مِن عِبادِنَا المُؤمِنينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmdccclxx{ثُمَّ أَغرَقنَا الآخَرينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmdccclxxi{۞ وَإِنَّ مِن شيعَتِهِ لَإِبراهيمَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmdccclxxii{إِذ جاءَ رَبَّهُ بِقَلبٍ سَليمٍ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmdccclxxiii{إِذ قالَ لِأَبيهِ وَقَومِهِ ماذا تَعبُدونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmdccclxxiv{أَئِفكًا آلِهَةً دونَ اللَّهِ تُريدونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmdccclxxv{فَما ظَنُّكُم بِرَبِّ العالَمينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmdccclxxvi{فَنَظَرَ نَظرَةً فِي النُّجومِ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmdccclxxvii{فَقالَ إِنّي سَقيمٌ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmdccclxxviii{فَتَوَلَّوا عَنهُ مُدبِرينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmdccclxxix{فَراغَ إِلىٰ آلِهَتِهِم فَقالَ أَلا تَأكُلونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmdccclxxx{ما لَكُم لا تَنطِقونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmdccclxxxi{فَراغَ عَلَيهِم ضَربًا بِاليَمينِ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmdccclxxxii{فَأَقبَلوا إِلَيهِ يَزِفّونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmmdccclxxxiii{قالَ أَتَعبُدونَ ما تَنحِتونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmmdccclxxxiv{وَاللَّهُ خَلَقَكُم وَما تَعمَلونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmmdccclxxxv{قالُوا ابنوا لَهُ بُنيانًا فَأَلقوهُ فِي الجَحيمِ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmmdccclxxxvi{فَأَرادوا بِهِ كَيدًا فَجَعَلناهُمُ الأَسفَلينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmmdccclxxxvii{وَقالَ إِنّي ذاهِبٌ إِلىٰ رَبّي سَيَهدينِ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmmdccclxxxviii{رَبِّ هَب لي مِنَ الصّالِحينَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmmdccclxxxix{فَبَشَّرناهُ بِغُلامٍ حَليمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmmdcccxc{فَلَمّا بَلَغَ مَعَهُ السَّعيَ قالَ يا بُنَيَّ إِنّي أَرىٰ فِي المَنامِ أَنّي أَذبَحُكَ فَانظُر ماذا تَرىٰ ۚ قالَ يا أَبَتِ افعَل ما تُؤمَرُ ۖ سَتَجِدُني إِن شاءَ اللَّهُ مِنَ الصّابِرينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmmdcccxci{فَلَمّا أَسلَما وَتَلَّهُ لِلجَبينِ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmmdcccxcii{وَنادَيناهُ أَن يا إِبراهيمُ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmmdcccxciii{قَد صَدَّقتَ الرُّؤيا ۚ إِنّا كَذٰلِكَ نَجزِي المُحسِنينَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmmdcccxciv{إِنَّ هٰذا لَهُوَ البَلاءُ المُبينُ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmmdcccxcv{وَفَدَيناهُ بِذِبحٍ عَظيمٍ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmmdcccxcvi{وَتَرَكنا عَلَيهِ فِي الآخِرينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmmdcccxcvii{سَلامٌ عَلىٰ إِبراهيمَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmmdcccxcviii{كَذٰلِكَ نَجزِي المُحسِنينَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmmdcccxcix{إِنَّهُ مِن عِبادِنَا المُؤمِنينَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmmcm{وَبَشَّرناهُ بِإِسحاقَ نَبِيًّا مِنَ الصّالِحينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmmcmi{وَبارَكنا عَلَيهِ وَعَلىٰ إِسحاقَ ۚ وَمِن ذُرِّيَّتِهِما مُحسِنٌ وَظالِمٌ لِنَفسِهِ مُبينٌ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmmcmii{وَلَقَد مَنَنّا عَلىٰ موسىٰ وَهارونَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmmcmiii{وَنَجَّيناهُما وَقَومَهُما مِنَ الكَربِ العَظيمِ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmmcmiv{وَنَصَرناهُم فَكانوا هُمُ الغالِبينَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmmcmv{وَآتَيناهُمَا الكِتابَ المُستَبينَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmmcmvi{وَهَدَيناهُمَا الصِّراطَ المُستَقيمَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmmcmvii{وَتَرَكنا عَلَيهِما فِي الآخِرينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmmcmviii{سَلامٌ عَلىٰ موسىٰ وَهارونَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmmcmix{إِنّا كَذٰلِكَ نَجزِي المُحسِنينَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmmcmx{إِنَّهُما مِن عِبادِنَا المُؤمِنينَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmmcmxi{وَإِنَّ إِلياسَ لَمِنَ المُرسَلينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmmcmxii{إِذ قالَ لِقَومِهِ أَلا تَتَّقونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmmcmxiii{أَتَدعونَ بَعلًا وَتَذَرونَ أَحسَنَ الخالِقينَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmmcmxiv{اللَّهَ رَبَّكُم وَرَبَّ آبائِكُمُ الأَوَّلينَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmmcmxv{فَكَذَّبوهُ فَإِنَّهُم لَمُحضَرونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmmcmxvi{إِلّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmmcmxvii{وَتَرَكنا عَلَيهِ فِي الآخِرينَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mmmcmxviii{سَلامٌ عَلىٰ إِل ياسينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mmmcmxix{إِنّا كَذٰلِكَ نَجزِي المُحسِنينَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mmmcmxx{إِنَّهُ مِن عِبادِنَا المُؤمِنينَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mmmcmxxi{وَإِنَّ لوطًا لَمِنَ المُرسَلينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mmmcmxxii{إِذ نَجَّيناهُ وَأَهلَهُ أَجمَعينَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mmmcmxxiii{إِلّا عَجوزًا فِي الغابِرينَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mmmcmxxiv{ثُمَّ دَمَّرنَا الآخَرينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@mmmcmxxv{وَإِنَّكُم لَتَمُرّونَ عَلَيهِم مُصبِحينَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@mmmcmxxvi{وَبِاللَّيلِ ۗ أَفَلا تَعقِلونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@mmmcmxxvii{وَإِنَّ يونُسَ لَمِنَ المُرسَلينَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@mmmcmxxviii{إِذ أَبَقَ إِلَى الفُلكِ المَشحونِ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@mmmcmxxix{فَساهَمَ فَكانَ مِنَ المُدحَضينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@mmmcmxxx{فَالتَقَمَهُ الحوتُ وَهُوَ مُليمٌ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@mmmcmxxxi{فَلَولا أَنَّهُ كانَ مِنَ المُسَبِّحينَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@mmmcmxxxii{لَلَبِثَ في بَطنِهِ إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@mmmcmxxxiii{۞ فَنَبَذناهُ بِالعَراءِ وَهُوَ سَقيمٌ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@mmmcmxxxiv{وَأَنبَتنا عَلَيهِ شَجَرَةً مِن يَقطينٍ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@mmmcmxxxv{وَأَرسَلناهُ إِلىٰ مِائَةِ أَلفٍ أَو يَزيدونَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@mmmcmxxxvi{فَآمَنوا فَمَتَّعناهُم إِلىٰ حينٍ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@mmmcmxxxvii{فَاستَفتِهِم أَلِرَبِّكَ البَناتُ وَلَهُمُ البَنونَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@mmmcmxxxviii{أَم خَلَقنَا المَلائِكَةَ إِناثًا وَهُم شاهِدونَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@mmmcmxxxix{أَلا إِنَّهُم مِن إِفكِهِم لَيَقولونَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@mmmcmxl{وَلَدَ اللَّهُ وَإِنَّهُم لَكاذِبونَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@mmmcmxli{أَصطَفَى البَناتِ عَلَى البَنينَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@mmmcmxlii{ما لَكُم كَيفَ تَحكُمونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@mmmcmxliii{أَفَلا تَذَكَّرونَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@mmmcmxliv{أَم لَكُم سُلطانٌ مُبينٌ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@mmmcmxlv{فَأتوا بِكِتابِكُم إِن كُنتُم صادِقينَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@mmmcmxlvi{وَجَعَلوا بَينَهُ وَبَينَ الجِنَّةِ نَسَبًا ۚ وَلَقَد عَلِمَتِ الجِنَّةُ إِنَّهُم لَمُحضَرونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@mmmcmxlvii{سُبحانَ اللَّهِ عَمّا يَصِفونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@mmmcmxlviii{إِلّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@mmmcmxlix{فَإِنَّكُم وَما تَعبُدونَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@mmmcml{ما أَنتُم عَلَيهِ بِفاتِنينَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@mmmcmli{إِلّا مَن هُوَ صالِ الجَحيمِ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@mmmcmlii{وَما مِنّا إِلّا لَهُ مَقامٌ مَعلومٌ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@mmmcmliii{وَإِنّا لَنَحنُ الصّافّونَ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@mmmcmliv{وَإِنّا لَنَحنُ المُسَبِّحونَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@mmmcmlv{وَإِن كانوا لَيَقولونَ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@mmmcmlvi{لَو أَنَّ عِندَنا ذِكرًا مِنَ الأَوَّلينَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@mmmcmlvii{لَكُنّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@mmmcmlviii{فَكَفَروا بِهِ ۖ فَسَوفَ يَعلَمونَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@mmmcmlix{وَلَقَد سَبَقَت كَلِمَتُنا لِعِبادِنَا المُرسَلينَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@mmmcmlx{إِنَّهُم لَهُمُ المَنصورونَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@mmmcmlxi{وَإِنَّ جُندَنا لَهُمُ الغالِبونَ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@mmmcmlxii{فَتَوَلَّ عَنهُم حَتّىٰ حينٍ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@mmmcmlxiii{وَأَبصِرهُم فَسَوفَ يُبصِرونَ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@mmmcmlxiv{أَفَبِعَذابِنا يَستَعجِلونَ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@mmmcmlxv{فَإِذا نَزَلَ بِساحَتِهِم فَساءَ صَباحُ المُنذَرينَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@mmmcmlxvi{وَتَوَلَّ عَنهُم حَتّىٰ حينٍ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@mmmcmlxvii{وَأَبصِر فَسَوفَ يُبصِرونَ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@mmmcmlxviii{سُبحانَ رَبِّكَ رَبِّ العِزَّةِ عَمّا يَصِفونَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@mmmcmlxix{وَسَلامٌ عَلَى المُرسَلينَ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@mmmcmlxx{وَالحَمدُ لِلَّهِ رَبِّ العالَمينَ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@mmmcmlxxi{\basmalah ص ۚ وَالقُرآنِ ذِي الذِّكرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcmlxxii{بَلِ الَّذينَ كَفَروا في عِزَّةٍ وَشِقاقٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcmlxxiii{كَم أَهلَكنا مِن قَبلِهِم مِن قَرنٍ فَنادَوا وَلاتَ حينَ مَناصٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcmlxxiv{وَعَجِبوا أَن جاءَهُم مُنذِرٌ مِنهُم ۖ وَقالَ الكافِرونَ هٰذا ساحِرٌ كَذّابٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcmlxxv{أَجَعَلَ الآلِهَةَ إِلٰهًا واحِدًا ۖ إِنَّ هٰذا لَشَيءٌ عُجابٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcmlxxvi{وَانطَلَقَ المَلَأُ مِنهُم أَنِ امشوا وَاصبِروا عَلىٰ آلِهَتِكُم ۖ إِنَّ هٰذا لَشَيءٌ يُرادُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcmlxxvii{ما سَمِعنا بِهٰذا فِي المِلَّةِ الآخِرَةِ إِن هٰذا إِلَّا اختِلاقٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcmlxxviii{أَأُنزِلَ عَلَيهِ الذِّكرُ مِن بَينِنا ۚ بَل هُم في شَكٍّ مِن ذِكري ۖ بَل لَمّا يَذوقوا عَذابِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcmlxxix{أَم عِندَهُم خَزائِنُ رَحمَةِ رَبِّكَ العَزيزِ الوَهّابِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcmlxxx{أَم لَهُم مُلكُ السَّماواتِ وَالأَرضِ وَما بَينَهُما ۖ فَليَرتَقوا فِي الأَسبابِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcmlxxxi{جُندٌ ما هُنالِكَ مَهزومٌ مِنَ الأَحزابِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcmlxxxii{كَذَّبَت قَبلَهُم قَومُ نوحٍ وَعادٌ وَفِرعَونُ ذُو الأَوتادِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcmlxxxiii{وَثَمودُ وَقَومُ لوطٍ وَأَصحابُ الأَيكَةِ ۚ أُولٰئِكَ الأَحزابُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcmlxxxiv{إِن كُلٌّ إِلّا كَذَّبَ الرُّسُلَ فَحَقَّ عِقابِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcmlxxxv{وَما يَنظُرُ هٰؤُلاءِ إِلّا صَيحَةً واحِدَةً ما لَها مِن فَواقٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcmlxxxvi{وَقالوا رَبَّنا عَجِّل لَنا قِطَّنا قَبلَ يَومِ الحِسابِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcmlxxxvii{اصبِر عَلىٰ ما يَقولونَ وَاذكُر عَبدَنا داوودَ ذَا الأَيدِ ۖ إِنَّهُ أَوّابٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcmlxxxviii{إِنّا سَخَّرنَا الجِبالَ مَعَهُ يُسَبِّحنَ بِالعَشِيِّ وَالإِشراقِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcmlxxxix{وَالطَّيرَ مَحشورَةً ۖ كُلٌّ لَهُ أَوّابٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcmxc{وَشَدَدنا مُلكَهُ وَآتَيناهُ الحِكمَةَ وَفَصلَ الخِطابِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcmxci{۞ وَهَل أَتاكَ نَبَأُ الخَصمِ إِذ تَسَوَّرُوا المِحرابَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcmxcii{إِذ دَخَلوا عَلىٰ داوودَ فَفَزِعَ مِنهُم ۖ قالوا لا تَخَف ۖ خَصمانِ بَغىٰ بَعضُنا عَلىٰ بَعضٍ فَاحكُم بَينَنا بِالحَقِّ وَلا تُشطِط وَاهدِنا إِلىٰ سَواءِ الصِّراطِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcmxciii{إِنَّ هٰذا أَخي لَهُ تِسعٌ وَتِسعونَ نَعجَةً وَلِيَ نَعجَةٌ واحِدَةٌ فَقالَ أَكفِلنيها وَعَزَّني فِي الخِطابِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcmxciv{قالَ لَقَد ظَلَمَكَ بِسُؤالِ نَعجَتِكَ إِلىٰ نِعاجِهِ ۖ وَإِنَّ كَثيرًا مِنَ الخُلَطاءِ لَيَبغي بَعضُهُم عَلىٰ بَعضٍ إِلَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ وَقَليلٌ ما هُم ۗ وَظَنَّ داوودُ أَنَّما فَتَنّاهُ فَاستَغفَرَ رَبَّهُ وَخَرَّ راكِعًا وَأَنابَ ۩\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcmxcv{فَغَفَرنا لَهُ ذٰلِكَ ۖ وَإِنَّ لَهُ عِندَنا لَزُلفىٰ وَحُسنَ مَآبٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcmxcvi{يا داوودُ إِنّا جَعَلناكَ خَليفَةً فِي الأَرضِ فَاحكُم بَينَ النّاسِ بِالحَقِّ وَلا تَتَّبِعِ الهَوىٰ فَيُضِلَّكَ عَن سَبيلِ اللَّهِ ۚ إِنَّ الَّذينَ يَضِلّونَ عَن سَبيلِ اللَّهِ لَهُم عَذابٌ شَديدٌ بِما نَسوا يَومَ الحِسابِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcmxcvii{وَما خَلَقنَا السَّماءَ وَالأَرضَ وَما بَينَهُما باطِلًا ۚ ذٰلِكَ ظَنُّ الَّذينَ كَفَروا ۚ فَوَيلٌ لِلَّذينَ كَفَروا مِنَ النّارِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcmxcviii{أَم نَجعَلُ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ كَالمُفسِدينَ فِي الأَرضِ أَم نَجعَلُ المُتَّقينَ كَالفُجّارِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcmxcix{كِتابٌ أَنزَلناهُ إِلَيكَ مُبارَكٌ لِيَدَّبَّروا آياتِهِ وَلِيَتَذَكَّرَ أُولُو الأَلبابِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmm{وَوَهَبنا لِداوودَ سُلَيمانَ ۚ نِعمَ العَبدُ ۖ إِنَّهُ أَوّابٌ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmi{إِذ عُرِضَ عَلَيهِ بِالعَشِيِّ الصّافِناتُ الجِيادُ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmii{فَقالَ إِنّي أَحبَبتُ حُبَّ الخَيرِ عَن ذِكرِ رَبّي حَتّىٰ تَوارَت بِالحِجابِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmiii{رُدّوها عَلَيَّ ۖ فَطَفِقَ مَسحًا بِالسّوقِ وَالأَعناقِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmiv{وَلَقَد فَتَنّا سُلَيمانَ وَأَلقَينا عَلىٰ كُرسِيِّهِ جَسَدًا ثُمَّ أَنابَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmv{قالَ رَبِّ اغفِر لي وَهَب لي مُلكًا لا يَنبَغي لِأَحَدٍ مِن بَعدي ۖ إِنَّكَ أَنتَ الوَهّابُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmvi{فَسَخَّرنا لَهُ الرّيحَ تَجري بِأَمرِهِ رُخاءً حَيثُ أَصابَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmvii{وَالشَّياطينَ كُلَّ بَنّاءٍ وَغَوّاصٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmviii{وَآخَرينَ مُقَرَّنينَ فِي الأَصفادِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmix{هٰذا عَطاؤُنا فَامنُن أَو أَمسِك بِغَيرِ حِسابٍ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmx{وَإِنَّ لَهُ عِندَنا لَزُلفىٰ وَحُسنَ مَآبٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmxi{وَاذكُر عَبدَنا أَيّوبَ إِذ نادىٰ رَبَّهُ أَنّي مَسَّنِيَ الشَّيطانُ بِنُصبٍ وَعَذابٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmxii{اركُض بِرِجلِكَ ۖ هٰذا مُغتَسَلٌ بارِدٌ وَشَرابٌ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmxiii{وَوَهَبنا لَهُ أَهلَهُ وَمِثلَهُم مَعَهُم رَحمَةً مِنّا وَذِكرىٰ لِأُولِي الأَلبابِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmxiv{وَخُذ بِيَدِكَ ضِغثًا فَاضرِب بِهِ وَلا تَحنَث ۗ إِنّا وَجَدناهُ صابِرًا ۚ نِعمَ العَبدُ ۖ إِنَّهُ أَوّابٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmxv{وَاذكُر عِبادَنا إِبراهيمَ وَإِسحاقَ وَيَعقوبَ أُولِي الأَيدي وَالأَبصارِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmxvi{إِنّا أَخلَصناهُم بِخالِصَةٍ ذِكرَى الدّارِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmxvii{وَإِنَّهُم عِندَنا لَمِنَ المُصطَفَينَ الأَخيارِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmxviii{وَاذكُر إِسماعيلَ وَاليَسَعَ وَذَا الكِفلِ ۖ وَكُلٌّ مِنَ الأَخيارِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmxix{هٰذا ذِكرٌ ۚ وَإِنَّ لِلمُتَّقينَ لَحُسنَ مَآبٍ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmxx{جَنّاتِ عَدنٍ مُفَتَّحَةً لَهُمُ الأَبوابُ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmxxi{مُتَّكِئينَ فيها يَدعونَ فيها بِفاكِهَةٍ كَثيرَةٍ وَشَرابٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmxxii{۞ وَعِندَهُم قاصِراتُ الطَّرفِ أَترابٌ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmxxiii{هٰذا ما توعَدونَ لِيَومِ الحِسابِ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmxxiv{إِنَّ هٰذا لَرِزقُنا ما لَهُ مِن نَفادٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmxxv{هٰذا ۚ وَإِنَّ لِلطّاغينَ لَشَرَّ مَآبٍ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmxxvi{جَهَنَّمَ يَصلَونَها فَبِئسَ المِهادُ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmxxvii{هٰذا فَليَذوقوهُ حَميمٌ وَغَسّاقٌ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmxxviii{وَآخَرُ مِن شَكلِهِ أَزواجٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmxxix{هٰذا فَوجٌ مُقتَحِمٌ مَعَكُم ۖ لا مَرحَبًا بِهِم ۚ إِنَّهُم صالُو النّارِ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmxxx{قالوا بَل أَنتُم لا مَرحَبًا بِكُم ۖ أَنتُم قَدَّمتُموهُ لَنا ۖ فَبِئسَ القَرارُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmxxxi{قالوا رَبَّنا مَن قَدَّمَ لَنا هٰذا فَزِدهُ عَذابًا ضِعفًا فِي النّارِ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmxxxii{وَقالوا ما لَنا لا نَرىٰ رِجالًا كُنّا نَعُدُّهُم مِنَ الأَشرارِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmxxxiii{أَتَّخَذناهُم سِخرِيًّا أَم زاغَت عَنهُمُ الأَبصارُ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmxxxiv{إِنَّ ذٰلِكَ لَحَقٌّ تَخاصُمُ أَهلِ النّارِ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmxxxv{قُل إِنَّما أَنا مُنذِرٌ ۖ وَما مِن إِلٰهٍ إِلَّا اللَّهُ الواحِدُ القَهّارُ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmxxxvi{رَبُّ السَّماواتِ وَالأَرضِ وَما بَينَهُمَا العَزيزُ الغَفّارُ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmxxxvii{قُل هُوَ نَبَأٌ عَظيمٌ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmxxxviii{أَنتُم عَنهُ مُعرِضونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmxxxix{ما كانَ لِيَ مِن عِلمٍ بِالمَلَإِ الأَعلىٰ إِذ يَختَصِمونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmxl{إِن يوحىٰ إِلَيَّ إِلّا أَنَّما أَنا نَذيرٌ مُبينٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmxli{إِذ قالَ رَبُّكَ لِلمَلائِكَةِ إِنّي خالِقٌ بَشَرًا مِن طينٍ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmxlii{فَإِذا سَوَّيتُهُ وَنَفَختُ فيهِ مِن روحي فَقَعوا لَهُ ساجِدينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmxliii{فَسَجَدَ المَلائِكَةُ كُلُّهُم أَجمَعونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmxliv{إِلّا إِبليسَ استَكبَرَ وَكانَ مِنَ الكافِرينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmxlv{قالَ يا إِبليسُ ما مَنَعَكَ أَن تَسجُدَ لِما خَلَقتُ بِيَدَيَّ ۖ أَستَكبَرتَ أَم كُنتَ مِنَ العالينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmxlvi{قالَ أَنا خَيرٌ مِنهُ ۖ خَلَقتَني مِن نارٍ وَخَلَقتَهُ مِن طينٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmxlvii{قالَ فَاخرُج مِنها فَإِنَّكَ رَجيمٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmxlviii{وَإِنَّ عَلَيكَ لَعنَتي إِلىٰ يَومِ الدّينِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmxlix{قالَ رَبِّ فَأَنظِرني إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmml{قالَ فَإِنَّكَ مِنَ المُنظَرينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmli{إِلىٰ يَومِ الوَقتِ المَعلومِ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmlii{قالَ فَبِعِزَّتِكَ لَأُغوِيَنَّهُم أَجمَعينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmliii{إِلّا عِبادَكَ مِنهُمُ المُخلَصينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmliv{قالَ فَالحَقُّ وَالحَقَّ أَقولُ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmlv{لَأَملَأَنَّ جَهَنَّمَ مِنكَ وَمِمَّن تَبِعَكَ مِنهُم أَجمَعينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmlvi{قُل ما أَسأَلُكُم عَلَيهِ مِن أَجرٍ وَما أَنا مِنَ المُتَكَلِّفينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmmlvii{إِن هُوَ إِلّا ذِكرٌ لِلعالَمينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmmlviii{وَلَتَعلَمُنَّ نَبَأَهُ بَعدَ حينٍ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmmlix{\basmalah تَنزيلُ الكِتابِ مِنَ اللَّهِ العَزيزِ الحَكيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmlx{إِنّا أَنزَلنا إِلَيكَ الكِتابَ بِالحَقِّ فَاعبُدِ اللَّهَ مُخلِصًا لَهُ الدّينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmlxi{أَلا لِلَّهِ الدّينُ الخالِصُ ۚ وَالَّذينَ اتَّخَذوا مِن دونِهِ أَولِياءَ ما نَعبُدُهُم إِلّا لِيُقَرِّبونا إِلَى اللَّهِ زُلفىٰ إِنَّ اللَّهَ يَحكُمُ بَينَهُم في ما هُم فيهِ يَختَلِفونَ ۗ إِنَّ اللَّهَ لا يَهدي مَن هُوَ كاذِبٌ كَفّارٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmlxii{لَو أَرادَ اللَّهُ أَن يَتَّخِذَ وَلَدًا لَاصطَفىٰ مِمّا يَخلُقُ ما يَشاءُ ۚ سُبحانَهُ ۖ هُوَ اللَّهُ الواحِدُ القَهّارُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmlxiii{خَلَقَ السَّماواتِ وَالأَرضَ بِالحَقِّ ۖ يُكَوِّرُ اللَّيلَ عَلَى النَّهارِ وَيُكَوِّرُ النَّهارَ عَلَى اللَّيلِ ۖ وَسَخَّرَ الشَّمسَ وَالقَمَرَ ۖ كُلٌّ يَجري لِأَجَلٍ مُسَمًّى ۗ أَلا هُوَ العَزيزُ الغَفّارُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmlxiv{خَلَقَكُم مِن نَفسٍ واحِدَةٍ ثُمَّ جَعَلَ مِنها زَوجَها وَأَنزَلَ لَكُم مِنَ الأَنعامِ ثَمانِيَةَ أَزواجٍ ۚ يَخلُقُكُم في بُطونِ أُمَّهاتِكُم خَلقًا مِن بَعدِ خَلقٍ في ظُلُماتٍ ثَلاثٍ ۚ ذٰلِكُمُ اللَّهُ رَبُّكُم لَهُ المُلكُ ۖ لا إِلٰهَ إِلّا هُوَ ۖ فَأَنّىٰ تُصرَفونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmlxv{إِن تَكفُروا فَإِنَّ اللَّهَ غَنِيٌّ عَنكُم ۖ وَلا يَرضىٰ لِعِبادِهِ الكُفرَ ۖ وَإِن تَشكُروا يَرضَهُ لَكُم ۗ وَلا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ ۗ ثُمَّ إِلىٰ رَبِّكُم مَرجِعُكُم فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ ۚ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmlxvi{۞ وَإِذا مَسَّ الإِنسانَ ضُرٌّ دَعا رَبَّهُ مُنيبًا إِلَيهِ ثُمَّ إِذا خَوَّلَهُ نِعمَةً مِنهُ نَسِيَ ما كانَ يَدعو إِلَيهِ مِن قَبلُ وَجَعَلَ لِلَّهِ أَندادًا لِيُضِلَّ عَن سَبيلِهِ ۚ قُل تَمَتَّع بِكُفرِكَ قَليلًا ۖ إِنَّكَ مِن أَصحابِ النّارِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmlxvii{أَمَّن هُوَ قانِتٌ آناءَ اللَّيلِ ساجِدًا وَقائِمًا يَحذَرُ الآخِرَةَ وَيَرجو رَحمَةَ رَبِّهِ ۗ قُل هَل يَستَوِي الَّذينَ يَعلَمونَ وَالَّذينَ لا يَعلَمونَ ۗ إِنَّما يَتَذَكَّرُ أُولُو الأَلبابِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmlxviii{قُل يا عِبادِ الَّذينَ آمَنُوا اتَّقوا رَبَّكُم ۚ لِلَّذينَ أَحسَنوا في هٰذِهِ الدُّنيا حَسَنَةٌ ۗ وَأَرضُ اللَّهِ واسِعَةٌ ۗ إِنَّما يُوَفَّى الصّابِرونَ أَجرَهُم بِغَيرِ حِسابٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmlxix{قُل إِنّي أُمِرتُ أَن أَعبُدَ اللَّهَ مُخلِصًا لَهُ الدّينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmlxx{وَأُمِرتُ لِأَن أَكونَ أَوَّلَ المُسلِمينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmlxxi{قُل إِنّي أَخافُ إِن عَصَيتُ رَبّي عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmlxxii{قُلِ اللَّهَ أَعبُدُ مُخلِصًا لَهُ ديني\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmlxxiii{فَاعبُدوا ما شِئتُم مِن دونِهِ ۗ قُل إِنَّ الخاسِرينَ الَّذينَ خَسِروا أَنفُسَهُم وَأَهليهِم يَومَ القِيامَةِ ۗ أَلا ذٰلِكَ هُوَ الخُسرانُ المُبينُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmlxxiv{لَهُم مِن فَوقِهِم ظُلَلٌ مِنَ النّارِ وَمِن تَحتِهِم ظُلَلٌ ۚ ذٰلِكَ يُخَوِّفُ اللَّهُ بِهِ عِبادَهُ ۚ يا عِبادِ فَاتَّقونِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmlxxv{وَالَّذينَ اجتَنَبُوا الطّاغوتَ أَن يَعبُدوها وَأَنابوا إِلَى اللَّهِ لَهُمُ البُشرىٰ ۚ فَبَشِّر عِبادِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmlxxvi{الَّذينَ يَستَمِعونَ القَولَ فَيَتَّبِعونَ أَحسَنَهُ ۚ أُولٰئِكَ الَّذينَ هَداهُمُ اللَّهُ ۖ وَأُولٰئِكَ هُم أُولُو الأَلبابِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmlxxvii{أَفَمَن حَقَّ عَلَيهِ كَلِمَةُ العَذابِ أَفَأَنتَ تُنقِذُ مَن فِي النّارِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmlxxviii{لٰكِنِ الَّذينَ اتَّقَوا رَبَّهُم لَهُم غُرَفٌ مِن فَوقِها غُرَفٌ مَبنِيَّةٌ تَجري مِن تَحتِهَا الأَنهارُ ۖ وَعدَ اللَّهِ ۖ لا يُخلِفُ اللَّهُ الميعادَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmlxxix{أَلَم تَرَ أَنَّ اللَّهَ أَنزَلَ مِنَ السَّماءِ ماءً فَسَلَكَهُ يَنابيعَ فِي الأَرضِ ثُمَّ يُخرِجُ بِهِ زَرعًا مُختَلِفًا أَلوانُهُ ثُمَّ يَهيجُ فَتَراهُ مُصفَرًّا ثُمَّ يَجعَلُهُ حُطامًا ۚ إِنَّ في ذٰلِكَ لَذِكرىٰ لِأُولِي الأَلبابِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmlxxx{أَفَمَن شَرَحَ اللَّهُ صَدرَهُ لِلإِسلامِ فَهُوَ عَلىٰ نورٍ مِن رَبِّهِ ۚ فَوَيلٌ لِلقاسِيَةِ قُلوبُهُم مِن ذِكرِ اللَّهِ ۚ أُولٰئِكَ في ضَلالٍ مُبينٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmlxxxi{اللَّهُ نَزَّلَ أَحسَنَ الحَديثِ كِتابًا مُتَشابِهًا مَثانِيَ تَقشَعِرُّ مِنهُ جُلودُ الَّذينَ يَخشَونَ رَبَّهُم ثُمَّ تَلينُ جُلودُهُم وَقُلوبُهُم إِلىٰ ذِكرِ اللَّهِ ۚ ذٰلِكَ هُدَى اللَّهِ يَهدي بِهِ مَن يَشاءُ ۚ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن هادٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmlxxxii{أَفَمَن يَتَّقي بِوَجهِهِ سوءَ العَذابِ يَومَ القِيامَةِ ۚ وَقيلَ لِلظّالِمينَ ذوقوا ما كُنتُم تَكسِبونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmlxxxiii{كَذَّبَ الَّذينَ مِن قَبلِهِم فَأَتاهُمُ العَذابُ مِن حَيثُ لا يَشعُرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmlxxxiv{فَأَذاقَهُمُ اللَّهُ الخِزيَ فِي الحَياةِ الدُّنيا ۖ وَلَعَذابُ الآخِرَةِ أَكبَرُ ۚ لَو كانوا يَعلَمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmlxxxv{وَلَقَد ضَرَبنا لِلنّاسِ في هٰذَا القُرآنِ مِن كُلِّ مَثَلٍ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmlxxxvi{قُرآنًا عَرَبِيًّا غَيرَ ذي عِوَجٍ لَعَلَّهُم يَتَّقونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmlxxxvii{ضَرَبَ اللَّهُ مَثَلًا رَجُلًا فيهِ شُرَكاءُ مُتَشاكِسونَ وَرَجُلًا سَلَمًا لِرَجُلٍ هَل يَستَوِيانِ مَثَلًا ۚ الحَمدُ لِلَّهِ ۚ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmlxxxviii{إِنَّكَ مَيِّتٌ وَإِنَّهُم مَيِّتونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmlxxxix{ثُمَّ إِنَّكُم يَومَ القِيامَةِ عِندَ رَبِّكُم تَختَصِمونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmxc{۞ فَمَن أَظلَمُ مِمَّن كَذَبَ عَلَى اللَّهِ وَكَذَّبَ بِالصِّدقِ إِذ جاءَهُ ۚ أَلَيسَ في جَهَنَّمَ مَثوًى لِلكافِرينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmxci{وَالَّذي جاءَ بِالصِّدقِ وَصَدَّقَ بِهِ ۙ أُولٰئِكَ هُمُ المُتَّقونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmxcii{لَهُم ما يَشاءونَ عِندَ رَبِّهِم ۚ ذٰلِكَ جَزاءُ المُحسِنينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmxciii{لِيُكَفِّرَ اللَّهُ عَنهُم أَسوَأَ الَّذي عَمِلوا وَيَجزِيَهُم أَجرَهُم بِأَحسَنِ الَّذي كانوا يَعمَلونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmxciv{أَلَيسَ اللَّهُ بِكافٍ عَبدَهُ ۖ وَيُخَوِّفونَكَ بِالَّذينَ مِن دونِهِ ۚ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن هادٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmxcv{وَمَن يَهدِ اللَّهُ فَما لَهُ مِن مُضِلٍّ ۗ أَلَيسَ اللَّهُ بِعَزيزٍ ذِي انتِقامٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmxcvi{وَلَئِن سَأَلتَهُم مَن خَلَقَ السَّماواتِ وَالأَرضَ لَيَقولُنَّ اللَّهُ ۚ قُل أَفَرَأَيتُم ما تَدعونَ مِن دونِ اللَّهِ إِن أَرادَنِيَ اللَّهُ بِضُرٍّ هَل هُنَّ كاشِفاتُ ضُرِّهِ أَو أَرادَني بِرَحمَةٍ هَل هُنَّ مُمسِكاتُ رَحمَتِهِ ۚ قُل حَسبِيَ اللَّهُ ۖ عَلَيهِ يَتَوَكَّلُ المُتَوَكِّلونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmxcvii{قُل يا قَومِ اعمَلوا عَلىٰ مَكانَتِكُم إِنّي عامِلٌ ۖ فَسَوفَ تَعلَمونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmxcviii{مَن يَأتيهِ عَذابٌ يُخزيهِ وَيَحِلُّ عَلَيهِ عَذابٌ مُقيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmxcix{إِنّا أَنزَلنا عَلَيكَ الكِتابَ لِلنّاسِ بِالحَقِّ ۖ فَمَنِ اهتَدىٰ فَلِنَفسِهِ ۖ وَمَن ضَلَّ فَإِنَّما يَضِلُّ عَلَيها ۖ وَما أَنتَ عَلَيهِم بِوَكيلٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmc{اللَّهُ يَتَوَفَّى الأَنفُسَ حينَ مَوتِها وَالَّتي لَم تَمُت في مَنامِها ۖ فَيُمسِكُ الَّتي قَضىٰ عَلَيهَا المَوتَ وَيُرسِلُ الأُخرىٰ إِلىٰ أَجَلٍ مُسَمًّى ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmci{أَمِ اتَّخَذوا مِن دونِ اللَّهِ شُفَعاءَ ۚ قُل أَوَلَو كانوا لا يَملِكونَ شَيئًا وَلا يَعقِلونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcii{قُل لِلَّهِ الشَّفاعَةُ جَميعًا ۖ لَهُ مُلكُ السَّماواتِ وَالأَرضِ ۖ ثُمَّ إِلَيهِ تُرجَعونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmciii{وَإِذا ذُكِرَ اللَّهُ وَحدَهُ اشمَأَزَّت قُلوبُ الَّذينَ لا يُؤمِنونَ بِالآخِرَةِ ۖ وَإِذا ذُكِرَ الَّذينَ مِن دونِهِ إِذا هُم يَستَبشِرونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmciv{قُلِ اللَّهُمَّ فاطِرَ السَّماواتِ وَالأَرضِ عالِمَ الغَيبِ وَالشَّهادَةِ أَنتَ تَحكُمُ بَينَ عِبادِكَ في ما كانوا فيهِ يَختَلِفونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcv{وَلَو أَنَّ لِلَّذينَ ظَلَموا ما فِي الأَرضِ جَميعًا وَمِثلَهُ مَعَهُ لَافتَدَوا بِهِ مِن سوءِ العَذابِ يَومَ القِيامَةِ ۚ وَبَدا لَهُم مِنَ اللَّهِ ما لَم يَكونوا يَحتَسِبونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcvi{وَبَدا لَهُم سَيِّئَاتُ ما كَسَبوا وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcvii{فَإِذا مَسَّ الإِنسانَ ضُرٌّ دَعانا ثُمَّ إِذا خَوَّلناهُ نِعمَةً مِنّا قالَ إِنَّما أوتيتُهُ عَلىٰ عِلمٍ ۚ بَل هِيَ فِتنَةٌ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcviii{قَد قالَهَا الَّذينَ مِن قَبلِهِم فَما أَغنىٰ عَنهُم ما كانوا يَكسِبونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcix{فَأَصابَهُم سَيِّئَاتُ ما كَسَبوا ۚ وَالَّذينَ ظَلَموا مِن هٰؤُلاءِ سَيُصيبُهُم سَيِّئَاتُ ما كَسَبوا وَما هُم بِمُعجِزينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcx{أَوَلَم يَعلَموا أَنَّ اللَّهَ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcxi{۞ قُل يا عِبادِيَ الَّذينَ أَسرَفوا عَلىٰ أَنفُسِهِم لا تَقنَطوا مِن رَحمَةِ اللَّهِ ۚ إِنَّ اللَّهَ يَغفِرُ الذُّنوبَ جَميعًا ۚ إِنَّهُ هُوَ الغَفورُ الرَّحيمُ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcxii{وَأَنيبوا إِلىٰ رَبِّكُم وَأَسلِموا لَهُ مِن قَبلِ أَن يَأتِيَكُمُ العَذابُ ثُمَّ لا تُنصَرونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcxiii{وَاتَّبِعوا أَحسَنَ ما أُنزِلَ إِلَيكُم مِن رَبِّكُم مِن قَبلِ أَن يَأتِيَكُمُ العَذابُ بَغتَةً وَأَنتُم لا تَشعُرونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcxiv{أَن تَقولَ نَفسٌ يا حَسرَتا عَلىٰ ما فَرَّطتُ في جَنبِ اللَّهِ وَإِن كُنتُ لَمِنَ السّاخِرينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcxv{أَو تَقولَ لَو أَنَّ اللَّهَ هَداني لَكُنتُ مِنَ المُتَّقينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcxvi{أَو تَقولَ حينَ تَرَى العَذابَ لَو أَنَّ لي كَرَّةً فَأَكونَ مِنَ المُحسِنينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcxvii{بَلىٰ قَد جاءَتكَ آياتي فَكَذَّبتَ بِها وَاستَكبَرتَ وَكُنتَ مِنَ الكافِرينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcxviii{وَيَومَ القِيامَةِ تَرَى الَّذينَ كَذَبوا عَلَى اللَّهِ وُجوهُهُم مُسوَدَّةٌ ۚ أَلَيسَ في جَهَنَّمَ مَثوًى لِلمُتَكَبِّرينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmcxix{وَيُنَجِّي اللَّهُ الَّذينَ اتَّقَوا بِمَفازَتِهِم لا يَمَسُّهُمُ السّوءُ وَلا هُم يَحزَنونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmcxx{اللَّهُ خالِقُ كُلِّ شَيءٍ ۖ وَهُوَ عَلىٰ كُلِّ شَيءٍ وَكيلٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmcxxi{لَهُ مَقاليدُ السَّماواتِ وَالأَرضِ ۗ وَالَّذينَ كَفَروا بِآياتِ اللَّهِ أُولٰئِكَ هُمُ الخاسِرونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmcxxii{قُل أَفَغَيرَ اللَّهِ تَأمُرونّي أَعبُدُ أَيُّهَا الجاهِلونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcxxiii{وَلَقَد أوحِيَ إِلَيكَ وَإِلَى الَّذينَ مِن قَبلِكَ لَئِن أَشرَكتَ لَيَحبَطَنَّ عَمَلُكَ وَلَتَكونَنَّ مِنَ الخاسِرينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcxxiv{بَلِ اللَّهَ فَاعبُد وَكُن مِنَ الشّاكِرينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcxxv{وَما قَدَرُوا اللَّهَ حَقَّ قَدرِهِ وَالأَرضُ جَميعًا قَبضَتُهُ يَومَ القِيامَةِ وَالسَّماواتُ مَطوِيّاتٌ بِيَمينِهِ ۚ سُبحانَهُ وَتَعالىٰ عَمّا يُشرِكونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcxxvi{وَنُفِخَ فِي الصّورِ فَصَعِقَ مَن فِي السَّماواتِ وَمَن فِي الأَرضِ إِلّا مَن شاءَ اللَّهُ ۖ ثُمَّ نُفِخَ فيهِ أُخرىٰ فَإِذا هُم قِيامٌ يَنظُرونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmcxxvii{وَأَشرَقَتِ الأَرضُ بِنورِ رَبِّها وَوُضِعَ الكِتابُ وَجِيءَ بِالنَّبِيّينَ وَالشُّهَداءِ وَقُضِيَ بَينَهُم بِالحَقِّ وَهُم لا يُظلَمونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcxxviii{وَوُفِّيَت كُلُّ نَفسٍ ما عَمِلَت وَهُوَ أَعلَمُ بِما يَفعَلونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcxxix{وَسيقَ الَّذينَ كَفَروا إِلىٰ جَهَنَّمَ زُمَرًا ۖ حَتّىٰ إِذا جاءوها فُتِحَت أَبوابُها وَقالَ لَهُم خَزَنَتُها أَلَم يَأتِكُم رُسُلٌ مِنكُم يَتلونَ عَلَيكُم آياتِ رَبِّكُم وَيُنذِرونَكُم لِقاءَ يَومِكُم هٰذا ۚ قالوا بَلىٰ وَلٰكِن حَقَّت كَلِمَةُ العَذابِ عَلَى الكافِرينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmcxxx{قيلَ ادخُلوا أَبوابَ جَهَنَّمَ خالِدينَ فيها ۖ فَبِئسَ مَثوَى المُتَكَبِّرينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmcxxxi{وَسيقَ الَّذينَ اتَّقَوا رَبَّهُم إِلَى الجَنَّةِ زُمَرًا ۖ حَتّىٰ إِذا جاءوها وَفُتِحَت أَبوابُها وَقالَ لَهُم خَزَنَتُها سَلامٌ عَلَيكُم طِبتُم فَادخُلوها خالِدينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmcxxxii{وَقالُوا الحَمدُ لِلَّهِ الَّذي صَدَقَنا وَعدَهُ وَأَورَثَنَا الأَرضَ نَتَبَوَّأُ مِنَ الجَنَّةِ حَيثُ نَشاءُ ۖ فَنِعمَ أَجرُ العامِلينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmcxxxiii{وَتَرَى المَلائِكَةَ حافّينَ مِن حَولِ العَرشِ يُسَبِّحونَ بِحَمدِ رَبِّهِم ۖ وَقُضِيَ بَينَهُم بِالحَقِّ وَقيلَ الحَمدُ لِلَّهِ رَبِّ العالَمينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmcxxxiv{\basmalah حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcxxxv{تَنزيلُ الكِتابِ مِنَ اللَّهِ العَزيزِ العَليمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcxxxvi{غافِرِ الذَّنبِ وَقابِلِ التَّوبِ شَديدِ العِقابِ ذِي الطَّولِ ۖ لا إِلٰهَ إِلّا هُوَ ۖ إِلَيهِ المَصيرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcxxxvii{ما يُجادِلُ في آياتِ اللَّهِ إِلَّا الَّذينَ كَفَروا فَلا يَغرُركَ تَقَلُّبُهُم فِي البِلادِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcxxxviii{كَذَّبَت قَبلَهُم قَومُ نوحٍ وَالأَحزابُ مِن بَعدِهِم ۖ وَهَمَّت كُلُّ أُمَّةٍ بِرَسولِهِم لِيَأخُذوهُ ۖ وَجادَلوا بِالباطِلِ لِيُدحِضوا بِهِ الحَقَّ فَأَخَذتُهُم ۖ فَكَيفَ كانَ عِقابِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcxxxix{وَكَذٰلِكَ حَقَّت كَلِمَتُ رَبِّكَ عَلَى الَّذينَ كَفَروا أَنَّهُم أَصحابُ النّارِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcxl{الَّذينَ يَحمِلونَ العَرشَ وَمَن حَولَهُ يُسَبِّحونَ بِحَمدِ رَبِّهِم وَيُؤمِنونَ بِهِ وَيَستَغفِرونَ لِلَّذينَ آمَنوا رَبَّنا وَسِعتَ كُلَّ شَيءٍ رَحمَةً وَعِلمًا فَاغفِر لِلَّذينَ تابوا وَاتَّبَعوا سَبيلَكَ وَقِهِم عَذابَ الجَحيمِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcxli{رَبَّنا وَأَدخِلهُم جَنّاتِ عَدنٍ الَّتي وَعَدتَهُم وَمَن صَلَحَ مِن آبائِهِم وَأَزواجِهِم وَذُرِّيّاتِهِم ۚ إِنَّكَ أَنتَ العَزيزُ الحَكيمُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcxlii{وَقِهِمُ السَّيِّئَاتِ ۚ وَمَن تَقِ السَّيِّئَاتِ يَومَئِذٍ فَقَد رَحِمتَهُ ۚ وَذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcxliii{إِنَّ الَّذينَ كَفَروا يُنادَونَ لَمَقتُ اللَّهِ أَكبَرُ مِن مَقتِكُم أَنفُسَكُم إِذ تُدعَونَ إِلَى الإيمانِ فَتَكفُرونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcxliv{قالوا رَبَّنا أَمَتَّنَا اثنَتَينِ وَأَحيَيتَنَا اثنَتَينِ فَاعتَرَفنا بِذُنوبِنا فَهَل إِلىٰ خُروجٍ مِن سَبيلٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcxlv{ذٰلِكُم بِأَنَّهُ إِذا دُعِيَ اللَّهُ وَحدَهُ كَفَرتُم ۖ وَإِن يُشرَك بِهِ تُؤمِنوا ۚ فَالحُكمُ لِلَّهِ العَلِيِّ الكَبيرِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcxlvi{هُوَ الَّذي يُريكُم آياتِهِ وَيُنَزِّلُ لَكُم مِنَ السَّماءِ رِزقًا ۚ وَما يَتَذَكَّرُ إِلّا مَن يُنيبُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcxlvii{فَادعُوا اللَّهَ مُخلِصينَ لَهُ الدّينَ وَلَو كَرِهَ الكافِرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcxlviii{رَفيعُ الدَّرَجاتِ ذُو العَرشِ يُلقِي الرّوحَ مِن أَمرِهِ عَلىٰ مَن يَشاءُ مِن عِبادِهِ لِيُنذِرَ يَومَ التَّلاقِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcxlix{يَومَ هُم بارِزونَ ۖ لا يَخفىٰ عَلَى اللَّهِ مِنهُم شَيءٌ ۚ لِمَنِ المُلكُ اليَومَ ۖ لِلَّهِ الواحِدِ القَهّارِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcl{اليَومَ تُجزىٰ كُلُّ نَفسٍ بِما كَسَبَت ۚ لا ظُلمَ اليَومَ ۚ إِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcli{وَأَنذِرهُم يَومَ الآزِفَةِ إِذِ القُلوبُ لَدَى الحَناجِرِ كاظِمينَ ۚ ما لِلظّالِمينَ مِن حَميمٍ وَلا شَفيعٍ يُطاعُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmclii{يَعلَمُ خائِنَةَ الأَعيُنِ وَما تُخفِي الصُّدورُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcliii{وَاللَّهُ يَقضي بِالحَقِّ ۖ وَالَّذينَ يَدعونَ مِن دونِهِ لا يَقضونَ بِشَيءٍ ۗ إِنَّ اللَّهَ هُوَ السَّميعُ البَصيرُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcliv{۞ أَوَلَم يَسيروا فِي الأَرضِ فَيَنظُروا كَيفَ كانَ عاقِبَةُ الَّذينَ كانوا مِن قَبلِهِم ۚ كانوا هُم أَشَدَّ مِنهُم قُوَّةً وَآثارًا فِي الأَرضِ فَأَخَذَهُمُ اللَّهُ بِذُنوبِهِم وَما كانَ لَهُم مِنَ اللَّهِ مِن واقٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmclv{ذٰلِكَ بِأَنَّهُم كانَت تَأتيهِم رُسُلُهُم بِالبَيِّناتِ فَكَفَروا فَأَخَذَهُمُ اللَّهُ ۚ إِنَّهُ قَوِيٌّ شَديدُ العِقابِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmclvi{وَلَقَد أَرسَلنا موسىٰ بِآياتِنا وَسُلطانٍ مُبينٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmclvii{إِلىٰ فِرعَونَ وَهامانَ وَقارونَ فَقالوا ساحِرٌ كَذّابٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmclviii{فَلَمّا جاءَهُم بِالحَقِّ مِن عِندِنا قالُوا اقتُلوا أَبناءَ الَّذينَ آمَنوا مَعَهُ وَاستَحيوا نِساءَهُم ۚ وَما كَيدُ الكافِرينَ إِلّا في ضَلالٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmclix{وَقالَ فِرعَونُ ذَروني أَقتُل موسىٰ وَليَدعُ رَبَّهُ ۖ إِنّي أَخافُ أَن يُبَدِّلَ دينَكُم أَو أَن يُظهِرَ فِي الأَرضِ الفَسادَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmclx{وَقالَ موسىٰ إِنّي عُذتُ بِرَبّي وَرَبِّكُم مِن كُلِّ مُتَكَبِّرٍ لا يُؤمِنُ بِيَومِ الحِسابِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmclxi{وَقالَ رَجُلٌ مُؤمِنٌ مِن آلِ فِرعَونَ يَكتُمُ إيمانَهُ أَتَقتُلونَ رَجُلًا أَن يَقولَ رَبِّيَ اللَّهُ وَقَد جاءَكُم بِالبَيِّناتِ مِن رَبِّكُم ۖ وَإِن يَكُ كاذِبًا فَعَلَيهِ كَذِبُهُ ۖ وَإِن يَكُ صادِقًا يُصِبكُم بَعضُ الَّذي يَعِدُكُم ۖ إِنَّ اللَّهَ لا يَهدي مَن هُوَ مُسرِفٌ كَذّابٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmclxii{يا قَومِ لَكُمُ المُلكُ اليَومَ ظاهِرينَ فِي الأَرضِ فَمَن يَنصُرُنا مِن بَأسِ اللَّهِ إِن جاءَنا ۚ قالَ فِرعَونُ ما أُريكُم إِلّا ما أَرىٰ وَما أَهديكُم إِلّا سَبيلَ الرَّشادِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmclxiii{وَقالَ الَّذي آمَنَ يا قَومِ إِنّي أَخافُ عَلَيكُم مِثلَ يَومِ الأَحزابِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmclxiv{مِثلَ دَأبِ قَومِ نوحٍ وَعادٍ وَثَمودَ وَالَّذينَ مِن بَعدِهِم ۚ وَمَا اللَّهُ يُريدُ ظُلمًا لِلعِبادِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmclxv{وَيا قَومِ إِنّي أَخافُ عَلَيكُم يَومَ التَّنادِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmclxvi{يَومَ تُوَلّونَ مُدبِرينَ ما لَكُم مِنَ اللَّهِ مِن عاصِمٍ ۗ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن هادٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmclxvii{وَلَقَد جاءَكُم يوسُفُ مِن قَبلُ بِالبَيِّناتِ فَما زِلتُم في شَكٍّ مِمّا جاءَكُم بِهِ ۖ حَتّىٰ إِذا هَلَكَ قُلتُم لَن يَبعَثَ اللَّهُ مِن بَعدِهِ رَسولًا ۚ كَذٰلِكَ يُضِلُّ اللَّهُ مَن هُوَ مُسرِفٌ مُرتابٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmclxviii{الَّذينَ يُجادِلونَ في آياتِ اللَّهِ بِغَيرِ سُلطانٍ أَتاهُم ۖ كَبُرَ مَقتًا عِندَ اللَّهِ وَعِندَ الَّذينَ آمَنوا ۚ كَذٰلِكَ يَطبَعُ اللَّهُ عَلىٰ كُلِّ قَلبِ مُتَكَبِّرٍ جَبّارٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmclxix{وَقالَ فِرعَونُ يا هامانُ ابنِ لي صَرحًا لَعَلّي أَبلُغُ الأَسبابَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmclxx{أَسبابَ السَّماواتِ فَأَطَّلِعَ إِلىٰ إِلٰهِ موسىٰ وَإِنّي لَأَظُنُّهُ كاذِبًا ۚ وَكَذٰلِكَ زُيِّنَ لِفِرعَونَ سوءُ عَمَلِهِ وَصُدَّ عَنِ السَّبيلِ ۚ وَما كَيدُ فِرعَونَ إِلّا في تَبابٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmclxxi{وَقالَ الَّذي آمَنَ يا قَومِ اتَّبِعونِ أَهدِكُم سَبيلَ الرَّشادِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmclxxii{يا قَومِ إِنَّما هٰذِهِ الحَياةُ الدُّنيا مَتاعٌ وَإِنَّ الآخِرَةَ هِيَ دارُ القَرارِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmclxxiii{مَن عَمِلَ سَيِّئَةً فَلا يُجزىٰ إِلّا مِثلَها ۖ وَمَن عَمِلَ صالِحًا مِن ذَكَرٍ أَو أُنثىٰ وَهُوَ مُؤمِنٌ فَأُولٰئِكَ يَدخُلونَ الجَنَّةَ يُرزَقونَ فيها بِغَيرِ حِسابٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmclxxiv{۞ وَيا قَومِ ما لي أَدعوكُم إِلَى النَّجاةِ وَتَدعونَني إِلَى النّارِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmclxxv{تَدعونَني لِأَكفُرَ بِاللَّهِ وَأُشرِكَ بِهِ ما لَيسَ لي بِهِ عِلمٌ وَأَنا أَدعوكُم إِلَى العَزيزِ الغَفّارِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmclxxvi{لا جَرَمَ أَنَّما تَدعونَني إِلَيهِ لَيسَ لَهُ دَعوَةٌ فِي الدُّنيا وَلا فِي الآخِرَةِ وَأَنَّ مَرَدَّنا إِلَى اللَّهِ وَأَنَّ المُسرِفينَ هُم أَصحابُ النّارِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmclxxvii{فَسَتَذكُرونَ ما أَقولُ لَكُم ۚ وَأُفَوِّضُ أَمري إِلَى اللَّهِ ۚ إِنَّ اللَّهَ بَصيرٌ بِالعِبادِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmclxxviii{فَوَقاهُ اللَّهُ سَيِّئَاتِ ما مَكَروا ۖ وَحاقَ بِآلِ فِرعَونَ سوءُ العَذابِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmclxxix{النّارُ يُعرَضونَ عَلَيها غُدُوًّا وَعَشِيًّا ۖ وَيَومَ تَقومُ السّاعَةُ أَدخِلوا آلَ فِرعَونَ أَشَدَّ العَذابِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmclxxx{وَإِذ يَتَحاجّونَ فِي النّارِ فَيَقولُ الضُّعَفاءُ لِلَّذينَ استَكبَروا إِنّا كُنّا لَكُم تَبَعًا فَهَل أَنتُم مُغنونَ عَنّا نَصيبًا مِنَ النّارِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmclxxxi{قالَ الَّذينَ استَكبَروا إِنّا كُلٌّ فيها إِنَّ اللَّهَ قَد حَكَمَ بَينَ العِبادِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmclxxxii{وَقالَ الَّذينَ فِي النّارِ لِخَزَنَةِ جَهَنَّمَ ادعوا رَبَّكُم يُخَفِّف عَنّا يَومًا مِنَ العَذابِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmclxxxiii{قالوا أَوَلَم تَكُ تَأتيكُم رُسُلُكُم بِالبَيِّناتِ ۖ قالوا بَلىٰ ۚ قالوا فَادعوا ۗ وَما دُعاءُ الكافِرينَ إِلّا في ضَلالٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmclxxxiv{إِنّا لَنَنصُرُ رُسُلَنا وَالَّذينَ آمَنوا فِي الحَياةِ الدُّنيا وَيَومَ يَقومُ الأَشهادُ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmclxxxv{يَومَ لا يَنفَعُ الظّالِمينَ مَعذِرَتُهُم ۖ وَلَهُمُ اللَّعنَةُ وَلَهُم سوءُ الدّارِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmclxxxvi{وَلَقَد آتَينا موسَى الهُدىٰ وَأَورَثنا بَني إِسرائيلَ الكِتابَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmclxxxvii{هُدًى وَذِكرىٰ لِأُولِي الأَلبابِ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmclxxxviii{فَاصبِر إِنَّ وَعدَ اللَّهِ حَقٌّ وَاستَغفِر لِذَنبِكَ وَسَبِّح بِحَمدِ رَبِّكَ بِالعَشِيِّ وَالإِبكارِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmclxxxix{إِنَّ الَّذينَ يُجادِلونَ في آياتِ اللَّهِ بِغَيرِ سُلطانٍ أَتاهُم ۙ إِن في صُدورِهِم إِلّا كِبرٌ ما هُم بِبالِغيهِ ۚ فَاستَعِذ بِاللَّهِ ۖ إِنَّهُ هُوَ السَّميعُ البَصيرُ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcxc{لَخَلقُ السَّماواتِ وَالأَرضِ أَكبَرُ مِن خَلقِ النّاسِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcxci{وَما يَستَوِي الأَعمىٰ وَالبَصيرُ وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ وَلَا المُسيءُ ۚ قَليلًا ما تَتَذَكَّرونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcxcii{إِنَّ السّاعَةَ لَآتِيَةٌ لا رَيبَ فيها وَلٰكِنَّ أَكثَرَ النّاسِ لا يُؤمِنونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcxciii{وَقالَ رَبُّكُمُ ادعوني أَستَجِب لَكُم ۚ إِنَّ الَّذينَ يَستَكبِرونَ عَن عِبادَتي سَيَدخُلونَ جَهَنَّمَ داخِرينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmcxciv{اللَّهُ الَّذي جَعَلَ لَكُمُ اللَّيلَ لِتَسكُنوا فيهِ وَالنَّهارَ مُبصِرًا ۚ إِنَّ اللَّهَ لَذو فَضلٍ عَلَى النّاسِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَشكُرونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmcxcv{ذٰلِكُمُ اللَّهُ رَبُّكُم خالِقُ كُلِّ شَيءٍ لا إِلٰهَ إِلّا هُوَ ۖ فَأَنّىٰ تُؤفَكونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmcxcvi{كَذٰلِكَ يُؤفَكُ الَّذينَ كانوا بِآياتِ اللَّهِ يَجحَدونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmcxcvii{اللَّهُ الَّذي جَعَلَ لَكُمُ الأَرضَ قَرارًا وَالسَّماءَ بِناءً وَصَوَّرَكُم فَأَحسَنَ صُوَرَكُم وَرَزَقَكُم مِنَ الطَّيِّباتِ ۚ ذٰلِكُمُ اللَّهُ رَبُّكُم ۖ فَتَبارَكَ اللَّهُ رَبُّ العالَمينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcxcviii{هُوَ الحَيُّ لا إِلٰهَ إِلّا هُوَ فَادعوهُ مُخلِصينَ لَهُ الدّينَ ۗ الحَمدُ لِلَّهِ رَبِّ العالَمينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcxcix{۞ قُل إِنّي نُهيتُ أَن أَعبُدَ الَّذينَ تَدعونَ مِن دونِ اللَّهِ لَمّا جاءَنِيَ البَيِّناتُ مِن رَبّي وَأُمِرتُ أَن أُسلِمَ لِرَبِّ العالَمينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcc{هُوَ الَّذي خَلَقَكُم مِن تُرابٍ ثُمَّ مِن نُطفَةٍ ثُمَّ مِن عَلَقَةٍ ثُمَّ يُخرِجُكُم طِفلًا ثُمَّ لِتَبلُغوا أَشُدَّكُم ثُمَّ لِتَكونوا شُيوخًا ۚ وَمِنكُم مَن يُتَوَفّىٰ مِن قَبلُ ۖ وَلِتَبلُغوا أَجَلًا مُسَمًّى وَلَعَلَّكُم تَعقِلونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcci{هُوَ الَّذي يُحيي وَيُميتُ ۖ فَإِذا قَضىٰ أَمرًا فَإِنَّما يَقولُ لَهُ كُن فَيَكونُ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmccii{أَلَم تَرَ إِلَى الَّذينَ يُجادِلونَ في آياتِ اللَّهِ أَنّىٰ يُصرَفونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcciii{الَّذينَ كَذَّبوا بِالكِتابِ وَبِما أَرسَلنا بِهِ رُسُلَنا ۖ فَسَوفَ يَعلَمونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcciv{إِذِ الأَغلالُ في أَعناقِهِم وَالسَّلاسِلُ يُسحَبونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmccv{فِي الحَميمِ ثُمَّ فِي النّارِ يُسجَرونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmccvi{ثُمَّ قيلَ لَهُم أَينَ ما كُنتُم تُشرِكونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmccvii{مِن دونِ اللَّهِ ۖ قالوا ضَلّوا عَنّا بَل لَم نَكُن نَدعو مِن قَبلُ شَيئًا ۚ كَذٰلِكَ يُضِلُّ اللَّهُ الكافِرينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmccviii{ذٰلِكُم بِما كُنتُم تَفرَحونَ فِي الأَرضِ بِغَيرِ الحَقِّ وَبِما كُنتُم تَمرَحونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmccix{ادخُلوا أَبوابَ جَهَنَّمَ خالِدينَ فيها ۖ فَبِئسَ مَثوَى المُتَكَبِّرينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmccx{فَاصبِر إِنَّ وَعدَ اللَّهِ حَقٌّ ۚ فَإِمّا نُرِيَنَّكَ بَعضَ الَّذي نَعِدُهُم أَو نَتَوَفَّيَنَّكَ فَإِلَينا يُرجَعونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmccxi{وَلَقَد أَرسَلنا رُسُلًا مِن قَبلِكَ مِنهُم مَن قَصَصنا عَلَيكَ وَمِنهُم مَن لَم نَقصُص عَلَيكَ ۗ وَما كانَ لِرَسولٍ أَن يَأتِيَ بِآيَةٍ إِلّا بِإِذنِ اللَّهِ ۚ فَإِذا جاءَ أَمرُ اللَّهِ قُضِيَ بِالحَقِّ وَخَسِرَ هُنالِكَ المُبطِلونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmccxii{اللَّهُ الَّذي جَعَلَ لَكُمُ الأَنعامَ لِتَركَبوا مِنها وَمِنها تَأكُلونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmmccxiii{وَلَكُم فيها مَنافِعُ وَلِتَبلُغوا عَلَيها حاجَةً في صُدورِكُم وَعَلَيها وَعَلَى الفُلكِ تُحمَلونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmccxiv{وَيُريكُم آياتِهِ فَأَيَّ آياتِ اللَّهِ تُنكِرونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmccxv{أَفَلَم يَسيروا فِي الأَرضِ فَيَنظُروا كَيفَ كانَ عاقِبَةُ الَّذينَ مِن قَبلِهِم ۚ كانوا أَكثَرَ مِنهُم وَأَشَدَّ قُوَّةً وَآثارًا فِي الأَرضِ فَما أَغنىٰ عَنهُم ما كانوا يَكسِبونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmccxvi{فَلَمّا جاءَتهُم رُسُلُهُم بِالبَيِّناتِ فَرِحوا بِما عِندَهُم مِنَ العِلمِ وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmccxvii{فَلَمّا رَأَوا بَأسَنا قالوا آمَنّا بِاللَّهِ وَحدَهُ وَكَفَرنا بِما كُنّا بِهِ مُشرِكينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmccxviii{فَلَم يَكُ يَنفَعُهُم إيمانُهُم لَمّا رَأَوا بَأسَنا ۖ سُنَّتَ اللَّهِ الَّتي قَد خَلَت في عِبادِهِ ۖ وَخَسِرَ هُنالِكَ الكافِرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmccxix{\basmalah حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmccxx{تَنزيلٌ مِنَ الرَّحمٰنِ الرَّحيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmccxxi{كِتابٌ فُصِّلَت آياتُهُ قُرآنًا عَرَبِيًّا لِقَومٍ يَعلَمونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmccxxii{بَشيرًا وَنَذيرًا فَأَعرَضَ أَكثَرُهُم فَهُم لا يَسمَعونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmccxxiii{وَقالوا قُلوبُنا في أَكِنَّةٍ مِمّا تَدعونا إِلَيهِ وَفي آذانِنا وَقرٌ وَمِن بَينِنا وَبَينِكَ حِجابٌ فَاعمَل إِنَّنا عامِلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmccxxiv{قُل إِنَّما أَنا بَشَرٌ مِثلُكُم يوحىٰ إِلَيَّ أَنَّما إِلٰهُكُم إِلٰهٌ واحِدٌ فَاستَقيموا إِلَيهِ وَاستَغفِروهُ ۗ وَوَيلٌ لِلمُشرِكينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmccxxv{الَّذينَ لا يُؤتونَ الزَّكاةَ وَهُم بِالآخِرَةِ هُم كافِرونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmccxxvi{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لَهُم أَجرٌ غَيرُ مَمنونٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmccxxvii{۞ قُل أَئِنَّكُم لَتَكفُرونَ بِالَّذي خَلَقَ الأَرضَ في يَومَينِ وَتَجعَلونَ لَهُ أَندادًا ۚ ذٰلِكَ رَبُّ العالَمينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmccxxviii{وَجَعَلَ فيها رَواسِيَ مِن فَوقِها وَبارَكَ فيها وَقَدَّرَ فيها أَقواتَها في أَربَعَةِ أَيّامٍ سَواءً لِلسّائِلينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmccxxix{ثُمَّ استَوىٰ إِلَى السَّماءِ وَهِيَ دُخانٌ فَقالَ لَها وَلِلأَرضِ ائتِيا طَوعًا أَو كَرهًا قالَتا أَتَينا طائِعينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmccxxx{فَقَضاهُنَّ سَبعَ سَماواتٍ في يَومَينِ وَأَوحىٰ في كُلِّ سَماءٍ أَمرَها ۚ وَزَيَّنَّا السَّماءَ الدُّنيا بِمَصابيحَ وَحِفظًا ۚ ذٰلِكَ تَقديرُ العَزيزِ العَليمِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmccxxxi{فَإِن أَعرَضوا فَقُل أَنذَرتُكُم صاعِقَةً مِثلَ صاعِقَةِ عادٍ وَثَمودَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmccxxxii{إِذ جاءَتهُمُ الرُّسُلُ مِن بَينِ أَيديهِم وَمِن خَلفِهِم أَلّا تَعبُدوا إِلَّا اللَّهَ ۖ قالوا لَو شاءَ رَبُّنا لَأَنزَلَ مَلائِكَةً فَإِنّا بِما أُرسِلتُم بِهِ كافِرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmccxxxiii{فَأَمّا عادٌ فَاستَكبَروا فِي الأَرضِ بِغَيرِ الحَقِّ وَقالوا مَن أَشَدُّ مِنّا قُوَّةً ۖ أَوَلَم يَرَوا أَنَّ اللَّهَ الَّذي خَلَقَهُم هُوَ أَشَدُّ مِنهُم قُوَّةً ۖ وَكانوا بِآياتِنا يَجحَدونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmccxxxiv{فَأَرسَلنا عَلَيهِم ريحًا صَرصَرًا في أَيّامٍ نَحِساتٍ لِنُذيقَهُم عَذابَ الخِزيِ فِي الحَياةِ الدُّنيا ۖ وَلَعَذابُ الآخِرَةِ أَخزىٰ ۖ وَهُم لا يُنصَرونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmccxxxv{وَأَمّا ثَمودُ فَهَدَيناهُم فَاستَحَبُّوا العَمىٰ عَلَى الهُدىٰ فَأَخَذَتهُم صاعِقَةُ العَذابِ الهونِ بِما كانوا يَكسِبونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmccxxxvi{وَنَجَّينَا الَّذينَ آمَنوا وَكانوا يَتَّقونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmccxxxvii{وَيَومَ يُحشَرُ أَعداءُ اللَّهِ إِلَى النّارِ فَهُم يوزَعونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmccxxxviii{حَتّىٰ إِذا ما جاءوها شَهِدَ عَلَيهِم سَمعُهُم وَأَبصارُهُم وَجُلودُهُم بِما كانوا يَعمَلونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmccxxxix{وَقالوا لِجُلودِهِم لِمَ شَهِدتُم عَلَينا ۖ قالوا أَنطَقَنَا اللَّهُ الَّذي أَنطَقَ كُلَّ شَيءٍ وَهُوَ خَلَقَكُم أَوَّلَ مَرَّةٍ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmccxl{وَما كُنتُم تَستَتِرونَ أَن يَشهَدَ عَلَيكُم سَمعُكُم وَلا أَبصارُكُم وَلا جُلودُكُم وَلٰكِن ظَنَنتُم أَنَّ اللَّهَ لا يَعلَمُ كَثيرًا مِمّا تَعمَلونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmccxli{وَذٰلِكُم ظَنُّكُمُ الَّذي ظَنَنتُم بِرَبِّكُم أَرداكُم فَأَصبَحتُم مِنَ الخاسِرينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmccxlii{فَإِن يَصبِروا فَالنّارُ مَثوًى لَهُم ۖ وَإِن يَستَعتِبوا فَما هُم مِنَ المُعتَبينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmccxliii{۞ وَقَيَّضنا لَهُم قُرَناءَ فَزَيَّنوا لَهُم ما بَينَ أَيديهِم وَما خَلفَهُم وَحَقَّ عَلَيهِمُ القَولُ في أُمَمٍ قَد خَلَت مِن قَبلِهِم مِنَ الجِنِّ وَالإِنسِ ۖ إِنَّهُم كانوا خاسِرينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmccxliv{وَقالَ الَّذينَ كَفَروا لا تَسمَعوا لِهٰذَا القُرآنِ وَالغَوا فيهِ لَعَلَّكُم تَغلِبونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmccxlv{فَلَنُذيقَنَّ الَّذينَ كَفَروا عَذابًا شَديدًا وَلَنَجزِيَنَّهُم أَسوَأَ الَّذي كانوا يَعمَلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmccxlvi{ذٰلِكَ جَزاءُ أَعداءِ اللَّهِ النّارُ ۖ لَهُم فيها دارُ الخُلدِ ۖ جَزاءً بِما كانوا بِآياتِنا يَجحَدونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmccxlvii{وَقالَ الَّذينَ كَفَروا رَبَّنا أَرِنَا اللَّذَينِ أَضَلّانا مِنَ الجِنِّ وَالإِنسِ نَجعَلهُما تَحتَ أَقدامِنا لِيَكونا مِنَ الأَسفَلينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmccxlviii{إِنَّ الَّذينَ قالوا رَبُّنَا اللَّهُ ثُمَّ استَقاموا تَتَنَزَّلُ عَلَيهِمُ المَلائِكَةُ أَلّا تَخافوا وَلا تَحزَنوا وَأَبشِروا بِالجَنَّةِ الَّتي كُنتُم توعَدونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmccxlix{نَحنُ أَولِياؤُكُم فِي الحَياةِ الدُّنيا وَفِي الآخِرَةِ ۖ وَلَكُم فيها ما تَشتَهي أَنفُسُكُم وَلَكُم فيها ما تَدَّعونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmccl{نُزُلًا مِن غَفورٍ رَحيمٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmccli{وَمَن أَحسَنُ قَولًا مِمَّن دَعا إِلَى اللَّهِ وَعَمِلَ صالِحًا وَقالَ إِنَّني مِنَ المُسلِمينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcclii{وَلا تَستَوِي الحَسَنَةُ وَلَا السَّيِّئَةُ ۚ ادفَع بِالَّتي هِيَ أَحسَنُ فَإِذَا الَّذي بَينَكَ وَبَينَهُ عَداوَةٌ كَأَنَّهُ وَلِيٌّ حَميمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmccliii{وَما يُلَقّاها إِلَّا الَّذينَ صَبَروا وَما يُلَقّاها إِلّا ذو حَظٍّ عَظيمٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmccliv{وَإِمّا يَنزَغَنَّكَ مِنَ الشَّيطانِ نَزغٌ فَاستَعِذ بِاللَّهِ ۖ إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcclv{وَمِن آياتِهِ اللَّيلُ وَالنَّهارُ وَالشَّمسُ وَالقَمَرُ ۚ لا تَسجُدوا لِلشَّمسِ وَلا لِلقَمَرِ وَاسجُدوا لِلَّهِ الَّذي خَلَقَهُنَّ إِن كُنتُم إِيّاهُ تَعبُدونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcclvi{فَإِنِ استَكبَروا فَالَّذينَ عِندَ رَبِّكَ يُسَبِّحونَ لَهُ بِاللَّيلِ وَالنَّهارِ وَهُم لا يَسأَمونَ ۩\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcclvii{وَمِن آياتِهِ أَنَّكَ تَرَى الأَرضَ خاشِعَةً فَإِذا أَنزَلنا عَلَيهَا الماءَ اهتَزَّت وَرَبَت ۚ إِنَّ الَّذي أَحياها لَمُحيِي المَوتىٰ ۚ إِنَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcclviii{إِنَّ الَّذينَ يُلحِدونَ في آياتِنا لا يَخفَونَ عَلَينا ۗ أَفَمَن يُلقىٰ فِي النّارِ خَيرٌ أَم مَن يَأتي آمِنًا يَومَ القِيامَةِ ۚ اعمَلوا ما شِئتُم ۖ إِنَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcclix{إِنَّ الَّذينَ كَفَروا بِالذِّكرِ لَمّا جاءَهُم ۖ وَإِنَّهُ لَكِتابٌ عَزيزٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcclx{لا يَأتيهِ الباطِلُ مِن بَينِ يَدَيهِ وَلا مِن خَلفِهِ ۖ تَنزيلٌ مِن حَكيمٍ حَميدٍ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcclxi{ما يُقالُ لَكَ إِلّا ما قَد قيلَ لِلرُّسُلِ مِن قَبلِكَ ۚ إِنَّ رَبَّكَ لَذو مَغفِرَةٍ وَذو عِقابٍ أَليمٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcclxii{وَلَو جَعَلناهُ قُرآنًا أَعجَمِيًّا لَقالوا لَولا فُصِّلَت آياتُهُ ۖ أَأَعجَمِيٌّ وَعَرَبِيٌّ ۗ قُل هُوَ لِلَّذينَ آمَنوا هُدًى وَشِفاءٌ ۖ وَالَّذينَ لا يُؤمِنونَ في آذانِهِم وَقرٌ وَهُوَ عَلَيهِم عَمًى ۚ أُولٰئِكَ يُنادَونَ مِن مَكانٍ بَعيدٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcclxiii{وَلَقَد آتَينا موسَى الكِتابَ فَاختُلِفَ فيهِ ۗ وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ لَقُضِيَ بَينَهُم ۚ وَإِنَّهُم لَفي شَكٍّ مِنهُ مُريبٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcclxiv{مَن عَمِلَ صالِحًا فَلِنَفسِهِ ۖ وَمَن أَساءَ فَعَلَيها ۗ وَما رَبُّكَ بِظَلّامٍ لِلعَبيدِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcclxv{۞ إِلَيهِ يُرَدُّ عِلمُ السّاعَةِ ۚ وَما تَخرُجُ مِن ثَمَراتٍ مِن أَكمامِها وَما تَحمِلُ مِن أُنثىٰ وَلا تَضَعُ إِلّا بِعِلمِهِ ۚ وَيَومَ يُناديهِم أَينَ شُرَكائي قالوا آذَنّاكَ ما مِنّا مِن شَهيدٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcclxvi{وَضَلَّ عَنهُم ما كانوا يَدعونَ مِن قَبلُ ۖ وَظَنّوا ما لَهُم مِن مَحيصٍ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcclxvii{لا يَسأَمُ الإِنسانُ مِن دُعاءِ الخَيرِ وَإِن مَسَّهُ الشَّرُّ فَيَئوسٌ قَنوطٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcclxviii{وَلَئِن أَذَقناهُ رَحمَةً مِنّا مِن بَعدِ ضَرّاءَ مَسَّتهُ لَيَقولَنَّ هٰذا لي وَما أَظُنُّ السّاعَةَ قائِمَةً وَلَئِن رُجِعتُ إِلىٰ رَبّي إِنَّ لي عِندَهُ لَلحُسنىٰ ۚ فَلَنُنَبِّئَنَّ الَّذينَ كَفَروا بِما عَمِلوا وَلَنُذيقَنَّهُم مِن عَذابٍ غَليظٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcclxix{وَإِذا أَنعَمنا عَلَى الإِنسانِ أَعرَضَ وَنَأىٰ بِجانِبِهِ وَإِذا مَسَّهُ الشَّرُّ فَذو دُعاءٍ عَريضٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcclxx{قُل أَرَأَيتُم إِن كانَ مِن عِندِ اللَّهِ ثُمَّ كَفَرتُم بِهِ مَن أَضَلُّ مِمَّن هُوَ في شِقاقٍ بَعيدٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcclxxi{سَنُريهِم آياتِنا فِي الآفاقِ وَفي أَنفُسِهِم حَتّىٰ يَتَبَيَّنَ لَهُم أَنَّهُ الحَقُّ ۗ أَوَلَم يَكفِ بِرَبِّكَ أَنَّهُ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcclxxii{أَلا إِنَّهُم في مِريَةٍ مِن لِقاءِ رَبِّهِم ۗ أَلا إِنَّهُ بِكُلِّ شَيءٍ مُحيطٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcclxxiii{\basmalah حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcclxxiv{عسق\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcclxxv{كَذٰلِكَ يوحي إِلَيكَ وَإِلَى الَّذينَ مِن قَبلِكَ اللَّهُ العَزيزُ الحَكيمُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcclxxvi{لَهُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۖ وَهُوَ العَلِيُّ العَظيمُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcclxxvii{تَكادُ السَّماواتُ يَتَفَطَّرنَ مِن فَوقِهِنَّ ۚ وَالمَلائِكَةُ يُسَبِّحونَ بِحَمدِ رَبِّهِم وَيَستَغفِرونَ لِمَن فِي الأَرضِ ۗ أَلا إِنَّ اللَّهَ هُوَ الغَفورُ الرَّحيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcclxxviii{وَالَّذينَ اتَّخَذوا مِن دونِهِ أَولِياءَ اللَّهُ حَفيظٌ عَلَيهِم وَما أَنتَ عَلَيهِم بِوَكيلٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcclxxix{وَكَذٰلِكَ أَوحَينا إِلَيكَ قُرآنًا عَرَبِيًّا لِتُنذِرَ أُمَّ القُرىٰ وَمَن حَولَها وَتُنذِرَ يَومَ الجَمعِ لا رَيبَ فيهِ ۚ فَريقٌ فِي الجَنَّةِ وَفَريقٌ فِي السَّعيرِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcclxxx{وَلَو شاءَ اللَّهُ لَجَعَلَهُم أُمَّةً واحِدَةً وَلٰكِن يُدخِلُ مَن يَشاءُ في رَحمَتِهِ ۚ وَالظّالِمونَ ما لَهُم مِن وَلِيٍّ وَلا نَصيرٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcclxxxi{أَمِ اتَّخَذوا مِن دونِهِ أَولِياءَ ۖ فَاللَّهُ هُوَ الوَلِيُّ وَهُوَ يُحيِي المَوتىٰ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcclxxxii{وَمَا اختَلَفتُم فيهِ مِن شَيءٍ فَحُكمُهُ إِلَى اللَّهِ ۚ ذٰلِكُمُ اللَّهُ رَبّي عَلَيهِ تَوَكَّلتُ وَإِلَيهِ أُنيبُ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcclxxxiii{فاطِرُ السَّماواتِ وَالأَرضِ ۚ جَعَلَ لَكُم مِن أَنفُسِكُم أَزواجًا وَمِنَ الأَنعامِ أَزواجًا ۖ يَذرَؤُكُم فيهِ ۚ لَيسَ كَمِثلِهِ شَيءٌ ۖ وَهُوَ السَّميعُ البَصيرُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcclxxxiv{لَهُ مَقاليدُ السَّماواتِ وَالأَرضِ ۖ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ ۚ إِنَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcclxxxv{۞ شَرَعَ لَكُم مِنَ الدّينِ ما وَصّىٰ بِهِ نوحًا وَالَّذي أَوحَينا إِلَيكَ وَما وَصَّينا بِهِ إِبراهيمَ وَموسىٰ وَعيسىٰ ۖ أَن أَقيمُوا الدّينَ وَلا تَتَفَرَّقوا فيهِ ۚ كَبُرَ عَلَى المُشرِكينَ ما تَدعوهُم إِلَيهِ ۚ اللَّهُ يَجتَبي إِلَيهِ مَن يَشاءُ وَيَهدي إِلَيهِ مَن يُنيبُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcclxxxvi{وَما تَفَرَّقوا إِلّا مِن بَعدِ ما جاءَهُمُ العِلمُ بَغيًا بَينَهُم ۚ وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ إِلىٰ أَجَلٍ مُسَمًّى لَقُضِيَ بَينَهُم ۚ وَإِنَّ الَّذينَ أورِثُوا الكِتابَ مِن بَعدِهِم لَفي شَكٍّ مِنهُ مُريبٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcclxxxvii{فَلِذٰلِكَ فَادعُ ۖ وَاستَقِم كَما أُمِرتَ ۖ وَلا تَتَّبِع أَهواءَهُم ۖ وَقُل آمَنتُ بِما أَنزَلَ اللَّهُ مِن كِتابٍ ۖ وَأُمِرتُ لِأَعدِلَ بَينَكُمُ ۖ اللَّهُ رَبُّنا وَرَبُّكُم ۖ لَنا أَعمالُنا وَلَكُم أَعمالُكُم ۖ لا حُجَّةَ بَينَنا وَبَينَكُمُ ۖ اللَّهُ يَجمَعُ بَينَنا ۖ وَإِلَيهِ المَصيرُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcclxxxviii{وَالَّذينَ يُحاجّونَ فِي اللَّهِ مِن بَعدِ مَا استُجيبَ لَهُ حُجَّتُهُم داحِضَةٌ عِندَ رَبِّهِم وَعَلَيهِم غَضَبٌ وَلَهُم عَذابٌ شَديدٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcclxxxix{اللَّهُ الَّذي أَنزَلَ الكِتابَ بِالحَقِّ وَالميزانَ ۗ وَما يُدريكَ لَعَلَّ السّاعَةَ قَريبٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmccxc{يَستَعجِلُ بِهَا الَّذينَ لا يُؤمِنونَ بِها ۖ وَالَّذينَ آمَنوا مُشفِقونَ مِنها وَيَعلَمونَ أَنَّهَا الحَقُّ ۗ أَلا إِنَّ الَّذينَ يُمارونَ فِي السّاعَةِ لَفي ضَلالٍ بَعيدٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmccxci{اللَّهُ لَطيفٌ بِعِبادِهِ يَرزُقُ مَن يَشاءُ ۖ وَهُوَ القَوِيُّ العَزيزُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmccxcii{مَن كانَ يُريدُ حَرثَ الآخِرَةِ نَزِد لَهُ في حَرثِهِ ۖ وَمَن كانَ يُريدُ حَرثَ الدُّنيا نُؤتِهِ مِنها وَما لَهُ فِي الآخِرَةِ مِن نَصيبٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmccxciii{أَم لَهُم شُرَكاءُ شَرَعوا لَهُم مِنَ الدّينِ ما لَم يَأذَن بِهِ اللَّهُ ۚ وَلَولا كَلِمَةُ الفَصلِ لَقُضِيَ بَينَهُم ۗ وَإِنَّ الظّالِمينَ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmccxciv{تَرَى الظّالِمينَ مُشفِقينَ مِمّا كَسَبوا وَهُوَ واقِعٌ بِهِم ۗ وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ في رَوضاتِ الجَنّاتِ ۖ لَهُم ما يَشاءونَ عِندَ رَبِّهِم ۚ ذٰلِكَ هُوَ الفَضلُ الكَبيرُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmccxcv{ذٰلِكَ الَّذي يُبَشِّرُ اللَّهُ عِبادَهُ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ ۗ قُل لا أَسأَلُكُم عَلَيهِ أَجرًا إِلَّا المَوَدَّةَ فِي القُربىٰ ۗ وَمَن يَقتَرِف حَسَنَةً نَزِد لَهُ فيها حُسنًا ۚ إِنَّ اللَّهَ غَفورٌ شَكورٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmccxcvi{أَم يَقولونَ افتَرىٰ عَلَى اللَّهِ كَذِبًا ۖ فَإِن يَشَإِ اللَّهُ يَختِم عَلىٰ قَلبِكَ ۗ وَيَمحُ اللَّهُ الباطِلَ وَيُحِقُّ الحَقَّ بِكَلِماتِهِ ۚ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmccxcvii{وَهُوَ الَّذي يَقبَلُ التَّوبَةَ عَن عِبادِهِ وَيَعفو عَنِ السَّيِّئَاتِ وَيَعلَمُ ما تَفعَلونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmccxcviii{وَيَستَجيبُ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ وَيَزيدُهُم مِن فَضلِهِ ۚ وَالكافِرونَ لَهُم عَذابٌ شَديدٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmccxcix{۞ وَلَو بَسَطَ اللَّهُ الرِّزقَ لِعِبادِهِ لَبَغَوا فِي الأَرضِ وَلٰكِن يُنَزِّلُ بِقَدَرٍ ما يَشاءُ ۚ إِنَّهُ بِعِبادِهِ خَبيرٌ بَصيرٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmccc{وَهُوَ الَّذي يُنَزِّلُ الغَيثَ مِن بَعدِ ما قَنَطوا وَيَنشُرُ رَحمَتَهُ ۚ وَهُوَ الوَلِيُّ الحَميدُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmccci{وَمِن آياتِهِ خَلقُ السَّماواتِ وَالأَرضِ وَما بَثَّ فيهِما مِن دابَّةٍ ۚ وَهُوَ عَلىٰ جَمعِهِم إِذا يَشاءُ قَديرٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmcccii{وَما أَصابَكُم مِن مُصيبَةٍ فَبِما كَسَبَت أَيديكُم وَيَعفو عَن كَثيرٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmccciii{وَما أَنتُم بِمُعجِزينَ فِي الأَرضِ ۖ وَما لَكُم مِن دونِ اللَّهِ مِن وَلِيٍّ وَلا نَصيرٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmccciv{وَمِن آياتِهِ الجَوارِ فِي البَحرِ كَالأَعلامِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmcccv{إِن يَشَأ يُسكِنِ الرّيحَ فَيَظلَلنَ رَواكِدَ عَلىٰ ظَهرِهِ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِكُلِّ صَبّارٍ شَكورٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcccvi{أَو يوبِقهُنَّ بِما كَسَبوا وَيَعفُ عَن كَثيرٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmcccvii{وَيَعلَمَ الَّذينَ يُجادِلونَ في آياتِنا ما لَهُم مِن مَحيصٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmcccviii{فَما أوتيتُم مِن شَيءٍ فَمَتاعُ الحَياةِ الدُّنيا ۖ وَما عِندَ اللَّهِ خَيرٌ وَأَبقىٰ لِلَّذينَ آمَنوا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcccix{وَالَّذينَ يَجتَنِبونَ كَبائِرَ الإِثمِ وَالفَواحِشَ وَإِذا ما غَضِبوا هُم يَغفِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcccx{وَالَّذينَ استَجابوا لِرَبِّهِم وَأَقامُوا الصَّلاةَ وَأَمرُهُم شورىٰ بَينَهُم وَمِمّا رَزَقناهُم يُنفِقونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcccxi{وَالَّذينَ إِذا أَصابَهُمُ البَغيُ هُم يَنتَصِرونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcccxii{وَجَزاءُ سَيِّئَةٍ سَيِّئَةٌ مِثلُها ۖ فَمَن عَفا وَأَصلَحَ فَأَجرُهُ عَلَى اللَّهِ ۚ إِنَّهُ لا يُحِبُّ الظّالِمينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcccxiii{وَلَمَنِ انتَصَرَ بَعدَ ظُلمِهِ فَأُولٰئِكَ ما عَلَيهِم مِن سَبيلٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcccxiv{إِنَّمَا السَّبيلُ عَلَى الَّذينَ يَظلِمونَ النّاسَ وَيَبغونَ فِي الأَرضِ بِغَيرِ الحَقِّ ۚ أُولٰئِكَ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcccxv{وَلَمَن صَبَرَ وَغَفَرَ إِنَّ ذٰلِكَ لَمِن عَزمِ الأُمورِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcccxvi{وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن وَلِيٍّ مِن بَعدِهِ ۗ وَتَرَى الظّالِمينَ لَمّا رَأَوُا العَذابَ يَقولونَ هَل إِلىٰ مَرَدٍّ مِن سَبيلٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcccxvii{وَتَراهُم يُعرَضونَ عَلَيها خاشِعينَ مِنَ الذُّلِّ يَنظُرونَ مِن طَرفٍ خَفِيٍّ ۗ وَقالَ الَّذينَ آمَنوا إِنَّ الخاسِرينَ الَّذينَ خَسِروا أَنفُسَهُم وَأَهليهِم يَومَ القِيامَةِ ۗ أَلا إِنَّ الظّالِمينَ في عَذابٍ مُقيمٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcccxviii{وَما كانَ لَهُم مِن أَولِياءَ يَنصُرونَهُم مِن دونِ اللَّهِ ۗ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن سَبيلٍ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcccxix{استَجيبوا لِرَبِّكُم مِن قَبلِ أَن يَأتِيَ يَومٌ لا مَرَدَّ لَهُ مِنَ اللَّهِ ۚ ما لَكُم مِن مَلجَإٍ يَومَئِذٍ وَما لَكُم مِن نَكيرٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcccxx{فَإِن أَعرَضوا فَما أَرسَلناكَ عَلَيهِم حَفيظًا ۖ إِن عَلَيكَ إِلَّا البَلاغُ ۗ وَإِنّا إِذا أَذَقنَا الإِنسانَ مِنّا رَحمَةً فَرِحَ بِها ۖ وَإِن تُصِبهُم سَيِّئَةٌ بِما قَدَّمَت أَيديهِم فَإِنَّ الإِنسانَ كَفورٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcccxxi{لِلَّهِ مُلكُ السَّماواتِ وَالأَرضِ ۚ يَخلُقُ ما يَشاءُ ۚ يَهَبُ لِمَن يَشاءُ إِناثًا وَيَهَبُ لِمَن يَشاءُ الذُّكورَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcccxxii{أَو يُزَوِّجُهُم ذُكرانًا وَإِناثًا ۖ وَيَجعَلُ مَن يَشاءُ عَقيمًا ۚ إِنَّهُ عَليمٌ قَديرٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcccxxiii{۞ وَما كانَ لِبَشَرٍ أَن يُكَلِّمَهُ اللَّهُ إِلّا وَحيًا أَو مِن وَراءِ حِجابٍ أَو يُرسِلَ رَسولًا فَيوحِيَ بِإِذنِهِ ما يَشاءُ ۚ إِنَّهُ عَلِيٌّ حَكيمٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcccxxiv{وَكَذٰلِكَ أَوحَينا إِلَيكَ روحًا مِن أَمرِنا ۚ ما كُنتَ تَدري مَا الكِتابُ وَلَا الإيمانُ وَلٰكِن جَعَلناهُ نورًا نَهدي بِهِ مَن نَشاءُ مِن عِبادِنا ۚ وَإِنَّكَ لَتَهدي إِلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcccxxv{صِراطِ اللَّهِ الَّذي لَهُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۗ أَلا إِلَى اللَّهِ تَصيرُ الأُمورُ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcccxxvi{\basmalah حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcccxxvii{وَالكِتابِ المُبينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcccxxviii{إِنّا جَعَلناهُ قُرآنًا عَرَبِيًّا لَعَلَّكُم تَعقِلونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcccxxix{وَإِنَّهُ في أُمِّ الكِتابِ لَدَينا لَعَلِيٌّ حَكيمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcccxxx{أَفَنَضرِبُ عَنكُمُ الذِّكرَ صَفحًا أَن كُنتُم قَومًا مُسرِفينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcccxxxi{وَكَم أَرسَلنا مِن نَبِيٍّ فِي الأَوَّلينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcccxxxii{وَما يَأتيهِم مِن نَبِيٍّ إِلّا كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcccxxxiii{فَأَهلَكنا أَشَدَّ مِنهُم بَطشًا وَمَضىٰ مَثَلُ الأَوَّلينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcccxxxiv{وَلَئِن سَأَلتَهُم مَن خَلَقَ السَّماواتِ وَالأَرضَ لَيَقولُنَّ خَلَقَهُنَّ العَزيزُ العَليمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcccxxxv{الَّذي جَعَلَ لَكُمُ الأَرضَ مَهدًا وَجَعَلَ لَكُم فيها سُبُلًا لَعَلَّكُم تَهتَدونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcccxxxvi{وَالَّذي نَزَّلَ مِنَ السَّماءِ ماءً بِقَدَرٍ فَأَنشَرنا بِهِ بَلدَةً مَيتًا ۚ كَذٰلِكَ تُخرَجونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcccxxxvii{وَالَّذي خَلَقَ الأَزواجَ كُلَّها وَجَعَلَ لَكُم مِنَ الفُلكِ وَالأَنعامِ ما تَركَبونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcccxxxviii{لِتَستَووا عَلىٰ ظُهورِهِ ثُمَّ تَذكُروا نِعمَةَ رَبِّكُم إِذَا استَوَيتُم عَلَيهِ وَتَقولوا سُبحانَ الَّذي سَخَّرَ لَنا هٰذا وَما كُنّا لَهُ مُقرِنينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcccxxxix{وَإِنّا إِلىٰ رَبِّنا لَمُنقَلِبونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcccxl{وَجَعَلوا لَهُ مِن عِبادِهِ جُزءًا ۚ إِنَّ الإِنسانَ لَكَفورٌ مُبينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcccxli{أَمِ اتَّخَذَ مِمّا يَخلُقُ بَناتٍ وَأَصفاكُم بِالبَنينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcccxlii{وَإِذا بُشِّرَ أَحَدُهُم بِما ضَرَبَ لِلرَّحمٰنِ مَثَلًا ظَلَّ وَجهُهُ مُسوَدًّا وَهُوَ كَظيمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcccxliii{أَوَمَن يُنَشَّأُ فِي الحِليَةِ وَهُوَ فِي الخِصامِ غَيرُ مُبينٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcccxliv{وَجَعَلُوا المَلائِكَةَ الَّذينَ هُم عِبادُ الرَّحمٰنِ إِناثًا ۚ أَشَهِدوا خَلقَهُم ۚ سَتُكتَبُ شَهادَتُهُم وَيُسأَلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcccxlv{وَقالوا لَو شاءَ الرَّحمٰنُ ما عَبَدناهُم ۗ ما لَهُم بِذٰلِكَ مِن عِلمٍ ۖ إِن هُم إِلّا يَخرُصونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcccxlvi{أَم آتَيناهُم كِتابًا مِن قَبلِهِ فَهُم بِهِ مُستَمسِكونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcccxlvii{بَل قالوا إِنّا وَجَدنا آباءَنا عَلىٰ أُمَّةٍ وَإِنّا عَلىٰ آثارِهِم مُهتَدونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcccxlviii{وَكَذٰلِكَ ما أَرسَلنا مِن قَبلِكَ في قَريَةٍ مِن نَذيرٍ إِلّا قالَ مُترَفوها إِنّا وَجَدنا آباءَنا عَلىٰ أُمَّةٍ وَإِنّا عَلىٰ آثارِهِم مُقتَدونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcccxlix{۞ قالَ أَوَلَو جِئتُكُم بِأَهدىٰ مِمّا وَجَدتُم عَلَيهِ آباءَكُم ۖ قالوا إِنّا بِما أُرسِلتُم بِهِ كافِرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcccl{فَانتَقَمنا مِنهُم ۖ فَانظُر كَيفَ كانَ عاقِبَةُ المُكَذِّبينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcccli{وَإِذ قالَ إِبراهيمُ لِأَبيهِ وَقَومِهِ إِنَّني بَراءٌ مِمّا تَعبُدونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmccclii{إِلَّا الَّذي فَطَرَني فَإِنَّهُ سَيَهدينِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmcccliii{وَجَعَلَها كَلِمَةً باقِيَةً في عَقِبِهِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmcccliv{بَل مَتَّعتُ هٰؤُلاءِ وَآباءَهُم حَتّىٰ جاءَهُمُ الحَقُّ وَرَسولٌ مُبينٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmccclv{وَلَمّا جاءَهُمُ الحَقُّ قالوا هٰذا سِحرٌ وَإِنّا بِهِ كافِرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmccclvi{وَقالوا لَولا نُزِّلَ هٰذَا القُرآنُ عَلىٰ رَجُلٍ مِنَ القَريَتَينِ عَظيمٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmccclvii{أَهُم يَقسِمونَ رَحمَتَ رَبِّكَ ۚ نَحنُ قَسَمنا بَينَهُم مَعيشَتَهُم فِي الحَياةِ الدُّنيا ۚ وَرَفَعنا بَعضَهُم فَوقَ بَعضٍ دَرَجاتٍ لِيَتَّخِذَ بَعضُهُم بَعضًا سُخرِيًّا ۗ وَرَحمَتُ رَبِّكَ خَيرٌ مِمّا يَجمَعونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmccclviii{وَلَولا أَن يَكونَ النّاسُ أُمَّةً واحِدَةً لَجَعَلنا لِمَن يَكفُرُ بِالرَّحمٰنِ لِبُيوتِهِم سُقُفًا مِن فِضَّةٍ وَمَعارِجَ عَلَيها يَظهَرونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmccclix{وَلِبُيوتِهِم أَبوابًا وَسُرُرًا عَلَيها يَتَّكِئونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmccclx{وَزُخرُفًا ۚ وَإِن كُلُّ ذٰلِكَ لَمّا مَتاعُ الحَياةِ الدُّنيا ۚ وَالآخِرَةُ عِندَ رَبِّكَ لِلمُتَّقينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmccclxi{وَمَن يَعشُ عَن ذِكرِ الرَّحمٰنِ نُقَيِّض لَهُ شَيطانًا فَهُوَ لَهُ قَرينٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmccclxii{وَإِنَّهُم لَيَصُدّونَهُم عَنِ السَّبيلِ وَيَحسَبونَ أَنَّهُم مُهتَدونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmccclxiii{حَتّىٰ إِذا جاءَنا قالَ يا لَيتَ بَيني وَبَينَكَ بُعدَ المَشرِقَينِ فَبِئسَ القَرينُ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmccclxiv{وَلَن يَنفَعَكُمُ اليَومَ إِذ ظَلَمتُم أَنَّكُم فِي العَذابِ مُشتَرِكونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmccclxv{أَفَأَنتَ تُسمِعُ الصُّمَّ أَو تَهدِي العُميَ وَمَن كانَ في ضَلالٍ مُبينٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmccclxvi{فَإِمّا نَذهَبَنَّ بِكَ فَإِنّا مِنهُم مُنتَقِمونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmccclxvii{أَو نُرِيَنَّكَ الَّذي وَعَدناهُم فَإِنّا عَلَيهِم مُقتَدِرونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmccclxviii{فَاستَمسِك بِالَّذي أوحِيَ إِلَيكَ ۖ إِنَّكَ عَلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmccclxix{وَإِنَّهُ لَذِكرٌ لَكَ وَلِقَومِكَ ۖ وَسَوفَ تُسأَلونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmccclxx{وَاسأَل مَن أَرسَلنا مِن قَبلِكَ مِن رُسُلِنا أَجَعَلنا مِن دونِ الرَّحمٰنِ آلِهَةً يُعبَدونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmccclxxi{وَلَقَد أَرسَلنا موسىٰ بِآياتِنا إِلىٰ فِرعَونَ وَمَلَئِهِ فَقالَ إِنّي رَسولُ رَبِّ العالَمينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmccclxxii{فَلَمّا جاءَهُم بِآياتِنا إِذا هُم مِنها يَضحَكونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmccclxxiii{وَما نُريهِم مِن آيَةٍ إِلّا هِيَ أَكبَرُ مِن أُختِها ۖ وَأَخَذناهُم بِالعَذابِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmccclxxiv{وَقالوا يا أَيُّهَ السّاحِرُ ادعُ لَنا رَبَّكَ بِما عَهِدَ عِندَكَ إِنَّنا لَمُهتَدونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmccclxxv{فَلَمّا كَشَفنا عَنهُمُ العَذابَ إِذا هُم يَنكُثونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmccclxxvi{وَنادىٰ فِرعَونُ في قَومِهِ قالَ يا قَومِ أَلَيسَ لي مُلكُ مِصرَ وَهٰذِهِ الأَنهارُ تَجري مِن تَحتي ۖ أَفَلا تُبصِرونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmccclxxvii{أَم أَنا خَيرٌ مِن هٰذَا الَّذي هُوَ مَهينٌ وَلا يَكادُ يُبينُ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmccclxxviii{فَلَولا أُلقِيَ عَلَيهِ أَسوِرَةٌ مِن ذَهَبٍ أَو جاءَ مَعَهُ المَلائِكَةُ مُقتَرِنينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmccclxxix{فَاستَخَفَّ قَومَهُ فَأَطاعوهُ ۚ إِنَّهُم كانوا قَومًا فاسِقينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmccclxxx{فَلَمّا آسَفونَا انتَقَمنا مِنهُم فَأَغرَقناهُم أَجمَعينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmccclxxxi{فَجَعَلناهُم سَلَفًا وَمَثَلًا لِلآخِرينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmccclxxxii{۞ وَلَمّا ضُرِبَ ابنُ مَريَمَ مَثَلًا إِذا قَومُكَ مِنهُ يَصِدّونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmccclxxxiii{وَقالوا أَآلِهَتُنا خَيرٌ أَم هُوَ ۚ ما ضَرَبوهُ لَكَ إِلّا جَدَلًا ۚ بَل هُم قَومٌ خَصِمونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmccclxxxiv{إِن هُوَ إِلّا عَبدٌ أَنعَمنا عَلَيهِ وَجَعَلناهُ مَثَلًا لِبَني إِسرائيلَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmccclxxxv{وَلَو نَشاءُ لَجَعَلنا مِنكُم مَلائِكَةً فِي الأَرضِ يَخلُفونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmccclxxxvi{وَإِنَّهُ لَعِلمٌ لِلسّاعَةِ فَلا تَمتَرُنَّ بِها وَاتَّبِعونِ ۚ هٰذا صِراطٌ مُستَقيمٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmccclxxxvii{وَلا يَصُدَّنَّكُمُ الشَّيطانُ ۖ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmccclxxxviii{وَلَمّا جاءَ عيسىٰ بِالبَيِّناتِ قالَ قَد جِئتُكُم بِالحِكمَةِ وَلِأُبَيِّنَ لَكُم بَعضَ الَّذي تَختَلِفونَ فيهِ ۖ فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmccclxxxix{إِنَّ اللَّهَ هُوَ رَبّي وَرَبُّكُم فَاعبُدوهُ ۚ هٰذا صِراطٌ مُستَقيمٌ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcccxc{فَاختَلَفَ الأَحزابُ مِن بَينِهِم ۖ فَوَيلٌ لِلَّذينَ ظَلَموا مِن عَذابِ يَومٍ أَليمٍ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcccxci{هَل يَنظُرونَ إِلَّا السّاعَةَ أَن تَأتِيَهُم بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcccxcii{الأَخِلّاءُ يَومَئِذٍ بَعضُهُم لِبَعضٍ عَدُوٌّ إِلَّا المُتَّقينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcccxciii{يا عِبادِ لا خَوفٌ عَلَيكُمُ اليَومَ وَلا أَنتُم تَحزَنونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmcccxciv{الَّذينَ آمَنوا بِآياتِنا وَكانوا مُسلِمينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcccxcv{ادخُلُوا الجَنَّةَ أَنتُم وَأَزواجُكُم تُحبَرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcccxcvi{يُطافُ عَلَيهِم بِصِحافٍ مِن ذَهَبٍ وَأَكوابٍ ۖ وَفيها ما تَشتَهيهِ الأَنفُسُ وَتَلَذُّ الأَعيُنُ ۖ وَأَنتُم فيها خالِدونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmcccxcvii{وَتِلكَ الجَنَّةُ الَّتي أورِثتُموها بِما كُنتُم تَعمَلونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmcccxcviii{لَكُم فيها فاكِهَةٌ كَثيرَةٌ مِنها تَأكُلونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmcccxcix{إِنَّ المُجرِمينَ في عَذابِ جَهَنَّمَ خالِدونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmcd{لا يُفَتَّرُ عَنهُم وَهُم فيهِ مُبلِسونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmcdi{وَما ظَلَمناهُم وَلٰكِن كانوا هُمُ الظّالِمينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmcdii{وَنادَوا يا مالِكُ لِيَقضِ عَلَينا رَبُّكَ ۖ قالَ إِنَّكُم ماكِثونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmcdiii{لَقَد جِئناكُم بِالحَقِّ وَلٰكِنَّ أَكثَرَكُم لِلحَقِّ كارِهونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmcdiv{أَم أَبرَموا أَمرًا فَإِنّا مُبرِمونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmmcdv{أَم يَحسَبونَ أَنّا لا نَسمَعُ سِرَّهُم وَنَجواهُم ۚ بَلىٰ وَرُسُلُنا لَدَيهِم يَكتُبونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmcdvi{قُل إِن كانَ لِلرَّحمٰنِ وَلَدٌ فَأَنا أَوَّلُ العابِدينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmcdvii{سُبحانَ رَبِّ السَّماواتِ وَالأَرضِ رَبِّ العَرشِ عَمّا يَصِفونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmcdviii{فَذَرهُم يَخوضوا وَيَلعَبوا حَتّىٰ يُلاقوا يَومَهُمُ الَّذي يوعَدونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmcdix{وَهُوَ الَّذي فِي السَّماءِ إِلٰهٌ وَفِي الأَرضِ إِلٰهٌ ۚ وَهُوَ الحَكيمُ العَليمُ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmcdx{وَتَبارَكَ الَّذي لَهُ مُلكُ السَّماواتِ وَالأَرضِ وَما بَينَهُما وَعِندَهُ عِلمُ السّاعَةِ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmcdxi{وَلا يَملِكُ الَّذينَ يَدعونَ مِن دونِهِ الشَّفاعَةَ إِلّا مَن شَهِدَ بِالحَقِّ وَهُم يَعلَمونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmmcdxii{وَلَئِن سَأَلتَهُم مَن خَلَقَهُم لَيَقولُنَّ اللَّهُ ۖ فَأَنّىٰ يُؤفَكونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmmcdxiii{وَقيلِهِ يا رَبِّ إِنَّ هٰؤُلاءِ قَومٌ لا يُؤمِنونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmmcdxiv{فَاصفَح عَنهُم وَقُل سَلامٌ ۚ فَسَوفَ يَعلَمونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmmcdxv{\basmalah حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcdxvi{وَالكِتابِ المُبينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcdxvii{إِنّا أَنزَلناهُ في لَيلَةٍ مُبارَكَةٍ ۚ إِنّا كُنّا مُنذِرينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcdxviii{فيها يُفرَقُ كُلُّ أَمرٍ حَكيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcdxix{أَمرًا مِن عِندِنا ۚ إِنّا كُنّا مُرسِلينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcdxx{رَحمَةً مِن رَبِّكَ ۚ إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcdxxi{رَبِّ السَّماواتِ وَالأَرضِ وَما بَينَهُما ۖ إِن كُنتُم موقِنينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcdxxii{لا إِلٰهَ إِلّا هُوَ يُحيي وَيُميتُ ۖ رَبُّكُم وَرَبُّ آبائِكُمُ الأَوَّلينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcdxxiii{بَل هُم في شَكٍّ يَلعَبونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcdxxiv{فَارتَقِب يَومَ تَأتِي السَّماءُ بِدُخانٍ مُبينٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcdxxv{يَغشَى النّاسَ ۖ هٰذا عَذابٌ أَليمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcdxxvi{رَبَّنَا اكشِف عَنَّا العَذابَ إِنّا مُؤمِنونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcdxxvii{أَنّىٰ لَهُمُ الذِّكرىٰ وَقَد جاءَهُم رَسولٌ مُبينٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcdxxviii{ثُمَّ تَوَلَّوا عَنهُ وَقالوا مُعَلَّمٌ مَجنونٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcdxxix{إِنّا كاشِفُو العَذابِ قَليلًا ۚ إِنَّكُم عائِدونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcdxxx{يَومَ نَبطِشُ البَطشَةَ الكُبرىٰ إِنّا مُنتَقِمونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcdxxxi{۞ وَلَقَد فَتَنّا قَبلَهُم قَومَ فِرعَونَ وَجاءَهُم رَسولٌ كَريمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcdxxxii{أَن أَدّوا إِلَيَّ عِبادَ اللَّهِ ۖ إِنّي لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcdxxxiii{وَأَن لا تَعلوا عَلَى اللَّهِ ۖ إِنّي آتيكُم بِسُلطانٍ مُبينٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcdxxxiv{وَإِنّي عُذتُ بِرَبّي وَرَبِّكُم أَن تَرجُمونِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcdxxxv{وَإِن لَم تُؤمِنوا لي فَاعتَزِلونِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcdxxxvi{فَدَعا رَبَّهُ أَنَّ هٰؤُلاءِ قَومٌ مُجرِمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcdxxxvii{فَأَسرِ بِعِبادي لَيلًا إِنَّكُم مُتَّبَعونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcdxxxviii{وَاترُكِ البَحرَ رَهوًا ۖ إِنَّهُم جُندٌ مُغرَقونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcdxxxix{كَم تَرَكوا مِن جَنّاتٍ وَعُيونٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcdxl{وَزُروعٍ وَمَقامٍ كَريمٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmcdxli{وَنَعمَةٍ كانوا فيها فاكِهينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmcdxlii{كَذٰلِكَ ۖ وَأَورَثناها قَومًا آخَرينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmcdxliii{فَما بَكَت عَلَيهِمُ السَّماءُ وَالأَرضُ وَما كانوا مُنظَرينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmcdxliv{وَلَقَد نَجَّينا بَني إِسرائيلَ مِنَ العَذابِ المُهينِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmcdxlv{مِن فِرعَونَ ۚ إِنَّهُ كانَ عالِيًا مِنَ المُسرِفينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmcdxlvi{وَلَقَدِ اختَرناهُم عَلىٰ عِلمٍ عَلَى العالَمينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmcdxlvii{وَآتَيناهُم مِنَ الآياتِ ما فيهِ بَلاءٌ مُبينٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcdxlviii{إِنَّ هٰؤُلاءِ لَيَقولونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmcdxlix{إِن هِيَ إِلّا مَوتَتُنَا الأولىٰ وَما نَحنُ بِمُنشَرينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmcdl{فَأتوا بِآبائِنا إِن كُنتُم صادِقينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcdli{أَهُم خَيرٌ أَم قَومُ تُبَّعٍ وَالَّذينَ مِن قَبلِهِم ۚ أَهلَكناهُم ۖ إِنَّهُم كانوا مُجرِمينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcdlii{وَما خَلَقنَا السَّماواتِ وَالأَرضَ وَما بَينَهُما لاعِبينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcdliii{ما خَلَقناهُما إِلّا بِالحَقِّ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcdliv{إِنَّ يَومَ الفَصلِ ميقاتُهُم أَجمَعينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcdlv{يَومَ لا يُغني مَولًى عَن مَولًى شَيئًا وَلا هُم يُنصَرونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcdlvi{إِلّا مَن رَحِمَ اللَّهُ ۚ إِنَّهُ هُوَ العَزيزُ الرَّحيمُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcdlvii{إِنَّ شَجَرَتَ الزَّقّومِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcdlviii{طَعامُ الأَثيمِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcdlix{كَالمُهلِ يَغلي فِي البُطونِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcdlx{كَغَليِ الحَميمِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcdlxi{خُذوهُ فَاعتِلوهُ إِلىٰ سَواءِ الجَحيمِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcdlxii{ثُمَّ صُبّوا فَوقَ رَأسِهِ مِن عَذابِ الحَميمِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcdlxiii{ذُق إِنَّكَ أَنتَ العَزيزُ الكَريمُ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcdlxiv{إِنَّ هٰذا ما كُنتُم بِهِ تَمتَرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcdlxv{إِنَّ المُتَّقينَ في مَقامٍ أَمينٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcdlxvi{في جَنّاتٍ وَعُيونٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcdlxvii{يَلبَسونَ مِن سُندُسٍ وَإِستَبرَقٍ مُتَقابِلينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcdlxviii{كَذٰلِكَ وَزَوَّجناهُم بِحورٍ عينٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcdlxix{يَدعونَ فيها بِكُلِّ فاكِهَةٍ آمِنينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcdlxx{لا يَذوقونَ فيهَا المَوتَ إِلَّا المَوتَةَ الأولىٰ ۖ وَوَقاهُم عَذابَ الجَحيمِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcdlxxi{فَضلًا مِن رَبِّكَ ۚ ذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcdlxxii{فَإِنَّما يَسَّرناهُ بِلِسانِكَ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcdlxxiii{فَارتَقِب إِنَّهُم مُرتَقِبونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcdlxxiv{\basmalah حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcdlxxv{تَنزيلُ الكِتابِ مِنَ اللَّهِ العَزيزِ الحَكيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcdlxxvi{إِنَّ فِي السَّماواتِ وَالأَرضِ لَآياتٍ لِلمُؤمِنينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcdlxxvii{وَفي خَلقِكُم وَما يَبُثُّ مِن دابَّةٍ آياتٌ لِقَومٍ يوقِنونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcdlxxviii{وَاختِلافِ اللَّيلِ وَالنَّهارِ وَما أَنزَلَ اللَّهُ مِنَ السَّماءِ مِن رِزقٍ فَأَحيا بِهِ الأَرضَ بَعدَ مَوتِها وَتَصريفِ الرِّياحِ آياتٌ لِقَومٍ يَعقِلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcdlxxix{تِلكَ آياتُ اللَّهِ نَتلوها عَلَيكَ بِالحَقِّ ۖ فَبِأَيِّ حَديثٍ بَعدَ اللَّهِ وَآياتِهِ يُؤمِنونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcdlxxx{وَيلٌ لِكُلِّ أَفّاكٍ أَثيمٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxi{يَسمَعُ آياتِ اللَّهِ تُتلىٰ عَلَيهِ ثُمَّ يُصِرُّ مُستَكبِرًا كَأَن لَم يَسمَعها ۖ فَبَشِّرهُ بِعَذابٍ أَليمٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxii{وَإِذا عَلِمَ مِن آياتِنا شَيئًا اتَّخَذَها هُزُوًا ۚ أُولٰئِكَ لَهُم عَذابٌ مُهينٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxiii{مِن وَرائِهِم جَهَنَّمُ ۖ وَلا يُغني عَنهُم ما كَسَبوا شَيئًا وَلا مَا اتَّخَذوا مِن دونِ اللَّهِ أَولِياءَ ۖ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxiv{هٰذا هُدًى ۖ وَالَّذينَ كَفَروا بِآياتِ رَبِّهِم لَهُم عَذابٌ مِن رِجزٍ أَليمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxv{۞ اللَّهُ الَّذي سَخَّرَ لَكُمُ البَحرَ لِتَجرِيَ الفُلكُ فيهِ بِأَمرِهِ وَلِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxvi{وَسَخَّرَ لَكُم ما فِي السَّماواتِ وَما فِي الأَرضِ جَميعًا مِنهُ ۚ إِنَّ في ذٰلِكَ لَآياتٍ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxvii{قُل لِلَّذينَ آمَنوا يَغفِروا لِلَّذينَ لا يَرجونَ أَيّامَ اللَّهِ لِيَجزِيَ قَومًا بِما كانوا يَكسِبونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxviii{مَن عَمِلَ صالِحًا فَلِنَفسِهِ ۖ وَمَن أَساءَ فَعَلَيها ۖ ثُمَّ إِلىٰ رَبِّكُم تُرجَعونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxix{وَلَقَد آتَينا بَني إِسرائيلَ الكِتابَ وَالحُكمَ وَالنُّبُوَّةَ وَرَزَقناهُم مِنَ الطَّيِّباتِ وَفَضَّلناهُم عَلَى العالَمينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcdxc{وَآتَيناهُم بَيِّناتٍ مِنَ الأَمرِ ۖ فَمَا اختَلَفوا إِلّا مِن بَعدِ ما جاءَهُمُ العِلمُ بَغيًا بَينَهُم ۚ إِنَّ رَبَّكَ يَقضي بَينَهُم يَومَ القِيامَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcdxci{ثُمَّ جَعَلناكَ عَلىٰ شَريعَةٍ مِنَ الأَمرِ فَاتَّبِعها وَلا تَتَّبِع أَهواءَ الَّذينَ لا يَعلَمونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcdxcii{إِنَّهُم لَن يُغنوا عَنكَ مِنَ اللَّهِ شَيئًا ۚ وَإِنَّ الظّالِمينَ بَعضُهُم أَولِياءُ بَعضٍ ۖ وَاللَّهُ وَلِيُّ المُتَّقينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcdxciii{هٰذا بَصائِرُ لِلنّاسِ وَهُدًى وَرَحمَةٌ لِقَومٍ يوقِنونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcdxciv{أَم حَسِبَ الَّذينَ اجتَرَحُوا السَّيِّئَاتِ أَن نَجعَلَهُم كَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ سَواءً مَحياهُم وَمَماتُهُم ۚ ساءَ ما يَحكُمونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcdxcv{وَخَلَقَ اللَّهُ السَّماواتِ وَالأَرضَ بِالحَقِّ وَلِتُجزىٰ كُلُّ نَفسٍ بِما كَسَبَت وَهُم لا يُظلَمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcdxcvi{أَفَرَأَيتَ مَنِ اتَّخَذَ إِلٰهَهُ هَواهُ وَأَضَلَّهُ اللَّهُ عَلىٰ عِلمٍ وَخَتَمَ عَلىٰ سَمعِهِ وَقَلبِهِ وَجَعَلَ عَلىٰ بَصَرِهِ غِشاوَةً فَمَن يَهديهِ مِن بَعدِ اللَّهِ ۚ أَفَلا تَذَكَّرونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcdxcvii{وَقالوا ما هِيَ إِلّا حَياتُنَا الدُّنيا نَموتُ وَنَحيا وَما يُهلِكُنا إِلَّا الدَّهرُ ۚ وَما لَهُم بِذٰلِكَ مِن عِلمٍ ۖ إِن هُم إِلّا يَظُنّونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcdxcviii{وَإِذا تُتلىٰ عَلَيهِم آياتُنا بَيِّناتٍ ما كانَ حُجَّتَهُم إِلّا أَن قالُوا ائتوا بِآبائِنا إِن كُنتُم صادِقينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcdxcix{قُلِ اللَّهُ يُحييكُم ثُمَّ يُميتُكُم ثُمَّ يَجمَعُكُم إِلىٰ يَومِ القِيامَةِ لا رَيبَ فيهِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmd{وَلِلَّهِ مُلكُ السَّماواتِ وَالأَرضِ ۚ وَيَومَ تَقومُ السّاعَةُ يَومَئِذٍ يَخسَرُ المُبطِلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdi{وَتَرىٰ كُلَّ أُمَّةٍ جاثِيَةً ۚ كُلُّ أُمَّةٍ تُدعىٰ إِلىٰ كِتابِهَا اليَومَ تُجزَونَ ما كُنتُم تَعمَلونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdii{هٰذا كِتابُنا يَنطِقُ عَلَيكُم بِالحَقِّ ۚ إِنّا كُنّا نَستَنسِخُ ما كُنتُم تَعمَلونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdiii{فَأَمَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ فَيُدخِلُهُم رَبُّهُم في رَحمَتِهِ ۚ ذٰلِكَ هُوَ الفَوزُ المُبينُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdiv{وَأَمَّا الَّذينَ كَفَروا أَفَلَم تَكُن آياتي تُتلىٰ عَلَيكُم فَاستَكبَرتُم وَكُنتُم قَومًا مُجرِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdv{وَإِذا قيلَ إِنَّ وَعدَ اللَّهِ حَقٌّ وَالسّاعَةُ لا رَيبَ فيها قُلتُم ما نَدري مَا السّاعَةُ إِن نَظُنُّ إِلّا ظَنًّا وَما نَحنُ بِمُستَيقِنينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdvi{وَبَدا لَهُم سَيِّئَاتُ ما عَمِلوا وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdvii{وَقيلَ اليَومَ نَنساكُم كَما نَسيتُم لِقاءَ يَومِكُم هٰذا وَمَأواكُمُ النّارُ وَما لَكُم مِن ناصِرينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdviii{ذٰلِكُم بِأَنَّكُمُ اتَّخَذتُم آياتِ اللَّهِ هُزُوًا وَغَرَّتكُمُ الحَياةُ الدُّنيا ۚ فَاليَومَ لا يُخرَجونَ مِنها وَلا هُم يُستَعتَبونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdix{فَلِلَّهِ الحَمدُ رَبِّ السَّماواتِ وَرَبِّ الأَرضِ رَبِّ العالَمينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdx{وَلَهُ الكِبرِياءُ فِي السَّماواتِ وَالأَرضِ ۖ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdxi{\basmalah حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdxii{تَنزيلُ الكِتابِ مِنَ اللَّهِ العَزيزِ الحَكيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdxiii{ما خَلَقنَا السَّماواتِ وَالأَرضَ وَما بَينَهُما إِلّا بِالحَقِّ وَأَجَلٍ مُسَمًّى ۚ وَالَّذينَ كَفَروا عَمّا أُنذِروا مُعرِضونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdxiv{قُل أَرَأَيتُم ما تَدعونَ مِن دونِ اللَّهِ أَروني ماذا خَلَقوا مِنَ الأَرضِ أَم لَهُم شِركٌ فِي السَّماواتِ ۖ ائتوني بِكِتابٍ مِن قَبلِ هٰذا أَو أَثارَةٍ مِن عِلمٍ إِن كُنتُم صادِقينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdxv{وَمَن أَضَلُّ مِمَّن يَدعو مِن دونِ اللَّهِ مَن لا يَستَجيبُ لَهُ إِلىٰ يَومِ القِيامَةِ وَهُم عَن دُعائِهِم غافِلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdxvi{وَإِذا حُشِرَ النّاسُ كانوا لَهُم أَعداءً وَكانوا بِعِبادَتِهِم كافِرينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdxvii{وَإِذا تُتلىٰ عَلَيهِم آياتُنا بَيِّناتٍ قالَ الَّذينَ كَفَروا لِلحَقِّ لَمّا جاءَهُم هٰذا سِحرٌ مُبينٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdxviii{أَم يَقولونَ افتَراهُ ۖ قُل إِنِ افتَرَيتُهُ فَلا تَملِكونَ لي مِنَ اللَّهِ شَيئًا ۖ هُوَ أَعلَمُ بِما تُفيضونَ فيهِ ۖ كَفىٰ بِهِ شَهيدًا بَيني وَبَينَكُم ۖ وَهُوَ الغَفورُ الرَّحيمُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdxix{قُل ما كُنتُ بِدعًا مِنَ الرُّسُلِ وَما أَدري ما يُفعَلُ بي وَلا بِكُم ۖ إِن أَتَّبِعُ إِلّا ما يوحىٰ إِلَيَّ وَما أَنا إِلّا نَذيرٌ مُبينٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdxx{قُل أَرَأَيتُم إِن كانَ مِن عِندِ اللَّهِ وَكَفَرتُم بِهِ وَشَهِدَ شاهِدٌ مِن بَني إِسرائيلَ عَلىٰ مِثلِهِ فَآمَنَ وَاستَكبَرتُم ۖ إِنَّ اللَّهَ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdxxi{وَقالَ الَّذينَ كَفَروا لِلَّذينَ آمَنوا لَو كانَ خَيرًا ما سَبَقونا إِلَيهِ ۚ وَإِذ لَم يَهتَدوا بِهِ فَسَيَقولونَ هٰذا إِفكٌ قَديمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdxxii{وَمِن قَبلِهِ كِتابُ موسىٰ إِمامًا وَرَحمَةً ۚ وَهٰذا كِتابٌ مُصَدِّقٌ لِسانًا عَرَبِيًّا لِيُنذِرَ الَّذينَ ظَلَموا وَبُشرىٰ لِلمُحسِنينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdxxiii{إِنَّ الَّذينَ قالوا رَبُّنَا اللَّهُ ثُمَّ استَقاموا فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdxxiv{أُولٰئِكَ أَصحابُ الجَنَّةِ خالِدينَ فيها جَزاءً بِما كانوا يَعمَلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdxxv{وَوَصَّينَا الإِنسانَ بِوالِدَيهِ إِحسانًا ۖ حَمَلَتهُ أُمُّهُ كُرهًا وَوَضَعَتهُ كُرهًا ۖ وَحَملُهُ وَفِصالُهُ ثَلاثونَ شَهرًا ۚ حَتّىٰ إِذا بَلَغَ أَشُدَّهُ وَبَلَغَ أَربَعينَ سَنَةً قالَ رَبِّ أَوزِعني أَن أَشكُرَ نِعمَتَكَ الَّتي أَنعَمتَ عَلَيَّ وَعَلىٰ والِدَيَّ وَأَن أَعمَلَ صالِحًا تَرضاهُ وَأَصلِح لي في ذُرِّيَّتي ۖ إِنّي تُبتُ إِلَيكَ وَإِنّي مِنَ المُسلِمينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdxxvi{أُولٰئِكَ الَّذينَ نَتَقَبَّلُ عَنهُم أَحسَنَ ما عَمِلوا وَنَتَجاوَزُ عَن سَيِّئَاتِهِم في أَصحابِ الجَنَّةِ ۖ وَعدَ الصِّدقِ الَّذي كانوا يوعَدونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdxxvii{وَالَّذي قالَ لِوالِدَيهِ أُفٍّ لَكُما أَتَعِدانِني أَن أُخرَجَ وَقَد خَلَتِ القُرونُ مِن قَبلي وَهُما يَستَغيثانِ اللَّهَ وَيلَكَ آمِن إِنَّ وَعدَ اللَّهِ حَقٌّ فَيَقولُ ما هٰذا إِلّا أَساطيرُ الأَوَّلينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdxxviii{أُولٰئِكَ الَّذينَ حَقَّ عَلَيهِمُ القَولُ في أُمَمٍ قَد خَلَت مِن قَبلِهِم مِنَ الجِنِّ وَالإِنسِ ۖ إِنَّهُم كانوا خاسِرينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdxxix{وَلِكُلٍّ دَرَجاتٌ مِمّا عَمِلوا ۖ وَلِيُوَفِّيَهُم أَعمالَهُم وَهُم لا يُظلَمونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdxxx{وَيَومَ يُعرَضُ الَّذينَ كَفَروا عَلَى النّارِ أَذهَبتُم طَيِّباتِكُم في حَياتِكُمُ الدُّنيا وَاستَمتَعتُم بِها فَاليَومَ تُجزَونَ عَذابَ الهونِ بِما كُنتُم تَستَكبِرونَ فِي الأَرضِ بِغَيرِ الحَقِّ وَبِما كُنتُم تَفسُقونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdxxxi{۞ وَاذكُر أَخا عادٍ إِذ أَنذَرَ قَومَهُ بِالأَحقافِ وَقَد خَلَتِ النُّذُرُ مِن بَينِ يَدَيهِ وَمِن خَلفِهِ أَلّا تَعبُدوا إِلَّا اللَّهَ إِنّي أَخافُ عَلَيكُم عَذابَ يَومٍ عَظيمٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdxxxii{قالوا أَجِئتَنا لِتَأفِكَنا عَن آلِهَتِنا فَأتِنا بِما تَعِدُنا إِن كُنتَ مِنَ الصّادِقينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdxxxiii{قالَ إِنَّمَا العِلمُ عِندَ اللَّهِ وَأُبَلِّغُكُم ما أُرسِلتُ بِهِ وَلٰكِنّي أَراكُم قَومًا تَجهَلونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdxxxiv{فَلَمّا رَأَوهُ عارِضًا مُستَقبِلَ أَودِيَتِهِم قالوا هٰذا عارِضٌ مُمطِرُنا ۚ بَل هُوَ مَا استَعجَلتُم بِهِ ۖ ريحٌ فيها عَذابٌ أَليمٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdxxxv{تُدَمِّرُ كُلَّ شَيءٍ بِأَمرِ رَبِّها فَأَصبَحوا لا يُرىٰ إِلّا مَساكِنُهُم ۚ كَذٰلِكَ نَجزِي القَومَ المُجرِمينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdxxxvi{وَلَقَد مَكَّنّاهُم فيما إِن مَكَّنّاكُم فيهِ وَجَعَلنا لَهُم سَمعًا وَأَبصارًا وَأَفئِدَةً فَما أَغنىٰ عَنهُم سَمعُهُم وَلا أَبصارُهُم وَلا أَفئِدَتُهُم مِن شَيءٍ إِذ كانوا يَجحَدونَ بِآياتِ اللَّهِ وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِئونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdxxxvii{وَلَقَد أَهلَكنا ما حَولَكُم مِنَ القُرىٰ وَصَرَّفنَا الآياتِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdxxxviii{فَلَولا نَصَرَهُمُ الَّذينَ اتَّخَذوا مِن دونِ اللَّهِ قُربانًا آلِهَةً ۖ بَل ضَلّوا عَنهُم ۚ وَذٰلِكَ إِفكُهُم وَما كانوا يَفتَرونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdxxxix{وَإِذ صَرَفنا إِلَيكَ نَفَرًا مِنَ الجِنِّ يَستَمِعونَ القُرآنَ فَلَمّا حَضَروهُ قالوا أَنصِتوا ۖ فَلَمّا قُضِيَ وَلَّوا إِلىٰ قَومِهِم مُنذِرينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdxl{قالوا يا قَومَنا إِنّا سَمِعنا كِتابًا أُنزِلَ مِن بَعدِ موسىٰ مُصَدِّقًا لِما بَينَ يَدَيهِ يَهدي إِلَى الحَقِّ وَإِلىٰ طَريقٍ مُستَقيمٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdxli{يا قَومَنا أَجيبوا داعِيَ اللَّهِ وَآمِنوا بِهِ يَغفِر لَكُم مِن ذُنوبِكُم وَيُجِركُم مِن عَذابٍ أَليمٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdxlii{وَمَن لا يُجِب داعِيَ اللَّهِ فَلَيسَ بِمُعجِزٍ فِي الأَرضِ وَلَيسَ لَهُ مِن دونِهِ أَولِياءُ ۚ أُولٰئِكَ في ضَلالٍ مُبينٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdxliii{أَوَلَم يَرَوا أَنَّ اللَّهَ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ وَلَم يَعيَ بِخَلقِهِنَّ بِقادِرٍ عَلىٰ أَن يُحيِيَ المَوتىٰ ۚ بَلىٰ إِنَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdxliv{وَيَومَ يُعرَضُ الَّذينَ كَفَروا عَلَى النّارِ أَلَيسَ هٰذا بِالحَقِّ ۖ قالوا بَلىٰ وَرَبِّنا ۚ قالَ فَذوقُوا العَذابَ بِما كُنتُم تَكفُرونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdxlv{فَاصبِر كَما صَبَرَ أُولُو العَزمِ مِنَ الرُّسُلِ وَلا تَستَعجِل لَهُم ۚ كَأَنَّهُم يَومَ يَرَونَ ما يوعَدونَ لَم يَلبَثوا إِلّا ساعَةً مِن نَهارٍ ۚ بَلاغٌ ۚ فَهَل يُهلَكُ إِلَّا القَومُ الفاسِقونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdxlvi{\basmalah الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ أَضَلَّ أَعمالَهُم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdxlvii{وَالَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ وَآمَنوا بِما نُزِّلَ عَلىٰ مُحَمَّدٍ وَهُوَ الحَقُّ مِن رَبِّهِم ۙ كَفَّرَ عَنهُم سَيِّئَاتِهِم وَأَصلَحَ بالَهُم\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdxlviii{ذٰلِكَ بِأَنَّ الَّذينَ كَفَرُوا اتَّبَعُوا الباطِلَ وَأَنَّ الَّذينَ آمَنُوا اتَّبَعُوا الحَقَّ مِن رَبِّهِم ۚ كَذٰلِكَ يَضرِبُ اللَّهُ لِلنّاسِ أَمثالَهُم\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdxlix{فَإِذا لَقيتُمُ الَّذينَ كَفَروا فَضَربَ الرِّقابِ حَتّىٰ إِذا أَثخَنتُموهُم فَشُدُّوا الوَثاقَ فَإِمّا مَنًّا بَعدُ وَإِمّا فِداءً حَتّىٰ تَضَعَ الحَربُ أَوزارَها ۚ ذٰلِكَ وَلَو يَشاءُ اللَّهُ لَانتَصَرَ مِنهُم وَلٰكِن لِيَبلُوَ بَعضَكُم بِبَعضٍ ۗ وَالَّذينَ قُتِلوا في سَبيلِ اللَّهِ فَلَن يُضِلَّ أَعمالَهُم\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdl{سَيَهديهِم وَيُصلِحُ بالَهُم\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdli{وَيُدخِلُهُمُ الجَنَّةَ عَرَّفَها لَهُم\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdlii{يا أَيُّهَا الَّذينَ آمَنوا إِن تَنصُرُوا اللَّهَ يَنصُركُم وَيُثَبِّت أَقدامَكُم\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdliii{وَالَّذينَ كَفَروا فَتَعسًا لَهُم وَأَضَلَّ أَعمالَهُم\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdliv{ذٰلِكَ بِأَنَّهُم كَرِهوا ما أَنزَلَ اللَّهُ فَأَحبَطَ أَعمالَهُم\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdlv{۞ أَفَلَم يَسيروا فِي الأَرضِ فَيَنظُروا كَيفَ كانَ عاقِبَةُ الَّذينَ مِن قَبلِهِم ۚ دَمَّرَ اللَّهُ عَلَيهِم ۖ وَلِلكافِرينَ أَمثالُها\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdlvi{ذٰلِكَ بِأَنَّ اللَّهَ مَولَى الَّذينَ آمَنوا وَأَنَّ الكافِرينَ لا مَولىٰ لَهُم\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdlvii{إِنَّ اللَّهَ يُدخِلُ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ ۖ وَالَّذينَ كَفَروا يَتَمَتَّعونَ وَيَأكُلونَ كَما تَأكُلُ الأَنعامُ وَالنّارُ مَثوًى لَهُم\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdlviii{وَكَأَيِّن مِن قَريَةٍ هِيَ أَشَدُّ قُوَّةً مِن قَريَتِكَ الَّتي أَخرَجَتكَ أَهلَكناهُم فَلا ناصِرَ لَهُم\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdlix{أَفَمَن كانَ عَلىٰ بَيِّنَةٍ مِن رَبِّهِ كَمَن زُيِّنَ لَهُ سوءُ عَمَلِهِ وَاتَّبَعوا أَهواءَهُم\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdlx{مَثَلُ الجَنَّةِ الَّتي وُعِدَ المُتَّقونَ ۖ فيها أَنهارٌ مِن ماءٍ غَيرِ آسِنٍ وَأَنهارٌ مِن لَبَنٍ لَم يَتَغَيَّر طَعمُهُ وَأَنهارٌ مِن خَمرٍ لَذَّةٍ لِلشّارِبينَ وَأَنهارٌ مِن عَسَلٍ مُصَفًّى ۖ وَلَهُم فيها مِن كُلِّ الثَّمَراتِ وَمَغفِرَةٌ مِن رَبِّهِم ۖ كَمَن هُوَ خالِدٌ فِي النّارِ وَسُقوا ماءً حَميمًا فَقَطَّعَ أَمعاءَهُم\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdlxi{وَمِنهُم مَن يَستَمِعُ إِلَيكَ حَتّىٰ إِذا خَرَجوا مِن عِندِكَ قالوا لِلَّذينَ أوتُوا العِلمَ ماذا قالَ آنِفًا ۚ أُولٰئِكَ الَّذينَ طَبَعَ اللَّهُ عَلىٰ قُلوبِهِم وَاتَّبَعوا أَهواءَهُم\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdlxii{وَالَّذينَ اهتَدَوا زادَهُم هُدًى وَآتاهُم تَقواهُم\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdlxiii{فَهَل يَنظُرونَ إِلَّا السّاعَةَ أَن تَأتِيَهُم بَغتَةً ۖ فَقَد جاءَ أَشراطُها ۚ فَأَنّىٰ لَهُم إِذا جاءَتهُم ذِكراهُم\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdlxiv{فَاعلَم أَنَّهُ لا إِلٰهَ إِلَّا اللَّهُ وَاستَغفِر لِذَنبِكَ وَلِلمُؤمِنينَ وَالمُؤمِناتِ ۗ وَاللَّهُ يَعلَمُ مُتَقَلَّبَكُم وَمَثواكُم\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdlxv{وَيَقولُ الَّذينَ آمَنوا لَولا نُزِّلَت سورَةٌ ۖ فَإِذا أُنزِلَت سورَةٌ مُحكَمَةٌ وَذُكِرَ فيهَا القِتالُ ۙ رَأَيتَ الَّذينَ في قُلوبِهِم مَرَضٌ يَنظُرونَ إِلَيكَ نَظَرَ المَغشِيِّ عَلَيهِ مِنَ المَوتِ ۖ فَأَولىٰ لَهُم\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdlxvi{طاعَةٌ وَقَولٌ مَعروفٌ ۚ فَإِذا عَزَمَ الأَمرُ فَلَو صَدَقُوا اللَّهَ لَكانَ خَيرًا لَهُم\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdlxvii{فَهَل عَسَيتُم إِن تَوَلَّيتُم أَن تُفسِدوا فِي الأَرضِ وَتُقَطِّعوا أَرحامَكُم\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdlxviii{أُولٰئِكَ الَّذينَ لَعَنَهُمُ اللَّهُ فَأَصَمَّهُم وَأَعمىٰ أَبصارَهُم\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdlxix{أَفَلا يَتَدَبَّرونَ القُرآنَ أَم عَلىٰ قُلوبٍ أَقفالُها\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdlxx{إِنَّ الَّذينَ ارتَدّوا عَلىٰ أَدبارِهِم مِن بَعدِ ما تَبَيَّنَ لَهُمُ الهُدَى ۙ الشَّيطانُ سَوَّلَ لَهُم وَأَملىٰ لَهُم\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdlxxi{ذٰلِكَ بِأَنَّهُم قالوا لِلَّذينَ كَرِهوا ما نَزَّلَ اللَّهُ سَنُطيعُكُم في بَعضِ الأَمرِ ۖ وَاللَّهُ يَعلَمُ إِسرارَهُم\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdlxxii{فَكَيفَ إِذا تَوَفَّتهُمُ المَلائِكَةُ يَضرِبونَ وُجوهَهُم وَأَدبارَهُم\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdlxxiii{ذٰلِكَ بِأَنَّهُمُ اتَّبَعوا ما أَسخَطَ اللَّهَ وَكَرِهوا رِضوانَهُ فَأَحبَطَ أَعمالَهُم\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdlxxiv{أَم حَسِبَ الَّذينَ في قُلوبِهِم مَرَضٌ أَن لَن يُخرِجَ اللَّهُ أَضغانَهُم\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdlxxv{وَلَو نَشاءُ لَأَرَيناكَهُم فَلَعَرَفتَهُم بِسيماهُم ۚ وَلَتَعرِفَنَّهُم في لَحنِ القَولِ ۚ وَاللَّهُ يَعلَمُ أَعمالَكُم\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdlxxvi{وَلَنَبلُوَنَّكُم حَتّىٰ نَعلَمَ المُجاهِدينَ مِنكُم وَالصّابِرينَ وَنَبلُوَ أَخبارَكُم\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdlxxvii{إِنَّ الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ وَشاقُّوا الرَّسولَ مِن بَعدِ ما تَبَيَّنَ لَهُمُ الهُدىٰ لَن يَضُرُّوا اللَّهَ شَيئًا وَسَيُحبِطُ أَعمالَهُم\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdlxxviii{۞ يا أَيُّهَا الَّذينَ آمَنوا أَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ وَلا تُبطِلوا أَعمالَكُم\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdlxxix{إِنَّ الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ ثُمَّ ماتوا وَهُم كُفّارٌ فَلَن يَغفِرَ اللَّهُ لَهُم\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdlxxx{فَلا تَهِنوا وَتَدعوا إِلَى السَّلمِ وَأَنتُمُ الأَعلَونَ وَاللَّهُ مَعَكُم وَلَن يَتِرَكُم أَعمالَكُم\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdlxxxi{إِنَّمَا الحَياةُ الدُّنيا لَعِبٌ وَلَهوٌ ۚ وَإِن تُؤمِنوا وَتَتَّقوا يُؤتِكُم أُجورَكُم وَلا يَسأَلكُم أَموالَكُم\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdlxxxii{إِن يَسأَلكُموها فَيُحفِكُم تَبخَلوا وَيُخرِج أَضغانَكُم\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdlxxxiii{ها أَنتُم هٰؤُلاءِ تُدعَونَ لِتُنفِقوا في سَبيلِ اللَّهِ فَمِنكُم مَن يَبخَلُ ۖ وَمَن يَبخَل فَإِنَّما يَبخَلُ عَن نَفسِهِ ۚ وَاللَّهُ الغَنِيُّ وَأَنتُمُ الفُقَراءُ ۚ وَإِن تَتَوَلَّوا يَستَبدِل قَومًا غَيرَكُم ثُمَّ لا يَكونوا أَمثالَكُم\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdlxxxiv{\basmalah إِنّا فَتَحنا لَكَ فَتحًا مُبينًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdlxxxv{لِيَغفِرَ لَكَ اللَّهُ ما تَقَدَّمَ مِن ذَنبِكَ وَما تَأَخَّرَ وَيُتِمَّ نِعمَتَهُ عَلَيكَ وَيَهدِيَكَ صِراطًا مُستَقيمًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdlxxxvi{وَيَنصُرَكَ اللَّهُ نَصرًا عَزيزًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdlxxxvii{هُوَ الَّذي أَنزَلَ السَّكينَةَ في قُلوبِ المُؤمِنينَ لِيَزدادوا إيمانًا مَعَ إيمانِهِم ۗ وَلِلَّهِ جُنودُ السَّماواتِ وَالأَرضِ ۚ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdlxxxviii{لِيُدخِلَ المُؤمِنينَ وَالمُؤمِناتِ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها وَيُكَفِّرَ عَنهُم سَيِّئَاتِهِم ۚ وَكانَ ذٰلِكَ عِندَ اللَّهِ فَوزًا عَظيمًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdlxxxix{وَيُعَذِّبَ المُنافِقينَ وَالمُنافِقاتِ وَالمُشرِكينَ وَالمُشرِكاتِ الظّانّينَ بِاللَّهِ ظَنَّ السَّوءِ ۚ عَلَيهِم دائِرَةُ السَّوءِ ۖ وَغَضِبَ اللَّهُ عَلَيهِم وَلَعَنَهُم وَأَعَدَّ لَهُم جَهَنَّمَ ۖ وَساءَت مَصيرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdxc{وَلِلَّهِ جُنودُ السَّماواتِ وَالأَرضِ ۚ وَكانَ اللَّهُ عَزيزًا حَكيمًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdxci{إِنّا أَرسَلناكَ شاهِدًا وَمُبَشِّرًا وَنَذيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdxcii{لِتُؤمِنوا بِاللَّهِ وَرَسولِهِ وَتُعَزِّروهُ وَتُوَقِّروهُ وَتُسَبِّحوهُ بُكرَةً وَأَصيلًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdxciii{إِنَّ الَّذينَ يُبايِعونَكَ إِنَّما يُبايِعونَ اللَّهَ يَدُ اللَّهِ فَوقَ أَيديهِم ۚ فَمَن نَكَثَ فَإِنَّما يَنكُثُ عَلىٰ نَفسِهِ ۖ وَمَن أَوفىٰ بِما عاهَدَ عَلَيهُ اللَّهَ فَسَيُؤتيهِ أَجرًا عَظيمًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdxciv{سَيَقولُ لَكَ المُخَلَّفونَ مِنَ الأَعرابِ شَغَلَتنا أَموالُنا وَأَهلونا فَاستَغفِر لَنا ۚ يَقولونَ بِأَلسِنَتِهِم ما لَيسَ في قُلوبِهِم ۚ قُل فَمَن يَملِكُ لَكُم مِنَ اللَّهِ شَيئًا إِن أَرادَ بِكُم ضَرًّا أَو أَرادَ بِكُم نَفعًا ۚ بَل كانَ اللَّهُ بِما تَعمَلونَ خَبيرًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdxcv{بَل ظَنَنتُم أَن لَن يَنقَلِبَ الرَّسولُ وَالمُؤمِنونَ إِلىٰ أَهليهِم أَبَدًا وَزُيِّنَ ذٰلِكَ في قُلوبِكُم وَظَنَنتُم ظَنَّ السَّوءِ وَكُنتُم قَومًا بورًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdxcvi{وَمَن لَم يُؤمِن بِاللَّهِ وَرَسولِهِ فَإِنّا أَعتَدنا لِلكافِرينَ سَعيرًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdxcvii{وَلِلَّهِ مُلكُ السَّماواتِ وَالأَرضِ ۚ يَغفِرُ لِمَن يَشاءُ وَيُعَذِّبُ مَن يَشاءُ ۚ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdxcviii{سَيَقولُ المُخَلَّفونَ إِذَا انطَلَقتُم إِلىٰ مَغانِمَ لِتَأخُذوها ذَرونا نَتَّبِعكُم ۖ يُريدونَ أَن يُبَدِّلوا كَلامَ اللَّهِ ۚ قُل لَن تَتَّبِعونا كَذٰلِكُم قالَ اللَّهُ مِن قَبلُ ۖ فَسَيَقولونَ بَل تَحسُدونَنا ۚ بَل كانوا لا يَفقَهونَ إِلّا قَليلًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdxcix{قُل لِلمُخَلَّفينَ مِنَ الأَعرابِ سَتُدعَونَ إِلىٰ قَومٍ أُولي بَأسٍ شَديدٍ تُقاتِلونَهُم أَو يُسلِمونَ ۖ فَإِن تُطيعوا يُؤتِكُمُ اللَّهُ أَجرًا حَسَنًا ۖ وَإِن تَتَوَلَّوا كَما تَوَلَّيتُم مِن قَبلُ يُعَذِّبكُم عَذابًا أَليمًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdc{لَيسَ عَلَى الأَعمىٰ حَرَجٌ وَلا عَلَى الأَعرَجِ حَرَجٌ وَلا عَلَى المَريضِ حَرَجٌ ۗ وَمَن يُطِعِ اللَّهَ وَرَسولَهُ يُدخِلهُ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ ۖ وَمَن يَتَوَلَّ يُعَذِّبهُ عَذابًا أَليمًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdci{۞ لَقَد رَضِيَ اللَّهُ عَنِ المُؤمِنينَ إِذ يُبايِعونَكَ تَحتَ الشَّجَرَةِ فَعَلِمَ ما في قُلوبِهِم فَأَنزَلَ السَّكينَةَ عَلَيهِم وَأَثابَهُم فَتحًا قَريبًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcii{وَمَغانِمَ كَثيرَةً يَأخُذونَها ۗ وَكانَ اللَّهُ عَزيزًا حَكيمًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdciii{وَعَدَكُمُ اللَّهُ مَغانِمَ كَثيرَةً تَأخُذونَها فَعَجَّلَ لَكُم هٰذِهِ وَكَفَّ أَيدِيَ النّاسِ عَنكُم وَلِتَكونَ آيَةً لِلمُؤمِنينَ وَيَهدِيَكُم صِراطًا مُستَقيمًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdciv{وَأُخرىٰ لَم تَقدِروا عَلَيها قَد أَحاطَ اللَّهُ بِها ۚ وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcv{وَلَو قاتَلَكُمُ الَّذينَ كَفَروا لَوَلَّوُا الأَدبارَ ثُمَّ لا يَجِدونَ وَلِيًّا وَلا نَصيرًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcvi{سُنَّةَ اللَّهِ الَّتي قَد خَلَت مِن قَبلُ ۖ وَلَن تَجِدَ لِسُنَّةِ اللَّهِ تَبديلًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcvii{وَهُوَ الَّذي كَفَّ أَيدِيَهُم عَنكُم وَأَيدِيَكُم عَنهُم بِبَطنِ مَكَّةَ مِن بَعدِ أَن أَظفَرَكُم عَلَيهِم ۚ وَكانَ اللَّهُ بِما تَعمَلونَ بَصيرًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcviii{هُمُ الَّذينَ كَفَروا وَصَدّوكُم عَنِ المَسجِدِ الحَرامِ وَالهَديَ مَعكوفًا أَن يَبلُغَ مَحِلَّهُ ۚ وَلَولا رِجالٌ مُؤمِنونَ وَنِساءٌ مُؤمِناتٌ لَم تَعلَموهُم أَن تَطَئوهُم فَتُصيبَكُم مِنهُم مَعَرَّةٌ بِغَيرِ عِلمٍ ۖ لِيُدخِلَ اللَّهُ في رَحمَتِهِ مَن يَشاءُ ۚ لَو تَزَيَّلوا لَعَذَّبنَا الَّذينَ كَفَروا مِنهُم عَذابًا أَليمًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcix{إِذ جَعَلَ الَّذينَ كَفَروا في قُلوبِهِمُ الحَمِيَّةَ حَمِيَّةَ الجاهِلِيَّةِ فَأَنزَلَ اللَّهُ سَكينَتَهُ عَلىٰ رَسولِهِ وَعَلَى المُؤمِنينَ وَأَلزَمَهُم كَلِمَةَ التَّقوىٰ وَكانوا أَحَقَّ بِها وَأَهلَها ۚ وَكانَ اللَّهُ بِكُلِّ شَيءٍ عَليمًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdcx{لَقَد صَدَقَ اللَّهُ رَسولَهُ الرُّؤيا بِالحَقِّ ۖ لَتَدخُلُنَّ المَسجِدَ الحَرامَ إِن شاءَ اللَّهُ آمِنينَ مُحَلِّقينَ رُءوسَكُم وَمُقَصِّرينَ لا تَخافونَ ۖ فَعَلِمَ ما لَم تَعلَموا فَجَعَلَ مِن دونِ ذٰلِكَ فَتحًا قَريبًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcxi{هُوَ الَّذي أَرسَلَ رَسولَهُ بِالهُدىٰ وَدينِ الحَقِّ لِيُظهِرَهُ عَلَى الدّينِ كُلِّهِ ۚ وَكَفىٰ بِاللَّهِ شَهيدًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcxii{مُحَمَّدٌ رَسولُ اللَّهِ ۚ وَالَّذينَ مَعَهُ أَشِدّاءُ عَلَى الكُفّارِ رُحَماءُ بَينَهُم ۖ تَراهُم رُكَّعًا سُجَّدًا يَبتَغونَ فَضلًا مِنَ اللَّهِ وَرِضوانًا ۖ سيماهُم في وُجوهِهِم مِن أَثَرِ السُّجودِ ۚ ذٰلِكَ مَثَلُهُم فِي التَّوراةِ ۚ وَمَثَلُهُم فِي الإِنجيلِ كَزَرعٍ أَخرَجَ شَطأَهُ فَآزَرَهُ فَاستَغلَظَ فَاستَوىٰ عَلىٰ سوقِهِ يُعجِبُ الزُّرّاعَ لِيَغيظَ بِهِمُ الكُفّارَ ۗ وَعَدَ اللَّهُ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ مِنهُم مَغفِرَةً وَأَجرًا عَظيمًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdcxiii{\basmalah يا أَيُّهَا الَّذينَ آمَنوا لا تُقَدِّموا بَينَ يَدَيِ اللَّهِ وَرَسولِهِ ۖ وَاتَّقُوا اللَّهَ ۚ إِنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcxiv{يا أَيُّهَا الَّذينَ آمَنوا لا تَرفَعوا أَصواتَكُم فَوقَ صَوتِ النَّبِيِّ وَلا تَجهَروا لَهُ بِالقَولِ كَجَهرِ بَعضِكُم لِبَعضٍ أَن تَحبَطَ أَعمالُكُم وَأَنتُم لا تَشعُرونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcxv{إِنَّ الَّذينَ يَغُضّونَ أَصواتَهُم عِندَ رَسولِ اللَّهِ أُولٰئِكَ الَّذينَ امتَحَنَ اللَّهُ قُلوبَهُم لِلتَّقوىٰ ۚ لَهُم مَغفِرَةٌ وَأَجرٌ عَظيمٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcxvi{إِنَّ الَّذينَ يُنادونَكَ مِن وَراءِ الحُجُراتِ أَكثَرُهُم لا يَعقِلونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcxvii{وَلَو أَنَّهُم صَبَروا حَتّىٰ تَخرُجَ إِلَيهِم لَكانَ خَيرًا لَهُم ۚ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdcxviii{يا أَيُّهَا الَّذينَ آمَنوا إِن جاءَكُم فاسِقٌ بِنَبَإٍ فَتَبَيَّنوا أَن تُصيبوا قَومًا بِجَهالَةٍ فَتُصبِحوا عَلىٰ ما فَعَلتُم نادِمينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdcxix{وَاعلَموا أَنَّ فيكُم رَسولَ اللَّهِ ۚ لَو يُطيعُكُم في كَثيرٍ مِنَ الأَمرِ لَعَنِتُّم وَلٰكِنَّ اللَّهَ حَبَّبَ إِلَيكُمُ الإيمانَ وَزَيَّنَهُ في قُلوبِكُم وَكَرَّهَ إِلَيكُمُ الكُفرَ وَالفُسوقَ وَالعِصيانَ ۚ أُولٰئِكَ هُمُ الرّاشِدونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdcxx{فَضلًا مِنَ اللَّهِ وَنِعمَةً ۚ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdcxxi{وَإِن طائِفَتانِ مِنَ المُؤمِنينَ اقتَتَلوا فَأَصلِحوا بَينَهُما ۖ فَإِن بَغَت إِحداهُما عَلَى الأُخرىٰ فَقاتِلُوا الَّتي تَبغي حَتّىٰ تَفيءَ إِلىٰ أَمرِ اللَّهِ ۚ فَإِن فاءَت فَأَصلِحوا بَينَهُما بِالعَدلِ وَأَقسِطوا ۖ إِنَّ اللَّهَ يُحِبُّ المُقسِطينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdcxxii{إِنَّمَا المُؤمِنونَ إِخوَةٌ فَأَصلِحوا بَينَ أَخَوَيكُم ۚ وَاتَّقُوا اللَّهَ لَعَلَّكُم تُرحَمونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdcxxiii{يا أَيُّهَا الَّذينَ آمَنوا لا يَسخَر قَومٌ مِن قَومٍ عَسىٰ أَن يَكونوا خَيرًا مِنهُم وَلا نِساءٌ مِن نِساءٍ عَسىٰ أَن يَكُنَّ خَيرًا مِنهُنَّ ۖ وَلا تَلمِزوا أَنفُسَكُم وَلا تَنابَزوا بِالأَلقابِ ۖ بِئسَ الِاسمُ الفُسوقُ بَعدَ الإيمانِ ۚ وَمَن لَم يَتُب فَأُولٰئِكَ هُمُ الظّالِمونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdcxxiv{يا أَيُّهَا الَّذينَ آمَنُوا اجتَنِبوا كَثيرًا مِنَ الظَّنِّ إِنَّ بَعضَ الظَّنِّ إِثمٌ ۖ وَلا تَجَسَّسوا وَلا يَغتَب بَعضُكُم بَعضًا ۚ أَيُحِبُّ أَحَدُكُم أَن يَأكُلَ لَحمَ أَخيهِ مَيتًا فَكَرِهتُموهُ ۚ وَاتَّقُوا اللَّهَ ۚ إِنَّ اللَّهَ تَوّابٌ رَحيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdcxxv{يا أَيُّهَا النّاسُ إِنّا خَلَقناكُم مِن ذَكَرٍ وَأُنثىٰ وَجَعَلناكُم شُعوبًا وَقَبائِلَ لِتَعارَفوا ۚ إِنَّ أَكرَمَكُم عِندَ اللَّهِ أَتقاكُم ۚ إِنَّ اللَّهَ عَليمٌ خَبيرٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdcxxvi{۞ قالَتِ الأَعرابُ آمَنّا ۖ قُل لَم تُؤمِنوا وَلٰكِن قولوا أَسلَمنا وَلَمّا يَدخُلِ الإيمانُ في قُلوبِكُم ۖ وَإِن تُطيعُوا اللَّهَ وَرَسولَهُ لا يَلِتكُم مِن أَعمالِكُم شَيئًا ۚ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdcxxvii{إِنَّمَا المُؤمِنونَ الَّذينَ آمَنوا بِاللَّهِ وَرَسولِهِ ثُمَّ لَم يَرتابوا وَجاهَدوا بِأَموالِهِم وَأَنفُسِهِم في سَبيلِ اللَّهِ ۚ أُولٰئِكَ هُمُ الصّادِقونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdcxxviii{قُل أَتُعَلِّمونَ اللَّهَ بِدينِكُم وَاللَّهُ يَعلَمُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۚ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcxxix{يَمُنّونَ عَلَيكَ أَن أَسلَموا ۖ قُل لا تَمُنّوا عَلَيَّ إِسلامَكُم ۖ بَلِ اللَّهُ يَمُنُّ عَلَيكُم أَن هَداكُم لِلإيمانِ إِن كُنتُم صادِقينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcxxx{إِنَّ اللَّهَ يَعلَمُ غَيبَ السَّماواتِ وَالأَرضِ ۚ وَاللَّهُ بَصيرٌ بِما تَعمَلونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcxxxi{\basmalah ق ۚ وَالقُرآنِ المَجيدِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcxxxii{بَل عَجِبوا أَن جاءَهُم مُنذِرٌ مِنهُم فَقالَ الكافِرونَ هٰذا شَيءٌ عَجيبٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcxxxiii{أَإِذا مِتنا وَكُنّا تُرابًا ۖ ذٰلِكَ رَجعٌ بَعيدٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcxxxiv{قَد عَلِمنا ما تَنقُصُ الأَرضُ مِنهُم ۖ وَعِندَنا كِتابٌ حَفيظٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcxxxv{بَل كَذَّبوا بِالحَقِّ لَمّا جاءَهُم فَهُم في أَمرٍ مَريجٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdcxxxvi{أَفَلَم يَنظُروا إِلَى السَّماءِ فَوقَهُم كَيفَ بَنَيناها وَزَيَّنّاها وَما لَها مِن فُروجٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdcxxxvii{وَالأَرضَ مَدَدناها وَأَلقَينا فيها رَواسِيَ وَأَنبَتنا فيها مِن كُلِّ زَوجٍ بَهيجٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdcxxxviii{تَبصِرَةً وَذِكرىٰ لِكُلِّ عَبدٍ مُنيبٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdcxxxix{وَنَزَّلنا مِنَ السَّماءِ ماءً مُبارَكًا فَأَنبَتنا بِهِ جَنّاتٍ وَحَبَّ الحَصيدِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdcxl{وَالنَّخلَ باسِقاتٍ لَها طَلعٌ نَضيدٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdcxli{رِزقًا لِلعِبادِ ۖ وَأَحيَينا بِهِ بَلدَةً مَيتًا ۚ كَذٰلِكَ الخُروجُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdcxlii{كَذَّبَت قَبلَهُم قَومُ نوحٍ وَأَصحابُ الرَّسِّ وَثَمودُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdcxliii{وَعادٌ وَفِرعَونُ وَإِخوانُ لوطٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdcxliv{وَأَصحابُ الأَيكَةِ وَقَومُ تُبَّعٍ ۚ كُلٌّ كَذَّبَ الرُّسُلَ فَحَقَّ وَعيدِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdcxlv{أَفَعَيينا بِالخَلقِ الأَوَّلِ ۚ بَل هُم في لَبسٍ مِن خَلقٍ جَديدٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdcxlvi{وَلَقَد خَلَقنَا الإِنسانَ وَنَعلَمُ ما تُوَسوِسُ بِهِ نَفسُهُ ۖ وَنَحنُ أَقرَبُ إِلَيهِ مِن حَبلِ الوَريدِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcxlvii{إِذ يَتَلَقَّى المُتَلَقِّيانِ عَنِ اليَمينِ وَعَنِ الشِّمالِ قَعيدٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcxlviii{ما يَلفِظُ مِن قَولٍ إِلّا لَدَيهِ رَقيبٌ عَتيدٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcxlix{وَجاءَت سَكرَةُ المَوتِ بِالحَقِّ ۖ ذٰلِكَ ما كُنتَ مِنهُ تَحيدُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdcl{وَنُفِخَ فِي الصّورِ ۚ ذٰلِكَ يَومُ الوَعيدِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcli{وَجاءَت كُلُّ نَفسٍ مَعَها سائِقٌ وَشَهيدٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdclii{لَقَد كُنتَ في غَفلَةٍ مِن هٰذا فَكَشَفنا عَنكَ غِطاءَكَ فَبَصَرُكَ اليَومَ حَديدٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcliii{وَقالَ قَرينُهُ هٰذا ما لَدَيَّ عَتيدٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcliv{أَلقِيا في جَهَنَّمَ كُلَّ كَفّارٍ عَنيدٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdclv{مَنّاعٍ لِلخَيرِ مُعتَدٍ مُريبٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdclvi{الَّذي جَعَلَ مَعَ اللَّهِ إِلٰهًا آخَرَ فَأَلقِياهُ فِي العَذابِ الشَّديدِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdclvii{۞ قالَ قَرينُهُ رَبَّنا ما أَطغَيتُهُ وَلٰكِن كانَ في ضَلالٍ بَعيدٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdclviii{قالَ لا تَختَصِموا لَدَيَّ وَقَد قَدَّمتُ إِلَيكُم بِالوَعيدِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdclix{ما يُبَدَّلُ القَولُ لَدَيَّ وَما أَنا بِظَلّامٍ لِلعَبيدِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdclx{يَومَ نَقولُ لِجَهَنَّمَ هَلِ امتَلَأتِ وَتَقولُ هَل مِن مَزيدٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdclxi{وَأُزلِفَتِ الجَنَّةُ لِلمُتَّقينَ غَيرَ بَعيدٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdclxii{هٰذا ما توعَدونَ لِكُلِّ أَوّابٍ حَفيظٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdclxiii{مَن خَشِيَ الرَّحمٰنَ بِالغَيبِ وَجاءَ بِقَلبٍ مُنيبٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdclxiv{ادخُلوها بِسَلامٍ ۖ ذٰلِكَ يَومُ الخُلودِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdclxv{لَهُم ما يَشاءونَ فيها وَلَدَينا مَزيدٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdclxvi{وَكَم أَهلَكنا قَبلَهُم مِن قَرنٍ هُم أَشَدُّ مِنهُم بَطشًا فَنَقَّبوا فِي البِلادِ هَل مِن مَحيصٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdclxvii{إِنَّ في ذٰلِكَ لَذِكرىٰ لِمَن كانَ لَهُ قَلبٌ أَو أَلقَى السَّمعَ وَهُوَ شَهيدٌ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdclxviii{وَلَقَد خَلَقنَا السَّماواتِ وَالأَرضَ وَما بَينَهُما في سِتَّةِ أَيّامٍ وَما مَسَّنا مِن لُغوبٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdclxix{فَاصبِر عَلىٰ ما يَقولونَ وَسَبِّح بِحَمدِ رَبِّكَ قَبلَ طُلوعِ الشَّمسِ وَقَبلَ الغُروبِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdclxx{وَمِنَ اللَّيلِ فَسَبِّحهُ وَأَدبارَ السُّجودِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdclxxi{وَاستَمِع يَومَ يُنادِ المُنادِ مِن مَكانٍ قَريبٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdclxxii{يَومَ يَسمَعونَ الصَّيحَةَ بِالحَقِّ ۚ ذٰلِكَ يَومُ الخُروجِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdclxxiii{إِنّا نَحنُ نُحيي وَنُميتُ وَإِلَينَا المَصيرُ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdclxxiv{يَومَ تَشَقَّقُ الأَرضُ عَنهُم سِراعًا ۚ ذٰلِكَ حَشرٌ عَلَينا يَسيرٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdclxxv{نَحنُ أَعلَمُ بِما يَقولونَ ۖ وَما أَنتَ عَلَيهِم بِجَبّارٍ ۖ فَذَكِّر بِالقُرآنِ مَن يَخافُ وَعيدِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdclxxvi{\basmalah وَالذّارِياتِ ذَروًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdclxxvii{فَالحامِلاتِ وِقرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdclxxviii{فَالجارِياتِ يُسرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdclxxix{فَالمُقَسِّماتِ أَمرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdclxxx{إِنَّما توعَدونَ لَصادِقٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdclxxxi{وَإِنَّ الدّينَ لَواقِعٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdclxxxii{وَالسَّماءِ ذاتِ الحُبُكِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdclxxxiii{إِنَّكُم لَفي قَولٍ مُختَلِفٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdclxxxiv{يُؤفَكُ عَنهُ مَن أُفِكَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdclxxxv{قُتِلَ الخَرّاصونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdclxxxvi{الَّذينَ هُم في غَمرَةٍ ساهونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdclxxxvii{يَسأَلونَ أَيّانَ يَومُ الدّينِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdclxxxviii{يَومَ هُم عَلَى النّارِ يُفتَنونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdclxxxix{ذوقوا فِتنَتَكُم هٰذَا الَّذي كُنتُم بِهِ تَستَعجِلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdcxc{إِنَّ المُتَّقينَ في جَنّاتٍ وَعُيونٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdcxci{آخِذينَ ما آتاهُم رَبُّهُم ۚ إِنَّهُم كانوا قَبلَ ذٰلِكَ مُحسِنينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcxcii{كانوا قَليلًا مِنَ اللَّيلِ ما يَهجَعونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcxciii{وَبِالأَسحارِ هُم يَستَغفِرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcxciv{وَفي أَموالِهِم حَقٌّ لِلسّائِلِ وَالمَحرومِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdcxcv{وَفِي الأَرضِ آياتٌ لِلموقِنينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcxcvi{وَفي أَنفُسِكُم ۚ أَفَلا تُبصِرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcxcvii{وَفِي السَّماءِ رِزقُكُم وَما توعَدونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcxcviii{فَوَرَبِّ السَّماءِ وَالأَرضِ إِنَّهُ لَحَقٌّ مِثلَ ما أَنَّكُم تَنطِقونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcxcix{هَل أَتاكَ حَديثُ ضَيفِ إِبراهيمَ المُكرَمينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcc{إِذ دَخَلوا عَلَيهِ فَقالوا سَلامًا ۖ قالَ سَلامٌ قَومٌ مُنكَرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcci{فَراغَ إِلىٰ أَهلِهِ فَجاءَ بِعِجلٍ سَمينٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdccii{فَقَرَّبَهُ إِلَيهِم قالَ أَلا تَأكُلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcciii{فَأَوجَسَ مِنهُم خيفَةً ۖ قالوا لا تَخَف ۖ وَبَشَّروهُ بِغُلامٍ عَليمٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcciv{فَأَقبَلَتِ امرَأَتُهُ في صَرَّةٍ فَصَكَّت وَجهَها وَقالَت عَجوزٌ عَقيمٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdccv{قالوا كَذٰلِكِ قالَ رَبُّكِ ۖ إِنَّهُ هُوَ الحَكيمُ العَليمُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdccvi{۞ قالَ فَما خَطبُكُم أَيُّهَا المُرسَلونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdccvii{قالوا إِنّا أُرسِلنا إِلىٰ قَومٍ مُجرِمينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdccviii{لِنُرسِلَ عَلَيهِم حِجارَةً مِن طينٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdccix{مُسَوَّمَةً عِندَ رَبِّكَ لِلمُسرِفينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdccx{فَأَخرَجنا مَن كانَ فيها مِنَ المُؤمِنينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdccxi{فَما وَجَدنا فيها غَيرَ بَيتٍ مِنَ المُسلِمينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdccxii{وَتَرَكنا فيها آيَةً لِلَّذينَ يَخافونَ العَذابَ الأَليمَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdccxiii{وَفي موسىٰ إِذ أَرسَلناهُ إِلىٰ فِرعَونَ بِسُلطانٍ مُبينٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdccxiv{فَتَوَلّىٰ بِرُكنِهِ وَقالَ ساحِرٌ أَو مَجنونٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdccxv{فَأَخَذناهُ وَجُنودَهُ فَنَبَذناهُم فِي اليَمِّ وَهُوَ مُليمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdccxvi{وَفي عادٍ إِذ أَرسَلنا عَلَيهِمُ الرّيحَ العَقيمَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdccxvii{ما تَذَرُ مِن شَيءٍ أَتَت عَلَيهِ إِلّا جَعَلَتهُ كَالرَّميمِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdccxviii{وَفي ثَمودَ إِذ قيلَ لَهُم تَمَتَّعوا حَتّىٰ حينٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdccxix{فَعَتَوا عَن أَمرِ رَبِّهِم فَأَخَذَتهُمُ الصّاعِقَةُ وَهُم يَنظُرونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdccxx{فَمَا استَطاعوا مِن قِيامٍ وَما كانوا مُنتَصِرينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdccxxi{وَقَومَ نوحٍ مِن قَبلُ ۖ إِنَّهُم كانوا قَومًا فاسِقينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdccxxii{وَالسَّماءَ بَنَيناها بِأَيدٍ وَإِنّا لَموسِعونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdccxxiii{وَالأَرضَ فَرَشناها فَنِعمَ الماهِدونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdccxxiv{وَمِن كُلِّ شَيءٍ خَلَقنا زَوجَينِ لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdccxxv{فَفِرّوا إِلَى اللَّهِ ۖ إِنّي لَكُم مِنهُ نَذيرٌ مُبينٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmdccxxvi{وَلا تَجعَلوا مَعَ اللَّهِ إِلٰهًا آخَرَ ۖ إِنّي لَكُم مِنهُ نَذيرٌ مُبينٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmdccxxvii{كَذٰلِكَ ما أَتَى الَّذينَ مِن قَبلِهِم مِن رَسولٍ إِلّا قالوا ساحِرٌ أَو مَجنونٌ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmdccxxviii{أَتَواصَوا بِهِ ۚ بَل هُم قَومٌ طاغونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmdccxxix{فَتَوَلَّ عَنهُم فَما أَنتَ بِمَلومٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmdccxxx{وَذَكِّر فَإِنَّ الذِّكرىٰ تَنفَعُ المُؤمِنينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmdccxxxi{وَما خَلَقتُ الجِنَّ وَالإِنسَ إِلّا لِيَعبُدونِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmdccxxxii{ما أُريدُ مِنهُم مِن رِزقٍ وَما أُريدُ أَن يُطعِمونِ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmdccxxxiii{إِنَّ اللَّهَ هُوَ الرَّزّاقُ ذُو القُوَّةِ المَتينُ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmdccxxxiv{فَإِنَّ لِلَّذينَ ظَلَموا ذَنوبًا مِثلَ ذَنوبِ أَصحابِهِم فَلا يَستَعجِلونِ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmdccxxxv{فَوَيلٌ لِلَّذينَ كَفَروا مِن يَومِهِمُ الَّذي يوعَدونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmdccxxxvi{\basmalah وَالطّورِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdccxxxvii{وَكِتابٍ مَسطورٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdccxxxviii{في رَقٍّ مَنشورٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdccxxxix{وَالبَيتِ المَعمورِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdccxl{وَالسَّقفِ المَرفوعِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdccxli{وَالبَحرِ المَسجورِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdccxlii{إِنَّ عَذابَ رَبِّكَ لَواقِعٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdccxliii{ما لَهُ مِن دافِعٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdccxliv{يَومَ تَمورُ السَّماءُ مَورًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdccxlv{وَتَسيرُ الجِبالُ سَيرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdccxlvi{فَوَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdccxlvii{الَّذينَ هُم في خَوضٍ يَلعَبونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdccxlviii{يَومَ يُدَعّونَ إِلىٰ نارِ جَهَنَّمَ دَعًّا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdccxlix{هٰذِهِ النّارُ الَّتي كُنتُم بِها تُكَذِّبونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdccl{أَفَسِحرٌ هٰذا أَم أَنتُم لا تُبصِرونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdccli{اصلَوها فَاصبِروا أَو لا تَصبِروا سَواءٌ عَلَيكُم ۖ إِنَّما تُجزَونَ ما كُنتُم تَعمَلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcclii{إِنَّ المُتَّقينَ في جَنّاتٍ وَنَعيمٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdccliii{فاكِهينَ بِما آتاهُم رَبُّهُم وَوَقاهُم رَبُّهُم عَذابَ الجَحيمِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdccliv{كُلوا وَاشرَبوا هَنيئًا بِما كُنتُم تَعمَلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdcclv{مُتَّكِئينَ عَلىٰ سُرُرٍ مَصفوفَةٍ ۖ وَزَوَّجناهُم بِحورٍ عينٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcclvi{وَالَّذينَ آمَنوا وَاتَّبَعَتهُم ذُرِّيَّتُهُم بِإيمانٍ أَلحَقنا بِهِم ذُرِّيَّتَهُم وَما أَلَتناهُم مِن عَمَلِهِم مِن شَيءٍ ۚ كُلُّ امرِئٍ بِما كَسَبَ رَهينٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcclvii{وَأَمدَدناهُم بِفاكِهَةٍ وَلَحمٍ مِمّا يَشتَهونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcclviii{يَتَنازَعونَ فيها كَأسًا لا لَغوٌ فيها وَلا تَأثيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcclix{۞ وَيَطوفُ عَلَيهِم غِلمانٌ لَهُم كَأَنَّهُم لُؤلُؤٌ مَكنونٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcclx{وَأَقبَلَ بَعضُهُم عَلىٰ بَعضٍ يَتَساءَلونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcclxi{قالوا إِنّا كُنّا قَبلُ في أَهلِنا مُشفِقينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdcclxii{فَمَنَّ اللَّهُ عَلَينا وَوَقانا عَذابَ السَّمومِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcclxiii{إِنّا كُنّا مِن قَبلُ نَدعوهُ ۖ إِنَّهُ هُوَ البَرُّ الرَّحيمُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcclxiv{فَذَكِّر فَما أَنتَ بِنِعمَتِ رَبِّكَ بِكاهِنٍ وَلا مَجنونٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdcclxv{أَم يَقولونَ شاعِرٌ نَتَرَبَّصُ بِهِ رَيبَ المَنونِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdcclxvi{قُل تَرَبَّصوا فَإِنّي مَعَكُم مِنَ المُتَرَبِّصينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdcclxvii{أَم تَأمُرُهُم أَحلامُهُم بِهٰذا ۚ أَم هُم قَومٌ طاغونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdcclxviii{أَم يَقولونَ تَقَوَّلَهُ ۚ بَل لا يُؤمِنونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdcclxix{فَليَأتوا بِحَديثٍ مِثلِهِ إِن كانوا صادِقينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdcclxx{أَم خُلِقوا مِن غَيرِ شَيءٍ أَم هُمُ الخالِقونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdcclxxi{أَم خَلَقُوا السَّماواتِ وَالأَرضَ ۚ بَل لا يوقِنونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdcclxxii{أَم عِندَهُم خَزائِنُ رَبِّكَ أَم هُمُ المُصَيطِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdcclxxiii{أَم لَهُم سُلَّمٌ يَستَمِعونَ فيهِ ۖ فَليَأتِ مُستَمِعُهُم بِسُلطانٍ مُبينٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdcclxxiv{أَم لَهُ البَناتُ وَلَكُمُ البَنونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdcclxxv{أَم تَسأَلُهُم أَجرًا فَهُم مِن مَغرَمٍ مُثقَلونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdcclxxvi{أَم عِندَهُمُ الغَيبُ فَهُم يَكتُبونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdcclxxvii{أَم يُريدونَ كَيدًا ۖ فَالَّذينَ كَفَروا هُمُ المَكيدونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdcclxxviii{أَم لَهُم إِلٰهٌ غَيرُ اللَّهِ ۚ سُبحانَ اللَّهِ عَمّا يُشرِكونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdcclxxix{وَإِن يَرَوا كِسفًا مِنَ السَّماءِ ساقِطًا يَقولوا سَحابٌ مَركومٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdcclxxx{فَذَرهُم حَتّىٰ يُلاقوا يَومَهُمُ الَّذي فيهِ يُصعَقونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxi{يَومَ لا يُغني عَنهُم كَيدُهُم شَيئًا وَلا هُم يُنصَرونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxii{وَإِنَّ لِلَّذينَ ظَلَموا عَذابًا دونَ ذٰلِكَ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxiii{وَاصبِر لِحُكمِ رَبِّكَ فَإِنَّكَ بِأَعيُنِنا ۖ وَسَبِّح بِحَمدِ رَبِّكَ حينَ تَقومُ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxiv{وَمِنَ اللَّيلِ فَسَبِّحهُ وَإِدبارَ النُّجومِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxv{\basmalah وَالنَّجمِ إِذا هَوىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxvi{ما ضَلَّ صاحِبُكُم وَما غَوىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxvii{وَما يَنطِقُ عَنِ الهَوىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxviii{إِن هُوَ إِلّا وَحيٌ يوحىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxix{عَلَّمَهُ شَديدُ القُوىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdccxc{ذو مِرَّةٍ فَاستَوىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdccxci{وَهُوَ بِالأُفُقِ الأَعلىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdccxcii{ثُمَّ دَنا فَتَدَلّىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdccxciii{فَكانَ قابَ قَوسَينِ أَو أَدنىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdccxciv{فَأَوحىٰ إِلىٰ عَبدِهِ ما أَوحىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdccxcv{ما كَذَبَ الفُؤادُ ما رَأىٰ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdccxcvi{أَفَتُمارونَهُ عَلىٰ ما يَرىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdccxcvii{وَلَقَد رَآهُ نَزلَةً أُخرىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdccxcviii{عِندَ سِدرَةِ المُنتَهىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdccxcix{عِندَها جَنَّةُ المَأوىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdccc{إِذ يَغشَى السِّدرَةَ ما يَغشىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdccci{ما زاغَ البَصَرُ وَما طَغىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcccii{لَقَد رَأىٰ مِن آياتِ رَبِّهِ الكُبرىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdccciii{أَفَرَأَيتُمُ اللّاتَ وَالعُزّىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdccciv{وَمَناةَ الثّالِثَةَ الأُخرىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcccv{أَلَكُمُ الذَّكَرُ وَلَهُ الأُنثىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcccvi{تِلكَ إِذًا قِسمَةٌ ضيزىٰ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcccvii{إِن هِيَ إِلّا أَسماءٌ سَمَّيتُموها أَنتُم وَآباؤُكُم ما أَنزَلَ اللَّهُ بِها مِن سُلطانٍ ۚ إِن يَتَّبِعونَ إِلَّا الظَّنَّ وَما تَهوَى الأَنفُسُ ۖ وَلَقَد جاءَهُم مِن رَبِّهِمُ الهُدىٰ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcccviii{أَم لِلإِنسانِ ما تَمَنّىٰ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcccix{فَلِلَّهِ الآخِرَةُ وَالأولىٰ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcccx{۞ وَكَم مِن مَلَكٍ فِي السَّماواتِ لا تُغني شَفاعَتُهُم شَيئًا إِلّا مِن بَعدِ أَن يَأذَنَ اللَّهُ لِمَن يَشاءُ وَيَرضىٰ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxi{إِنَّ الَّذينَ لا يُؤمِنونَ بِالآخِرَةِ لَيُسَمّونَ المَلائِكَةَ تَسمِيَةَ الأُنثىٰ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxii{وَما لَهُم بِهِ مِن عِلمٍ ۖ إِن يَتَّبِعونَ إِلَّا الظَّنَّ ۖ وَإِنَّ الظَّنَّ لا يُغني مِنَ الحَقِّ شَيئًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxiii{فَأَعرِض عَن مَن تَوَلّىٰ عَن ذِكرِنا وَلَم يُرِد إِلَّا الحَياةَ الدُّنيا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxiv{ذٰلِكَ مَبلَغُهُم مِنَ العِلمِ ۚ إِنَّ رَبَّكَ هُوَ أَعلَمُ بِمَن ضَلَّ عَن سَبيلِهِ وَهُوَ أَعلَمُ بِمَنِ اهتَدىٰ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxv{وَلِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ لِيَجزِيَ الَّذينَ أَساءوا بِما عَمِلوا وَيَجزِيَ الَّذينَ أَحسَنوا بِالحُسنَى\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdcccxvi{الَّذينَ يَجتَنِبونَ كَبائِرَ الإِثمِ وَالفَواحِشَ إِلَّا اللَّمَمَ ۚ إِنَّ رَبَّكَ واسِعُ المَغفِرَةِ ۚ هُوَ أَعلَمُ بِكُم إِذ أَنشَأَكُم مِنَ الأَرضِ وَإِذ أَنتُم أَجِنَّةٌ في بُطونِ أُمَّهاتِكُم ۖ فَلا تُزَكّوا أَنفُسَكُم ۖ هُوَ أَعلَمُ بِمَنِ اتَّقىٰ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxvii{أَفَرَأَيتَ الَّذي تَوَلّىٰ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxviii{وَأَعطىٰ قَليلًا وَأَكدىٰ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxix{أَعِندَهُ عِلمُ الغَيبِ فَهُوَ يَرىٰ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxx{أَم لَم يُنَبَّأ بِما في صُحُفِ موسىٰ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxxi{وَإِبراهيمَ الَّذي وَفّىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxxii{أَلّا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxxiii{وَأَن لَيسَ لِلإِنسانِ إِلّا ما سَعىٰ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxxiv{وَأَنَّ سَعيَهُ سَوفَ يُرىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxxv{ثُمَّ يُجزاهُ الجَزاءَ الأَوفىٰ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdcccxxvi{وَأَنَّ إِلىٰ رَبِّكَ المُنتَهىٰ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxxvii{وَأَنَّهُ هُوَ أَضحَكَ وَأَبكىٰ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxxviii{وَأَنَّهُ هُوَ أَماتَ وَأَحيا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxxix{وَأَنَّهُ خَلَقَ الزَّوجَينِ الذَّكَرَ وَالأُنثىٰ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxxx{مِن نُطفَةٍ إِذا تُمنىٰ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxi{وَأَنَّ عَلَيهِ النَّشأَةَ الأُخرىٰ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxii{وَأَنَّهُ هُوَ أَغنىٰ وَأَقنىٰ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxiii{وَأَنَّهُ هُوَ رَبُّ الشِّعرىٰ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxiv{وَأَنَّهُ أَهلَكَ عادًا الأولىٰ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxv{وَثَمودَ فَما أَبقىٰ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxvi{وَقَومَ نوحٍ مِن قَبلُ ۖ إِنَّهُم كانوا هُم أَظلَمَ وَأَطغىٰ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxvii{وَالمُؤتَفِكَةَ أَهوىٰ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxviii{فَغَشّاها ما غَشّىٰ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxix{فَبِأَيِّ آلاءِ رَبِّكَ تَتَمارىٰ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxl{هٰذا نَذيرٌ مِنَ النُّذُرِ الأولىٰ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxli{أَزِفَتِ الآزِفَةُ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxlii{لَيسَ لَها مِن دونِ اللَّهِ كاشِفَةٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxliii{أَفَمِن هٰذَا الحَديثِ تَعجَبونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxliv{وَتَضحَكونَ وَلا تَبكونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxlv{وَأَنتُم سامِدونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmdcccxlvi{فَاسجُدوا لِلَّهِ وَاعبُدوا ۩\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxlvii{\basmalah اقتَرَبَتِ السّاعَةُ وَانشَقَّ القَمَرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcccxlviii{وَإِن يَرَوا آيَةً يُعرِضوا وَيَقولوا سِحرٌ مُستَمِرٌّ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxlix{وَكَذَّبوا وَاتَّبَعوا أَهواءَهُم ۚ وَكُلُّ أَمرٍ مُستَقِرٌّ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcccl{وَلَقَد جاءَهُم مِنَ الأَنباءِ ما فيهِ مُزدَجَرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcccli{حِكمَةٌ بالِغَةٌ ۖ فَما تُغنِ النُّذُرُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdccclii{فَتَوَلَّ عَنهُم ۘ يَومَ يَدعُ الدّاعِ إِلىٰ شَيءٍ نُكُرٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdcccliii{خُشَّعًا أَبصارُهُم يَخرُجونَ مِنَ الأَجداثِ كَأَنَّهُم جَرادٌ مُنتَشِرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdcccliv{مُهطِعينَ إِلَى الدّاعِ ۖ يَقولُ الكافِرونَ هٰذا يَومٌ عَسِرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdccclv{۞ كَذَّبَت قَبلَهُم قَومُ نوحٍ فَكَذَّبوا عَبدَنا وَقالوا مَجنونٌ وَازدُجِرَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdccclvi{فَدَعا رَبَّهُ أَنّي مَغلوبٌ فَانتَصِر\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdccclvii{فَفَتَحنا أَبوابَ السَّماءِ بِماءٍ مُنهَمِرٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdccclviii{وَفَجَّرنَا الأَرضَ عُيونًا فَالتَقَى الماءُ عَلىٰ أَمرٍ قَد قُدِرَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdccclix{وَحَمَلناهُ عَلىٰ ذاتِ أَلواحٍ وَدُسُرٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdccclx{تَجري بِأَعيُنِنا جَزاءً لِمَن كانَ كُفِرَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdccclxi{وَلَقَد تَرَكناها آيَةً فَهَل مِن مُدَّكِرٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdccclxii{فَكَيفَ كانَ عَذابي وَنُذُرِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdccclxiii{وَلَقَد يَسَّرنَا القُرآنَ لِلذِّكرِ فَهَل مِن مُدَّكِرٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdccclxiv{كَذَّبَت عادٌ فَكَيفَ كانَ عَذابي وَنُذُرِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdccclxv{إِنّا أَرسَلنا عَلَيهِم ريحًا صَرصَرًا في يَومِ نَحسٍ مُستَمِرٍّ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdccclxvi{تَنزِعُ النّاسَ كَأَنَّهُم أَعجازُ نَخلٍ مُنقَعِرٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdccclxvii{فَكَيفَ كانَ عَذابي وَنُذُرِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdccclxviii{وَلَقَد يَسَّرنَا القُرآنَ لِلذِّكرِ فَهَل مِن مُدَّكِرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdccclxix{كَذَّبَت ثَمودُ بِالنُّذُرِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdccclxx{فَقالوا أَبَشَرًا مِنّا واحِدًا نَتَّبِعُهُ إِنّا إِذًا لَفي ضَلالٍ وَسُعُرٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdccclxxi{أَأُلقِيَ الذِّكرُ عَلَيهِ مِن بَينِنا بَل هُوَ كَذّابٌ أَشِرٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdccclxxii{سَيَعلَمونَ غَدًا مَنِ الكَذّابُ الأَشِرُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdccclxxiii{إِنّا مُرسِلُو النّاقَةِ فِتنَةً لَهُم فَارتَقِبهُم وَاصطَبِر\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdccclxxiv{وَنَبِّئهُم أَنَّ الماءَ قِسمَةٌ بَينَهُم ۖ كُلُّ شِربٍ مُحتَضَرٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdccclxxv{فَنادَوا صاحِبَهُم فَتَعاطىٰ فَعَقَرَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdccclxxvi{فَكَيفَ كانَ عَذابي وَنُذُرِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdccclxxvii{إِنّا أَرسَلنا عَلَيهِم صَيحَةً واحِدَةً فَكانوا كَهَشيمِ المُحتَظِرِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdccclxxviii{وَلَقَد يَسَّرنَا القُرآنَ لِلذِّكرِ فَهَل مِن مُدَّكِرٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdccclxxix{كَذَّبَت قَومُ لوطٍ بِالنُّذُرِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdccclxxx{إِنّا أَرسَلنا عَلَيهِم حاصِبًا إِلّا آلَ لوطٍ ۖ نَجَّيناهُم بِسَحَرٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxi{نِعمَةً مِن عِندِنا ۚ كَذٰلِكَ نَجزي مَن شَكَرَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxii{وَلَقَد أَنذَرَهُم بَطشَتَنا فَتَمارَوا بِالنُّذُرِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxiii{وَلَقَد راوَدوهُ عَن ضَيفِهِ فَطَمَسنا أَعيُنَهُم فَذوقوا عَذابي وَنُذُرِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxiv{وَلَقَد صَبَّحَهُم بُكرَةً عَذابٌ مُستَقِرٌّ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxv{فَذوقوا عَذابي وَنُذُرِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxvi{وَلَقَد يَسَّرنَا القُرآنَ لِلذِّكرِ فَهَل مِن مُدَّكِرٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxvii{وَلَقَد جاءَ آلَ فِرعَونَ النُّذُرُ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxviii{كَذَّبوا بِآياتِنا كُلِّها فَأَخَذناهُم أَخذَ عَزيزٍ مُقتَدِرٍ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxix{أَكُفّارُكُم خَيرٌ مِن أُولٰئِكُم أَم لَكُم بَراءَةٌ فِي الزُّبُرِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxc{أَم يَقولونَ نَحنُ جَميعٌ مُنتَصِرٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxci{سَيُهزَمُ الجَمعُ وَيُوَلّونَ الدُّبُرَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxcii{بَلِ السّاعَةُ مَوعِدُهُم وَالسّاعَةُ أَدهىٰ وَأَمَرُّ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxciii{إِنَّ المُجرِمينَ في ضَلالٍ وَسُعُرٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxciv{يَومَ يُسحَبونَ فِي النّارِ عَلىٰ وُجوهِهِم ذوقوا مَسَّ سَقَرَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxcv{إِنّا كُلَّ شَيءٍ خَلَقناهُ بِقَدَرٍ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxcvi{وَما أَمرُنا إِلّا واحِدَةٌ كَلَمحٍ بِالبَصَرِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxcvii{وَلَقَد أَهلَكنا أَشياعَكُم فَهَل مِن مُدَّكِرٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmdcccxcviii{وَكُلُّ شَيءٍ فَعَلوهُ فِي الزُّبُرِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxcix{وَكُلُّ صَغيرٍ وَكَبيرٍ مُستَطَرٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcm{إِنَّ المُتَّقينَ في جَنّاتٍ وَنَهَرٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcmi{في مَقعَدِ صِدقٍ عِندَ مَليكٍ مُقتَدِرٍ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcmii{\basmalah الرَّحمٰنُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcmiii{عَلَّمَ القُرآنَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcmiv{خَلَقَ الإِنسانَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcmv{عَلَّمَهُ البَيانَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcmvi{الشَّمسُ وَالقَمَرُ بِحُسبانٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcmvii{وَالنَّجمُ وَالشَّجَرُ يَسجُدانِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcmviii{وَالسَّماءَ رَفَعَها وَوَضَعَ الميزانَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcmix{أَلّا تَطغَوا فِي الميزانِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcmx{وَأَقيمُوا الوَزنَ بِالقِسطِ وَلا تُخسِرُوا الميزانَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcmxi{وَالأَرضَ وَضَعَها لِلأَنامِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcmxii{فيها فاكِهَةٌ وَالنَّخلُ ذاتُ الأَكمامِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcmxiii{وَالحَبُّ ذُو العَصفِ وَالرَّيحانُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcmxiv{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcmxv{خَلَقَ الإِنسانَ مِن صَلصالٍ كَالفَخّارِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcmxvi{وَخَلَقَ الجانَّ مِن مارِجٍ مِن نارٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcmxvii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcmxviii{رَبُّ المَشرِقَينِ وَرَبُّ المَغرِبَينِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcmxix{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcmxx{مَرَجَ البَحرَينِ يَلتَقِيانِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcmxxi{بَينَهُما بَرزَخٌ لا يَبغِيانِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcmxxii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcmxxiii{يَخرُجُ مِنهُمَا اللُّؤلُؤُ وَالمَرجانُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcmxxiv{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcmxxv{وَلَهُ الجَوارِ المُنشَآتُ فِي البَحرِ كَالأَعلامِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcmxxvi{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcmxxvii{كُلُّ مَن عَلَيها فانٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmcmxxviii{وَيَبقىٰ وَجهُ رَبِّكَ ذُو الجَلالِ وَالإِكرامِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmcmxxix{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmcmxxx{يَسأَلُهُ مَن فِي السَّماواتِ وَالأَرضِ ۚ كُلَّ يَومٍ هُوَ في شَأنٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmcmxxxi{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmcmxxxii{سَنَفرُغُ لَكُم أَيُّهَ الثَّقَلانِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmcmxxxiii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmcmxxxiv{يا مَعشَرَ الجِنِّ وَالإِنسِ إِنِ استَطَعتُم أَن تَنفُذوا مِن أَقطارِ السَّماواتِ وَالأَرضِ فَانفُذوا ۚ لا تَنفُذونَ إِلّا بِسُلطانٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcmxxxv{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmcmxxxvi{يُرسَلُ عَلَيكُما شُواظٌ مِن نارٍ وَنُحاسٌ فَلا تَنتَصِرانِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmcmxxxvii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcmxxxviii{فَإِذَا انشَقَّتِ السَّماءُ فَكانَت وَردَةً كَالدِّهانِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcmxxxix{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcmxl{فَيَومَئِذٍ لا يُسأَلُ عَن ذَنبِهِ إِنسٌ وَلا جانٌّ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcmxli{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcmxlii{يُعرَفُ المُجرِمونَ بِسيماهُم فَيُؤخَذُ بِالنَّواصي وَالأَقدامِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcmxliii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcmxliv{هٰذِهِ جَهَنَّمُ الَّتي يُكَذِّبُ بِهَا المُجرِمونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcmxlv{يَطوفونَ بَينَها وَبَينَ حَميمٍ آنٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcmxlvi{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcmxlvii{وَلِمَن خافَ مَقامَ رَبِّهِ جَنَّتانِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcmxlviii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcmxlix{ذَواتا أَفنانٍ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcml{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcmli{فيهِما عَينانِ تَجرِيانِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcmlii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcmliii{فيهِما مِن كُلِّ فاكِهَةٍ زَوجانِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcmliv{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcmlv{مُتَّكِئينَ عَلىٰ فُرُشٍ بَطائِنُها مِن إِستَبرَقٍ ۚ وَجَنَى الجَنَّتَينِ دانٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcmlvi{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcmlvii{فيهِنَّ قاصِراتُ الطَّرفِ لَم يَطمِثهُنَّ إِنسٌ قَبلَهُم وَلا جانٌّ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcmlviii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcmlix{كَأَنَّهُنَّ الياقوتُ وَالمَرجانُ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcmlx{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcmlxi{هَل جَزاءُ الإِحسانِ إِلَّا الإِحسانُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmcmlxii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmcmlxiii{وَمِن دونِهِما جَنَّتانِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmcmlxiv{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmcmlxv{مُدهامَّتانِ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcmlxvi{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcmlxvii{فيهِما عَينانِ نَضّاخَتانِ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcmlxviii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcmlxix{فيهِما فاكِهَةٌ وَنَخلٌ وَرُمّانٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmcmlxx{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcmlxxi{فيهِنَّ خَيراتٌ حِسانٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcmlxxii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmcmlxxiii{حورٌ مَقصوراتٌ فِي الخِيامِ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmcmlxxiv{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmcmlxxv{لَم يَطمِثهُنَّ إِنسٌ قَبلَهُم وَلا جانٌّ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmcmlxxvi{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmcmlxxvii{مُتَّكِئينَ عَلىٰ رَفرَفٍ خُضرٍ وَعَبقَرِيٍّ حِسانٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmcmlxxviii{فَبِأَيِّ آلاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmcmlxxix{تَبارَكَ اسمُ رَبِّكَ ذِي الجَلالِ وَالإِكرامِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmcmlxxx{\basmalah إِذا وَقَعَتِ الواقِعَةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxi{لَيسَ لِوَقعَتِها كاذِبَةٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxii{خافِضَةٌ رافِعَةٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxiii{إِذا رُجَّتِ الأَرضُ رَجًّا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxiv{وَبُسَّتِ الجِبالُ بَسًّا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxv{فَكانَت هَباءً مُنبَثًّا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxvi{وَكُنتُم أَزواجًا ثَلاثَةً\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxvii{فَأَصحابُ المَيمَنَةِ ما أَصحابُ المَيمَنَةِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxviii{وَأَصحابُ المَشأَمَةِ ما أَصحابُ المَشأَمَةِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxix{وَالسّابِقونَ السّابِقونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcmxc{أُولٰئِكَ المُقَرَّبونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcmxci{في جَنّاتِ النَّعيمِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcmxcii{ثُلَّةٌ مِنَ الأَوَّلينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcmxciii{وَقَليلٌ مِنَ الآخِرينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcmxciv{عَلىٰ سُرُرٍ مَوضونَةٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcmxcv{مُتَّكِئينَ عَلَيها مُتَقابِلينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcmxcvi{يَطوفُ عَلَيهِم وِلدانٌ مُخَلَّدونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcmxcvii{بِأَكوابٍ وَأَباريقَ وَكَأسٍ مِن مَعينٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcmxcviii{لا يُصَدَّعونَ عَنها وَلا يُنزِفونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcmxcix{وَفاكِهَةٍ مِمّا يَتَخَيَّرونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmm{وَلَحمِ طَيرٍ مِمّا يَشتَهونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmi{وَحورٌ عينٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmii{كَأَمثالِ اللُّؤلُؤِ المَكنونِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmiii{جَزاءً بِما كانوا يَعمَلونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmiv{لا يَسمَعونَ فيها لَغوًا وَلا تَأثيمًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmv{إِلّا قيلًا سَلامًا سَلامًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmvi{وَأَصحابُ اليَمينِ ما أَصحابُ اليَمينِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmvii{في سِدرٍ مَخضودٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmviii{وَطَلحٍ مَنضودٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmix{وَظِلٍّ مَمدودٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmx{وَماءٍ مَسكوبٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmxi{وَفاكِهَةٍ كَثيرَةٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmxii{لا مَقطوعَةٍ وَلا مَمنوعَةٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmxiii{وَفُرُشٍ مَرفوعَةٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmxiv{إِنّا أَنشَأناهُنَّ إِنشاءً\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmxv{فَجَعَلناهُنَّ أَبكارًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmxvi{عُرُبًا أَترابًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmxvii{لِأَصحابِ اليَمينِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmxviii{ثُلَّةٌ مِنَ الأَوَّلينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmxix{وَثُلَّةٌ مِنَ الآخِرينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmxx{وَأَصحابُ الشِّمالِ ما أَصحابُ الشِّمالِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmxxi{في سَمومٍ وَحَميمٍ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmxxii{وَظِلٍّ مِن يَحمومٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmxxiii{لا بارِدٍ وَلا كَريمٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmxxiv{إِنَّهُم كانوا قَبلَ ذٰلِكَ مُترَفينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmxxv{وَكانوا يُصِرّونَ عَلَى الحِنثِ العَظيمِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmxxvi{وَكانوا يَقولونَ أَئِذا مِتنا وَكُنّا تُرابًا وَعِظامًا أَإِنّا لَمَبعوثونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmxxvii{أَوَآباؤُنَا الأَوَّلونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmxxviii{قُل إِنَّ الأَوَّلينَ وَالآخِرينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmxxix{لَمَجموعونَ إِلىٰ ميقاتِ يَومٍ مَعلومٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmxxx{ثُمَّ إِنَّكُم أَيُّهَا الضّالّونَ المُكَذِّبونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmxxxi{لَآكِلونَ مِن شَجَرٍ مِن زَقّومٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmxxxii{فَمالِئونَ مِنهَا البُطونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmmxxxiii{فَشارِبونَ عَلَيهِ مِنَ الحَميمِ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmmxxxiv{فَشارِبونَ شُربَ الهيمِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmmxxxv{هٰذا نُزُلُهُم يَومَ الدّينِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmmxxxvi{نَحنُ خَلَقناكُم فَلَولا تُصَدِّقونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmmxxxvii{أَفَرَأَيتُم ما تُمنونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmmxxxviii{أَأَنتُم تَخلُقونَهُ أَم نَحنُ الخالِقونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmmxxxix{نَحنُ قَدَّرنا بَينَكُمُ المَوتَ وَما نَحنُ بِمَسبوقينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmmxl{عَلىٰ أَن نُبَدِّلَ أَمثالَكُم وَنُنشِئَكُم في ما لا تَعلَمونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmmxli{وَلَقَد عَلِمتُمُ النَّشأَةَ الأولىٰ فَلَولا تَذَكَّرونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmmxlii{أَفَرَأَيتُم ما تَحرُثونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmmxliii{أَأَنتُم تَزرَعونَهُ أَم نَحنُ الزّارِعونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmmxliv{لَو نَشاءُ لَجَعَلناهُ حُطامًا فَظَلتُم تَفَكَّهونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmmxlv{إِنّا لَمُغرَمونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmmxlvi{بَل نَحنُ مَحرومونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmmxlvii{أَفَرَأَيتُمُ الماءَ الَّذي تَشرَبونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmmxlviii{أَأَنتُم أَنزَلتُموهُ مِنَ المُزنِ أَم نَحنُ المُنزِلونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmmxlix{لَو نَشاءُ جَعَلناهُ أُجاجًا فَلَولا تَشكُرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmml{أَفَرَأَيتُمُ النّارَ الَّتي تورونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmmli{أَأَنتُم أَنشَأتُم شَجَرَتَها أَم نَحنُ المُنشِئونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmmlii{نَحنُ جَعَلناها تَذكِرَةً وَمَتاعًا لِلمُقوينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmmliii{فَسَبِّح بِاسمِ رَبِّكَ العَظيمِ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmmliv{۞ فَلا أُقسِمُ بِمَواقِعِ النُّجومِ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmmlv{وَإِنَّهُ لَقَسَمٌ لَو تَعلَمونَ عَظيمٌ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmmlvi{إِنَّهُ لَقُرآنٌ كَريمٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmmlvii{في كِتابٍ مَكنونٍ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmmlviii{لا يَمَسُّهُ إِلَّا المُطَهَّرونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmmmlix{تَنزيلٌ مِن رَبِّ العالَمينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmmlx{أَفَبِهٰذَا الحَديثِ أَنتُم مُدهِنونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmmlxi{وَتَجعَلونَ رِزقَكُم أَنَّكُم تُكَذِّبونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmmlxii{فَلَولا إِذا بَلَغَتِ الحُلقومَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmmlxiii{وَأَنتُم حينَئِذٍ تَنظُرونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmmlxiv{وَنَحنُ أَقرَبُ إِلَيهِ مِنكُم وَلٰكِن لا تُبصِرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmmlxv{فَلَولا إِن كُنتُم غَيرَ مَدينينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmmmlxvi{تَرجِعونَها إِن كُنتُم صادِقينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmmmlxvii{فَأَمّا إِن كانَ مِنَ المُقَرَّبينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmmmlxviii{فَرَوحٌ وَرَيحانٌ وَجَنَّتُ نَعيمٍ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmmmlxix{وَأَمّا إِن كانَ مِن أَصحابِ اليَمينِ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmmmlxx{فَسَلامٌ لَكَ مِن أَصحابِ اليَمينِ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmmmlxxi{وَأَمّا إِن كانَ مِنَ المُكَذِّبينَ الضّالّينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmmmlxxii{فَنُزُلٌ مِن حَميمٍ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmmmlxxiii{وَتَصلِيَةُ جَحيمٍ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmmmmlxxiv{إِنَّ هٰذا لَهُوَ حَقُّ اليَقينِ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmmmmlxxv{فَسَبِّح بِاسمِ رَبِّكَ العَظيمِ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmmmmlxxvi{\basmalah سَبَّحَ لِلَّهِ ما فِي السَّماواتِ وَالأَرضِ ۖ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmlxxvii{لَهُ مُلكُ السَّماواتِ وَالأَرضِ ۖ يُحيي وَيُميتُ ۖ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmlxxviii{هُوَ الأَوَّلُ وَالآخِرُ وَالظّاهِرُ وَالباطِنُ ۖ وَهُوَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmlxxix{هُوَ الَّذي خَلَقَ السَّماواتِ وَالأَرضَ في سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ ۚ يَعلَمُ ما يَلِجُ فِي الأَرضِ وَما يَخرُجُ مِنها وَما يَنزِلُ مِنَ السَّماءِ وَما يَعرُجُ فيها ۖ وَهُوَ مَعَكُم أَينَ ما كُنتُم ۚ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmlxxx{لَهُ مُلكُ السَّماواتِ وَالأَرضِ ۚ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmlxxxi{يولِجُ اللَّيلَ فِي النَّهارِ وَيولِجُ النَّهارَ فِي اللَّيلِ ۚ وَهُوَ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmlxxxii{آمِنوا بِاللَّهِ وَرَسولِهِ وَأَنفِقوا مِمّا جَعَلَكُم مُستَخلَفينَ فيهِ ۖ فَالَّذينَ آمَنوا مِنكُم وَأَنفَقوا لَهُم أَجرٌ كَبيرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmlxxxiii{وَما لَكُم لا تُؤمِنونَ بِاللَّهِ ۙ وَالرَّسولُ يَدعوكُم لِتُؤمِنوا بِرَبِّكُم وَقَد أَخَذَ ميثاقَكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmlxxxiv{هُوَ الَّذي يُنَزِّلُ عَلىٰ عَبدِهِ آياتٍ بَيِّناتٍ لِيُخرِجَكُم مِنَ الظُّلُماتِ إِلَى النّورِ ۚ وَإِنَّ اللَّهَ بِكُم لَرَءوفٌ رَحيمٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmlxxxv{وَما لَكُم أَلّا تُنفِقوا في سَبيلِ اللَّهِ وَلِلَّهِ ميراثُ السَّماواتِ وَالأَرضِ ۚ لا يَستَوي مِنكُم مَن أَنفَقَ مِن قَبلِ الفَتحِ وَقاتَلَ ۚ أُولٰئِكَ أَعظَمُ دَرَجَةً مِنَ الَّذينَ أَنفَقوا مِن بَعدُ وَقاتَلوا ۚ وَكُلًّا وَعَدَ اللَّهُ الحُسنىٰ ۚ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmlxxxvi{مَن ذَا الَّذي يُقرِضُ اللَّهَ قَرضًا حَسَنًا فَيُضاعِفَهُ لَهُ وَلَهُ أَجرٌ كَريمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmlxxxvii{يَومَ تَرَى المُؤمِنينَ وَالمُؤمِناتِ يَسعىٰ نورُهُم بَينَ أَيديهِم وَبِأَيمانِهِم بُشراكُمُ اليَومَ جَنّاتٌ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها ۚ ذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmlxxxviii{يَومَ يَقولُ المُنافِقونَ وَالمُنافِقاتُ لِلَّذينَ آمَنُوا انظُرونا نَقتَبِس مِن نورِكُم قيلَ ارجِعوا وَراءَكُم فَالتَمِسوا نورًا فَضُرِبَ بَينَهُم بِسورٍ لَهُ بابٌ باطِنُهُ فيهِ الرَّحمَةُ وَظاهِرُهُ مِن قِبَلِهِ العَذابُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmlxxxix{يُنادونَهُم أَلَم نَكُن مَعَكُم ۖ قالوا بَلىٰ وَلٰكِنَّكُم فَتَنتُم أَنفُسَكُم وَتَرَبَّصتُم وَارتَبتُم وَغَرَّتكُمُ الأَمانِيُّ حَتّىٰ جاءَ أَمرُ اللَّهِ وَغَرَّكُم بِاللَّهِ الغَرورُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmxc{فَاليَومَ لا يُؤخَذُ مِنكُم فِديَةٌ وَلا مِنَ الَّذينَ كَفَروا ۚ مَأواكُمُ النّارُ ۖ هِيَ مَولاكُم ۖ وَبِئسَ المَصيرُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmxci{۞ أَلَم يَأنِ لِلَّذينَ آمَنوا أَن تَخشَعَ قُلوبُهُم لِذِكرِ اللَّهِ وَما نَزَلَ مِنَ الحَقِّ وَلا يَكونوا كَالَّذينَ أوتُوا الكِتابَ مِن قَبلُ فَطالَ عَلَيهِمُ الأَمَدُ فَقَسَت قُلوبُهُم ۖ وَكَثيرٌ مِنهُم فاسِقونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmxcii{اعلَموا أَنَّ اللَّهَ يُحيِي الأَرضَ بَعدَ مَوتِها ۚ قَد بَيَّنّا لَكُمُ الآياتِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmxciii{إِنَّ المُصَّدِّقينَ وَالمُصَّدِّقاتِ وَأَقرَضُوا اللَّهَ قَرضًا حَسَنًا يُضاعَفُ لَهُم وَلَهُم أَجرٌ كَريمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmxciv{وَالَّذينَ آمَنوا بِاللَّهِ وَرُسُلِهِ أُولٰئِكَ هُمُ الصِّدّيقونَ ۖ وَالشُّهَداءُ عِندَ رَبِّهِم لَهُم أَجرُهُم وَنورُهُم ۖ وَالَّذينَ كَفَروا وَكَذَّبوا بِآياتِنا أُولٰئِكَ أَصحابُ الجَحيمِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmxcv{اعلَموا أَنَّمَا الحَياةُ الدُّنيا لَعِبٌ وَلَهوٌ وَزينَةٌ وَتَفاخُرٌ بَينَكُم وَتَكاثُرٌ فِي الأَموالِ وَالأَولادِ ۖ كَمَثَلِ غَيثٍ أَعجَبَ الكُفّارَ نَباتُهُ ثُمَّ يَهيجُ فَتَراهُ مُصفَرًّا ثُمَّ يَكونُ حُطامًا ۖ وَفِي الآخِرَةِ عَذابٌ شَديدٌ وَمَغفِرَةٌ مِنَ اللَّهِ وَرِضوانٌ ۚ وَمَا الحَياةُ الدُّنيا إِلّا مَتاعُ الغُرورِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmxcvi{سابِقوا إِلىٰ مَغفِرَةٍ مِن رَبِّكُم وَجَنَّةٍ عَرضُها كَعَرضِ السَّماءِ وَالأَرضِ أُعِدَّت لِلَّذينَ آمَنوا بِاللَّهِ وَرُسُلِهِ ۚ ذٰلِكَ فَضلُ اللَّهِ يُؤتيهِ مَن يَشاءُ ۚ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmxcvii{ما أَصابَ مِن مُصيبَةٍ فِي الأَرضِ وَلا في أَنفُسِكُم إِلّا في كِتابٍ مِن قَبلِ أَن نَبرَأَها ۚ إِنَّ ذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmxcviii{لِكَيلا تَأسَوا عَلىٰ ما فاتَكُم وَلا تَفرَحوا بِما آتاكُم ۗ وَاللَّهُ لا يُحِبُّ كُلَّ مُختالٍ فَخورٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmxcix{الَّذينَ يَبخَلونَ وَيَأمُرونَ النّاسَ بِالبُخلِ ۗ وَمَن يَتَوَلَّ فَإِنَّ اللَّهَ هُوَ الغَنِيُّ الحَميدُ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmc{لَقَد أَرسَلنا رُسُلَنا بِالبَيِّناتِ وَأَنزَلنا مَعَهُمُ الكِتابَ وَالميزانَ لِيَقومَ النّاسُ بِالقِسطِ ۖ وَأَنزَلنَا الحَديدَ فيهِ بَأسٌ شَديدٌ وَمَنافِعُ لِلنّاسِ وَلِيَعلَمَ اللَّهُ مَن يَنصُرُهُ وَرُسُلَهُ بِالغَيبِ ۚ إِنَّ اللَّهَ قَوِيٌّ عَزيزٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmci{وَلَقَد أَرسَلنا نوحًا وَإِبراهيمَ وَجَعَلنا في ذُرِّيَّتِهِمَا النُّبُوَّةَ وَالكِتابَ ۖ فَمِنهُم مُهتَدٍ ۖ وَكَثيرٌ مِنهُم فاسِقونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcii{ثُمَّ قَفَّينا عَلىٰ آثارِهِم بِرُسُلِنا وَقَفَّينا بِعيسَى ابنِ مَريَمَ وَآتَيناهُ الإِنجيلَ وَجَعَلنا في قُلوبِ الَّذينَ اتَّبَعوهُ رَأفَةً وَرَحمَةً وَرَهبانِيَّةً ابتَدَعوها ما كَتَبناها عَلَيهِم إِلَّا ابتِغاءَ رِضوانِ اللَّهِ فَما رَعَوها حَقَّ رِعايَتِها ۖ فَآتَينَا الَّذينَ آمَنوا مِنهُم أَجرَهُم ۖ وَكَثيرٌ مِنهُم فاسِقونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmciii{يا أَيُّهَا الَّذينَ آمَنُوا اتَّقُوا اللَّهَ وَآمِنوا بِرَسولِهِ يُؤتِكُم كِفلَينِ مِن رَحمَتِهِ وَيَجعَل لَكُم نورًا تَمشونَ بِهِ وَيَغفِر لَكُم ۚ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmciv{لِئَلّا يَعلَمَ أَهلُ الكِتابِ أَلّا يَقدِرونَ عَلىٰ شَيءٍ مِن فَضلِ اللَّهِ ۙ وَأَنَّ الفَضلَ بِيَدِ اللَّهِ يُؤتيهِ مَن يَشاءُ ۚ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcv{\basmalah قَد سَمِعَ اللَّهُ قَولَ الَّتي تُجادِلُكَ في زَوجِها وَتَشتَكي إِلَى اللَّهِ وَاللَّهُ يَسمَعُ تَحاوُرَكُما ۚ إِنَّ اللَّهَ سَميعٌ بَصيرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcvi{الَّذينَ يُظاهِرونَ مِنكُم مِن نِسائِهِم ما هُنَّ أُمَّهاتِهِم ۖ إِن أُمَّهاتُهُم إِلَّا اللّائي وَلَدنَهُم ۚ وَإِنَّهُم لَيَقولونَ مُنكَرًا مِنَ القَولِ وَزورًا ۚ وَإِنَّ اللَّهَ لَعَفُوٌّ غَفورٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcvii{وَالَّذينَ يُظاهِرونَ مِن نِسائِهِم ثُمَّ يَعودونَ لِما قالوا فَتَحريرُ رَقَبَةٍ مِن قَبلِ أَن يَتَماسّا ۚ ذٰلِكُم توعَظونَ بِهِ ۚ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcviii{فَمَن لَم يَجِد فَصِيامُ شَهرَينِ مُتَتابِعَينِ مِن قَبلِ أَن يَتَماسّا ۖ فَمَن لَم يَستَطِع فَإِطعامُ سِتّينَ مِسكينًا ۚ ذٰلِكَ لِتُؤمِنوا بِاللَّهِ وَرَسولِهِ ۚ وَتِلكَ حُدودُ اللَّهِ ۗ وَلِلكافِرينَ عَذابٌ أَليمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcix{إِنَّ الَّذينَ يُحادّونَ اللَّهَ وَرَسولَهُ كُبِتوا كَما كُبِتَ الَّذينَ مِن قَبلِهِم ۚ وَقَد أَنزَلنا آياتٍ بَيِّناتٍ ۚ وَلِلكافِرينَ عَذابٌ مُهينٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcx{يَومَ يَبعَثُهُمُ اللَّهُ جَميعًا فَيُنَبِّئُهُم بِما عَمِلوا ۚ أَحصاهُ اللَّهُ وَنَسوهُ ۚ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcxi{أَلَم تَرَ أَنَّ اللَّهَ يَعلَمُ ما فِي السَّماواتِ وَما فِي الأَرضِ ۖ ما يَكونُ مِن نَجوىٰ ثَلاثَةٍ إِلّا هُوَ رابِعُهُم وَلا خَمسَةٍ إِلّا هُوَ سادِسُهُم وَلا أَدنىٰ مِن ذٰلِكَ وَلا أَكثَرَ إِلّا هُوَ مَعَهُم أَينَ ما كانوا ۖ ثُمَّ يُنَبِّئُهُم بِما عَمِلوا يَومَ القِيامَةِ ۚ إِنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcxii{أَلَم تَرَ إِلَى الَّذينَ نُهوا عَنِ النَّجوىٰ ثُمَّ يَعودونَ لِما نُهوا عَنهُ وَيَتَناجَونَ بِالإِثمِ وَالعُدوانِ وَمَعصِيَتِ الرَّسولِ وَإِذا جاءوكَ حَيَّوكَ بِما لَم يُحَيِّكَ بِهِ اللَّهُ وَيَقولونَ في أَنفُسِهِم لَولا يُعَذِّبُنَا اللَّهُ بِما نَقولُ ۚ حَسبُهُم جَهَنَّمُ يَصلَونَها ۖ فَبِئسَ المَصيرُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcxiii{يا أَيُّهَا الَّذينَ آمَنوا إِذا تَناجَيتُم فَلا تَتَناجَوا بِالإِثمِ وَالعُدوانِ وَمَعصِيَتِ الرَّسولِ وَتَناجَوا بِالبِرِّ وَالتَّقوىٰ ۖ وَاتَّقُوا اللَّهَ الَّذي إِلَيهِ تُحشَرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcxiv{إِنَّمَا النَّجوىٰ مِنَ الشَّيطانِ لِيَحزُنَ الَّذينَ آمَنوا وَلَيسَ بِضارِّهِم شَيئًا إِلّا بِإِذنِ اللَّهِ ۚ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcxv{يا أَيُّهَا الَّذينَ آمَنوا إِذا قيلَ لَكُم تَفَسَّحوا فِي المَجالِسِ فَافسَحوا يَفسَحِ اللَّهُ لَكُم ۖ وَإِذا قيلَ انشُزوا فَانشُزوا يَرفَعِ اللَّهُ الَّذينَ آمَنوا مِنكُم وَالَّذينَ أوتُوا العِلمَ دَرَجاتٍ ۚ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcxvi{يا أَيُّهَا الَّذينَ آمَنوا إِذا ناجَيتُمُ الرَّسولَ فَقَدِّموا بَينَ يَدَي نَجواكُم صَدَقَةً ۚ ذٰلِكَ خَيرٌ لَكُم وَأَطهَرُ ۚ فَإِن لَم تَجِدوا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcxvii{أَأَشفَقتُم أَن تُقَدِّموا بَينَ يَدَي نَجواكُم صَدَقاتٍ ۚ فَإِذ لَم تَفعَلوا وَتابَ اللَّهُ عَلَيكُم فَأَقيمُوا الصَّلاةَ وَآتُوا الزَّكاةَ وَأَطيعُوا اللَّهَ وَرَسولَهُ ۚ وَاللَّهُ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcxviii{۞ أَلَم تَرَ إِلَى الَّذينَ تَوَلَّوا قَومًا غَضِبَ اللَّهُ عَلَيهِم ما هُم مِنكُم وَلا مِنهُم وَيَحلِفونَ عَلَى الكَذِبِ وَهُم يَعلَمونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcxix{أَعَدَّ اللَّهُ لَهُم عَذابًا شَديدًا ۖ إِنَّهُم ساءَ ما كانوا يَعمَلونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcxx{اتَّخَذوا أَيمانَهُم جُنَّةً فَصَدّوا عَن سَبيلِ اللَّهِ فَلَهُم عَذابٌ مُهينٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcxxi{لَن تُغنِيَ عَنهُم أَموالُهُم وَلا أَولادُهُم مِنَ اللَّهِ شَيئًا ۚ أُولٰئِكَ أَصحابُ النّارِ ۖ هُم فيها خالِدونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcxxii{يَومَ يَبعَثُهُمُ اللَّهُ جَميعًا فَيَحلِفونَ لَهُ كَما يَحلِفونَ لَكُم ۖ وَيَحسَبونَ أَنَّهُم عَلىٰ شَيءٍ ۚ أَلا إِنَّهُم هُمُ الكاذِبونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcxxiii{استَحوَذَ عَلَيهِمُ الشَّيطانُ فَأَنساهُم ذِكرَ اللَّهِ ۚ أُولٰئِكَ حِزبُ الشَّيطانِ ۚ أَلا إِنَّ حِزبَ الشَّيطانِ هُمُ الخاسِرونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcxxiv{إِنَّ الَّذينَ يُحادّونَ اللَّهَ وَرَسولَهُ أُولٰئِكَ فِي الأَذَلّينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcxxv{كَتَبَ اللَّهُ لَأَغلِبَنَّ أَنا وَرُسُلي ۚ إِنَّ اللَّهَ قَوِيٌّ عَزيزٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcxxvi{لا تَجِدُ قَومًا يُؤمِنونَ بِاللَّهِ وَاليَومِ الآخِرِ يُوادّونَ مَن حادَّ اللَّهَ وَرَسولَهُ وَلَو كانوا آباءَهُم أَو أَبناءَهُم أَو إِخوانَهُم أَو عَشيرَتَهُم ۚ أُولٰئِكَ كَتَبَ في قُلوبِهِمُ الإيمانَ وَأَيَّدَهُم بِروحٍ مِنهُ ۖ وَيُدخِلُهُم جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها ۚ رَضِيَ اللَّهُ عَنهُم وَرَضوا عَنهُ ۚ أُولٰئِكَ حِزبُ اللَّهِ ۚ أَلا إِنَّ حِزبَ اللَّهِ هُمُ المُفلِحونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcxxvii{\basmalah سَبَّحَ لِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۖ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcxxviii{هُوَ الَّذي أَخرَجَ الَّذينَ كَفَروا مِن أَهلِ الكِتابِ مِن دِيارِهِم لِأَوَّلِ الحَشرِ ۚ ما ظَنَنتُم أَن يَخرُجوا ۖ وَظَنّوا أَنَّهُم مانِعَتُهُم حُصونُهُم مِنَ اللَّهِ فَأَتاهُمُ اللَّهُ مِن حَيثُ لَم يَحتَسِبوا ۖ وَقَذَفَ في قُلوبِهِمُ الرُّعبَ ۚ يُخرِبونَ بُيوتَهُم بِأَيديهِم وَأَيدِي المُؤمِنينَ فَاعتَبِروا يا أُولِي الأَبصارِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcxxix{وَلَولا أَن كَتَبَ اللَّهُ عَلَيهِمُ الجَلاءَ لَعَذَّبَهُم فِي الدُّنيا ۖ وَلَهُم فِي الآخِرَةِ عَذابُ النّارِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcxxx{ذٰلِكَ بِأَنَّهُم شاقُّوا اللَّهَ وَرَسولَهُ ۖ وَمَن يُشاقِّ اللَّهَ فَإِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcxxxi{ما قَطَعتُم مِن لينَةٍ أَو تَرَكتُموها قائِمَةً عَلىٰ أُصولِها فَبِإِذنِ اللَّهِ وَلِيُخزِيَ الفاسِقينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcxxxii{وَما أَفاءَ اللَّهُ عَلىٰ رَسولِهِ مِنهُم فَما أَوجَفتُم عَلَيهِ مِن خَيلٍ وَلا رِكابٍ وَلٰكِنَّ اللَّهَ يُسَلِّطُ رُسُلَهُ عَلىٰ مَن يَشاءُ ۚ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcxxxiii{ما أَفاءَ اللَّهُ عَلىٰ رَسولِهِ مِن أَهلِ القُرىٰ فَلِلَّهِ وَلِلرَّسولِ وَلِذِي القُربىٰ وَاليَتامىٰ وَالمَساكينِ وَابنِ السَّبيلِ كَي لا يَكونَ دولَةً بَينَ الأَغنِياءِ مِنكُم ۚ وَما آتاكُمُ الرَّسولُ فَخُذوهُ وَما نَهاكُم عَنهُ فَانتَهوا ۚ وَاتَّقُوا اللَّهَ ۖ إِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcxxxiv{لِلفُقَراءِ المُهاجِرينَ الَّذينَ أُخرِجوا مِن دِيارِهِم وَأَموالِهِم يَبتَغونَ فَضلًا مِنَ اللَّهِ وَرِضوانًا وَيَنصُرونَ اللَّهَ وَرَسولَهُ ۚ أُولٰئِكَ هُمُ الصّادِقونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcxxxv{وَالَّذينَ تَبَوَّءُوا الدّارَ وَالإيمانَ مِن قَبلِهِم يُحِبّونَ مَن هاجَرَ إِلَيهِم وَلا يَجِدونَ في صُدورِهِم حاجَةً مِمّا أوتوا وَيُؤثِرونَ عَلىٰ أَنفُسِهِم وَلَو كانَ بِهِم خَصاصَةٌ ۚ وَمَن يوقَ شُحَّ نَفسِهِ فَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcxxxvi{وَالَّذينَ جاءوا مِن بَعدِهِم يَقولونَ رَبَّنَا اغفِر لَنا وَلِإِخوانِنَا الَّذينَ سَبَقونا بِالإيمانِ وَلا تَجعَل في قُلوبِنا غِلًّا لِلَّذينَ آمَنوا رَبَّنا إِنَّكَ رَءوفٌ رَحيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcxxxvii{۞ أَلَم تَرَ إِلَى الَّذينَ نافَقوا يَقولونَ لِإِخوانِهِمُ الَّذينَ كَفَروا مِن أَهلِ الكِتابِ لَئِن أُخرِجتُم لَنَخرُجَنَّ مَعَكُم وَلا نُطيعُ فيكُم أَحَدًا أَبَدًا وَإِن قوتِلتُم لَنَنصُرَنَّكُم وَاللَّهُ يَشهَدُ إِنَّهُم لَكاذِبونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcxxxviii{لَئِن أُخرِجوا لا يَخرُجونَ مَعَهُم وَلَئِن قوتِلوا لا يَنصُرونَهُم وَلَئِن نَصَروهُم لَيُوَلُّنَّ الأَدبارَ ثُمَّ لا يُنصَرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcxxxix{لَأَنتُم أَشَدُّ رَهبَةً في صُدورِهِم مِنَ اللَّهِ ۚ ذٰلِكَ بِأَنَّهُم قَومٌ لا يَفقَهونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcxl{لا يُقاتِلونَكُم جَميعًا إِلّا في قُرًى مُحَصَّنَةٍ أَو مِن وَراءِ جُدُرٍ ۚ بَأسُهُم بَينَهُم شَديدٌ ۚ تَحسَبُهُم جَميعًا وَقُلوبُهُم شَتّىٰ ۚ ذٰلِكَ بِأَنَّهُم قَومٌ لا يَعقِلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcxli{كَمَثَلِ الَّذينَ مِن قَبلِهِم قَريبًا ۖ ذاقوا وَبالَ أَمرِهِم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcxlii{كَمَثَلِ الشَّيطانِ إِذ قالَ لِلإِنسانِ اكفُر فَلَمّا كَفَرَ قالَ إِنّي بَريءٌ مِنكَ إِنّي أَخافُ اللَّهَ رَبَّ العالَمينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcxliii{فَكانَ عاقِبَتَهُما أَنَّهُما فِي النّارِ خالِدَينِ فيها ۚ وَذٰلِكَ جَزاءُ الظّالِمينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcxliv{يا أَيُّهَا الَّذينَ آمَنُوا اتَّقُوا اللَّهَ وَلتَنظُر نَفسٌ ما قَدَّمَت لِغَدٍ ۖ وَاتَّقُوا اللَّهَ ۚ إِنَّ اللَّهَ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcxlv{وَلا تَكونوا كَالَّذينَ نَسُوا اللَّهَ فَأَنساهُم أَنفُسَهُم ۚ أُولٰئِكَ هُمُ الفاسِقونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcxlvi{لا يَستَوي أَصحابُ النّارِ وَأَصحابُ الجَنَّةِ ۚ أَصحابُ الجَنَّةِ هُمُ الفائِزونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcxlvii{لَو أَنزَلنا هٰذَا القُرآنَ عَلىٰ جَبَلٍ لَرَأَيتَهُ خاشِعًا مُتَصَدِّعًا مِن خَشيَةِ اللَّهِ ۚ وَتِلكَ الأَمثالُ نَضرِبُها لِلنّاسِ لَعَلَّهُم يَتَفَكَّرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcxlviii{هُوَ اللَّهُ الَّذي لا إِلٰهَ إِلّا هُوَ ۖ عالِمُ الغَيبِ وَالشَّهادَةِ ۖ هُوَ الرَّحمٰنُ الرَّحيمُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcxlix{هُوَ اللَّهُ الَّذي لا إِلٰهَ إِلّا هُوَ المَلِكُ القُدّوسُ السَّلامُ المُؤمِنُ المُهَيمِنُ العَزيزُ الجَبّارُ المُتَكَبِّرُ ۚ سُبحانَ اللَّهِ عَمّا يُشرِكونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcl{هُوَ اللَّهُ الخالِقُ البارِئُ المُصَوِّرُ ۖ لَهُ الأَسماءُ الحُسنىٰ ۚ يُسَبِّحُ لَهُ ما فِي السَّماواتِ وَالأَرضِ ۖ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcli{\basmalah يا أَيُّهَا الَّذينَ آمَنوا لا تَتَّخِذوا عَدُوّي وَعَدُوَّكُم أَولِياءَ تُلقونَ إِلَيهِم بِالمَوَدَّةِ وَقَد كَفَروا بِما جاءَكُم مِنَ الحَقِّ يُخرِجونَ الرَّسولَ وَإِيّاكُم ۙ أَن تُؤمِنوا بِاللَّهِ رَبِّكُم إِن كُنتُم خَرَجتُم جِهادًا في سَبيلي وَابتِغاءَ مَرضاتي ۚ تُسِرّونَ إِلَيهِم بِالمَوَدَّةِ وَأَنا أَعلَمُ بِما أَخفَيتُم وَما أَعلَنتُم ۚ وَمَن يَفعَلهُ مِنكُم فَقَد ضَلَّ سَواءَ السَّبيلِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmclii{إِن يَثقَفوكُم يَكونوا لَكُم أَعداءً وَيَبسُطوا إِلَيكُم أَيدِيَهُم وَأَلسِنَتَهُم بِالسّوءِ وَوَدّوا لَو تَكفُرونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcliii{لَن تَنفَعَكُم أَرحامُكُم وَلا أَولادُكُم ۚ يَومَ القِيامَةِ يَفصِلُ بَينَكُم ۚ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcliv{قَد كانَت لَكُم أُسوَةٌ حَسَنَةٌ في إِبراهيمَ وَالَّذينَ مَعَهُ إِذ قالوا لِقَومِهِم إِنّا بُرَآءُ مِنكُم وَمِمّا تَعبُدونَ مِن دونِ اللَّهِ كَفَرنا بِكُم وَبَدا بَينَنا وَبَينَكُمُ العَداوَةُ وَالبَغضاءُ أَبَدًا حَتّىٰ تُؤمِنوا بِاللَّهِ وَحدَهُ إِلّا قَولَ إِبراهيمَ لِأَبيهِ لَأَستَغفِرَنَّ لَكَ وَما أَملِكُ لَكَ مِنَ اللَّهِ مِن شَيءٍ ۖ رَبَّنا عَلَيكَ تَوَكَّلنا وَإِلَيكَ أَنَبنا وَإِلَيكَ المَصيرُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmclv{رَبَّنا لا تَجعَلنا فِتنَةً لِلَّذينَ كَفَروا وَاغفِر لَنا رَبَّنا ۖ إِنَّكَ أَنتَ العَزيزُ الحَكيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmclvi{لَقَد كانَ لَكُم فيهِم أُسوَةٌ حَسَنَةٌ لِمَن كانَ يَرجُو اللَّهَ وَاليَومَ الآخِرَ ۚ وَمَن يَتَوَلَّ فَإِنَّ اللَّهَ هُوَ الغَنِيُّ الحَميدُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmclvii{۞ عَسَى اللَّهُ أَن يَجعَلَ بَينَكُم وَبَينَ الَّذينَ عادَيتُم مِنهُم مَوَدَّةً ۚ وَاللَّهُ قَديرٌ ۚ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmclviii{لا يَنهاكُمُ اللَّهُ عَنِ الَّذينَ لَم يُقاتِلوكُم فِي الدّينِ وَلَم يُخرِجوكُم مِن دِيارِكُم أَن تَبَرّوهُم وَتُقسِطوا إِلَيهِم ۚ إِنَّ اللَّهَ يُحِبُّ المُقسِطينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmclix{إِنَّما يَنهاكُمُ اللَّهُ عَنِ الَّذينَ قاتَلوكُم فِي الدّينِ وَأَخرَجوكُم مِن دِيارِكُم وَظاهَروا عَلىٰ إِخراجِكُم أَن تَوَلَّوهُم ۚ وَمَن يَتَوَلَّهُم فَأُولٰئِكَ هُمُ الظّالِمونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmclx{يا أَيُّهَا الَّذينَ آمَنوا إِذا جاءَكُمُ المُؤمِناتُ مُهاجِراتٍ فَامتَحِنوهُنَّ ۖ اللَّهُ أَعلَمُ بِإيمانِهِنَّ ۖ فَإِن عَلِمتُموهُنَّ مُؤمِناتٍ فَلا تَرجِعوهُنَّ إِلَى الكُفّارِ ۖ لا هُنَّ حِلٌّ لَهُم وَلا هُم يَحِلّونَ لَهُنَّ ۖ وَآتوهُم ما أَنفَقوا ۚ وَلا جُناحَ عَلَيكُم أَن تَنكِحوهُنَّ إِذا آتَيتُموهُنَّ أُجورَهُنَّ ۚ وَلا تُمسِكوا بِعِصَمِ الكَوافِرِ وَاسأَلوا ما أَنفَقتُم وَليَسأَلوا ما أَنفَقوا ۚ ذٰلِكُم حُكمُ اللَّهِ ۖ يَحكُمُ بَينَكُم ۚ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmclxi{وَإِن فاتَكُم شَيءٌ مِن أَزواجِكُم إِلَى الكُفّارِ فَعاقَبتُم فَآتُوا الَّذينَ ذَهَبَت أَزواجُهُم مِثلَ ما أَنفَقوا ۚ وَاتَّقُوا اللَّهَ الَّذي أَنتُم بِهِ مُؤمِنونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmclxii{يا أَيُّهَا النَّبِيُّ إِذا جاءَكَ المُؤمِناتُ يُبايِعنَكَ عَلىٰ أَن لا يُشرِكنَ بِاللَّهِ شَيئًا وَلا يَسرِقنَ وَلا يَزنينَ وَلا يَقتُلنَ أَولادَهُنَّ وَلا يَأتينَ بِبُهتانٍ يَفتَرينَهُ بَينَ أَيديهِنَّ وَأَرجُلِهِنَّ وَلا يَعصينَكَ في مَعروفٍ ۙ فَبايِعهُنَّ وَاستَغفِر لَهُنَّ اللَّهَ ۖ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmclxiii{يا أَيُّهَا الَّذينَ آمَنوا لا تَتَوَلَّوا قَومًا غَضِبَ اللَّهُ عَلَيهِم قَد يَئِسوا مِنَ الآخِرَةِ كَما يَئِسَ الكُفّارُ مِن أَصحابِ القُبورِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmclxiv{\basmalah سَبَّحَ لِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۖ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmclxv{يا أَيُّهَا الَّذينَ آمَنوا لِمَ تَقولونَ ما لا تَفعَلونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmclxvi{كَبُرَ مَقتًا عِندَ اللَّهِ أَن تَقولوا ما لا تَفعَلونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmclxvii{إِنَّ اللَّهَ يُحِبُّ الَّذينَ يُقاتِلونَ في سَبيلِهِ صَفًّا كَأَنَّهُم بُنيانٌ مَرصوصٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmclxviii{وَإِذ قالَ موسىٰ لِقَومِهِ يا قَومِ لِمَ تُؤذونَني وَقَد تَعلَمونَ أَنّي رَسولُ اللَّهِ إِلَيكُم ۖ فَلَمّا زاغوا أَزاغَ اللَّهُ قُلوبَهُم ۚ وَاللَّهُ لا يَهدِي القَومَ الفاسِقينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmclxix{وَإِذ قالَ عيسَى ابنُ مَريَمَ يا بَني إِسرائيلَ إِنّي رَسولُ اللَّهِ إِلَيكُم مُصَدِّقًا لِما بَينَ يَدَيَّ مِنَ التَّوراةِ وَمُبَشِّرًا بِرَسولٍ يَأتي مِن بَعدِي اسمُهُ أَحمَدُ ۖ فَلَمّا جاءَهُم بِالبَيِّناتِ قالوا هٰذا سِحرٌ مُبينٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmclxx{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ الكَذِبَ وَهُوَ يُدعىٰ إِلَى الإِسلامِ ۚ وَاللَّهُ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmclxxi{يُريدونَ لِيُطفِئوا نورَ اللَّهِ بِأَفواهِهِم وَاللَّهُ مُتِمُّ نورِهِ وَلَو كَرِهَ الكافِرونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmclxxii{هُوَ الَّذي أَرسَلَ رَسولَهُ بِالهُدىٰ وَدينِ الحَقِّ لِيُظهِرَهُ عَلَى الدّينِ كُلِّهِ وَلَو كَرِهَ المُشرِكونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmclxxiii{يا أَيُّهَا الَّذينَ آمَنوا هَل أَدُلُّكُم عَلىٰ تِجارَةٍ تُنجيكُم مِن عَذابٍ أَليمٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmclxxiv{تُؤمِنونَ بِاللَّهِ وَرَسولِهِ وَتُجاهِدونَ في سَبيلِ اللَّهِ بِأَموالِكُم وَأَنفُسِكُم ۚ ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmclxxv{يَغفِر لَكُم ذُنوبَكُم وَيُدخِلكُم جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ وَمَساكِنَ طَيِّبَةً في جَنّاتِ عَدنٍ ۚ ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmclxxvi{وَأُخرىٰ تُحِبّونَها ۖ نَصرٌ مِنَ اللَّهِ وَفَتحٌ قَريبٌ ۗ وَبَشِّرِ المُؤمِنينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmclxxvii{يا أَيُّهَا الَّذينَ آمَنوا كونوا أَنصارَ اللَّهِ كَما قالَ عيسَى ابنُ مَريَمَ لِلحَوارِيّينَ مَن أَنصاري إِلَى اللَّهِ ۖ قالَ الحَوارِيّونَ نَحنُ أَنصارُ اللَّهِ ۖ فَآمَنَت طائِفَةٌ مِن بَني إِسرائيلَ وَكَفَرَت طائِفَةٌ ۖ فَأَيَّدنَا الَّذينَ آمَنوا عَلىٰ عَدُوِّهِم فَأَصبَحوا ظاهِرينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmclxxviii{\basmalah يُسَبِّحُ لِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ المَلِكِ القُدّوسِ العَزيزِ الحَكيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmclxxix{هُوَ الَّذي بَعَثَ فِي الأُمِّيّينَ رَسولًا مِنهُم يَتلو عَلَيهِم آياتِهِ وَيُزَكّيهِم وَيُعَلِّمُهُمُ الكِتابَ وَالحِكمَةَ وَإِن كانوا مِن قَبلُ لَفي ضَلالٍ مُبينٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmclxxx{وَآخَرينَ مِنهُم لَمّا يَلحَقوا بِهِم ۚ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmclxxxi{ذٰلِكَ فَضلُ اللَّهِ يُؤتيهِ مَن يَشاءُ ۚ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmclxxxii{مَثَلُ الَّذينَ حُمِّلُوا التَّوراةَ ثُمَّ لَم يَحمِلوها كَمَثَلِ الحِمارِ يَحمِلُ أَسفارًا ۚ بِئسَ مَثَلُ القَومِ الَّذينَ كَذَّبوا بِآياتِ اللَّهِ ۚ وَاللَّهُ لا يَهدِي القَومَ الظّالِمينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmclxxxiii{قُل يا أَيُّهَا الَّذينَ هادوا إِن زَعَمتُم أَنَّكُم أَولِياءُ لِلَّهِ مِن دونِ النّاسِ فَتَمَنَّوُا المَوتَ إِن كُنتُم صادِقينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmclxxxiv{وَلا يَتَمَنَّونَهُ أَبَدًا بِما قَدَّمَت أَيديهِم ۚ وَاللَّهُ عَليمٌ بِالظّالِمينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmclxxxv{قُل إِنَّ المَوتَ الَّذي تَفِرّونَ مِنهُ فَإِنَّهُ مُلاقيكُم ۖ ثُمَّ تُرَدّونَ إِلىٰ عالِمِ الغَيبِ وَالشَّهادَةِ فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmclxxxvi{يا أَيُّهَا الَّذينَ آمَنوا إِذا نودِيَ لِلصَّلاةِ مِن يَومِ الجُمُعَةِ فَاسعَوا إِلىٰ ذِكرِ اللَّهِ وَذَرُوا البَيعَ ۚ ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmclxxxvii{فَإِذا قُضِيَتِ الصَّلاةُ فَانتَشِروا فِي الأَرضِ وَابتَغوا مِن فَضلِ اللَّهِ وَاذكُرُوا اللَّهَ كَثيرًا لَعَلَّكُم تُفلِحونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmclxxxviii{وَإِذا رَأَوا تِجارَةً أَو لَهوًا انفَضّوا إِلَيها وَتَرَكوكَ قائِمًا ۚ قُل ما عِندَ اللَّهِ خَيرٌ مِنَ اللَّهوِ وَمِنَ التِّجارَةِ ۚ وَاللَّهُ خَيرُ الرّازِقينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmclxxxix{\basmalah إِذا جاءَكَ المُنافِقونَ قالوا نَشهَدُ إِنَّكَ لَرَسولُ اللَّهِ ۗ وَاللَّهُ يَعلَمُ إِنَّكَ لَرَسولُهُ وَاللَّهُ يَشهَدُ إِنَّ المُنافِقينَ لَكاذِبونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcxc{اتَّخَذوا أَيمانَهُم جُنَّةً فَصَدّوا عَن سَبيلِ اللَّهِ ۚ إِنَّهُم ساءَ ما كانوا يَعمَلونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcxci{ذٰلِكَ بِأَنَّهُم آمَنوا ثُمَّ كَفَروا فَطُبِعَ عَلىٰ قُلوبِهِم فَهُم لا يَفقَهونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcxcii{۞ وَإِذا رَأَيتَهُم تُعجِبُكَ أَجسامُهُم ۖ وَإِن يَقولوا تَسمَع لِقَولِهِم ۖ كَأَنَّهُم خُشُبٌ مُسَنَّدَةٌ ۖ يَحسَبونَ كُلَّ صَيحَةٍ عَلَيهِم ۚ هُمُ العَدُوُّ فَاحذَرهُم ۚ قاتَلَهُمُ اللَّهُ ۖ أَنّىٰ يُؤفَكونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcxciii{وَإِذا قيلَ لَهُم تَعالَوا يَستَغفِر لَكُم رَسولُ اللَّهِ لَوَّوا رُءوسَهُم وَرَأَيتَهُم يَصُدّونَ وَهُم مُستَكبِرونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcxciv{سَواءٌ عَلَيهِم أَستَغفَرتَ لَهُم أَم لَم تَستَغفِر لَهُم لَن يَغفِرَ اللَّهُ لَهُم ۚ إِنَّ اللَّهَ لا يَهدِي القَومَ الفاسِقينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcxcv{هُمُ الَّذينَ يَقولونَ لا تُنفِقوا عَلىٰ مَن عِندَ رَسولِ اللَّهِ حَتّىٰ يَنفَضّوا ۗ وَلِلَّهِ خَزائِنُ السَّماواتِ وَالأَرضِ وَلٰكِنَّ المُنافِقينَ لا يَفقَهونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcxcvi{يَقولونَ لَئِن رَجَعنا إِلَى المَدينَةِ لَيُخرِجَنَّ الأَعَزُّ مِنهَا الأَذَلَّ ۚ وَلِلَّهِ العِزَّةُ وَلِرَسولِهِ وَلِلمُؤمِنينَ وَلٰكِنَّ المُنافِقينَ لا يَعلَمونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcxcvii{يا أَيُّهَا الَّذينَ آمَنوا لا تُلهِكُم أَموالُكُم وَلا أَولادُكُم عَن ذِكرِ اللَّهِ ۚ وَمَن يَفعَل ذٰلِكَ فَأُولٰئِكَ هُمُ الخاسِرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcxcviii{وَأَنفِقوا مِن ما رَزَقناكُم مِن قَبلِ أَن يَأتِيَ أَحَدَكُمُ المَوتُ فَيَقولَ رَبِّ لَولا أَخَّرتَني إِلىٰ أَجَلٍ قَريبٍ فَأَصَّدَّقَ وَأَكُن مِنَ الصّالِحينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcxcix{وَلَن يُؤَخِّرَ اللَّهُ نَفسًا إِذا جاءَ أَجَلُها ۚ وَاللَّهُ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcc{\basmalah يُسَبِّحُ لِلَّهِ ما فِي السَّماواتِ وَما فِي الأَرضِ ۖ لَهُ المُلكُ وَلَهُ الحَمدُ ۖ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcci{هُوَ الَّذي خَلَقَكُم فَمِنكُم كافِرٌ وَمِنكُم مُؤمِنٌ ۚ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccii{خَلَقَ السَّماواتِ وَالأَرضَ بِالحَقِّ وَصَوَّرَكُم فَأَحسَنَ صُوَرَكُم ۖ وَإِلَيهِ المَصيرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcciii{يَعلَمُ ما فِي السَّماواتِ وَالأَرضِ وَيَعلَمُ ما تُسِرّونَ وَما تُعلِنونَ ۚ وَاللَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcciv{أَلَم يَأتِكُم نَبَأُ الَّذينَ كَفَروا مِن قَبلُ فَذاقوا وَبالَ أَمرِهِم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccv{ذٰلِكَ بِأَنَّهُ كانَت تَأتيهِم رُسُلُهُم بِالبَيِّناتِ فَقالوا أَبَشَرٌ يَهدونَنا فَكَفَروا وَتَوَلَّوا ۚ وَاستَغنَى اللَّهُ ۚ وَاللَّهُ غَنِيٌّ حَميدٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccvi{زَعَمَ الَّذينَ كَفَروا أَن لَن يُبعَثوا ۚ قُل بَلىٰ وَرَبّي لَتُبعَثُنَّ ثُمَّ لَتُنَبَّؤُنَّ بِما عَمِلتُم ۚ وَذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccvii{فَآمِنوا بِاللَّهِ وَرَسولِهِ وَالنّورِ الَّذي أَنزَلنا ۚ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccviii{يَومَ يَجمَعُكُم لِيَومِ الجَمعِ ۖ ذٰلِكَ يَومُ التَّغابُنِ ۗ وَمَن يُؤمِن بِاللَّهِ وَيَعمَل صالِحًا يُكَفِّر عَنهُ سَيِّئَاتِهِ وَيُدخِلهُ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها أَبَدًا ۚ ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccix{وَالَّذينَ كَفَروا وَكَذَّبوا بِآياتِنا أُولٰئِكَ أَصحابُ النّارِ خالِدينَ فيها ۖ وَبِئسَ المَصيرُ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccx{ما أَصابَ مِن مُصيبَةٍ إِلّا بِإِذنِ اللَّهِ ۗ وَمَن يُؤمِن بِاللَّهِ يَهدِ قَلبَهُ ۚ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccxi{وَأَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ ۚ فَإِن تَوَلَّيتُم فَإِنَّما عَلىٰ رَسولِنَا البَلاغُ المُبينُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccxii{اللَّهُ لا إِلٰهَ إِلّا هُوَ ۚ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmccxiii{يا أَيُّهَا الَّذينَ آمَنوا إِنَّ مِن أَزواجِكُم وَأَولادِكُم عَدُوًّا لَكُم فَاحذَروهُم ۚ وَإِن تَعفوا وَتَصفَحوا وَتَغفِروا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmccxiv{إِنَّما أَموالُكُم وَأَولادُكُم فِتنَةٌ ۚ وَاللَّهُ عِندَهُ أَجرٌ عَظيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmccxv{فَاتَّقُوا اللَّهَ مَا استَطَعتُم وَاسمَعوا وَأَطيعوا وَأَنفِقوا خَيرًا لِأَنفُسِكُم ۗ وَمَن يوقَ شُحَّ نَفسِهِ فَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmccxvi{إِن تُقرِضُوا اللَّهَ قَرضًا حَسَنًا يُضاعِفهُ لَكُم وَيَغفِر لَكُم ۚ وَاللَّهُ شَكورٌ حَليمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmccxvii{عالِمُ الغَيبِ وَالشَّهادَةِ العَزيزُ الحَكيمُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmccxviii{\basmalah يا أَيُّهَا النَّبِيُّ إِذا طَلَّقتُمُ النِّساءَ فَطَلِّقوهُنَّ لِعِدَّتِهِنَّ وَأَحصُوا العِدَّةَ ۖ وَاتَّقُوا اللَّهَ رَبَّكُم ۖ لا تُخرِجوهُنَّ مِن بُيوتِهِنَّ وَلا يَخرُجنَ إِلّا أَن يَأتينَ بِفاحِشَةٍ مُبَيِّنَةٍ ۚ وَتِلكَ حُدودُ اللَّهِ ۚ وَمَن يَتَعَدَّ حُدودَ اللَّهِ فَقَد ظَلَمَ نَفسَهُ ۚ لا تَدري لَعَلَّ اللَّهَ يُحدِثُ بَعدَ ذٰلِكَ أَمرًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccxix{فَإِذا بَلَغنَ أَجَلَهُنَّ فَأَمسِكوهُنَّ بِمَعروفٍ أَو فارِقوهُنَّ بِمَعروفٍ وَأَشهِدوا ذَوَي عَدلٍ مِنكُم وَأَقيمُوا الشَّهادَةَ لِلَّهِ ۚ ذٰلِكُم يوعَظُ بِهِ مَن كانَ يُؤمِنُ بِاللَّهِ وَاليَومِ الآخِرِ ۚ وَمَن يَتَّقِ اللَّهَ يَجعَل لَهُ مَخرَجًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccxx{وَيَرزُقهُ مِن حَيثُ لا يَحتَسِبُ ۚ وَمَن يَتَوَكَّل عَلَى اللَّهِ فَهُوَ حَسبُهُ ۚ إِنَّ اللَّهَ بالِغُ أَمرِهِ ۚ قَد جَعَلَ اللَّهُ لِكُلِّ شَيءٍ قَدرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccxxi{وَاللّائي يَئِسنَ مِنَ المَحيضِ مِن نِسائِكُم إِنِ ارتَبتُم فَعِدَّتُهُنَّ ثَلاثَةُ أَشهُرٍ وَاللّائي لَم يَحِضنَ ۚ وَأُولاتُ الأَحمالِ أَجَلُهُنَّ أَن يَضَعنَ حَملَهُنَّ ۚ وَمَن يَتَّقِ اللَّهَ يَجعَل لَهُ مِن أَمرِهِ يُسرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccxxii{ذٰلِكَ أَمرُ اللَّهِ أَنزَلَهُ إِلَيكُم ۚ وَمَن يَتَّقِ اللَّهَ يُكَفِّر عَنهُ سَيِّئَاتِهِ وَيُعظِم لَهُ أَجرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccxxiii{أَسكِنوهُنَّ مِن حَيثُ سَكَنتُم مِن وُجدِكُم وَلا تُضارّوهُنَّ لِتُضَيِّقوا عَلَيهِنَّ ۚ وَإِن كُنَّ أُولاتِ حَملٍ فَأَنفِقوا عَلَيهِنَّ حَتّىٰ يَضَعنَ حَملَهُنَّ ۚ فَإِن أَرضَعنَ لَكُم فَآتوهُنَّ أُجورَهُنَّ ۖ وَأتَمِروا بَينَكُم بِمَعروفٍ ۖ وَإِن تَعاسَرتُم فَسَتُرضِعُ لَهُ أُخرىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccxxiv{لِيُنفِق ذو سَعَةٍ مِن سَعَتِهِ ۖ وَمَن قُدِرَ عَلَيهِ رِزقُهُ فَليُنفِق مِمّا آتاهُ اللَّهُ ۚ لا يُكَلِّفُ اللَّهُ نَفسًا إِلّا ما آتاها ۚ سَيَجعَلُ اللَّهُ بَعدَ عُسرٍ يُسرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccxxv{وَكَأَيِّن مِن قَريَةٍ عَتَت عَن أَمرِ رَبِّها وَرُسُلِهِ فَحاسَبناها حِسابًا شَديدًا وَعَذَّبناها عَذابًا نُكرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccxxvi{فَذاقَت وَبالَ أَمرِها وَكانَ عاقِبَةُ أَمرِها خُسرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccxxvii{أَعَدَّ اللَّهُ لَهُم عَذابًا شَديدًا ۖ فَاتَّقُوا اللَّهَ يا أُولِي الأَلبابِ الَّذينَ آمَنوا ۚ قَد أَنزَلَ اللَّهُ إِلَيكُم ذِكرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccxxviii{رَسولًا يَتلو عَلَيكُم آياتِ اللَّهِ مُبَيِّناتٍ لِيُخرِجَ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ مِنَ الظُّلُماتِ إِلَى النّورِ ۚ وَمَن يُؤمِن بِاللَّهِ وَيَعمَل صالِحًا يُدخِلهُ جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها أَبَدًا ۖ قَد أَحسَنَ اللَّهُ لَهُ رِزقًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccxxix{اللَّهُ الَّذي خَلَقَ سَبعَ سَماواتٍ وَمِنَ الأَرضِ مِثلَهُنَّ يَتَنَزَّلُ الأَمرُ بَينَهُنَّ لِتَعلَموا أَنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ وَأَنَّ اللَّهَ قَد أَحاطَ بِكُلِّ شَيءٍ عِلمًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccxxx{\basmalah يا أَيُّهَا النَّبِيُّ لِمَ تُحَرِّمُ ما أَحَلَّ اللَّهُ لَكَ ۖ تَبتَغي مَرضاتَ أَزواجِكَ ۚ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccxxxi{قَد فَرَضَ اللَّهُ لَكُم تَحِلَّةَ أَيمانِكُم ۚ وَاللَّهُ مَولاكُم ۖ وَهُوَ العَليمُ الحَكيمُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccxxxii{وَإِذ أَسَرَّ النَّبِيُّ إِلىٰ بَعضِ أَزواجِهِ حَديثًا فَلَمّا نَبَّأَت بِهِ وَأَظهَرَهُ اللَّهُ عَلَيهِ عَرَّفَ بَعضَهُ وَأَعرَضَ عَن بَعضٍ ۖ فَلَمّا نَبَّأَها بِهِ قالَت مَن أَنبَأَكَ هٰذا ۖ قالَ نَبَّأَنِيَ العَليمُ الخَبيرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccxxxiii{إِن تَتوبا إِلَى اللَّهِ فَقَد صَغَت قُلوبُكُما ۖ وَإِن تَظاهَرا عَلَيهِ فَإِنَّ اللَّهَ هُوَ مَولاهُ وَجِبريلُ وَصالِحُ المُؤمِنينَ ۖ وَالمَلائِكَةُ بَعدَ ذٰلِكَ ظَهيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccxxxiv{عَسىٰ رَبُّهُ إِن طَلَّقَكُنَّ أَن يُبدِلَهُ أَزواجًا خَيرًا مِنكُنَّ مُسلِماتٍ مُؤمِناتٍ قانِتاتٍ تائِباتٍ عابِداتٍ سائِحاتٍ ثَيِّباتٍ وَأَبكارًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccxxxv{يا أَيُّهَا الَّذينَ آمَنوا قوا أَنفُسَكُم وَأَهليكُم نارًا وَقودُهَا النّاسُ وَالحِجارَةُ عَلَيها مَلائِكَةٌ غِلاظٌ شِدادٌ لا يَعصونَ اللَّهَ ما أَمَرَهُم وَيَفعَلونَ ما يُؤمَرونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccxxxvi{يا أَيُّهَا الَّذينَ كَفَروا لا تَعتَذِرُوا اليَومَ ۖ إِنَّما تُجزَونَ ما كُنتُم تَعمَلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccxxxvii{يا أَيُّهَا الَّذينَ آمَنوا توبوا إِلَى اللَّهِ تَوبَةً نَصوحًا عَسىٰ رَبُّكُم أَن يُكَفِّرَ عَنكُم سَيِّئَاتِكُم وَيُدخِلَكُم جَنّاتٍ تَجري مِن تَحتِهَا الأَنهارُ يَومَ لا يُخزِي اللَّهُ النَّبِيَّ وَالَّذينَ آمَنوا مَعَهُ ۖ نورُهُم يَسعىٰ بَينَ أَيديهِم وَبِأَيمانِهِم يَقولونَ رَبَّنا أَتمِم لَنا نورَنا وَاغفِر لَنا ۖ إِنَّكَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccxxxviii{يا أَيُّهَا النَّبِيُّ جاهِدِ الكُفّارَ وَالمُنافِقينَ وَاغلُظ عَلَيهِم ۚ وَمَأواهُم جَهَنَّمُ ۖ وَبِئسَ المَصيرُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccxxxix{ضَرَبَ اللَّهُ مَثَلًا لِلَّذينَ كَفَرُوا امرَأَتَ نوحٍ وَامرَأَتَ لوطٍ ۖ كانَتا تَحتَ عَبدَينِ مِن عِبادِنا صالِحَينِ فَخانَتاهُما فَلَم يُغنِيا عَنهُما مِنَ اللَّهِ شَيئًا وَقيلَ ادخُلَا النّارَ مَعَ الدّاخِلينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccxl{وَضَرَبَ اللَّهُ مَثَلًا لِلَّذينَ آمَنُوا امرَأَتَ فِرعَونَ إِذ قالَت رَبِّ ابنِ لي عِندَكَ بَيتًا فِي الجَنَّةِ وَنَجِّني مِن فِرعَونَ وَعَمَلِهِ وَنَجِّني مِنَ القَومِ الظّالِمينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccxli{وَمَريَمَ ابنَتَ عِمرانَ الَّتي أَحصَنَت فَرجَها فَنَفَخنا فيهِ مِن روحِنا وَصَدَّقَت بِكَلِماتِ رَبِّها وَكُتُبِهِ وَكانَت مِنَ القانِتينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccxlii{\basmalah تَبارَكَ الَّذي بِيَدِهِ المُلكُ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccxliii{الَّذي خَلَقَ المَوتَ وَالحَياةَ لِيَبلُوَكُم أَيُّكُم أَحسَنُ عَمَلًا ۚ وَهُوَ العَزيزُ الغَفورُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccxliv{الَّذي خَلَقَ سَبعَ سَماواتٍ طِباقًا ۖ ما تَرىٰ في خَلقِ الرَّحمٰنِ مِن تَفاوُتٍ ۖ فَارجِعِ البَصَرَ هَل تَرىٰ مِن فُطورٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccxlv{ثُمَّ ارجِعِ البَصَرَ كَرَّتَينِ يَنقَلِب إِلَيكَ البَصَرُ خاسِئًا وَهُوَ حَسيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccxlvi{وَلَقَد زَيَّنَّا السَّماءَ الدُّنيا بِمَصابيحَ وَجَعَلناها رُجومًا لِلشَّياطينِ ۖ وَأَعتَدنا لَهُم عَذابَ السَّعيرِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccxlvii{وَلِلَّذينَ كَفَروا بِرَبِّهِم عَذابُ جَهَنَّمَ ۖ وَبِئسَ المَصيرُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccxlviii{إِذا أُلقوا فيها سَمِعوا لَها شَهيقًا وَهِيَ تَفورُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccxlix{تَكادُ تَمَيَّزُ مِنَ الغَيظِ ۖ كُلَّما أُلقِيَ فيها فَوجٌ سَأَلَهُم خَزَنَتُها أَلَم يَأتِكُم نَذيرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccl{قالوا بَلىٰ قَد جاءَنا نَذيرٌ فَكَذَّبنا وَقُلنا ما نَزَّلَ اللَّهُ مِن شَيءٍ إِن أَنتُم إِلّا في ضَلالٍ كَبيرٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccli{وَقالوا لَو كُنّا نَسمَعُ أَو نَعقِلُ ما كُنّا في أَصحابِ السَّعيرِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcclii{فَاعتَرَفوا بِذَنبِهِم فَسُحقًا لِأَصحابِ السَّعيرِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccliii{إِنَّ الَّذينَ يَخشَونَ رَبَّهُم بِالغَيبِ لَهُم مَغفِرَةٌ وَأَجرٌ كَبيرٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccliv{وَأَسِرّوا قَولَكُم أَوِ اجهَروا بِهِ ۖ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcclv{أَلا يَعلَمُ مَن خَلَقَ وَهُوَ اللَّطيفُ الخَبيرُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcclvi{هُوَ الَّذي جَعَلَ لَكُمُ الأَرضَ ذَلولًا فَامشوا في مَناكِبِها وَكُلوا مِن رِزقِهِ ۖ وَإِلَيهِ النُّشورُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcclvii{أَأَمِنتُم مَن فِي السَّماءِ أَن يَخسِفَ بِكُمُ الأَرضَ فَإِذا هِيَ تَمورُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcclviii{أَم أَمِنتُم مَن فِي السَّماءِ أَن يُرسِلَ عَلَيكُم حاصِبًا ۖ فَسَتَعلَمونَ كَيفَ نَذيرِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcclix{وَلَقَد كَذَّبَ الَّذينَ مِن قَبلِهِم فَكَيفَ كانَ نَكيرِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcclx{أَوَلَم يَرَوا إِلَى الطَّيرِ فَوقَهُم صافّاتٍ وَيَقبِضنَ ۚ ما يُمسِكُهُنَّ إِلَّا الرَّحمٰنُ ۚ إِنَّهُ بِكُلِّ شَيءٍ بَصيرٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcclxi{أَمَّن هٰذَا الَّذي هُوَ جُندٌ لَكُم يَنصُرُكُم مِن دونِ الرَّحمٰنِ ۚ إِنِ الكافِرونَ إِلّا في غُرورٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcclxii{أَمَّن هٰذَا الَّذي يَرزُقُكُم إِن أَمسَكَ رِزقَهُ ۚ بَل لَجّوا في عُتُوٍّ وَنُفورٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcclxiii{أَفَمَن يَمشي مُكِبًّا عَلىٰ وَجهِهِ أَهدىٰ أَمَّن يَمشي سَوِيًّا عَلىٰ صِراطٍ مُستَقيمٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcclxiv{قُل هُوَ الَّذي أَنشَأَكُم وَجَعَلَ لَكُمُ السَّمعَ وَالأَبصارَ وَالأَفئِدَةَ ۖ قَليلًا ما تَشكُرونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcclxv{قُل هُوَ الَّذي ذَرَأَكُم فِي الأَرضِ وَإِلَيهِ تُحشَرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcclxvi{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صادِقينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcclxvii{قُل إِنَّمَا العِلمُ عِندَ اللَّهِ وَإِنَّما أَنا نَذيرٌ مُبينٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcclxviii{فَلَمّا رَأَوهُ زُلفَةً سيئَت وُجوهُ الَّذينَ كَفَروا وَقيلَ هٰذَا الَّذي كُنتُم بِهِ تَدَّعونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcclxix{قُل أَرَأَيتُم إِن أَهلَكَنِيَ اللَّهُ وَمَن مَعِيَ أَو رَحِمَنا فَمَن يُجيرُ الكافِرينَ مِن عَذابٍ أَليمٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcclxx{قُل هُوَ الرَّحمٰنُ آمَنّا بِهِ وَعَلَيهِ تَوَكَّلنا ۖ فَسَتَعلَمونَ مَن هُوَ في ضَلالٍ مُبينٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcclxxi{قُل أَرَأَيتُم إِن أَصبَحَ ماؤُكُم غَورًا فَمَن يَأتيكُم بِماءٍ مَعينٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcclxxii{\basmalah ن ۚ وَالقَلَمِ وَما يَسطُرونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcclxxiii{ما أَنتَ بِنِعمَةِ رَبِّكَ بِمَجنونٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcclxxiv{وَإِنَّ لَكَ لَأَجرًا غَيرَ مَمنونٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcclxxv{وَإِنَّكَ لَعَلىٰ خُلُقٍ عَظيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcclxxvi{فَسَتُبصِرُ وَيُبصِرونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcclxxvii{بِأَييِكُمُ المَفتونُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcclxxviii{إِنَّ رَبَّكَ هُوَ أَعلَمُ بِمَن ضَلَّ عَن سَبيلِهِ وَهُوَ أَعلَمُ بِالمُهتَدينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcclxxix{فَلا تُطِعِ المُكَذِّبينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcclxxx{وَدّوا لَو تُدهِنُ فَيُدهِنونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxi{وَلا تُطِع كُلَّ حَلّافٍ مَهينٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxii{هَمّازٍ مَشّاءٍ بِنَميمٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxiii{مَنّاعٍ لِلخَيرِ مُعتَدٍ أَثيمٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxiv{عُتُلٍّ بَعدَ ذٰلِكَ زَنيمٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxv{أَن كانَ ذا مالٍ وَبَنينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxvi{إِذا تُتلىٰ عَلَيهِ آياتُنا قالَ أَساطيرُ الأَوَّلينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxvii{سَنَسِمُهُ عَلَى الخُرطومِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxviii{إِنّا بَلَوناهُم كَما بَلَونا أَصحابَ الجَنَّةِ إِذ أَقسَموا لَيَصرِمُنَّها مُصبِحينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxix{وَلا يَستَثنونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmccxc{فَطافَ عَلَيها طائِفٌ مِن رَبِّكَ وَهُم نائِمونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmccxci{فَأَصبَحَت كَالصَّريمِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmccxcii{فَتَنادَوا مُصبِحينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmccxciii{أَنِ اغدوا عَلىٰ حَرثِكُم إِن كُنتُم صارِمينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmccxciv{فَانطَلَقوا وَهُم يَتَخافَتونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmccxcv{أَن لا يَدخُلَنَّهَا اليَومَ عَلَيكُم مِسكينٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmccxcvi{وَغَدَوا عَلىٰ حَردٍ قادِرينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmccxcvii{فَلَمّا رَأَوها قالوا إِنّا لَضالّونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmccxcviii{بَل نَحنُ مَحرومونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmccxcix{قالَ أَوسَطُهُم أَلَم أَقُل لَكُم لَولا تُسَبِّحونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmccc{قالوا سُبحانَ رَبِّنا إِنّا كُنّا ظالِمينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmccci{فَأَقبَلَ بَعضُهُم عَلىٰ بَعضٍ يَتَلاوَمونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcccii{قالوا يا وَيلَنا إِنّا كُنّا طاغينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmccciii{عَسىٰ رَبُّنا أَن يُبدِلَنا خَيرًا مِنها إِنّا إِلىٰ رَبِّنا راغِبونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmccciv{كَذٰلِكَ العَذابُ ۖ وَلَعَذابُ الآخِرَةِ أَكبَرُ ۚ لَو كانوا يَعلَمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmcccv{إِنَّ لِلمُتَّقينَ عِندَ رَبِّهِم جَنّاتِ النَّعيمِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmcccvi{أَفَنَجعَلُ المُسلِمينَ كَالمُجرِمينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmcccvii{ما لَكُم كَيفَ تَحكُمونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmcccviii{أَم لَكُم كِتابٌ فيهِ تَدرُسونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmcccix{إِنَّ لَكُم فيهِ لَما تَخَيَّرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmcccx{أَم لَكُم أَيمانٌ عَلَينا بالِغَةٌ إِلىٰ يَومِ القِيامَةِ ۙ إِنَّ لَكُم لَما تَحكُمونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxi{سَلهُم أَيُّهُم بِذٰلِكَ زَعيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxii{أَم لَهُم شُرَكاءُ فَليَأتوا بِشُرَكائِهِم إِن كانوا صادِقينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmcccxiii{يَومَ يُكشَفُ عَن ساقٍ وَيُدعَونَ إِلَى السُّجودِ فَلا يَستَطيعونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxiv{خاشِعَةً أَبصارُهُم تَرهَقُهُم ذِلَّةٌ ۖ وَقَد كانوا يُدعَونَ إِلَى السُّجودِ وَهُم سالِمونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxv{فَذَرني وَمَن يُكَذِّبُ بِهٰذَا الحَديثِ ۖ سَنَستَدرِجُهُم مِن حَيثُ لا يَعلَمونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxvi{وَأُملي لَهُم ۚ إِنَّ كَيدي مَتينٌ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxvii{أَم تَسأَلُهُم أَجرًا فَهُم مِن مَغرَمٍ مُثقَلونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxviii{أَم عِندَهُمُ الغَيبُ فَهُم يَكتُبونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxix{فَاصبِر لِحُكمِ رَبِّكَ وَلا تَكُن كَصاحِبِ الحوتِ إِذ نادىٰ وَهُوَ مَكظومٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxx{لَولا أَن تَدارَكَهُ نِعمَةٌ مِن رَبِّهِ لَنُبِذَ بِالعَراءِ وَهُوَ مَذمومٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxxi{فَاجتَباهُ رَبُّهُ فَجَعَلَهُ مِنَ الصّالِحينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxxii{وَإِن يَكادُ الَّذينَ كَفَروا لَيُزلِقونَكَ بِأَبصارِهِم لَمّا سَمِعُوا الذِّكرَ وَيَقولونَ إِنَّهُ لَمَجنونٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmcccxxiii{وَما هُوَ إِلّا ذِكرٌ لِلعالَمينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxxiv{\basmalah الحاقَّةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcccxxv{مَا الحاقَّةُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxxvi{وَما أَدراكَ مَا الحاقَّةُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxxvii{كَذَّبَت ثَمودُ وَعادٌ بِالقارِعَةِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxxviii{فَأَمّا ثَمودُ فَأُهلِكوا بِالطّاغِيَةِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxxix{وَأَمّا عادٌ فَأُهلِكوا بِريحٍ صَرصَرٍ عاتِيَةٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxxx{سَخَّرَها عَلَيهِم سَبعَ لَيالٍ وَثَمانِيَةَ أَيّامٍ حُسومًا فَتَرَى القَومَ فيها صَرعىٰ كَأَنَّهُم أَعجازُ نَخلٍ خاوِيَةٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxi{فَهَل تَرىٰ لَهُم مِن باقِيَةٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxii{وَجاءَ فِرعَونُ وَمَن قَبلَهُ وَالمُؤتَفِكاتُ بِالخاطِئَةِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxiii{فَعَصَوا رَسولَ رَبِّهِم فَأَخَذَهُم أَخذَةً رابِيَةً\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxiv{إِنّا لَمّا طَغَى الماءُ حَمَلناكُم فِي الجارِيَةِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxv{لِنَجعَلَها لَكُم تَذكِرَةً وَتَعِيَها أُذُنٌ واعِيَةٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxvi{فَإِذا نُفِخَ فِي الصّورِ نَفخَةٌ واحِدَةٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxvii{وَحُمِلَتِ الأَرضُ وَالجِبالُ فَدُكَّتا دَكَّةً واحِدَةً\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxviii{فَيَومَئِذٍ وَقَعَتِ الواقِعَةُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxix{وَانشَقَّتِ السَّماءُ فَهِيَ يَومَئِذٍ واهِيَةٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxl{وَالمَلَكُ عَلىٰ أَرجائِها ۚ وَيَحمِلُ عَرشَ رَبِّكَ فَوقَهُم يَومَئِذٍ ثَمانِيَةٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxli{يَومَئِذٍ تُعرَضونَ لا تَخفىٰ مِنكُم خافِيَةٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxlii{فَأَمّا مَن أوتِيَ كِتابَهُ بِيَمينِهِ فَيَقولُ هاؤُمُ اقرَءوا كِتابِيَه\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxliii{إِنّي ظَنَنتُ أَنّي مُلاقٍ حِسابِيَه\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxliv{فَهُوَ في عيشَةٍ راضِيَةٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcccxlv{في جَنَّةٍ عالِيَةٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxlvi{قُطوفُها دانِيَةٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxlvii{كُلوا وَاشرَبوا هَنيئًا بِما أَسلَفتُم فِي الأَيّامِ الخالِيَةِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxlviii{وَأَمّا مَن أوتِيَ كِتابَهُ بِشِمالِهِ فَيَقولُ يا لَيتَني لَم أوتَ كِتابِيَه\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxlix{وَلَم أَدرِ ما حِسابِيَه\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcccl{يا لَيتَها كانَتِ القاضِيَةَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcccli{ما أَغنىٰ عَنّي مالِيَه ۜ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmccclii{هَلَكَ عَنّي سُلطانِيَه\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcccliii{خُذوهُ فَغُلّوهُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcccliv{ثُمَّ الجَحيمَ صَلّوهُ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmccclv{ثُمَّ في سِلسِلَةٍ ذَرعُها سَبعونَ ذِراعًا فَاسلُكوهُ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmccclvi{إِنَّهُ كانَ لا يُؤمِنُ بِاللَّهِ العَظيمِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmccclvii{وَلا يَحُضُّ عَلىٰ طَعامِ المِسكينِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmccclviii{فَلَيسَ لَهُ اليَومَ هاهُنا حَميمٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmccclix{وَلا طَعامٌ إِلّا مِن غِسلينٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmccclx{لا يَأكُلُهُ إِلَّا الخاطِئونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmccclxi{فَلا أُقسِمُ بِما تُبصِرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmccclxii{وَما لا تُبصِرونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmccclxiii{إِنَّهُ لَقَولُ رَسولٍ كَريمٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmccclxiv{وَما هُوَ بِقَولِ شاعِرٍ ۚ قَليلًا ما تُؤمِنونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmccclxv{وَلا بِقَولِ كاهِنٍ ۚ قَليلًا ما تَذَكَّرونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxvi{تَنزيلٌ مِن رَبِّ العالَمينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmccclxvii{وَلَو تَقَوَّلَ عَلَينا بَعضَ الأَقاويلِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmccclxviii{لَأَخَذنا مِنهُ بِاليَمينِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmccclxix{ثُمَّ لَقَطَعنا مِنهُ الوَتينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmccclxx{فَما مِنكُم مِن أَحَدٍ عَنهُ حاجِزينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmccclxxi{وَإِنَّهُ لَتَذكِرَةٌ لِلمُتَّقينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmccclxxii{وَإِنّا لَنَعلَمُ أَنَّ مِنكُم مُكَذِّبينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmccclxxiii{وَإِنَّهُ لَحَسرَةٌ عَلَى الكافِرينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmccclxxiv{وَإِنَّهُ لَحَقُّ اليَقينِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmccclxxv{فَسَبِّح بِاسمِ رَبِّكَ العَظيمِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxxvi{\basmalah سَأَلَ سائِلٌ بِعَذابٍ واقِعٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccclxxvii{لِلكافِرينَ لَيسَ لَهُ دافِعٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxxviii{مِنَ اللَّهِ ذِي المَعارِجِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccclxxix{تَعرُجُ المَلائِكَةُ وَالرّوحُ إِلَيهِ في يَومٍ كانَ مِقدارُهُ خَمسينَ أَلفَ سَنَةٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccclxxx{فَاصبِر صَبرًا جَميلًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxi{إِنَّهُم يَرَونَهُ بَعيدًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxii{وَنَراهُ قَريبًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxiii{يَومَ تَكونُ السَّماءُ كَالمُهلِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxiv{وَتَكونُ الجِبالُ كَالعِهنِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxv{وَلا يَسأَلُ حَميمٌ حَميمًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxvi{يُبَصَّرونَهُم ۚ يَوَدُّ المُجرِمُ لَو يَفتَدي مِن عَذابِ يَومِئِذٍ بِبَنيهِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxvii{وَصاحِبَتِهِ وَأَخيهِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxviii{وَفَصيلَتِهِ الَّتي تُؤويهِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxix{وَمَن فِي الأَرضِ جَميعًا ثُمَّ يُنجيهِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxc{كَلّا ۖ إِنَّها لَظىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxci{نَزّاعَةً لِلشَّوىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxcii{تَدعو مَن أَدبَرَ وَتَوَلّىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxciii{وَجَمَعَ فَأَوعىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxciv{۞ إِنَّ الإِنسانَ خُلِقَ هَلوعًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxcv{إِذا مَسَّهُ الشَّرُّ جَزوعًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxcvi{وَإِذا مَسَّهُ الخَيرُ مَنوعًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcccxcvii{إِلَّا المُصَلّينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxcviii{الَّذينَ هُم عَلىٰ صَلاتِهِم دائِمونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxcix{وَالَّذينَ في أَموالِهِم حَقٌّ مَعلومٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcd{لِلسّائِلِ وَالمَحرومِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcdi{وَالَّذينَ يُصَدِّقونَ بِيَومِ الدّينِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcdii{وَالَّذينَ هُم مِن عَذابِ رَبِّهِم مُشفِقونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcdiii{إِنَّ عَذابَ رَبِّهِم غَيرُ مَأمونٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcdiv{وَالَّذينَ هُم لِفُروجِهِم حافِظونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcdv{إِلّا عَلىٰ أَزواجِهِم أَو ما مَلَكَت أَيمانُهُم فَإِنَّهُم غَيرُ مَلومينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcdvi{فَمَنِ ابتَغىٰ وَراءَ ذٰلِكَ فَأُولٰئِكَ هُمُ العادونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmcdvii{وَالَّذينَ هُم لِأَماناتِهِم وَعَهدِهِم راعونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmcdviii{وَالَّذينَ هُم بِشَهاداتِهِم قائِمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmcdix{وَالَّذينَ هُم عَلىٰ صَلاتِهِم يُحافِظونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmcdx{أُولٰئِكَ في جَنّاتٍ مُكرَمونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxi{فَمالِ الَّذينَ كَفَروا قِبَلَكَ مُهطِعينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxii{عَنِ اليَمينِ وَعَنِ الشِّمالِ عِزينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxiii{أَيَطمَعُ كُلُّ امرِئٍ مِنهُم أَن يُدخَلَ جَنَّةَ نَعيمٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxiv{كَلّا ۖ إِنّا خَلَقناهُم مِمّا يَعلَمونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxv{فَلا أُقسِمُ بِرَبِّ المَشارِقِ وَالمَغارِبِ إِنّا لَقادِرونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxvi{عَلىٰ أَن نُبَدِّلَ خَيرًا مِنهُم وَما نَحنُ بِمَسبوقينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmcdxvii{فَذَرهُم يَخوضوا وَيَلعَبوا حَتّىٰ يُلاقوا يَومَهُمُ الَّذي يوعَدونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxviii{يَومَ يَخرُجونَ مِنَ الأَجداثِ سِراعًا كَأَنَّهُم إِلىٰ نُصُبٍ يوفِضونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxix{خاشِعَةً أَبصارُهُم تَرهَقُهُم ذِلَّةٌ ۚ ذٰلِكَ اليَومُ الَّذي كانوا يوعَدونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxx{\basmalah إِنّا أَرسَلنا نوحًا إِلىٰ قَومِهِ أَن أَنذِر قَومَكَ مِن قَبلِ أَن يَأتِيَهُم عَذابٌ أَليمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdxxi{قالَ يا قَومِ إِنّي لَكُم نَذيرٌ مُبينٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxxii{أَنِ اعبُدُوا اللَّهَ وَاتَّقوهُ وَأَطيعونِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxxiii{يَغفِر لَكُم مِن ذُنوبِكُم وَيُؤَخِّركُم إِلىٰ أَجَلٍ مُسَمًّى ۚ إِنَّ أَجَلَ اللَّهِ إِذا جاءَ لا يُؤَخَّرُ ۖ لَو كُنتُم تَعلَمونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxxiv{قالَ رَبِّ إِنّي دَعَوتُ قَومي لَيلًا وَنَهارًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxxv{فَلَم يَزِدهُم دُعائي إِلّا فِرارًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxxvi{وَإِنّي كُلَّما دَعَوتُهُم لِتَغفِرَ لَهُم جَعَلوا أَصابِعَهُم في آذانِهِم وَاستَغشَوا ثِيابَهُم وَأَصَرّوا وَاستَكبَرُوا استِكبارًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxxvii{ثُمَّ إِنّي دَعَوتُهُم جِهارًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxxviii{ثُمَّ إِنّي أَعلَنتُ لَهُم وَأَسرَرتُ لَهُم إِسرارًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxxix{فَقُلتُ استَغفِروا رَبَّكُم إِنَّهُ كانَ غَفّارًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxxx{يُرسِلِ السَّماءَ عَلَيكُم مِدرارًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxi{وَيُمدِدكُم بِأَموالٍ وَبَنينَ وَيَجعَل لَكُم جَنّاتٍ وَيَجعَل لَكُم أَنهارًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxii{ما لَكُم لا تَرجونَ لِلَّهِ وَقارًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxiii{وَقَد خَلَقَكُم أَطوارًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxiv{أَلَم تَرَوا كَيفَ خَلَقَ اللَّهُ سَبعَ سَماواتٍ طِباقًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxv{وَجَعَلَ القَمَرَ فيهِنَّ نورًا وَجَعَلَ الشَّمسَ سِراجًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxvi{وَاللَّهُ أَنبَتَكُم مِنَ الأَرضِ نَباتًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxvii{ثُمَّ يُعيدُكُم فيها وَيُخرِجُكُم إِخراجًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxviii{وَاللَّهُ جَعَلَ لَكُمُ الأَرضَ بِساطًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxix{لِتَسلُكوا مِنها سُبُلًا فِجاجًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxl{قالَ نوحٌ رَبِّ إِنَّهُم عَصَوني وَاتَّبَعوا مَن لَم يَزِدهُ مالُهُ وَوَلَدُهُ إِلّا خَسارًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcdxli{وَمَكَروا مَكرًا كُبّارًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxlii{وَقالوا لا تَذَرُنَّ آلِهَتَكُم وَلا تَذَرُنَّ وَدًّا وَلا سُواعًا وَلا يَغوثَ وَيَعوقَ وَنَسرًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxliii{وَقَد أَضَلّوا كَثيرًا ۖ وَلا تَزِدِ الظّالِمينَ إِلّا ضَلالًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxliv{مِمّا خَطيئَاتِهِم أُغرِقوا فَأُدخِلوا نارًا فَلَم يَجِدوا لَهُم مِن دونِ اللَّهِ أَنصارًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxlv{وَقالَ نوحٌ رَبِّ لا تَذَر عَلَى الأَرضِ مِنَ الكافِرينَ دَيّارًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxlvi{إِنَّكَ إِن تَذَرهُم يُضِلّوا عِبادَكَ وَلا يَلِدوا إِلّا فاجِرًا كَفّارًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxlvii{رَبِّ اغفِر لي وَلِوالِدَيَّ وَلِمَن دَخَلَ بَيتِيَ مُؤمِنًا وَلِلمُؤمِنينَ وَالمُؤمِناتِ وَلا تَزِدِ الظّالِمينَ إِلّا تَبارًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxlviii{\basmalah قُل أوحِيَ إِلَيَّ أَنَّهُ استَمَعَ نَفَرٌ مِنَ الجِنِّ فَقالوا إِنّا سَمِعنا قُرآنًا عَجَبًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdxlix{يَهدي إِلَى الرُّشدِ فَآمَنّا بِهِ ۖ وَلَن نُشرِكَ بِرَبِّنا أَحَدًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdl{وَأَنَّهُ تَعالىٰ جَدُّ رَبِّنا مَا اتَّخَذَ صاحِبَةً وَلا وَلَدًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdli{وَأَنَّهُ كانَ يَقولُ سَفيهُنا عَلَى اللَّهِ شَطَطًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlii{وَأَنّا ظَنَنّا أَن لَن تَقولَ الإِنسُ وَالجِنُّ عَلَى اللَّهِ كَذِبًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcdliii{وَأَنَّهُ كانَ رِجالٌ مِنَ الإِنسِ يَعوذونَ بِرِجالٍ مِنَ الجِنِّ فَزادوهُم رَهَقًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcdliv{وَأَنَّهُم ظَنّوا كَما ظَنَنتُم أَن لَن يَبعَثَ اللَّهُ أَحَدًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlv{وَأَنّا لَمَسنَا السَّماءَ فَوَجَدناها مُلِئَت حَرَسًا شَديدًا وَشُهُبًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlvi{وَأَنّا كُنّا نَقعُدُ مِنها مَقاعِدَ لِلسَّمعِ ۖ فَمَن يَستَمِعِ الآنَ يَجِد لَهُ شِهابًا رَصَدًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcdlvii{وَأَنّا لا نَدري أَشَرٌّ أُريدَ بِمَن فِي الأَرضِ أَم أَرادَ بِهِم رَبُّهُم رَشَدًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcdlviii{وَأَنّا مِنَّا الصّالِحونَ وَمِنّا دونَ ذٰلِكَ ۖ كُنّا طَرائِقَ قِدَدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcdlix{وَأَنّا ظَنَنّا أَن لَن نُعجِزَ اللَّهَ فِي الأَرضِ وَلَن نُعجِزَهُ هَرَبًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlx{وَأَنّا لَمّا سَمِعنَا الهُدىٰ آمَنّا بِهِ ۖ فَمَن يُؤمِن بِرَبِّهِ فَلا يَخافُ بَخسًا وَلا رَهَقًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxi{وَأَنّا مِنَّا المُسلِمونَ وَمِنَّا القاسِطونَ ۖ فَمَن أَسلَمَ فَأُولٰئِكَ تَحَرَّوا رَشَدًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlxii{وَأَمَّا القاسِطونَ فَكانوا لِجَهَنَّمَ حَطَبًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcdlxiii{وَأَن لَوِ استَقاموا عَلَى الطَّريقَةِ لَأَسقَيناهُم ماءً غَدَقًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcdlxiv{لِنَفتِنَهُم فيهِ ۚ وَمَن يُعرِض عَن ذِكرِ رَبِّهِ يَسلُكهُ عَذابًا صَعَدًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlxv{وَأَنَّ المَساجِدَ لِلَّهِ فَلا تَدعوا مَعَ اللَّهِ أَحَدًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlxvi{وَأَنَّهُ لَمّا قامَ عَبدُ اللَّهِ يَدعوهُ كادوا يَكونونَ عَلَيهِ لِبَدًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcdlxvii{قُل إِنَّما أَدعو رَبّي وَلا أُشرِكُ بِهِ أَحَدًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcdlxviii{قُل إِنّي لا أَملِكُ لَكُم ضَرًّا وَلا رَشَدًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcdlxix{قُل إِنّي لَن يُجيرَني مِنَ اللَّهِ أَحَدٌ وَلَن أَجِدَ مِن دونِهِ مُلتَحَدًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlxx{إِلّا بَلاغًا مِنَ اللَّهِ وَرِسالاتِهِ ۚ وَمَن يَعصِ اللَّهَ وَرَسولَهُ فَإِنَّ لَهُ نارَ جَهَنَّمَ خالِدينَ فيها أَبَدًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxi{حَتّىٰ إِذا رَأَوا ما يوعَدونَ فَسَيَعلَمونَ مَن أَضعَفُ ناصِرًا وَأَقَلُّ عَدَدًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxii{قُل إِن أَدري أَقَريبٌ ما توعَدونَ أَم يَجعَلُ لَهُ رَبّي أَمَدًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxiii{عالِمُ الغَيبِ فَلا يُظهِرُ عَلىٰ غَيبِهِ أَحَدًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxiv{إِلّا مَنِ ارتَضىٰ مِن رَسولٍ فَإِنَّهُ يَسلُكُ مِن بَينِ يَدَيهِ وَمِن خَلفِهِ رَصَدًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxv{لِيَعلَمَ أَن قَد أَبلَغوا رِسالاتِ رَبِّهِم وَأَحاطَ بِما لَدَيهِم وَأَحصىٰ كُلَّ شَيءٍ عَدَدًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxvi{\basmalah يا أَيُّهَا المُزَّمِّلُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxvii{قُمِ اللَّيلَ إِلّا قَليلًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxviii{نِصفَهُ أَوِ انقُص مِنهُ قَليلًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxix{أَو زِد عَلَيهِ وَرَتِّلِ القُرآنَ تَرتيلًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxx{إِنّا سَنُلقي عَلَيكَ قَولًا ثَقيلًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxi{إِنَّ ناشِئَةَ اللَّيلِ هِيَ أَشَدُّ وَطئًا وَأَقوَمُ قيلًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxii{إِنَّ لَكَ فِي النَّهارِ سَبحًا طَويلًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxiii{وَاذكُرِ اسمَ رَبِّكَ وَتَبَتَّل إِلَيهِ تَبتيلًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxiv{رَبُّ المَشرِقِ وَالمَغرِبِ لا إِلٰهَ إِلّا هُوَ فَاتَّخِذهُ وَكيلًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxv{وَاصبِر عَلىٰ ما يَقولونَ وَاهجُرهُم هَجرًا جَميلًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxvi{وَذَرني وَالمُكَذِّبينَ أُولِي النَّعمَةِ وَمَهِّلهُم قَليلًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxvii{إِنَّ لَدَينا أَنكالًا وَجَحيمًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxviii{وَطَعامًا ذا غُصَّةٍ وَعَذابًا أَليمًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxix{يَومَ تَرجُفُ الأَرضُ وَالجِبالُ وَكانَتِ الجِبالُ كَثيبًا مَهيلًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxc{إِنّا أَرسَلنا إِلَيكُم رَسولًا شاهِدًا عَلَيكُم كَما أَرسَلنا إِلىٰ فِرعَونَ رَسولًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxci{فَعَصىٰ فِرعَونُ الرَّسولَ فَأَخَذناهُ أَخذًا وَبيلًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxcii{فَكَيفَ تَتَّقونَ إِن كَفَرتُم يَومًا يَجعَلُ الوِلدانَ شيبًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxciii{السَّماءُ مُنفَطِرٌ بِهِ ۚ كانَ وَعدُهُ مَفعولًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxciv{إِنَّ هٰذِهِ تَذكِرَةٌ ۖ فَمَن شاءَ اتَّخَذَ إِلىٰ رَبِّهِ سَبيلًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxcv{۞ إِنَّ رَبَّكَ يَعلَمُ أَنَّكَ تَقومُ أَدنىٰ مِن ثُلُثَيِ اللَّيلِ وَنِصفَهُ وَثُلُثَهُ وَطائِفَةٌ مِنَ الَّذينَ مَعَكَ ۚ وَاللَّهُ يُقَدِّرُ اللَّيلَ وَالنَّهارَ ۚ عَلِمَ أَن لَن تُحصوهُ فَتابَ عَلَيكُم ۖ فَاقرَءوا ما تَيَسَّرَ مِنَ القُرآنِ ۚ عَلِمَ أَن سَيَكونُ مِنكُم مَرضىٰ ۙ وَآخَرونَ يَضرِبونَ فِي الأَرضِ يَبتَغونَ مِن فَضلِ اللَّهِ ۙ وَآخَرونَ يُقاتِلونَ في سَبيلِ اللَّهِ ۖ فَاقرَءوا ما تَيَسَّرَ مِنهُ ۚ وَأَقيمُوا الصَّلاةَ وَآتُوا الزَّكاةَ وَأَقرِضُوا اللَّهَ قَرضًا حَسَنًا ۚ وَما تُقَدِّموا لِأَنفُسِكُم مِن خَيرٍ تَجِدوهُ عِندَ اللَّهِ هُوَ خَيرًا وَأَعظَمَ أَجرًا ۚ وَاستَغفِرُوا اللَّهَ ۖ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxcvi{\basmalah يا أَيُّهَا المُدَّثِّرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdxcvii{قُم فَأَنذِر\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxcviii{وَرَبَّكَ فَكَبِّر\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxcix{وَثِيابَكَ فَطَهِّر\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmd{وَالرُّجزَ فَاهجُر\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdi{وَلا تَمنُن تَستَكثِرُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdii{وَلِرَبِّكَ فَاصبِر\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdiii{فَإِذا نُقِرَ فِي النّاقورِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdiv{فَذٰلِكَ يَومَئِذٍ يَومٌ عَسيرٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdv{عَلَى الكافِرينَ غَيرُ يَسيرٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdvi{ذَرني وَمَن خَلَقتُ وَحيدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdvii{وَجَعَلتُ لَهُ مالًا مَمدودًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdviii{وَبَنينَ شُهودًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdix{وَمَهَّدتُ لَهُ تَمهيدًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdx{ثُمَّ يَطمَعُ أَن أَزيدَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdxi{كَلّا ۖ إِنَّهُ كانَ لِآياتِنا عَنيدًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdxii{سَأُرهِقُهُ صَعودًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdxiii{إِنَّهُ فَكَّرَ وَقَدَّرَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdxiv{فَقُتِلَ كَيفَ قَدَّرَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdxv{ثُمَّ قُتِلَ كَيفَ قَدَّرَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdxvi{ثُمَّ نَظَرَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdxvii{ثُمَّ عَبَسَ وَبَسَرَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdxviii{ثُمَّ أَدبَرَ وَاستَكبَرَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdxix{فَقالَ إِن هٰذا إِلّا سِحرٌ يُؤثَرُ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdxx{إِن هٰذا إِلّا قَولُ البَشَرِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdxxi{سَأُصليهِ سَقَرَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdxxii{وَما أَدراكَ ما سَقَرُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdxxiii{لا تُبقي وَلا تَذَرُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdxxiv{لَوّاحَةٌ لِلبَشَرِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdxxv{عَلَيها تِسعَةَ عَشَرَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdxxvi{وَما جَعَلنا أَصحابَ النّارِ إِلّا مَلائِكَةً ۙ وَما جَعَلنا عِدَّتَهُم إِلّا فِتنَةً لِلَّذينَ كَفَروا لِيَستَيقِنَ الَّذينَ أوتُوا الكِتابَ وَيَزدادَ الَّذينَ آمَنوا إيمانًا ۙ وَلا يَرتابَ الَّذينَ أوتُوا الكِتابَ وَالمُؤمِنونَ ۙ وَلِيَقولَ الَّذينَ في قُلوبِهِم مَرَضٌ وَالكافِرونَ ماذا أَرادَ اللَّهُ بِهٰذا مَثَلًا ۚ كَذٰلِكَ يُضِلُّ اللَّهُ مَن يَشاءُ وَيَهدي مَن يَشاءُ ۚ وَما يَعلَمُ جُنودَ رَبِّكَ إِلّا هُوَ ۚ وَما هِيَ إِلّا ذِكرىٰ لِلبَشَرِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdxxvii{كَلّا وَالقَمَرِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdxxviii{وَاللَّيلِ إِذ أَدبَرَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdxxix{وَالصُّبحِ إِذا أَسفَرَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdxxx{إِنَّها لَإِحدَى الكُبَرِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdxxxi{نَذيرًا لِلبَشَرِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdxxxii{لِمَن شاءَ مِنكُم أَن يَتَقَدَّمَ أَو يَتَأَخَّرَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdxxxiii{كُلُّ نَفسٍ بِما كَسَبَت رَهينَةٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdxxxiv{إِلّا أَصحابَ اليَمينِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdxxxv{في جَنّاتٍ يَتَساءَلونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdxxxvi{عَنِ المُجرِمينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdxxxvii{ما سَلَكَكُم في سَقَرَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdxxxviii{قالوا لَم نَكُ مِنَ المُصَلّينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmdxxxix{وَلَم نَكُ نُطعِمُ المِسكينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmdxl{وَكُنّا نَخوضُ مَعَ الخائِضينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmdxli{وَكُنّا نُكَذِّبُ بِيَومِ الدّينِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmdxlii{حَتّىٰ أَتانَا اليَقينُ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmdxliii{فَما تَنفَعُهُم شَفاعَةُ الشّافِعينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmdxliv{فَما لَهُم عَنِ التَّذكِرَةِ مُعرِضينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmdxlv{كَأَنَّهُم حُمُرٌ مُستَنفِرَةٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmdxlvi{فَرَّت مِن قَسوَرَةٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmdxlvii{بَل يُريدُ كُلُّ امرِئٍ مِنهُم أَن يُؤتىٰ صُحُفًا مُنَشَّرَةً\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmdxlviii{كَلّا ۖ بَل لا يَخافونَ الآخِرَةَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmmdxlix{كَلّا إِنَّهُ تَذكِرَةٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmmdl{فَمَن شاءَ ذَكَرَهُ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmmdli{وَما يَذكُرونَ إِلّا أَن يَشاءَ اللَّهُ ۚ هُوَ أَهلُ التَّقوىٰ وَأَهلُ المَغفِرَةِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmmdlii{\basmalah لا أُقسِمُ بِيَومِ القِيامَةِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdliii{وَلا أُقسِمُ بِالنَّفسِ اللَّوّامَةِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdliv{أَيَحسَبُ الإِنسانُ أَلَّن نَجمَعَ عِظامَهُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdlv{بَلىٰ قادِرينَ عَلىٰ أَن نُسَوِّيَ بَنانَهُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdlvi{بَل يُريدُ الإِنسانُ لِيَفجُرَ أَمامَهُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdlvii{يَسأَلُ أَيّانَ يَومُ القِيامَةِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdlviii{فَإِذا بَرِقَ البَصَرُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdlix{وَخَسَفَ القَمَرُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdlx{وَجُمِعَ الشَّمسُ وَالقَمَرُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdlxi{يَقولُ الإِنسانُ يَومَئِذٍ أَينَ المَفَرُّ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdlxii{كَلّا لا وَزَرَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdlxiii{إِلىٰ رَبِّكَ يَومَئِذٍ المُستَقَرُّ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdlxiv{يُنَبَّأُ الإِنسانُ يَومَئِذٍ بِما قَدَّمَ وَأَخَّرَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdlxv{بَلِ الإِنسانُ عَلىٰ نَفسِهِ بَصيرَةٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdlxvi{وَلَو أَلقىٰ مَعاذيرَهُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdlxvii{لا تُحَرِّك بِهِ لِسانَكَ لِتَعجَلَ بِهِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdlxviii{إِنَّ عَلَينا جَمعَهُ وَقُرآنَهُ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdlxix{فَإِذا قَرَأناهُ فَاتَّبِع قُرآنَهُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdlxx{ثُمَّ إِنَّ عَلَينا بَيانَهُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdlxxi{كَلّا بَل تُحِبّونَ العاجِلَةَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdlxxii{وَتَذَرونَ الآخِرَةَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdlxxiii{وُجوهٌ يَومَئِذٍ ناضِرَةٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdlxxiv{إِلىٰ رَبِّها ناظِرَةٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdlxxv{وَوُجوهٌ يَومَئِذٍ باسِرَةٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdlxxvi{تَظُنُّ أَن يُفعَلَ بِها فاقِرَةٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdlxxvii{كَلّا إِذا بَلَغَتِ التَّراقِيَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdlxxviii{وَقيلَ مَن ۜ راقٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdlxxix{وَظَنَّ أَنَّهُ الفِراقُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdlxxx{وَالتَفَّتِ السّاقُ بِالسّاقِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxi{إِلىٰ رَبِّكَ يَومَئِذٍ المَساقُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxii{فَلا صَدَّقَ وَلا صَلّىٰ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxiii{وَلٰكِن كَذَّبَ وَتَوَلّىٰ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxiv{ثُمَّ ذَهَبَ إِلىٰ أَهلِهِ يَتَمَطّىٰ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxv{أَولىٰ لَكَ فَأَولىٰ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxvi{ثُمَّ أَولىٰ لَكَ فَأَولىٰ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxvii{أَيَحسَبُ الإِنسانُ أَن يُترَكَ سُدًى\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxviii{أَلَم يَكُ نُطفَةً مِن مَنِيٍّ يُمنىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxix{ثُمَّ كانَ عَلَقَةً فَخَلَقَ فَسَوّىٰ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdxc{فَجَعَلَ مِنهُ الزَّوجَينِ الذَّكَرَ وَالأُنثىٰ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdxci{أَلَيسَ ذٰلِكَ بِقادِرٍ عَلىٰ أَن يُحيِيَ المَوتىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdxcii{\basmalah هَل أَتىٰ عَلَى الإِنسانِ حينٌ مِنَ الدَّهرِ لَم يَكُن شَيئًا مَذكورًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdxciii{إِنّا خَلَقنَا الإِنسانَ مِن نُطفَةٍ أَمشاجٍ نَبتَليهِ فَجَعَلناهُ سَميعًا بَصيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdxciv{إِنّا هَدَيناهُ السَّبيلَ إِمّا شاكِرًا وَإِمّا كَفورًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdxcv{إِنّا أَعتَدنا لِلكافِرينَ سَلاسِلَ وَأَغلالًا وَسَعيرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdxcvi{إِنَّ الأَبرارَ يَشرَبونَ مِن كَأسٍ كانَ مِزاجُها كافورًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdxcvii{عَينًا يَشرَبُ بِها عِبادُ اللَّهِ يُفَجِّرونَها تَفجيرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdxcviii{يوفونَ بِالنَّذرِ وَيَخافونَ يَومًا كانَ شَرُّهُ مُستَطيرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdxcix{وَيُطعِمونَ الطَّعامَ عَلىٰ حُبِّهِ مِسكينًا وَيَتيمًا وَأَسيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdc{إِنَّما نُطعِمُكُم لِوَجهِ اللَّهِ لا نُريدُ مِنكُم جَزاءً وَلا شُكورًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdci{إِنّا نَخافُ مِن رَبِّنا يَومًا عَبوسًا قَمطَريرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcii{فَوَقاهُمُ اللَّهُ شَرَّ ذٰلِكَ اليَومِ وَلَقّاهُم نَضرَةً وَسُرورًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdciii{وَجَزاهُم بِما صَبَروا جَنَّةً وَحَريرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdciv{مُتَّكِئينَ فيها عَلَى الأَرائِكِ ۖ لا يَرَونَ فيها شَمسًا وَلا زَمهَريرًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcv{وَدانِيَةً عَلَيهِم ظِلالُها وَذُلِّلَت قُطوفُها تَذليلًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcvi{وَيُطافُ عَلَيهِم بِآنِيَةٍ مِن فِضَّةٍ وَأَكوابٍ كانَت قَواريرا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcvii{قَواريرَ مِن فِضَّةٍ قَدَّروها تَقديرًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcviii{وَيُسقَونَ فيها كَأسًا كانَ مِزاجُها زَنجَبيلًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcix{عَينًا فيها تُسَمّىٰ سَلسَبيلًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcx{۞ وَيَطوفُ عَلَيهِم وِلدانٌ مُخَلَّدونَ إِذا رَأَيتَهُم حَسِبتَهُم لُؤلُؤًا مَنثورًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxi{وَإِذا رَأَيتَ ثَمَّ رَأَيتَ نَعيمًا وَمُلكًا كَبيرًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxii{عالِيَهُم ثِيابُ سُندُسٍ خُضرٌ وَإِستَبرَقٌ ۖ وَحُلّوا أَساوِرَ مِن فِضَّةٍ وَسَقاهُم رَبُّهُم شَرابًا طَهورًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcxiii{إِنَّ هٰذا كانَ لَكُم جَزاءً وَكانَ سَعيُكُم مَشكورًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxiv{إِنّا نَحنُ نَزَّلنا عَلَيكَ القُرآنَ تَنزيلًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxv{فَاصبِر لِحُكمِ رَبِّكَ وَلا تُطِع مِنهُم آثِمًا أَو كَفورًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxvi{وَاذكُرِ اسمَ رَبِّكَ بُكرَةً وَأَصيلًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxvii{وَمِنَ اللَّيلِ فَاسجُد لَهُ وَسَبِّحهُ لَيلًا طَويلًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxviii{إِنَّ هٰؤُلاءِ يُحِبّونَ العاجِلَةَ وَيَذَرونَ وَراءَهُم يَومًا ثَقيلًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxix{نَحنُ خَلَقناهُم وَشَدَدنا أَسرَهُم ۖ وَإِذا شِئنا بَدَّلنا أَمثالَهُم تَبديلًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxx{إِنَّ هٰذِهِ تَذكِرَةٌ ۖ فَمَن شاءَ اتَّخَذَ إِلىٰ رَبِّهِ سَبيلًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxxi{وَما تَشاءونَ إِلّا أَن يَشاءَ اللَّهُ ۚ إِنَّ اللَّهَ كانَ عَليمًا حَكيمًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxxii{يُدخِلُ مَن يَشاءُ في رَحمَتِهِ ۚ وَالظّالِمينَ أَعَدَّ لَهُم عَذابًا أَليمًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdcxxiii{\basmalah وَالمُرسَلاتِ عُرفًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcxxiv{فَالعاصِفاتِ عَصفًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxxv{وَالنّاشِراتِ نَشرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxxvi{فَالفارِقاتِ فَرقًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxxvii{فَالمُلقِياتِ ذِكرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxxviii{عُذرًا أَو نُذرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxxix{إِنَّما توعَدونَ لَواقِعٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxxx{فَإِذَا النُّجومُ طُمِسَت\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxi{وَإِذَا السَّماءُ فُرِجَت\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxii{وَإِذَا الجِبالُ نُسِفَت\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxiii{وَإِذَا الرُّسُلُ أُقِّتَت\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxiv{لِأَيِّ يَومٍ أُجِّلَت\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxv{لِيَومِ الفَصلِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxvi{وَما أَدراكَ ما يَومُ الفَصلِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxvii{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxviii{أَلَم نُهلِكِ الأَوَّلينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxix{ثُمَّ نُتبِعُهُمُ الآخِرينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxl{كَذٰلِكَ نَفعَلُ بِالمُجرِمينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxli{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxlii{أَلَم نَخلُقكُم مِن ماءٍ مَهينٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxliii{فَجَعَلناهُ في قَرارٍ مَكينٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcxliv{إِلىٰ قَدَرٍ مَعلومٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxlv{فَقَدَرنا فَنِعمَ القادِرونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxlvi{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxlvii{أَلَم نَجعَلِ الأَرضَ كِفاتًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxlviii{أَحياءً وَأَمواتًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxlix{وَجَعَلنا فيها رَواسِيَ شامِخاتٍ وَأَسقَيناكُم ماءً فُراتًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcl{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcli{انطَلِقوا إِلىٰ ما كُنتُم بِهِ تُكَذِّبونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdclii{انطَلِقوا إِلىٰ ظِلٍّ ذي ثَلاثِ شُعَبٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcliii{لا ظَليلٍ وَلا يُغني مِنَ اللَّهَبِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdcliv{إِنَّها تَرمي بِشَرَرٍ كَالقَصرِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdclv{كَأَنَّهُ جِمالَتٌ صُفرٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdclvi{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdclvii{هٰذا يَومُ لا يَنطِقونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdclviii{وَلا يُؤذَنُ لَهُم فَيَعتَذِرونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdclix{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdclx{هٰذا يَومُ الفَصلِ ۖ جَمَعناكُم وَالأَوَّلينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdclxi{فَإِن كانَ لَكُم كَيدٌ فَكيدونِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdclxii{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdclxiii{إِنَّ المُتَّقينَ في ظِلالٍ وَعُيونٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdclxiv{وَفَواكِهَ مِمّا يَشتَهونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdclxv{كُلوا وَاشرَبوا هَنيئًا بِما كُنتُم تَعمَلونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmdclxvi{إِنّا كَذٰلِكَ نَجزِي المُحسِنينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmdclxvii{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmdclxviii{كُلوا وَتَمَتَّعوا قَليلًا إِنَّكُم مُجرِمونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmdclxix{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmdclxx{وَإِذا قيلَ لَهُمُ اركَعوا لا يَركَعونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmdclxxi{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmdclxxii{فَبِأَيِّ حَديثٍ بَعدَهُ يُؤمِنونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmdclxxiii{\basmalah عَمَّ يَتَساءَلونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdclxxiv{عَنِ النَّبَإِ العَظيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdclxxv{الَّذي هُم فيهِ مُختَلِفونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdclxxvi{كَلّا سَيَعلَمونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdclxxvii{ثُمَّ كَلّا سَيَعلَمونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdclxxviii{أَلَم نَجعَلِ الأَرضَ مِهادًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdclxxix{وَالجِبالَ أَوتادًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdclxxx{وَخَلَقناكُم أَزواجًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxi{وَجَعَلنا نَومَكُم سُباتًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxii{وَجَعَلنَا اللَّيلَ لِباسًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxiii{وَجَعَلنَا النَّهارَ مَعاشًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxiv{وَبَنَينا فَوقَكُم سَبعًا شِدادًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxv{وَجَعَلنا سِراجًا وَهّاجًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxvi{وَأَنزَلنا مِنَ المُعصِراتِ ماءً ثَجّاجًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxvii{لِنُخرِجَ بِهِ حَبًّا وَنَباتًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxviii{وَجَنّاتٍ أَلفافًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxix{إِنَّ يَومَ الفَصلِ كانَ ميقاتًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxc{يَومَ يُنفَخُ فِي الصّورِ فَتَأتونَ أَفواجًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxci{وَفُتِحَتِ السَّماءُ فَكانَت أَبوابًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxcii{وَسُيِّرَتِ الجِبالُ فَكانَت سَرابًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxciii{إِنَّ جَهَنَّمَ كانَت مِرصادًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcxciv{لِلطّاغينَ مَآبًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxcv{لابِثينَ فيها أَحقابًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxcvi{لا يَذوقونَ فيها بَردًا وَلا شَرابًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxcvii{إِلّا حَميمًا وَغَسّاقًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxcviii{جَزاءً وِفاقًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxcix{إِنَّهُم كانوا لا يَرجونَ حِسابًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcc{وَكَذَّبوا بِآياتِنا كِذّابًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcci{وَكُلَّ شَيءٍ أَحصَيناهُ كِتابًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdccii{فَذوقوا فَلَن نَزيدَكُم إِلّا عَذابًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcciii{إِنَّ لِلمُتَّقينَ مَفازًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdcciv{حَدائِقَ وَأَعنابًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccv{وَكَواعِبَ أَترابًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccvi{وَكَأسًا دِهاقًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccvii{لا يَسمَعونَ فيها لَغوًا وَلا كِذّابًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccviii{جَزاءً مِن رَبِّكَ عَطاءً حِسابًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccix{رَبِّ السَّماواتِ وَالأَرضِ وَما بَينَهُمَا الرَّحمٰنِ ۖ لا يَملِكونَ مِنهُ خِطابًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdccx{يَومَ يَقومُ الرّوحُ وَالمَلائِكَةُ صَفًّا ۖ لا يَتَكَلَّمونَ إِلّا مَن أَذِنَ لَهُ الرَّحمٰنُ وَقالَ صَوابًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxi{ذٰلِكَ اليَومُ الحَقُّ ۖ فَمَن شاءَ اتَّخَذَ إِلىٰ رَبِّهِ مَآبًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxii{إِنّا أَنذَرناكُم عَذابًا قَريبًا يَومَ يَنظُرُ المَرءُ ما قَدَّمَت يَداهُ وَيَقولُ الكافِرُ يا لَيتَني كُنتُ تُرابًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxiii{\basmalah وَالنّازِعاتِ غَرقًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdccxiv{وَالنّاشِطاتِ نَشطًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxv{وَالسّابِحاتِ سَبحًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxvi{فَالسّابِقاتِ سَبقًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxvii{فَالمُدَبِّراتِ أَمرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxviii{يَومَ تَرجُفُ الرّاجِفَةُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxix{تَتبَعُهَا الرّادِفَةُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxx{قُلوبٌ يَومَئِذٍ واجِفَةٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxxi{أَبصارُها خاشِعَةٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxxii{يَقولونَ أَإِنّا لَمَردودونَ فِي الحافِرَةِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxxiii{أَإِذا كُنّا عِظامًا نَخِرَةً\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdccxxiv{قالوا تِلكَ إِذًا كَرَّةٌ خاسِرَةٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxxv{فَإِنَّما هِيَ زَجرَةٌ واحِدَةٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxxvi{فَإِذا هُم بِالسّاهِرَةِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxxvii{هَل أَتاكَ حَديثُ موسىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxxviii{إِذ ناداهُ رَبُّهُ بِالوادِ المُقَدَّسِ طُوًى\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxxix{اذهَب إِلىٰ فِرعَونَ إِنَّهُ طَغىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxxx{فَقُل هَل لَكَ إِلىٰ أَن تَزَكّىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxi{وَأَهدِيَكَ إِلىٰ رَبِّكَ فَتَخشىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxii{فَأَراهُ الآيَةَ الكُبرىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxiii{فَكَذَّبَ وَعَصىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxiv{ثُمَّ أَدبَرَ يَسعىٰ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxv{فَحَشَرَ فَنادىٰ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxvi{فَقالَ أَنا رَبُّكُمُ الأَعلىٰ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxvii{فَأَخَذَهُ اللَّهُ نَكالَ الآخِرَةِ وَالأولىٰ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxviii{إِنَّ في ذٰلِكَ لَعِبرَةً لِمَن يَخشىٰ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxix{أَأَنتُم أَشَدُّ خَلقًا أَمِ السَّماءُ ۚ بَناها\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxl{رَفَعَ سَمكَها فَسَوّاها\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxli{وَأَغطَشَ لَيلَها وَأَخرَجَ ضُحاها\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxlii{وَالأَرضَ بَعدَ ذٰلِكَ دَحاها\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxliii{أَخرَجَ مِنها ماءَها وَمَرعاها\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdccxliv{وَالجِبالَ أَرساها\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxlv{مَتاعًا لَكُم وَلِأَنعامِكُم\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxlvi{فَإِذا جاءَتِ الطّامَّةُ الكُبرىٰ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxlvii{يَومَ يَتَذَكَّرُ الإِنسانُ ما سَعىٰ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxlviii{وَبُرِّزَتِ الجَحيمُ لِمَن يَرىٰ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxlix{فَأَمّا مَن طَغىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdccl{وَآثَرَ الحَياةَ الدُّنيا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdccli{فَإِنَّ الجَحيمَ هِيَ المَأوىٰ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclii{وَأَمّا مَن خافَ مَقامَ رَبِّهِ وَنَهَى النَّفسَ عَنِ الهَوىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdccliii{فَإِنَّ الجَنَّةَ هِيَ المَأوىٰ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdccliv{يَسأَلونَكَ عَنِ السّاعَةِ أَيّانَ مُرساها\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclv{فيمَ أَنتَ مِن ذِكراها\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclvi{إِلىٰ رَبِّكَ مُنتَهاها\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclvii{إِنَّما أَنتَ مُنذِرُ مَن يَخشاها\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclviii{كَأَنَّهُم يَومَ يَرَونَها لَم يَلبَثوا إِلّا عَشِيَّةً أَو ضُحاها\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclix{\basmalah عَبَسَ وَتَوَلّىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcclx{أَن جاءَهُ الأَعمىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclxi{وَما يُدريكَ لَعَلَّهُ يَزَّكّىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclxii{أَو يَذَّكَّرُ فَتَنفَعَهُ الذِّكرىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclxiii{أَمّا مَنِ استَغنىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclxiv{فَأَنتَ لَهُ تَصَدّىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclxv{وَما عَلَيكَ أَلّا يَزَّكّىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcclxvi{وَأَمّا مَن جاءَكَ يَسعىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcclxvii{وَهُوَ يَخشىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclxviii{فَأَنتَ عَنهُ تَلَهّىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcclxix{كَلّا إِنَّها تَذكِرَةٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcclxx{فَمَن شاءَ ذَكَرَهُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxi{في صُحُفٍ مُكَرَّمَةٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxii{مَرفوعَةٍ مُطَهَّرَةٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxiii{بِأَيدي سَفَرَةٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxiv{كِرامٍ بَرَرَةٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxv{قُتِلَ الإِنسانُ ما أَكفَرَهُ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxvi{مِن أَيِّ شَيءٍ خَلَقَهُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxvii{مِن نُطفَةٍ خَلَقَهُ فَقَدَّرَهُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxviii{ثُمَّ السَّبيلَ يَسَّرَهُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxix{ثُمَّ أَماتَهُ فَأَقبَرَهُ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxx{ثُمَّ إِذا شاءَ أَنشَرَهُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxi{كَلّا لَمّا يَقضِ ما أَمَرَهُ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxii{فَليَنظُرِ الإِنسانُ إِلىٰ طَعامِهِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxiii{أَنّا صَبَبنَا الماءَ صَبًّا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxiv{ثُمَّ شَقَقنَا الأَرضَ شَقًّا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxv{فَأَنبَتنا فيها حَبًّا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxvi{وَعِنَبًا وَقَضبًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxvii{وَزَيتونًا وَنَخلًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxviii{وَحَدائِقَ غُلبًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxix{وَفاكِهَةً وَأَبًّا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdccxc{مَتاعًا لَكُم وَلِأَنعامِكُم\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxci{فَإِذا جاءَتِ الصّاخَّةُ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxcii{يَومَ يَفِرُّ المَرءُ مِن أَخيهِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxciii{وَأُمِّهِ وَأَبيهِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxciv{وَصاحِبَتِهِ وَبَنيهِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxcv{لِكُلِّ امرِئٍ مِنهُم يَومَئِذٍ شَأنٌ يُغنيهِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxcvi{وُجوهٌ يَومَئِذٍ مُسفِرَةٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxcvii{ضاحِكَةٌ مُستَبشِرَةٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxcviii{وَوُجوهٌ يَومَئِذٍ عَلَيها غَبَرَةٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxcix{تَرهَقُها قَتَرَةٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdccc{أُولٰئِكَ هُمُ الكَفَرَةُ الفَجَرَةُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdccci{\basmalah إِذَا الشَّمسُ كُوِّرَت\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcccii{وَإِذَا النُّجومُ انكَدَرَت\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdccciii{وَإِذَا الجِبالُ سُيِّرَت\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccciv{وَإِذَا العِشارُ عُطِّلَت\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccv{وَإِذَا الوُحوشُ حُشِرَت\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccvi{وَإِذَا البِحارُ سُجِّرَت\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccvii{وَإِذَا النُّفوسُ زُوِّجَت\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccviii{وَإِذَا المَوءودَةُ سُئِلَت\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccix{بِأَيِّ ذَنبٍ قُتِلَت\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccx{وَإِذَا الصُّحُفُ نُشِرَت\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxi{وَإِذَا السَّماءُ كُشِطَت\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxii{وَإِذَا الجَحيمُ سُعِّرَت\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxiii{وَإِذَا الجَنَّةُ أُزلِفَت\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxiv{عَلِمَت نَفسٌ ما أَحضَرَت\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxv{فَلا أُقسِمُ بِالخُنَّسِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxvi{الجَوارِ الكُنَّسِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxvii{وَاللَّيلِ إِذا عَسعَسَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxviii{وَالصُّبحِ إِذا تَنَفَّسَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxix{إِنَّهُ لَقَولُ رَسولٍ كَريمٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxx{ذي قُوَّةٍ عِندَ ذِي العَرشِ مَكينٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxi{مُطاعٍ ثَمَّ أَمينٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxii{وَما صاحِبُكُم بِمَجنونٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxiii{وَلَقَد رَآهُ بِالأُفُقِ المُبينِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxiv{وَما هُوَ عَلَى الغَيبِ بِضَنينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxv{وَما هُوَ بِقَولِ شَيطانٍ رَجيمٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxvi{فَأَينَ تَذهَبونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxvii{إِن هُوَ إِلّا ذِكرٌ لِلعالَمينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxviii{لِمَن شاءَ مِنكُم أَن يَستَقيمَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxix{وَما تَشاءونَ إِلّا أَن يَشاءَ اللَّهُ رَبُّ العالَمينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxx{\basmalah إِذَا السَّماءُ انفَطَرَت\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxi{وَإِذَا الكَواكِبُ انتَثَرَت\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxii{وَإِذَا البِحارُ فُجِّرَت\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxiii{وَإِذَا القُبورُ بُعثِرَت\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxiv{عَلِمَت نَفسٌ ما قَدَّمَت وَأَخَّرَت\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxv{يا أَيُّهَا الإِنسانُ ما غَرَّكَ بِرَبِّكَ الكَريمِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxvi{الَّذي خَلَقَكَ فَسَوّاكَ فَعَدَلَكَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxvii{في أَيِّ صورَةٍ ما شاءَ رَكَّبَكَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxviii{كَلّا بَل تُكَذِّبونَ بِالدّينِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxix{وَإِنَّ عَلَيكُم لَحافِظينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxl{كِرامًا كاتِبينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxli{يَعلَمونَ ما تَفعَلونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlii{إِنَّ الأَبرارَ لَفي نَعيمٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxliii{وَإِنَّ الفُجّارَ لَفي جَحيمٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxliv{يَصلَونَها يَومَ الدّينِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlv{وَما هُم عَنها بِغائِبينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlvi{وَما أَدراكَ ما يَومُ الدّينِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlvii{ثُمَّ ما أَدراكَ ما يَومُ الدّينِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlviii{يَومَ لا تَملِكُ نَفسٌ لِنَفسٍ شَيئًا ۖ وَالأَمرُ يَومَئِذٍ لِلَّهِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlix{\basmalah وَيلٌ لِلمُطَفِّفينَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcccl{الَّذينَ إِذَا اكتالوا عَلَى النّاسِ يَستَوفونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccli{وَإِذا كالوهُم أَو وَزَنوهُم يُخسِرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclii{أَلا يَظُنُّ أُولٰئِكَ أَنَّهُم مَبعوثونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccliii{لِيَومٍ عَظيمٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccliv{يَومَ يَقومُ النّاسُ لِرَبِّ العالَمينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclv{كَلّا إِنَّ كِتابَ الفُجّارِ لَفي سِجّينٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdccclvi{وَما أَدراكَ ما سِجّينٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdccclvii{كِتابٌ مَرقومٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdccclviii{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdccclix{الَّذينَ يُكَذِّبونَ بِيَومِ الدّينِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdccclx{وَما يُكَذِّبُ بِهِ إِلّا كُلُّ مُعتَدٍ أَثيمٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxi{إِذا تُتلىٰ عَلَيهِ آياتُنا قالَ أَساطيرُ الأَوَّلينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxii{كَلّا ۖ بَل ۜ رانَ عَلىٰ قُلوبِهِم ما كانوا يَكسِبونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxiii{كَلّا إِنَّهُم عَن رَبِّهِم يَومَئِذٍ لَمَحجوبونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdccclxiv{ثُمَّ إِنَّهُم لَصالُو الجَحيمِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclxv{ثُمَّ يُقالُ هٰذَا الَّذي كُنتُم بِهِ تُكَذِّبونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdccclxvi{كَلّا إِنَّ كِتابَ الأَبرارِ لَفي عِلِّيّينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdccclxvii{وَما أَدراكَ ما عِلِّيّونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdccclxviii{كِتابٌ مَرقومٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdccclxix{يَشهَدُهُ المُقَرَّبونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdccclxx{إِنَّ الأَبرارَ لَفي نَعيمٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxi{عَلَى الأَرائِكِ يَنظُرونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxii{تَعرِفُ في وُجوهِهِم نَضرَةَ النَّعيمِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxiii{يُسقَونَ مِن رَحيقٍ مَختومٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxiv{خِتامُهُ مِسكٌ ۚ وَفي ذٰلِكَ فَليَتَنافَسِ المُتَنافِسونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxv{وَمِزاجُهُ مِن تَسنيمٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxvi{عَينًا يَشرَبُ بِهَا المُقَرَّبونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxvii{إِنَّ الَّذينَ أَجرَموا كانوا مِنَ الَّذينَ آمَنوا يَضحَكونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxviii{وَإِذا مَرّوا بِهِم يَتَغامَزونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxix{وَإِذَا انقَلَبوا إِلىٰ أَهلِهِمُ انقَلَبوا فَكِهينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxx{وَإِذا رَأَوهُم قالوا إِنَّ هٰؤُلاءِ لَضالّونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxi{وَما أُرسِلوا عَلَيهِم حافِظينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxii{فَاليَومَ الَّذينَ آمَنوا مِنَ الكُفّارِ يَضحَكونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxiii{عَلَى الأَرائِكِ يَنظُرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxiv{هَل ثُوِّبَ الكُفّارُ ما كانوا يَفعَلونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxv{\basmalah إِذَا السَّماءُ انشَقَّت\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxvi{وَأَذِنَت لِرَبِّها وَحُقَّت\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxvii{وَإِذَا الأَرضُ مُدَّت\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxviii{وَأَلقَت ما فيها وَتَخَلَّت\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxix{وَأَذِنَت لِرَبِّها وَحُقَّت\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxc{يا أَيُّهَا الإِنسانُ إِنَّكَ كادِحٌ إِلىٰ رَبِّكَ كَدحًا فَمُلاقيهِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxci{فَأَمّا مَن أوتِيَ كِتابَهُ بِيَمينِهِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcii{فَسَوفَ يُحاسَبُ حِسابًا يَسيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxciii{وَيَنقَلِبُ إِلىٰ أَهلِهِ مَسرورًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxciv{وَأَمّا مَن أوتِيَ كِتابَهُ وَراءَ ظَهرِهِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcv{فَسَوفَ يَدعو ثُبورًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcvi{وَيَصلىٰ سَعيرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcvii{إِنَّهُ كانَ في أَهلِهِ مَسرورًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcviii{إِنَّهُ ظَنَّ أَن لَن يَحورَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcix{بَلىٰ إِنَّ رَبَّهُ كانَ بِهِ بَصيرًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcm{فَلا أُقسِمُ بِالشَّفَقِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmi{وَاللَّيلِ وَما وَسَقَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmii{وَالقَمَرِ إِذَا اتَّسَقَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmiii{لَتَركَبُنَّ طَبَقًا عَن طَبَقٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmiv{فَما لَهُم لا يُؤمِنونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcmv{وَإِذا قُرِئَ عَلَيهِمُ القُرآنُ لا يَسجُدونَ ۩\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcmvi{بَلِ الَّذينَ كَفَروا يُكَذِّبونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcmvii{وَاللَّهُ أَعلَمُ بِما يوعونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcmviii{فَبَشِّرهُم بِعَذابٍ أَليمٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcmix{إِلَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لَهُم أَجرٌ غَيرُ مَمنونٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcmx{\basmalah وَالسَّماءِ ذاتِ البُروجِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmxi{وَاليَومِ المَوعودِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxii{وَشاهِدٍ وَمَشهودٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxiii{قُتِلَ أَصحابُ الأُخدودِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxiv{النّارِ ذاتِ الوَقودِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxv{إِذ هُم عَلَيها قُعودٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxvi{وَهُم عَلىٰ ما يَفعَلونَ بِالمُؤمِنينَ شُهودٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxvii{وَما نَقَموا مِنهُم إِلّا أَن يُؤمِنوا بِاللَّهِ العَزيزِ الحَميدِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmxviii{الَّذي لَهُ مُلكُ السَّماواتِ وَالأَرضِ ۚ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmxix{إِنَّ الَّذينَ فَتَنُوا المُؤمِنينَ وَالمُؤمِناتِ ثُمَّ لَم يَتوبوا فَلَهُم عَذابُ جَهَنَّمَ وَلَهُم عَذابُ الحَريقِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmxx{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ لَهُم جَنّاتٌ تَجري مِن تَحتِهَا الأَنهارُ ۚ ذٰلِكَ الفَوزُ الكَبيرُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmxxi{إِنَّ بَطشَ رَبِّكَ لَشَديدٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxxii{إِنَّهُ هُوَ يُبدِئُ وَيُعيدُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxxiii{وَهُوَ الغَفورُ الوَدودُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxxiv{ذُو العَرشِ المَجيدُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxxv{فَعّالٌ لِما يُريدُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxxvi{هَل أَتاكَ حَديثُ الجُنودِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxxvii{فِرعَونَ وَثَمودَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmxxviii{بَلِ الَّذينَ كَفَروا في تَكذيبٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmxxix{وَاللَّهُ مِن وَرائِهِم مُحيطٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcmxxx{بَل هُوَ قُرآنٌ مَجيدٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxi{في لَوحٍ مَحفوظٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxii{\basmalah وَالسَّماءِ وَالطّارِقِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxiii{وَما أَدراكَ مَا الطّارِقُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxiv{النَّجمُ الثّاقِبُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxv{إِن كُلُّ نَفسٍ لَمّا عَلَيها حافِظٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxvi{فَليَنظُرِ الإِنسانُ مِمَّ خُلِقَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxvii{خُلِقَ مِن ماءٍ دافِقٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxviii{يَخرُجُ مِن بَينِ الصُّلبِ وَالتَّرائِبِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxix{إِنَّهُ عَلىٰ رَجعِهِ لَقادِرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmxl{يَومَ تُبلَى السَّرائِرُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmxli{فَما لَهُ مِن قُوَّةٍ وَلا ناصِرٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmxlii{وَالسَّماءِ ذاتِ الرَّجعِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmxliii{وَالأَرضِ ذاتِ الصَّدعِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxliv{إِنَّهُ لَقَولٌ فَصلٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxlv{وَما هُوَ بِالهَزلِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxlvi{إِنَّهُم يَكيدونَ كَيدًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxlvii{وَأَكيدُ كَيدًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxlviii{فَمَهِّلِ الكافِرينَ أَمهِلهُم رُوَيدًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxlix{\basmalah سَبِّحِ اسمَ رَبِّكَ الأَعلَى\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcml{الَّذي خَلَقَ فَسَوّىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmli{وَالَّذي قَدَّرَ فَهَدىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlii{وَالَّذي أَخرَجَ المَرعىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmliii{فَجَعَلَهُ غُثاءً أَحوىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmliv{سَنُقرِئُكَ فَلا تَنسىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlv{إِلّا ما شاءَ اللَّهُ ۚ إِنَّهُ يَعلَمُ الجَهرَ وَما يَخفىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlvi{وَنُيَسِّرُكَ لِليُسرىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlvii{فَذَكِّر إِن نَفَعَتِ الذِّكرىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlviii{سَيَذَّكَّرُ مَن يَخشىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmlix{وَيَتَجَنَّبُهَا الأَشقَى\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmlx{الَّذي يَصلَى النّارَ الكُبرىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmlxi{ثُمَّ لا يَموتُ فيها وَلا يَحيىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlxii{قَد أَفلَحَ مَن تَزَكّىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmlxiii{وَذَكَرَ اسمَ رَبِّهِ فَصَلّىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmlxiv{بَل تُؤثِرونَ الحَياةَ الدُّنيا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlxv{وَالآخِرَةُ خَيرٌ وَأَبقىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlxvi{إِنَّ هٰذا لَفِي الصُّحُفِ الأولىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlxvii{صُحُفِ إِبراهيمَ وَموسىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlxviii{\basmalah هَل أَتاكَ حَديثُ الغاشِيَةِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmlxix{وُجوهٌ يَومَئِذٍ خاشِعَةٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmlxx{عامِلَةٌ ناصِبَةٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxi{تَصلىٰ نارًا حامِيَةً\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxii{تُسقىٰ مِن عَينٍ آنِيَةٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxiii{لَيسَ لَهُم طَعامٌ إِلّا مِن ضَريعٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxiv{لا يُسمِنُ وَلا يُغني مِن جوعٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxv{وُجوهٌ يَومَئِذٍ ناعِمَةٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxvi{لِسَعيِها راضِيَةٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxvii{في جَنَّةٍ عالِيَةٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxviii{لا تَسمَعُ فيها لاغِيَةً\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxix{فيها عَينٌ جارِيَةٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxx{فيها سُرُرٌ مَرفوعَةٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxi{وَأَكوابٌ مَوضوعَةٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxii{وَنَمارِقُ مَصفوفَةٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxiii{وَزَرابِيُّ مَبثوثَةٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxiv{أَفَلا يَنظُرونَ إِلَى الإِبِلِ كَيفَ خُلِقَت\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxv{وَإِلَى السَّماءِ كَيفَ رُفِعَت\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxvi{وَإِلَى الجِبالِ كَيفَ نُصِبَت\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxvii{وَإِلَى الأَرضِ كَيفَ سُطِحَت\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxviii{فَذَكِّر إِنَّما أَنتَ مُذَكِّرٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxix{لَستَ عَلَيهِم بِمُصَيطِرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxc{إِلّا مَن تَوَلّىٰ وَكَفَرَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxci{فَيُعَذِّبُهُ اللَّهُ العَذابَ الأَكبَرَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxcii{إِنَّ إِلَينا إِيابَهُم\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxciii{ثُمَّ إِنَّ عَلَينا حِسابَهُم\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxciv{\basmalah وَالفَجرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmxcv{وَلَيالٍ عَشرٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxcvi{وَالشَّفعِ وَالوَترِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxcvii{وَاللَّيلِ إِذا يَسرِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxcviii{هَل في ذٰلِكَ قَسَمٌ لِذي حِجرٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxcix{أَلَم تَرَ كَيفَ فَعَلَ رَبُّكَ بِعادٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmm{إِرَمَ ذاتِ العِمادِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmi{الَّتي لَم يُخلَق مِثلُها فِي البِلادِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmii{وَثَمودَ الَّذينَ جابُوا الصَّخرَ بِالوادِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmiii{وَفِرعَونَ ذِي الأَوتادِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmiv{الَّذينَ طَغَوا فِي البِلادِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmv{فَأَكثَروا فيهَا الفَسادَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmvi{فَصَبَّ عَلَيهِم رَبُّكَ سَوطَ عَذابٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmvii{إِنَّ رَبَّكَ لَبِالمِرصادِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmviii{فَأَمَّا الإِنسانُ إِذا مَا ابتَلاهُ رَبُّهُ فَأَكرَمَهُ وَنَعَّمَهُ فَيَقولُ رَبّي أَكرَمَنِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmix{وَأَمّا إِذا مَا ابتَلاهُ فَقَدَرَ عَلَيهِ رِزقَهُ فَيَقولُ رَبّي أَهانَنِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmx{كَلّا ۖ بَل لا تُكرِمونَ اليَتيمَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmxi{وَلا تَحاضّونَ عَلىٰ طَعامِ المِسكينِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmxii{وَتَأكُلونَ التُّراثَ أَكلًا لَمًّا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmxiii{وَتُحِبّونَ المالَ حُبًّا جَمًّا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmmxiv{كَلّا إِذا دُكَّتِ الأَرضُ دَكًّا دَكًّا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmmxv{وَجاءَ رَبُّكَ وَالمَلَكُ صَفًّا صَفًّا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmmxvi{وَجِيءَ يَومَئِذٍ بِجَهَنَّمَ ۚ يَومَئِذٍ يَتَذَكَّرُ الإِنسانُ وَأَنّىٰ لَهُ الذِّكرىٰ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmmxvii{يَقولُ يا لَيتَني قَدَّمتُ لِحَياتي\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmmxviii{فَيَومَئِذٍ لا يُعَذِّبُ عَذابَهُ أَحَدٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmmxix{وَلا يوثِقُ وَثاقَهُ أَحَدٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmmxx{يا أَيَّتُهَا النَّفسُ المُطمَئِنَّةُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmmxxi{ارجِعي إِلىٰ رَبِّكِ راضِيَةً مَرضِيَّةً\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmmxxii{فَادخُلي في عِبادي\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmmxxiii{وَادخُلي جَنَّتي\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmmxxiv{\basmalah لا أُقسِمُ بِهٰذَا البَلَدِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmxxv{وَأَنتَ حِلٌّ بِهٰذَا البَلَدِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmxxvi{وَوالِدٍ وَما وَلَدَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmxxvii{لَقَد خَلَقنَا الإِنسانَ في كَبَدٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmxxviii{أَيَحسَبُ أَن لَن يَقدِرَ عَلَيهِ أَحَدٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmxxix{يَقولُ أَهلَكتُ مالًا لُبَدًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmxxx{أَيَحسَبُ أَن لَم يَرَهُ أَحَدٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmxxxi{أَلَم نَجعَل لَهُ عَينَينِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmxxxii{وَلِسانًا وَشَفَتَينِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmxxxiii{وَهَدَيناهُ النَّجدَينِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmxxxiv{فَلَا اقتَحَمَ العَقَبَةَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmxxxv{وَما أَدراكَ مَا العَقَبَةُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmxxxvi{فَكُّ رَقَبَةٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmxxxvii{أَو إِطعامٌ في يَومٍ ذي مَسغَبَةٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmxxxviii{يَتيمًا ذا مَقرَبَةٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmxxxix{أَو مِسكينًا ذا مَترَبَةٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmxl{ثُمَّ كانَ مِنَ الَّذينَ آمَنوا وَتَواصَوا بِالصَّبرِ وَتَواصَوا بِالمَرحَمَةِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmxli{أُولٰئِكَ أَصحابُ المَيمَنَةِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmxlii{وَالَّذينَ كَفَروا بِآياتِنا هُم أَصحابُ المَشأَمَةِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmxliii{عَلَيهِم نارٌ مُؤصَدَةٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmmxliv{\basmalah وَالشَّمسِ وَضُحاها\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmxlv{وَالقَمَرِ إِذا تَلاها\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmxlvi{وَالنَّهارِ إِذا جَلّاها\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmxlvii{وَاللَّيلِ إِذا يَغشاها\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmxlviii{وَالسَّماءِ وَما بَناها\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmxlix{وَالأَرضِ وَما طَحاها\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmml{وَنَفسٍ وَما سَوّاها\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmli{فَأَلهَمَها فُجورَها وَتَقواها\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmlii{قَد أَفلَحَ مَن زَكّاها\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmliii{وَقَد خابَ مَن دَسّاها\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmliv{كَذَّبَت ثَمودُ بِطَغواها\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmlv{إِذِ انبَعَثَ أَشقاها\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmlvi{فَقالَ لَهُم رَسولُ اللَّهِ ناقَةَ اللَّهِ وَسُقياها\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmlvii{فَكَذَّبوهُ فَعَقَروها فَدَمدَمَ عَلَيهِم رَبُّهُم بِذَنبِهِم فَسَوّاها\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmlviii{وَلا يَخافُ عُقباها\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmlix{\basmalah وَاللَّيلِ إِذا يَغشىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmlx{وَالنَّهارِ إِذا تَجَلّىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmlxi{وَما خَلَقَ الذَّكَرَ وَالأُنثىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmlxii{إِنَّ سَعيَكُم لَشَتّىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmlxiii{فَأَمّا مَن أَعطىٰ وَاتَّقىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmlxiv{وَصَدَّقَ بِالحُسنىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmlxv{فَسَنُيَسِّرُهُ لِليُسرىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmlxvi{وَأَمّا مَن بَخِلَ وَاستَغنىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmlxvii{وَكَذَّبَ بِالحُسنىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmlxviii{فَسَنُيَسِّرُهُ لِلعُسرىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmlxix{وَما يُغني عَنهُ مالُهُ إِذا تَرَدّىٰ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmlxx{إِنَّ عَلَينا لَلهُدىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmlxxi{وَإِنَّ لَنا لَلآخِرَةَ وَالأولىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmlxxii{فَأَنذَرتُكُم نارًا تَلَظّىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmlxxiii{لا يَصلاها إِلَّا الأَشقَى\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmlxxiv{الَّذي كَذَّبَ وَتَوَلّىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmlxxv{وَسَيُجَنَّبُهَا الأَتقَى\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmlxxvi{الَّذي يُؤتي مالَهُ يَتَزَكّىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmlxxvii{وَما لِأَحَدٍ عِندَهُ مِن نِعمَةٍ تُجزىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmlxxviii{إِلَّا ابتِغاءَ وَجهِ رَبِّهِ الأَعلىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmmlxxix{وَلَسَوفَ يَرضىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmmlxxx{\basmalah وَالضُّحىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxi{وَاللَّيلِ إِذا سَجىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxii{ما وَدَّعَكَ رَبُّكَ وَما قَلىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxiii{وَلَلآخِرَةُ خَيرٌ لَكَ مِنَ الأولىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxiv{وَلَسَوفَ يُعطيكَ رَبُّكَ فَتَرضىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxv{أَلَم يَجِدكَ يَتيمًا فَآوىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxvi{وَوَجَدَكَ ضالًّا فَهَدىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxvii{وَوَجَدَكَ عائِلًا فَأَغنىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxviii{فَأَمَّا اليَتيمَ فَلا تَقهَر\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxix{وَأَمَّا السّائِلَ فَلا تَنهَر\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmxc{وَأَمّا بِنِعمَةِ رَبِّكَ فَحَدِّث\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmxci{\basmalah أَلَم نَشرَح لَكَ صَدرَكَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmxcii{وَوَضَعنا عَنكَ وِزرَكَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmxciii{الَّذي أَنقَضَ ظَهرَكَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmxciv{وَرَفَعنا لَكَ ذِكرَكَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmxcv{فَإِنَّ مَعَ العُسرِ يُسرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmxcvi{إِنَّ مَعَ العُسرِ يُسرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmxcvii{فَإِذا فَرَغتَ فَانصَب\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmxcviii{وَإِلىٰ رَبِّكَ فَارغَب\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmxcix{\basmalah وَالتّينِ وَالزَّيتونِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmc{وَطورِ سينينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmci{وَهٰذَا البَلَدِ الأَمينِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcii{لَقَد خَلَقنَا الإِنسانَ في أَحسَنِ تَقويمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmciii{ثُمَّ رَدَدناهُ أَسفَلَ سافِلينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmciv{إِلَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ فَلَهُم أَجرٌ غَيرُ مَمنونٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcv{فَما يُكَذِّبُكَ بَعدُ بِالدّينِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcvi{أَلَيسَ اللَّهُ بِأَحكَمِ الحاكِمينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcvii{\basmalah اقرَأ بِاسمِ رَبِّكَ الَّذي خَلَقَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcviii{خَلَقَ الإِنسانَ مِن عَلَقٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcix{اقرَأ وَرَبُّكَ الأَكرَمُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcx{الَّذي عَلَّمَ بِالقَلَمِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxi{عَلَّمَ الإِنسانَ ما لَم يَعلَم\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxii{كَلّا إِنَّ الإِنسانَ لَيَطغىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxiii{أَن رَآهُ استَغنىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxiv{إِنَّ إِلىٰ رَبِّكَ الرُّجعىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxv{أَرَأَيتَ الَّذي يَنهىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmcxvi{عَبدًا إِذا صَلّىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmcxvii{أَرَأَيتَ إِن كانَ عَلَى الهُدىٰ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmcxviii{أَو أَمَرَ بِالتَّقوىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxix{أَرَأَيتَ إِن كَذَّبَ وَتَوَلّىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxx{أَلَم يَعلَم بِأَنَّ اللَّهَ يَرىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxxi{كَلّا لَئِن لَم يَنتَهِ لَنَسفَعًا بِالنّاصِيَةِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxxii{ناصِيَةٍ كاذِبَةٍ خاطِئَةٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxxiii{فَليَدعُ نادِيَهُ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxxiv{سَنَدعُ الزَّبانِيَةَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxxv{كَلّا لا تُطِعهُ وَاسجُد وَاقتَرِب ۩\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmcxxvi{\basmalah إِنّا أَنزَلناهُ في لَيلَةِ القَدرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxxvii{وَما أَدراكَ ما لَيلَةُ القَدرِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxxviii{لَيلَةُ القَدرِ خَيرٌ مِن أَلفِ شَهرٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxxix{تَنَزَّلُ المَلائِكَةُ وَالرّوحُ فيها بِإِذنِ رَبِّهِم مِن كُلِّ أَمرٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxxx{سَلامٌ هِيَ حَتّىٰ مَطلَعِ الفَجرِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxi{\basmalah لَم يَكُنِ الَّذينَ كَفَروا مِن أَهلِ الكِتابِ وَالمُشرِكينَ مُنفَكّينَ حَتّىٰ تَأتِيَهُمُ البَيِّنَةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxii{رَسولٌ مِنَ اللَّهِ يَتلو صُحُفًا مُطَهَّرَةً\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxiii{فيها كُتُبٌ قَيِّمَةٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxiv{وَما تَفَرَّقَ الَّذينَ أوتُوا الكِتابَ إِلّا مِن بَعدِ ما جاءَتهُمُ البَيِّنَةُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxv{وَما أُمِروا إِلّا لِيَعبُدُوا اللَّهَ مُخلِصينَ لَهُ الدّينَ حُنَفاءَ وَيُقيمُوا الصَّلاةَ وَيُؤتُوا الزَّكاةَ ۚ وَذٰلِكَ دينُ القَيِّمَةِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxvi{إِنَّ الَّذينَ كَفَروا مِن أَهلِ الكِتابِ وَالمُشرِكينَ في نارِ جَهَنَّمَ خالِدينَ فيها ۚ أُولٰئِكَ هُم شَرُّ البَرِيَّةِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxvii{إِنَّ الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ أُولٰئِكَ هُم خَيرُ البَرِيَّةِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxviii{جَزاؤُهُم عِندَ رَبِّهِم جَنّاتُ عَدنٍ تَجري مِن تَحتِهَا الأَنهارُ خالِدينَ فيها أَبَدًا ۖ رَضِيَ اللَّهُ عَنهُم وَرَضوا عَنهُ ۚ ذٰلِكَ لِمَن خَشِيَ رَبَّهُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxix{\basmalah إِذا زُلزِلَتِ الأَرضُ زِلزالَها\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxl{وَأَخرَجَتِ الأَرضُ أَثقالَها\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxli{وَقالَ الإِنسانُ ما لَها\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxlii{يَومَئِذٍ تُحَدِّثُ أَخبارَها\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxliii{بِأَنَّ رَبَّكَ أَوحىٰ لَها\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxliv{يَومَئِذٍ يَصدُرُ النّاسُ أَشتاتًا لِيُرَوا أَعمالَهُم\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxlv{فَمَن يَعمَل مِثقالَ ذَرَّةٍ خَيرًا يَرَهُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxlvi{وَمَن يَعمَل مِثقالَ ذَرَّةٍ شَرًّا يَرَهُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxlvii{\basmalah وَالعادِياتِ ضَبحًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxlviii{فَالمورِياتِ قَدحًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxlix{فَالمُغيراتِ صُبحًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcl{فَأَثَرنَ بِهِ نَقعًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcli{فَوَسَطنَ بِهِ جَمعًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclii{إِنَّ الإِنسانَ لِرَبِّهِ لَكَنودٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcliii{وَإِنَّهُ عَلىٰ ذٰلِكَ لَشَهيدٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcliv{وَإِنَّهُ لِحُبِّ الخَيرِ لَشَديدٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclv{۞ أَفَلا يَعلَمُ إِذا بُعثِرَ ما فِي القُبورِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmclvi{وَحُصِّلَ ما فِي الصُّدورِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmclvii{إِنَّ رَبَّهُم بِهِم يَومَئِذٍ لَخَبيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmclviii{\basmalah القارِعَةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclix{مَا القارِعَةُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclx{وَما أَدراكَ مَا القارِعَةُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxi{يَومَ يَكونُ النّاسُ كَالفَراشِ المَبثوثِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmclxii{وَتَكونُ الجِبالُ كَالعِهنِ المَنفوشِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclxiii{فَأَمّا مَن ثَقُلَت مَوازينُهُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmclxiv{فَهُوَ في عيشَةٍ راضِيَةٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmclxv{وَأَمّا مَن خَفَّت مَوازينُهُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclxvi{فَأُمُّهُ هاوِيَةٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmclxvii{وَما أَدراكَ ما هِيَه\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmclxviii{نارٌ حامِيَةٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmclxix{\basmalah أَلهاكُمُ التَّكاثُرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclxx{حَتّىٰ زُرتُمُ المَقابِرَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclxxi{كَلّا سَوفَ تَعلَمونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxxii{ثُمَّ كَلّا سَوفَ تَعلَمونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmclxxiii{كَلّا لَو تَعلَمونَ عِلمَ اليَقينِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclxxiv{لَتَرَوُنَّ الجَحيمَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmclxxv{ثُمَّ لَتَرَوُنَّها عَينَ اليَقينِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmclxxvi{ثُمَّ لَتُسأَلُنَّ يَومَئِذٍ عَنِ النَّعيمِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclxxvii{\basmalah وَالعَصرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclxxviii{إِنَّ الإِنسانَ لَفي خُسرٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclxxix{إِلَّا الَّذينَ آمَنوا وَعَمِلُوا الصّالِحاتِ وَتَواصَوا بِالحَقِّ وَتَواصَوا بِالصَّبرِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxxx{\basmalah وَيلٌ لِكُلِّ هُمَزَةٍ لُمَزَةٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxi{الَّذي جَمَعَ مالًا وَعَدَّدَهُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxii{يَحسَبُ أَنَّ مالَهُ أَخلَدَهُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxiii{كَلّا ۖ لَيُنبَذَنَّ فِي الحُطَمَةِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxiv{وَما أَدراكَ مَا الحُطَمَةُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxv{نارُ اللَّهِ الموقَدَةُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxvi{الَّتي تَطَّلِعُ عَلَى الأَفئِدَةِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxvii{إِنَّها عَلَيهِم مُؤصَدَةٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxviii{في عَمَدٍ مُمَدَّدَةٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxix{\basmalah أَلَم تَرَ كَيفَ فَعَلَ رَبُّكَ بِأَصحابِ الفيلِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxc{أَلَم يَجعَل كَيدَهُم في تَضليلٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxci{وَأَرسَلَ عَلَيهِم طَيرًا أَبابيلَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxcii{تَرميهِم بِحِجارَةٍ مِن سِجّيلٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxciii{فَجَعَلَهُم كَعَصفٍ مَأكولٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxciv{\basmalah لِإيلافِ قُرَيشٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxcv{إيلافِهِم رِحلَةَ الشِّتاءِ وَالصَّيفِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxcvi{فَليَعبُدوا رَبَّ هٰذَا البَيتِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxcvii{الَّذي أَطعَمَهُم مِن جوعٍ وَآمَنَهُم مِن خَوفٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxcviii{\basmalah أَرَأَيتَ الَّذي يُكَذِّبُ بِالدّينِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxcix{فَذٰلِكَ الَّذي يَدُعُّ اليَتيمَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcc{وَلا يَحُضُّ عَلىٰ طَعامِ المِسكينِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcci{فَوَيلٌ لِلمُصَلّينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccii{الَّذينَ هُم عَن صَلاتِهِم ساهونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcciii{الَّذينَ هُم يُراءونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcciv{وَيَمنَعونَ الماعونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmccv{\basmalah إِنّا أَعطَيناكَ الكَوثَرَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccvi{فَصَلِّ لِرَبِّكَ وَانحَر\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccvii{إِنَّ شانِئَكَ هُوَ الأَبتَرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccviii{\basmalah قُل يا أَيُّهَا الكافِرونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccix{لا أَعبُدُ ما تَعبُدونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccx{وَلا أَنتُم عابِدونَ ما أَعبُدُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxi{وَلا أَنا عابِدٌ ما عَبَدتُم\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxii{وَلا أَنتُم عابِدونَ ما أَعبُدُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxiii{لَكُم دينُكُم وَلِيَ دينِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmccxiv{\basmalah إِذا جاءَ نَصرُ اللَّهِ وَالفَتحُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxv{وَرَأَيتَ النّاسَ يَدخُلونَ في دينِ اللَّهِ أَفواجًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxvi{فَسَبِّح بِحَمدِ رَبِّكَ وَاستَغفِرهُ ۚ إِنَّهُ كانَ تَوّابًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxvii{\basmalah تَبَّت يَدا أَبي لَهَبٍ وَتَبَّ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxviii{ما أَغنىٰ عَنهُ مالُهُ وَما كَسَبَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxix{سَيَصلىٰ نارًا ذاتَ لَهَبٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxx{وَامرَأَتُهُ حَمّالَةَ الحَطَبِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxi{في جيدِها حَبلٌ مِن مَسَدٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxxii{\basmalah قُل هُوَ اللَّهُ أَحَدٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxxiii{اللَّهُ الصَّمَدُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxxiv{لَم يَلِد وَلَم يولَد\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxxv{وَلَم يَكُن لَهُ كُفُوًا أَحَدٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxvi{\basmalah قُل أَعوذُ بِرَبِّ الفَلَقِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxxvii{مِن شَرِّ ما خَلَقَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxxviii{وَمِن شَرِّ غاسِقٍ إِذا وَقَبَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxxix{وَمِن شَرِّ النَّفّاثاتِ فِي العُقَدِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxx{وَمِن شَرِّ حاسِدٍ إِذا حَسَدَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxi{\basmalah قُل أَعوذُ بِرَبِّ النّاسِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxii{مَلِكِ النّاسِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxiii{إِلٰهِ النّاسِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxiv{مِن شَرِّ الوَسواسِ الخَنّاسِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxv{الَّذي يُوَسوِسُ في صُدورِ النّاسِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxvi{مِنَ الجِنَّةِ وَالنّاسِ\qt@no{﴿٦﴾}}
