%% This is file `qurantext-uthmani.def',
%%
%% Copyright © 2015-2021
%% Seiied-Mohammad-Javad Razavian <javadr@gmail.com>
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%%
%% This work is “author-maintained” (as per LPPL maintenance status).
%%
%% The Current Maintainer of this work is Seiied-Mohammad-Javad Razavian.
%%
%% to one who has devoted his life to Quran
%%
\qt@newcmd\qurantext@i{بِسْمِ ٱللَّهِ ٱلرَّحْمَٰنِ ٱلرَّحِيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@ii{ٱلْحَمْدُ لِلَّهِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@iii{ٱلرَّحْمَٰنِ ٱلرَّحِيمِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@iv{مَٰلِكِ يَوْمِ ٱلدِّينِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@v{إِيَّاكَ نَعْبُدُ وَإِيَّاكَ نَسْتَعِينُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@vi{ٱهْدِنَا ٱلصِّرَٰطَ ٱلْمُسْتَقِيمَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@vii{صِرَٰطَ ٱلَّذِينَ أَنْعَمْتَ عَلَيْهِمْ غَيْرِ ٱلْمَغْضُوبِ عَلَيْهِمْ وَلَا ٱلضَّآلِّينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@viii{\basmalah الٓمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@ix{ذَٰلِكَ ٱلْكِتَٰبُ لَا رَيْبَ فِيهِ هُدًى لِّلْمُتَّقِينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@x{ٱلَّذِينَ يُؤْمِنُونَ بِٱلْغَيْبِ وَيُقِيمُونَ ٱلصَّلَوٰةَ وَمِمَّا رَزَقْنَٰهُمْ يُنفِقُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@xi{وَٱلَّذِينَ يُؤْمِنُونَ بِمَآ أُنزِلَ إِلَيْكَ وَمَآ أُنزِلَ مِن قَبْلِكَ وَبِٱلْءَاخِرَةِ هُمْ يُوقِنُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@xii{أُو۟لَٰٓئِكَ عَلَىٰ هُدًى مِّن رَّبِّهِمْ وَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@xiii{إِنَّ ٱلَّذِينَ كَفَرُوا۟ سَوَآءٌ عَلَيْهِمْ ءَأَنذَرْتَهُمْ أَمْ لَمْ تُنذِرْهُمْ لَا يُؤْمِنُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@xiv{خَتَمَ ٱللَّهُ عَلَىٰ قُلُوبِهِمْ وَعَلَىٰ سَمْعِهِمْ وَعَلَىٰٓ أَبْصَٰرِهِمْ غِشَٰوَةٌ وَلَهُمْ عَذَابٌ عَظِيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@xv{وَمِنَ ٱلنَّاسِ مَن يَقُولُ ءَامَنَّا بِٱللَّهِ وَبِٱلْيَوْمِ ٱلْءَاخِرِ وَمَا هُم بِمُؤْمِنِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@xvi{يُخَٰدِعُونَ ٱللَّهَ وَٱلَّذِينَ ءَامَنُوا۟ وَمَا يَخْدَعُونَ إِلَّآ أَنفُسَهُمْ وَمَا يَشْعُرُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@xvii{فِى قُلُوبِهِم مَّرَضٌ فَزَادَهُمُ ٱللَّهُ مَرَضًا وَلَهُمْ عَذَابٌ أَلِيمٌۢ بِمَا كَانُوا۟ يَكْذِبُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@xviii{وَإِذَا قِيلَ لَهُمْ لَا تُفْسِدُوا۟ فِى ٱلْأَرْضِ قَالُوٓا۟ إِنَّمَا نَحْنُ مُصْلِحُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@xix{أَلَآ إِنَّهُمْ هُمُ ٱلْمُفْسِدُونَ وَلَٰكِن لَّا يَشْعُرُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@xx{وَإِذَا قِيلَ لَهُمْ ءَامِنُوا۟ كَمَآ ءَامَنَ ٱلنَّاسُ قَالُوٓا۟ أَنُؤْمِنُ كَمَآ ءَامَنَ ٱلسُّفَهَآءُ أَلَآ إِنَّهُمْ هُمُ ٱلسُّفَهَآءُ وَلَٰكِن لَّا يَعْلَمُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@xxi{وَإِذَا لَقُوا۟ ٱلَّذِينَ ءَامَنُوا۟ قَالُوٓا۟ ءَامَنَّا وَإِذَا خَلَوْا۟ إِلَىٰ شَيَٰطِينِهِمْ قَالُوٓا۟ إِنَّا مَعَكُمْ إِنَّمَا نَحْنُ مُسْتَهْزِءُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@xxii{ٱللَّهُ يَسْتَهْزِئُ بِهِمْ وَيَمُدُّهُمْ فِى طُغْيَٰنِهِمْ يَعْمَهُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@xxiii{أُو۟لَٰٓئِكَ ٱلَّذِينَ ٱشْتَرَوُا۟ ٱلضَّلَٰلَةَ بِٱلْهُدَىٰ فَمَا رَبِحَت تِّجَٰرَتُهُمْ وَمَا كَانُوا۟ مُهْتَدِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@xxiv{مَثَلُهُمْ كَمَثَلِ ٱلَّذِى ٱسْتَوْقَدَ نَارًا فَلَمَّآ أَضَآءَتْ مَا حَوْلَهُۥ ذَهَبَ ٱللَّهُ بِنُورِهِمْ وَتَرَكَهُمْ فِى ظُلُمَٰتٍ لَّا يُبْصِرُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@xxv{صُمٌّۢ بُكْمٌ عُمْىٌ فَهُمْ لَا يَرْجِعُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@xxvi{أَوْ كَصَيِّبٍ مِّنَ ٱلسَّمَآءِ فِيهِ ظُلُمَٰتٌ وَرَعْدٌ وَبَرْقٌ يَجْعَلُونَ أَصَٰبِعَهُمْ فِىٓ ءَاذَانِهِم مِّنَ ٱلصَّوَٰعِقِ حَذَرَ ٱلْمَوْتِ وَٱللَّهُ مُحِيطٌۢ بِٱلْكَٰفِرِينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@xxvii{يَكَادُ ٱلْبَرْقُ يَخْطَفُ أَبْصَٰرَهُمْ كُلَّمَآ أَضَآءَ لَهُم مَّشَوْا۟ فِيهِ وَإِذَآ أَظْلَمَ عَلَيْهِمْ قَامُوا۟ وَلَوْ شَآءَ ٱللَّهُ لَذَهَبَ بِسَمْعِهِمْ وَأَبْصَٰرِهِمْ إِنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@xxviii{يَٰٓأَيُّهَا ٱلنَّاسُ ٱعْبُدُوا۟ رَبَّكُمُ ٱلَّذِى خَلَقَكُمْ وَٱلَّذِينَ مِن قَبْلِكُمْ لَعَلَّكُمْ تَتَّقُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@xxix{ٱلَّذِى جَعَلَ لَكُمُ ٱلْأَرْضَ فِرَٰشًا وَٱلسَّمَآءَ بِنَآءً وَأَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً فَأَخْرَجَ بِهِۦ مِنَ ٱلثَّمَرَٰتِ رِزْقًا لَّكُمْ فَلَا تَجْعَلُوا۟ لِلَّهِ أَندَادًا وَأَنتُمْ تَعْلَمُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@xxx{وَإِن كُنتُمْ فِى رَيْبٍ مِّمَّا نَزَّلْنَا عَلَىٰ عَبْدِنَا فَأْتُوا۟ بِسُورَةٍ مِّن مِّثْلِهِۦ وَٱدْعُوا۟ شُهَدَآءَكُم مِّن دُونِ ٱللَّهِ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@xxxi{فَإِن لَّمْ تَفْعَلُوا۟ وَلَن تَفْعَلُوا۟ فَٱتَّقُوا۟ ٱلنَّارَ ٱلَّتِى وَقُودُهَا ٱلنَّاسُ وَٱلْحِجَارَةُ أُعِدَّتْ لِلْكَٰفِرِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@xxxii{وَبَشِّرِ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ أَنَّ لَهُمْ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ كُلَّمَا رُزِقُوا۟ مِنْهَا مِن ثَمَرَةٍ رِّزْقًا قَالُوا۟ هَٰذَا ٱلَّذِى رُزِقْنَا مِن قَبْلُ وَأُتُوا۟ بِهِۦ مُتَشَٰبِهًا وَلَهُمْ فِيهَآ أَزْوَٰجٌ مُّطَهَّرَةٌ وَهُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@xxxiii{إِنَّ ٱللَّهَ لَا يَسْتَحْىِۦٓ أَن يَضْرِبَ مَثَلًا مَّا بَعُوضَةً فَمَا فَوْقَهَا فَأَمَّا ٱلَّذِينَ ءَامَنُوا۟ فَيَعْلَمُونَ أَنَّهُ ٱلْحَقُّ مِن رَّبِّهِمْ وَأَمَّا ٱلَّذِينَ كَفَرُوا۟ فَيَقُولُونَ مَاذَآ أَرَادَ ٱللَّهُ بِهَٰذَا مَثَلًا يُضِلُّ بِهِۦ كَثِيرًا وَيَهْدِى بِهِۦ كَثِيرًا وَمَا يُضِلُّ بِهِۦٓ إِلَّا ٱلْفَٰسِقِينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@xxxiv{ٱلَّذِينَ يَنقُضُونَ عَهْدَ ٱللَّهِ مِنۢ بَعْدِ مِيثَٰقِهِۦ وَيَقْطَعُونَ مَآ أَمَرَ ٱللَّهُ بِهِۦٓ أَن يُوصَلَ وَيُفْسِدُونَ فِى ٱلْأَرْضِ أُو۟لَٰٓئِكَ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@xxxv{كَيْفَ تَكْفُرُونَ بِٱللَّهِ وَكُنتُمْ أَمْوَٰتًا فَأَحْيَٰكُمْ ثُمَّ يُمِيتُكُمْ ثُمَّ يُحْيِيكُمْ ثُمَّ إِلَيْهِ تُرْجَعُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@xxxvi{هُوَ ٱلَّذِى خَلَقَ لَكُم مَّا فِى ٱلْأَرْضِ جَمِيعًا ثُمَّ ٱسْتَوَىٰٓ إِلَى ٱلسَّمَآءِ فَسَوَّىٰهُنَّ سَبْعَ سَمَٰوَٰتٍ وَهُوَ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@xxxvii{وَإِذْ قَالَ رَبُّكَ لِلْمَلَٰٓئِكَةِ إِنِّى جَاعِلٌ فِى ٱلْأَرْضِ خَلِيفَةً قَالُوٓا۟ أَتَجْعَلُ فِيهَا مَن يُفْسِدُ فِيهَا وَيَسْفِكُ ٱلدِّمَآءَ وَنَحْنُ نُسَبِّحُ بِحَمْدِكَ وَنُقَدِّسُ لَكَ قَالَ إِنِّىٓ أَعْلَمُ مَا لَا تَعْلَمُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@xxxviii{وَعَلَّمَ ءَادَمَ ٱلْأَسْمَآءَ كُلَّهَا ثُمَّ عَرَضَهُمْ عَلَى ٱلْمَلَٰٓئِكَةِ فَقَالَ أَنۢبِـُٔونِى بِأَسْمَآءِ هَٰٓؤُلَآءِ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@xxxix{قَالُوا۟ سُبْحَٰنَكَ لَا عِلْمَ لَنَآ إِلَّا مَا عَلَّمْتَنَآ إِنَّكَ أَنتَ ٱلْعَلِيمُ ٱلْحَكِيمُ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@xl{قَالَ يَٰٓـَٔادَمُ أَنۢبِئْهُم بِأَسْمَآئِهِمْ فَلَمَّآ أَنۢبَأَهُم بِأَسْمَآئِهِمْ قَالَ أَلَمْ أَقُل لَّكُمْ إِنِّىٓ أَعْلَمُ غَيْبَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَأَعْلَمُ مَا تُبْدُونَ وَمَا كُنتُمْ تَكْتُمُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@xli{وَإِذْ قُلْنَا لِلْمَلَٰٓئِكَةِ ٱسْجُدُوا۟ لِءَادَمَ فَسَجَدُوٓا۟ إِلَّآ إِبْلِيسَ أَبَىٰ وَٱسْتَكْبَرَ وَكَانَ مِنَ ٱلْكَٰفِرِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@xlii{وَقُلْنَا يَٰٓـَٔادَمُ ٱسْكُنْ أَنتَ وَزَوْجُكَ ٱلْجَنَّةَ وَكُلَا مِنْهَا رَغَدًا حَيْثُ شِئْتُمَا وَلَا تَقْرَبَا هَٰذِهِ ٱلشَّجَرَةَ فَتَكُونَا مِنَ ٱلظَّٰلِمِينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@xliii{فَأَزَلَّهُمَا ٱلشَّيْطَٰنُ عَنْهَا فَأَخْرَجَهُمَا مِمَّا كَانَا فِيهِ وَقُلْنَا ٱهْبِطُوا۟ بَعْضُكُمْ لِبَعْضٍ عَدُوٌّ وَلَكُمْ فِى ٱلْأَرْضِ مُسْتَقَرٌّ وَمَتَٰعٌ إِلَىٰ حِينٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@xliv{فَتَلَقَّىٰٓ ءَادَمُ مِن رَّبِّهِۦ كَلِمَٰتٍ فَتَابَ عَلَيْهِ إِنَّهُۥ هُوَ ٱلتَّوَّابُ ٱلرَّحِيمُ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@xlv{قُلْنَا ٱهْبِطُوا۟ مِنْهَا جَمِيعًا فَإِمَّا يَأْتِيَنَّكُم مِّنِّى هُدًى فَمَن تَبِعَ هُدَاىَ فَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@xlvi{وَٱلَّذِينَ كَفَرُوا۟ وَكَذَّبُوا۟ بِـَٔايَٰتِنَآ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@xlvii{يَٰبَنِىٓ إِسْرَٰٓءِيلَ ٱذْكُرُوا۟ نِعْمَتِىَ ٱلَّتِىٓ أَنْعَمْتُ عَلَيْكُمْ وَأَوْفُوا۟ بِعَهْدِىٓ أُوفِ بِعَهْدِكُمْ وَإِيَّٰىَ فَٱرْهَبُونِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@xlviii{وَءَامِنُوا۟ بِمَآ أَنزَلْتُ مُصَدِّقًا لِّمَا مَعَكُمْ وَلَا تَكُونُوٓا۟ أَوَّلَ كَافِرٍۭ بِهِۦ وَلَا تَشْتَرُوا۟ بِـَٔايَٰتِى ثَمَنًا قَلِيلًا وَإِيَّٰىَ فَٱتَّقُونِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@xlix{وَلَا تَلْبِسُوا۟ ٱلْحَقَّ بِٱلْبَٰطِلِ وَتَكْتُمُوا۟ ٱلْحَقَّ وَأَنتُمْ تَعْلَمُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@l{وَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَءَاتُوا۟ ٱلزَّكَوٰةَ وَٱرْكَعُوا۟ مَعَ ٱلرَّٰكِعِينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@li{أَتَأْمُرُونَ ٱلنَّاسَ بِٱلْبِرِّ وَتَنسَوْنَ أَنفُسَكُمْ وَأَنتُمْ تَتْلُونَ ٱلْكِتَٰبَ أَفَلَا تَعْقِلُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@lii{وَٱسْتَعِينُوا۟ بِٱلصَّبْرِ وَٱلصَّلَوٰةِ وَإِنَّهَا لَكَبِيرَةٌ إِلَّا عَلَى ٱلْخَٰشِعِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@liii{ٱلَّذِينَ يَظُنُّونَ أَنَّهُم مُّلَٰقُوا۟ رَبِّهِمْ وَأَنَّهُمْ إِلَيْهِ رَٰجِعُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@liv{يَٰبَنِىٓ إِسْرَٰٓءِيلَ ٱذْكُرُوا۟ نِعْمَتِىَ ٱلَّتِىٓ أَنْعَمْتُ عَلَيْكُمْ وَأَنِّى فَضَّلْتُكُمْ عَلَى ٱلْعَٰلَمِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@lv{وَٱتَّقُوا۟ يَوْمًا لَّا تَجْزِى نَفْسٌ عَن نَّفْسٍ شَيْـًٔا وَلَا يُقْبَلُ مِنْهَا شَفَٰعَةٌ وَلَا يُؤْخَذُ مِنْهَا عَدْلٌ وَلَا هُمْ يُنصَرُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@lvi{وَإِذْ نَجَّيْنَٰكُم مِّنْ ءَالِ فِرْعَوْنَ يَسُومُونَكُمْ سُوٓءَ ٱلْعَذَابِ يُذَبِّحُونَ أَبْنَآءَكُمْ وَيَسْتَحْيُونَ نِسَآءَكُمْ وَفِى ذَٰلِكُم بَلَآءٌ مِّن رَّبِّكُمْ عَظِيمٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@lvii{وَإِذْ فَرَقْنَا بِكُمُ ٱلْبَحْرَ فَأَنجَيْنَٰكُمْ وَأَغْرَقْنَآ ءَالَ فِرْعَوْنَ وَأَنتُمْ تَنظُرُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@lviii{وَإِذْ وَٰعَدْنَا مُوسَىٰٓ أَرْبَعِينَ لَيْلَةً ثُمَّ ٱتَّخَذْتُمُ ٱلْعِجْلَ مِنۢ بَعْدِهِۦ وَأَنتُمْ ظَٰلِمُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@lix{ثُمَّ عَفَوْنَا عَنكُم مِّنۢ بَعْدِ ذَٰلِكَ لَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@lx{وَإِذْ ءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ وَٱلْفُرْقَانَ لَعَلَّكُمْ تَهْتَدُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@lxi{وَإِذْ قَالَ مُوسَىٰ لِقَوْمِهِۦ يَٰقَوْمِ إِنَّكُمْ ظَلَمْتُمْ أَنفُسَكُم بِٱتِّخَاذِكُمُ ٱلْعِجْلَ فَتُوبُوٓا۟ إِلَىٰ بَارِئِكُمْ فَٱقْتُلُوٓا۟ أَنفُسَكُمْ ذَٰلِكُمْ خَيْرٌ لَّكُمْ عِندَ بَارِئِكُمْ فَتَابَ عَلَيْكُمْ إِنَّهُۥ هُوَ ٱلتَّوَّابُ ٱلرَّحِيمُ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@lxii{وَإِذْ قُلْتُمْ يَٰمُوسَىٰ لَن نُّؤْمِنَ لَكَ حَتَّىٰ نَرَى ٱللَّهَ جَهْرَةً فَأَخَذَتْكُمُ ٱلصَّٰعِقَةُ وَأَنتُمْ تَنظُرُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@lxiii{ثُمَّ بَعَثْنَٰكُم مِّنۢ بَعْدِ مَوْتِكُمْ لَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@lxiv{وَظَلَّلْنَا عَلَيْكُمُ ٱلْغَمَامَ وَأَنزَلْنَا عَلَيْكُمُ ٱلْمَنَّ وَٱلسَّلْوَىٰ كُلُوا۟ مِن طَيِّبَٰتِ مَا رَزَقْنَٰكُمْ وَمَا ظَلَمُونَا وَلَٰكِن كَانُوٓا۟ أَنفُسَهُمْ يَظْلِمُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@lxv{وَإِذْ قُلْنَا ٱدْخُلُوا۟ هَٰذِهِ ٱلْقَرْيَةَ فَكُلُوا۟ مِنْهَا حَيْثُ شِئْتُمْ رَغَدًا وَٱدْخُلُوا۟ ٱلْبَابَ سُجَّدًا وَقُولُوا۟ حِطَّةٌ نَّغْفِرْ لَكُمْ خَطَٰيَٰكُمْ وَسَنَزِيدُ ٱلْمُحْسِنِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@lxvi{فَبَدَّلَ ٱلَّذِينَ ظَلَمُوا۟ قَوْلًا غَيْرَ ٱلَّذِى قِيلَ لَهُمْ فَأَنزَلْنَا عَلَى ٱلَّذِينَ ظَلَمُوا۟ رِجْزًا مِّنَ ٱلسَّمَآءِ بِمَا كَانُوا۟ يَفْسُقُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@lxvii{وَإِذِ ٱسْتَسْقَىٰ مُوسَىٰ لِقَوْمِهِۦ فَقُلْنَا ٱضْرِب بِّعَصَاكَ ٱلْحَجَرَ فَٱنفَجَرَتْ مِنْهُ ٱثْنَتَا عَشْرَةَ عَيْنًا قَدْ عَلِمَ كُلُّ أُنَاسٍ مَّشْرَبَهُمْ كُلُوا۟ وَٱشْرَبُوا۟ مِن رِّزْقِ ٱللَّهِ وَلَا تَعْثَوْا۟ فِى ٱلْأَرْضِ مُفْسِدِينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@lxviii{وَإِذْ قُلْتُمْ يَٰمُوسَىٰ لَن نَّصْبِرَ عَلَىٰ طَعَامٍ وَٰحِدٍ فَٱدْعُ لَنَا رَبَّكَ يُخْرِجْ لَنَا مِمَّا تُنۢبِتُ ٱلْأَرْضُ مِنۢ بَقْلِهَا وَقِثَّآئِهَا وَفُومِهَا وَعَدَسِهَا وَبَصَلِهَا قَالَ أَتَسْتَبْدِلُونَ ٱلَّذِى هُوَ أَدْنَىٰ بِٱلَّذِى هُوَ خَيْرٌ ٱهْبِطُوا۟ مِصْرًا فَإِنَّ لَكُم مَّا سَأَلْتُمْ وَضُرِبَتْ عَلَيْهِمُ ٱلذِّلَّةُ وَٱلْمَسْكَنَةُ وَبَآءُو بِغَضَبٍ مِّنَ ٱللَّهِ ذَٰلِكَ بِأَنَّهُمْ كَانُوا۟ يَكْفُرُونَ بِـَٔايَٰتِ ٱللَّهِ وَيَقْتُلُونَ ٱلنَّبِيِّۦنَ بِغَيْرِ ٱلْحَقِّ ذَٰلِكَ بِمَا عَصَوا۟ وَّكَانُوا۟ يَعْتَدُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@lxix{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَٱلَّذِينَ هَادُوا۟ وَٱلنَّصَٰرَىٰ وَٱلصَّٰبِـِٔينَ مَنْ ءَامَنَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَعَمِلَ صَٰلِحًا فَلَهُمْ أَجْرُهُمْ عِندَ رَبِّهِمْ وَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@lxx{وَإِذْ أَخَذْنَا مِيثَٰقَكُمْ وَرَفَعْنَا فَوْقَكُمُ ٱلطُّورَ خُذُوا۟ مَآ ءَاتَيْنَٰكُم بِقُوَّةٍ وَٱذْكُرُوا۟ مَا فِيهِ لَعَلَّكُمْ تَتَّقُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@lxxi{ثُمَّ تَوَلَّيْتُم مِّنۢ بَعْدِ ذَٰلِكَ فَلَوْلَا فَضْلُ ٱللَّهِ عَلَيْكُمْ وَرَحْمَتُهُۥ لَكُنتُم مِّنَ ٱلْخَٰسِرِينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@lxxii{وَلَقَدْ عَلِمْتُمُ ٱلَّذِينَ ٱعْتَدَوْا۟ مِنكُمْ فِى ٱلسَّبْتِ فَقُلْنَا لَهُمْ كُونُوا۟ قِرَدَةً خَٰسِـِٔينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@lxxiii{فَجَعَلْنَٰهَا نَكَٰلًا لِّمَا بَيْنَ يَدَيْهَا وَمَا خَلْفَهَا وَمَوْعِظَةً لِّلْمُتَّقِينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@lxxiv{وَإِذْ قَالَ مُوسَىٰ لِقَوْمِهِۦٓ إِنَّ ٱللَّهَ يَأْمُرُكُمْ أَن تَذْبَحُوا۟ بَقَرَةً قَالُوٓا۟ أَتَتَّخِذُنَا هُزُوًا قَالَ أَعُوذُ بِٱللَّهِ أَنْ أَكُونَ مِنَ ٱلْجَٰهِلِينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@lxxv{قَالُوا۟ ٱدْعُ لَنَا رَبَّكَ يُبَيِّن لَّنَا مَا هِىَ قَالَ إِنَّهُۥ يَقُولُ إِنَّهَا بَقَرَةٌ لَّا فَارِضٌ وَلَا بِكْرٌ عَوَانٌۢ بَيْنَ ذَٰلِكَ فَٱفْعَلُوا۟ مَا تُؤْمَرُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@lxxvi{قَالُوا۟ ٱدْعُ لَنَا رَبَّكَ يُبَيِّن لَّنَا مَا لَوْنُهَا قَالَ إِنَّهُۥ يَقُولُ إِنَّهَا بَقَرَةٌ صَفْرَآءُ فَاقِعٌ لَّوْنُهَا تَسُرُّ ٱلنَّٰظِرِينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@lxxvii{قَالُوا۟ ٱدْعُ لَنَا رَبَّكَ يُبَيِّن لَّنَا مَا هِىَ إِنَّ ٱلْبَقَرَ تَشَٰبَهَ عَلَيْنَا وَإِنَّآ إِن شَآءَ ٱللَّهُ لَمُهْتَدُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@lxxviii{قَالَ إِنَّهُۥ يَقُولُ إِنَّهَا بَقَرَةٌ لَّا ذَلُولٌ تُثِيرُ ٱلْأَرْضَ وَلَا تَسْقِى ٱلْحَرْثَ مُسَلَّمَةٌ لَّا شِيَةَ فِيهَا قَالُوا۟ ٱلْـَٰٔنَ جِئْتَ بِٱلْحَقِّ فَذَبَحُوهَا وَمَا كَادُوا۟ يَفْعَلُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@lxxix{وَإِذْ قَتَلْتُمْ نَفْسًا فَٱدَّٰرَْٰٔتُمْ فِيهَا وَٱللَّهُ مُخْرِجٌ مَّا كُنتُمْ تَكْتُمُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@lxxx{فَقُلْنَا ٱضْرِبُوهُ بِبَعْضِهَا كَذَٰلِكَ يُحْىِ ٱللَّهُ ٱلْمَوْتَىٰ وَيُرِيكُمْ ءَايَٰتِهِۦ لَعَلَّكُمْ تَعْقِلُونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@lxxxi{ثُمَّ قَسَتْ قُلُوبُكُم مِّنۢ بَعْدِ ذَٰلِكَ فَهِىَ كَٱلْحِجَارَةِ أَوْ أَشَدُّ قَسْوَةً وَإِنَّ مِنَ ٱلْحِجَارَةِ لَمَا يَتَفَجَّرُ مِنْهُ ٱلْأَنْهَٰرُ وَإِنَّ مِنْهَا لَمَا يَشَّقَّقُ فَيَخْرُجُ مِنْهُ ٱلْمَآءُ وَإِنَّ مِنْهَا لَمَا يَهْبِطُ مِنْ خَشْيَةِ ٱللَّهِ وَمَا ٱللَّهُ بِغَٰفِلٍ عَمَّا تَعْمَلُونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@lxxxii{أَفَتَطْمَعُونَ أَن يُؤْمِنُوا۟ لَكُمْ وَقَدْ كَانَ فَرِيقٌ مِّنْهُمْ يَسْمَعُونَ كَلَٰمَ ٱللَّهِ ثُمَّ يُحَرِّفُونَهُۥ مِنۢ بَعْدِ مَا عَقَلُوهُ وَهُمْ يَعْلَمُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@lxxxiii{وَإِذَا لَقُوا۟ ٱلَّذِينَ ءَامَنُوا۟ قَالُوٓا۟ ءَامَنَّا وَإِذَا خَلَا بَعْضُهُمْ إِلَىٰ بَعْضٍ قَالُوٓا۟ أَتُحَدِّثُونَهُم بِمَا فَتَحَ ٱللَّهُ عَلَيْكُمْ لِيُحَآجُّوكُم بِهِۦ عِندَ رَبِّكُمْ أَفَلَا تَعْقِلُونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@lxxxiv{أَوَلَا يَعْلَمُونَ أَنَّ ٱللَّهَ يَعْلَمُ مَا يُسِرُّونَ وَمَا يُعْلِنُونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@lxxxv{وَمِنْهُمْ أُمِّيُّونَ لَا يَعْلَمُونَ ٱلْكِتَٰبَ إِلَّآ أَمَانِىَّ وَإِنْ هُمْ إِلَّا يَظُنُّونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@lxxxvi{فَوَيْلٌ لِّلَّذِينَ يَكْتُبُونَ ٱلْكِتَٰبَ بِأَيْدِيهِمْ ثُمَّ يَقُولُونَ هَٰذَا مِنْ عِندِ ٱللَّهِ لِيَشْتَرُوا۟ بِهِۦ ثَمَنًا قَلِيلًا فَوَيْلٌ لَّهُم مِّمَّا كَتَبَتْ أَيْدِيهِمْ وَوَيْلٌ لَّهُم مِّمَّا يَكْسِبُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@lxxxvii{وَقَالُوا۟ لَن تَمَسَّنَا ٱلنَّارُ إِلَّآ أَيَّامًا مَّعْدُودَةً قُلْ أَتَّخَذْتُمْ عِندَ ٱللَّهِ عَهْدًا فَلَن يُخْلِفَ ٱللَّهُ عَهْدَهُۥٓ أَمْ تَقُولُونَ عَلَى ٱللَّهِ مَا لَا تَعْلَمُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@lxxxviii{بَلَىٰ مَن كَسَبَ سَيِّئَةً وَأَحَٰطَتْ بِهِۦ خَطِيٓـَٔتُهُۥ فَأُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@lxxxix{وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْجَنَّةِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@xc{وَإِذْ أَخَذْنَا مِيثَٰقَ بَنِىٓ إِسْرَٰٓءِيلَ لَا تَعْبُدُونَ إِلَّا ٱللَّهَ وَبِٱلْوَٰلِدَيْنِ إِحْسَانًا وَذِى ٱلْقُرْبَىٰ وَٱلْيَتَٰمَىٰ وَٱلْمَسَٰكِينِ وَقُولُوا۟ لِلنَّاسِ حُسْنًا وَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَءَاتُوا۟ ٱلزَّكَوٰةَ ثُمَّ تَوَلَّيْتُمْ إِلَّا قَلِيلًا مِّنكُمْ وَأَنتُم مُّعْرِضُونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@xci{وَإِذْ أَخَذْنَا مِيثَٰقَكُمْ لَا تَسْفِكُونَ دِمَآءَكُمْ وَلَا تُخْرِجُونَ أَنفُسَكُم مِّن دِيَٰرِكُمْ ثُمَّ أَقْرَرْتُمْ وَأَنتُمْ تَشْهَدُونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@xcii{ثُمَّ أَنتُمْ هَٰٓؤُلَآءِ تَقْتُلُونَ أَنفُسَكُمْ وَتُخْرِجُونَ فَرِيقًا مِّنكُم مِّن دِيَٰرِهِمْ تَظَٰهَرُونَ عَلَيْهِم بِٱلْإِثْمِ وَٱلْعُدْوَٰنِ وَإِن يَأْتُوكُمْ أُسَٰرَىٰ تُفَٰدُوهُمْ وَهُوَ مُحَرَّمٌ عَلَيْكُمْ إِخْرَاجُهُمْ أَفَتُؤْمِنُونَ بِبَعْضِ ٱلْكِتَٰبِ وَتَكْفُرُونَ بِبَعْضٍ فَمَا جَزَآءُ مَن يَفْعَلُ ذَٰلِكَ مِنكُمْ إِلَّا خِزْىٌ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَيَوْمَ ٱلْقِيَٰمَةِ يُرَدُّونَ إِلَىٰٓ أَشَدِّ ٱلْعَذَابِ وَمَا ٱللَّهُ بِغَٰفِلٍ عَمَّا تَعْمَلُونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@xciii{أُو۟لَٰٓئِكَ ٱلَّذِينَ ٱشْتَرَوُا۟ ٱلْحَيَوٰةَ ٱلدُّنْيَا بِٱلْءَاخِرَةِ فَلَا يُخَفَّفُ عَنْهُمُ ٱلْعَذَابُ وَلَا هُمْ يُنصَرُونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@xciv{وَلَقَدْ ءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ وَقَفَّيْنَا مِنۢ بَعْدِهِۦ بِٱلرُّسُلِ وَءَاتَيْنَا عِيسَى ٱبْنَ مَرْيَمَ ٱلْبَيِّنَٰتِ وَأَيَّدْنَٰهُ بِرُوحِ ٱلْقُدُسِ أَفَكُلَّمَا جَآءَكُمْ رَسُولٌۢ بِمَا لَا تَهْوَىٰٓ أَنفُسُكُمُ ٱسْتَكْبَرْتُمْ فَفَرِيقًا كَذَّبْتُمْ وَفَرِيقًا تَقْتُلُونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@xcv{وَقَالُوا۟ قُلُوبُنَا غُلْفٌۢ بَل لَّعَنَهُمُ ٱللَّهُ بِكُفْرِهِمْ فَقَلِيلًا مَّا يُؤْمِنُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@xcvi{وَلَمَّا جَآءَهُمْ كِتَٰبٌ مِّنْ عِندِ ٱللَّهِ مُصَدِّقٌ لِّمَا مَعَهُمْ وَكَانُوا۟ مِن قَبْلُ يَسْتَفْتِحُونَ عَلَى ٱلَّذِينَ كَفَرُوا۟ فَلَمَّا جَآءَهُم مَّا عَرَفُوا۟ كَفَرُوا۟ بِهِۦ فَلَعْنَةُ ٱللَّهِ عَلَى ٱلْكَٰفِرِينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@xcvii{بِئْسَمَا ٱشْتَرَوْا۟ بِهِۦٓ أَنفُسَهُمْ أَن يَكْفُرُوا۟ بِمَآ أَنزَلَ ٱللَّهُ بَغْيًا أَن يُنَزِّلَ ٱللَّهُ مِن فَضْلِهِۦ عَلَىٰ مَن يَشَآءُ مِنْ عِبَادِهِۦ فَبَآءُو بِغَضَبٍ عَلَىٰ غَضَبٍ وَلِلْكَٰفِرِينَ عَذَابٌ مُّهِينٌ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@xcviii{وَإِذَا قِيلَ لَهُمْ ءَامِنُوا۟ بِمَآ أَنزَلَ ٱللَّهُ قَالُوا۟ نُؤْمِنُ بِمَآ أُنزِلَ عَلَيْنَا وَيَكْفُرُونَ بِمَا وَرَآءَهُۥ وَهُوَ ٱلْحَقُّ مُصَدِّقًا لِّمَا مَعَهُمْ قُلْ فَلِمَ تَقْتُلُونَ أَنۢبِيَآءَ ٱللَّهِ مِن قَبْلُ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@xcix{وَلَقَدْ جَآءَكُم مُّوسَىٰ بِٱلْبَيِّنَٰتِ ثُمَّ ٱتَّخَذْتُمُ ٱلْعِجْلَ مِنۢ بَعْدِهِۦ وَأَنتُمْ ظَٰلِمُونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@c{وَإِذْ أَخَذْنَا مِيثَٰقَكُمْ وَرَفَعْنَا فَوْقَكُمُ ٱلطُّورَ خُذُوا۟ مَآ ءَاتَيْنَٰكُم بِقُوَّةٍ وَٱسْمَعُوا۟ قَالُوا۟ سَمِعْنَا وَعَصَيْنَا وَأُشْرِبُوا۟ فِى قُلُوبِهِمُ ٱلْعِجْلَ بِكُفْرِهِمْ قُلْ بِئْسَمَا يَأْمُرُكُم بِهِۦٓ إِيمَٰنُكُمْ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@ci{قُلْ إِن كَانَتْ لَكُمُ ٱلدَّارُ ٱلْءَاخِرَةُ عِندَ ٱللَّهِ خَالِصَةً مِّن دُونِ ٱلنَّاسِ فَتَمَنَّوُا۟ ٱلْمَوْتَ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@cii{وَلَن يَتَمَنَّوْهُ أَبَدًۢا بِمَا قَدَّمَتْ أَيْدِيهِمْ وَٱللَّهُ عَلِيمٌۢ بِٱلظَّٰلِمِينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@ciii{وَلَتَجِدَنَّهُمْ أَحْرَصَ ٱلنَّاسِ عَلَىٰ حَيَوٰةٍ وَمِنَ ٱلَّذِينَ أَشْرَكُوا۟ يَوَدُّ أَحَدُهُمْ لَوْ يُعَمَّرُ أَلْفَ سَنَةٍ وَمَا هُوَ بِمُزَحْزِحِهِۦ مِنَ ٱلْعَذَابِ أَن يُعَمَّرَ وَٱللَّهُ بَصِيرٌۢ بِمَا يَعْمَلُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@civ{قُلْ مَن كَانَ عَدُوًّا لِّجِبْرِيلَ فَإِنَّهُۥ نَزَّلَهُۥ عَلَىٰ قَلْبِكَ بِإِذْنِ ٱللَّهِ مُصَدِّقًا لِّمَا بَيْنَ يَدَيْهِ وَهُدًى وَبُشْرَىٰ لِلْمُؤْمِنِينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@cv{مَن كَانَ عَدُوًّا لِّلَّهِ وَمَلَٰٓئِكَتِهِۦ وَرُسُلِهِۦ وَجِبْرِيلَ وَمِيكَىٰلَ فَإِنَّ ٱللَّهَ عَدُوٌّ لِّلْكَٰفِرِينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@cvi{وَلَقَدْ أَنزَلْنَآ إِلَيْكَ ءَايَٰتٍۭ بَيِّنَٰتٍ وَمَا يَكْفُرُ بِهَآ إِلَّا ٱلْفَٰسِقُونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@cvii{أَوَكُلَّمَا عَٰهَدُوا۟ عَهْدًا نَّبَذَهُۥ فَرِيقٌ مِّنْهُم بَلْ أَكْثَرُهُمْ لَا يُؤْمِنُونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@cviii{وَلَمَّا جَآءَهُمْ رَسُولٌ مِّنْ عِندِ ٱللَّهِ مُصَدِّقٌ لِّمَا مَعَهُمْ نَبَذَ فَرِيقٌ مِّنَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ كِتَٰبَ ٱللَّهِ وَرَآءَ ظُهُورِهِمْ كَأَنَّهُمْ لَا يَعْلَمُونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@cix{وَٱتَّبَعُوا۟ مَا تَتْلُوا۟ ٱلشَّيَٰطِينُ عَلَىٰ مُلْكِ سُلَيْمَٰنَ وَمَا كَفَرَ سُلَيْمَٰنُ وَلَٰكِنَّ ٱلشَّيَٰطِينَ كَفَرُوا۟ يُعَلِّمُونَ ٱلنَّاسَ ٱلسِّحْرَ وَمَآ أُنزِلَ عَلَى ٱلْمَلَكَيْنِ بِبَابِلَ هَٰرُوتَ وَمَٰرُوتَ وَمَا يُعَلِّمَانِ مِنْ أَحَدٍ حَتَّىٰ يَقُولَآ إِنَّمَا نَحْنُ فِتْنَةٌ فَلَا تَكْفُرْ فَيَتَعَلَّمُونَ مِنْهُمَا مَا يُفَرِّقُونَ بِهِۦ بَيْنَ ٱلْمَرْءِ وَزَوْجِهِۦ وَمَا هُم بِضَآرِّينَ بِهِۦ مِنْ أَحَدٍ إِلَّا بِإِذْنِ ٱللَّهِ وَيَتَعَلَّمُونَ مَا يَضُرُّهُمْ وَلَا يَنفَعُهُمْ وَلَقَدْ عَلِمُوا۟ لَمَنِ ٱشْتَرَىٰهُ مَا لَهُۥ فِى ٱلْءَاخِرَةِ مِنْ خَلَٰقٍ وَلَبِئْسَ مَا شَرَوْا۟ بِهِۦٓ أَنفُسَهُمْ لَوْ كَانُوا۟ يَعْلَمُونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@cx{وَلَوْ أَنَّهُمْ ءَامَنُوا۟ وَٱتَّقَوْا۟ لَمَثُوبَةٌ مِّنْ عِندِ ٱللَّهِ خَيْرٌ لَّوْ كَانُوا۟ يَعْلَمُونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@cxi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَقُولُوا۟ رَٰعِنَا وَقُولُوا۟ ٱنظُرْنَا وَٱسْمَعُوا۟ وَلِلْكَٰفِرِينَ عَذَابٌ أَلِيمٌ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@cxii{مَّا يَوَدُّ ٱلَّذِينَ كَفَرُوا۟ مِنْ أَهْلِ ٱلْكِتَٰبِ وَلَا ٱلْمُشْرِكِينَ أَن يُنَزَّلَ عَلَيْكُم مِّنْ خَيْرٍ مِّن رَّبِّكُمْ وَٱللَّهُ يَخْتَصُّ بِرَحْمَتِهِۦ مَن يَشَآءُ وَٱللَّهُ ذُو ٱلْفَضْلِ ٱلْعَظِيمِ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@cxiii{مَا نَنسَخْ مِنْ ءَايَةٍ أَوْ نُنسِهَا نَأْتِ بِخَيْرٍ مِّنْهَآ أَوْ مِثْلِهَآ أَلَمْ تَعْلَمْ أَنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@cxiv{أَلَمْ تَعْلَمْ أَنَّ ٱللَّهَ لَهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا لَكُم مِّن دُونِ ٱللَّهِ مِن وَلِىٍّ وَلَا نَصِيرٍ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@cxv{أَمْ تُرِيدُونَ أَن تَسْـَٔلُوا۟ رَسُولَكُمْ كَمَا سُئِلَ مُوسَىٰ مِن قَبْلُ وَمَن يَتَبَدَّلِ ٱلْكُفْرَ بِٱلْإِيمَٰنِ فَقَدْ ضَلَّ سَوَآءَ ٱلسَّبِيلِ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@cxvi{وَدَّ كَثِيرٌ مِّنْ أَهْلِ ٱلْكِتَٰبِ لَوْ يَرُدُّونَكُم مِّنۢ بَعْدِ إِيمَٰنِكُمْ كُفَّارًا حَسَدًا مِّنْ عِندِ أَنفُسِهِم مِّنۢ بَعْدِ مَا تَبَيَّنَ لَهُمُ ٱلْحَقُّ فَٱعْفُوا۟ وَٱصْفَحُوا۟ حَتَّىٰ يَأْتِىَ ٱللَّهُ بِأَمْرِهِۦٓ إِنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@cxvii{وَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَءَاتُوا۟ ٱلزَّكَوٰةَ وَمَا تُقَدِّمُوا۟ لِأَنفُسِكُم مِّنْ خَيْرٍ تَجِدُوهُ عِندَ ٱللَّهِ إِنَّ ٱللَّهَ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@cxviii{وَقَالُوا۟ لَن يَدْخُلَ ٱلْجَنَّةَ إِلَّا مَن كَانَ هُودًا أَوْ نَصَٰرَىٰ تِلْكَ أَمَانِيُّهُمْ قُلْ هَاتُوا۟ بُرْهَٰنَكُمْ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@cxix{بَلَىٰ مَنْ أَسْلَمَ وَجْهَهُۥ لِلَّهِ وَهُوَ مُحْسِنٌ فَلَهُۥٓ أَجْرُهُۥ عِندَ رَبِّهِۦ وَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@cxx{وَقَالَتِ ٱلْيَهُودُ لَيْسَتِ ٱلنَّصَٰرَىٰ عَلَىٰ شَىْءٍ وَقَالَتِ ٱلنَّصَٰرَىٰ لَيْسَتِ ٱلْيَهُودُ عَلَىٰ شَىْءٍ وَهُمْ يَتْلُونَ ٱلْكِتَٰبَ كَذَٰلِكَ قَالَ ٱلَّذِينَ لَا يَعْلَمُونَ مِثْلَ قَوْلِهِمْ فَٱللَّهُ يَحْكُمُ بَيْنَهُمْ يَوْمَ ٱلْقِيَٰمَةِ فِيمَا كَانُوا۟ فِيهِ يَخْتَلِفُونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@cxxi{وَمَنْ أَظْلَمُ مِمَّن مَّنَعَ مَسَٰجِدَ ٱللَّهِ أَن يُذْكَرَ فِيهَا ٱسْمُهُۥ وَسَعَىٰ فِى خَرَابِهَآ أُو۟لَٰٓئِكَ مَا كَانَ لَهُمْ أَن يَدْخُلُوهَآ إِلَّا خَآئِفِينَ لَهُمْ فِى ٱلدُّنْيَا خِزْىٌ وَلَهُمْ فِى ٱلْءَاخِرَةِ عَذَابٌ عَظِيمٌ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@cxxii{وَلِلَّهِ ٱلْمَشْرِقُ وَٱلْمَغْرِبُ فَأَيْنَمَا تُوَلُّوا۟ فَثَمَّ وَجْهُ ٱللَّهِ إِنَّ ٱللَّهَ وَٰسِعٌ عَلِيمٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@cxxiii{وَقَالُوا۟ ٱتَّخَذَ ٱللَّهُ وَلَدًا سُبْحَٰنَهُۥ بَل لَّهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ كُلٌّ لَّهُۥ قَٰنِتُونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@cxxiv{بَدِيعُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَإِذَا قَضَىٰٓ أَمْرًا فَإِنَّمَا يَقُولُ لَهُۥ كُن فَيَكُونُ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@cxxv{وَقَالَ ٱلَّذِينَ لَا يَعْلَمُونَ لَوْلَا يُكَلِّمُنَا ٱللَّهُ أَوْ تَأْتِينَآ ءَايَةٌ كَذَٰلِكَ قَالَ ٱلَّذِينَ مِن قَبْلِهِم مِّثْلَ قَوْلِهِمْ تَشَٰبَهَتْ قُلُوبُهُمْ قَدْ بَيَّنَّا ٱلْءَايَٰتِ لِقَوْمٍ يُوقِنُونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@cxxvi{إِنَّآ أَرْسَلْنَٰكَ بِٱلْحَقِّ بَشِيرًا وَنَذِيرًا وَلَا تُسْـَٔلُ عَنْ أَصْحَٰبِ ٱلْجَحِيمِ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@cxxvii{وَلَن تَرْضَىٰ عَنكَ ٱلْيَهُودُ وَلَا ٱلنَّصَٰرَىٰ حَتَّىٰ تَتَّبِعَ مِلَّتَهُمْ قُلْ إِنَّ هُدَى ٱللَّهِ هُوَ ٱلْهُدَىٰ وَلَئِنِ ٱتَّبَعْتَ أَهْوَآءَهُم بَعْدَ ٱلَّذِى جَآءَكَ مِنَ ٱلْعِلْمِ مَا لَكَ مِنَ ٱللَّهِ مِن وَلِىٍّ وَلَا نَصِيرٍ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@cxxviii{ٱلَّذِينَ ءَاتَيْنَٰهُمُ ٱلْكِتَٰبَ يَتْلُونَهُۥ حَقَّ تِلَاوَتِهِۦٓ أُو۟لَٰٓئِكَ يُؤْمِنُونَ بِهِۦ وَمَن يَكْفُرْ بِهِۦ فَأُو۟لَٰٓئِكَ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@cxxix{يَٰبَنِىٓ إِسْرَٰٓءِيلَ ٱذْكُرُوا۟ نِعْمَتِىَ ٱلَّتِىٓ أَنْعَمْتُ عَلَيْكُمْ وَأَنِّى فَضَّلْتُكُمْ عَلَى ٱلْعَٰلَمِينَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@cxxx{وَٱتَّقُوا۟ يَوْمًا لَّا تَجْزِى نَفْسٌ عَن نَّفْسٍ شَيْـًٔا وَلَا يُقْبَلُ مِنْهَا عَدْلٌ وَلَا تَنفَعُهَا شَفَٰعَةٌ وَلَا هُمْ يُنصَرُونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@cxxxi{وَإِذِ ٱبْتَلَىٰٓ إِبْرَٰهِۦمَ رَبُّهُۥ بِكَلِمَٰتٍ فَأَتَمَّهُنَّ قَالَ إِنِّى جَاعِلُكَ لِلنَّاسِ إِمَامًا قَالَ وَمِن ذُرِّيَّتِى قَالَ لَا يَنَالُ عَهْدِى ٱلظَّٰلِمِينَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@cxxxii{وَإِذْ جَعَلْنَا ٱلْبَيْتَ مَثَابَةً لِّلنَّاسِ وَأَمْنًا وَٱتَّخِذُوا۟ مِن مَّقَامِ إِبْرَٰهِۦمَ مُصَلًّى وَعَهِدْنَآ إِلَىٰٓ إِبْرَٰهِۦمَ وَإِسْمَٰعِيلَ أَن طَهِّرَا بَيْتِىَ لِلطَّآئِفِينَ وَٱلْعَٰكِفِينَ وَٱلرُّكَّعِ ٱلسُّجُودِ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@cxxxiii{وَإِذْ قَالَ إِبْرَٰهِۦمُ رَبِّ ٱجْعَلْ هَٰذَا بَلَدًا ءَامِنًا وَٱرْزُقْ أَهْلَهُۥ مِنَ ٱلثَّمَرَٰتِ مَنْ ءَامَنَ مِنْهُم بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ قَالَ وَمَن كَفَرَ فَأُمَتِّعُهُۥ قَلِيلًا ثُمَّ أَضْطَرُّهُۥٓ إِلَىٰ عَذَابِ ٱلنَّارِ وَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@cxxxiv{وَإِذْ يَرْفَعُ إِبْرَٰهِۦمُ ٱلْقَوَاعِدَ مِنَ ٱلْبَيْتِ وَإِسْمَٰعِيلُ رَبَّنَا تَقَبَّلْ مِنَّآ إِنَّكَ أَنتَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@cxxxv{رَبَّنَا وَٱجْعَلْنَا مُسْلِمَيْنِ لَكَ وَمِن ذُرِّيَّتِنَآ أُمَّةً مُّسْلِمَةً لَّكَ وَأَرِنَا مَنَاسِكَنَا وَتُبْ عَلَيْنَآ إِنَّكَ أَنتَ ٱلتَّوَّابُ ٱلرَّحِيمُ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@cxxxvi{رَبَّنَا وَٱبْعَثْ فِيهِمْ رَسُولًا مِّنْهُمْ يَتْلُوا۟ عَلَيْهِمْ ءَايَٰتِكَ وَيُعَلِّمُهُمُ ٱلْكِتَٰبَ وَٱلْحِكْمَةَ وَيُزَكِّيهِمْ إِنَّكَ أَنتَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@cxxxvii{وَمَن يَرْغَبُ عَن مِّلَّةِ إِبْرَٰهِۦمَ إِلَّا مَن سَفِهَ نَفْسَهُۥ وَلَقَدِ ٱصْطَفَيْنَٰهُ فِى ٱلدُّنْيَا وَإِنَّهُۥ فِى ٱلْءَاخِرَةِ لَمِنَ ٱلصَّٰلِحِينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@cxxxviii{إِذْ قَالَ لَهُۥ رَبُّهُۥٓ أَسْلِمْ قَالَ أَسْلَمْتُ لِرَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@cxxxix{وَوَصَّىٰ بِهَآ إِبْرَٰهِۦمُ بَنِيهِ وَيَعْقُوبُ يَٰبَنِىَّ إِنَّ ٱللَّهَ ٱصْطَفَىٰ لَكُمُ ٱلدِّينَ فَلَا تَمُوتُنَّ إِلَّا وَأَنتُم مُّسْلِمُونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@cxl{أَمْ كُنتُمْ شُهَدَآءَ إِذْ حَضَرَ يَعْقُوبَ ٱلْمَوْتُ إِذْ قَالَ لِبَنِيهِ مَا تَعْبُدُونَ مِنۢ بَعْدِى قَالُوا۟ نَعْبُدُ إِلَٰهَكَ وَإِلَٰهَ ءَابَآئِكَ إِبْرَٰهِۦمَ وَإِسْمَٰعِيلَ وَإِسْحَٰقَ إِلَٰهًا وَٰحِدًا وَنَحْنُ لَهُۥ مُسْلِمُونَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@cxli{تِلْكَ أُمَّةٌ قَدْ خَلَتْ لَهَا مَا كَسَبَتْ وَلَكُم مَّا كَسَبْتُمْ وَلَا تُسْـَٔلُونَ عَمَّا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@cxlii{وَقَالُوا۟ كُونُوا۟ هُودًا أَوْ نَصَٰرَىٰ تَهْتَدُوا۟ قُلْ بَلْ مِلَّةَ إِبْرَٰهِۦمَ حَنِيفًا وَمَا كَانَ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@cxliii{قُولُوٓا۟ ءَامَنَّا بِٱللَّهِ وَمَآ أُنزِلَ إِلَيْنَا وَمَآ أُنزِلَ إِلَىٰٓ إِبْرَٰهِۦمَ وَإِسْمَٰعِيلَ وَإِسْحَٰقَ وَيَعْقُوبَ وَٱلْأَسْبَاطِ وَمَآ أُوتِىَ مُوسَىٰ وَعِيسَىٰ وَمَآ أُوتِىَ ٱلنَّبِيُّونَ مِن رَّبِّهِمْ لَا نُفَرِّقُ بَيْنَ أَحَدٍ مِّنْهُمْ وَنَحْنُ لَهُۥ مُسْلِمُونَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@cxliv{فَإِنْ ءَامَنُوا۟ بِمِثْلِ مَآ ءَامَنتُم بِهِۦ فَقَدِ ٱهْتَدَوا۟ وَّإِن تَوَلَّوْا۟ فَإِنَّمَا هُمْ فِى شِقَاقٍ فَسَيَكْفِيكَهُمُ ٱللَّهُ وَهُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@cxlv{صِبْغَةَ ٱللَّهِ وَمَنْ أَحْسَنُ مِنَ ٱللَّهِ صِبْغَةً وَنَحْنُ لَهُۥ عَٰبِدُونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@cxlvi{قُلْ أَتُحَآجُّونَنَا فِى ٱللَّهِ وَهُوَ رَبُّنَا وَرَبُّكُمْ وَلَنَآ أَعْمَٰلُنَا وَلَكُمْ أَعْمَٰلُكُمْ وَنَحْنُ لَهُۥ مُخْلِصُونَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@cxlvii{أَمْ تَقُولُونَ إِنَّ إِبْرَٰهِۦمَ وَإِسْمَٰعِيلَ وَإِسْحَٰقَ وَيَعْقُوبَ وَٱلْأَسْبَاطَ كَانُوا۟ هُودًا أَوْ نَصَٰرَىٰ قُلْ ءَأَنتُمْ أَعْلَمُ أَمِ ٱللَّهُ وَمَنْ أَظْلَمُ مِمَّن كَتَمَ شَهَٰدَةً عِندَهُۥ مِنَ ٱللَّهِ وَمَا ٱللَّهُ بِغَٰفِلٍ عَمَّا تَعْمَلُونَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@cxlviii{تِلْكَ أُمَّةٌ قَدْ خَلَتْ لَهَا مَا كَسَبَتْ وَلَكُم مَّا كَسَبْتُمْ وَلَا تُسْـَٔلُونَ عَمَّا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@cxlix{سَيَقُولُ ٱلسُّفَهَآءُ مِنَ ٱلنَّاسِ مَا وَلَّىٰهُمْ عَن قِبْلَتِهِمُ ٱلَّتِى كَانُوا۟ عَلَيْهَا قُل لِّلَّهِ ٱلْمَشْرِقُ وَٱلْمَغْرِبُ يَهْدِى مَن يَشَآءُ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@cl{وَكَذَٰلِكَ جَعَلْنَٰكُمْ أُمَّةً وَسَطًا لِّتَكُونُوا۟ شُهَدَآءَ عَلَى ٱلنَّاسِ وَيَكُونَ ٱلرَّسُولُ عَلَيْكُمْ شَهِيدًا وَمَا جَعَلْنَا ٱلْقِبْلَةَ ٱلَّتِى كُنتَ عَلَيْهَآ إِلَّا لِنَعْلَمَ مَن يَتَّبِعُ ٱلرَّسُولَ مِمَّن يَنقَلِبُ عَلَىٰ عَقِبَيْهِ وَإِن كَانَتْ لَكَبِيرَةً إِلَّا عَلَى ٱلَّذِينَ هَدَى ٱللَّهُ وَمَا كَانَ ٱللَّهُ لِيُضِيعَ إِيمَٰنَكُمْ إِنَّ ٱللَّهَ بِٱلنَّاسِ لَرَءُوفٌ رَّحِيمٌ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@cli{قَدْ نَرَىٰ تَقَلُّبَ وَجْهِكَ فِى ٱلسَّمَآءِ فَلَنُوَلِّيَنَّكَ قِبْلَةً تَرْضَىٰهَا فَوَلِّ وَجْهَكَ شَطْرَ ٱلْمَسْجِدِ ٱلْحَرَامِ وَحَيْثُ مَا كُنتُمْ فَوَلُّوا۟ وُجُوهَكُمْ شَطْرَهُۥ وَإِنَّ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ لَيَعْلَمُونَ أَنَّهُ ٱلْحَقُّ مِن رَّبِّهِمْ وَمَا ٱللَّهُ بِغَٰفِلٍ عَمَّا يَعْمَلُونَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@clii{وَلَئِنْ أَتَيْتَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ بِكُلِّ ءَايَةٍ مَّا تَبِعُوا۟ قِبْلَتَكَ وَمَآ أَنتَ بِتَابِعٍ قِبْلَتَهُمْ وَمَا بَعْضُهُم بِتَابِعٍ قِبْلَةَ بَعْضٍ وَلَئِنِ ٱتَّبَعْتَ أَهْوَآءَهُم مِّنۢ بَعْدِ مَا جَآءَكَ مِنَ ٱلْعِلْمِ إِنَّكَ إِذًا لَّمِنَ ٱلظَّٰلِمِينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@cliii{ٱلَّذِينَ ءَاتَيْنَٰهُمُ ٱلْكِتَٰبَ يَعْرِفُونَهُۥ كَمَا يَعْرِفُونَ أَبْنَآءَهُمْ وَإِنَّ فَرِيقًا مِّنْهُمْ لَيَكْتُمُونَ ٱلْحَقَّ وَهُمْ يَعْلَمُونَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@cliv{ٱلْحَقُّ مِن رَّبِّكَ فَلَا تَكُونَنَّ مِنَ ٱلْمُمْتَرِينَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@clv{وَلِكُلٍّ وِجْهَةٌ هُوَ مُوَلِّيهَا فَٱسْتَبِقُوا۟ ٱلْخَيْرَٰتِ أَيْنَ مَا تَكُونُوا۟ يَأْتِ بِكُمُ ٱللَّهُ جَمِيعًا إِنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@clvi{وَمِنْ حَيْثُ خَرَجْتَ فَوَلِّ وَجْهَكَ شَطْرَ ٱلْمَسْجِدِ ٱلْحَرَامِ وَإِنَّهُۥ لَلْحَقُّ مِن رَّبِّكَ وَمَا ٱللَّهُ بِغَٰفِلٍ عَمَّا تَعْمَلُونَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@clvii{وَمِنْ حَيْثُ خَرَجْتَ فَوَلِّ وَجْهَكَ شَطْرَ ٱلْمَسْجِدِ ٱلْحَرَامِ وَحَيْثُ مَا كُنتُمْ فَوَلُّوا۟ وُجُوهَكُمْ شَطْرَهُۥ لِئَلَّا يَكُونَ لِلنَّاسِ عَلَيْكُمْ حُجَّةٌ إِلَّا ٱلَّذِينَ ظَلَمُوا۟ مِنْهُمْ فَلَا تَخْشَوْهُمْ وَٱخْشَوْنِى وَلِأُتِمَّ نِعْمَتِى عَلَيْكُمْ وَلَعَلَّكُمْ تَهْتَدُونَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@clviii{كَمَآ أَرْسَلْنَا فِيكُمْ رَسُولًا مِّنكُمْ يَتْلُوا۟ عَلَيْكُمْ ءَايَٰتِنَا وَيُزَكِّيكُمْ وَيُعَلِّمُكُمُ ٱلْكِتَٰبَ وَٱلْحِكْمَةَ وَيُعَلِّمُكُم مَّا لَمْ تَكُونُوا۟ تَعْلَمُونَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@clix{فَٱذْكُرُونِىٓ أَذْكُرْكُمْ وَٱشْكُرُوا۟ لِى وَلَا تَكْفُرُونِ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@clx{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱسْتَعِينُوا۟ بِٱلصَّبْرِ وَٱلصَّلَوٰةِ إِنَّ ٱللَّهَ مَعَ ٱلصَّٰبِرِينَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@clxi{وَلَا تَقُولُوا۟ لِمَن يُقْتَلُ فِى سَبِيلِ ٱللَّهِ أَمْوَٰتٌۢ بَلْ أَحْيَآءٌ وَلَٰكِن لَّا تَشْعُرُونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@clxii{وَلَنَبْلُوَنَّكُم بِشَىْءٍ مِّنَ ٱلْخَوْفِ وَٱلْجُوعِ وَنَقْصٍ مِّنَ ٱلْأَمْوَٰلِ وَٱلْأَنفُسِ وَٱلثَّمَرَٰتِ وَبَشِّرِ ٱلصَّٰبِرِينَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@clxiii{ٱلَّذِينَ إِذَآ أَصَٰبَتْهُم مُّصِيبَةٌ قَالُوٓا۟ إِنَّا لِلَّهِ وَإِنَّآ إِلَيْهِ رَٰجِعُونَ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@clxiv{أُو۟لَٰٓئِكَ عَلَيْهِمْ صَلَوَٰتٌ مِّن رَّبِّهِمْ وَرَحْمَةٌ وَأُو۟لَٰٓئِكَ هُمُ ٱلْمُهْتَدُونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@clxv{إِنَّ ٱلصَّفَا وَٱلْمَرْوَةَ مِن شَعَآئِرِ ٱللَّهِ فَمَنْ حَجَّ ٱلْبَيْتَ أَوِ ٱعْتَمَرَ فَلَا جُنَاحَ عَلَيْهِ أَن يَطَّوَّفَ بِهِمَا وَمَن تَطَوَّعَ خَيْرًا فَإِنَّ ٱللَّهَ شَاكِرٌ عَلِيمٌ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@clxvi{إِنَّ ٱلَّذِينَ يَكْتُمُونَ مَآ أَنزَلْنَا مِنَ ٱلْبَيِّنَٰتِ وَٱلْهُدَىٰ مِنۢ بَعْدِ مَا بَيَّنَّٰهُ لِلنَّاسِ فِى ٱلْكِتَٰبِ أُو۟لَٰٓئِكَ يَلْعَنُهُمُ ٱللَّهُ وَيَلْعَنُهُمُ ٱللَّٰعِنُونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@clxvii{إِلَّا ٱلَّذِينَ تَابُوا۟ وَأَصْلَحُوا۟ وَبَيَّنُوا۟ فَأُو۟لَٰٓئِكَ أَتُوبُ عَلَيْهِمْ وَأَنَا ٱلتَّوَّابُ ٱلرَّحِيمُ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@clxviii{إِنَّ ٱلَّذِينَ كَفَرُوا۟ وَمَاتُوا۟ وَهُمْ كُفَّارٌ أُو۟لَٰٓئِكَ عَلَيْهِمْ لَعْنَةُ ٱللَّهِ وَٱلْمَلَٰٓئِكَةِ وَٱلنَّاسِ أَجْمَعِينَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@clxix{خَٰلِدِينَ فِيهَا لَا يُخَفَّفُ عَنْهُمُ ٱلْعَذَابُ وَلَا هُمْ يُنظَرُونَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@clxx{وَإِلَٰهُكُمْ إِلَٰهٌ وَٰحِدٌ لَّآ إِلَٰهَ إِلَّا هُوَ ٱلرَّحْمَٰنُ ٱلرَّحِيمُ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@clxxi{إِنَّ فِى خَلْقِ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱخْتِلَٰفِ ٱلَّيْلِ وَٱلنَّهَارِ وَٱلْفُلْكِ ٱلَّتِى تَجْرِى فِى ٱلْبَحْرِ بِمَا يَنفَعُ ٱلنَّاسَ وَمَآ أَنزَلَ ٱللَّهُ مِنَ ٱلسَّمَآءِ مِن مَّآءٍ فَأَحْيَا بِهِ ٱلْأَرْضَ بَعْدَ مَوْتِهَا وَبَثَّ فِيهَا مِن كُلِّ دَآبَّةٍ وَتَصْرِيفِ ٱلرِّيَٰحِ وَٱلسَّحَابِ ٱلْمُسَخَّرِ بَيْنَ ٱلسَّمَآءِ وَٱلْأَرْضِ لَءَايَٰتٍ لِّقَوْمٍ يَعْقِلُونَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@clxxii{وَمِنَ ٱلنَّاسِ مَن يَتَّخِذُ مِن دُونِ ٱللَّهِ أَندَادًا يُحِبُّونَهُمْ كَحُبِّ ٱللَّهِ وَٱلَّذِينَ ءَامَنُوٓا۟ أَشَدُّ حُبًّا لِّلَّهِ وَلَوْ يَرَى ٱلَّذِينَ ظَلَمُوٓا۟ إِذْ يَرَوْنَ ٱلْعَذَابَ أَنَّ ٱلْقُوَّةَ لِلَّهِ جَمِيعًا وَأَنَّ ٱللَّهَ شَدِيدُ ٱلْعَذَابِ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@clxxiii{إِذْ تَبَرَّأَ ٱلَّذِينَ ٱتُّبِعُوا۟ مِنَ ٱلَّذِينَ ٱتَّبَعُوا۟ وَرَأَوُا۟ ٱلْعَذَابَ وَتَقَطَّعَتْ بِهِمُ ٱلْأَسْبَابُ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@clxxiv{وَقَالَ ٱلَّذِينَ ٱتَّبَعُوا۟ لَوْ أَنَّ لَنَا كَرَّةً فَنَتَبَرَّأَ مِنْهُمْ كَمَا تَبَرَّءُوا۟ مِنَّا كَذَٰلِكَ يُرِيهِمُ ٱللَّهُ أَعْمَٰلَهُمْ حَسَرَٰتٍ عَلَيْهِمْ وَمَا هُم بِخَٰرِجِينَ مِنَ ٱلنَّارِ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@clxxv{يَٰٓأَيُّهَا ٱلنَّاسُ كُلُوا۟ مِمَّا فِى ٱلْأَرْضِ حَلَٰلًا طَيِّبًا وَلَا تَتَّبِعُوا۟ خُطُوَٰتِ ٱلشَّيْطَٰنِ إِنَّهُۥ لَكُمْ عَدُوٌّ مُّبِينٌ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@clxxvi{إِنَّمَا يَأْمُرُكُم بِٱلسُّوٓءِ وَٱلْفَحْشَآءِ وَأَن تَقُولُوا۟ عَلَى ٱللَّهِ مَا لَا تَعْلَمُونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@clxxvii{وَإِذَا قِيلَ لَهُمُ ٱتَّبِعُوا۟ مَآ أَنزَلَ ٱللَّهُ قَالُوا۟ بَلْ نَتَّبِعُ مَآ أَلْفَيْنَا عَلَيْهِ ءَابَآءَنَآ أَوَلَوْ كَانَ ءَابَآؤُهُمْ لَا يَعْقِلُونَ شَيْـًٔا وَلَا يَهْتَدُونَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@clxxviii{وَمَثَلُ ٱلَّذِينَ كَفَرُوا۟ كَمَثَلِ ٱلَّذِى يَنْعِقُ بِمَا لَا يَسْمَعُ إِلَّا دُعَآءً وَنِدَآءً صُمٌّۢ بُكْمٌ عُمْىٌ فَهُمْ لَا يَعْقِلُونَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@clxxix{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ كُلُوا۟ مِن طَيِّبَٰتِ مَا رَزَقْنَٰكُمْ وَٱشْكُرُوا۟ لِلَّهِ إِن كُنتُمْ إِيَّاهُ تَعْبُدُونَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@clxxx{إِنَّمَا حَرَّمَ عَلَيْكُمُ ٱلْمَيْتَةَ وَٱلدَّمَ وَلَحْمَ ٱلْخِنزِيرِ وَمَآ أُهِلَّ بِهِۦ لِغَيْرِ ٱللَّهِ فَمَنِ ٱضْطُرَّ غَيْرَ بَاغٍ وَلَا عَادٍ فَلَآ إِثْمَ عَلَيْهِ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@clxxxi{إِنَّ ٱلَّذِينَ يَكْتُمُونَ مَآ أَنزَلَ ٱللَّهُ مِنَ ٱلْكِتَٰبِ وَيَشْتَرُونَ بِهِۦ ثَمَنًا قَلِيلًا أُو۟لَٰٓئِكَ مَا يَأْكُلُونَ فِى بُطُونِهِمْ إِلَّا ٱلنَّارَ وَلَا يُكَلِّمُهُمُ ٱللَّهُ يَوْمَ ٱلْقِيَٰمَةِ وَلَا يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@clxxxii{أُو۟لَٰٓئِكَ ٱلَّذِينَ ٱشْتَرَوُا۟ ٱلضَّلَٰلَةَ بِٱلْهُدَىٰ وَٱلْعَذَابَ بِٱلْمَغْفِرَةِ فَمَآ أَصْبَرَهُمْ عَلَى ٱلنَّارِ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@clxxxiii{ذَٰلِكَ بِأَنَّ ٱللَّهَ نَزَّلَ ٱلْكِتَٰبَ بِٱلْحَقِّ وَإِنَّ ٱلَّذِينَ ٱخْتَلَفُوا۟ فِى ٱلْكِتَٰبِ لَفِى شِقَاقٍۭ بَعِيدٍ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@clxxxiv{لَّيْسَ ٱلْبِرَّ أَن تُوَلُّوا۟ وُجُوهَكُمْ قِبَلَ ٱلْمَشْرِقِ وَٱلْمَغْرِبِ وَلَٰكِنَّ ٱلْبِرَّ مَنْ ءَامَنَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَٱلْمَلَٰٓئِكَةِ وَٱلْكِتَٰبِ وَٱلنَّبِيِّۦنَ وَءَاتَى ٱلْمَالَ عَلَىٰ حُبِّهِۦ ذَوِى ٱلْقُرْبَىٰ وَٱلْيَتَٰمَىٰ وَٱلْمَسَٰكِينَ وَٱبْنَ ٱلسَّبِيلِ وَٱلسَّآئِلِينَ وَفِى ٱلرِّقَابِ وَأَقَامَ ٱلصَّلَوٰةَ وَءَاتَى ٱلزَّكَوٰةَ وَٱلْمُوفُونَ بِعَهْدِهِمْ إِذَا عَٰهَدُوا۟ وَٱلصَّٰبِرِينَ فِى ٱلْبَأْسَآءِ وَٱلضَّرَّآءِ وَحِينَ ٱلْبَأْسِ أُو۟لَٰٓئِكَ ٱلَّذِينَ صَدَقُوا۟ وَأُو۟لَٰٓئِكَ هُمُ ٱلْمُتَّقُونَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@clxxxv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ كُتِبَ عَلَيْكُمُ ٱلْقِصَاصُ فِى ٱلْقَتْلَى ٱلْحُرُّ بِٱلْحُرِّ وَٱلْعَبْدُ بِٱلْعَبْدِ وَٱلْأُنثَىٰ بِٱلْأُنثَىٰ فَمَنْ عُفِىَ لَهُۥ مِنْ أَخِيهِ شَىْءٌ فَٱتِّبَاعٌۢ بِٱلْمَعْرُوفِ وَأَدَآءٌ إِلَيْهِ بِإِحْسَٰنٍ ذَٰلِكَ تَخْفِيفٌ مِّن رَّبِّكُمْ وَرَحْمَةٌ فَمَنِ ٱعْتَدَىٰ بَعْدَ ذَٰلِكَ فَلَهُۥ عَذَابٌ أَلِيمٌ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@clxxxvi{وَلَكُمْ فِى ٱلْقِصَاصِ حَيَوٰةٌ يَٰٓأُو۟لِى ٱلْأَلْبَٰبِ لَعَلَّكُمْ تَتَّقُونَ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@clxxxvii{كُتِبَ عَلَيْكُمْ إِذَا حَضَرَ أَحَدَكُمُ ٱلْمَوْتُ إِن تَرَكَ خَيْرًا ٱلْوَصِيَّةُ لِلْوَٰلِدَيْنِ وَٱلْأَقْرَبِينَ بِٱلْمَعْرُوفِ حَقًّا عَلَى ٱلْمُتَّقِينَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@clxxxviii{فَمَنۢ بَدَّلَهُۥ بَعْدَمَا سَمِعَهُۥ فَإِنَّمَآ إِثْمُهُۥ عَلَى ٱلَّذِينَ يُبَدِّلُونَهُۥٓ إِنَّ ٱللَّهَ سَمِيعٌ عَلِيمٌ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@clxxxix{فَمَنْ خَافَ مِن مُّوصٍ جَنَفًا أَوْ إِثْمًا فَأَصْلَحَ بَيْنَهُمْ فَلَآ إِثْمَ عَلَيْهِ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@cxc{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ كُتِبَ عَلَيْكُمُ ٱلصِّيَامُ كَمَا كُتِبَ عَلَى ٱلَّذِينَ مِن قَبْلِكُمْ لَعَلَّكُمْ تَتَّقُونَ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@cxci{أَيَّامًا مَّعْدُودَٰتٍ فَمَن كَانَ مِنكُم مَّرِيضًا أَوْ عَلَىٰ سَفَرٍ فَعِدَّةٌ مِّنْ أَيَّامٍ أُخَرَ وَعَلَى ٱلَّذِينَ يُطِيقُونَهُۥ فِدْيَةٌ طَعَامُ مِسْكِينٍ فَمَن تَطَوَّعَ خَيْرًا فَهُوَ خَيْرٌ لَّهُۥ وَأَن تَصُومُوا۟ خَيْرٌ لَّكُمْ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@cxcii{شَهْرُ رَمَضَانَ ٱلَّذِىٓ أُنزِلَ فِيهِ ٱلْقُرْءَانُ هُدًى لِّلنَّاسِ وَبَيِّنَٰتٍ مِّنَ ٱلْهُدَىٰ وَٱلْفُرْقَانِ فَمَن شَهِدَ مِنكُمُ ٱلشَّهْرَ فَلْيَصُمْهُ وَمَن كَانَ مَرِيضًا أَوْ عَلَىٰ سَفَرٍ فَعِدَّةٌ مِّنْ أَيَّامٍ أُخَرَ يُرِيدُ ٱللَّهُ بِكُمُ ٱلْيُسْرَ وَلَا يُرِيدُ بِكُمُ ٱلْعُسْرَ وَلِتُكْمِلُوا۟ ٱلْعِدَّةَ وَلِتُكَبِّرُوا۟ ٱللَّهَ عَلَىٰ مَا هَدَىٰكُمْ وَلَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@cxciii{وَإِذَا سَأَلَكَ عِبَادِى عَنِّى فَإِنِّى قَرِيبٌ أُجِيبُ دَعْوَةَ ٱلدَّاعِ إِذَا دَعَانِ فَلْيَسْتَجِيبُوا۟ لِى وَلْيُؤْمِنُوا۟ بِى لَعَلَّهُمْ يَرْشُدُونَ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@cxciv{أُحِلَّ لَكُمْ لَيْلَةَ ٱلصِّيَامِ ٱلرَّفَثُ إِلَىٰ نِسَآئِكُمْ هُنَّ لِبَاسٌ لَّكُمْ وَأَنتُمْ لِبَاسٌ لَّهُنَّ عَلِمَ ٱللَّهُ أَنَّكُمْ كُنتُمْ تَخْتَانُونَ أَنفُسَكُمْ فَتَابَ عَلَيْكُمْ وَعَفَا عَنكُمْ فَٱلْـَٰٔنَ بَٰشِرُوهُنَّ وَٱبْتَغُوا۟ مَا كَتَبَ ٱللَّهُ لَكُمْ وَكُلُوا۟ وَٱشْرَبُوا۟ حَتَّىٰ يَتَبَيَّنَ لَكُمُ ٱلْخَيْطُ ٱلْأَبْيَضُ مِنَ ٱلْخَيْطِ ٱلْأَسْوَدِ مِنَ ٱلْفَجْرِ ثُمَّ أَتِمُّوا۟ ٱلصِّيَامَ إِلَى ٱلَّيْلِ وَلَا تُبَٰشِرُوهُنَّ وَأَنتُمْ عَٰكِفُونَ فِى ٱلْمَسَٰجِدِ تِلْكَ حُدُودُ ٱللَّهِ فَلَا تَقْرَبُوهَا كَذَٰلِكَ يُبَيِّنُ ٱللَّهُ ءَايَٰتِهِۦ لِلنَّاسِ لَعَلَّهُمْ يَتَّقُونَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@cxcv{وَلَا تَأْكُلُوٓا۟ أَمْوَٰلَكُم بَيْنَكُم بِٱلْبَٰطِلِ وَتُدْلُوا۟ بِهَآ إِلَى ٱلْحُكَّامِ لِتَأْكُلُوا۟ فَرِيقًا مِّنْ أَمْوَٰلِ ٱلنَّاسِ بِٱلْإِثْمِ وَأَنتُمْ تَعْلَمُونَ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@cxcvi{يَسْـَٔلُونَكَ عَنِ ٱلْأَهِلَّةِ قُلْ هِىَ مَوَٰقِيتُ لِلنَّاسِ وَٱلْحَجِّ وَلَيْسَ ٱلْبِرُّ بِأَن تَأْتُوا۟ ٱلْبُيُوتَ مِن ظُهُورِهَا وَلَٰكِنَّ ٱلْبِرَّ مَنِ ٱتَّقَىٰ وَأْتُوا۟ ٱلْبُيُوتَ مِنْ أَبْوَٰبِهَا وَٱتَّقُوا۟ ٱللَّهَ لَعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@cxcvii{وَقَٰتِلُوا۟ فِى سَبِيلِ ٱللَّهِ ٱلَّذِينَ يُقَٰتِلُونَكُمْ وَلَا تَعْتَدُوٓا۟ إِنَّ ٱللَّهَ لَا يُحِبُّ ٱلْمُعْتَدِينَ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@cxcviii{وَٱقْتُلُوهُمْ حَيْثُ ثَقِفْتُمُوهُمْ وَأَخْرِجُوهُم مِّنْ حَيْثُ أَخْرَجُوكُمْ وَٱلْفِتْنَةُ أَشَدُّ مِنَ ٱلْقَتْلِ وَلَا تُقَٰتِلُوهُمْ عِندَ ٱلْمَسْجِدِ ٱلْحَرَامِ حَتَّىٰ يُقَٰتِلُوكُمْ فِيهِ فَإِن قَٰتَلُوكُمْ فَٱقْتُلُوهُمْ كَذَٰلِكَ جَزَآءُ ٱلْكَٰفِرِينَ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@cxcix{فَإِنِ ٱنتَهَوْا۟ فَإِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@cc{وَقَٰتِلُوهُمْ حَتَّىٰ لَا تَكُونَ فِتْنَةٌ وَيَكُونَ ٱلدِّينُ لِلَّهِ فَإِنِ ٱنتَهَوْا۟ فَلَا عُدْوَٰنَ إِلَّا عَلَى ٱلظَّٰلِمِينَ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@cci{ٱلشَّهْرُ ٱلْحَرَامُ بِٱلشَّهْرِ ٱلْحَرَامِ وَٱلْحُرُمَٰتُ قِصَاصٌ فَمَنِ ٱعْتَدَىٰ عَلَيْكُمْ فَٱعْتَدُوا۟ عَلَيْهِ بِمِثْلِ مَا ٱعْتَدَىٰ عَلَيْكُمْ وَٱتَّقُوا۟ ٱللَّهَ وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ مَعَ ٱلْمُتَّقِينَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@ccii{وَأَنفِقُوا۟ فِى سَبِيلِ ٱللَّهِ وَلَا تُلْقُوا۟ بِأَيْدِيكُمْ إِلَى ٱلتَّهْلُكَةِ وَأَحْسِنُوٓا۟ إِنَّ ٱللَّهَ يُحِبُّ ٱلْمُحْسِنِينَ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@cciii{وَأَتِمُّوا۟ ٱلْحَجَّ وَٱلْعُمْرَةَ لِلَّهِ فَإِنْ أُحْصِرْتُمْ فَمَا ٱسْتَيْسَرَ مِنَ ٱلْهَدْىِ وَلَا تَحْلِقُوا۟ رُءُوسَكُمْ حَتَّىٰ يَبْلُغَ ٱلْهَدْىُ مَحِلَّهُۥ فَمَن كَانَ مِنكُم مَّرِيضًا أَوْ بِهِۦٓ أَذًى مِّن رَّأْسِهِۦ فَفِدْيَةٌ مِّن صِيَامٍ أَوْ صَدَقَةٍ أَوْ نُسُكٍ فَإِذَآ أَمِنتُمْ فَمَن تَمَتَّعَ بِٱلْعُمْرَةِ إِلَى ٱلْحَجِّ فَمَا ٱسْتَيْسَرَ مِنَ ٱلْهَدْىِ فَمَن لَّمْ يَجِدْ فَصِيَامُ ثَلَٰثَةِ أَيَّامٍ فِى ٱلْحَجِّ وَسَبْعَةٍ إِذَا رَجَعْتُمْ تِلْكَ عَشَرَةٌ كَامِلَةٌ ذَٰلِكَ لِمَن لَّمْ يَكُنْ أَهْلُهُۥ حَاضِرِى ٱلْمَسْجِدِ ٱلْحَرَامِ وَٱتَّقُوا۟ ٱللَّهَ وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@cciv{ٱلْحَجُّ أَشْهُرٌ مَّعْلُومَٰتٌ فَمَن فَرَضَ فِيهِنَّ ٱلْحَجَّ فَلَا رَفَثَ وَلَا فُسُوقَ وَلَا جِدَالَ فِى ٱلْحَجِّ وَمَا تَفْعَلُوا۟ مِنْ خَيْرٍ يَعْلَمْهُ ٱللَّهُ وَتَزَوَّدُوا۟ فَإِنَّ خَيْرَ ٱلزَّادِ ٱلتَّقْوَىٰ وَٱتَّقُونِ يَٰٓأُو۟لِى ٱلْأَلْبَٰبِ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@ccv{لَيْسَ عَلَيْكُمْ جُنَاحٌ أَن تَبْتَغُوا۟ فَضْلًا مِّن رَّبِّكُمْ فَإِذَآ أَفَضْتُم مِّنْ عَرَفَٰتٍ فَٱذْكُرُوا۟ ٱللَّهَ عِندَ ٱلْمَشْعَرِ ٱلْحَرَامِ وَٱذْكُرُوهُ كَمَا هَدَىٰكُمْ وَإِن كُنتُم مِّن قَبْلِهِۦ لَمِنَ ٱلضَّآلِّينَ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@ccvi{ثُمَّ أَفِيضُوا۟ مِنْ حَيْثُ أَفَاضَ ٱلنَّاسُ وَٱسْتَغْفِرُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@ccvii{فَإِذَا قَضَيْتُم مَّنَٰسِكَكُمْ فَٱذْكُرُوا۟ ٱللَّهَ كَذِكْرِكُمْ ءَابَآءَكُمْ أَوْ أَشَدَّ ذِكْرًا فَمِنَ ٱلنَّاسِ مَن يَقُولُ رَبَّنَآ ءَاتِنَا فِى ٱلدُّنْيَا وَمَا لَهُۥ فِى ٱلْءَاخِرَةِ مِنْ خَلَٰقٍ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@ccviii{وَمِنْهُم مَّن يَقُولُ رَبَّنَآ ءَاتِنَا فِى ٱلدُّنْيَا حَسَنَةً وَفِى ٱلْءَاخِرَةِ حَسَنَةً وَقِنَا عَذَابَ ٱلنَّارِ\qt@no{﴿٢٠١﴾}}
\qt@newcmd\qurantext@ccix{أُو۟لَٰٓئِكَ لَهُمْ نَصِيبٌ مِّمَّا كَسَبُوا۟ وَٱللَّهُ سَرِيعُ ٱلْحِسَابِ\qt@no{﴿٢٠٢﴾}}
\qt@newcmd\qurantext@ccx{وَٱذْكُرُوا۟ ٱللَّهَ فِىٓ أَيَّامٍ مَّعْدُودَٰتٍ فَمَن تَعَجَّلَ فِى يَوْمَيْنِ فَلَآ إِثْمَ عَلَيْهِ وَمَن تَأَخَّرَ فَلَآ إِثْمَ عَلَيْهِ لِمَنِ ٱتَّقَىٰ وَٱتَّقُوا۟ ٱللَّهَ وَٱعْلَمُوٓا۟ أَنَّكُمْ إِلَيْهِ تُحْشَرُونَ\qt@no{﴿٢٠٣﴾}}
\qt@newcmd\qurantext@ccxi{وَمِنَ ٱلنَّاسِ مَن يُعْجِبُكَ قَوْلُهُۥ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَيُشْهِدُ ٱللَّهَ عَلَىٰ مَا فِى قَلْبِهِۦ وَهُوَ أَلَدُّ ٱلْخِصَامِ\qt@no{﴿٢٠٤﴾}}
\qt@newcmd\qurantext@ccxii{وَإِذَا تَوَلَّىٰ سَعَىٰ فِى ٱلْأَرْضِ لِيُفْسِدَ فِيهَا وَيُهْلِكَ ٱلْحَرْثَ وَٱلنَّسْلَ وَٱللَّهُ لَا يُحِبُّ ٱلْفَسَادَ\qt@no{﴿٢٠٥﴾}}
\qt@newcmd\qurantext@ccxiii{وَإِذَا قِيلَ لَهُ ٱتَّقِ ٱللَّهَ أَخَذَتْهُ ٱلْعِزَّةُ بِٱلْإِثْمِ فَحَسْبُهُۥ جَهَنَّمُ وَلَبِئْسَ ٱلْمِهَادُ\qt@no{﴿٢٠٦﴾}}
\qt@newcmd\qurantext@ccxiv{وَمِنَ ٱلنَّاسِ مَن يَشْرِى نَفْسَهُ ٱبْتِغَآءَ مَرْضَاتِ ٱللَّهِ وَٱللَّهُ رَءُوفٌۢ بِٱلْعِبَادِ\qt@no{﴿٢٠٧﴾}}
\qt@newcmd\qurantext@ccxv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱدْخُلُوا۟ فِى ٱلسِّلْمِ كَآفَّةً وَلَا تَتَّبِعُوا۟ خُطُوَٰتِ ٱلشَّيْطَٰنِ إِنَّهُۥ لَكُمْ عَدُوٌّ مُّبِينٌ\qt@no{﴿٢٠٨﴾}}
\qt@newcmd\qurantext@ccxvi{فَإِن زَلَلْتُم مِّنۢ بَعْدِ مَا جَآءَتْكُمُ ٱلْبَيِّنَٰتُ فَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ عَزِيزٌ حَكِيمٌ\qt@no{﴿٢٠٩﴾}}
\qt@newcmd\qurantext@ccxvii{هَلْ يَنظُرُونَ إِلَّآ أَن يَأْتِيَهُمُ ٱللَّهُ فِى ظُلَلٍ مِّنَ ٱلْغَمَامِ وَٱلْمَلَٰٓئِكَةُ وَقُضِىَ ٱلْأَمْرُ وَإِلَى ٱللَّهِ تُرْجَعُ ٱلْأُمُورُ\qt@no{﴿٢١٠﴾}}
\qt@newcmd\qurantext@ccxviii{سَلْ بَنِىٓ إِسْرَٰٓءِيلَ كَمْ ءَاتَيْنَٰهُم مِّنْ ءَايَةٍۭ بَيِّنَةٍ وَمَن يُبَدِّلْ نِعْمَةَ ٱللَّهِ مِنۢ بَعْدِ مَا جَآءَتْهُ فَإِنَّ ٱللَّهَ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿٢١١﴾}}
\qt@newcmd\qurantext@ccxix{زُيِّنَ لِلَّذِينَ كَفَرُوا۟ ٱلْحَيَوٰةُ ٱلدُّنْيَا وَيَسْخَرُونَ مِنَ ٱلَّذِينَ ءَامَنُوا۟ وَٱلَّذِينَ ٱتَّقَوْا۟ فَوْقَهُمْ يَوْمَ ٱلْقِيَٰمَةِ وَٱللَّهُ يَرْزُقُ مَن يَشَآءُ بِغَيْرِ حِسَابٍ\qt@no{﴿٢١٢﴾}}
\qt@newcmd\qurantext@ccxx{كَانَ ٱلنَّاسُ أُمَّةً وَٰحِدَةً فَبَعَثَ ٱللَّهُ ٱلنَّبِيِّۦنَ مُبَشِّرِينَ وَمُنذِرِينَ وَأَنزَلَ مَعَهُمُ ٱلْكِتَٰبَ بِٱلْحَقِّ لِيَحْكُمَ بَيْنَ ٱلنَّاسِ فِيمَا ٱخْتَلَفُوا۟ فِيهِ وَمَا ٱخْتَلَفَ فِيهِ إِلَّا ٱلَّذِينَ أُوتُوهُ مِنۢ بَعْدِ مَا جَآءَتْهُمُ ٱلْبَيِّنَٰتُ بَغْيًۢا بَيْنَهُمْ فَهَدَى ٱللَّهُ ٱلَّذِينَ ءَامَنُوا۟ لِمَا ٱخْتَلَفُوا۟ فِيهِ مِنَ ٱلْحَقِّ بِإِذْنِهِۦ وَٱللَّهُ يَهْدِى مَن يَشَآءُ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٢١٣﴾}}
\qt@newcmd\qurantext@ccxxi{أَمْ حَسِبْتُمْ أَن تَدْخُلُوا۟ ٱلْجَنَّةَ وَلَمَّا يَأْتِكُم مَّثَلُ ٱلَّذِينَ خَلَوْا۟ مِن قَبْلِكُم مَّسَّتْهُمُ ٱلْبَأْسَآءُ وَٱلضَّرَّآءُ وَزُلْزِلُوا۟ حَتَّىٰ يَقُولَ ٱلرَّسُولُ وَٱلَّذِينَ ءَامَنُوا۟ مَعَهُۥ مَتَىٰ نَصْرُ ٱللَّهِ أَلَآ إِنَّ نَصْرَ ٱللَّهِ قَرِيبٌ\qt@no{﴿٢١٤﴾}}
\qt@newcmd\qurantext@ccxxii{يَسْـَٔلُونَكَ مَاذَا يُنفِقُونَ قُلْ مَآ أَنفَقْتُم مِّنْ خَيْرٍ فَلِلْوَٰلِدَيْنِ وَٱلْأَقْرَبِينَ وَٱلْيَتَٰمَىٰ وَٱلْمَسَٰكِينِ وَٱبْنِ ٱلسَّبِيلِ وَمَا تَفْعَلُوا۟ مِنْ خَيْرٍ فَإِنَّ ٱللَّهَ بِهِۦ عَلِيمٌ\qt@no{﴿٢١٥﴾}}
\qt@newcmd\qurantext@ccxxiii{كُتِبَ عَلَيْكُمُ ٱلْقِتَالُ وَهُوَ كُرْهٌ لَّكُمْ وَعَسَىٰٓ أَن تَكْرَهُوا۟ شَيْـًٔا وَهُوَ خَيْرٌ لَّكُمْ وَعَسَىٰٓ أَن تُحِبُّوا۟ شَيْـًٔا وَهُوَ شَرٌّ لَّكُمْ وَٱللَّهُ يَعْلَمُ وَأَنتُمْ لَا تَعْلَمُونَ\qt@no{﴿٢١٦﴾}}
\qt@newcmd\qurantext@ccxxiv{يَسْـَٔلُونَكَ عَنِ ٱلشَّهْرِ ٱلْحَرَامِ قِتَالٍ فِيهِ قُلْ قِتَالٌ فِيهِ كَبِيرٌ وَصَدٌّ عَن سَبِيلِ ٱللَّهِ وَكُفْرٌۢ بِهِۦ وَٱلْمَسْجِدِ ٱلْحَرَامِ وَإِخْرَاجُ أَهْلِهِۦ مِنْهُ أَكْبَرُ عِندَ ٱللَّهِ وَٱلْفِتْنَةُ أَكْبَرُ مِنَ ٱلْقَتْلِ وَلَا يَزَالُونَ يُقَٰتِلُونَكُمْ حَتَّىٰ يَرُدُّوكُمْ عَن دِينِكُمْ إِنِ ٱسْتَطَٰعُوا۟ وَمَن يَرْتَدِدْ مِنكُمْ عَن دِينِهِۦ فَيَمُتْ وَهُوَ كَافِرٌ فَأُو۟لَٰٓئِكَ حَبِطَتْ أَعْمَٰلُهُمْ فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَأُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٢١٧﴾}}
\qt@newcmd\qurantext@ccxxv{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَٱلَّذِينَ هَاجَرُوا۟ وَجَٰهَدُوا۟ فِى سَبِيلِ ٱللَّهِ أُو۟لَٰٓئِكَ يَرْجُونَ رَحْمَتَ ٱللَّهِ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٢١٨﴾}}
\qt@newcmd\qurantext@ccxxvi{يَسْـَٔلُونَكَ عَنِ ٱلْخَمْرِ وَٱلْمَيْسِرِ قُلْ فِيهِمَآ إِثْمٌ كَبِيرٌ وَمَنَٰفِعُ لِلنَّاسِ وَإِثْمُهُمَآ أَكْبَرُ مِن نَّفْعِهِمَا وَيَسْـَٔلُونَكَ مَاذَا يُنفِقُونَ قُلِ ٱلْعَفْوَ كَذَٰلِكَ يُبَيِّنُ ٱللَّهُ لَكُمُ ٱلْءَايَٰتِ لَعَلَّكُمْ تَتَفَكَّرُونَ\qt@no{﴿٢١٩﴾}}
\qt@newcmd\qurantext@ccxxvii{فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَيَسْـَٔلُونَكَ عَنِ ٱلْيَتَٰمَىٰ قُلْ إِصْلَاحٌ لَّهُمْ خَيْرٌ وَإِن تُخَالِطُوهُمْ فَإِخْوَٰنُكُمْ وَٱللَّهُ يَعْلَمُ ٱلْمُفْسِدَ مِنَ ٱلْمُصْلِحِ وَلَوْ شَآءَ ٱللَّهُ لَأَعْنَتَكُمْ إِنَّ ٱللَّهَ عَزِيزٌ حَكِيمٌ\qt@no{﴿٢٢٠﴾}}
\qt@newcmd\qurantext@ccxxviii{وَلَا تَنكِحُوا۟ ٱلْمُشْرِكَٰتِ حَتَّىٰ يُؤْمِنَّ وَلَأَمَةٌ مُّؤْمِنَةٌ خَيْرٌ مِّن مُّشْرِكَةٍ وَلَوْ أَعْجَبَتْكُمْ وَلَا تُنكِحُوا۟ ٱلْمُشْرِكِينَ حَتَّىٰ يُؤْمِنُوا۟ وَلَعَبْدٌ مُّؤْمِنٌ خَيْرٌ مِّن مُّشْرِكٍ وَلَوْ أَعْجَبَكُمْ أُو۟لَٰٓئِكَ يَدْعُونَ إِلَى ٱلنَّارِ وَٱللَّهُ يَدْعُوٓا۟ إِلَى ٱلْجَنَّةِ وَٱلْمَغْفِرَةِ بِإِذْنِهِۦ وَيُبَيِّنُ ءَايَٰتِهِۦ لِلنَّاسِ لَعَلَّهُمْ يَتَذَكَّرُونَ\qt@no{﴿٢٢١﴾}}
\qt@newcmd\qurantext@ccxxix{وَيَسْـَٔلُونَكَ عَنِ ٱلْمَحِيضِ قُلْ هُوَ أَذًى فَٱعْتَزِلُوا۟ ٱلنِّسَآءَ فِى ٱلْمَحِيضِ وَلَا تَقْرَبُوهُنَّ حَتَّىٰ يَطْهُرْنَ فَإِذَا تَطَهَّرْنَ فَأْتُوهُنَّ مِنْ حَيْثُ أَمَرَكُمُ ٱللَّهُ إِنَّ ٱللَّهَ يُحِبُّ ٱلتَّوَّٰبِينَ وَيُحِبُّ ٱلْمُتَطَهِّرِينَ\qt@no{﴿٢٢٢﴾}}
\qt@newcmd\qurantext@ccxxx{نِسَآؤُكُمْ حَرْثٌ لَّكُمْ فَأْتُوا۟ حَرْثَكُمْ أَنَّىٰ شِئْتُمْ وَقَدِّمُوا۟ لِأَنفُسِكُمْ وَٱتَّقُوا۟ ٱللَّهَ وَٱعْلَمُوٓا۟ أَنَّكُم مُّلَٰقُوهُ وَبَشِّرِ ٱلْمُؤْمِنِينَ\qt@no{﴿٢٢٣﴾}}
\qt@newcmd\qurantext@ccxxxi{وَلَا تَجْعَلُوا۟ ٱللَّهَ عُرْضَةً لِّأَيْمَٰنِكُمْ أَن تَبَرُّوا۟ وَتَتَّقُوا۟ وَتُصْلِحُوا۟ بَيْنَ ٱلنَّاسِ وَٱللَّهُ سَمِيعٌ عَلِيمٌ\qt@no{﴿٢٢٤﴾}}
\qt@newcmd\qurantext@ccxxxii{لَّا يُؤَاخِذُكُمُ ٱللَّهُ بِٱللَّغْوِ فِىٓ أَيْمَٰنِكُمْ وَلَٰكِن يُؤَاخِذُكُم بِمَا كَسَبَتْ قُلُوبُكُمْ وَٱللَّهُ غَفُورٌ حَلِيمٌ\qt@no{﴿٢٢٥﴾}}
\qt@newcmd\qurantext@ccxxxiii{لِّلَّذِينَ يُؤْلُونَ مِن نِّسَآئِهِمْ تَرَبُّصُ أَرْبَعَةِ أَشْهُرٍ فَإِن فَآءُو فَإِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٢٢٦﴾}}
\qt@newcmd\qurantext@ccxxxiv{وَإِنْ عَزَمُوا۟ ٱلطَّلَٰقَ فَإِنَّ ٱللَّهَ سَمِيعٌ عَلِيمٌ\qt@no{﴿٢٢٧﴾}}
\qt@newcmd\qurantext@ccxxxv{وَٱلْمُطَلَّقَٰتُ يَتَرَبَّصْنَ بِأَنفُسِهِنَّ ثَلَٰثَةَ قُرُوٓءٍ وَلَا يَحِلُّ لَهُنَّ أَن يَكْتُمْنَ مَا خَلَقَ ٱللَّهُ فِىٓ أَرْحَامِهِنَّ إِن كُنَّ يُؤْمِنَّ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَبُعُولَتُهُنَّ أَحَقُّ بِرَدِّهِنَّ فِى ذَٰلِكَ إِنْ أَرَادُوٓا۟ إِصْلَٰحًا وَلَهُنَّ مِثْلُ ٱلَّذِى عَلَيْهِنَّ بِٱلْمَعْرُوفِ وَلِلرِّجَالِ عَلَيْهِنَّ دَرَجَةٌ وَٱللَّهُ عَزِيزٌ حَكِيمٌ\qt@no{﴿٢٢٨﴾}}
\qt@newcmd\qurantext@ccxxxvi{ٱلطَّلَٰقُ مَرَّتَانِ فَإِمْسَاكٌۢ بِمَعْرُوفٍ أَوْ تَسْرِيحٌۢ بِإِحْسَٰنٍ وَلَا يَحِلُّ لَكُمْ أَن تَأْخُذُوا۟ مِمَّآ ءَاتَيْتُمُوهُنَّ شَيْـًٔا إِلَّآ أَن يَخَافَآ أَلَّا يُقِيمَا حُدُودَ ٱللَّهِ فَإِنْ خِفْتُمْ أَلَّا يُقِيمَا حُدُودَ ٱللَّهِ فَلَا جُنَاحَ عَلَيْهِمَا فِيمَا ٱفْتَدَتْ بِهِۦ تِلْكَ حُدُودُ ٱللَّهِ فَلَا تَعْتَدُوهَا وَمَن يَتَعَدَّ حُدُودَ ٱللَّهِ فَأُو۟لَٰٓئِكَ هُمُ ٱلظَّٰلِمُونَ\qt@no{﴿٢٢٩﴾}}
\qt@newcmd\qurantext@ccxxxvii{فَإِن طَلَّقَهَا فَلَا تَحِلُّ لَهُۥ مِنۢ بَعْدُ حَتَّىٰ تَنكِحَ زَوْجًا غَيْرَهُۥ فَإِن طَلَّقَهَا فَلَا جُنَاحَ عَلَيْهِمَآ أَن يَتَرَاجَعَآ إِن ظَنَّآ أَن يُقِيمَا حُدُودَ ٱللَّهِ وَتِلْكَ حُدُودُ ٱللَّهِ يُبَيِّنُهَا لِقَوْمٍ يَعْلَمُونَ\qt@no{﴿٢٣٠﴾}}
\qt@newcmd\qurantext@ccxxxviii{وَإِذَا طَلَّقْتُمُ ٱلنِّسَآءَ فَبَلَغْنَ أَجَلَهُنَّ فَأَمْسِكُوهُنَّ بِمَعْرُوفٍ أَوْ سَرِّحُوهُنَّ بِمَعْرُوفٍ وَلَا تُمْسِكُوهُنَّ ضِرَارًا لِّتَعْتَدُوا۟ وَمَن يَفْعَلْ ذَٰلِكَ فَقَدْ ظَلَمَ نَفْسَهُۥ وَلَا تَتَّخِذُوٓا۟ ءَايَٰتِ ٱللَّهِ هُزُوًا وَٱذْكُرُوا۟ نِعْمَتَ ٱللَّهِ عَلَيْكُمْ وَمَآ أَنزَلَ عَلَيْكُم مِّنَ ٱلْكِتَٰبِ وَٱلْحِكْمَةِ يَعِظُكُم بِهِۦ وَٱتَّقُوا۟ ٱللَّهَ وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿٢٣١﴾}}
\qt@newcmd\qurantext@ccxxxix{وَإِذَا طَلَّقْتُمُ ٱلنِّسَآءَ فَبَلَغْنَ أَجَلَهُنَّ فَلَا تَعْضُلُوهُنَّ أَن يَنكِحْنَ أَزْوَٰجَهُنَّ إِذَا تَرَٰضَوْا۟ بَيْنَهُم بِٱلْمَعْرُوفِ ذَٰلِكَ يُوعَظُ بِهِۦ مَن كَانَ مِنكُمْ يُؤْمِنُ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ ذَٰلِكُمْ أَزْكَىٰ لَكُمْ وَأَطْهَرُ وَٱللَّهُ يَعْلَمُ وَأَنتُمْ لَا تَعْلَمُونَ\qt@no{﴿٢٣٢﴾}}
\qt@newcmd\qurantext@ccxl{وَٱلْوَٰلِدَٰتُ يُرْضِعْنَ أَوْلَٰدَهُنَّ حَوْلَيْنِ كَامِلَيْنِ لِمَنْ أَرَادَ أَن يُتِمَّ ٱلرَّضَاعَةَ وَعَلَى ٱلْمَوْلُودِ لَهُۥ رِزْقُهُنَّ وَكِسْوَتُهُنَّ بِٱلْمَعْرُوفِ لَا تُكَلَّفُ نَفْسٌ إِلَّا وُسْعَهَا لَا تُضَآرَّ وَٰلِدَةٌۢ بِوَلَدِهَا وَلَا مَوْلُودٌ لَّهُۥ بِوَلَدِهِۦ وَعَلَى ٱلْوَارِثِ مِثْلُ ذَٰلِكَ فَإِنْ أَرَادَا فِصَالًا عَن تَرَاضٍ مِّنْهُمَا وَتَشَاوُرٍ فَلَا جُنَاحَ عَلَيْهِمَا وَإِنْ أَرَدتُّمْ أَن تَسْتَرْضِعُوٓا۟ أَوْلَٰدَكُمْ فَلَا جُنَاحَ عَلَيْكُمْ إِذَا سَلَّمْتُم مَّآ ءَاتَيْتُم بِٱلْمَعْرُوفِ وَٱتَّقُوا۟ ٱللَّهَ وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿٢٣٣﴾}}
\qt@newcmd\qurantext@ccxli{وَٱلَّذِينَ يُتَوَفَّوْنَ مِنكُمْ وَيَذَرُونَ أَزْوَٰجًا يَتَرَبَّصْنَ بِأَنفُسِهِنَّ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا فَإِذَا بَلَغْنَ أَجَلَهُنَّ فَلَا جُنَاحَ عَلَيْكُمْ فِيمَا فَعَلْنَ فِىٓ أَنفُسِهِنَّ بِٱلْمَعْرُوفِ وَٱللَّهُ بِمَا تَعْمَلُونَ خَبِيرٌ\qt@no{﴿٢٣٤﴾}}
\qt@newcmd\qurantext@ccxlii{وَلَا جُنَاحَ عَلَيْكُمْ فِيمَا عَرَّضْتُم بِهِۦ مِنْ خِطْبَةِ ٱلنِّسَآءِ أَوْ أَكْنَنتُمْ فِىٓ أَنفُسِكُمْ عَلِمَ ٱللَّهُ أَنَّكُمْ سَتَذْكُرُونَهُنَّ وَلَٰكِن لَّا تُوَاعِدُوهُنَّ سِرًّا إِلَّآ أَن تَقُولُوا۟ قَوْلًا مَّعْرُوفًا وَلَا تَعْزِمُوا۟ عُقْدَةَ ٱلنِّكَاحِ حَتَّىٰ يَبْلُغَ ٱلْكِتَٰبُ أَجَلَهُۥ وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ يَعْلَمُ مَا فِىٓ أَنفُسِكُمْ فَٱحْذَرُوهُ وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ غَفُورٌ حَلِيمٌ\qt@no{﴿٢٣٥﴾}}
\qt@newcmd\qurantext@ccxliii{لَّا جُنَاحَ عَلَيْكُمْ إِن طَلَّقْتُمُ ٱلنِّسَآءَ مَا لَمْ تَمَسُّوهُنَّ أَوْ تَفْرِضُوا۟ لَهُنَّ فَرِيضَةً وَمَتِّعُوهُنَّ عَلَى ٱلْمُوسِعِ قَدَرُهُۥ وَعَلَى ٱلْمُقْتِرِ قَدَرُهُۥ مَتَٰعًۢا بِٱلْمَعْرُوفِ حَقًّا عَلَى ٱلْمُحْسِنِينَ\qt@no{﴿٢٣٦﴾}}
\qt@newcmd\qurantext@ccxliv{وَإِن طَلَّقْتُمُوهُنَّ مِن قَبْلِ أَن تَمَسُّوهُنَّ وَقَدْ فَرَضْتُمْ لَهُنَّ فَرِيضَةً فَنِصْفُ مَا فَرَضْتُمْ إِلَّآ أَن يَعْفُونَ أَوْ يَعْفُوَا۟ ٱلَّذِى بِيَدِهِۦ عُقْدَةُ ٱلنِّكَاحِ وَأَن تَعْفُوٓا۟ أَقْرَبُ لِلتَّقْوَىٰ وَلَا تَنسَوُا۟ ٱلْفَضْلَ بَيْنَكُمْ إِنَّ ٱللَّهَ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿٢٣٧﴾}}
\qt@newcmd\qurantext@ccxlv{حَٰفِظُوا۟ عَلَى ٱلصَّلَوَٰتِ وَٱلصَّلَوٰةِ ٱلْوُسْطَىٰ وَقُومُوا۟ لِلَّهِ قَٰنِتِينَ\qt@no{﴿٢٣٨﴾}}
\qt@newcmd\qurantext@ccxlvi{فَإِنْ خِفْتُمْ فَرِجَالًا أَوْ رُكْبَانًا فَإِذَآ أَمِنتُمْ فَٱذْكُرُوا۟ ٱللَّهَ كَمَا عَلَّمَكُم مَّا لَمْ تَكُونُوا۟ تَعْلَمُونَ\qt@no{﴿٢٣٩﴾}}
\qt@newcmd\qurantext@ccxlvii{وَٱلَّذِينَ يُتَوَفَّوْنَ مِنكُمْ وَيَذَرُونَ أَزْوَٰجًا وَصِيَّةً لِّأَزْوَٰجِهِم مَّتَٰعًا إِلَى ٱلْحَوْلِ غَيْرَ إِخْرَاجٍ فَإِنْ خَرَجْنَ فَلَا جُنَاحَ عَلَيْكُمْ فِى مَا فَعَلْنَ فِىٓ أَنفُسِهِنَّ مِن مَّعْرُوفٍ وَٱللَّهُ عَزِيزٌ حَكِيمٌ\qt@no{﴿٢٤٠﴾}}
\qt@newcmd\qurantext@ccxlviii{وَلِلْمُطَلَّقَٰتِ مَتَٰعٌۢ بِٱلْمَعْرُوفِ حَقًّا عَلَى ٱلْمُتَّقِينَ\qt@no{﴿٢٤١﴾}}
\qt@newcmd\qurantext@ccxlix{كَذَٰلِكَ يُبَيِّنُ ٱللَّهُ لَكُمْ ءَايَٰتِهِۦ لَعَلَّكُمْ تَعْقِلُونَ\qt@no{﴿٢٤٢﴾}}
\qt@newcmd\qurantext@ccl{أَلَمْ تَرَ إِلَى ٱلَّذِينَ خَرَجُوا۟ مِن دِيَٰرِهِمْ وَهُمْ أُلُوفٌ حَذَرَ ٱلْمَوْتِ فَقَالَ لَهُمُ ٱللَّهُ مُوتُوا۟ ثُمَّ أَحْيَٰهُمْ إِنَّ ٱللَّهَ لَذُو فَضْلٍ عَلَى ٱلنَّاسِ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَشْكُرُونَ\qt@no{﴿٢٤٣﴾}}
\qt@newcmd\qurantext@ccli{وَقَٰتِلُوا۟ فِى سَبِيلِ ٱللَّهِ وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ سَمِيعٌ عَلِيمٌ\qt@no{﴿٢٤٤﴾}}
\qt@newcmd\qurantext@cclii{مَّن ذَا ٱلَّذِى يُقْرِضُ ٱللَّهَ قَرْضًا حَسَنًا فَيُضَٰعِفَهُۥ لَهُۥٓ أَضْعَافًا كَثِيرَةً وَٱللَّهُ يَقْبِضُ وَيَبْصُۜطُ وَإِلَيْهِ تُرْجَعُونَ\qt@no{﴿٢٤٥﴾}}
\qt@newcmd\qurantext@ccliii{أَلَمْ تَرَ إِلَى ٱلْمَلَإِ مِنۢ بَنِىٓ إِسْرَٰٓءِيلَ مِنۢ بَعْدِ مُوسَىٰٓ إِذْ قَالُوا۟ لِنَبِىٍّ لَّهُمُ ٱبْعَثْ لَنَا مَلِكًا نُّقَٰتِلْ فِى سَبِيلِ ٱللَّهِ قَالَ هَلْ عَسَيْتُمْ إِن كُتِبَ عَلَيْكُمُ ٱلْقِتَالُ أَلَّا تُقَٰتِلُوا۟ قَالُوا۟ وَمَا لَنَآ أَلَّا نُقَٰتِلَ فِى سَبِيلِ ٱللَّهِ وَقَدْ أُخْرِجْنَا مِن دِيَٰرِنَا وَأَبْنَآئِنَا فَلَمَّا كُتِبَ عَلَيْهِمُ ٱلْقِتَالُ تَوَلَّوْا۟ إِلَّا قَلِيلًا مِّنْهُمْ وَٱللَّهُ عَلِيمٌۢ بِٱلظَّٰلِمِينَ\qt@no{﴿٢٤٦﴾}}
\qt@newcmd\qurantext@ccliv{وَقَالَ لَهُمْ نَبِيُّهُمْ إِنَّ ٱللَّهَ قَدْ بَعَثَ لَكُمْ طَالُوتَ مَلِكًا قَالُوٓا۟ أَنَّىٰ يَكُونُ لَهُ ٱلْمُلْكُ عَلَيْنَا وَنَحْنُ أَحَقُّ بِٱلْمُلْكِ مِنْهُ وَلَمْ يُؤْتَ سَعَةً مِّنَ ٱلْمَالِ قَالَ إِنَّ ٱللَّهَ ٱصْطَفَىٰهُ عَلَيْكُمْ وَزَادَهُۥ بَسْطَةً فِى ٱلْعِلْمِ وَٱلْجِسْمِ وَٱللَّهُ يُؤْتِى مُلْكَهُۥ مَن يَشَآءُ وَٱللَّهُ وَٰسِعٌ عَلِيمٌ\qt@no{﴿٢٤٧﴾}}
\qt@newcmd\qurantext@cclv{وَقَالَ لَهُمْ نَبِيُّهُمْ إِنَّ ءَايَةَ مُلْكِهِۦٓ أَن يَأْتِيَكُمُ ٱلتَّابُوتُ فِيهِ سَكِينَةٌ مِّن رَّبِّكُمْ وَبَقِيَّةٌ مِّمَّا تَرَكَ ءَالُ مُوسَىٰ وَءَالُ هَٰرُونَ تَحْمِلُهُ ٱلْمَلَٰٓئِكَةُ إِنَّ فِى ذَٰلِكَ لَءَايَةً لَّكُمْ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿٢٤٨﴾}}
\qt@newcmd\qurantext@cclvi{فَلَمَّا فَصَلَ طَالُوتُ بِٱلْجُنُودِ قَالَ إِنَّ ٱللَّهَ مُبْتَلِيكُم بِنَهَرٍ فَمَن شَرِبَ مِنْهُ فَلَيْسَ مِنِّى وَمَن لَّمْ يَطْعَمْهُ فَإِنَّهُۥ مِنِّىٓ إِلَّا مَنِ ٱغْتَرَفَ غُرْفَةًۢ بِيَدِهِۦ فَشَرِبُوا۟ مِنْهُ إِلَّا قَلِيلًا مِّنْهُمْ فَلَمَّا جَاوَزَهُۥ هُوَ وَٱلَّذِينَ ءَامَنُوا۟ مَعَهُۥ قَالُوا۟ لَا طَاقَةَ لَنَا ٱلْيَوْمَ بِجَالُوتَ وَجُنُودِهِۦ قَالَ ٱلَّذِينَ يَظُنُّونَ أَنَّهُم مُّلَٰقُوا۟ ٱللَّهِ كَم مِّن فِئَةٍ قَلِيلَةٍ غَلَبَتْ فِئَةً كَثِيرَةًۢ بِإِذْنِ ٱللَّهِ وَٱللَّهُ مَعَ ٱلصَّٰبِرِينَ\qt@no{﴿٢٤٩﴾}}
\qt@newcmd\qurantext@cclvii{وَلَمَّا بَرَزُوا۟ لِجَالُوتَ وَجُنُودِهِۦ قَالُوا۟ رَبَّنَآ أَفْرِغْ عَلَيْنَا صَبْرًا وَثَبِّتْ أَقْدَامَنَا وَٱنصُرْنَا عَلَى ٱلْقَوْمِ ٱلْكَٰفِرِينَ\qt@no{﴿٢٥٠﴾}}
\qt@newcmd\qurantext@cclviii{فَهَزَمُوهُم بِإِذْنِ ٱللَّهِ وَقَتَلَ دَاوُۥدُ جَالُوتَ وَءَاتَىٰهُ ٱللَّهُ ٱلْمُلْكَ وَٱلْحِكْمَةَ وَعَلَّمَهُۥ مِمَّا يَشَآءُ وَلَوْلَا دَفْعُ ٱللَّهِ ٱلنَّاسَ بَعْضَهُم بِبَعْضٍ لَّفَسَدَتِ ٱلْأَرْضُ وَلَٰكِنَّ ٱللَّهَ ذُو فَضْلٍ عَلَى ٱلْعَٰلَمِينَ\qt@no{﴿٢٥١﴾}}
\qt@newcmd\qurantext@cclix{تِلْكَ ءَايَٰتُ ٱللَّهِ نَتْلُوهَا عَلَيْكَ بِٱلْحَقِّ وَإِنَّكَ لَمِنَ ٱلْمُرْسَلِينَ\qt@no{﴿٢٥٢﴾}}
\qt@newcmd\qurantext@cclx{تِلْكَ ٱلرُّسُلُ فَضَّلْنَا بَعْضَهُمْ عَلَىٰ بَعْضٍ مِّنْهُم مَّن كَلَّمَ ٱللَّهُ وَرَفَعَ بَعْضَهُمْ دَرَجَٰتٍ وَءَاتَيْنَا عِيسَى ٱبْنَ مَرْيَمَ ٱلْبَيِّنَٰتِ وَأَيَّدْنَٰهُ بِرُوحِ ٱلْقُدُسِ وَلَوْ شَآءَ ٱللَّهُ مَا ٱقْتَتَلَ ٱلَّذِينَ مِنۢ بَعْدِهِم مِّنۢ بَعْدِ مَا جَآءَتْهُمُ ٱلْبَيِّنَٰتُ وَلَٰكِنِ ٱخْتَلَفُوا۟ فَمِنْهُم مَّنْ ءَامَنَ وَمِنْهُم مَّن كَفَرَ وَلَوْ شَآءَ ٱللَّهُ مَا ٱقْتَتَلُوا۟ وَلَٰكِنَّ ٱللَّهَ يَفْعَلُ مَا يُرِيدُ\qt@no{﴿٢٥٣﴾}}
\qt@newcmd\qurantext@cclxi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ أَنفِقُوا۟ مِمَّا رَزَقْنَٰكُم مِّن قَبْلِ أَن يَأْتِىَ يَوْمٌ لَّا بَيْعٌ فِيهِ وَلَا خُلَّةٌ وَلَا شَفَٰعَةٌ وَٱلْكَٰفِرُونَ هُمُ ٱلظَّٰلِمُونَ\qt@no{﴿٢٥٤﴾}}
\qt@newcmd\qurantext@cclxii{ٱللَّهُ لَآ إِلَٰهَ إِلَّا هُوَ ٱلْحَىُّ ٱلْقَيُّومُ لَا تَأْخُذُهُۥ سِنَةٌ وَلَا نَوْمٌ لَّهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ مَن ذَا ٱلَّذِى يَشْفَعُ عِندَهُۥٓ إِلَّا بِإِذْنِهِۦ يَعْلَمُ مَا بَيْنَ أَيْدِيهِمْ وَمَا خَلْفَهُمْ وَلَا يُحِيطُونَ بِشَىْءٍ مِّنْ عِلْمِهِۦٓ إِلَّا بِمَا شَآءَ وَسِعَ كُرْسِيُّهُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَلَا يَـُٔودُهُۥ حِفْظُهُمَا وَهُوَ ٱلْعَلِىُّ ٱلْعَظِيمُ\qt@no{﴿٢٥٥﴾}}
\qt@newcmd\qurantext@cclxiii{لَآ إِكْرَاهَ فِى ٱلدِّينِ قَد تَّبَيَّنَ ٱلرُّشْدُ مِنَ ٱلْغَىِّ فَمَن يَكْفُرْ بِٱلطَّٰغُوتِ وَيُؤْمِنۢ بِٱللَّهِ فَقَدِ ٱسْتَمْسَكَ بِٱلْعُرْوَةِ ٱلْوُثْقَىٰ لَا ٱنفِصَامَ لَهَا وَٱللَّهُ سَمِيعٌ عَلِيمٌ\qt@no{﴿٢٥٦﴾}}
\qt@newcmd\qurantext@cclxiv{ٱللَّهُ وَلِىُّ ٱلَّذِينَ ءَامَنُوا۟ يُخْرِجُهُم مِّنَ ٱلظُّلُمَٰتِ إِلَى ٱلنُّورِ وَٱلَّذِينَ كَفَرُوٓا۟ أَوْلِيَآؤُهُمُ ٱلطَّٰغُوتُ يُخْرِجُونَهُم مِّنَ ٱلنُّورِ إِلَى ٱلظُّلُمَٰتِ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٢٥٧﴾}}
\qt@newcmd\qurantext@cclxv{أَلَمْ تَرَ إِلَى ٱلَّذِى حَآجَّ إِبْرَٰهِۦمَ فِى رَبِّهِۦٓ أَنْ ءَاتَىٰهُ ٱللَّهُ ٱلْمُلْكَ إِذْ قَالَ إِبْرَٰهِۦمُ رَبِّىَ ٱلَّذِى يُحْىِۦ وَيُمِيتُ قَالَ أَنَا۠ أُحْىِۦ وَأُمِيتُ قَالَ إِبْرَٰهِۦمُ فَإِنَّ ٱللَّهَ يَأْتِى بِٱلشَّمْسِ مِنَ ٱلْمَشْرِقِ فَأْتِ بِهَا مِنَ ٱلْمَغْرِبِ فَبُهِتَ ٱلَّذِى كَفَرَ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿٢٥٨﴾}}
\qt@newcmd\qurantext@cclxvi{أَوْ كَٱلَّذِى مَرَّ عَلَىٰ قَرْيَةٍ وَهِىَ خَاوِيَةٌ عَلَىٰ عُرُوشِهَا قَالَ أَنَّىٰ يُحْىِۦ هَٰذِهِ ٱللَّهُ بَعْدَ مَوْتِهَا فَأَمَاتَهُ ٱللَّهُ مِا۟ئَةَ عَامٍ ثُمَّ بَعَثَهُۥ قَالَ كَمْ لَبِثْتَ قَالَ لَبِثْتُ يَوْمًا أَوْ بَعْضَ يَوْمٍ قَالَ بَل لَّبِثْتَ مِا۟ئَةَ عَامٍ فَٱنظُرْ إِلَىٰ طَعَامِكَ وَشَرَابِكَ لَمْ يَتَسَنَّهْ وَٱنظُرْ إِلَىٰ حِمَارِكَ وَلِنَجْعَلَكَ ءَايَةً لِّلنَّاسِ وَٱنظُرْ إِلَى ٱلْعِظَامِ كَيْفَ نُنشِزُهَا ثُمَّ نَكْسُوهَا لَحْمًا فَلَمَّا تَبَيَّنَ لَهُۥ قَالَ أَعْلَمُ أَنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٢٥٩﴾}}
\qt@newcmd\qurantext@cclxvii{وَإِذْ قَالَ إِبْرَٰهِۦمُ رَبِّ أَرِنِى كَيْفَ تُحْىِ ٱلْمَوْتَىٰ قَالَ أَوَلَمْ تُؤْمِن قَالَ بَلَىٰ وَلَٰكِن لِّيَطْمَئِنَّ قَلْبِى قَالَ فَخُذْ أَرْبَعَةً مِّنَ ٱلطَّيْرِ فَصُرْهُنَّ إِلَيْكَ ثُمَّ ٱجْعَلْ عَلَىٰ كُلِّ جَبَلٍ مِّنْهُنَّ جُزْءًا ثُمَّ ٱدْعُهُنَّ يَأْتِينَكَ سَعْيًا وَٱعْلَمْ أَنَّ ٱللَّهَ عَزِيزٌ حَكِيمٌ\qt@no{﴿٢٦٠﴾}}
\qt@newcmd\qurantext@cclxviii{مَّثَلُ ٱلَّذِينَ يُنفِقُونَ أَمْوَٰلَهُمْ فِى سَبِيلِ ٱللَّهِ كَمَثَلِ حَبَّةٍ أَنۢبَتَتْ سَبْعَ سَنَابِلَ فِى كُلِّ سُنۢبُلَةٍ مِّا۟ئَةُ حَبَّةٍ وَٱللَّهُ يُضَٰعِفُ لِمَن يَشَآءُ وَٱللَّهُ وَٰسِعٌ عَلِيمٌ\qt@no{﴿٢٦١﴾}}
\qt@newcmd\qurantext@cclxix{ٱلَّذِينَ يُنفِقُونَ أَمْوَٰلَهُمْ فِى سَبِيلِ ٱللَّهِ ثُمَّ لَا يُتْبِعُونَ مَآ أَنفَقُوا۟ مَنًّا وَلَآ أَذًى لَّهُمْ أَجْرُهُمْ عِندَ رَبِّهِمْ وَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٢٦٢﴾}}
\qt@newcmd\qurantext@cclxx{قَوْلٌ مَّعْرُوفٌ وَمَغْفِرَةٌ خَيْرٌ مِّن صَدَقَةٍ يَتْبَعُهَآ أَذًى وَٱللَّهُ غَنِىٌّ حَلِيمٌ\qt@no{﴿٢٦٣﴾}}
\qt@newcmd\qurantext@cclxxi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تُبْطِلُوا۟ صَدَقَٰتِكُم بِٱلْمَنِّ وَٱلْأَذَىٰ كَٱلَّذِى يُنفِقُ مَالَهُۥ رِئَآءَ ٱلنَّاسِ وَلَا يُؤْمِنُ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ فَمَثَلُهُۥ كَمَثَلِ صَفْوَانٍ عَلَيْهِ تُرَابٌ فَأَصَابَهُۥ وَابِلٌ فَتَرَكَهُۥ صَلْدًا لَّا يَقْدِرُونَ عَلَىٰ شَىْءٍ مِّمَّا كَسَبُوا۟ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلْكَٰفِرِينَ\qt@no{﴿٢٦٤﴾}}
\qt@newcmd\qurantext@cclxxii{وَمَثَلُ ٱلَّذِينَ يُنفِقُونَ أَمْوَٰلَهُمُ ٱبْتِغَآءَ مَرْضَاتِ ٱللَّهِ وَتَثْبِيتًا مِّنْ أَنفُسِهِمْ كَمَثَلِ جَنَّةٍۭ بِرَبْوَةٍ أَصَابَهَا وَابِلٌ فَـَٔاتَتْ أُكُلَهَا ضِعْفَيْنِ فَإِن لَّمْ يُصِبْهَا وَابِلٌ فَطَلٌّ وَٱللَّهُ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿٢٦٥﴾}}
\qt@newcmd\qurantext@cclxxiii{أَيَوَدُّ أَحَدُكُمْ أَن تَكُونَ لَهُۥ جَنَّةٌ مِّن نَّخِيلٍ وَأَعْنَابٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ لَهُۥ فِيهَا مِن كُلِّ ٱلثَّمَرَٰتِ وَأَصَابَهُ ٱلْكِبَرُ وَلَهُۥ ذُرِّيَّةٌ ضُعَفَآءُ فَأَصَابَهَآ إِعْصَارٌ فِيهِ نَارٌ فَٱحْتَرَقَتْ كَذَٰلِكَ يُبَيِّنُ ٱللَّهُ لَكُمُ ٱلْءَايَٰتِ لَعَلَّكُمْ تَتَفَكَّرُونَ\qt@no{﴿٢٦٦﴾}}
\qt@newcmd\qurantext@cclxxiv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ أَنفِقُوا۟ مِن طَيِّبَٰتِ مَا كَسَبْتُمْ وَمِمَّآ أَخْرَجْنَا لَكُم مِّنَ ٱلْأَرْضِ وَلَا تَيَمَّمُوا۟ ٱلْخَبِيثَ مِنْهُ تُنفِقُونَ وَلَسْتُم بِـَٔاخِذِيهِ إِلَّآ أَن تُغْمِضُوا۟ فِيهِ وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ غَنِىٌّ حَمِيدٌ\qt@no{﴿٢٦٧﴾}}
\qt@newcmd\qurantext@cclxxv{ٱلشَّيْطَٰنُ يَعِدُكُمُ ٱلْفَقْرَ وَيَأْمُرُكُم بِٱلْفَحْشَآءِ وَٱللَّهُ يَعِدُكُم مَّغْفِرَةً مِّنْهُ وَفَضْلًا وَٱللَّهُ وَٰسِعٌ عَلِيمٌ\qt@no{﴿٢٦٨﴾}}
\qt@newcmd\qurantext@cclxxvi{يُؤْتِى ٱلْحِكْمَةَ مَن يَشَآءُ وَمَن يُؤْتَ ٱلْحِكْمَةَ فَقَدْ أُوتِىَ خَيْرًا كَثِيرًا وَمَا يَذَّكَّرُ إِلَّآ أُو۟لُوا۟ ٱلْأَلْبَٰبِ\qt@no{﴿٢٦٩﴾}}
\qt@newcmd\qurantext@cclxxvii{وَمَآ أَنفَقْتُم مِّن نَّفَقَةٍ أَوْ نَذَرْتُم مِّن نَّذْرٍ فَإِنَّ ٱللَّهَ يَعْلَمُهُۥ وَمَا لِلظَّٰلِمِينَ مِنْ أَنصَارٍ\qt@no{﴿٢٧٠﴾}}
\qt@newcmd\qurantext@cclxxviii{إِن تُبْدُوا۟ ٱلصَّدَقَٰتِ فَنِعِمَّا هِىَ وَإِن تُخْفُوهَا وَتُؤْتُوهَا ٱلْفُقَرَآءَ فَهُوَ خَيْرٌ لَّكُمْ وَيُكَفِّرُ عَنكُم مِّن سَيِّـَٔاتِكُمْ وَٱللَّهُ بِمَا تَعْمَلُونَ خَبِيرٌ\qt@no{﴿٢٧١﴾}}
\qt@newcmd\qurantext@cclxxix{لَّيْسَ عَلَيْكَ هُدَىٰهُمْ وَلَٰكِنَّ ٱللَّهَ يَهْدِى مَن يَشَآءُ وَمَا تُنفِقُوا۟ مِنْ خَيْرٍ فَلِأَنفُسِكُمْ وَمَا تُنفِقُونَ إِلَّا ٱبْتِغَآءَ وَجْهِ ٱللَّهِ وَمَا تُنفِقُوا۟ مِنْ خَيْرٍ يُوَفَّ إِلَيْكُمْ وَأَنتُمْ لَا تُظْلَمُونَ\qt@no{﴿٢٧٢﴾}}
\qt@newcmd\qurantext@cclxxx{لِلْفُقَرَآءِ ٱلَّذِينَ أُحْصِرُوا۟ فِى سَبِيلِ ٱللَّهِ لَا يَسْتَطِيعُونَ ضَرْبًا فِى ٱلْأَرْضِ يَحْسَبُهُمُ ٱلْجَاهِلُ أَغْنِيَآءَ مِنَ ٱلتَّعَفُّفِ تَعْرِفُهُم بِسِيمَٰهُمْ لَا يَسْـَٔلُونَ ٱلنَّاسَ إِلْحَافًا وَمَا تُنفِقُوا۟ مِنْ خَيْرٍ فَإِنَّ ٱللَّهَ بِهِۦ عَلِيمٌ\qt@no{﴿٢٧٣﴾}}
\qt@newcmd\qurantext@cclxxxi{ٱلَّذِينَ يُنفِقُونَ أَمْوَٰلَهُم بِٱلَّيْلِ وَٱلنَّهَارِ سِرًّا وَعَلَانِيَةً فَلَهُمْ أَجْرُهُمْ عِندَ رَبِّهِمْ وَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٢٧٤﴾}}
\qt@newcmd\qurantext@cclxxxii{ٱلَّذِينَ يَأْكُلُونَ ٱلرِّبَوٰا۟ لَا يَقُومُونَ إِلَّا كَمَا يَقُومُ ٱلَّذِى يَتَخَبَّطُهُ ٱلشَّيْطَٰنُ مِنَ ٱلْمَسِّ ذَٰلِكَ بِأَنَّهُمْ قَالُوٓا۟ إِنَّمَا ٱلْبَيْعُ مِثْلُ ٱلرِّبَوٰا۟ وَأَحَلَّ ٱللَّهُ ٱلْبَيْعَ وَحَرَّمَ ٱلرِّبَوٰا۟ فَمَن جَآءَهُۥ مَوْعِظَةٌ مِّن رَّبِّهِۦ فَٱنتَهَىٰ فَلَهُۥ مَا سَلَفَ وَأَمْرُهُۥٓ إِلَى ٱللَّهِ وَمَنْ عَادَ فَأُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٢٧٥﴾}}
\qt@newcmd\qurantext@cclxxxiii{يَمْحَقُ ٱللَّهُ ٱلرِّبَوٰا۟ وَيُرْبِى ٱلصَّدَقَٰتِ وَٱللَّهُ لَا يُحِبُّ كُلَّ كَفَّارٍ أَثِيمٍ\qt@no{﴿٢٧٦﴾}}
\qt@newcmd\qurantext@cclxxxiv{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ وَأَقَامُوا۟ ٱلصَّلَوٰةَ وَءَاتَوُا۟ ٱلزَّكَوٰةَ لَهُمْ أَجْرُهُمْ عِندَ رَبِّهِمْ وَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٢٧٧﴾}}
\qt@newcmd\qurantext@cclxxxv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱتَّقُوا۟ ٱللَّهَ وَذَرُوا۟ مَا بَقِىَ مِنَ ٱلرِّبَوٰٓا۟ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿٢٧٨﴾}}
\qt@newcmd\qurantext@cclxxxvi{فَإِن لَّمْ تَفْعَلُوا۟ فَأْذَنُوا۟ بِحَرْبٍ مِّنَ ٱللَّهِ وَرَسُولِهِۦ وَإِن تُبْتُمْ فَلَكُمْ رُءُوسُ أَمْوَٰلِكُمْ لَا تَظْلِمُونَ وَلَا تُظْلَمُونَ\qt@no{﴿٢٧٩﴾}}
\qt@newcmd\qurantext@cclxxxvii{وَإِن كَانَ ذُو عُسْرَةٍ فَنَظِرَةٌ إِلَىٰ مَيْسَرَةٍ وَأَن تَصَدَّقُوا۟ خَيْرٌ لَّكُمْ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿٢٨٠﴾}}
\qt@newcmd\qurantext@cclxxxviii{وَٱتَّقُوا۟ يَوْمًا تُرْجَعُونَ فِيهِ إِلَى ٱللَّهِ ثُمَّ تُوَفَّىٰ كُلُّ نَفْسٍ مَّا كَسَبَتْ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿٢٨١﴾}}
\qt@newcmd\qurantext@cclxxxix{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا تَدَايَنتُم بِدَيْنٍ إِلَىٰٓ أَجَلٍ مُّسَمًّى فَٱكْتُبُوهُ وَلْيَكْتُب بَّيْنَكُمْ كَاتِبٌۢ بِٱلْعَدْلِ وَلَا يَأْبَ كَاتِبٌ أَن يَكْتُبَ كَمَا عَلَّمَهُ ٱللَّهُ فَلْيَكْتُبْ وَلْيُمْلِلِ ٱلَّذِى عَلَيْهِ ٱلْحَقُّ وَلْيَتَّقِ ٱللَّهَ رَبَّهُۥ وَلَا يَبْخَسْ مِنْهُ شَيْـًٔا فَإِن كَانَ ٱلَّذِى عَلَيْهِ ٱلْحَقُّ سَفِيهًا أَوْ ضَعِيفًا أَوْ لَا يَسْتَطِيعُ أَن يُمِلَّ هُوَ فَلْيُمْلِلْ وَلِيُّهُۥ بِٱلْعَدْلِ وَٱسْتَشْهِدُوا۟ شَهِيدَيْنِ مِن رِّجَالِكُمْ فَإِن لَّمْ يَكُونَا رَجُلَيْنِ فَرَجُلٌ وَٱمْرَأَتَانِ مِمَّن تَرْضَوْنَ مِنَ ٱلشُّهَدَآءِ أَن تَضِلَّ إِحْدَىٰهُمَا فَتُذَكِّرَ إِحْدَىٰهُمَا ٱلْأُخْرَىٰ وَلَا يَأْبَ ٱلشُّهَدَآءُ إِذَا مَا دُعُوا۟ وَلَا تَسْـَٔمُوٓا۟ أَن تَكْتُبُوهُ صَغِيرًا أَوْ كَبِيرًا إِلَىٰٓ أَجَلِهِۦ ذَٰلِكُمْ أَقْسَطُ عِندَ ٱللَّهِ وَأَقْوَمُ لِلشَّهَٰدَةِ وَأَدْنَىٰٓ أَلَّا تَرْتَابُوٓا۟ إِلَّآ أَن تَكُونَ تِجَٰرَةً حَاضِرَةً تُدِيرُونَهَا بَيْنَكُمْ فَلَيْسَ عَلَيْكُمْ جُنَاحٌ أَلَّا تَكْتُبُوهَا وَأَشْهِدُوٓا۟ إِذَا تَبَايَعْتُمْ وَلَا يُضَآرَّ كَاتِبٌ وَلَا شَهِيدٌ وَإِن تَفْعَلُوا۟ فَإِنَّهُۥ فُسُوقٌۢ بِكُمْ وَٱتَّقُوا۟ ٱللَّهَ وَيُعَلِّمُكُمُ ٱللَّهُ وَٱللَّهُ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿٢٨٢﴾}}
\qt@newcmd\qurantext@ccxc{وَإِن كُنتُمْ عَلَىٰ سَفَرٍ وَلَمْ تَجِدُوا۟ كَاتِبًا فَرِهَٰنٌ مَّقْبُوضَةٌ فَإِنْ أَمِنَ بَعْضُكُم بَعْضًا فَلْيُؤَدِّ ٱلَّذِى ٱؤْتُمِنَ أَمَٰنَتَهُۥ وَلْيَتَّقِ ٱللَّهَ رَبَّهُۥ وَلَا تَكْتُمُوا۟ ٱلشَّهَٰدَةَ وَمَن يَكْتُمْهَا فَإِنَّهُۥٓ ءَاثِمٌ قَلْبُهُۥ وَٱللَّهُ بِمَا تَعْمَلُونَ عَلِيمٌ\qt@no{﴿٢٨٣﴾}}
\qt@newcmd\qurantext@ccxci{لِّلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَإِن تُبْدُوا۟ مَا فِىٓ أَنفُسِكُمْ أَوْ تُخْفُوهُ يُحَاسِبْكُم بِهِ ٱللَّهُ فَيَغْفِرُ لِمَن يَشَآءُ وَيُعَذِّبُ مَن يَشَآءُ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٢٨٤﴾}}
\qt@newcmd\qurantext@ccxcii{ءَامَنَ ٱلرَّسُولُ بِمَآ أُنزِلَ إِلَيْهِ مِن رَّبِّهِۦ وَٱلْمُؤْمِنُونَ كُلٌّ ءَامَنَ بِٱللَّهِ وَمَلَٰٓئِكَتِهِۦ وَكُتُبِهِۦ وَرُسُلِهِۦ لَا نُفَرِّقُ بَيْنَ أَحَدٍ مِّن رُّسُلِهِۦ وَقَالُوا۟ سَمِعْنَا وَأَطَعْنَا غُفْرَانَكَ رَبَّنَا وَإِلَيْكَ ٱلْمَصِيرُ\qt@no{﴿٢٨٥﴾}}
\qt@newcmd\qurantext@ccxciii{لَا يُكَلِّفُ ٱللَّهُ نَفْسًا إِلَّا وُسْعَهَا لَهَا مَا كَسَبَتْ وَعَلَيْهَا مَا ٱكْتَسَبَتْ رَبَّنَا لَا تُؤَاخِذْنَآ إِن نَّسِينَآ أَوْ أَخْطَأْنَا رَبَّنَا وَلَا تَحْمِلْ عَلَيْنَآ إِصْرًا كَمَا حَمَلْتَهُۥ عَلَى ٱلَّذِينَ مِن قَبْلِنَا رَبَّنَا وَلَا تُحَمِّلْنَا مَا لَا طَاقَةَ لَنَا بِهِۦ وَٱعْفُ عَنَّا وَٱغْفِرْ لَنَا وَٱرْحَمْنَآ أَنتَ مَوْلَىٰنَا فَٱنصُرْنَا عَلَى ٱلْقَوْمِ ٱلْكَٰفِرِينَ\qt@no{﴿٢٨٦﴾}}
\qt@newcmd\qurantext@ccxciv{\basmalah الٓمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@ccxcv{ٱللَّهُ لَآ إِلَٰهَ إِلَّا هُوَ ٱلْحَىُّ ٱلْقَيُّومُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@ccxcvi{نَزَّلَ عَلَيْكَ ٱلْكِتَٰبَ بِٱلْحَقِّ مُصَدِّقًا لِّمَا بَيْنَ يَدَيْهِ وَأَنزَلَ ٱلتَّوْرَىٰةَ وَٱلْإِنجِيلَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@ccxcvii{مِن قَبْلُ هُدًى لِّلنَّاسِ وَأَنزَلَ ٱلْفُرْقَانَ إِنَّ ٱلَّذِينَ كَفَرُوا۟ بِـَٔايَٰتِ ٱللَّهِ لَهُمْ عَذَابٌ شَدِيدٌ وَٱللَّهُ عَزِيزٌ ذُو ٱنتِقَامٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@ccxcviii{إِنَّ ٱللَّهَ لَا يَخْفَىٰ عَلَيْهِ شَىْءٌ فِى ٱلْأَرْضِ وَلَا فِى ٱلسَّمَآءِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@ccxcix{هُوَ ٱلَّذِى يُصَوِّرُكُمْ فِى ٱلْأَرْحَامِ كَيْفَ يَشَآءُ لَآ إِلَٰهَ إِلَّا هُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@ccc{هُوَ ٱلَّذِىٓ أَنزَلَ عَلَيْكَ ٱلْكِتَٰبَ مِنْهُ ءَايَٰتٌ مُّحْكَمَٰتٌ هُنَّ أُمُّ ٱلْكِتَٰبِ وَأُخَرُ مُتَشَٰبِهَٰتٌ فَأَمَّا ٱلَّذِينَ فِى قُلُوبِهِمْ زَيْغٌ فَيَتَّبِعُونَ مَا تَشَٰبَهَ مِنْهُ ٱبْتِغَآءَ ٱلْفِتْنَةِ وَٱبْتِغَآءَ تَأْوِيلِهِۦ وَمَا يَعْلَمُ تَأْوِيلَهُۥٓ إِلَّا ٱللَّهُ وَٱلرَّٰسِخُونَ فِى ٱلْعِلْمِ يَقُولُونَ ءَامَنَّا بِهِۦ كُلٌّ مِّنْ عِندِ رَبِّنَا وَمَا يَذَّكَّرُ إِلَّآ أُو۟لُوا۟ ٱلْأَلْبَٰبِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@ccci{رَبَّنَا لَا تُزِغْ قُلُوبَنَا بَعْدَ إِذْ هَدَيْتَنَا وَهَبْ لَنَا مِن لَّدُنكَ رَحْمَةً إِنَّكَ أَنتَ ٱلْوَهَّابُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@cccii{رَبَّنَآ إِنَّكَ جَامِعُ ٱلنَّاسِ لِيَوْمٍ لَّا رَيْبَ فِيهِ إِنَّ ٱللَّهَ لَا يُخْلِفُ ٱلْمِيعَادَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@ccciii{إِنَّ ٱلَّذِينَ كَفَرُوا۟ لَن تُغْنِىَ عَنْهُمْ أَمْوَٰلُهُمْ وَلَآ أَوْلَٰدُهُم مِّنَ ٱللَّهِ شَيْـًٔا وَأُو۟لَٰٓئِكَ هُمْ وَقُودُ ٱلنَّارِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@ccciv{كَدَأْبِ ءَالِ فِرْعَوْنَ وَٱلَّذِينَ مِن قَبْلِهِمْ كَذَّبُوا۟ بِـَٔايَٰتِنَا فَأَخَذَهُمُ ٱللَّهُ بِذُنُوبِهِمْ وَٱللَّهُ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@cccv{قُل لِّلَّذِينَ كَفَرُوا۟ سَتُغْلَبُونَ وَتُحْشَرُونَ إِلَىٰ جَهَنَّمَ وَبِئْسَ ٱلْمِهَادُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@cccvi{قَدْ كَانَ لَكُمْ ءَايَةٌ فِى فِئَتَيْنِ ٱلْتَقَتَا فِئَةٌ تُقَٰتِلُ فِى سَبِيلِ ٱللَّهِ وَأُخْرَىٰ كَافِرَةٌ يَرَوْنَهُم مِّثْلَيْهِمْ رَأْىَ ٱلْعَيْنِ وَٱللَّهُ يُؤَيِّدُ بِنَصْرِهِۦ مَن يَشَآءُ إِنَّ فِى ذَٰلِكَ لَعِبْرَةً لِّأُو۟لِى ٱلْأَبْصَٰرِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@cccvii{زُيِّنَ لِلنَّاسِ حُبُّ ٱلشَّهَوَٰتِ مِنَ ٱلنِّسَآءِ وَٱلْبَنِينَ وَٱلْقَنَٰطِيرِ ٱلْمُقَنطَرَةِ مِنَ ٱلذَّهَبِ وَٱلْفِضَّةِ وَٱلْخَيْلِ ٱلْمُسَوَّمَةِ وَٱلْأَنْعَٰمِ وَٱلْحَرْثِ ذَٰلِكَ مَتَٰعُ ٱلْحَيَوٰةِ ٱلدُّنْيَا وَٱللَّهُ عِندَهُۥ حُسْنُ ٱلْمَـَٔابِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@cccviii{قُلْ أَؤُنَبِّئُكُم بِخَيْرٍ مِّن ذَٰلِكُمْ لِلَّذِينَ ٱتَّقَوْا۟ عِندَ رَبِّهِمْ جَنَّٰتٌ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا وَأَزْوَٰجٌ مُّطَهَّرَةٌ وَرِضْوَٰنٌ مِّنَ ٱللَّهِ وَٱللَّهُ بَصِيرٌۢ بِٱلْعِبَادِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@cccix{ٱلَّذِينَ يَقُولُونَ رَبَّنَآ إِنَّنَآ ءَامَنَّا فَٱغْفِرْ لَنَا ذُنُوبَنَا وَقِنَا عَذَابَ ٱلنَّارِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@cccx{ٱلصَّٰبِرِينَ وَٱلصَّٰدِقِينَ وَٱلْقَٰنِتِينَ وَٱلْمُنفِقِينَ وَٱلْمُسْتَغْفِرِينَ بِٱلْأَسْحَارِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@cccxi{شَهِدَ ٱللَّهُ أَنَّهُۥ لَآ إِلَٰهَ إِلَّا هُوَ وَٱلْمَلَٰٓئِكَةُ وَأُو۟لُوا۟ ٱلْعِلْمِ قَآئِمًۢا بِٱلْقِسْطِ لَآ إِلَٰهَ إِلَّا هُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@cccxii{إِنَّ ٱلدِّينَ عِندَ ٱللَّهِ ٱلْإِسْلَٰمُ وَمَا ٱخْتَلَفَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ إِلَّا مِنۢ بَعْدِ مَا جَآءَهُمُ ٱلْعِلْمُ بَغْيًۢا بَيْنَهُمْ وَمَن يَكْفُرْ بِـَٔايَٰتِ ٱللَّهِ فَإِنَّ ٱللَّهَ سَرِيعُ ٱلْحِسَابِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@cccxiii{فَإِنْ حَآجُّوكَ فَقُلْ أَسْلَمْتُ وَجْهِىَ لِلَّهِ وَمَنِ ٱتَّبَعَنِ وَقُل لِّلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ وَٱلْأُمِّيِّۦنَ ءَأَسْلَمْتُمْ فَإِنْ أَسْلَمُوا۟ فَقَدِ ٱهْتَدَوا۟ وَّإِن تَوَلَّوْا۟ فَإِنَّمَا عَلَيْكَ ٱلْبَلَٰغُ وَٱللَّهُ بَصِيرٌۢ بِٱلْعِبَادِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@cccxiv{إِنَّ ٱلَّذِينَ يَكْفُرُونَ بِـَٔايَٰتِ ٱللَّهِ وَيَقْتُلُونَ ٱلنَّبِيِّۦنَ بِغَيْرِ حَقٍّ وَيَقْتُلُونَ ٱلَّذِينَ يَأْمُرُونَ بِٱلْقِسْطِ مِنَ ٱلنَّاسِ فَبَشِّرْهُم بِعَذَابٍ أَلِيمٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@cccxv{أُو۟لَٰٓئِكَ ٱلَّذِينَ حَبِطَتْ أَعْمَٰلُهُمْ فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَمَا لَهُم مِّن نَّٰصِرِينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@cccxvi{أَلَمْ تَرَ إِلَى ٱلَّذِينَ أُوتُوا۟ نَصِيبًا مِّنَ ٱلْكِتَٰبِ يُدْعَوْنَ إِلَىٰ كِتَٰبِ ٱللَّهِ لِيَحْكُمَ بَيْنَهُمْ ثُمَّ يَتَوَلَّىٰ فَرِيقٌ مِّنْهُمْ وَهُم مُّعْرِضُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@cccxvii{ذَٰلِكَ بِأَنَّهُمْ قَالُوا۟ لَن تَمَسَّنَا ٱلنَّارُ إِلَّآ أَيَّامًا مَّعْدُودَٰتٍ وَغَرَّهُمْ فِى دِينِهِم مَّا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@cccxviii{فَكَيْفَ إِذَا جَمَعْنَٰهُمْ لِيَوْمٍ لَّا رَيْبَ فِيهِ وَوُفِّيَتْ كُلُّ نَفْسٍ مَّا كَسَبَتْ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@cccxix{قُلِ ٱللَّهُمَّ مَٰلِكَ ٱلْمُلْكِ تُؤْتِى ٱلْمُلْكَ مَن تَشَآءُ وَتَنزِعُ ٱلْمُلْكَ مِمَّن تَشَآءُ وَتُعِزُّ مَن تَشَآءُ وَتُذِلُّ مَن تَشَآءُ بِيَدِكَ ٱلْخَيْرُ إِنَّكَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@cccxx{تُولِجُ ٱلَّيْلَ فِى ٱلنَّهَارِ وَتُولِجُ ٱلنَّهَارَ فِى ٱلَّيْلِ وَتُخْرِجُ ٱلْحَىَّ مِنَ ٱلْمَيِّتِ وَتُخْرِجُ ٱلْمَيِّتَ مِنَ ٱلْحَىِّ وَتَرْزُقُ مَن تَشَآءُ بِغَيْرِ حِسَابٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@cccxxi{لَّا يَتَّخِذِ ٱلْمُؤْمِنُونَ ٱلْكَٰفِرِينَ أَوْلِيَآءَ مِن دُونِ ٱلْمُؤْمِنِينَ وَمَن يَفْعَلْ ذَٰلِكَ فَلَيْسَ مِنَ ٱللَّهِ فِى شَىْءٍ إِلَّآ أَن تَتَّقُوا۟ مِنْهُمْ تُقَىٰةً وَيُحَذِّرُكُمُ ٱللَّهُ نَفْسَهُۥ وَإِلَى ٱللَّهِ ٱلْمَصِيرُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@cccxxii{قُلْ إِن تُخْفُوا۟ مَا فِى صُدُورِكُمْ أَوْ تُبْدُوهُ يَعْلَمْهُ ٱللَّهُ وَيَعْلَمُ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@cccxxiii{يَوْمَ تَجِدُ كُلُّ نَفْسٍ مَّا عَمِلَتْ مِنْ خَيْرٍ مُّحْضَرًا وَمَا عَمِلَتْ مِن سُوٓءٍ تَوَدُّ لَوْ أَنَّ بَيْنَهَا وَبَيْنَهُۥٓ أَمَدًۢا بَعِيدًا وَيُحَذِّرُكُمُ ٱللَّهُ نَفْسَهُۥ وَٱللَّهُ رَءُوفٌۢ بِٱلْعِبَادِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@cccxxiv{قُلْ إِن كُنتُمْ تُحِبُّونَ ٱللَّهَ فَٱتَّبِعُونِى يُحْبِبْكُمُ ٱللَّهُ وَيَغْفِرْ لَكُمْ ذُنُوبَكُمْ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@cccxxv{قُلْ أَطِيعُوا۟ ٱللَّهَ وَٱلرَّسُولَ فَإِن تَوَلَّوْا۟ فَإِنَّ ٱللَّهَ لَا يُحِبُّ ٱلْكَٰفِرِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@cccxxvi{إِنَّ ٱللَّهَ ٱصْطَفَىٰٓ ءَادَمَ وَنُوحًا وَءَالَ إِبْرَٰهِيمَ وَءَالَ عِمْرَٰنَ عَلَى ٱلْعَٰلَمِينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@cccxxvii{ذُرِّيَّةًۢ بَعْضُهَا مِنۢ بَعْضٍ وَٱللَّهُ سَمِيعٌ عَلِيمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@cccxxviii{إِذْ قَالَتِ ٱمْرَأَتُ عِمْرَٰنَ رَبِّ إِنِّى نَذَرْتُ لَكَ مَا فِى بَطْنِى مُحَرَّرًا فَتَقَبَّلْ مِنِّىٓ إِنَّكَ أَنتَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@cccxxix{فَلَمَّا وَضَعَتْهَا قَالَتْ رَبِّ إِنِّى وَضَعْتُهَآ أُنثَىٰ وَٱللَّهُ أَعْلَمُ بِمَا وَضَعَتْ وَلَيْسَ ٱلذَّكَرُ كَٱلْأُنثَىٰ وَإِنِّى سَمَّيْتُهَا مَرْيَمَ وَإِنِّىٓ أُعِيذُهَا بِكَ وَذُرِّيَّتَهَا مِنَ ٱلشَّيْطَٰنِ ٱلرَّجِيمِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@cccxxx{فَتَقَبَّلَهَا رَبُّهَا بِقَبُولٍ حَسَنٍ وَأَنۢبَتَهَا نَبَاتًا حَسَنًا وَكَفَّلَهَا زَكَرِيَّا كُلَّمَا دَخَلَ عَلَيْهَا زَكَرِيَّا ٱلْمِحْرَابَ وَجَدَ عِندَهَا رِزْقًا قَالَ يَٰمَرْيَمُ أَنَّىٰ لَكِ هَٰذَا قَالَتْ هُوَ مِنْ عِندِ ٱللَّهِ إِنَّ ٱللَّهَ يَرْزُقُ مَن يَشَآءُ بِغَيْرِ حِسَابٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@cccxxxi{هُنَالِكَ دَعَا زَكَرِيَّا رَبَّهُۥ قَالَ رَبِّ هَبْ لِى مِن لَّدُنكَ ذُرِّيَّةً طَيِّبَةً إِنَّكَ سَمِيعُ ٱلدُّعَآءِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@cccxxxii{فَنَادَتْهُ ٱلْمَلَٰٓئِكَةُ وَهُوَ قَآئِمٌ يُصَلِّى فِى ٱلْمِحْرَابِ أَنَّ ٱللَّهَ يُبَشِّرُكَ بِيَحْيَىٰ مُصَدِّقًۢا بِكَلِمَةٍ مِّنَ ٱللَّهِ وَسَيِّدًا وَحَصُورًا وَنَبِيًّا مِّنَ ٱلصَّٰلِحِينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@cccxxxiii{قَالَ رَبِّ أَنَّىٰ يَكُونُ لِى غُلَٰمٌ وَقَدْ بَلَغَنِىَ ٱلْكِبَرُ وَٱمْرَأَتِى عَاقِرٌ قَالَ كَذَٰلِكَ ٱللَّهُ يَفْعَلُ مَا يَشَآءُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@cccxxxiv{قَالَ رَبِّ ٱجْعَل لِّىٓ ءَايَةً قَالَ ءَايَتُكَ أَلَّا تُكَلِّمَ ٱلنَّاسَ ثَلَٰثَةَ أَيَّامٍ إِلَّا رَمْزًا وَٱذْكُر رَّبَّكَ كَثِيرًا وَسَبِّحْ بِٱلْعَشِىِّ وَٱلْإِبْكَٰرِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@cccxxxv{وَإِذْ قَالَتِ ٱلْمَلَٰٓئِكَةُ يَٰمَرْيَمُ إِنَّ ٱللَّهَ ٱصْطَفَىٰكِ وَطَهَّرَكِ وَٱصْطَفَىٰكِ عَلَىٰ نِسَآءِ ٱلْعَٰلَمِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@cccxxxvi{يَٰمَرْيَمُ ٱقْنُتِى لِرَبِّكِ وَٱسْجُدِى وَٱرْكَعِى مَعَ ٱلرَّٰكِعِينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@cccxxxvii{ذَٰلِكَ مِنْ أَنۢبَآءِ ٱلْغَيْبِ نُوحِيهِ إِلَيْكَ وَمَا كُنتَ لَدَيْهِمْ إِذْ يُلْقُونَ أَقْلَٰمَهُمْ أَيُّهُمْ يَكْفُلُ مَرْيَمَ وَمَا كُنتَ لَدَيْهِمْ إِذْ يَخْتَصِمُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@cccxxxviii{إِذْ قَالَتِ ٱلْمَلَٰٓئِكَةُ يَٰمَرْيَمُ إِنَّ ٱللَّهَ يُبَشِّرُكِ بِكَلِمَةٍ مِّنْهُ ٱسْمُهُ ٱلْمَسِيحُ عِيسَى ٱبْنُ مَرْيَمَ وَجِيهًا فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَمِنَ ٱلْمُقَرَّبِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@cccxxxix{وَيُكَلِّمُ ٱلنَّاسَ فِى ٱلْمَهْدِ وَكَهْلًا وَمِنَ ٱلصَّٰلِحِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@cccxl{قَالَتْ رَبِّ أَنَّىٰ يَكُونُ لِى وَلَدٌ وَلَمْ يَمْسَسْنِى بَشَرٌ قَالَ كَذَٰلِكِ ٱللَّهُ يَخْلُقُ مَا يَشَآءُ إِذَا قَضَىٰٓ أَمْرًا فَإِنَّمَا يَقُولُ لَهُۥ كُن فَيَكُونُ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@cccxli{وَيُعَلِّمُهُ ٱلْكِتَٰبَ وَٱلْحِكْمَةَ وَٱلتَّوْرَىٰةَ وَٱلْإِنجِيلَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@cccxlii{وَرَسُولًا إِلَىٰ بَنِىٓ إِسْرَٰٓءِيلَ أَنِّى قَدْ جِئْتُكُم بِـَٔايَةٍ مِّن رَّبِّكُمْ أَنِّىٓ أَخْلُقُ لَكُم مِّنَ ٱلطِّينِ كَهَيْـَٔةِ ٱلطَّيْرِ فَأَنفُخُ فِيهِ فَيَكُونُ طَيْرًۢا بِإِذْنِ ٱللَّهِ وَأُبْرِئُ ٱلْأَكْمَهَ وَٱلْأَبْرَصَ وَأُحْىِ ٱلْمَوْتَىٰ بِإِذْنِ ٱللَّهِ وَأُنَبِّئُكُم بِمَا تَأْكُلُونَ وَمَا تَدَّخِرُونَ فِى بُيُوتِكُمْ إِنَّ فِى ذَٰلِكَ لَءَايَةً لَّكُمْ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@cccxliii{وَمُصَدِّقًا لِّمَا بَيْنَ يَدَىَّ مِنَ ٱلتَّوْرَىٰةِ وَلِأُحِلَّ لَكُم بَعْضَ ٱلَّذِى حُرِّمَ عَلَيْكُمْ وَجِئْتُكُم بِـَٔايَةٍ مِّن رَّبِّكُمْ فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@cccxliv{إِنَّ ٱللَّهَ رَبِّى وَرَبُّكُمْ فَٱعْبُدُوهُ هَٰذَا صِرَٰطٌ مُّسْتَقِيمٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@cccxlv{فَلَمَّآ أَحَسَّ عِيسَىٰ مِنْهُمُ ٱلْكُفْرَ قَالَ مَنْ أَنصَارِىٓ إِلَى ٱللَّهِ قَالَ ٱلْحَوَارِيُّونَ نَحْنُ أَنصَارُ ٱللَّهِ ءَامَنَّا بِٱللَّهِ وَٱشْهَدْ بِأَنَّا مُسْلِمُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@cccxlvi{رَبَّنَآ ءَامَنَّا بِمَآ أَنزَلْتَ وَٱتَّبَعْنَا ٱلرَّسُولَ فَٱكْتُبْنَا مَعَ ٱلشَّٰهِدِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@cccxlvii{وَمَكَرُوا۟ وَمَكَرَ ٱللَّهُ وَٱللَّهُ خَيْرُ ٱلْمَٰكِرِينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@cccxlviii{إِذْ قَالَ ٱللَّهُ يَٰعِيسَىٰٓ إِنِّى مُتَوَفِّيكَ وَرَافِعُكَ إِلَىَّ وَمُطَهِّرُكَ مِنَ ٱلَّذِينَ كَفَرُوا۟ وَجَاعِلُ ٱلَّذِينَ ٱتَّبَعُوكَ فَوْقَ ٱلَّذِينَ كَفَرُوٓا۟ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ ثُمَّ إِلَىَّ مَرْجِعُكُمْ فَأَحْكُمُ بَيْنَكُمْ فِيمَا كُنتُمْ فِيهِ تَخْتَلِفُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@cccxlix{فَأَمَّا ٱلَّذِينَ كَفَرُوا۟ فَأُعَذِّبُهُمْ عَذَابًا شَدِيدًا فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَمَا لَهُم مِّن نَّٰصِرِينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@cccl{وَأَمَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ فَيُوَفِّيهِمْ أُجُورَهُمْ وَٱللَّهُ لَا يُحِبُّ ٱلظَّٰلِمِينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@cccli{ذَٰلِكَ نَتْلُوهُ عَلَيْكَ مِنَ ٱلْءَايَٰتِ وَٱلذِّكْرِ ٱلْحَكِيمِ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@ccclii{إِنَّ مَثَلَ عِيسَىٰ عِندَ ٱللَّهِ كَمَثَلِ ءَادَمَ خَلَقَهُۥ مِن تُرَابٍ ثُمَّ قَالَ لَهُۥ كُن فَيَكُونُ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@cccliii{ٱلْحَقُّ مِن رَّبِّكَ فَلَا تَكُن مِّنَ ٱلْمُمْتَرِينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@cccliv{فَمَنْ حَآجَّكَ فِيهِ مِنۢ بَعْدِ مَا جَآءَكَ مِنَ ٱلْعِلْمِ فَقُلْ تَعَالَوْا۟ نَدْعُ أَبْنَآءَنَا وَأَبْنَآءَكُمْ وَنِسَآءَنَا وَنِسَآءَكُمْ وَأَنفُسَنَا وَأَنفُسَكُمْ ثُمَّ نَبْتَهِلْ فَنَجْعَل لَّعْنَتَ ٱللَّهِ عَلَى ٱلْكَٰذِبِينَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@ccclv{إِنَّ هَٰذَا لَهُوَ ٱلْقَصَصُ ٱلْحَقُّ وَمَا مِنْ إِلَٰهٍ إِلَّا ٱللَّهُ وَإِنَّ ٱللَّهَ لَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@ccclvi{فَإِن تَوَلَّوْا۟ فَإِنَّ ٱللَّهَ عَلِيمٌۢ بِٱلْمُفْسِدِينَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@ccclvii{قُلْ يَٰٓأَهْلَ ٱلْكِتَٰبِ تَعَالَوْا۟ إِلَىٰ كَلِمَةٍ سَوَآءٍۭ بَيْنَنَا وَبَيْنَكُمْ أَلَّا نَعْبُدَ إِلَّا ٱللَّهَ وَلَا نُشْرِكَ بِهِۦ شَيْـًٔا وَلَا يَتَّخِذَ بَعْضُنَا بَعْضًا أَرْبَابًا مِّن دُونِ ٱللَّهِ فَإِن تَوَلَّوْا۟ فَقُولُوا۟ ٱشْهَدُوا۟ بِأَنَّا مُسْلِمُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@ccclviii{يَٰٓأَهْلَ ٱلْكِتَٰبِ لِمَ تُحَآجُّونَ فِىٓ إِبْرَٰهِيمَ وَمَآ أُنزِلَتِ ٱلتَّوْرَىٰةُ وَٱلْإِنجِيلُ إِلَّا مِنۢ بَعْدِهِۦٓ أَفَلَا تَعْقِلُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@ccclix{هَٰٓأَنتُمْ هَٰٓؤُلَآءِ حَٰجَجْتُمْ فِيمَا لَكُم بِهِۦ عِلْمٌ فَلِمَ تُحَآجُّونَ فِيمَا لَيْسَ لَكُم بِهِۦ عِلْمٌ وَٱللَّهُ يَعْلَمُ وَأَنتُمْ لَا تَعْلَمُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@ccclx{مَا كَانَ إِبْرَٰهِيمُ يَهُودِيًّا وَلَا نَصْرَانِيًّا وَلَٰكِن كَانَ حَنِيفًا مُّسْلِمًا وَمَا كَانَ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@ccclxi{إِنَّ أَوْلَى ٱلنَّاسِ بِإِبْرَٰهِيمَ لَلَّذِينَ ٱتَّبَعُوهُ وَهَٰذَا ٱلنَّبِىُّ وَٱلَّذِينَ ءَامَنُوا۟ وَٱللَّهُ وَلِىُّ ٱلْمُؤْمِنِينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@ccclxii{وَدَّت طَّآئِفَةٌ مِّنْ أَهْلِ ٱلْكِتَٰبِ لَوْ يُضِلُّونَكُمْ وَمَا يُضِلُّونَ إِلَّآ أَنفُسَهُمْ وَمَا يَشْعُرُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@ccclxiii{يَٰٓأَهْلَ ٱلْكِتَٰبِ لِمَ تَكْفُرُونَ بِـَٔايَٰتِ ٱللَّهِ وَأَنتُمْ تَشْهَدُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@ccclxiv{يَٰٓأَهْلَ ٱلْكِتَٰبِ لِمَ تَلْبِسُونَ ٱلْحَقَّ بِٱلْبَٰطِلِ وَتَكْتُمُونَ ٱلْحَقَّ وَأَنتُمْ تَعْلَمُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@ccclxv{وَقَالَت طَّآئِفَةٌ مِّنْ أَهْلِ ٱلْكِتَٰبِ ءَامِنُوا۟ بِٱلَّذِىٓ أُنزِلَ عَلَى ٱلَّذِينَ ءَامَنُوا۟ وَجْهَ ٱلنَّهَارِ وَٱكْفُرُوٓا۟ ءَاخِرَهُۥ لَعَلَّهُمْ يَرْجِعُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@ccclxvi{وَلَا تُؤْمِنُوٓا۟ إِلَّا لِمَن تَبِعَ دِينَكُمْ قُلْ إِنَّ ٱلْهُدَىٰ هُدَى ٱللَّهِ أَن يُؤْتَىٰٓ أَحَدٌ مِّثْلَ مَآ أُوتِيتُمْ أَوْ يُحَآجُّوكُمْ عِندَ رَبِّكُمْ قُلْ إِنَّ ٱلْفَضْلَ بِيَدِ ٱللَّهِ يُؤْتِيهِ مَن يَشَآءُ وَٱللَّهُ وَٰسِعٌ عَلِيمٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@ccclxvii{يَخْتَصُّ بِرَحْمَتِهِۦ مَن يَشَآءُ وَٱللَّهُ ذُو ٱلْفَضْلِ ٱلْعَظِيمِ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@ccclxviii{وَمِنْ أَهْلِ ٱلْكِتَٰبِ مَنْ إِن تَأْمَنْهُ بِقِنطَارٍ يُؤَدِّهِۦٓ إِلَيْكَ وَمِنْهُم مَّنْ إِن تَأْمَنْهُ بِدِينَارٍ لَّا يُؤَدِّهِۦٓ إِلَيْكَ إِلَّا مَا دُمْتَ عَلَيْهِ قَآئِمًا ذَٰلِكَ بِأَنَّهُمْ قَالُوا۟ لَيْسَ عَلَيْنَا فِى ٱلْأُمِّيِّۦنَ سَبِيلٌ وَيَقُولُونَ عَلَى ٱللَّهِ ٱلْكَذِبَ وَهُمْ يَعْلَمُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@ccclxix{بَلَىٰ مَنْ أَوْفَىٰ بِعَهْدِهِۦ وَٱتَّقَىٰ فَإِنَّ ٱللَّهَ يُحِبُّ ٱلْمُتَّقِينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@ccclxx{إِنَّ ٱلَّذِينَ يَشْتَرُونَ بِعَهْدِ ٱللَّهِ وَأَيْمَٰنِهِمْ ثَمَنًا قَلِيلًا أُو۟لَٰٓئِكَ لَا خَلَٰقَ لَهُمْ فِى ٱلْءَاخِرَةِ وَلَا يُكَلِّمُهُمُ ٱللَّهُ وَلَا يَنظُرُ إِلَيْهِمْ يَوْمَ ٱلْقِيَٰمَةِ وَلَا يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@ccclxxi{وَإِنَّ مِنْهُمْ لَفَرِيقًا يَلْوُۥنَ أَلْسِنَتَهُم بِٱلْكِتَٰبِ لِتَحْسَبُوهُ مِنَ ٱلْكِتَٰبِ وَمَا هُوَ مِنَ ٱلْكِتَٰبِ وَيَقُولُونَ هُوَ مِنْ عِندِ ٱللَّهِ وَمَا هُوَ مِنْ عِندِ ٱللَّهِ وَيَقُولُونَ عَلَى ٱللَّهِ ٱلْكَذِبَ وَهُمْ يَعْلَمُونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@ccclxxii{مَا كَانَ لِبَشَرٍ أَن يُؤْتِيَهُ ٱللَّهُ ٱلْكِتَٰبَ وَٱلْحُكْمَ وَٱلنُّبُوَّةَ ثُمَّ يَقُولَ لِلنَّاسِ كُونُوا۟ عِبَادًا لِّى مِن دُونِ ٱللَّهِ وَلَٰكِن كُونُوا۟ رَبَّٰنِيِّۦنَ بِمَا كُنتُمْ تُعَلِّمُونَ ٱلْكِتَٰبَ وَبِمَا كُنتُمْ تَدْرُسُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@ccclxxiii{وَلَا يَأْمُرَكُمْ أَن تَتَّخِذُوا۟ ٱلْمَلَٰٓئِكَةَ وَٱلنَّبِيِّۦنَ أَرْبَابًا أَيَأْمُرُكُم بِٱلْكُفْرِ بَعْدَ إِذْ أَنتُم مُّسْلِمُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@ccclxxiv{وَإِذْ أَخَذَ ٱللَّهُ مِيثَٰقَ ٱلنَّبِيِّۦنَ لَمَآ ءَاتَيْتُكُم مِّن كِتَٰبٍ وَحِكْمَةٍ ثُمَّ جَآءَكُمْ رَسُولٌ مُّصَدِّقٌ لِّمَا مَعَكُمْ لَتُؤْمِنُنَّ بِهِۦ وَلَتَنصُرُنَّهُۥ قَالَ ءَأَقْرَرْتُمْ وَأَخَذْتُمْ عَلَىٰ ذَٰلِكُمْ إِصْرِى قَالُوٓا۟ أَقْرَرْنَا قَالَ فَٱشْهَدُوا۟ وَأَنَا۠ مَعَكُم مِّنَ ٱلشَّٰهِدِينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@ccclxxv{فَمَن تَوَلَّىٰ بَعْدَ ذَٰلِكَ فَأُو۟لَٰٓئِكَ هُمُ ٱلْفَٰسِقُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@ccclxxvi{أَفَغَيْرَ دِينِ ٱللَّهِ يَبْغُونَ وَلَهُۥٓ أَسْلَمَ مَن فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ طَوْعًا وَكَرْهًا وَإِلَيْهِ يُرْجَعُونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@ccclxxvii{قُلْ ءَامَنَّا بِٱللَّهِ وَمَآ أُنزِلَ عَلَيْنَا وَمَآ أُنزِلَ عَلَىٰٓ إِبْرَٰهِيمَ وَإِسْمَٰعِيلَ وَإِسْحَٰقَ وَيَعْقُوبَ وَٱلْأَسْبَاطِ وَمَآ أُوتِىَ مُوسَىٰ وَعِيسَىٰ وَٱلنَّبِيُّونَ مِن رَّبِّهِمْ لَا نُفَرِّقُ بَيْنَ أَحَدٍ مِّنْهُمْ وَنَحْنُ لَهُۥ مُسْلِمُونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@ccclxxviii{وَمَن يَبْتَغِ غَيْرَ ٱلْإِسْلَٰمِ دِينًا فَلَن يُقْبَلَ مِنْهُ وَهُوَ فِى ٱلْءَاخِرَةِ مِنَ ٱلْخَٰسِرِينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@ccclxxix{كَيْفَ يَهْدِى ٱللَّهُ قَوْمًا كَفَرُوا۟ بَعْدَ إِيمَٰنِهِمْ وَشَهِدُوٓا۟ أَنَّ ٱلرَّسُولَ حَقٌّ وَجَآءَهُمُ ٱلْبَيِّنَٰتُ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@ccclxxx{أُو۟لَٰٓئِكَ جَزَآؤُهُمْ أَنَّ عَلَيْهِمْ لَعْنَةَ ٱللَّهِ وَٱلْمَلَٰٓئِكَةِ وَٱلنَّاسِ أَجْمَعِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@ccclxxxi{خَٰلِدِينَ فِيهَا لَا يُخَفَّفُ عَنْهُمُ ٱلْعَذَابُ وَلَا هُمْ يُنظَرُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@ccclxxxii{إِلَّا ٱلَّذِينَ تَابُوا۟ مِنۢ بَعْدِ ذَٰلِكَ وَأَصْلَحُوا۟ فَإِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@ccclxxxiii{إِنَّ ٱلَّذِينَ كَفَرُوا۟ بَعْدَ إِيمَٰنِهِمْ ثُمَّ ٱزْدَادُوا۟ كُفْرًا لَّن تُقْبَلَ تَوْبَتُهُمْ وَأُو۟لَٰٓئِكَ هُمُ ٱلضَّآلُّونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@ccclxxxiv{إِنَّ ٱلَّذِينَ كَفَرُوا۟ وَمَاتُوا۟ وَهُمْ كُفَّارٌ فَلَن يُقْبَلَ مِنْ أَحَدِهِم مِّلْءُ ٱلْأَرْضِ ذَهَبًا وَلَوِ ٱفْتَدَىٰ بِهِۦٓ أُو۟لَٰٓئِكَ لَهُمْ عَذَابٌ أَلِيمٌ وَمَا لَهُم مِّن نَّٰصِرِينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@ccclxxxv{لَن تَنَالُوا۟ ٱلْبِرَّ حَتَّىٰ تُنفِقُوا۟ مِمَّا تُحِبُّونَ وَمَا تُنفِقُوا۟ مِن شَىْءٍ فَإِنَّ ٱللَّهَ بِهِۦ عَلِيمٌ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@ccclxxxvi{كُلُّ ٱلطَّعَامِ كَانَ حِلًّا لِّبَنِىٓ إِسْرَٰٓءِيلَ إِلَّا مَا حَرَّمَ إِسْرَٰٓءِيلُ عَلَىٰ نَفْسِهِۦ مِن قَبْلِ أَن تُنَزَّلَ ٱلتَّوْرَىٰةُ قُلْ فَأْتُوا۟ بِٱلتَّوْرَىٰةِ فَٱتْلُوهَآ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@ccclxxxvii{فَمَنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ ٱلْكَذِبَ مِنۢ بَعْدِ ذَٰلِكَ فَأُو۟لَٰٓئِكَ هُمُ ٱلظَّٰلِمُونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@ccclxxxviii{قُلْ صَدَقَ ٱللَّهُ فَٱتَّبِعُوا۟ مِلَّةَ إِبْرَٰهِيمَ حَنِيفًا وَمَا كَانَ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@ccclxxxix{إِنَّ أَوَّلَ بَيْتٍ وُضِعَ لِلنَّاسِ لَلَّذِى بِبَكَّةَ مُبَارَكًا وَهُدًى لِّلْعَٰلَمِينَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@cccxc{فِيهِ ءَايَٰتٌۢ بَيِّنَٰتٌ مَّقَامُ إِبْرَٰهِيمَ وَمَن دَخَلَهُۥ كَانَ ءَامِنًا وَلِلَّهِ عَلَى ٱلنَّاسِ حِجُّ ٱلْبَيْتِ مَنِ ٱسْتَطَاعَ إِلَيْهِ سَبِيلًا وَمَن كَفَرَ فَإِنَّ ٱللَّهَ غَنِىٌّ عَنِ ٱلْعَٰلَمِينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@cccxci{قُلْ يَٰٓأَهْلَ ٱلْكِتَٰبِ لِمَ تَكْفُرُونَ بِـَٔايَٰتِ ٱللَّهِ وَٱللَّهُ شَهِيدٌ عَلَىٰ مَا تَعْمَلُونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@cccxcii{قُلْ يَٰٓأَهْلَ ٱلْكِتَٰبِ لِمَ تَصُدُّونَ عَن سَبِيلِ ٱللَّهِ مَنْ ءَامَنَ تَبْغُونَهَا عِوَجًا وَأَنتُمْ شُهَدَآءُ وَمَا ٱللَّهُ بِغَٰفِلٍ عَمَّا تَعْمَلُونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@cccxciii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِن تُطِيعُوا۟ فَرِيقًا مِّنَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ يَرُدُّوكُم بَعْدَ إِيمَٰنِكُمْ كَٰفِرِينَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@cccxciv{وَكَيْفَ تَكْفُرُونَ وَأَنتُمْ تُتْلَىٰ عَلَيْكُمْ ءَايَٰتُ ٱللَّهِ وَفِيكُمْ رَسُولُهُۥ وَمَن يَعْتَصِم بِٱللَّهِ فَقَدْ هُدِىَ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@cccxcv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱتَّقُوا۟ ٱللَّهَ حَقَّ تُقَاتِهِۦ وَلَا تَمُوتُنَّ إِلَّا وَأَنتُم مُّسْلِمُونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@cccxcvi{وَٱعْتَصِمُوا۟ بِحَبْلِ ٱللَّهِ جَمِيعًا وَلَا تَفَرَّقُوا۟ وَٱذْكُرُوا۟ نِعْمَتَ ٱللَّهِ عَلَيْكُمْ إِذْ كُنتُمْ أَعْدَآءً فَأَلَّفَ بَيْنَ قُلُوبِكُمْ فَأَصْبَحْتُم بِنِعْمَتِهِۦٓ إِخْوَٰنًا وَكُنتُمْ عَلَىٰ شَفَا حُفْرَةٍ مِّنَ ٱلنَّارِ فَأَنقَذَكُم مِّنْهَا كَذَٰلِكَ يُبَيِّنُ ٱللَّهُ لَكُمْ ءَايَٰتِهِۦ لَعَلَّكُمْ تَهْتَدُونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@cccxcvii{وَلْتَكُن مِّنكُمْ أُمَّةٌ يَدْعُونَ إِلَى ٱلْخَيْرِ وَيَأْمُرُونَ بِٱلْمَعْرُوفِ وَيَنْهَوْنَ عَنِ ٱلْمُنكَرِ وَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@cccxcviii{وَلَا تَكُونُوا۟ كَٱلَّذِينَ تَفَرَّقُوا۟ وَٱخْتَلَفُوا۟ مِنۢ بَعْدِ مَا جَآءَهُمُ ٱلْبَيِّنَٰتُ وَأُو۟لَٰٓئِكَ لَهُمْ عَذَابٌ عَظِيمٌ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@cccxcix{يَوْمَ تَبْيَضُّ وُجُوهٌ وَتَسْوَدُّ وُجُوهٌ فَأَمَّا ٱلَّذِينَ ٱسْوَدَّتْ وُجُوهُهُمْ أَكَفَرْتُم بَعْدَ إِيمَٰنِكُمْ فَذُوقُوا۟ ٱلْعَذَابَ بِمَا كُنتُمْ تَكْفُرُونَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@cd{وَأَمَّا ٱلَّذِينَ ٱبْيَضَّتْ وُجُوهُهُمْ فَفِى رَحْمَةِ ٱللَّهِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@cdi{تِلْكَ ءَايَٰتُ ٱللَّهِ نَتْلُوهَا عَلَيْكَ بِٱلْحَقِّ وَمَا ٱللَّهُ يُرِيدُ ظُلْمًا لِّلْعَٰلَمِينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@cdii{وَلِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَإِلَى ٱللَّهِ تُرْجَعُ ٱلْأُمُورُ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@cdiii{كُنتُمْ خَيْرَ أُمَّةٍ أُخْرِجَتْ لِلنَّاسِ تَأْمُرُونَ بِٱلْمَعْرُوفِ وَتَنْهَوْنَ عَنِ ٱلْمُنكَرِ وَتُؤْمِنُونَ بِٱللَّهِ وَلَوْ ءَامَنَ أَهْلُ ٱلْكِتَٰبِ لَكَانَ خَيْرًا لَّهُم مِّنْهُمُ ٱلْمُؤْمِنُونَ وَأَكْثَرُهُمُ ٱلْفَٰسِقُونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@cdiv{لَن يَضُرُّوكُمْ إِلَّآ أَذًى وَإِن يُقَٰتِلُوكُمْ يُوَلُّوكُمُ ٱلْأَدْبَارَ ثُمَّ لَا يُنصَرُونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@cdv{ضُرِبَتْ عَلَيْهِمُ ٱلذِّلَّةُ أَيْنَ مَا ثُقِفُوٓا۟ إِلَّا بِحَبْلٍ مِّنَ ٱللَّهِ وَحَبْلٍ مِّنَ ٱلنَّاسِ وَبَآءُو بِغَضَبٍ مِّنَ ٱللَّهِ وَضُرِبَتْ عَلَيْهِمُ ٱلْمَسْكَنَةُ ذَٰلِكَ بِأَنَّهُمْ كَانُوا۟ يَكْفُرُونَ بِـَٔايَٰتِ ٱللَّهِ وَيَقْتُلُونَ ٱلْأَنۢبِيَآءَ بِغَيْرِ حَقٍّ ذَٰلِكَ بِمَا عَصَوا۟ وَّكَانُوا۟ يَعْتَدُونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@cdvi{لَيْسُوا۟ سَوَآءً مِّنْ أَهْلِ ٱلْكِتَٰبِ أُمَّةٌ قَآئِمَةٌ يَتْلُونَ ءَايَٰتِ ٱللَّهِ ءَانَآءَ ٱلَّيْلِ وَهُمْ يَسْجُدُونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@cdvii{يُؤْمِنُونَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَيَأْمُرُونَ بِٱلْمَعْرُوفِ وَيَنْهَوْنَ عَنِ ٱلْمُنكَرِ وَيُسَٰرِعُونَ فِى ٱلْخَيْرَٰتِ وَأُو۟لَٰٓئِكَ مِنَ ٱلصَّٰلِحِينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@cdviii{وَمَا يَفْعَلُوا۟ مِنْ خَيْرٍ فَلَن يُكْفَرُوهُ وَٱللَّهُ عَلِيمٌۢ بِٱلْمُتَّقِينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@cdix{إِنَّ ٱلَّذِينَ كَفَرُوا۟ لَن تُغْنِىَ عَنْهُمْ أَمْوَٰلُهُمْ وَلَآ أَوْلَٰدُهُم مِّنَ ٱللَّهِ شَيْـًٔا وَأُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@cdx{مَثَلُ مَا يُنفِقُونَ فِى هَٰذِهِ ٱلْحَيَوٰةِ ٱلدُّنْيَا كَمَثَلِ رِيحٍ فِيهَا صِرٌّ أَصَابَتْ حَرْثَ قَوْمٍ ظَلَمُوٓا۟ أَنفُسَهُمْ فَأَهْلَكَتْهُ وَمَا ظَلَمَهُمُ ٱللَّهُ وَلَٰكِنْ أَنفُسَهُمْ يَظْلِمُونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@cdxi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَتَّخِذُوا۟ بِطَانَةً مِّن دُونِكُمْ لَا يَأْلُونَكُمْ خَبَالًا وَدُّوا۟ مَا عَنِتُّمْ قَدْ بَدَتِ ٱلْبَغْضَآءُ مِنْ أَفْوَٰهِهِمْ وَمَا تُخْفِى صُدُورُهُمْ أَكْبَرُ قَدْ بَيَّنَّا لَكُمُ ٱلْءَايَٰتِ إِن كُنتُمْ تَعْقِلُونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@cdxii{هَٰٓأَنتُمْ أُو۟لَآءِ تُحِبُّونَهُمْ وَلَا يُحِبُّونَكُمْ وَتُؤْمِنُونَ بِٱلْكِتَٰبِ كُلِّهِۦ وَإِذَا لَقُوكُمْ قَالُوٓا۟ ءَامَنَّا وَإِذَا خَلَوْا۟ عَضُّوا۟ عَلَيْكُمُ ٱلْأَنَامِلَ مِنَ ٱلْغَيْظِ قُلْ مُوتُوا۟ بِغَيْظِكُمْ إِنَّ ٱللَّهَ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@cdxiii{إِن تَمْسَسْكُمْ حَسَنَةٌ تَسُؤْهُمْ وَإِن تُصِبْكُمْ سَيِّئَةٌ يَفْرَحُوا۟ بِهَا وَإِن تَصْبِرُوا۟ وَتَتَّقُوا۟ لَا يَضُرُّكُمْ كَيْدُهُمْ شَيْـًٔا إِنَّ ٱللَّهَ بِمَا يَعْمَلُونَ مُحِيطٌ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@cdxiv{وَإِذْ غَدَوْتَ مِنْ أَهْلِكَ تُبَوِّئُ ٱلْمُؤْمِنِينَ مَقَٰعِدَ لِلْقِتَالِ وَٱللَّهُ سَمِيعٌ عَلِيمٌ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@cdxv{إِذْ هَمَّت طَّآئِفَتَانِ مِنكُمْ أَن تَفْشَلَا وَٱللَّهُ وَلِيُّهُمَا وَعَلَى ٱللَّهِ فَلْيَتَوَكَّلِ ٱلْمُؤْمِنُونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@cdxvi{وَلَقَدْ نَصَرَكُمُ ٱللَّهُ بِبَدْرٍ وَأَنتُمْ أَذِلَّةٌ فَٱتَّقُوا۟ ٱللَّهَ لَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@cdxvii{إِذْ تَقُولُ لِلْمُؤْمِنِينَ أَلَن يَكْفِيَكُمْ أَن يُمِدَّكُمْ رَبُّكُم بِثَلَٰثَةِ ءَالَٰفٍ مِّنَ ٱلْمَلَٰٓئِكَةِ مُنزَلِينَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@cdxviii{بَلَىٰٓ إِن تَصْبِرُوا۟ وَتَتَّقُوا۟ وَيَأْتُوكُم مِّن فَوْرِهِمْ هَٰذَا يُمْدِدْكُمْ رَبُّكُم بِخَمْسَةِ ءَالَٰفٍ مِّنَ ٱلْمَلَٰٓئِكَةِ مُسَوِّمِينَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@cdxix{وَمَا جَعَلَهُ ٱللَّهُ إِلَّا بُشْرَىٰ لَكُمْ وَلِتَطْمَئِنَّ قُلُوبُكُم بِهِۦ وَمَا ٱلنَّصْرُ إِلَّا مِنْ عِندِ ٱللَّهِ ٱلْعَزِيزِ ٱلْحَكِيمِ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@cdxx{لِيَقْطَعَ طَرَفًا مِّنَ ٱلَّذِينَ كَفَرُوٓا۟ أَوْ يَكْبِتَهُمْ فَيَنقَلِبُوا۟ خَآئِبِينَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@cdxxi{لَيْسَ لَكَ مِنَ ٱلْأَمْرِ شَىْءٌ أَوْ يَتُوبَ عَلَيْهِمْ أَوْ يُعَذِّبَهُمْ فَإِنَّهُمْ ظَٰلِمُونَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@cdxxii{وَلِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ يَغْفِرُ لِمَن يَشَآءُ وَيُعَذِّبُ مَن يَشَآءُ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@cdxxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَأْكُلُوا۟ ٱلرِّبَوٰٓا۟ أَضْعَٰفًا مُّضَٰعَفَةً وَٱتَّقُوا۟ ٱللَّهَ لَعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@cdxxiv{وَٱتَّقُوا۟ ٱلنَّارَ ٱلَّتِىٓ أُعِدَّتْ لِلْكَٰفِرِينَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@cdxxv{وَأَطِيعُوا۟ ٱللَّهَ وَٱلرَّسُولَ لَعَلَّكُمْ تُرْحَمُونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@cdxxvi{وَسَارِعُوٓا۟ إِلَىٰ مَغْفِرَةٍ مِّن رَّبِّكُمْ وَجَنَّةٍ عَرْضُهَا ٱلسَّمَٰوَٰتُ وَٱلْأَرْضُ أُعِدَّتْ لِلْمُتَّقِينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@cdxxvii{ٱلَّذِينَ يُنفِقُونَ فِى ٱلسَّرَّآءِ وَٱلضَّرَّآءِ وَٱلْكَٰظِمِينَ ٱلْغَيْظَ وَٱلْعَافِينَ عَنِ ٱلنَّاسِ وَٱللَّهُ يُحِبُّ ٱلْمُحْسِنِينَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@cdxxviii{وَٱلَّذِينَ إِذَا فَعَلُوا۟ فَٰحِشَةً أَوْ ظَلَمُوٓا۟ أَنفُسَهُمْ ذَكَرُوا۟ ٱللَّهَ فَٱسْتَغْفَرُوا۟ لِذُنُوبِهِمْ وَمَن يَغْفِرُ ٱلذُّنُوبَ إِلَّا ٱللَّهُ وَلَمْ يُصِرُّوا۟ عَلَىٰ مَا فَعَلُوا۟ وَهُمْ يَعْلَمُونَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@cdxxix{أُو۟لَٰٓئِكَ جَزَآؤُهُم مَّغْفِرَةٌ مِّن رَّبِّهِمْ وَجَنَّٰتٌ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا وَنِعْمَ أَجْرُ ٱلْعَٰمِلِينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@cdxxx{قَدْ خَلَتْ مِن قَبْلِكُمْ سُنَنٌ فَسِيرُوا۟ فِى ٱلْأَرْضِ فَٱنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُكَذِّبِينَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@cdxxxi{هَٰذَا بَيَانٌ لِّلنَّاسِ وَهُدًى وَمَوْعِظَةٌ لِّلْمُتَّقِينَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@cdxxxii{وَلَا تَهِنُوا۟ وَلَا تَحْزَنُوا۟ وَأَنتُمُ ٱلْأَعْلَوْنَ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@cdxxxiii{إِن يَمْسَسْكُمْ قَرْحٌ فَقَدْ مَسَّ ٱلْقَوْمَ قَرْحٌ مِّثْلُهُۥ وَتِلْكَ ٱلْأَيَّامُ نُدَاوِلُهَا بَيْنَ ٱلنَّاسِ وَلِيَعْلَمَ ٱللَّهُ ٱلَّذِينَ ءَامَنُوا۟ وَيَتَّخِذَ مِنكُمْ شُهَدَآءَ وَٱللَّهُ لَا يُحِبُّ ٱلظَّٰلِمِينَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@cdxxxiv{وَلِيُمَحِّصَ ٱللَّهُ ٱلَّذِينَ ءَامَنُوا۟ وَيَمْحَقَ ٱلْكَٰفِرِينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@cdxxxv{أَمْ حَسِبْتُمْ أَن تَدْخُلُوا۟ ٱلْجَنَّةَ وَلَمَّا يَعْلَمِ ٱللَّهُ ٱلَّذِينَ جَٰهَدُوا۟ مِنكُمْ وَيَعْلَمَ ٱلصَّٰبِرِينَ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@cdxxxvi{وَلَقَدْ كُنتُمْ تَمَنَّوْنَ ٱلْمَوْتَ مِن قَبْلِ أَن تَلْقَوْهُ فَقَدْ رَأَيْتُمُوهُ وَأَنتُمْ تَنظُرُونَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@cdxxxvii{وَمَا مُحَمَّدٌ إِلَّا رَسُولٌ قَدْ خَلَتْ مِن قَبْلِهِ ٱلرُّسُلُ أَفَإِي۟ن مَّاتَ أَوْ قُتِلَ ٱنقَلَبْتُمْ عَلَىٰٓ أَعْقَٰبِكُمْ وَمَن يَنقَلِبْ عَلَىٰ عَقِبَيْهِ فَلَن يَضُرَّ ٱللَّهَ شَيْـًٔا وَسَيَجْزِى ٱللَّهُ ٱلشَّٰكِرِينَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@cdxxxviii{وَمَا كَانَ لِنَفْسٍ أَن تَمُوتَ إِلَّا بِإِذْنِ ٱللَّهِ كِتَٰبًا مُّؤَجَّلًا وَمَن يُرِدْ ثَوَابَ ٱلدُّنْيَا نُؤْتِهِۦ مِنْهَا وَمَن يُرِدْ ثَوَابَ ٱلْءَاخِرَةِ نُؤْتِهِۦ مِنْهَا وَسَنَجْزِى ٱلشَّٰكِرِينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@cdxxxix{وَكَأَيِّن مِّن نَّبِىٍّ قَٰتَلَ مَعَهُۥ رِبِّيُّونَ كَثِيرٌ فَمَا وَهَنُوا۟ لِمَآ أَصَابَهُمْ فِى سَبِيلِ ٱللَّهِ وَمَا ضَعُفُوا۟ وَمَا ٱسْتَكَانُوا۟ وَٱللَّهُ يُحِبُّ ٱلصَّٰبِرِينَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@cdxl{وَمَا كَانَ قَوْلَهُمْ إِلَّآ أَن قَالُوا۟ رَبَّنَا ٱغْفِرْ لَنَا ذُنُوبَنَا وَإِسْرَافَنَا فِىٓ أَمْرِنَا وَثَبِّتْ أَقْدَامَنَا وَٱنصُرْنَا عَلَى ٱلْقَوْمِ ٱلْكَٰفِرِينَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@cdxli{فَـَٔاتَىٰهُمُ ٱللَّهُ ثَوَابَ ٱلدُّنْيَا وَحُسْنَ ثَوَابِ ٱلْءَاخِرَةِ وَٱللَّهُ يُحِبُّ ٱلْمُحْسِنِينَ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@cdxlii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِن تُطِيعُوا۟ ٱلَّذِينَ كَفَرُوا۟ يَرُدُّوكُمْ عَلَىٰٓ أَعْقَٰبِكُمْ فَتَنقَلِبُوا۟ خَٰسِرِينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@cdxliii{بَلِ ٱللَّهُ مَوْلَىٰكُمْ وَهُوَ خَيْرُ ٱلنَّٰصِرِينَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@cdxliv{سَنُلْقِى فِى قُلُوبِ ٱلَّذِينَ كَفَرُوا۟ ٱلرُّعْبَ بِمَآ أَشْرَكُوا۟ بِٱللَّهِ مَا لَمْ يُنَزِّلْ بِهِۦ سُلْطَٰنًا وَمَأْوَىٰهُمُ ٱلنَّارُ وَبِئْسَ مَثْوَى ٱلظَّٰلِمِينَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@cdxlv{وَلَقَدْ صَدَقَكُمُ ٱللَّهُ وَعْدَهُۥٓ إِذْ تَحُسُّونَهُم بِإِذْنِهِۦ حَتَّىٰٓ إِذَا فَشِلْتُمْ وَتَنَٰزَعْتُمْ فِى ٱلْأَمْرِ وَعَصَيْتُم مِّنۢ بَعْدِ مَآ أَرَىٰكُم مَّا تُحِبُّونَ مِنكُم مَّن يُرِيدُ ٱلدُّنْيَا وَمِنكُم مَّن يُرِيدُ ٱلْءَاخِرَةَ ثُمَّ صَرَفَكُمْ عَنْهُمْ لِيَبْتَلِيَكُمْ وَلَقَدْ عَفَا عَنكُمْ وَٱللَّهُ ذُو فَضْلٍ عَلَى ٱلْمُؤْمِنِينَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@cdxlvi{إِذْ تُصْعِدُونَ وَلَا تَلْوُۥنَ عَلَىٰٓ أَحَدٍ وَٱلرَّسُولُ يَدْعُوكُمْ فِىٓ أُخْرَىٰكُمْ فَأَثَٰبَكُمْ غَمًّۢا بِغَمٍّ لِّكَيْلَا تَحْزَنُوا۟ عَلَىٰ مَا فَاتَكُمْ وَلَا مَآ أَصَٰبَكُمْ وَٱللَّهُ خَبِيرٌۢ بِمَا تَعْمَلُونَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@cdxlvii{ثُمَّ أَنزَلَ عَلَيْكُم مِّنۢ بَعْدِ ٱلْغَمِّ أَمَنَةً نُّعَاسًا يَغْشَىٰ طَآئِفَةً مِّنكُمْ وَطَآئِفَةٌ قَدْ أَهَمَّتْهُمْ أَنفُسُهُمْ يَظُنُّونَ بِٱللَّهِ غَيْرَ ٱلْحَقِّ ظَنَّ ٱلْجَٰهِلِيَّةِ يَقُولُونَ هَل لَّنَا مِنَ ٱلْأَمْرِ مِن شَىْءٍ قُلْ إِنَّ ٱلْأَمْرَ كُلَّهُۥ لِلَّهِ يُخْفُونَ فِىٓ أَنفُسِهِم مَّا لَا يُبْدُونَ لَكَ يَقُولُونَ لَوْ كَانَ لَنَا مِنَ ٱلْأَمْرِ شَىْءٌ مَّا قُتِلْنَا هَٰهُنَا قُل لَّوْ كُنتُمْ فِى بُيُوتِكُمْ لَبَرَزَ ٱلَّذِينَ كُتِبَ عَلَيْهِمُ ٱلْقَتْلُ إِلَىٰ مَضَاجِعِهِمْ وَلِيَبْتَلِىَ ٱللَّهُ مَا فِى صُدُورِكُمْ وَلِيُمَحِّصَ مَا فِى قُلُوبِكُمْ وَٱللَّهُ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@cdxlviii{إِنَّ ٱلَّذِينَ تَوَلَّوْا۟ مِنكُمْ يَوْمَ ٱلْتَقَى ٱلْجَمْعَانِ إِنَّمَا ٱسْتَزَلَّهُمُ ٱلشَّيْطَٰنُ بِبَعْضِ مَا كَسَبُوا۟ وَلَقَدْ عَفَا ٱللَّهُ عَنْهُمْ إِنَّ ٱللَّهَ غَفُورٌ حَلِيمٌ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@cdxlix{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَكُونُوا۟ كَٱلَّذِينَ كَفَرُوا۟ وَقَالُوا۟ لِإِخْوَٰنِهِمْ إِذَا ضَرَبُوا۟ فِى ٱلْأَرْضِ أَوْ كَانُوا۟ غُزًّى لَّوْ كَانُوا۟ عِندَنَا مَا مَاتُوا۟ وَمَا قُتِلُوا۟ لِيَجْعَلَ ٱللَّهُ ذَٰلِكَ حَسْرَةً فِى قُلُوبِهِمْ وَٱللَّهُ يُحْىِۦ وَيُمِيتُ وَٱللَّهُ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@cdl{وَلَئِن قُتِلْتُمْ فِى سَبِيلِ ٱللَّهِ أَوْ مُتُّمْ لَمَغْفِرَةٌ مِّنَ ٱللَّهِ وَرَحْمَةٌ خَيْرٌ مِّمَّا يَجْمَعُونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@cdli{وَلَئِن مُّتُّمْ أَوْ قُتِلْتُمْ لَإِلَى ٱللَّهِ تُحْشَرُونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@cdlii{فَبِمَا رَحْمَةٍ مِّنَ ٱللَّهِ لِنتَ لَهُمْ وَلَوْ كُنتَ فَظًّا غَلِيظَ ٱلْقَلْبِ لَٱنفَضُّوا۟ مِنْ حَوْلِكَ فَٱعْفُ عَنْهُمْ وَٱسْتَغْفِرْ لَهُمْ وَشَاوِرْهُمْ فِى ٱلْأَمْرِ فَإِذَا عَزَمْتَ فَتَوَكَّلْ عَلَى ٱللَّهِ إِنَّ ٱللَّهَ يُحِبُّ ٱلْمُتَوَكِّلِينَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@cdliii{إِن يَنصُرْكُمُ ٱللَّهُ فَلَا غَالِبَ لَكُمْ وَإِن يَخْذُلْكُمْ فَمَن ذَا ٱلَّذِى يَنصُرُكُم مِّنۢ بَعْدِهِۦ وَعَلَى ٱللَّهِ فَلْيَتَوَكَّلِ ٱلْمُؤْمِنُونَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@cdliv{وَمَا كَانَ لِنَبِىٍّ أَن يَغُلَّ وَمَن يَغْلُلْ يَأْتِ بِمَا غَلَّ يَوْمَ ٱلْقِيَٰمَةِ ثُمَّ تُوَفَّىٰ كُلُّ نَفْسٍ مَّا كَسَبَتْ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@cdlv{أَفَمَنِ ٱتَّبَعَ رِضْوَٰنَ ٱللَّهِ كَمَنۢ بَآءَ بِسَخَطٍ مِّنَ ٱللَّهِ وَمَأْوَىٰهُ جَهَنَّمُ وَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@cdlvi{هُمْ دَرَجَٰتٌ عِندَ ٱللَّهِ وَٱللَّهُ بَصِيرٌۢ بِمَا يَعْمَلُونَ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@cdlvii{لَقَدْ مَنَّ ٱللَّهُ عَلَى ٱلْمُؤْمِنِينَ إِذْ بَعَثَ فِيهِمْ رَسُولًا مِّنْ أَنفُسِهِمْ يَتْلُوا۟ عَلَيْهِمْ ءَايَٰتِهِۦ وَيُزَكِّيهِمْ وَيُعَلِّمُهُمُ ٱلْكِتَٰبَ وَٱلْحِكْمَةَ وَإِن كَانُوا۟ مِن قَبْلُ لَفِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@cdlviii{أَوَلَمَّآ أَصَٰبَتْكُم مُّصِيبَةٌ قَدْ أَصَبْتُم مِّثْلَيْهَا قُلْتُمْ أَنَّىٰ هَٰذَا قُلْ هُوَ مِنْ عِندِ أَنفُسِكُمْ إِنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@cdlix{وَمَآ أَصَٰبَكُمْ يَوْمَ ٱلْتَقَى ٱلْجَمْعَانِ فَبِإِذْنِ ٱللَّهِ وَلِيَعْلَمَ ٱلْمُؤْمِنِينَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@cdlx{وَلِيَعْلَمَ ٱلَّذِينَ نَافَقُوا۟ وَقِيلَ لَهُمْ تَعَالَوْا۟ قَٰتِلُوا۟ فِى سَبِيلِ ٱللَّهِ أَوِ ٱدْفَعُوا۟ قَالُوا۟ لَوْ نَعْلَمُ قِتَالًا لَّٱتَّبَعْنَٰكُمْ هُمْ لِلْكُفْرِ يَوْمَئِذٍ أَقْرَبُ مِنْهُمْ لِلْإِيمَٰنِ يَقُولُونَ بِأَفْوَٰهِهِم مَّا لَيْسَ فِى قُلُوبِهِمْ وَٱللَّهُ أَعْلَمُ بِمَا يَكْتُمُونَ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@cdlxi{ٱلَّذِينَ قَالُوا۟ لِإِخْوَٰنِهِمْ وَقَعَدُوا۟ لَوْ أَطَاعُونَا مَا قُتِلُوا۟ قُلْ فَٱدْرَءُوا۟ عَنْ أَنفُسِكُمُ ٱلْمَوْتَ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@cdlxii{وَلَا تَحْسَبَنَّ ٱلَّذِينَ قُتِلُوا۟ فِى سَبِيلِ ٱللَّهِ أَمْوَٰتًۢا بَلْ أَحْيَآءٌ عِندَ رَبِّهِمْ يُرْزَقُونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@cdlxiii{فَرِحِينَ بِمَآ ءَاتَىٰهُمُ ٱللَّهُ مِن فَضْلِهِۦ وَيَسْتَبْشِرُونَ بِٱلَّذِينَ لَمْ يَلْحَقُوا۟ بِهِم مِّنْ خَلْفِهِمْ أَلَّا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@cdlxiv{يَسْتَبْشِرُونَ بِنِعْمَةٍ مِّنَ ٱللَّهِ وَفَضْلٍ وَأَنَّ ٱللَّهَ لَا يُضِيعُ أَجْرَ ٱلْمُؤْمِنِينَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@cdlxv{ٱلَّذِينَ ٱسْتَجَابُوا۟ لِلَّهِ وَٱلرَّسُولِ مِنۢ بَعْدِ مَآ أَصَابَهُمُ ٱلْقَرْحُ لِلَّذِينَ أَحْسَنُوا۟ مِنْهُمْ وَٱتَّقَوْا۟ أَجْرٌ عَظِيمٌ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@cdlxvi{ٱلَّذِينَ قَالَ لَهُمُ ٱلنَّاسُ إِنَّ ٱلنَّاسَ قَدْ جَمَعُوا۟ لَكُمْ فَٱخْشَوْهُمْ فَزَادَهُمْ إِيمَٰنًا وَقَالُوا۟ حَسْبُنَا ٱللَّهُ وَنِعْمَ ٱلْوَكِيلُ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@cdlxvii{فَٱنقَلَبُوا۟ بِنِعْمَةٍ مِّنَ ٱللَّهِ وَفَضْلٍ لَّمْ يَمْسَسْهُمْ سُوٓءٌ وَٱتَّبَعُوا۟ رِضْوَٰنَ ٱللَّهِ وَٱللَّهُ ذُو فَضْلٍ عَظِيمٍ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@cdlxviii{إِنَّمَا ذَٰلِكُمُ ٱلشَّيْطَٰنُ يُخَوِّفُ أَوْلِيَآءَهُۥ فَلَا تَخَافُوهُمْ وَخَافُونِ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@cdlxix{وَلَا يَحْزُنكَ ٱلَّذِينَ يُسَٰرِعُونَ فِى ٱلْكُفْرِ إِنَّهُمْ لَن يَضُرُّوا۟ ٱللَّهَ شَيْـًٔا يُرِيدُ ٱللَّهُ أَلَّا يَجْعَلَ لَهُمْ حَظًّا فِى ٱلْءَاخِرَةِ وَلَهُمْ عَذَابٌ عَظِيمٌ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@cdlxx{إِنَّ ٱلَّذِينَ ٱشْتَرَوُا۟ ٱلْكُفْرَ بِٱلْإِيمَٰنِ لَن يَضُرُّوا۟ ٱللَّهَ شَيْـًٔا وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@cdlxxi{وَلَا يَحْسَبَنَّ ٱلَّذِينَ كَفَرُوٓا۟ أَنَّمَا نُمْلِى لَهُمْ خَيْرٌ لِّأَنفُسِهِمْ إِنَّمَا نُمْلِى لَهُمْ لِيَزْدَادُوٓا۟ إِثْمًا وَلَهُمْ عَذَابٌ مُّهِينٌ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@cdlxxii{مَّا كَانَ ٱللَّهُ لِيَذَرَ ٱلْمُؤْمِنِينَ عَلَىٰ مَآ أَنتُمْ عَلَيْهِ حَتَّىٰ يَمِيزَ ٱلْخَبِيثَ مِنَ ٱلطَّيِّبِ وَمَا كَانَ ٱللَّهُ لِيُطْلِعَكُمْ عَلَى ٱلْغَيْبِ وَلَٰكِنَّ ٱللَّهَ يَجْتَبِى مِن رُّسُلِهِۦ مَن يَشَآءُ فَـَٔامِنُوا۟ بِٱللَّهِ وَرُسُلِهِۦ وَإِن تُؤْمِنُوا۟ وَتَتَّقُوا۟ فَلَكُمْ أَجْرٌ عَظِيمٌ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@cdlxxiii{وَلَا يَحْسَبَنَّ ٱلَّذِينَ يَبْخَلُونَ بِمَآ ءَاتَىٰهُمُ ٱللَّهُ مِن فَضْلِهِۦ هُوَ خَيْرًا لَّهُم بَلْ هُوَ شَرٌّ لَّهُمْ سَيُطَوَّقُونَ مَا بَخِلُوا۟ بِهِۦ يَوْمَ ٱلْقِيَٰمَةِ وَلِلَّهِ مِيرَٰثُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱللَّهُ بِمَا تَعْمَلُونَ خَبِيرٌ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@cdlxxiv{لَّقَدْ سَمِعَ ٱللَّهُ قَوْلَ ٱلَّذِينَ قَالُوٓا۟ إِنَّ ٱللَّهَ فَقِيرٌ وَنَحْنُ أَغْنِيَآءُ سَنَكْتُبُ مَا قَالُوا۟ وَقَتْلَهُمُ ٱلْأَنۢبِيَآءَ بِغَيْرِ حَقٍّ وَنَقُولُ ذُوقُوا۟ عَذَابَ ٱلْحَرِيقِ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@cdlxxv{ذَٰلِكَ بِمَا قَدَّمَتْ أَيْدِيكُمْ وَأَنَّ ٱللَّهَ لَيْسَ بِظَلَّامٍ لِّلْعَبِيدِ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@cdlxxvi{ٱلَّذِينَ قَالُوٓا۟ إِنَّ ٱللَّهَ عَهِدَ إِلَيْنَآ أَلَّا نُؤْمِنَ لِرَسُولٍ حَتَّىٰ يَأْتِيَنَا بِقُرْبَانٍ تَأْكُلُهُ ٱلنَّارُ قُلْ قَدْ جَآءَكُمْ رُسُلٌ مِّن قَبْلِى بِٱلْبَيِّنَٰتِ وَبِٱلَّذِى قُلْتُمْ فَلِمَ قَتَلْتُمُوهُمْ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@cdlxxvii{فَإِن كَذَّبُوكَ فَقَدْ كُذِّبَ رُسُلٌ مِّن قَبْلِكَ جَآءُو بِٱلْبَيِّنَٰتِ وَٱلزُّبُرِ وَٱلْكِتَٰبِ ٱلْمُنِيرِ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@cdlxxviii{كُلُّ نَفْسٍ ذَآئِقَةُ ٱلْمَوْتِ وَإِنَّمَا تُوَفَّوْنَ أُجُورَكُمْ يَوْمَ ٱلْقِيَٰمَةِ فَمَن زُحْزِحَ عَنِ ٱلنَّارِ وَأُدْخِلَ ٱلْجَنَّةَ فَقَدْ فَازَ وَمَا ٱلْحَيَوٰةُ ٱلدُّنْيَآ إِلَّا مَتَٰعُ ٱلْغُرُورِ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@cdlxxix{لَتُبْلَوُنَّ فِىٓ أَمْوَٰلِكُمْ وَأَنفُسِكُمْ وَلَتَسْمَعُنَّ مِنَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ مِن قَبْلِكُمْ وَمِنَ ٱلَّذِينَ أَشْرَكُوٓا۟ أَذًى كَثِيرًا وَإِن تَصْبِرُوا۟ وَتَتَّقُوا۟ فَإِنَّ ذَٰلِكَ مِنْ عَزْمِ ٱلْأُمُورِ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@cdlxxx{وَإِذْ أَخَذَ ٱللَّهُ مِيثَٰقَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ لَتُبَيِّنُنَّهُۥ لِلنَّاسِ وَلَا تَكْتُمُونَهُۥ فَنَبَذُوهُ وَرَآءَ ظُهُورِهِمْ وَٱشْتَرَوْا۟ بِهِۦ ثَمَنًا قَلِيلًا فَبِئْسَ مَا يَشْتَرُونَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@cdlxxxi{لَا تَحْسَبَنَّ ٱلَّذِينَ يَفْرَحُونَ بِمَآ أَتَوا۟ وَّيُحِبُّونَ أَن يُحْمَدُوا۟ بِمَا لَمْ يَفْعَلُوا۟ فَلَا تَحْسَبَنَّهُم بِمَفَازَةٍ مِّنَ ٱلْعَذَابِ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@cdlxxxii{وَلِلَّهِ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@cdlxxxiii{إِنَّ فِى خَلْقِ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱخْتِلَٰفِ ٱلَّيْلِ وَٱلنَّهَارِ لَءَايَٰتٍ لِّأُو۟لِى ٱلْأَلْبَٰبِ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@cdlxxxiv{ٱلَّذِينَ يَذْكُرُونَ ٱللَّهَ قِيَٰمًا وَقُعُودًا وَعَلَىٰ جُنُوبِهِمْ وَيَتَفَكَّرُونَ فِى خَلْقِ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ رَبَّنَا مَا خَلَقْتَ هَٰذَا بَٰطِلًا سُبْحَٰنَكَ فَقِنَا عَذَابَ ٱلنَّارِ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@cdlxxxv{رَبَّنَآ إِنَّكَ مَن تُدْخِلِ ٱلنَّارَ فَقَدْ أَخْزَيْتَهُۥ وَمَا لِلظَّٰلِمِينَ مِنْ أَنصَارٍ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@cdlxxxvi{رَّبَّنَآ إِنَّنَا سَمِعْنَا مُنَادِيًا يُنَادِى لِلْإِيمَٰنِ أَنْ ءَامِنُوا۟ بِرَبِّكُمْ فَـَٔامَنَّا رَبَّنَا فَٱغْفِرْ لَنَا ذُنُوبَنَا وَكَفِّرْ عَنَّا سَيِّـَٔاتِنَا وَتَوَفَّنَا مَعَ ٱلْأَبْرَارِ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@cdlxxxvii{رَبَّنَا وَءَاتِنَا مَا وَعَدتَّنَا عَلَىٰ رُسُلِكَ وَلَا تُخْزِنَا يَوْمَ ٱلْقِيَٰمَةِ إِنَّكَ لَا تُخْلِفُ ٱلْمِيعَادَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@cdlxxxviii{فَٱسْتَجَابَ لَهُمْ رَبُّهُمْ أَنِّى لَآ أُضِيعُ عَمَلَ عَٰمِلٍ مِّنكُم مِّن ذَكَرٍ أَوْ أُنثَىٰ بَعْضُكُم مِّنۢ بَعْضٍ فَٱلَّذِينَ هَاجَرُوا۟ وَأُخْرِجُوا۟ مِن دِيَٰرِهِمْ وَأُوذُوا۟ فِى سَبِيلِى وَقَٰتَلُوا۟ وَقُتِلُوا۟ لَأُكَفِّرَنَّ عَنْهُمْ سَيِّـَٔاتِهِمْ وَلَأُدْخِلَنَّهُمْ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ ثَوَابًا مِّنْ عِندِ ٱللَّهِ وَٱللَّهُ عِندَهُۥ حُسْنُ ٱلثَّوَابِ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@cdlxxxix{لَا يَغُرَّنَّكَ تَقَلُّبُ ٱلَّذِينَ كَفَرُوا۟ فِى ٱلْبِلَٰدِ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@cdxc{مَتَٰعٌ قَلِيلٌ ثُمَّ مَأْوَىٰهُمْ جَهَنَّمُ وَبِئْسَ ٱلْمِهَادُ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@cdxci{لَٰكِنِ ٱلَّذِينَ ٱتَّقَوْا۟ رَبَّهُمْ لَهُمْ جَنَّٰتٌ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا نُزُلًا مِّنْ عِندِ ٱللَّهِ وَمَا عِندَ ٱللَّهِ خَيْرٌ لِّلْأَبْرَارِ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@cdxcii{وَإِنَّ مِنْ أَهْلِ ٱلْكِتَٰبِ لَمَن يُؤْمِنُ بِٱللَّهِ وَمَآ أُنزِلَ إِلَيْكُمْ وَمَآ أُنزِلَ إِلَيْهِمْ خَٰشِعِينَ لِلَّهِ لَا يَشْتَرُونَ بِـَٔايَٰتِ ٱللَّهِ ثَمَنًا قَلِيلًا أُو۟لَٰٓئِكَ لَهُمْ أَجْرُهُمْ عِندَ رَبِّهِمْ إِنَّ ٱللَّهَ سَرِيعُ ٱلْحِسَابِ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@cdxciii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱصْبِرُوا۟ وَصَابِرُوا۟ وَرَابِطُوا۟ وَٱتَّقُوا۟ ٱللَّهَ لَعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@cdxciv{\basmalah يَٰٓأَيُّهَا ٱلنَّاسُ ٱتَّقُوا۟ رَبَّكُمُ ٱلَّذِى خَلَقَكُم مِّن نَّفْسٍ وَٰحِدَةٍ وَخَلَقَ مِنْهَا زَوْجَهَا وَبَثَّ مِنْهُمَا رِجَالًا كَثِيرًا وَنِسَآءً وَٱتَّقُوا۟ ٱللَّهَ ٱلَّذِى تَسَآءَلُونَ بِهِۦ وَٱلْأَرْحَامَ إِنَّ ٱللَّهَ كَانَ عَلَيْكُمْ رَقِيبًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@cdxcv{وَءَاتُوا۟ ٱلْيَتَٰمَىٰٓ أَمْوَٰلَهُمْ وَلَا تَتَبَدَّلُوا۟ ٱلْخَبِيثَ بِٱلطَّيِّبِ وَلَا تَأْكُلُوٓا۟ أَمْوَٰلَهُمْ إِلَىٰٓ أَمْوَٰلِكُمْ إِنَّهُۥ كَانَ حُوبًا كَبِيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@cdxcvi{وَإِنْ خِفْتُمْ أَلَّا تُقْسِطُوا۟ فِى ٱلْيَتَٰمَىٰ فَٱنكِحُوا۟ مَا طَابَ لَكُم مِّنَ ٱلنِّسَآءِ مَثْنَىٰ وَثُلَٰثَ وَرُبَٰعَ فَإِنْ خِفْتُمْ أَلَّا تَعْدِلُوا۟ فَوَٰحِدَةً أَوْ مَا مَلَكَتْ أَيْمَٰنُكُمْ ذَٰلِكَ أَدْنَىٰٓ أَلَّا تَعُولُوا۟\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@cdxcvii{وَءَاتُوا۟ ٱلنِّسَآءَ صَدُقَٰتِهِنَّ نِحْلَةً فَإِن طِبْنَ لَكُمْ عَن شَىْءٍ مِّنْهُ نَفْسًا فَكُلُوهُ هَنِيٓـًٔا مَّرِيٓـًٔا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@cdxcviii{وَلَا تُؤْتُوا۟ ٱلسُّفَهَآءَ أَمْوَٰلَكُمُ ٱلَّتِى جَعَلَ ٱللَّهُ لَكُمْ قِيَٰمًا وَٱرْزُقُوهُمْ فِيهَا وَٱكْسُوهُمْ وَقُولُوا۟ لَهُمْ قَوْلًا مَّعْرُوفًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@cdxcix{وَٱبْتَلُوا۟ ٱلْيَتَٰمَىٰ حَتَّىٰٓ إِذَا بَلَغُوا۟ ٱلنِّكَاحَ فَإِنْ ءَانَسْتُم مِّنْهُمْ رُشْدًا فَٱدْفَعُوٓا۟ إِلَيْهِمْ أَمْوَٰلَهُمْ وَلَا تَأْكُلُوهَآ إِسْرَافًا وَبِدَارًا أَن يَكْبَرُوا۟ وَمَن كَانَ غَنِيًّا فَلْيَسْتَعْفِفْ وَمَن كَانَ فَقِيرًا فَلْيَأْكُلْ بِٱلْمَعْرُوفِ فَإِذَا دَفَعْتُمْ إِلَيْهِمْ أَمْوَٰلَهُمْ فَأَشْهِدُوا۟ عَلَيْهِمْ وَكَفَىٰ بِٱللَّهِ حَسِيبًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@d{لِّلرِّجَالِ نَصِيبٌ مِّمَّا تَرَكَ ٱلْوَٰلِدَانِ وَٱلْأَقْرَبُونَ وَلِلنِّسَآءِ نَصِيبٌ مِّمَّا تَرَكَ ٱلْوَٰلِدَانِ وَٱلْأَقْرَبُونَ مِمَّا قَلَّ مِنْهُ أَوْ كَثُرَ نَصِيبًا مَّفْرُوضًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@di{وَإِذَا حَضَرَ ٱلْقِسْمَةَ أُو۟لُوا۟ ٱلْقُرْبَىٰ وَٱلْيَتَٰمَىٰ وَٱلْمَسَٰكِينُ فَٱرْزُقُوهُم مِّنْهُ وَقُولُوا۟ لَهُمْ قَوْلًا مَّعْرُوفًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@dii{وَلْيَخْشَ ٱلَّذِينَ لَوْ تَرَكُوا۟ مِنْ خَلْفِهِمْ ذُرِّيَّةً ضِعَٰفًا خَافُوا۟ عَلَيْهِمْ فَلْيَتَّقُوا۟ ٱللَّهَ وَلْيَقُولُوا۟ قَوْلًا سَدِيدًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@diii{إِنَّ ٱلَّذِينَ يَأْكُلُونَ أَمْوَٰلَ ٱلْيَتَٰمَىٰ ظُلْمًا إِنَّمَا يَأْكُلُونَ فِى بُطُونِهِمْ نَارًا وَسَيَصْلَوْنَ سَعِيرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@div{يُوصِيكُمُ ٱللَّهُ فِىٓ أَوْلَٰدِكُمْ لِلذَّكَرِ مِثْلُ حَظِّ ٱلْأُنثَيَيْنِ فَإِن كُنَّ نِسَآءً فَوْقَ ٱثْنَتَيْنِ فَلَهُنَّ ثُلُثَا مَا تَرَكَ وَإِن كَانَتْ وَٰحِدَةً فَلَهَا ٱلنِّصْفُ وَلِأَبَوَيْهِ لِكُلِّ وَٰحِدٍ مِّنْهُمَا ٱلسُّدُسُ مِمَّا تَرَكَ إِن كَانَ لَهُۥ وَلَدٌ فَإِن لَّمْ يَكُن لَّهُۥ وَلَدٌ وَوَرِثَهُۥٓ أَبَوَاهُ فَلِأُمِّهِ ٱلثُّلُثُ فَإِن كَانَ لَهُۥٓ إِخْوَةٌ فَلِأُمِّهِ ٱلسُّدُسُ مِنۢ بَعْدِ وَصِيَّةٍ يُوصِى بِهَآ أَوْ دَيْنٍ ءَابَآؤُكُمْ وَأَبْنَآؤُكُمْ لَا تَدْرُونَ أَيُّهُمْ أَقْرَبُ لَكُمْ نَفْعًا فَرِيضَةً مِّنَ ٱللَّهِ إِنَّ ٱللَّهَ كَانَ عَلِيمًا حَكِيمًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@dv{وَلَكُمْ نِصْفُ مَا تَرَكَ أَزْوَٰجُكُمْ إِن لَّمْ يَكُن لَّهُنَّ وَلَدٌ فَإِن كَانَ لَهُنَّ وَلَدٌ فَلَكُمُ ٱلرُّبُعُ مِمَّا تَرَكْنَ مِنۢ بَعْدِ وَصِيَّةٍ يُوصِينَ بِهَآ أَوْ دَيْنٍ وَلَهُنَّ ٱلرُّبُعُ مِمَّا تَرَكْتُمْ إِن لَّمْ يَكُن لَّكُمْ وَلَدٌ فَإِن كَانَ لَكُمْ وَلَدٌ فَلَهُنَّ ٱلثُّمُنُ مِمَّا تَرَكْتُم مِّنۢ بَعْدِ وَصِيَّةٍ تُوصُونَ بِهَآ أَوْ دَيْنٍ وَإِن كَانَ رَجُلٌ يُورَثُ كَلَٰلَةً أَوِ ٱمْرَأَةٌ وَلَهُۥٓ أَخٌ أَوْ أُخْتٌ فَلِكُلِّ وَٰحِدٍ مِّنْهُمَا ٱلسُّدُسُ فَإِن كَانُوٓا۟ أَكْثَرَ مِن ذَٰلِكَ فَهُمْ شُرَكَآءُ فِى ٱلثُّلُثِ مِنۢ بَعْدِ وَصِيَّةٍ يُوصَىٰ بِهَآ أَوْ دَيْنٍ غَيْرَ مُضَآرٍّ وَصِيَّةً مِّنَ ٱللَّهِ وَٱللَّهُ عَلِيمٌ حَلِيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@dvi{تِلْكَ حُدُودُ ٱللَّهِ وَمَن يُطِعِ ٱللَّهَ وَرَسُولَهُۥ يُدْخِلْهُ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا وَذَٰلِكَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@dvii{وَمَن يَعْصِ ٱللَّهَ وَرَسُولَهُۥ وَيَتَعَدَّ حُدُودَهُۥ يُدْخِلْهُ نَارًا خَٰلِدًا فِيهَا وَلَهُۥ عَذَابٌ مُّهِينٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@dviii{وَٱلَّٰتِى يَأْتِينَ ٱلْفَٰحِشَةَ مِن نِّسَآئِكُمْ فَٱسْتَشْهِدُوا۟ عَلَيْهِنَّ أَرْبَعَةً مِّنكُمْ فَإِن شَهِدُوا۟ فَأَمْسِكُوهُنَّ فِى ٱلْبُيُوتِ حَتَّىٰ يَتَوَفَّىٰهُنَّ ٱلْمَوْتُ أَوْ يَجْعَلَ ٱللَّهُ لَهُنَّ سَبِيلًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@dix{وَٱلَّذَانِ يَأْتِيَٰنِهَا مِنكُمْ فَـَٔاذُوهُمَا فَإِن تَابَا وَأَصْلَحَا فَأَعْرِضُوا۟ عَنْهُمَآ إِنَّ ٱللَّهَ كَانَ تَوَّابًا رَّحِيمًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@dx{إِنَّمَا ٱلتَّوْبَةُ عَلَى ٱللَّهِ لِلَّذِينَ يَعْمَلُونَ ٱلسُّوٓءَ بِجَهَٰلَةٍ ثُمَّ يَتُوبُونَ مِن قَرِيبٍ فَأُو۟لَٰٓئِكَ يَتُوبُ ٱللَّهُ عَلَيْهِمْ وَكَانَ ٱللَّهُ عَلِيمًا حَكِيمًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@dxi{وَلَيْسَتِ ٱلتَّوْبَةُ لِلَّذِينَ يَعْمَلُونَ ٱلسَّيِّـَٔاتِ حَتَّىٰٓ إِذَا حَضَرَ أَحَدَهُمُ ٱلْمَوْتُ قَالَ إِنِّى تُبْتُ ٱلْـَٰٔنَ وَلَا ٱلَّذِينَ يَمُوتُونَ وَهُمْ كُفَّارٌ أُو۟لَٰٓئِكَ أَعْتَدْنَا لَهُمْ عَذَابًا أَلِيمًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@dxii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا يَحِلُّ لَكُمْ أَن تَرِثُوا۟ ٱلنِّسَآءَ كَرْهًا وَلَا تَعْضُلُوهُنَّ لِتَذْهَبُوا۟ بِبَعْضِ مَآ ءَاتَيْتُمُوهُنَّ إِلَّآ أَن يَأْتِينَ بِفَٰحِشَةٍ مُّبَيِّنَةٍ وَعَاشِرُوهُنَّ بِٱلْمَعْرُوفِ فَإِن كَرِهْتُمُوهُنَّ فَعَسَىٰٓ أَن تَكْرَهُوا۟ شَيْـًٔا وَيَجْعَلَ ٱللَّهُ فِيهِ خَيْرًا كَثِيرًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@dxiii{وَإِنْ أَرَدتُّمُ ٱسْتِبْدَالَ زَوْجٍ مَّكَانَ زَوْجٍ وَءَاتَيْتُمْ إِحْدَىٰهُنَّ قِنطَارًا فَلَا تَأْخُذُوا۟ مِنْهُ شَيْـًٔا أَتَأْخُذُونَهُۥ بُهْتَٰنًا وَإِثْمًا مُّبِينًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@dxiv{وَكَيْفَ تَأْخُذُونَهُۥ وَقَدْ أَفْضَىٰ بَعْضُكُمْ إِلَىٰ بَعْضٍ وَأَخَذْنَ مِنكُم مِّيثَٰقًا غَلِيظًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@dxv{وَلَا تَنكِحُوا۟ مَا نَكَحَ ءَابَآؤُكُم مِّنَ ٱلنِّسَآءِ إِلَّا مَا قَدْ سَلَفَ إِنَّهُۥ كَانَ فَٰحِشَةً وَمَقْتًا وَسَآءَ سَبِيلًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@dxvi{حُرِّمَتْ عَلَيْكُمْ أُمَّهَٰتُكُمْ وَبَنَاتُكُمْ وَأَخَوَٰتُكُمْ وَعَمَّٰتُكُمْ وَخَٰلَٰتُكُمْ وَبَنَاتُ ٱلْأَخِ وَبَنَاتُ ٱلْأُخْتِ وَأُمَّهَٰتُكُمُ ٱلَّٰتِىٓ أَرْضَعْنَكُمْ وَأَخَوَٰتُكُم مِّنَ ٱلرَّضَٰعَةِ وَأُمَّهَٰتُ نِسَآئِكُمْ وَرَبَٰٓئِبُكُمُ ٱلَّٰتِى فِى حُجُورِكُم مِّن نِّسَآئِكُمُ ٱلَّٰتِى دَخَلْتُم بِهِنَّ فَإِن لَّمْ تَكُونُوا۟ دَخَلْتُم بِهِنَّ فَلَا جُنَاحَ عَلَيْكُمْ وَحَلَٰٓئِلُ أَبْنَآئِكُمُ ٱلَّذِينَ مِنْ أَصْلَٰبِكُمْ وَأَن تَجْمَعُوا۟ بَيْنَ ٱلْأُخْتَيْنِ إِلَّا مَا قَدْ سَلَفَ إِنَّ ٱللَّهَ كَانَ غَفُورًا رَّحِيمًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@dxvii{وَٱلْمُحْصَنَٰتُ مِنَ ٱلنِّسَآءِ إِلَّا مَا مَلَكَتْ أَيْمَٰنُكُمْ كِتَٰبَ ٱللَّهِ عَلَيْكُمْ وَأُحِلَّ لَكُم مَّا وَرَآءَ ذَٰلِكُمْ أَن تَبْتَغُوا۟ بِأَمْوَٰلِكُم مُّحْصِنِينَ غَيْرَ مُسَٰفِحِينَ فَمَا ٱسْتَمْتَعْتُم بِهِۦ مِنْهُنَّ فَـَٔاتُوهُنَّ أُجُورَهُنَّ فَرِيضَةً وَلَا جُنَاحَ عَلَيْكُمْ فِيمَا تَرَٰضَيْتُم بِهِۦ مِنۢ بَعْدِ ٱلْفَرِيضَةِ إِنَّ ٱللَّهَ كَانَ عَلِيمًا حَكِيمًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@dxviii{وَمَن لَّمْ يَسْتَطِعْ مِنكُمْ طَوْلًا أَن يَنكِحَ ٱلْمُحْصَنَٰتِ ٱلْمُؤْمِنَٰتِ فَمِن مَّا مَلَكَتْ أَيْمَٰنُكُم مِّن فَتَيَٰتِكُمُ ٱلْمُؤْمِنَٰتِ وَٱللَّهُ أَعْلَمُ بِإِيمَٰنِكُم بَعْضُكُم مِّنۢ بَعْضٍ فَٱنكِحُوهُنَّ بِإِذْنِ أَهْلِهِنَّ وَءَاتُوهُنَّ أُجُورَهُنَّ بِٱلْمَعْرُوفِ مُحْصَنَٰتٍ غَيْرَ مُسَٰفِحَٰتٍ وَلَا مُتَّخِذَٰتِ أَخْدَانٍ فَإِذَآ أُحْصِنَّ فَإِنْ أَتَيْنَ بِفَٰحِشَةٍ فَعَلَيْهِنَّ نِصْفُ مَا عَلَى ٱلْمُحْصَنَٰتِ مِنَ ٱلْعَذَابِ ذَٰلِكَ لِمَنْ خَشِىَ ٱلْعَنَتَ مِنكُمْ وَأَن تَصْبِرُوا۟ خَيْرٌ لَّكُمْ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@dxix{يُرِيدُ ٱللَّهُ لِيُبَيِّنَ لَكُمْ وَيَهْدِيَكُمْ سُنَنَ ٱلَّذِينَ مِن قَبْلِكُمْ وَيَتُوبَ عَلَيْكُمْ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@dxx{وَٱللَّهُ يُرِيدُ أَن يَتُوبَ عَلَيْكُمْ وَيُرِيدُ ٱلَّذِينَ يَتَّبِعُونَ ٱلشَّهَوَٰتِ أَن تَمِيلُوا۟ مَيْلًا عَظِيمًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@dxxi{يُرِيدُ ٱللَّهُ أَن يُخَفِّفَ عَنكُمْ وَخُلِقَ ٱلْإِنسَٰنُ ضَعِيفًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@dxxii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَأْكُلُوٓا۟ أَمْوَٰلَكُم بَيْنَكُم بِٱلْبَٰطِلِ إِلَّآ أَن تَكُونَ تِجَٰرَةً عَن تَرَاضٍ مِّنكُمْ وَلَا تَقْتُلُوٓا۟ أَنفُسَكُمْ إِنَّ ٱللَّهَ كَانَ بِكُمْ رَحِيمًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@dxxiii{وَمَن يَفْعَلْ ذَٰلِكَ عُدْوَٰنًا وَظُلْمًا فَسَوْفَ نُصْلِيهِ نَارًا وَكَانَ ذَٰلِكَ عَلَى ٱللَّهِ يَسِيرًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@dxxiv{إِن تَجْتَنِبُوا۟ كَبَآئِرَ مَا تُنْهَوْنَ عَنْهُ نُكَفِّرْ عَنكُمْ سَيِّـَٔاتِكُمْ وَنُدْخِلْكُم مُّدْخَلًا كَرِيمًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@dxxv{وَلَا تَتَمَنَّوْا۟ مَا فَضَّلَ ٱللَّهُ بِهِۦ بَعْضَكُمْ عَلَىٰ بَعْضٍ لِّلرِّجَالِ نَصِيبٌ مِّمَّا ٱكْتَسَبُوا۟ وَلِلنِّسَآءِ نَصِيبٌ مِّمَّا ٱكْتَسَبْنَ وَسْـَٔلُوا۟ ٱللَّهَ مِن فَضْلِهِۦٓ إِنَّ ٱللَّهَ كَانَ بِكُلِّ شَىْءٍ عَلِيمًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@dxxvi{وَلِكُلٍّ جَعَلْنَا مَوَٰلِىَ مِمَّا تَرَكَ ٱلْوَٰلِدَانِ وَٱلْأَقْرَبُونَ وَٱلَّذِينَ عَقَدَتْ أَيْمَٰنُكُمْ فَـَٔاتُوهُمْ نَصِيبَهُمْ إِنَّ ٱللَّهَ كَانَ عَلَىٰ كُلِّ شَىْءٍ شَهِيدًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@dxxvii{ٱلرِّجَالُ قَوَّٰمُونَ عَلَى ٱلنِّسَآءِ بِمَا فَضَّلَ ٱللَّهُ بَعْضَهُمْ عَلَىٰ بَعْضٍ وَبِمَآ أَنفَقُوا۟ مِنْ أَمْوَٰلِهِمْ فَٱلصَّٰلِحَٰتُ قَٰنِتَٰتٌ حَٰفِظَٰتٌ لِّلْغَيْبِ بِمَا حَفِظَ ٱللَّهُ وَٱلَّٰتِى تَخَافُونَ نُشُوزَهُنَّ فَعِظُوهُنَّ وَٱهْجُرُوهُنَّ فِى ٱلْمَضَاجِعِ وَٱضْرِبُوهُنَّ فَإِنْ أَطَعْنَكُمْ فَلَا تَبْغُوا۟ عَلَيْهِنَّ سَبِيلًا إِنَّ ٱللَّهَ كَانَ عَلِيًّا كَبِيرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@dxxviii{وَإِنْ خِفْتُمْ شِقَاقَ بَيْنِهِمَا فَٱبْعَثُوا۟ حَكَمًا مِّنْ أَهْلِهِۦ وَحَكَمًا مِّنْ أَهْلِهَآ إِن يُرِيدَآ إِصْلَٰحًا يُوَفِّقِ ٱللَّهُ بَيْنَهُمَآ إِنَّ ٱللَّهَ كَانَ عَلِيمًا خَبِيرًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@dxxix{وَٱعْبُدُوا۟ ٱللَّهَ وَلَا تُشْرِكُوا۟ بِهِۦ شَيْـًٔا وَبِٱلْوَٰلِدَيْنِ إِحْسَٰنًا وَبِذِى ٱلْقُرْبَىٰ وَٱلْيَتَٰمَىٰ وَٱلْمَسَٰكِينِ وَٱلْجَارِ ذِى ٱلْقُرْبَىٰ وَٱلْجَارِ ٱلْجُنُبِ وَٱلصَّاحِبِ بِٱلْجَنۢبِ وَٱبْنِ ٱلسَّبِيلِ وَمَا مَلَكَتْ أَيْمَٰنُكُمْ إِنَّ ٱللَّهَ لَا يُحِبُّ مَن كَانَ مُخْتَالًا فَخُورًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@dxxx{ٱلَّذِينَ يَبْخَلُونَ وَيَأْمُرُونَ ٱلنَّاسَ بِٱلْبُخْلِ وَيَكْتُمُونَ مَآ ءَاتَىٰهُمُ ٱللَّهُ مِن فَضْلِهِۦ وَأَعْتَدْنَا لِلْكَٰفِرِينَ عَذَابًا مُّهِينًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@dxxxi{وَٱلَّذِينَ يُنفِقُونَ أَمْوَٰلَهُمْ رِئَآءَ ٱلنَّاسِ وَلَا يُؤْمِنُونَ بِٱللَّهِ وَلَا بِٱلْيَوْمِ ٱلْءَاخِرِ وَمَن يَكُنِ ٱلشَّيْطَٰنُ لَهُۥ قَرِينًا فَسَآءَ قَرِينًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@dxxxii{وَمَاذَا عَلَيْهِمْ لَوْ ءَامَنُوا۟ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَأَنفَقُوا۟ مِمَّا رَزَقَهُمُ ٱللَّهُ وَكَانَ ٱللَّهُ بِهِمْ عَلِيمًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@dxxxiii{إِنَّ ٱللَّهَ لَا يَظْلِمُ مِثْقَالَ ذَرَّةٍ وَإِن تَكُ حَسَنَةً يُضَٰعِفْهَا وَيُؤْتِ مِن لَّدُنْهُ أَجْرًا عَظِيمًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@dxxxiv{فَكَيْفَ إِذَا جِئْنَا مِن كُلِّ أُمَّةٍۭ بِشَهِيدٍ وَجِئْنَا بِكَ عَلَىٰ هَٰٓؤُلَآءِ شَهِيدًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@dxxxv{يَوْمَئِذٍ يَوَدُّ ٱلَّذِينَ كَفَرُوا۟ وَعَصَوُا۟ ٱلرَّسُولَ لَوْ تُسَوَّىٰ بِهِمُ ٱلْأَرْضُ وَلَا يَكْتُمُونَ ٱللَّهَ حَدِيثًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@dxxxvi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَقْرَبُوا۟ ٱلصَّلَوٰةَ وَأَنتُمْ سُكَٰرَىٰ حَتَّىٰ تَعْلَمُوا۟ مَا تَقُولُونَ وَلَا جُنُبًا إِلَّا عَابِرِى سَبِيلٍ حَتَّىٰ تَغْتَسِلُوا۟ وَإِن كُنتُم مَّرْضَىٰٓ أَوْ عَلَىٰ سَفَرٍ أَوْ جَآءَ أَحَدٌ مِّنكُم مِّنَ ٱلْغَآئِطِ أَوْ لَٰمَسْتُمُ ٱلنِّسَآءَ فَلَمْ تَجِدُوا۟ مَآءً فَتَيَمَّمُوا۟ صَعِيدًا طَيِّبًا فَٱمْسَحُوا۟ بِوُجُوهِكُمْ وَأَيْدِيكُمْ إِنَّ ٱللَّهَ كَانَ عَفُوًّا غَفُورًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@dxxxvii{أَلَمْ تَرَ إِلَى ٱلَّذِينَ أُوتُوا۟ نَصِيبًا مِّنَ ٱلْكِتَٰبِ يَشْتَرُونَ ٱلضَّلَٰلَةَ وَيُرِيدُونَ أَن تَضِلُّوا۟ ٱلسَّبِيلَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@dxxxviii{وَٱللَّهُ أَعْلَمُ بِأَعْدَآئِكُمْ وَكَفَىٰ بِٱللَّهِ وَلِيًّا وَكَفَىٰ بِٱللَّهِ نَصِيرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@dxxxix{مِّنَ ٱلَّذِينَ هَادُوا۟ يُحَرِّفُونَ ٱلْكَلِمَ عَن مَّوَاضِعِهِۦ وَيَقُولُونَ سَمِعْنَا وَعَصَيْنَا وَٱسْمَعْ غَيْرَ مُسْمَعٍ وَرَٰعِنَا لَيًّۢا بِأَلْسِنَتِهِمْ وَطَعْنًا فِى ٱلدِّينِ وَلَوْ أَنَّهُمْ قَالُوا۟ سَمِعْنَا وَأَطَعْنَا وَٱسْمَعْ وَٱنظُرْنَا لَكَانَ خَيْرًا لَّهُمْ وَأَقْوَمَ وَلَٰكِن لَّعَنَهُمُ ٱللَّهُ بِكُفْرِهِمْ فَلَا يُؤْمِنُونَ إِلَّا قَلِيلًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@dxl{يَٰٓأَيُّهَا ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ ءَامِنُوا۟ بِمَا نَزَّلْنَا مُصَدِّقًا لِّمَا مَعَكُم مِّن قَبْلِ أَن نَّطْمِسَ وُجُوهًا فَنَرُدَّهَا عَلَىٰٓ أَدْبَارِهَآ أَوْ نَلْعَنَهُمْ كَمَا لَعَنَّآ أَصْحَٰبَ ٱلسَّبْتِ وَكَانَ أَمْرُ ٱللَّهِ مَفْعُولًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@dxli{إِنَّ ٱللَّهَ لَا يَغْفِرُ أَن يُشْرَكَ بِهِۦ وَيَغْفِرُ مَا دُونَ ذَٰلِكَ لِمَن يَشَآءُ وَمَن يُشْرِكْ بِٱللَّهِ فَقَدِ ٱفْتَرَىٰٓ إِثْمًا عَظِيمًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@dxlii{أَلَمْ تَرَ إِلَى ٱلَّذِينَ يُزَكُّونَ أَنفُسَهُم بَلِ ٱللَّهُ يُزَكِّى مَن يَشَآءُ وَلَا يُظْلَمُونَ فَتِيلًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@dxliii{ٱنظُرْ كَيْفَ يَفْتَرُونَ عَلَى ٱللَّهِ ٱلْكَذِبَ وَكَفَىٰ بِهِۦٓ إِثْمًا مُّبِينًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@dxliv{أَلَمْ تَرَ إِلَى ٱلَّذِينَ أُوتُوا۟ نَصِيبًا مِّنَ ٱلْكِتَٰبِ يُؤْمِنُونَ بِٱلْجِبْتِ وَٱلطَّٰغُوتِ وَيَقُولُونَ لِلَّذِينَ كَفَرُوا۟ هَٰٓؤُلَآءِ أَهْدَىٰ مِنَ ٱلَّذِينَ ءَامَنُوا۟ سَبِيلًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@dxlv{أُو۟لَٰٓئِكَ ٱلَّذِينَ لَعَنَهُمُ ٱللَّهُ وَمَن يَلْعَنِ ٱللَّهُ فَلَن تَجِدَ لَهُۥ نَصِيرًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@dxlvi{أَمْ لَهُمْ نَصِيبٌ مِّنَ ٱلْمُلْكِ فَإِذًا لَّا يُؤْتُونَ ٱلنَّاسَ نَقِيرًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@dxlvii{أَمْ يَحْسُدُونَ ٱلنَّاسَ عَلَىٰ مَآ ءَاتَىٰهُمُ ٱللَّهُ مِن فَضْلِهِۦ فَقَدْ ءَاتَيْنَآ ءَالَ إِبْرَٰهِيمَ ٱلْكِتَٰبَ وَٱلْحِكْمَةَ وَءَاتَيْنَٰهُم مُّلْكًا عَظِيمًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@dxlviii{فَمِنْهُم مَّنْ ءَامَنَ بِهِۦ وَمِنْهُم مَّن صَدَّ عَنْهُ وَكَفَىٰ بِجَهَنَّمَ سَعِيرًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@dxlix{إِنَّ ٱلَّذِينَ كَفَرُوا۟ بِـَٔايَٰتِنَا سَوْفَ نُصْلِيهِمْ نَارًا كُلَّمَا نَضِجَتْ جُلُودُهُم بَدَّلْنَٰهُمْ جُلُودًا غَيْرَهَا لِيَذُوقُوا۟ ٱلْعَذَابَ إِنَّ ٱللَّهَ كَانَ عَزِيزًا حَكِيمًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@dl{وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ سَنُدْخِلُهُمْ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَآ أَبَدًا لَّهُمْ فِيهَآ أَزْوَٰجٌ مُّطَهَّرَةٌ وَنُدْخِلُهُمْ ظِلًّا ظَلِيلًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@dli{إِنَّ ٱللَّهَ يَأْمُرُكُمْ أَن تُؤَدُّوا۟ ٱلْأَمَٰنَٰتِ إِلَىٰٓ أَهْلِهَا وَإِذَا حَكَمْتُم بَيْنَ ٱلنَّاسِ أَن تَحْكُمُوا۟ بِٱلْعَدْلِ إِنَّ ٱللَّهَ نِعِمَّا يَعِظُكُم بِهِۦٓ إِنَّ ٱللَّهَ كَانَ سَمِيعًۢا بَصِيرًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@dlii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ أَطِيعُوا۟ ٱللَّهَ وَأَطِيعُوا۟ ٱلرَّسُولَ وَأُو۟لِى ٱلْأَمْرِ مِنكُمْ فَإِن تَنَٰزَعْتُمْ فِى شَىْءٍ فَرُدُّوهُ إِلَى ٱللَّهِ وَٱلرَّسُولِ إِن كُنتُمْ تُؤْمِنُونَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ ذَٰلِكَ خَيْرٌ وَأَحْسَنُ تَأْوِيلًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@dliii{أَلَمْ تَرَ إِلَى ٱلَّذِينَ يَزْعُمُونَ أَنَّهُمْ ءَامَنُوا۟ بِمَآ أُنزِلَ إِلَيْكَ وَمَآ أُنزِلَ مِن قَبْلِكَ يُرِيدُونَ أَن يَتَحَاكَمُوٓا۟ إِلَى ٱلطَّٰغُوتِ وَقَدْ أُمِرُوٓا۟ أَن يَكْفُرُوا۟ بِهِۦ وَيُرِيدُ ٱلشَّيْطَٰنُ أَن يُضِلَّهُمْ ضَلَٰلًۢا بَعِيدًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@dliv{وَإِذَا قِيلَ لَهُمْ تَعَالَوْا۟ إِلَىٰ مَآ أَنزَلَ ٱللَّهُ وَإِلَى ٱلرَّسُولِ رَأَيْتَ ٱلْمُنَٰفِقِينَ يَصُدُّونَ عَنكَ صُدُودًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@dlv{فَكَيْفَ إِذَآ أَصَٰبَتْهُم مُّصِيبَةٌۢ بِمَا قَدَّمَتْ أَيْدِيهِمْ ثُمَّ جَآءُوكَ يَحْلِفُونَ بِٱللَّهِ إِنْ أَرَدْنَآ إِلَّآ إِحْسَٰنًا وَتَوْفِيقًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@dlvi{أُو۟لَٰٓئِكَ ٱلَّذِينَ يَعْلَمُ ٱللَّهُ مَا فِى قُلُوبِهِمْ فَأَعْرِضْ عَنْهُمْ وَعِظْهُمْ وَقُل لَّهُمْ فِىٓ أَنفُسِهِمْ قَوْلًۢا بَلِيغًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@dlvii{وَمَآ أَرْسَلْنَا مِن رَّسُولٍ إِلَّا لِيُطَاعَ بِإِذْنِ ٱللَّهِ وَلَوْ أَنَّهُمْ إِذ ظَّلَمُوٓا۟ أَنفُسَهُمْ جَآءُوكَ فَٱسْتَغْفَرُوا۟ ٱللَّهَ وَٱسْتَغْفَرَ لَهُمُ ٱلرَّسُولُ لَوَجَدُوا۟ ٱللَّهَ تَوَّابًا رَّحِيمًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@dlviii{فَلَا وَرَبِّكَ لَا يُؤْمِنُونَ حَتَّىٰ يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ ثُمَّ لَا يَجِدُوا۟ فِىٓ أَنفُسِهِمْ حَرَجًا مِّمَّا قَضَيْتَ وَيُسَلِّمُوا۟ تَسْلِيمًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@dlix{وَلَوْ أَنَّا كَتَبْنَا عَلَيْهِمْ أَنِ ٱقْتُلُوٓا۟ أَنفُسَكُمْ أَوِ ٱخْرُجُوا۟ مِن دِيَٰرِكُم مَّا فَعَلُوهُ إِلَّا قَلِيلٌ مِّنْهُمْ وَلَوْ أَنَّهُمْ فَعَلُوا۟ مَا يُوعَظُونَ بِهِۦ لَكَانَ خَيْرًا لَّهُمْ وَأَشَدَّ تَثْبِيتًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@dlx{وَإِذًا لَّءَاتَيْنَٰهُم مِّن لَّدُنَّآ أَجْرًا عَظِيمًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@dlxi{وَلَهَدَيْنَٰهُمْ صِرَٰطًا مُّسْتَقِيمًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@dlxii{وَمَن يُطِعِ ٱللَّهَ وَٱلرَّسُولَ فَأُو۟لَٰٓئِكَ مَعَ ٱلَّذِينَ أَنْعَمَ ٱللَّهُ عَلَيْهِم مِّنَ ٱلنَّبِيِّۦنَ وَٱلصِّدِّيقِينَ وَٱلشُّهَدَآءِ وَٱلصَّٰلِحِينَ وَحَسُنَ أُو۟لَٰٓئِكَ رَفِيقًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@dlxiii{ذَٰلِكَ ٱلْفَضْلُ مِنَ ٱللَّهِ وَكَفَىٰ بِٱللَّهِ عَلِيمًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@dlxiv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ خُذُوا۟ حِذْرَكُمْ فَٱنفِرُوا۟ ثُبَاتٍ أَوِ ٱنفِرُوا۟ جَمِيعًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@dlxv{وَإِنَّ مِنكُمْ لَمَن لَّيُبَطِّئَنَّ فَإِنْ أَصَٰبَتْكُم مُّصِيبَةٌ قَالَ قَدْ أَنْعَمَ ٱللَّهُ عَلَىَّ إِذْ لَمْ أَكُن مَّعَهُمْ شَهِيدًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@dlxvi{وَلَئِنْ أَصَٰبَكُمْ فَضْلٌ مِّنَ ٱللَّهِ لَيَقُولَنَّ كَأَن لَّمْ تَكُنۢ بَيْنَكُمْ وَبَيْنَهُۥ مَوَدَّةٌ يَٰلَيْتَنِى كُنتُ مَعَهُمْ فَأَفُوزَ فَوْزًا عَظِيمًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@dlxvii{فَلْيُقَٰتِلْ فِى سَبِيلِ ٱللَّهِ ٱلَّذِينَ يَشْرُونَ ٱلْحَيَوٰةَ ٱلدُّنْيَا بِٱلْءَاخِرَةِ وَمَن يُقَٰتِلْ فِى سَبِيلِ ٱللَّهِ فَيُقْتَلْ أَوْ يَغْلِبْ فَسَوْفَ نُؤْتِيهِ أَجْرًا عَظِيمًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@dlxviii{وَمَا لَكُمْ لَا تُقَٰتِلُونَ فِى سَبِيلِ ٱللَّهِ وَٱلْمُسْتَضْعَفِينَ مِنَ ٱلرِّجَالِ وَٱلنِّسَآءِ وَٱلْوِلْدَٰنِ ٱلَّذِينَ يَقُولُونَ رَبَّنَآ أَخْرِجْنَا مِنْ هَٰذِهِ ٱلْقَرْيَةِ ٱلظَّالِمِ أَهْلُهَا وَٱجْعَل لَّنَا مِن لَّدُنكَ وَلِيًّا وَٱجْعَل لَّنَا مِن لَّدُنكَ نَصِيرًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@dlxix{ٱلَّذِينَ ءَامَنُوا۟ يُقَٰتِلُونَ فِى سَبِيلِ ٱللَّهِ وَٱلَّذِينَ كَفَرُوا۟ يُقَٰتِلُونَ فِى سَبِيلِ ٱلطَّٰغُوتِ فَقَٰتِلُوٓا۟ أَوْلِيَآءَ ٱلشَّيْطَٰنِ إِنَّ كَيْدَ ٱلشَّيْطَٰنِ كَانَ ضَعِيفًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@dlxx{أَلَمْ تَرَ إِلَى ٱلَّذِينَ قِيلَ لَهُمْ كُفُّوٓا۟ أَيْدِيَكُمْ وَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَءَاتُوا۟ ٱلزَّكَوٰةَ فَلَمَّا كُتِبَ عَلَيْهِمُ ٱلْقِتَالُ إِذَا فَرِيقٌ مِّنْهُمْ يَخْشَوْنَ ٱلنَّاسَ كَخَشْيَةِ ٱللَّهِ أَوْ أَشَدَّ خَشْيَةً وَقَالُوا۟ رَبَّنَا لِمَ كَتَبْتَ عَلَيْنَا ٱلْقِتَالَ لَوْلَآ أَخَّرْتَنَآ إِلَىٰٓ أَجَلٍ قَرِيبٍ قُلْ مَتَٰعُ ٱلدُّنْيَا قَلِيلٌ وَٱلْءَاخِرَةُ خَيْرٌ لِّمَنِ ٱتَّقَىٰ وَلَا تُظْلَمُونَ فَتِيلًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@dlxxi{أَيْنَمَا تَكُونُوا۟ يُدْرِككُّمُ ٱلْمَوْتُ وَلَوْ كُنتُمْ فِى بُرُوجٍ مُّشَيَّدَةٍ وَإِن تُصِبْهُمْ حَسَنَةٌ يَقُولُوا۟ هَٰذِهِۦ مِنْ عِندِ ٱللَّهِ وَإِن تُصِبْهُمْ سَيِّئَةٌ يَقُولُوا۟ هَٰذِهِۦ مِنْ عِندِكَ قُلْ كُلٌّ مِّنْ عِندِ ٱللَّهِ فَمَالِ هَٰٓؤُلَآءِ ٱلْقَوْمِ لَا يَكَادُونَ يَفْقَهُونَ حَدِيثًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@dlxxii{مَّآ أَصَابَكَ مِنْ حَسَنَةٍ فَمِنَ ٱللَّهِ وَمَآ أَصَابَكَ مِن سَيِّئَةٍ فَمِن نَّفْسِكَ وَأَرْسَلْنَٰكَ لِلنَّاسِ رَسُولًا وَكَفَىٰ بِٱللَّهِ شَهِيدًا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@dlxxiii{مَّن يُطِعِ ٱلرَّسُولَ فَقَدْ أَطَاعَ ٱللَّهَ وَمَن تَوَلَّىٰ فَمَآ أَرْسَلْنَٰكَ عَلَيْهِمْ حَفِيظًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@dlxxiv{وَيَقُولُونَ طَاعَةٌ فَإِذَا بَرَزُوا۟ مِنْ عِندِكَ بَيَّتَ طَآئِفَةٌ مِّنْهُمْ غَيْرَ ٱلَّذِى تَقُولُ وَٱللَّهُ يَكْتُبُ مَا يُبَيِّتُونَ فَأَعْرِضْ عَنْهُمْ وَتَوَكَّلْ عَلَى ٱللَّهِ وَكَفَىٰ بِٱللَّهِ وَكِيلًا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@dlxxv{أَفَلَا يَتَدَبَّرُونَ ٱلْقُرْءَانَ وَلَوْ كَانَ مِنْ عِندِ غَيْرِ ٱللَّهِ لَوَجَدُوا۟ فِيهِ ٱخْتِلَٰفًا كَثِيرًا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@dlxxvi{وَإِذَا جَآءَهُمْ أَمْرٌ مِّنَ ٱلْأَمْنِ أَوِ ٱلْخَوْفِ أَذَاعُوا۟ بِهِۦ وَلَوْ رَدُّوهُ إِلَى ٱلرَّسُولِ وَإِلَىٰٓ أُو۟لِى ٱلْأَمْرِ مِنْهُمْ لَعَلِمَهُ ٱلَّذِينَ يَسْتَنۢبِطُونَهُۥ مِنْهُمْ وَلَوْلَا فَضْلُ ٱللَّهِ عَلَيْكُمْ وَرَحْمَتُهُۥ لَٱتَّبَعْتُمُ ٱلشَّيْطَٰنَ إِلَّا قَلِيلًا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@dlxxvii{فَقَٰتِلْ فِى سَبِيلِ ٱللَّهِ لَا تُكَلَّفُ إِلَّا نَفْسَكَ وَحَرِّضِ ٱلْمُؤْمِنِينَ عَسَى ٱللَّهُ أَن يَكُفَّ بَأْسَ ٱلَّذِينَ كَفَرُوا۟ وَٱللَّهُ أَشَدُّ بَأْسًا وَأَشَدُّ تَنكِيلًا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@dlxxviii{مَّن يَشْفَعْ شَفَٰعَةً حَسَنَةً يَكُن لَّهُۥ نَصِيبٌ مِّنْهَا وَمَن يَشْفَعْ شَفَٰعَةً سَيِّئَةً يَكُن لَّهُۥ كِفْلٌ مِّنْهَا وَكَانَ ٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ مُّقِيتًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@dlxxix{وَإِذَا حُيِّيتُم بِتَحِيَّةٍ فَحَيُّوا۟ بِأَحْسَنَ مِنْهَآ أَوْ رُدُّوهَآ إِنَّ ٱللَّهَ كَانَ عَلَىٰ كُلِّ شَىْءٍ حَسِيبًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@dlxxx{ٱللَّهُ لَآ إِلَٰهَ إِلَّا هُوَ لَيَجْمَعَنَّكُمْ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ لَا رَيْبَ فِيهِ وَمَنْ أَصْدَقُ مِنَ ٱللَّهِ حَدِيثًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@dlxxxi{فَمَا لَكُمْ فِى ٱلْمُنَٰفِقِينَ فِئَتَيْنِ وَٱللَّهُ أَرْكَسَهُم بِمَا كَسَبُوٓا۟ أَتُرِيدُونَ أَن تَهْدُوا۟ مَنْ أَضَلَّ ٱللَّهُ وَمَن يُضْلِلِ ٱللَّهُ فَلَن تَجِدَ لَهُۥ سَبِيلًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@dlxxxii{وَدُّوا۟ لَوْ تَكْفُرُونَ كَمَا كَفَرُوا۟ فَتَكُونُونَ سَوَآءً فَلَا تَتَّخِذُوا۟ مِنْهُمْ أَوْلِيَآءَ حَتَّىٰ يُهَاجِرُوا۟ فِى سَبِيلِ ٱللَّهِ فَإِن تَوَلَّوْا۟ فَخُذُوهُمْ وَٱقْتُلُوهُمْ حَيْثُ وَجَدتُّمُوهُمْ وَلَا تَتَّخِذُوا۟ مِنْهُمْ وَلِيًّا وَلَا نَصِيرًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@dlxxxiii{إِلَّا ٱلَّذِينَ يَصِلُونَ إِلَىٰ قَوْمٍۭ بَيْنَكُمْ وَبَيْنَهُم مِّيثَٰقٌ أَوْ جَآءُوكُمْ حَصِرَتْ صُدُورُهُمْ أَن يُقَٰتِلُوكُمْ أَوْ يُقَٰتِلُوا۟ قَوْمَهُمْ وَلَوْ شَآءَ ٱللَّهُ لَسَلَّطَهُمْ عَلَيْكُمْ فَلَقَٰتَلُوكُمْ فَإِنِ ٱعْتَزَلُوكُمْ فَلَمْ يُقَٰتِلُوكُمْ وَأَلْقَوْا۟ إِلَيْكُمُ ٱلسَّلَمَ فَمَا جَعَلَ ٱللَّهُ لَكُمْ عَلَيْهِمْ سَبِيلًا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@dlxxxiv{سَتَجِدُونَ ءَاخَرِينَ يُرِيدُونَ أَن يَأْمَنُوكُمْ وَيَأْمَنُوا۟ قَوْمَهُمْ كُلَّ مَا رُدُّوٓا۟ إِلَى ٱلْفِتْنَةِ أُرْكِسُوا۟ فِيهَا فَإِن لَّمْ يَعْتَزِلُوكُمْ وَيُلْقُوٓا۟ إِلَيْكُمُ ٱلسَّلَمَ وَيَكُفُّوٓا۟ أَيْدِيَهُمْ فَخُذُوهُمْ وَٱقْتُلُوهُمْ حَيْثُ ثَقِفْتُمُوهُمْ وَأُو۟لَٰٓئِكُمْ جَعَلْنَا لَكُمْ عَلَيْهِمْ سُلْطَٰنًا مُّبِينًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@dlxxxv{وَمَا كَانَ لِمُؤْمِنٍ أَن يَقْتُلَ مُؤْمِنًا إِلَّا خَطَـًٔا وَمَن قَتَلَ مُؤْمِنًا خَطَـًٔا فَتَحْرِيرُ رَقَبَةٍ مُّؤْمِنَةٍ وَدِيَةٌ مُّسَلَّمَةٌ إِلَىٰٓ أَهْلِهِۦٓ إِلَّآ أَن يَصَّدَّقُوا۟ فَإِن كَانَ مِن قَوْمٍ عَدُوٍّ لَّكُمْ وَهُوَ مُؤْمِنٌ فَتَحْرِيرُ رَقَبَةٍ مُّؤْمِنَةٍ وَإِن كَانَ مِن قَوْمٍۭ بَيْنَكُمْ وَبَيْنَهُم مِّيثَٰقٌ فَدِيَةٌ مُّسَلَّمَةٌ إِلَىٰٓ أَهْلِهِۦ وَتَحْرِيرُ رَقَبَةٍ مُّؤْمِنَةٍ فَمَن لَّمْ يَجِدْ فَصِيَامُ شَهْرَيْنِ مُتَتَابِعَيْنِ تَوْبَةً مِّنَ ٱللَّهِ وَكَانَ ٱللَّهُ عَلِيمًا حَكِيمًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@dlxxxvi{وَمَن يَقْتُلْ مُؤْمِنًا مُّتَعَمِّدًا فَجَزَآؤُهُۥ جَهَنَّمُ خَٰلِدًا فِيهَا وَغَضِبَ ٱللَّهُ عَلَيْهِ وَلَعَنَهُۥ وَأَعَدَّ لَهُۥ عَذَابًا عَظِيمًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@dlxxxvii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا ضَرَبْتُمْ فِى سَبِيلِ ٱللَّهِ فَتَبَيَّنُوا۟ وَلَا تَقُولُوا۟ لِمَنْ أَلْقَىٰٓ إِلَيْكُمُ ٱلسَّلَٰمَ لَسْتَ مُؤْمِنًا تَبْتَغُونَ عَرَضَ ٱلْحَيَوٰةِ ٱلدُّنْيَا فَعِندَ ٱللَّهِ مَغَانِمُ كَثِيرَةٌ كَذَٰلِكَ كُنتُم مِّن قَبْلُ فَمَنَّ ٱللَّهُ عَلَيْكُمْ فَتَبَيَّنُوٓا۟ إِنَّ ٱللَّهَ كَانَ بِمَا تَعْمَلُونَ خَبِيرًا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@dlxxxviii{لَّا يَسْتَوِى ٱلْقَٰعِدُونَ مِنَ ٱلْمُؤْمِنِينَ غَيْرُ أُو۟لِى ٱلضَّرَرِ وَٱلْمُجَٰهِدُونَ فِى سَبِيلِ ٱللَّهِ بِأَمْوَٰلِهِمْ وَأَنفُسِهِمْ فَضَّلَ ٱللَّهُ ٱلْمُجَٰهِدِينَ بِأَمْوَٰلِهِمْ وَأَنفُسِهِمْ عَلَى ٱلْقَٰعِدِينَ دَرَجَةً وَكُلًّا وَعَدَ ٱللَّهُ ٱلْحُسْنَىٰ وَفَضَّلَ ٱللَّهُ ٱلْمُجَٰهِدِينَ عَلَى ٱلْقَٰعِدِينَ أَجْرًا عَظِيمًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@dlxxxix{دَرَجَٰتٍ مِّنْهُ وَمَغْفِرَةً وَرَحْمَةً وَكَانَ ٱللَّهُ غَفُورًا رَّحِيمًا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@dxc{إِنَّ ٱلَّذِينَ تَوَفَّىٰهُمُ ٱلْمَلَٰٓئِكَةُ ظَالِمِىٓ أَنفُسِهِمْ قَالُوا۟ فِيمَ كُنتُمْ قَالُوا۟ كُنَّا مُسْتَضْعَفِينَ فِى ٱلْأَرْضِ قَالُوٓا۟ أَلَمْ تَكُنْ أَرْضُ ٱللَّهِ وَٰسِعَةً فَتُهَاجِرُوا۟ فِيهَا فَأُو۟لَٰٓئِكَ مَأْوَىٰهُمْ جَهَنَّمُ وَسَآءَتْ مَصِيرًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@dxci{إِلَّا ٱلْمُسْتَضْعَفِينَ مِنَ ٱلرِّجَالِ وَٱلنِّسَآءِ وَٱلْوِلْدَٰنِ لَا يَسْتَطِيعُونَ حِيلَةً وَلَا يَهْتَدُونَ سَبِيلًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@dxcii{فَأُو۟لَٰٓئِكَ عَسَى ٱللَّهُ أَن يَعْفُوَ عَنْهُمْ وَكَانَ ٱللَّهُ عَفُوًّا غَفُورًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@dxciii{وَمَن يُهَاجِرْ فِى سَبِيلِ ٱللَّهِ يَجِدْ فِى ٱلْأَرْضِ مُرَٰغَمًا كَثِيرًا وَسَعَةً وَمَن يَخْرُجْ مِنۢ بَيْتِهِۦ مُهَاجِرًا إِلَى ٱللَّهِ وَرَسُولِهِۦ ثُمَّ يُدْرِكْهُ ٱلْمَوْتُ فَقَدْ وَقَعَ أَجْرُهُۥ عَلَى ٱللَّهِ وَكَانَ ٱللَّهُ غَفُورًا رَّحِيمًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@dxciv{وَإِذَا ضَرَبْتُمْ فِى ٱلْأَرْضِ فَلَيْسَ عَلَيْكُمْ جُنَاحٌ أَن تَقْصُرُوا۟ مِنَ ٱلصَّلَوٰةِ إِنْ خِفْتُمْ أَن يَفْتِنَكُمُ ٱلَّذِينَ كَفَرُوٓا۟ إِنَّ ٱلْكَٰفِرِينَ كَانُوا۟ لَكُمْ عَدُوًّا مُّبِينًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@dxcv{وَإِذَا كُنتَ فِيهِمْ فَأَقَمْتَ لَهُمُ ٱلصَّلَوٰةَ فَلْتَقُمْ طَآئِفَةٌ مِّنْهُم مَّعَكَ وَلْيَأْخُذُوٓا۟ أَسْلِحَتَهُمْ فَإِذَا سَجَدُوا۟ فَلْيَكُونُوا۟ مِن وَرَآئِكُمْ وَلْتَأْتِ طَآئِفَةٌ أُخْرَىٰ لَمْ يُصَلُّوا۟ فَلْيُصَلُّوا۟ مَعَكَ وَلْيَأْخُذُوا۟ حِذْرَهُمْ وَأَسْلِحَتَهُمْ وَدَّ ٱلَّذِينَ كَفَرُوا۟ لَوْ تَغْفُلُونَ عَنْ أَسْلِحَتِكُمْ وَأَمْتِعَتِكُمْ فَيَمِيلُونَ عَلَيْكُم مَّيْلَةً وَٰحِدَةً وَلَا جُنَاحَ عَلَيْكُمْ إِن كَانَ بِكُمْ أَذًى مِّن مَّطَرٍ أَوْ كُنتُم مَّرْضَىٰٓ أَن تَضَعُوٓا۟ أَسْلِحَتَكُمْ وَخُذُوا۟ حِذْرَكُمْ إِنَّ ٱللَّهَ أَعَدَّ لِلْكَٰفِرِينَ عَذَابًا مُّهِينًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@dxcvi{فَإِذَا قَضَيْتُمُ ٱلصَّلَوٰةَ فَٱذْكُرُوا۟ ٱللَّهَ قِيَٰمًا وَقُعُودًا وَعَلَىٰ جُنُوبِكُمْ فَإِذَا ٱطْمَأْنَنتُمْ فَأَقِيمُوا۟ ٱلصَّلَوٰةَ إِنَّ ٱلصَّلَوٰةَ كَانَتْ عَلَى ٱلْمُؤْمِنِينَ كِتَٰبًا مَّوْقُوتًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@dxcvii{وَلَا تَهِنُوا۟ فِى ٱبْتِغَآءِ ٱلْقَوْمِ إِن تَكُونُوا۟ تَأْلَمُونَ فَإِنَّهُمْ يَأْلَمُونَ كَمَا تَأْلَمُونَ وَتَرْجُونَ مِنَ ٱللَّهِ مَا لَا يَرْجُونَ وَكَانَ ٱللَّهُ عَلِيمًا حَكِيمًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@dxcviii{إِنَّآ أَنزَلْنَآ إِلَيْكَ ٱلْكِتَٰبَ بِٱلْحَقِّ لِتَحْكُمَ بَيْنَ ٱلنَّاسِ بِمَآ أَرَىٰكَ ٱللَّهُ وَلَا تَكُن لِّلْخَآئِنِينَ خَصِيمًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@dxcix{وَٱسْتَغْفِرِ ٱللَّهَ إِنَّ ٱللَّهَ كَانَ غَفُورًا رَّحِيمًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@dc{وَلَا تُجَٰدِلْ عَنِ ٱلَّذِينَ يَخْتَانُونَ أَنفُسَهُمْ إِنَّ ٱللَّهَ لَا يُحِبُّ مَن كَانَ خَوَّانًا أَثِيمًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@dci{يَسْتَخْفُونَ مِنَ ٱلنَّاسِ وَلَا يَسْتَخْفُونَ مِنَ ٱللَّهِ وَهُوَ مَعَهُمْ إِذْ يُبَيِّتُونَ مَا لَا يَرْضَىٰ مِنَ ٱلْقَوْلِ وَكَانَ ٱللَّهُ بِمَا يَعْمَلُونَ مُحِيطًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@dcii{هَٰٓأَنتُمْ هَٰٓؤُلَآءِ جَٰدَلْتُمْ عَنْهُمْ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا فَمَن يُجَٰدِلُ ٱللَّهَ عَنْهُمْ يَوْمَ ٱلْقِيَٰمَةِ أَم مَّن يَكُونُ عَلَيْهِمْ وَكِيلًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@dciii{وَمَن يَعْمَلْ سُوٓءًا أَوْ يَظْلِمْ نَفْسَهُۥ ثُمَّ يَسْتَغْفِرِ ٱللَّهَ يَجِدِ ٱللَّهَ غَفُورًا رَّحِيمًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@dciv{وَمَن يَكْسِبْ إِثْمًا فَإِنَّمَا يَكْسِبُهُۥ عَلَىٰ نَفْسِهِۦ وَكَانَ ٱللَّهُ عَلِيمًا حَكِيمًا\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@dcv{وَمَن يَكْسِبْ خَطِيٓـَٔةً أَوْ إِثْمًا ثُمَّ يَرْمِ بِهِۦ بَرِيٓـًٔا فَقَدِ ٱحْتَمَلَ بُهْتَٰنًا وَإِثْمًا مُّبِينًا\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@dcvi{وَلَوْلَا فَضْلُ ٱللَّهِ عَلَيْكَ وَرَحْمَتُهُۥ لَهَمَّت طَّآئِفَةٌ مِّنْهُمْ أَن يُضِلُّوكَ وَمَا يُضِلُّونَ إِلَّآ أَنفُسَهُمْ وَمَا يَضُرُّونَكَ مِن شَىْءٍ وَأَنزَلَ ٱللَّهُ عَلَيْكَ ٱلْكِتَٰبَ وَٱلْحِكْمَةَ وَعَلَّمَكَ مَا لَمْ تَكُن تَعْلَمُ وَكَانَ فَضْلُ ٱللَّهِ عَلَيْكَ عَظِيمًا\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@dcvii{لَّا خَيْرَ فِى كَثِيرٍ مِّن نَّجْوَىٰهُمْ إِلَّا مَنْ أَمَرَ بِصَدَقَةٍ أَوْ مَعْرُوفٍ أَوْ إِصْلَٰحٍۭ بَيْنَ ٱلنَّاسِ وَمَن يَفْعَلْ ذَٰلِكَ ٱبْتِغَآءَ مَرْضَاتِ ٱللَّهِ فَسَوْفَ نُؤْتِيهِ أَجْرًا عَظِيمًا\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@dcviii{وَمَن يُشَاقِقِ ٱلرَّسُولَ مِنۢ بَعْدِ مَا تَبَيَّنَ لَهُ ٱلْهُدَىٰ وَيَتَّبِعْ غَيْرَ سَبِيلِ ٱلْمُؤْمِنِينَ نُوَلِّهِۦ مَا تَوَلَّىٰ وَنُصْلِهِۦ جَهَنَّمَ وَسَآءَتْ مَصِيرًا\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@dcix{إِنَّ ٱللَّهَ لَا يَغْفِرُ أَن يُشْرَكَ بِهِۦ وَيَغْفِرُ مَا دُونَ ذَٰلِكَ لِمَن يَشَآءُ وَمَن يُشْرِكْ بِٱللَّهِ فَقَدْ ضَلَّ ضَلَٰلًۢا بَعِيدًا\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@dcx{إِن يَدْعُونَ مِن دُونِهِۦٓ إِلَّآ إِنَٰثًا وَإِن يَدْعُونَ إِلَّا شَيْطَٰنًا مَّرِيدًا\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@dcxi{لَّعَنَهُ ٱللَّهُ وَقَالَ لَأَتَّخِذَنَّ مِنْ عِبَادِكَ نَصِيبًا مَّفْرُوضًا\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@dcxii{وَلَأُضِلَّنَّهُمْ وَلَأُمَنِّيَنَّهُمْ وَلَءَامُرَنَّهُمْ فَلَيُبَتِّكُنَّ ءَاذَانَ ٱلْأَنْعَٰمِ وَلَءَامُرَنَّهُمْ فَلَيُغَيِّرُنَّ خَلْقَ ٱللَّهِ وَمَن يَتَّخِذِ ٱلشَّيْطَٰنَ وَلِيًّا مِّن دُونِ ٱللَّهِ فَقَدْ خَسِرَ خُسْرَانًا مُّبِينًا\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@dcxiii{يَعِدُهُمْ وَيُمَنِّيهِمْ وَمَا يَعِدُهُمُ ٱلشَّيْطَٰنُ إِلَّا غُرُورًا\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@dcxiv{أُو۟لَٰٓئِكَ مَأْوَىٰهُمْ جَهَنَّمُ وَلَا يَجِدُونَ عَنْهَا مَحِيصًا\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@dcxv{وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ سَنُدْخِلُهُمْ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَآ أَبَدًا وَعْدَ ٱللَّهِ حَقًّا وَمَنْ أَصْدَقُ مِنَ ٱللَّهِ قِيلًا\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@dcxvi{لَّيْسَ بِأَمَانِيِّكُمْ وَلَآ أَمَانِىِّ أَهْلِ ٱلْكِتَٰبِ مَن يَعْمَلْ سُوٓءًا يُجْزَ بِهِۦ وَلَا يَجِدْ لَهُۥ مِن دُونِ ٱللَّهِ وَلِيًّا وَلَا نَصِيرًا\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@dcxvii{وَمَن يَعْمَلْ مِنَ ٱلصَّٰلِحَٰتِ مِن ذَكَرٍ أَوْ أُنثَىٰ وَهُوَ مُؤْمِنٌ فَأُو۟لَٰٓئِكَ يَدْخُلُونَ ٱلْجَنَّةَ وَلَا يُظْلَمُونَ نَقِيرًا\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@dcxviii{وَمَنْ أَحْسَنُ دِينًا مِّمَّنْ أَسْلَمَ وَجْهَهُۥ لِلَّهِ وَهُوَ مُحْسِنٌ وَٱتَّبَعَ مِلَّةَ إِبْرَٰهِيمَ حَنِيفًا وَٱتَّخَذَ ٱللَّهُ إِبْرَٰهِيمَ خَلِيلًا\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@dcxix{وَلِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَكَانَ ٱللَّهُ بِكُلِّ شَىْءٍ مُّحِيطًا\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@dcxx{وَيَسْتَفْتُونَكَ فِى ٱلنِّسَآءِ قُلِ ٱللَّهُ يُفْتِيكُمْ فِيهِنَّ وَمَا يُتْلَىٰ عَلَيْكُمْ فِى ٱلْكِتَٰبِ فِى يَتَٰمَى ٱلنِّسَآءِ ٱلَّٰتِى لَا تُؤْتُونَهُنَّ مَا كُتِبَ لَهُنَّ وَتَرْغَبُونَ أَن تَنكِحُوهُنَّ وَٱلْمُسْتَضْعَفِينَ مِنَ ٱلْوِلْدَٰنِ وَأَن تَقُومُوا۟ لِلْيَتَٰمَىٰ بِٱلْقِسْطِ وَمَا تَفْعَلُوا۟ مِنْ خَيْرٍ فَإِنَّ ٱللَّهَ كَانَ بِهِۦ عَلِيمًا\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@dcxxi{وَإِنِ ٱمْرَأَةٌ خَافَتْ مِنۢ بَعْلِهَا نُشُوزًا أَوْ إِعْرَاضًا فَلَا جُنَاحَ عَلَيْهِمَآ أَن يُصْلِحَا بَيْنَهُمَا صُلْحًا وَٱلصُّلْحُ خَيْرٌ وَأُحْضِرَتِ ٱلْأَنفُسُ ٱلشُّحَّ وَإِن تُحْسِنُوا۟ وَتَتَّقُوا۟ فَإِنَّ ٱللَّهَ كَانَ بِمَا تَعْمَلُونَ خَبِيرًا\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@dcxxii{وَلَن تَسْتَطِيعُوٓا۟ أَن تَعْدِلُوا۟ بَيْنَ ٱلنِّسَآءِ وَلَوْ حَرَصْتُمْ فَلَا تَمِيلُوا۟ كُلَّ ٱلْمَيْلِ فَتَذَرُوهَا كَٱلْمُعَلَّقَةِ وَإِن تُصْلِحُوا۟ وَتَتَّقُوا۟ فَإِنَّ ٱللَّهَ كَانَ غَفُورًا رَّحِيمًا\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@dcxxiii{وَإِن يَتَفَرَّقَا يُغْنِ ٱللَّهُ كُلًّا مِّن سَعَتِهِۦ وَكَانَ ٱللَّهُ وَٰسِعًا حَكِيمًا\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@dcxxiv{وَلِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَلَقَدْ وَصَّيْنَا ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ مِن قَبْلِكُمْ وَإِيَّاكُمْ أَنِ ٱتَّقُوا۟ ٱللَّهَ وَإِن تَكْفُرُوا۟ فَإِنَّ لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَكَانَ ٱللَّهُ غَنِيًّا حَمِيدًا\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@dcxxv{وَلِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَكَفَىٰ بِٱللَّهِ وَكِيلًا\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@dcxxvi{إِن يَشَأْ يُذْهِبْكُمْ أَيُّهَا ٱلنَّاسُ وَيَأْتِ بِـَٔاخَرِينَ وَكَانَ ٱللَّهُ عَلَىٰ ذَٰلِكَ قَدِيرًا\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@dcxxvii{مَّن كَانَ يُرِيدُ ثَوَابَ ٱلدُّنْيَا فَعِندَ ٱللَّهِ ثَوَابُ ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَكَانَ ٱللَّهُ سَمِيعًۢا بَصِيرًا\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@dcxxviii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ كُونُوا۟ قَوَّٰمِينَ بِٱلْقِسْطِ شُهَدَآءَ لِلَّهِ وَلَوْ عَلَىٰٓ أَنفُسِكُمْ أَوِ ٱلْوَٰلِدَيْنِ وَٱلْأَقْرَبِينَ إِن يَكُنْ غَنِيًّا أَوْ فَقِيرًا فَٱللَّهُ أَوْلَىٰ بِهِمَا فَلَا تَتَّبِعُوا۟ ٱلْهَوَىٰٓ أَن تَعْدِلُوا۟ وَإِن تَلْوُۥٓا۟ أَوْ تُعْرِضُوا۟ فَإِنَّ ٱللَّهَ كَانَ بِمَا تَعْمَلُونَ خَبِيرًا\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@dcxxix{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ ءَامِنُوا۟ بِٱللَّهِ وَرَسُولِهِۦ وَٱلْكِتَٰبِ ٱلَّذِى نَزَّلَ عَلَىٰ رَسُولِهِۦ وَٱلْكِتَٰبِ ٱلَّذِىٓ أَنزَلَ مِن قَبْلُ وَمَن يَكْفُرْ بِٱللَّهِ وَمَلَٰٓئِكَتِهِۦ وَكُتُبِهِۦ وَرُسُلِهِۦ وَٱلْيَوْمِ ٱلْءَاخِرِ فَقَدْ ضَلَّ ضَلَٰلًۢا بَعِيدًا\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@dcxxx{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ ثُمَّ كَفَرُوا۟ ثُمَّ ءَامَنُوا۟ ثُمَّ كَفَرُوا۟ ثُمَّ ٱزْدَادُوا۟ كُفْرًا لَّمْ يَكُنِ ٱللَّهُ لِيَغْفِرَ لَهُمْ وَلَا لِيَهْدِيَهُمْ سَبِيلًۢا\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@dcxxxi{بَشِّرِ ٱلْمُنَٰفِقِينَ بِأَنَّ لَهُمْ عَذَابًا أَلِيمًا\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@dcxxxii{ٱلَّذِينَ يَتَّخِذُونَ ٱلْكَٰفِرِينَ أَوْلِيَآءَ مِن دُونِ ٱلْمُؤْمِنِينَ أَيَبْتَغُونَ عِندَهُمُ ٱلْعِزَّةَ فَإِنَّ ٱلْعِزَّةَ لِلَّهِ جَمِيعًا\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@dcxxxiii{وَقَدْ نَزَّلَ عَلَيْكُمْ فِى ٱلْكِتَٰبِ أَنْ إِذَا سَمِعْتُمْ ءَايَٰتِ ٱللَّهِ يُكْفَرُ بِهَا وَيُسْتَهْزَأُ بِهَا فَلَا تَقْعُدُوا۟ مَعَهُمْ حَتَّىٰ يَخُوضُوا۟ فِى حَدِيثٍ غَيْرِهِۦٓ إِنَّكُمْ إِذًا مِّثْلُهُمْ إِنَّ ٱللَّهَ جَامِعُ ٱلْمُنَٰفِقِينَ وَٱلْكَٰفِرِينَ فِى جَهَنَّمَ جَمِيعًا\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@dcxxxiv{ٱلَّذِينَ يَتَرَبَّصُونَ بِكُمْ فَإِن كَانَ لَكُمْ فَتْحٌ مِّنَ ٱللَّهِ قَالُوٓا۟ أَلَمْ نَكُن مَّعَكُمْ وَإِن كَانَ لِلْكَٰفِرِينَ نَصِيبٌ قَالُوٓا۟ أَلَمْ نَسْتَحْوِذْ عَلَيْكُمْ وَنَمْنَعْكُم مِّنَ ٱلْمُؤْمِنِينَ فَٱللَّهُ يَحْكُمُ بَيْنَكُمْ يَوْمَ ٱلْقِيَٰمَةِ وَلَن يَجْعَلَ ٱللَّهُ لِلْكَٰفِرِينَ عَلَى ٱلْمُؤْمِنِينَ سَبِيلًا\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@dcxxxv{إِنَّ ٱلْمُنَٰفِقِينَ يُخَٰدِعُونَ ٱللَّهَ وَهُوَ خَٰدِعُهُمْ وَإِذَا قَامُوٓا۟ إِلَى ٱلصَّلَوٰةِ قَامُوا۟ كُسَالَىٰ يُرَآءُونَ ٱلنَّاسَ وَلَا يَذْكُرُونَ ٱللَّهَ إِلَّا قَلِيلًا\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@dcxxxvi{مُّذَبْذَبِينَ بَيْنَ ذَٰلِكَ لَآ إِلَىٰ هَٰٓؤُلَآءِ وَلَآ إِلَىٰ هَٰٓؤُلَآءِ وَمَن يُضْلِلِ ٱللَّهُ فَلَن تَجِدَ لَهُۥ سَبِيلًا\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@dcxxxvii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَتَّخِذُوا۟ ٱلْكَٰفِرِينَ أَوْلِيَآءَ مِن دُونِ ٱلْمُؤْمِنِينَ أَتُرِيدُونَ أَن تَجْعَلُوا۟ لِلَّهِ عَلَيْكُمْ سُلْطَٰنًا مُّبِينًا\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@dcxxxviii{إِنَّ ٱلْمُنَٰفِقِينَ فِى ٱلدَّرْكِ ٱلْأَسْفَلِ مِنَ ٱلنَّارِ وَلَن تَجِدَ لَهُمْ نَصِيرًا\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@dcxxxix{إِلَّا ٱلَّذِينَ تَابُوا۟ وَأَصْلَحُوا۟ وَٱعْتَصَمُوا۟ بِٱللَّهِ وَأَخْلَصُوا۟ دِينَهُمْ لِلَّهِ فَأُو۟لَٰٓئِكَ مَعَ ٱلْمُؤْمِنِينَ وَسَوْفَ يُؤْتِ ٱللَّهُ ٱلْمُؤْمِنِينَ أَجْرًا عَظِيمًا\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@dcxl{مَّا يَفْعَلُ ٱللَّهُ بِعَذَابِكُمْ إِن شَكَرْتُمْ وَءَامَنتُمْ وَكَانَ ٱللَّهُ شَاكِرًا عَلِيمًا\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@dcxli{لَّا يُحِبُّ ٱللَّهُ ٱلْجَهْرَ بِٱلسُّوٓءِ مِنَ ٱلْقَوْلِ إِلَّا مَن ظُلِمَ وَكَانَ ٱللَّهُ سَمِيعًا عَلِيمًا\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@dcxlii{إِن تُبْدُوا۟ خَيْرًا أَوْ تُخْفُوهُ أَوْ تَعْفُوا۟ عَن سُوٓءٍ فَإِنَّ ٱللَّهَ كَانَ عَفُوًّا قَدِيرًا\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@dcxliii{إِنَّ ٱلَّذِينَ يَكْفُرُونَ بِٱللَّهِ وَرُسُلِهِۦ وَيُرِيدُونَ أَن يُفَرِّقُوا۟ بَيْنَ ٱللَّهِ وَرُسُلِهِۦ وَيَقُولُونَ نُؤْمِنُ بِبَعْضٍ وَنَكْفُرُ بِبَعْضٍ وَيُرِيدُونَ أَن يَتَّخِذُوا۟ بَيْنَ ذَٰلِكَ سَبِيلًا\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@dcxliv{أُو۟لَٰٓئِكَ هُمُ ٱلْكَٰفِرُونَ حَقًّا وَأَعْتَدْنَا لِلْكَٰفِرِينَ عَذَابًا مُّهِينًا\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@dcxlv{وَٱلَّذِينَ ءَامَنُوا۟ بِٱللَّهِ وَرُسُلِهِۦ وَلَمْ يُفَرِّقُوا۟ بَيْنَ أَحَدٍ مِّنْهُمْ أُو۟لَٰٓئِكَ سَوْفَ يُؤْتِيهِمْ أُجُورَهُمْ وَكَانَ ٱللَّهُ غَفُورًا رَّحِيمًا\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@dcxlvi{يَسْـَٔلُكَ أَهْلُ ٱلْكِتَٰبِ أَن تُنَزِّلَ عَلَيْهِمْ كِتَٰبًا مِّنَ ٱلسَّمَآءِ فَقَدْ سَأَلُوا۟ مُوسَىٰٓ أَكْبَرَ مِن ذَٰلِكَ فَقَالُوٓا۟ أَرِنَا ٱللَّهَ جَهْرَةً فَأَخَذَتْهُمُ ٱلصَّٰعِقَةُ بِظُلْمِهِمْ ثُمَّ ٱتَّخَذُوا۟ ٱلْعِجْلَ مِنۢ بَعْدِ مَا جَآءَتْهُمُ ٱلْبَيِّنَٰتُ فَعَفَوْنَا عَن ذَٰلِكَ وَءَاتَيْنَا مُوسَىٰ سُلْطَٰنًا مُّبِينًا\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@dcxlvii{وَرَفَعْنَا فَوْقَهُمُ ٱلطُّورَ بِمِيثَٰقِهِمْ وَقُلْنَا لَهُمُ ٱدْخُلُوا۟ ٱلْبَابَ سُجَّدًا وَقُلْنَا لَهُمْ لَا تَعْدُوا۟ فِى ٱلسَّبْتِ وَأَخَذْنَا مِنْهُم مِّيثَٰقًا غَلِيظًا\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@dcxlviii{فَبِمَا نَقْضِهِم مِّيثَٰقَهُمْ وَكُفْرِهِم بِـَٔايَٰتِ ٱللَّهِ وَقَتْلِهِمُ ٱلْأَنۢبِيَآءَ بِغَيْرِ حَقٍّ وَقَوْلِهِمْ قُلُوبُنَا غُلْفٌۢ بَلْ طَبَعَ ٱللَّهُ عَلَيْهَا بِكُفْرِهِمْ فَلَا يُؤْمِنُونَ إِلَّا قَلِيلًا\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@dcxlix{وَبِكُفْرِهِمْ وَقَوْلِهِمْ عَلَىٰ مَرْيَمَ بُهْتَٰنًا عَظِيمًا\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@dcl{وَقَوْلِهِمْ إِنَّا قَتَلْنَا ٱلْمَسِيحَ عِيسَى ٱبْنَ مَرْيَمَ رَسُولَ ٱللَّهِ وَمَا قَتَلُوهُ وَمَا صَلَبُوهُ وَلَٰكِن شُبِّهَ لَهُمْ وَإِنَّ ٱلَّذِينَ ٱخْتَلَفُوا۟ فِيهِ لَفِى شَكٍّ مِّنْهُ مَا لَهُم بِهِۦ مِنْ عِلْمٍ إِلَّا ٱتِّبَاعَ ٱلظَّنِّ وَمَا قَتَلُوهُ يَقِينًۢا\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@dcli{بَل رَّفَعَهُ ٱللَّهُ إِلَيْهِ وَكَانَ ٱللَّهُ عَزِيزًا حَكِيمًا\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@dclii{وَإِن مِّنْ أَهْلِ ٱلْكِتَٰبِ إِلَّا لَيُؤْمِنَنَّ بِهِۦ قَبْلَ مَوْتِهِۦ وَيَوْمَ ٱلْقِيَٰمَةِ يَكُونُ عَلَيْهِمْ شَهِيدًا\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@dcliii{فَبِظُلْمٍ مِّنَ ٱلَّذِينَ هَادُوا۟ حَرَّمْنَا عَلَيْهِمْ طَيِّبَٰتٍ أُحِلَّتْ لَهُمْ وَبِصَدِّهِمْ عَن سَبِيلِ ٱللَّهِ كَثِيرًا\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@dcliv{وَأَخْذِهِمُ ٱلرِّبَوٰا۟ وَقَدْ نُهُوا۟ عَنْهُ وَأَكْلِهِمْ أَمْوَٰلَ ٱلنَّاسِ بِٱلْبَٰطِلِ وَأَعْتَدْنَا لِلْكَٰفِرِينَ مِنْهُمْ عَذَابًا أَلِيمًا\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@dclv{لَّٰكِنِ ٱلرَّٰسِخُونَ فِى ٱلْعِلْمِ مِنْهُمْ وَٱلْمُؤْمِنُونَ يُؤْمِنُونَ بِمَآ أُنزِلَ إِلَيْكَ وَمَآ أُنزِلَ مِن قَبْلِكَ وَٱلْمُقِيمِينَ ٱلصَّلَوٰةَ وَٱلْمُؤْتُونَ ٱلزَّكَوٰةَ وَٱلْمُؤْمِنُونَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ أُو۟لَٰٓئِكَ سَنُؤْتِيهِمْ أَجْرًا عَظِيمًا\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@dclvi{إِنَّآ أَوْحَيْنَآ إِلَيْكَ كَمَآ أَوْحَيْنَآ إِلَىٰ نُوحٍ وَٱلنَّبِيِّۦنَ مِنۢ بَعْدِهِۦ وَأَوْحَيْنَآ إِلَىٰٓ إِبْرَٰهِيمَ وَإِسْمَٰعِيلَ وَإِسْحَٰقَ وَيَعْقُوبَ وَٱلْأَسْبَاطِ وَعِيسَىٰ وَأَيُّوبَ وَيُونُسَ وَهَٰرُونَ وَسُلَيْمَٰنَ وَءَاتَيْنَا دَاوُۥدَ زَبُورًا\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@dclvii{وَرُسُلًا قَدْ قَصَصْنَٰهُمْ عَلَيْكَ مِن قَبْلُ وَرُسُلًا لَّمْ نَقْصُصْهُمْ عَلَيْكَ وَكَلَّمَ ٱللَّهُ مُوسَىٰ تَكْلِيمًا\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@dclviii{رُّسُلًا مُّبَشِّرِينَ وَمُنذِرِينَ لِئَلَّا يَكُونَ لِلنَّاسِ عَلَى ٱللَّهِ حُجَّةٌۢ بَعْدَ ٱلرُّسُلِ وَكَانَ ٱللَّهُ عَزِيزًا حَكِيمًا\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@dclix{لَّٰكِنِ ٱللَّهُ يَشْهَدُ بِمَآ أَنزَلَ إِلَيْكَ أَنزَلَهُۥ بِعِلْمِهِۦ وَٱلْمَلَٰٓئِكَةُ يَشْهَدُونَ وَكَفَىٰ بِٱللَّهِ شَهِيدًا\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@dclx{إِنَّ ٱلَّذِينَ كَفَرُوا۟ وَصَدُّوا۟ عَن سَبِيلِ ٱللَّهِ قَدْ ضَلُّوا۟ ضَلَٰلًۢا بَعِيدًا\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@dclxi{إِنَّ ٱلَّذِينَ كَفَرُوا۟ وَظَلَمُوا۟ لَمْ يَكُنِ ٱللَّهُ لِيَغْفِرَ لَهُمْ وَلَا لِيَهْدِيَهُمْ طَرِيقًا\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@dclxii{إِلَّا طَرِيقَ جَهَنَّمَ خَٰلِدِينَ فِيهَآ أَبَدًا وَكَانَ ذَٰلِكَ عَلَى ٱللَّهِ يَسِيرًا\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@dclxiii{يَٰٓأَيُّهَا ٱلنَّاسُ قَدْ جَآءَكُمُ ٱلرَّسُولُ بِٱلْحَقِّ مِن رَّبِّكُمْ فَـَٔامِنُوا۟ خَيْرًا لَّكُمْ وَإِن تَكْفُرُوا۟ فَإِنَّ لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَكَانَ ٱللَّهُ عَلِيمًا حَكِيمًا\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@dclxiv{يَٰٓأَهْلَ ٱلْكِتَٰبِ لَا تَغْلُوا۟ فِى دِينِكُمْ وَلَا تَقُولُوا۟ عَلَى ٱللَّهِ إِلَّا ٱلْحَقَّ إِنَّمَا ٱلْمَسِيحُ عِيسَى ٱبْنُ مَرْيَمَ رَسُولُ ٱللَّهِ وَكَلِمَتُهُۥٓ أَلْقَىٰهَآ إِلَىٰ مَرْيَمَ وَرُوحٌ مِّنْهُ فَـَٔامِنُوا۟ بِٱللَّهِ وَرُسُلِهِۦ وَلَا تَقُولُوا۟ ثَلَٰثَةٌ ٱنتَهُوا۟ خَيْرًا لَّكُمْ إِنَّمَا ٱللَّهُ إِلَٰهٌ وَٰحِدٌ سُبْحَٰنَهُۥٓ أَن يَكُونَ لَهُۥ وَلَدٌ لَّهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَكَفَىٰ بِٱللَّهِ وَكِيلًا\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@dclxv{لَّن يَسْتَنكِفَ ٱلْمَسِيحُ أَن يَكُونَ عَبْدًا لِّلَّهِ وَلَا ٱلْمَلَٰٓئِكَةُ ٱلْمُقَرَّبُونَ وَمَن يَسْتَنكِفْ عَنْ عِبَادَتِهِۦ وَيَسْتَكْبِرْ فَسَيَحْشُرُهُمْ إِلَيْهِ جَمِيعًا\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@dclxvi{فَأَمَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ فَيُوَفِّيهِمْ أُجُورَهُمْ وَيَزِيدُهُم مِّن فَضْلِهِۦ وَأَمَّا ٱلَّذِينَ ٱسْتَنكَفُوا۟ وَٱسْتَكْبَرُوا۟ فَيُعَذِّبُهُمْ عَذَابًا أَلِيمًا وَلَا يَجِدُونَ لَهُم مِّن دُونِ ٱللَّهِ وَلِيًّا وَلَا نَصِيرًا\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@dclxvii{يَٰٓأَيُّهَا ٱلنَّاسُ قَدْ جَآءَكُم بُرْهَٰنٌ مِّن رَّبِّكُمْ وَأَنزَلْنَآ إِلَيْكُمْ نُورًا مُّبِينًا\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@dclxviii{فَأَمَّا ٱلَّذِينَ ءَامَنُوا۟ بِٱللَّهِ وَٱعْتَصَمُوا۟ بِهِۦ فَسَيُدْخِلُهُمْ فِى رَحْمَةٍ مِّنْهُ وَفَضْلٍ وَيَهْدِيهِمْ إِلَيْهِ صِرَٰطًا مُّسْتَقِيمًا\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@dclxix{يَسْتَفْتُونَكَ قُلِ ٱللَّهُ يُفْتِيكُمْ فِى ٱلْكَلَٰلَةِ إِنِ ٱمْرُؤٌا۟ هَلَكَ لَيْسَ لَهُۥ وَلَدٌ وَلَهُۥٓ أُخْتٌ فَلَهَا نِصْفُ مَا تَرَكَ وَهُوَ يَرِثُهَآ إِن لَّمْ يَكُن لَّهَا وَلَدٌ فَإِن كَانَتَا ٱثْنَتَيْنِ فَلَهُمَا ٱلثُّلُثَانِ مِمَّا تَرَكَ وَإِن كَانُوٓا۟ إِخْوَةً رِّجَالًا وَنِسَآءً فَلِلذَّكَرِ مِثْلُ حَظِّ ٱلْأُنثَيَيْنِ يُبَيِّنُ ٱللَّهُ لَكُمْ أَن تَضِلُّوا۟ وَٱللَّهُ بِكُلِّ شَىْءٍ عَلِيمٌۢ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@dclxx{\basmalah يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ أَوْفُوا۟ بِٱلْعُقُودِ أُحِلَّتْ لَكُم بَهِيمَةُ ٱلْأَنْعَٰمِ إِلَّا مَا يُتْلَىٰ عَلَيْكُمْ غَيْرَ مُحِلِّى ٱلصَّيْدِ وَأَنتُمْ حُرُمٌ إِنَّ ٱللَّهَ يَحْكُمُ مَا يُرِيدُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@dclxxi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تُحِلُّوا۟ شَعَٰٓئِرَ ٱللَّهِ وَلَا ٱلشَّهْرَ ٱلْحَرَامَ وَلَا ٱلْهَدْىَ وَلَا ٱلْقَلَٰٓئِدَ وَلَآ ءَآمِّينَ ٱلْبَيْتَ ٱلْحَرَامَ يَبْتَغُونَ فَضْلًا مِّن رَّبِّهِمْ وَرِضْوَٰنًا وَإِذَا حَلَلْتُمْ فَٱصْطَادُوا۟ وَلَا يَجْرِمَنَّكُمْ شَنَـَٔانُ قَوْمٍ أَن صَدُّوكُمْ عَنِ ٱلْمَسْجِدِ ٱلْحَرَامِ أَن تَعْتَدُوا۟ وَتَعَاوَنُوا۟ عَلَى ٱلْبِرِّ وَٱلتَّقْوَىٰ وَلَا تَعَاوَنُوا۟ عَلَى ٱلْإِثْمِ وَٱلْعُدْوَٰنِ وَٱتَّقُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@dclxxii{حُرِّمَتْ عَلَيْكُمُ ٱلْمَيْتَةُ وَٱلدَّمُ وَلَحْمُ ٱلْخِنزِيرِ وَمَآ أُهِلَّ لِغَيْرِ ٱللَّهِ بِهِۦ وَٱلْمُنْخَنِقَةُ وَٱلْمَوْقُوذَةُ وَٱلْمُتَرَدِّيَةُ وَٱلنَّطِيحَةُ وَمَآ أَكَلَ ٱلسَّبُعُ إِلَّا مَا ذَكَّيْتُمْ وَمَا ذُبِحَ عَلَى ٱلنُّصُبِ وَأَن تَسْتَقْسِمُوا۟ بِٱلْأَزْلَٰمِ ذَٰلِكُمْ فِسْقٌ ٱلْيَوْمَ يَئِسَ ٱلَّذِينَ كَفَرُوا۟ مِن دِينِكُمْ فَلَا تَخْشَوْهُمْ وَٱخْشَوْنِ ٱلْيَوْمَ أَكْمَلْتُ لَكُمْ دِينَكُمْ وَأَتْمَمْتُ عَلَيْكُمْ نِعْمَتِى وَرَضِيتُ لَكُمُ ٱلْإِسْلَٰمَ دِينًا فَمَنِ ٱضْطُرَّ فِى مَخْمَصَةٍ غَيْرَ مُتَجَانِفٍ لِّإِثْمٍ فَإِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@dclxxiii{يَسْـَٔلُونَكَ مَاذَآ أُحِلَّ لَهُمْ قُلْ أُحِلَّ لَكُمُ ٱلطَّيِّبَٰتُ وَمَا عَلَّمْتُم مِّنَ ٱلْجَوَارِحِ مُكَلِّبِينَ تُعَلِّمُونَهُنَّ مِمَّا عَلَّمَكُمُ ٱللَّهُ فَكُلُوا۟ مِمَّآ أَمْسَكْنَ عَلَيْكُمْ وَٱذْكُرُوا۟ ٱسْمَ ٱللَّهِ عَلَيْهِ وَٱتَّقُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ سَرِيعُ ٱلْحِسَابِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@dclxxiv{ٱلْيَوْمَ أُحِلَّ لَكُمُ ٱلطَّيِّبَٰتُ وَطَعَامُ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ حِلٌّ لَّكُمْ وَطَعَامُكُمْ حِلٌّ لَّهُمْ وَٱلْمُحْصَنَٰتُ مِنَ ٱلْمُؤْمِنَٰتِ وَٱلْمُحْصَنَٰتُ مِنَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ مِن قَبْلِكُمْ إِذَآ ءَاتَيْتُمُوهُنَّ أُجُورَهُنَّ مُحْصِنِينَ غَيْرَ مُسَٰفِحِينَ وَلَا مُتَّخِذِىٓ أَخْدَانٍ وَمَن يَكْفُرْ بِٱلْإِيمَٰنِ فَقَدْ حَبِطَ عَمَلُهُۥ وَهُوَ فِى ٱلْءَاخِرَةِ مِنَ ٱلْخَٰسِرِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@dclxxv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا قُمْتُمْ إِلَى ٱلصَّلَوٰةِ فَٱغْسِلُوا۟ وُجُوهَكُمْ وَأَيْدِيَكُمْ إِلَى ٱلْمَرَافِقِ وَٱمْسَحُوا۟ بِرُءُوسِكُمْ وَأَرْجُلَكُمْ إِلَى ٱلْكَعْبَيْنِ وَإِن كُنتُمْ جُنُبًا فَٱطَّهَّرُوا۟ وَإِن كُنتُم مَّرْضَىٰٓ أَوْ عَلَىٰ سَفَرٍ أَوْ جَآءَ أَحَدٌ مِّنكُم مِّنَ ٱلْغَآئِطِ أَوْ لَٰمَسْتُمُ ٱلنِّسَآءَ فَلَمْ تَجِدُوا۟ مَآءً فَتَيَمَّمُوا۟ صَعِيدًا طَيِّبًا فَٱمْسَحُوا۟ بِوُجُوهِكُمْ وَأَيْدِيكُم مِّنْهُ مَا يُرِيدُ ٱللَّهُ لِيَجْعَلَ عَلَيْكُم مِّنْ حَرَجٍ وَلَٰكِن يُرِيدُ لِيُطَهِّرَكُمْ وَلِيُتِمَّ نِعْمَتَهُۥ عَلَيْكُمْ لَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@dclxxvi{وَٱذْكُرُوا۟ نِعْمَةَ ٱللَّهِ عَلَيْكُمْ وَمِيثَٰقَهُ ٱلَّذِى وَاثَقَكُم بِهِۦٓ إِذْ قُلْتُمْ سَمِعْنَا وَأَطَعْنَا وَٱتَّقُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@dclxxvii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ كُونُوا۟ قَوَّٰمِينَ لِلَّهِ شُهَدَآءَ بِٱلْقِسْطِ وَلَا يَجْرِمَنَّكُمْ شَنَـَٔانُ قَوْمٍ عَلَىٰٓ أَلَّا تَعْدِلُوا۟ ٱعْدِلُوا۟ هُوَ أَقْرَبُ لِلتَّقْوَىٰ وَٱتَّقُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ خَبِيرٌۢ بِمَا تَعْمَلُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@dclxxviii{وَعَدَ ٱللَّهُ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَهُم مَّغْفِرَةٌ وَأَجْرٌ عَظِيمٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@dclxxix{وَٱلَّذِينَ كَفَرُوا۟ وَكَذَّبُوا۟ بِـَٔايَٰتِنَآ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْجَحِيمِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@dclxxx{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱذْكُرُوا۟ نِعْمَتَ ٱللَّهِ عَلَيْكُمْ إِذْ هَمَّ قَوْمٌ أَن يَبْسُطُوٓا۟ إِلَيْكُمْ أَيْدِيَهُمْ فَكَفَّ أَيْدِيَهُمْ عَنكُمْ وَٱتَّقُوا۟ ٱللَّهَ وَعَلَى ٱللَّهِ فَلْيَتَوَكَّلِ ٱلْمُؤْمِنُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@dclxxxi{وَلَقَدْ أَخَذَ ٱللَّهُ مِيثَٰقَ بَنِىٓ إِسْرَٰٓءِيلَ وَبَعَثْنَا مِنْهُمُ ٱثْنَىْ عَشَرَ نَقِيبًا وَقَالَ ٱللَّهُ إِنِّى مَعَكُمْ لَئِنْ أَقَمْتُمُ ٱلصَّلَوٰةَ وَءَاتَيْتُمُ ٱلزَّكَوٰةَ وَءَامَنتُم بِرُسُلِى وَعَزَّرْتُمُوهُمْ وَأَقْرَضْتُمُ ٱللَّهَ قَرْضًا حَسَنًا لَّأُكَفِّرَنَّ عَنكُمْ سَيِّـَٔاتِكُمْ وَلَأُدْخِلَنَّكُمْ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ فَمَن كَفَرَ بَعْدَ ذَٰلِكَ مِنكُمْ فَقَدْ ضَلَّ سَوَآءَ ٱلسَّبِيلِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@dclxxxii{فَبِمَا نَقْضِهِم مِّيثَٰقَهُمْ لَعَنَّٰهُمْ وَجَعَلْنَا قُلُوبَهُمْ قَٰسِيَةً يُحَرِّفُونَ ٱلْكَلِمَ عَن مَّوَاضِعِهِۦ وَنَسُوا۟ حَظًّا مِّمَّا ذُكِّرُوا۟ بِهِۦ وَلَا تَزَالُ تَطَّلِعُ عَلَىٰ خَآئِنَةٍ مِّنْهُمْ إِلَّا قَلِيلًا مِّنْهُمْ فَٱعْفُ عَنْهُمْ وَٱصْفَحْ إِنَّ ٱللَّهَ يُحِبُّ ٱلْمُحْسِنِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@dclxxxiii{وَمِنَ ٱلَّذِينَ قَالُوٓا۟ إِنَّا نَصَٰرَىٰٓ أَخَذْنَا مِيثَٰقَهُمْ فَنَسُوا۟ حَظًّا مِّمَّا ذُكِّرُوا۟ بِهِۦ فَأَغْرَيْنَا بَيْنَهُمُ ٱلْعَدَاوَةَ وَٱلْبَغْضَآءَ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ وَسَوْفَ يُنَبِّئُهُمُ ٱللَّهُ بِمَا كَانُوا۟ يَصْنَعُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@dclxxxiv{يَٰٓأَهْلَ ٱلْكِتَٰبِ قَدْ جَآءَكُمْ رَسُولُنَا يُبَيِّنُ لَكُمْ كَثِيرًا مِّمَّا كُنتُمْ تُخْفُونَ مِنَ ٱلْكِتَٰبِ وَيَعْفُوا۟ عَن كَثِيرٍ قَدْ جَآءَكُم مِّنَ ٱللَّهِ نُورٌ وَكِتَٰبٌ مُّبِينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@dclxxxv{يَهْدِى بِهِ ٱللَّهُ مَنِ ٱتَّبَعَ رِضْوَٰنَهُۥ سُبُلَ ٱلسَّلَٰمِ وَيُخْرِجُهُم مِّنَ ٱلظُّلُمَٰتِ إِلَى ٱلنُّورِ بِإِذْنِهِۦ وَيَهْدِيهِمْ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@dclxxxvi{لَّقَدْ كَفَرَ ٱلَّذِينَ قَالُوٓا۟ إِنَّ ٱللَّهَ هُوَ ٱلْمَسِيحُ ٱبْنُ مَرْيَمَ قُلْ فَمَن يَمْلِكُ مِنَ ٱللَّهِ شَيْـًٔا إِنْ أَرَادَ أَن يُهْلِكَ ٱلْمَسِيحَ ٱبْنَ مَرْيَمَ وَأُمَّهُۥ وَمَن فِى ٱلْأَرْضِ جَمِيعًا وَلِلَّهِ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَا يَخْلُقُ مَا يَشَآءُ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@dclxxxvii{وَقَالَتِ ٱلْيَهُودُ وَٱلنَّصَٰرَىٰ نَحْنُ أَبْنَٰٓؤُا۟ ٱللَّهِ وَأَحِبَّٰٓؤُهُۥ قُلْ فَلِمَ يُعَذِّبُكُم بِذُنُوبِكُم بَلْ أَنتُم بَشَرٌ مِّمَّنْ خَلَقَ يَغْفِرُ لِمَن يَشَآءُ وَيُعَذِّبُ مَن يَشَآءُ وَلِلَّهِ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَا وَإِلَيْهِ ٱلْمَصِيرُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@dclxxxviii{يَٰٓأَهْلَ ٱلْكِتَٰبِ قَدْ جَآءَكُمْ رَسُولُنَا يُبَيِّنُ لَكُمْ عَلَىٰ فَتْرَةٍ مِّنَ ٱلرُّسُلِ أَن تَقُولُوا۟ مَا جَآءَنَا مِنۢ بَشِيرٍ وَلَا نَذِيرٍ فَقَدْ جَآءَكُم بَشِيرٌ وَنَذِيرٌ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@dclxxxix{وَإِذْ قَالَ مُوسَىٰ لِقَوْمِهِۦ يَٰقَوْمِ ٱذْكُرُوا۟ نِعْمَةَ ٱللَّهِ عَلَيْكُمْ إِذْ جَعَلَ فِيكُمْ أَنۢبِيَآءَ وَجَعَلَكُم مُّلُوكًا وَءَاتَىٰكُم مَّا لَمْ يُؤْتِ أَحَدًا مِّنَ ٱلْعَٰلَمِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@dcxc{يَٰقَوْمِ ٱدْخُلُوا۟ ٱلْأَرْضَ ٱلْمُقَدَّسَةَ ٱلَّتِى كَتَبَ ٱللَّهُ لَكُمْ وَلَا تَرْتَدُّوا۟ عَلَىٰٓ أَدْبَارِكُمْ فَتَنقَلِبُوا۟ خَٰسِرِينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@dcxci{قَالُوا۟ يَٰمُوسَىٰٓ إِنَّ فِيهَا قَوْمًا جَبَّارِينَ وَإِنَّا لَن نَّدْخُلَهَا حَتَّىٰ يَخْرُجُوا۟ مِنْهَا فَإِن يَخْرُجُوا۟ مِنْهَا فَإِنَّا دَٰخِلُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@dcxcii{قَالَ رَجُلَانِ مِنَ ٱلَّذِينَ يَخَافُونَ أَنْعَمَ ٱللَّهُ عَلَيْهِمَا ٱدْخُلُوا۟ عَلَيْهِمُ ٱلْبَابَ فَإِذَا دَخَلْتُمُوهُ فَإِنَّكُمْ غَٰلِبُونَ وَعَلَى ٱللَّهِ فَتَوَكَّلُوٓا۟ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@dcxciii{قَالُوا۟ يَٰمُوسَىٰٓ إِنَّا لَن نَّدْخُلَهَآ أَبَدًا مَّا دَامُوا۟ فِيهَا فَٱذْهَبْ أَنتَ وَرَبُّكَ فَقَٰتِلَآ إِنَّا هَٰهُنَا قَٰعِدُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@dcxciv{قَالَ رَبِّ إِنِّى لَآ أَمْلِكُ إِلَّا نَفْسِى وَأَخِى فَٱفْرُقْ بَيْنَنَا وَبَيْنَ ٱلْقَوْمِ ٱلْفَٰسِقِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@dcxcv{قَالَ فَإِنَّهَا مُحَرَّمَةٌ عَلَيْهِمْ أَرْبَعِينَ سَنَةً يَتِيهُونَ فِى ٱلْأَرْضِ فَلَا تَأْسَ عَلَى ٱلْقَوْمِ ٱلْفَٰسِقِينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@dcxcvi{وَٱتْلُ عَلَيْهِمْ نَبَأَ ٱبْنَىْ ءَادَمَ بِٱلْحَقِّ إِذْ قَرَّبَا قُرْبَانًا فَتُقُبِّلَ مِنْ أَحَدِهِمَا وَلَمْ يُتَقَبَّلْ مِنَ ٱلْءَاخَرِ قَالَ لَأَقْتُلَنَّكَ قَالَ إِنَّمَا يَتَقَبَّلُ ٱللَّهُ مِنَ ٱلْمُتَّقِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@dcxcvii{لَئِنۢ بَسَطتَ إِلَىَّ يَدَكَ لِتَقْتُلَنِى مَآ أَنَا۠ بِبَاسِطٍ يَدِىَ إِلَيْكَ لِأَقْتُلَكَ إِنِّىٓ أَخَافُ ٱللَّهَ رَبَّ ٱلْعَٰلَمِينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@dcxcviii{إِنِّىٓ أُرِيدُ أَن تَبُوٓأَ بِإِثْمِى وَإِثْمِكَ فَتَكُونَ مِنْ أَصْحَٰبِ ٱلنَّارِ وَذَٰلِكَ جَزَٰٓؤُا۟ ٱلظَّٰلِمِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@dcxcix{فَطَوَّعَتْ لَهُۥ نَفْسُهُۥ قَتْلَ أَخِيهِ فَقَتَلَهُۥ فَأَصْبَحَ مِنَ ٱلْخَٰسِرِينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@dcc{فَبَعَثَ ٱللَّهُ غُرَابًا يَبْحَثُ فِى ٱلْأَرْضِ لِيُرِيَهُۥ كَيْفَ يُوَٰرِى سَوْءَةَ أَخِيهِ قَالَ يَٰوَيْلَتَىٰٓ أَعَجَزْتُ أَنْ أَكُونَ مِثْلَ هَٰذَا ٱلْغُرَابِ فَأُوَٰرِىَ سَوْءَةَ أَخِى فَأَصْبَحَ مِنَ ٱلنَّٰدِمِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@dcci{مِنْ أَجْلِ ذَٰلِكَ كَتَبْنَا عَلَىٰ بَنِىٓ إِسْرَٰٓءِيلَ أَنَّهُۥ مَن قَتَلَ نَفْسًۢا بِغَيْرِ نَفْسٍ أَوْ فَسَادٍ فِى ٱلْأَرْضِ فَكَأَنَّمَا قَتَلَ ٱلنَّاسَ جَمِيعًا وَمَنْ أَحْيَاهَا فَكَأَنَّمَآ أَحْيَا ٱلنَّاسَ جَمِيعًا وَلَقَدْ جَآءَتْهُمْ رُسُلُنَا بِٱلْبَيِّنَٰتِ ثُمَّ إِنَّ كَثِيرًا مِّنْهُم بَعْدَ ذَٰلِكَ فِى ٱلْأَرْضِ لَمُسْرِفُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@dccii{إِنَّمَا جَزَٰٓؤُا۟ ٱلَّذِينَ يُحَارِبُونَ ٱللَّهَ وَرَسُولَهُۥ وَيَسْعَوْنَ فِى ٱلْأَرْضِ فَسَادًا أَن يُقَتَّلُوٓا۟ أَوْ يُصَلَّبُوٓا۟ أَوْ تُقَطَّعَ أَيْدِيهِمْ وَأَرْجُلُهُم مِّنْ خِلَٰفٍ أَوْ يُنفَوْا۟ مِنَ ٱلْأَرْضِ ذَٰلِكَ لَهُمْ خِزْىٌ فِى ٱلدُّنْيَا وَلَهُمْ فِى ٱلْءَاخِرَةِ عَذَابٌ عَظِيمٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@dcciii{إِلَّا ٱلَّذِينَ تَابُوا۟ مِن قَبْلِ أَن تَقْدِرُوا۟ عَلَيْهِمْ فَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@dcciv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱتَّقُوا۟ ٱللَّهَ وَٱبْتَغُوٓا۟ إِلَيْهِ ٱلْوَسِيلَةَ وَجَٰهِدُوا۟ فِى سَبِيلِهِۦ لَعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@dccv{إِنَّ ٱلَّذِينَ كَفَرُوا۟ لَوْ أَنَّ لَهُم مَّا فِى ٱلْأَرْضِ جَمِيعًا وَمِثْلَهُۥ مَعَهُۥ لِيَفْتَدُوا۟ بِهِۦ مِنْ عَذَابِ يَوْمِ ٱلْقِيَٰمَةِ مَا تُقُبِّلَ مِنْهُمْ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@dccvi{يُرِيدُونَ أَن يَخْرُجُوا۟ مِنَ ٱلنَّارِ وَمَا هُم بِخَٰرِجِينَ مِنْهَا وَلَهُمْ عَذَابٌ مُّقِيمٌ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@dccvii{وَٱلسَّارِقُ وَٱلسَّارِقَةُ فَٱقْطَعُوٓا۟ أَيْدِيَهُمَا جَزَآءًۢ بِمَا كَسَبَا نَكَٰلًا مِّنَ ٱللَّهِ وَٱللَّهُ عَزِيزٌ حَكِيمٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@dccviii{فَمَن تَابَ مِنۢ بَعْدِ ظُلْمِهِۦ وَأَصْلَحَ فَإِنَّ ٱللَّهَ يَتُوبُ عَلَيْهِ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@dccix{أَلَمْ تَعْلَمْ أَنَّ ٱللَّهَ لَهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ يُعَذِّبُ مَن يَشَآءُ وَيَغْفِرُ لِمَن يَشَآءُ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@dccx{يَٰٓأَيُّهَا ٱلرَّسُولُ لَا يَحْزُنكَ ٱلَّذِينَ يُسَٰرِعُونَ فِى ٱلْكُفْرِ مِنَ ٱلَّذِينَ قَالُوٓا۟ ءَامَنَّا بِأَفْوَٰهِهِمْ وَلَمْ تُؤْمِن قُلُوبُهُمْ وَمِنَ ٱلَّذِينَ هَادُوا۟ سَمَّٰعُونَ لِلْكَذِبِ سَمَّٰعُونَ لِقَوْمٍ ءَاخَرِينَ لَمْ يَأْتُوكَ يُحَرِّفُونَ ٱلْكَلِمَ مِنۢ بَعْدِ مَوَاضِعِهِۦ يَقُولُونَ إِنْ أُوتِيتُمْ هَٰذَا فَخُذُوهُ وَإِن لَّمْ تُؤْتَوْهُ فَٱحْذَرُوا۟ وَمَن يُرِدِ ٱللَّهُ فِتْنَتَهُۥ فَلَن تَمْلِكَ لَهُۥ مِنَ ٱللَّهِ شَيْـًٔا أُو۟لَٰٓئِكَ ٱلَّذِينَ لَمْ يُرِدِ ٱللَّهُ أَن يُطَهِّرَ قُلُوبَهُمْ لَهُمْ فِى ٱلدُّنْيَا خِزْىٌ وَلَهُمْ فِى ٱلْءَاخِرَةِ عَذَابٌ عَظِيمٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@dccxi{سَمَّٰعُونَ لِلْكَذِبِ أَكَّٰلُونَ لِلسُّحْتِ فَإِن جَآءُوكَ فَٱحْكُم بَيْنَهُمْ أَوْ أَعْرِضْ عَنْهُمْ وَإِن تُعْرِضْ عَنْهُمْ فَلَن يَضُرُّوكَ شَيْـًٔا وَإِنْ حَكَمْتَ فَٱحْكُم بَيْنَهُم بِٱلْقِسْطِ إِنَّ ٱللَّهَ يُحِبُّ ٱلْمُقْسِطِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@dccxii{وَكَيْفَ يُحَكِّمُونَكَ وَعِندَهُمُ ٱلتَّوْرَىٰةُ فِيهَا حُكْمُ ٱللَّهِ ثُمَّ يَتَوَلَّوْنَ مِنۢ بَعْدِ ذَٰلِكَ وَمَآ أُو۟لَٰٓئِكَ بِٱلْمُؤْمِنِينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@dccxiii{إِنَّآ أَنزَلْنَا ٱلتَّوْرَىٰةَ فِيهَا هُدًى وَنُورٌ يَحْكُمُ بِهَا ٱلنَّبِيُّونَ ٱلَّذِينَ أَسْلَمُوا۟ لِلَّذِينَ هَادُوا۟ وَٱلرَّبَّٰنِيُّونَ وَٱلْأَحْبَارُ بِمَا ٱسْتُحْفِظُوا۟ مِن كِتَٰبِ ٱللَّهِ وَكَانُوا۟ عَلَيْهِ شُهَدَآءَ فَلَا تَخْشَوُا۟ ٱلنَّاسَ وَٱخْشَوْنِ وَلَا تَشْتَرُوا۟ بِـَٔايَٰتِى ثَمَنًا قَلِيلًا وَمَن لَّمْ يَحْكُم بِمَآ أَنزَلَ ٱللَّهُ فَأُو۟لَٰٓئِكَ هُمُ ٱلْكَٰفِرُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@dccxiv{وَكَتَبْنَا عَلَيْهِمْ فِيهَآ أَنَّ ٱلنَّفْسَ بِٱلنَّفْسِ وَٱلْعَيْنَ بِٱلْعَيْنِ وَٱلْأَنفَ بِٱلْأَنفِ وَٱلْأُذُنَ بِٱلْأُذُنِ وَٱلسِّنَّ بِٱلسِّنِّ وَٱلْجُرُوحَ قِصَاصٌ فَمَن تَصَدَّقَ بِهِۦ فَهُوَ كَفَّارَةٌ لَّهُۥ وَمَن لَّمْ يَحْكُم بِمَآ أَنزَلَ ٱللَّهُ فَأُو۟لَٰٓئِكَ هُمُ ٱلظَّٰلِمُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@dccxv{وَقَفَّيْنَا عَلَىٰٓ ءَاثَٰرِهِم بِعِيسَى ٱبْنِ مَرْيَمَ مُصَدِّقًا لِّمَا بَيْنَ يَدَيْهِ مِنَ ٱلتَّوْرَىٰةِ وَءَاتَيْنَٰهُ ٱلْإِنجِيلَ فِيهِ هُدًى وَنُورٌ وَمُصَدِّقًا لِّمَا بَيْنَ يَدَيْهِ مِنَ ٱلتَّوْرَىٰةِ وَهُدًى وَمَوْعِظَةً لِّلْمُتَّقِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@dccxvi{وَلْيَحْكُمْ أَهْلُ ٱلْإِنجِيلِ بِمَآ أَنزَلَ ٱللَّهُ فِيهِ وَمَن لَّمْ يَحْكُم بِمَآ أَنزَلَ ٱللَّهُ فَأُو۟لَٰٓئِكَ هُمُ ٱلْفَٰسِقُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@dccxvii{وَأَنزَلْنَآ إِلَيْكَ ٱلْكِتَٰبَ بِٱلْحَقِّ مُصَدِّقًا لِّمَا بَيْنَ يَدَيْهِ مِنَ ٱلْكِتَٰبِ وَمُهَيْمِنًا عَلَيْهِ فَٱحْكُم بَيْنَهُم بِمَآ أَنزَلَ ٱللَّهُ وَلَا تَتَّبِعْ أَهْوَآءَهُمْ عَمَّا جَآءَكَ مِنَ ٱلْحَقِّ لِكُلٍّ جَعَلْنَا مِنكُمْ شِرْعَةً وَمِنْهَاجًا وَلَوْ شَآءَ ٱللَّهُ لَجَعَلَكُمْ أُمَّةً وَٰحِدَةً وَلَٰكِن لِّيَبْلُوَكُمْ فِى مَآ ءَاتَىٰكُمْ فَٱسْتَبِقُوا۟ ٱلْخَيْرَٰتِ إِلَى ٱللَّهِ مَرْجِعُكُمْ جَمِيعًا فَيُنَبِّئُكُم بِمَا كُنتُمْ فِيهِ تَخْتَلِفُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@dccxviii{وَأَنِ ٱحْكُم بَيْنَهُم بِمَآ أَنزَلَ ٱللَّهُ وَلَا تَتَّبِعْ أَهْوَآءَهُمْ وَٱحْذَرْهُمْ أَن يَفْتِنُوكَ عَنۢ بَعْضِ مَآ أَنزَلَ ٱللَّهُ إِلَيْكَ فَإِن تَوَلَّوْا۟ فَٱعْلَمْ أَنَّمَا يُرِيدُ ٱللَّهُ أَن يُصِيبَهُم بِبَعْضِ ذُنُوبِهِمْ وَإِنَّ كَثِيرًا مِّنَ ٱلنَّاسِ لَفَٰسِقُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@dccxix{أَفَحُكْمَ ٱلْجَٰهِلِيَّةِ يَبْغُونَ وَمَنْ أَحْسَنُ مِنَ ٱللَّهِ حُكْمًا لِّقَوْمٍ يُوقِنُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@dccxx{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَتَّخِذُوا۟ ٱلْيَهُودَ وَٱلنَّصَٰرَىٰٓ أَوْلِيَآءَ بَعْضُهُمْ أَوْلِيَآءُ بَعْضٍ وَمَن يَتَوَلَّهُم مِّنكُمْ فَإِنَّهُۥ مِنْهُمْ إِنَّ ٱللَّهَ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@dccxxi{فَتَرَى ٱلَّذِينَ فِى قُلُوبِهِم مَّرَضٌ يُسَٰرِعُونَ فِيهِمْ يَقُولُونَ نَخْشَىٰٓ أَن تُصِيبَنَا دَآئِرَةٌ فَعَسَى ٱللَّهُ أَن يَأْتِىَ بِٱلْفَتْحِ أَوْ أَمْرٍ مِّنْ عِندِهِۦ فَيُصْبِحُوا۟ عَلَىٰ مَآ أَسَرُّوا۟ فِىٓ أَنفُسِهِمْ نَٰدِمِينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@dccxxii{وَيَقُولُ ٱلَّذِينَ ءَامَنُوٓا۟ أَهَٰٓؤُلَآءِ ٱلَّذِينَ أَقْسَمُوا۟ بِٱللَّهِ جَهْدَ أَيْمَٰنِهِمْ إِنَّهُمْ لَمَعَكُمْ حَبِطَتْ أَعْمَٰلُهُمْ فَأَصْبَحُوا۟ خَٰسِرِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@dccxxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ مَن يَرْتَدَّ مِنكُمْ عَن دِينِهِۦ فَسَوْفَ يَأْتِى ٱللَّهُ بِقَوْمٍ يُحِبُّهُمْ وَيُحِبُّونَهُۥٓ أَذِلَّةٍ عَلَى ٱلْمُؤْمِنِينَ أَعِزَّةٍ عَلَى ٱلْكَٰفِرِينَ يُجَٰهِدُونَ فِى سَبِيلِ ٱللَّهِ وَلَا يَخَافُونَ لَوْمَةَ لَآئِمٍ ذَٰلِكَ فَضْلُ ٱللَّهِ يُؤْتِيهِ مَن يَشَآءُ وَٱللَّهُ وَٰسِعٌ عَلِيمٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@dccxxiv{إِنَّمَا وَلِيُّكُمُ ٱللَّهُ وَرَسُولُهُۥ وَٱلَّذِينَ ءَامَنُوا۟ ٱلَّذِينَ يُقِيمُونَ ٱلصَّلَوٰةَ وَيُؤْتُونَ ٱلزَّكَوٰةَ وَهُمْ رَٰكِعُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@dccxxv{وَمَن يَتَوَلَّ ٱللَّهَ وَرَسُولَهُۥ وَٱلَّذِينَ ءَامَنُوا۟ فَإِنَّ حِزْبَ ٱللَّهِ هُمُ ٱلْغَٰلِبُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@dccxxvi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَتَّخِذُوا۟ ٱلَّذِينَ ٱتَّخَذُوا۟ دِينَكُمْ هُزُوًا وَلَعِبًا مِّنَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ مِن قَبْلِكُمْ وَٱلْكُفَّارَ أَوْلِيَآءَ وَٱتَّقُوا۟ ٱللَّهَ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@dccxxvii{وَإِذَا نَادَيْتُمْ إِلَى ٱلصَّلَوٰةِ ٱتَّخَذُوهَا هُزُوًا وَلَعِبًا ذَٰلِكَ بِأَنَّهُمْ قَوْمٌ لَّا يَعْقِلُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@dccxxviii{قُلْ يَٰٓأَهْلَ ٱلْكِتَٰبِ هَلْ تَنقِمُونَ مِنَّآ إِلَّآ أَنْ ءَامَنَّا بِٱللَّهِ وَمَآ أُنزِلَ إِلَيْنَا وَمَآ أُنزِلَ مِن قَبْلُ وَأَنَّ أَكْثَرَكُمْ فَٰسِقُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@dccxxix{قُلْ هَلْ أُنَبِّئُكُم بِشَرٍّ مِّن ذَٰلِكَ مَثُوبَةً عِندَ ٱللَّهِ مَن لَّعَنَهُ ٱللَّهُ وَغَضِبَ عَلَيْهِ وَجَعَلَ مِنْهُمُ ٱلْقِرَدَةَ وَٱلْخَنَازِيرَ وَعَبَدَ ٱلطَّٰغُوتَ أُو۟لَٰٓئِكَ شَرٌّ مَّكَانًا وَأَضَلُّ عَن سَوَآءِ ٱلسَّبِيلِ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@dccxxx{وَإِذَا جَآءُوكُمْ قَالُوٓا۟ ءَامَنَّا وَقَد دَّخَلُوا۟ بِٱلْكُفْرِ وَهُمْ قَدْ خَرَجُوا۟ بِهِۦ وَٱللَّهُ أَعْلَمُ بِمَا كَانُوا۟ يَكْتُمُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@dccxxxi{وَتَرَىٰ كَثِيرًا مِّنْهُمْ يُسَٰرِعُونَ فِى ٱلْإِثْمِ وَٱلْعُدْوَٰنِ وَأَكْلِهِمُ ٱلسُّحْتَ لَبِئْسَ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@dccxxxii{لَوْلَا يَنْهَىٰهُمُ ٱلرَّبَّٰنِيُّونَ وَٱلْأَحْبَارُ عَن قَوْلِهِمُ ٱلْإِثْمَ وَأَكْلِهِمُ ٱلسُّحْتَ لَبِئْسَ مَا كَانُوا۟ يَصْنَعُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@dccxxxiii{وَقَالَتِ ٱلْيَهُودُ يَدُ ٱللَّهِ مَغْلُولَةٌ غُلَّتْ أَيْدِيهِمْ وَلُعِنُوا۟ بِمَا قَالُوا۟ بَلْ يَدَاهُ مَبْسُوطَتَانِ يُنفِقُ كَيْفَ يَشَآءُ وَلَيَزِيدَنَّ كَثِيرًا مِّنْهُم مَّآ أُنزِلَ إِلَيْكَ مِن رَّبِّكَ طُغْيَٰنًا وَكُفْرًا وَأَلْقَيْنَا بَيْنَهُمُ ٱلْعَدَٰوَةَ وَٱلْبَغْضَآءَ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ كُلَّمَآ أَوْقَدُوا۟ نَارًا لِّلْحَرْبِ أَطْفَأَهَا ٱللَّهُ وَيَسْعَوْنَ فِى ٱلْأَرْضِ فَسَادًا وَٱللَّهُ لَا يُحِبُّ ٱلْمُفْسِدِينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@dccxxxiv{وَلَوْ أَنَّ أَهْلَ ٱلْكِتَٰبِ ءَامَنُوا۟ وَٱتَّقَوْا۟ لَكَفَّرْنَا عَنْهُمْ سَيِّـَٔاتِهِمْ وَلَأَدْخَلْنَٰهُمْ جَنَّٰتِ ٱلنَّعِيمِ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@dccxxxv{وَلَوْ أَنَّهُمْ أَقَامُوا۟ ٱلتَّوْرَىٰةَ وَٱلْإِنجِيلَ وَمَآ أُنزِلَ إِلَيْهِم مِّن رَّبِّهِمْ لَأَكَلُوا۟ مِن فَوْقِهِمْ وَمِن تَحْتِ أَرْجُلِهِم مِّنْهُمْ أُمَّةٌ مُّقْتَصِدَةٌ وَكَثِيرٌ مِّنْهُمْ سَآءَ مَا يَعْمَلُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@dccxxxvi{يَٰٓأَيُّهَا ٱلرَّسُولُ بَلِّغْ مَآ أُنزِلَ إِلَيْكَ مِن رَّبِّكَ وَإِن لَّمْ تَفْعَلْ فَمَا بَلَّغْتَ رِسَالَتَهُۥ وَٱللَّهُ يَعْصِمُكَ مِنَ ٱلنَّاسِ إِنَّ ٱللَّهَ لَا يَهْدِى ٱلْقَوْمَ ٱلْكَٰفِرِينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@dccxxxvii{قُلْ يَٰٓأَهْلَ ٱلْكِتَٰبِ لَسْتُمْ عَلَىٰ شَىْءٍ حَتَّىٰ تُقِيمُوا۟ ٱلتَّوْرَىٰةَ وَٱلْإِنجِيلَ وَمَآ أُنزِلَ إِلَيْكُم مِّن رَّبِّكُمْ وَلَيَزِيدَنَّ كَثِيرًا مِّنْهُم مَّآ أُنزِلَ إِلَيْكَ مِن رَّبِّكَ طُغْيَٰنًا وَكُفْرًا فَلَا تَأْسَ عَلَى ٱلْقَوْمِ ٱلْكَٰفِرِينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@dccxxxviii{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَٱلَّذِينَ هَادُوا۟ وَٱلصَّٰبِـُٔونَ وَٱلنَّصَٰرَىٰ مَنْ ءَامَنَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَعَمِلَ صَٰلِحًا فَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@dccxxxix{لَقَدْ أَخَذْنَا مِيثَٰقَ بَنِىٓ إِسْرَٰٓءِيلَ وَأَرْسَلْنَآ إِلَيْهِمْ رُسُلًا كُلَّمَا جَآءَهُمْ رَسُولٌۢ بِمَا لَا تَهْوَىٰٓ أَنفُسُهُمْ فَرِيقًا كَذَّبُوا۟ وَفَرِيقًا يَقْتُلُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@dccxl{وَحَسِبُوٓا۟ أَلَّا تَكُونَ فِتْنَةٌ فَعَمُوا۟ وَصَمُّوا۟ ثُمَّ تَابَ ٱللَّهُ عَلَيْهِمْ ثُمَّ عَمُوا۟ وَصَمُّوا۟ كَثِيرٌ مِّنْهُمْ وَٱللَّهُ بَصِيرٌۢ بِمَا يَعْمَلُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@dccxli{لَقَدْ كَفَرَ ٱلَّذِينَ قَالُوٓا۟ إِنَّ ٱللَّهَ هُوَ ٱلْمَسِيحُ ٱبْنُ مَرْيَمَ وَقَالَ ٱلْمَسِيحُ يَٰبَنِىٓ إِسْرَٰٓءِيلَ ٱعْبُدُوا۟ ٱللَّهَ رَبِّى وَرَبَّكُمْ إِنَّهُۥ مَن يُشْرِكْ بِٱللَّهِ فَقَدْ حَرَّمَ ٱللَّهُ عَلَيْهِ ٱلْجَنَّةَ وَمَأْوَىٰهُ ٱلنَّارُ وَمَا لِلظَّٰلِمِينَ مِنْ أَنصَارٍ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@dccxlii{لَّقَدْ كَفَرَ ٱلَّذِينَ قَالُوٓا۟ إِنَّ ٱللَّهَ ثَالِثُ ثَلَٰثَةٍ وَمَا مِنْ إِلَٰهٍ إِلَّآ إِلَٰهٌ وَٰحِدٌ وَإِن لَّمْ يَنتَهُوا۟ عَمَّا يَقُولُونَ لَيَمَسَّنَّ ٱلَّذِينَ كَفَرُوا۟ مِنْهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@dccxliii{أَفَلَا يَتُوبُونَ إِلَى ٱللَّهِ وَيَسْتَغْفِرُونَهُۥ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@dccxliv{مَّا ٱلْمَسِيحُ ٱبْنُ مَرْيَمَ إِلَّا رَسُولٌ قَدْ خَلَتْ مِن قَبْلِهِ ٱلرُّسُلُ وَأُمُّهُۥ صِدِّيقَةٌ كَانَا يَأْكُلَانِ ٱلطَّعَامَ ٱنظُرْ كَيْفَ نُبَيِّنُ لَهُمُ ٱلْءَايَٰتِ ثُمَّ ٱنظُرْ أَنَّىٰ يُؤْفَكُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@dccxlv{قُلْ أَتَعْبُدُونَ مِن دُونِ ٱللَّهِ مَا لَا يَمْلِكُ لَكُمْ ضَرًّا وَلَا نَفْعًا وَٱللَّهُ هُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@dccxlvi{قُلْ يَٰٓأَهْلَ ٱلْكِتَٰبِ لَا تَغْلُوا۟ فِى دِينِكُمْ غَيْرَ ٱلْحَقِّ وَلَا تَتَّبِعُوٓا۟ أَهْوَآءَ قَوْمٍ قَدْ ضَلُّوا۟ مِن قَبْلُ وَأَضَلُّوا۟ كَثِيرًا وَضَلُّوا۟ عَن سَوَآءِ ٱلسَّبِيلِ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@dccxlvii{لُعِنَ ٱلَّذِينَ كَفَرُوا۟ مِنۢ بَنِىٓ إِسْرَٰٓءِيلَ عَلَىٰ لِسَانِ دَاوُۥدَ وَعِيسَى ٱبْنِ مَرْيَمَ ذَٰلِكَ بِمَا عَصَوا۟ وَّكَانُوا۟ يَعْتَدُونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@dccxlviii{كَانُوا۟ لَا يَتَنَاهَوْنَ عَن مُّنكَرٍ فَعَلُوهُ لَبِئْسَ مَا كَانُوا۟ يَفْعَلُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@dccxlix{تَرَىٰ كَثِيرًا مِّنْهُمْ يَتَوَلَّوْنَ ٱلَّذِينَ كَفَرُوا۟ لَبِئْسَ مَا قَدَّمَتْ لَهُمْ أَنفُسُهُمْ أَن سَخِطَ ٱللَّهُ عَلَيْهِمْ وَفِى ٱلْعَذَابِ هُمْ خَٰلِدُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@dccl{وَلَوْ كَانُوا۟ يُؤْمِنُونَ بِٱللَّهِ وَٱلنَّبِىِّ وَمَآ أُنزِلَ إِلَيْهِ مَا ٱتَّخَذُوهُمْ أَوْلِيَآءَ وَلَٰكِنَّ كَثِيرًا مِّنْهُمْ فَٰسِقُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@dccli{لَتَجِدَنَّ أَشَدَّ ٱلنَّاسِ عَدَٰوَةً لِّلَّذِينَ ءَامَنُوا۟ ٱلْيَهُودَ وَٱلَّذِينَ أَشْرَكُوا۟ وَلَتَجِدَنَّ أَقْرَبَهُم مَّوَدَّةً لِّلَّذِينَ ءَامَنُوا۟ ٱلَّذِينَ قَالُوٓا۟ إِنَّا نَصَٰرَىٰ ذَٰلِكَ بِأَنَّ مِنْهُمْ قِسِّيسِينَ وَرُهْبَانًا وَأَنَّهُمْ لَا يَسْتَكْبِرُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@dcclii{وَإِذَا سَمِعُوا۟ مَآ أُنزِلَ إِلَى ٱلرَّسُولِ تَرَىٰٓ أَعْيُنَهُمْ تَفِيضُ مِنَ ٱلدَّمْعِ مِمَّا عَرَفُوا۟ مِنَ ٱلْحَقِّ يَقُولُونَ رَبَّنَآ ءَامَنَّا فَٱكْتُبْنَا مَعَ ٱلشَّٰهِدِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@dccliii{وَمَا لَنَا لَا نُؤْمِنُ بِٱللَّهِ وَمَا جَآءَنَا مِنَ ٱلْحَقِّ وَنَطْمَعُ أَن يُدْخِلَنَا رَبُّنَا مَعَ ٱلْقَوْمِ ٱلصَّٰلِحِينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@dccliv{فَأَثَٰبَهُمُ ٱللَّهُ بِمَا قَالُوا۟ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا وَذَٰلِكَ جَزَآءُ ٱلْمُحْسِنِينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@dcclv{وَٱلَّذِينَ كَفَرُوا۟ وَكَذَّبُوا۟ بِـَٔايَٰتِنَآ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْجَحِيمِ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@dcclvi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تُحَرِّمُوا۟ طَيِّبَٰتِ مَآ أَحَلَّ ٱللَّهُ لَكُمْ وَلَا تَعْتَدُوٓا۟ إِنَّ ٱللَّهَ لَا يُحِبُّ ٱلْمُعْتَدِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@dcclvii{وَكُلُوا۟ مِمَّا رَزَقَكُمُ ٱللَّهُ حَلَٰلًا طَيِّبًا وَٱتَّقُوا۟ ٱللَّهَ ٱلَّذِىٓ أَنتُم بِهِۦ مُؤْمِنُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@dcclviii{لَا يُؤَاخِذُكُمُ ٱللَّهُ بِٱللَّغْوِ فِىٓ أَيْمَٰنِكُمْ وَلَٰكِن يُؤَاخِذُكُم بِمَا عَقَّدتُّمُ ٱلْأَيْمَٰنَ فَكَفَّٰرَتُهُۥٓ إِطْعَامُ عَشَرَةِ مَسَٰكِينَ مِنْ أَوْسَطِ مَا تُطْعِمُونَ أَهْلِيكُمْ أَوْ كِسْوَتُهُمْ أَوْ تَحْرِيرُ رَقَبَةٍ فَمَن لَّمْ يَجِدْ فَصِيَامُ ثَلَٰثَةِ أَيَّامٍ ذَٰلِكَ كَفَّٰرَةُ أَيْمَٰنِكُمْ إِذَا حَلَفْتُمْ وَٱحْفَظُوٓا۟ أَيْمَٰنَكُمْ كَذَٰلِكَ يُبَيِّنُ ٱللَّهُ لَكُمْ ءَايَٰتِهِۦ لَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@dcclix{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِنَّمَا ٱلْخَمْرُ وَٱلْمَيْسِرُ وَٱلْأَنصَابُ وَٱلْأَزْلَٰمُ رِجْسٌ مِّنْ عَمَلِ ٱلشَّيْطَٰنِ فَٱجْتَنِبُوهُ لَعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@dcclx{إِنَّمَا يُرِيدُ ٱلشَّيْطَٰنُ أَن يُوقِعَ بَيْنَكُمُ ٱلْعَدَٰوَةَ وَٱلْبَغْضَآءَ فِى ٱلْخَمْرِ وَٱلْمَيْسِرِ وَيَصُدَّكُمْ عَن ذِكْرِ ٱللَّهِ وَعَنِ ٱلصَّلَوٰةِ فَهَلْ أَنتُم مُّنتَهُونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@dcclxi{وَأَطِيعُوا۟ ٱللَّهَ وَأَطِيعُوا۟ ٱلرَّسُولَ وَٱحْذَرُوا۟ فَإِن تَوَلَّيْتُمْ فَٱعْلَمُوٓا۟ أَنَّمَا عَلَىٰ رَسُولِنَا ٱلْبَلَٰغُ ٱلْمُبِينُ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@dcclxii{لَيْسَ عَلَى ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ جُنَاحٌ فِيمَا طَعِمُوٓا۟ إِذَا مَا ٱتَّقَوا۟ وَّءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ ثُمَّ ٱتَّقَوا۟ وَّءَامَنُوا۟ ثُمَّ ٱتَّقَوا۟ وَّأَحْسَنُوا۟ وَٱللَّهُ يُحِبُّ ٱلْمُحْسِنِينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@dcclxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَيَبْلُوَنَّكُمُ ٱللَّهُ بِشَىْءٍ مِّنَ ٱلصَّيْدِ تَنَالُهُۥٓ أَيْدِيكُمْ وَرِمَاحُكُمْ لِيَعْلَمَ ٱللَّهُ مَن يَخَافُهُۥ بِٱلْغَيْبِ فَمَنِ ٱعْتَدَىٰ بَعْدَ ذَٰلِكَ فَلَهُۥ عَذَابٌ أَلِيمٌ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@dcclxiv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَقْتُلُوا۟ ٱلصَّيْدَ وَأَنتُمْ حُرُمٌ وَمَن قَتَلَهُۥ مِنكُم مُّتَعَمِّدًا فَجَزَآءٌ مِّثْلُ مَا قَتَلَ مِنَ ٱلنَّعَمِ يَحْكُمُ بِهِۦ ذَوَا عَدْلٍ مِّنكُمْ هَدْيًۢا بَٰلِغَ ٱلْكَعْبَةِ أَوْ كَفَّٰرَةٌ طَعَامُ مَسَٰكِينَ أَوْ عَدْلُ ذَٰلِكَ صِيَامًا لِّيَذُوقَ وَبَالَ أَمْرِهِۦ عَفَا ٱللَّهُ عَمَّا سَلَفَ وَمَنْ عَادَ فَيَنتَقِمُ ٱللَّهُ مِنْهُ وَٱللَّهُ عَزِيزٌ ذُو ٱنتِقَامٍ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@dcclxv{أُحِلَّ لَكُمْ صَيْدُ ٱلْبَحْرِ وَطَعَامُهُۥ مَتَٰعًا لَّكُمْ وَلِلسَّيَّارَةِ وَحُرِّمَ عَلَيْكُمْ صَيْدُ ٱلْبَرِّ مَا دُمْتُمْ حُرُمًا وَٱتَّقُوا۟ ٱللَّهَ ٱلَّذِىٓ إِلَيْهِ تُحْشَرُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@dcclxvi{جَعَلَ ٱللَّهُ ٱلْكَعْبَةَ ٱلْبَيْتَ ٱلْحَرَامَ قِيَٰمًا لِّلنَّاسِ وَٱلشَّهْرَ ٱلْحَرَامَ وَٱلْهَدْىَ وَٱلْقَلَٰٓئِدَ ذَٰلِكَ لِتَعْلَمُوٓا۟ أَنَّ ٱللَّهَ يَعْلَمُ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَأَنَّ ٱللَّهَ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@dcclxvii{ٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ شَدِيدُ ٱلْعِقَابِ وَأَنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@dcclxviii{مَّا عَلَى ٱلرَّسُولِ إِلَّا ٱلْبَلَٰغُ وَٱللَّهُ يَعْلَمُ مَا تُبْدُونَ وَمَا تَكْتُمُونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@dcclxix{قُل لَّا يَسْتَوِى ٱلْخَبِيثُ وَٱلطَّيِّبُ وَلَوْ أَعْجَبَكَ كَثْرَةُ ٱلْخَبِيثِ فَٱتَّقُوا۟ ٱللَّهَ يَٰٓأُو۟لِى ٱلْأَلْبَٰبِ لَعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@dcclxx{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَسْـَٔلُوا۟ عَنْ أَشْيَآءَ إِن تُبْدَ لَكُمْ تَسُؤْكُمْ وَإِن تَسْـَٔلُوا۟ عَنْهَا حِينَ يُنَزَّلُ ٱلْقُرْءَانُ تُبْدَ لَكُمْ عَفَا ٱللَّهُ عَنْهَا وَٱللَّهُ غَفُورٌ حَلِيمٌ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@dcclxxi{قَدْ سَأَلَهَا قَوْمٌ مِّن قَبْلِكُمْ ثُمَّ أَصْبَحُوا۟ بِهَا كَٰفِرِينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@dcclxxii{مَا جَعَلَ ٱللَّهُ مِنۢ بَحِيرَةٍ وَلَا سَآئِبَةٍ وَلَا وَصِيلَةٍ وَلَا حَامٍ وَلَٰكِنَّ ٱلَّذِينَ كَفَرُوا۟ يَفْتَرُونَ عَلَى ٱللَّهِ ٱلْكَذِبَ وَأَكْثَرُهُمْ لَا يَعْقِلُونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@dcclxxiii{وَإِذَا قِيلَ لَهُمْ تَعَالَوْا۟ إِلَىٰ مَآ أَنزَلَ ٱللَّهُ وَإِلَى ٱلرَّسُولِ قَالُوا۟ حَسْبُنَا مَا وَجَدْنَا عَلَيْهِ ءَابَآءَنَآ أَوَلَوْ كَانَ ءَابَآؤُهُمْ لَا يَعْلَمُونَ شَيْـًٔا وَلَا يَهْتَدُونَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@dcclxxiv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ عَلَيْكُمْ أَنفُسَكُمْ لَا يَضُرُّكُم مَّن ضَلَّ إِذَا ٱهْتَدَيْتُمْ إِلَى ٱللَّهِ مَرْجِعُكُمْ جَمِيعًا فَيُنَبِّئُكُم بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@dcclxxv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ شَهَٰدَةُ بَيْنِكُمْ إِذَا حَضَرَ أَحَدَكُمُ ٱلْمَوْتُ حِينَ ٱلْوَصِيَّةِ ٱثْنَانِ ذَوَا عَدْلٍ مِّنكُمْ أَوْ ءَاخَرَانِ مِنْ غَيْرِكُمْ إِنْ أَنتُمْ ضَرَبْتُمْ فِى ٱلْأَرْضِ فَأَصَٰبَتْكُم مُّصِيبَةُ ٱلْمَوْتِ تَحْبِسُونَهُمَا مِنۢ بَعْدِ ٱلصَّلَوٰةِ فَيُقْسِمَانِ بِٱللَّهِ إِنِ ٱرْتَبْتُمْ لَا نَشْتَرِى بِهِۦ ثَمَنًا وَلَوْ كَانَ ذَا قُرْبَىٰ وَلَا نَكْتُمُ شَهَٰدَةَ ٱللَّهِ إِنَّآ إِذًا لَّمِنَ ٱلْءَاثِمِينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@dcclxxvi{فَإِنْ عُثِرَ عَلَىٰٓ أَنَّهُمَا ٱسْتَحَقَّآ إِثْمًا فَـَٔاخَرَانِ يَقُومَانِ مَقَامَهُمَا مِنَ ٱلَّذِينَ ٱسْتَحَقَّ عَلَيْهِمُ ٱلْأَوْلَيَٰنِ فَيُقْسِمَانِ بِٱللَّهِ لَشَهَٰدَتُنَآ أَحَقُّ مِن شَهَٰدَتِهِمَا وَمَا ٱعْتَدَيْنَآ إِنَّآ إِذًا لَّمِنَ ٱلظَّٰلِمِينَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@dcclxxvii{ذَٰلِكَ أَدْنَىٰٓ أَن يَأْتُوا۟ بِٱلشَّهَٰدَةِ عَلَىٰ وَجْهِهَآ أَوْ يَخَافُوٓا۟ أَن تُرَدَّ أَيْمَٰنٌۢ بَعْدَ أَيْمَٰنِهِمْ وَٱتَّقُوا۟ ٱللَّهَ وَٱسْمَعُوا۟ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلْفَٰسِقِينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@dcclxxviii{يَوْمَ يَجْمَعُ ٱللَّهُ ٱلرُّسُلَ فَيَقُولُ مَاذَآ أُجِبْتُمْ قَالُوا۟ لَا عِلْمَ لَنَآ إِنَّكَ أَنتَ عَلَّٰمُ ٱلْغُيُوبِ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@dcclxxix{إِذْ قَالَ ٱللَّهُ يَٰعِيسَى ٱبْنَ مَرْيَمَ ٱذْكُرْ نِعْمَتِى عَلَيْكَ وَعَلَىٰ وَٰلِدَتِكَ إِذْ أَيَّدتُّكَ بِرُوحِ ٱلْقُدُسِ تُكَلِّمُ ٱلنَّاسَ فِى ٱلْمَهْدِ وَكَهْلًا وَإِذْ عَلَّمْتُكَ ٱلْكِتَٰبَ وَٱلْحِكْمَةَ وَٱلتَّوْرَىٰةَ وَٱلْإِنجِيلَ وَإِذْ تَخْلُقُ مِنَ ٱلطِّينِ كَهَيْـَٔةِ ٱلطَّيْرِ بِإِذْنِى فَتَنفُخُ فِيهَا فَتَكُونُ طَيْرًۢا بِإِذْنِى وَتُبْرِئُ ٱلْأَكْمَهَ وَٱلْأَبْرَصَ بِإِذْنِى وَإِذْ تُخْرِجُ ٱلْمَوْتَىٰ بِإِذْنِى وَإِذْ كَفَفْتُ بَنِىٓ إِسْرَٰٓءِيلَ عَنكَ إِذْ جِئْتَهُم بِٱلْبَيِّنَٰتِ فَقَالَ ٱلَّذِينَ كَفَرُوا۟ مِنْهُمْ إِنْ هَٰذَآ إِلَّا سِحْرٌ مُّبِينٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@dcclxxx{وَإِذْ أَوْحَيْتُ إِلَى ٱلْحَوَارِيِّۦنَ أَنْ ءَامِنُوا۟ بِى وَبِرَسُولِى قَالُوٓا۟ ءَامَنَّا وَٱشْهَدْ بِأَنَّنَا مُسْلِمُونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@dcclxxxi{إِذْ قَالَ ٱلْحَوَارِيُّونَ يَٰعِيسَى ٱبْنَ مَرْيَمَ هَلْ يَسْتَطِيعُ رَبُّكَ أَن يُنَزِّلَ عَلَيْنَا مَآئِدَةً مِّنَ ٱلسَّمَآءِ قَالَ ٱتَّقُوا۟ ٱللَّهَ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@dcclxxxii{قَالُوا۟ نُرِيدُ أَن نَّأْكُلَ مِنْهَا وَتَطْمَئِنَّ قُلُوبُنَا وَنَعْلَمَ أَن قَدْ صَدَقْتَنَا وَنَكُونَ عَلَيْهَا مِنَ ٱلشَّٰهِدِينَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@dcclxxxiii{قَالَ عِيسَى ٱبْنُ مَرْيَمَ ٱللَّهُمَّ رَبَّنَآ أَنزِلْ عَلَيْنَا مَآئِدَةً مِّنَ ٱلسَّمَآءِ تَكُونُ لَنَا عِيدًا لِّأَوَّلِنَا وَءَاخِرِنَا وَءَايَةً مِّنكَ وَٱرْزُقْنَا وَأَنتَ خَيْرُ ٱلرَّٰزِقِينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@dcclxxxiv{قَالَ ٱللَّهُ إِنِّى مُنَزِّلُهَا عَلَيْكُمْ فَمَن يَكْفُرْ بَعْدُ مِنكُمْ فَإِنِّىٓ أُعَذِّبُهُۥ عَذَابًا لَّآ أُعَذِّبُهُۥٓ أَحَدًا مِّنَ ٱلْعَٰلَمِينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@dcclxxxv{وَإِذْ قَالَ ٱللَّهُ يَٰعِيسَى ٱبْنَ مَرْيَمَ ءَأَنتَ قُلْتَ لِلنَّاسِ ٱتَّخِذُونِى وَأُمِّىَ إِلَٰهَيْنِ مِن دُونِ ٱللَّهِ قَالَ سُبْحَٰنَكَ مَا يَكُونُ لِىٓ أَنْ أَقُولَ مَا لَيْسَ لِى بِحَقٍّ إِن كُنتُ قُلْتُهُۥ فَقَدْ عَلِمْتَهُۥ تَعْلَمُ مَا فِى نَفْسِى وَلَآ أَعْلَمُ مَا فِى نَفْسِكَ إِنَّكَ أَنتَ عَلَّٰمُ ٱلْغُيُوبِ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@dcclxxxvi{مَا قُلْتُ لَهُمْ إِلَّا مَآ أَمَرْتَنِى بِهِۦٓ أَنِ ٱعْبُدُوا۟ ٱللَّهَ رَبِّى وَرَبَّكُمْ وَكُنتُ عَلَيْهِمْ شَهِيدًا مَّا دُمْتُ فِيهِمْ فَلَمَّا تَوَفَّيْتَنِى كُنتَ أَنتَ ٱلرَّقِيبَ عَلَيْهِمْ وَأَنتَ عَلَىٰ كُلِّ شَىْءٍ شَهِيدٌ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@dcclxxxvii{إِن تُعَذِّبْهُمْ فَإِنَّهُمْ عِبَادُكَ وَإِن تَغْفِرْ لَهُمْ فَإِنَّكَ أَنتَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@dcclxxxviii{قَالَ ٱللَّهُ هَٰذَا يَوْمُ يَنفَعُ ٱلصَّٰدِقِينَ صِدْقُهُمْ لَهُمْ جَنَّٰتٌ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَآ أَبَدًا رَّضِىَ ٱللَّهُ عَنْهُمْ وَرَضُوا۟ عَنْهُ ذَٰلِكَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@dcclxxxix{لِلَّهِ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا فِيهِنَّ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌۢ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@dccxc{\basmalah ٱلْحَمْدُ لِلَّهِ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَجَعَلَ ٱلظُّلُمَٰتِ وَٱلنُّورَ ثُمَّ ٱلَّذِينَ كَفَرُوا۟ بِرَبِّهِمْ يَعْدِلُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@dccxci{هُوَ ٱلَّذِى خَلَقَكُم مِّن طِينٍ ثُمَّ قَضَىٰٓ أَجَلًا وَأَجَلٌ مُّسَمًّى عِندَهُۥ ثُمَّ أَنتُمْ تَمْتَرُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@dccxcii{وَهُوَ ٱللَّهُ فِى ٱلسَّمَٰوَٰتِ وَفِى ٱلْأَرْضِ يَعْلَمُ سِرَّكُمْ وَجَهْرَكُمْ وَيَعْلَمُ مَا تَكْسِبُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@dccxciii{وَمَا تَأْتِيهِم مِّنْ ءَايَةٍ مِّنْ ءَايَٰتِ رَبِّهِمْ إِلَّا كَانُوا۟ عَنْهَا مُعْرِضِينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@dccxciv{فَقَدْ كَذَّبُوا۟ بِٱلْحَقِّ لَمَّا جَآءَهُمْ فَسَوْفَ يَأْتِيهِمْ أَنۢبَٰٓؤُا۟ مَا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@dccxcv{أَلَمْ يَرَوْا۟ كَمْ أَهْلَكْنَا مِن قَبْلِهِم مِّن قَرْنٍ مَّكَّنَّٰهُمْ فِى ٱلْأَرْضِ مَا لَمْ نُمَكِّن لَّكُمْ وَأَرْسَلْنَا ٱلسَّمَآءَ عَلَيْهِم مِّدْرَارًا وَجَعَلْنَا ٱلْأَنْهَٰرَ تَجْرِى مِن تَحْتِهِمْ فَأَهْلَكْنَٰهُم بِذُنُوبِهِمْ وَأَنشَأْنَا مِنۢ بَعْدِهِمْ قَرْنًا ءَاخَرِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@dccxcvi{وَلَوْ نَزَّلْنَا عَلَيْكَ كِتَٰبًا فِى قِرْطَاسٍ فَلَمَسُوهُ بِأَيْدِيهِمْ لَقَالَ ٱلَّذِينَ كَفَرُوٓا۟ إِنْ هَٰذَآ إِلَّا سِحْرٌ مُّبِينٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@dccxcvii{وَقَالُوا۟ لَوْلَآ أُنزِلَ عَلَيْهِ مَلَكٌ وَلَوْ أَنزَلْنَا مَلَكًا لَّقُضِىَ ٱلْأَمْرُ ثُمَّ لَا يُنظَرُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@dccxcviii{وَلَوْ جَعَلْنَٰهُ مَلَكًا لَّجَعَلْنَٰهُ رَجُلًا وَلَلَبَسْنَا عَلَيْهِم مَّا يَلْبِسُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@dccxcix{وَلَقَدِ ٱسْتُهْزِئَ بِرُسُلٍ مِّن قَبْلِكَ فَحَاقَ بِٱلَّذِينَ سَخِرُوا۟ مِنْهُم مَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@dccc{قُلْ سِيرُوا۟ فِى ٱلْأَرْضِ ثُمَّ ٱنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُكَذِّبِينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@dccci{قُل لِّمَن مَّا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ قُل لِّلَّهِ كَتَبَ عَلَىٰ نَفْسِهِ ٱلرَّحْمَةَ لَيَجْمَعَنَّكُمْ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ لَا رَيْبَ فِيهِ ٱلَّذِينَ خَسِرُوٓا۟ أَنفُسَهُمْ فَهُمْ لَا يُؤْمِنُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@dcccii{وَلَهُۥ مَا سَكَنَ فِى ٱلَّيْلِ وَٱلنَّهَارِ وَهُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@dccciii{قُلْ أَغَيْرَ ٱللَّهِ أَتَّخِذُ وَلِيًّا فَاطِرِ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَهُوَ يُطْعِمُ وَلَا يُطْعَمُ قُلْ إِنِّىٓ أُمِرْتُ أَنْ أَكُونَ أَوَّلَ مَنْ أَسْلَمَ وَلَا تَكُونَنَّ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@dccciv{قُلْ إِنِّىٓ أَخَافُ إِنْ عَصَيْتُ رَبِّى عَذَابَ يَوْمٍ عَظِيمٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@dcccv{مَّن يُصْرَفْ عَنْهُ يَوْمَئِذٍ فَقَدْ رَحِمَهُۥ وَذَٰلِكَ ٱلْفَوْزُ ٱلْمُبِينُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@dcccvi{وَإِن يَمْسَسْكَ ٱللَّهُ بِضُرٍّ فَلَا كَاشِفَ لَهُۥٓ إِلَّا هُوَ وَإِن يَمْسَسْكَ بِخَيْرٍ فَهُوَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@dcccvii{وَهُوَ ٱلْقَاهِرُ فَوْقَ عِبَادِهِۦ وَهُوَ ٱلْحَكِيمُ ٱلْخَبِيرُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@dcccviii{قُلْ أَىُّ شَىْءٍ أَكْبَرُ شَهَٰدَةً قُلِ ٱللَّهُ شَهِيدٌۢ بَيْنِى وَبَيْنَكُمْ وَأُوحِىَ إِلَىَّ هَٰذَا ٱلْقُرْءَانُ لِأُنذِرَكُم بِهِۦ وَمَنۢ بَلَغَ أَئِنَّكُمْ لَتَشْهَدُونَ أَنَّ مَعَ ٱللَّهِ ءَالِهَةً أُخْرَىٰ قُل لَّآ أَشْهَدُ قُلْ إِنَّمَا هُوَ إِلَٰهٌ وَٰحِدٌ وَإِنَّنِى بَرِىٓءٌ مِّمَّا تُشْرِكُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@dcccix{ٱلَّذِينَ ءَاتَيْنَٰهُمُ ٱلْكِتَٰبَ يَعْرِفُونَهُۥ كَمَا يَعْرِفُونَ أَبْنَآءَهُمُ ٱلَّذِينَ خَسِرُوٓا۟ أَنفُسَهُمْ فَهُمْ لَا يُؤْمِنُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@dcccx{وَمَنْ أَظْلَمُ مِمَّنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا أَوْ كَذَّبَ بِـَٔايَٰتِهِۦٓ إِنَّهُۥ لَا يُفْلِحُ ٱلظَّٰلِمُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@dcccxi{وَيَوْمَ نَحْشُرُهُمْ جَمِيعًا ثُمَّ نَقُولُ لِلَّذِينَ أَشْرَكُوٓا۟ أَيْنَ شُرَكَآؤُكُمُ ٱلَّذِينَ كُنتُمْ تَزْعُمُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@dcccxii{ثُمَّ لَمْ تَكُن فِتْنَتُهُمْ إِلَّآ أَن قَالُوا۟ وَٱللَّهِ رَبِّنَا مَا كُنَّا مُشْرِكِينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@dcccxiii{ٱنظُرْ كَيْفَ كَذَبُوا۟ عَلَىٰٓ أَنفُسِهِمْ وَضَلَّ عَنْهُم مَّا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@dcccxiv{وَمِنْهُم مَّن يَسْتَمِعُ إِلَيْكَ وَجَعَلْنَا عَلَىٰ قُلُوبِهِمْ أَكِنَّةً أَن يَفْقَهُوهُ وَفِىٓ ءَاذَانِهِمْ وَقْرًا وَإِن يَرَوْا۟ كُلَّ ءَايَةٍ لَّا يُؤْمِنُوا۟ بِهَا حَتَّىٰٓ إِذَا جَآءُوكَ يُجَٰدِلُونَكَ يَقُولُ ٱلَّذِينَ كَفَرُوٓا۟ إِنْ هَٰذَآ إِلَّآ أَسَٰطِيرُ ٱلْأَوَّلِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@dcccxv{وَهُمْ يَنْهَوْنَ عَنْهُ وَيَنْـَٔوْنَ عَنْهُ وَإِن يُهْلِكُونَ إِلَّآ أَنفُسَهُمْ وَمَا يَشْعُرُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@dcccxvi{وَلَوْ تَرَىٰٓ إِذْ وُقِفُوا۟ عَلَى ٱلنَّارِ فَقَالُوا۟ يَٰلَيْتَنَا نُرَدُّ وَلَا نُكَذِّبَ بِـَٔايَٰتِ رَبِّنَا وَنَكُونَ مِنَ ٱلْمُؤْمِنِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@dcccxvii{بَلْ بَدَا لَهُم مَّا كَانُوا۟ يُخْفُونَ مِن قَبْلُ وَلَوْ رُدُّوا۟ لَعَادُوا۟ لِمَا نُهُوا۟ عَنْهُ وَإِنَّهُمْ لَكَٰذِبُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@dcccxviii{وَقَالُوٓا۟ إِنْ هِىَ إِلَّا حَيَاتُنَا ٱلدُّنْيَا وَمَا نَحْنُ بِمَبْعُوثِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@dcccxix{وَلَوْ تَرَىٰٓ إِذْ وُقِفُوا۟ عَلَىٰ رَبِّهِمْ قَالَ أَلَيْسَ هَٰذَا بِٱلْحَقِّ قَالُوا۟ بَلَىٰ وَرَبِّنَا قَالَ فَذُوقُوا۟ ٱلْعَذَابَ بِمَا كُنتُمْ تَكْفُرُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@dcccxx{قَدْ خَسِرَ ٱلَّذِينَ كَذَّبُوا۟ بِلِقَآءِ ٱللَّهِ حَتَّىٰٓ إِذَا جَآءَتْهُمُ ٱلسَّاعَةُ بَغْتَةً قَالُوا۟ يَٰحَسْرَتَنَا عَلَىٰ مَا فَرَّطْنَا فِيهَا وَهُمْ يَحْمِلُونَ أَوْزَارَهُمْ عَلَىٰ ظُهُورِهِمْ أَلَا سَآءَ مَا يَزِرُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@dcccxxi{وَمَا ٱلْحَيَوٰةُ ٱلدُّنْيَآ إِلَّا لَعِبٌ وَلَهْوٌ وَلَلدَّارُ ٱلْءَاخِرَةُ خَيْرٌ لِّلَّذِينَ يَتَّقُونَ أَفَلَا تَعْقِلُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@dcccxxii{قَدْ نَعْلَمُ إِنَّهُۥ لَيَحْزُنُكَ ٱلَّذِى يَقُولُونَ فَإِنَّهُمْ لَا يُكَذِّبُونَكَ وَلَٰكِنَّ ٱلظَّٰلِمِينَ بِـَٔايَٰتِ ٱللَّهِ يَجْحَدُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@dcccxxiii{وَلَقَدْ كُذِّبَتْ رُسُلٌ مِّن قَبْلِكَ فَصَبَرُوا۟ عَلَىٰ مَا كُذِّبُوا۟ وَأُوذُوا۟ حَتَّىٰٓ أَتَىٰهُمْ نَصْرُنَا وَلَا مُبَدِّلَ لِكَلِمَٰتِ ٱللَّهِ وَلَقَدْ جَآءَكَ مِن نَّبَإِى۟ ٱلْمُرْسَلِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@dcccxxiv{وَإِن كَانَ كَبُرَ عَلَيْكَ إِعْرَاضُهُمْ فَإِنِ ٱسْتَطَعْتَ أَن تَبْتَغِىَ نَفَقًا فِى ٱلْأَرْضِ أَوْ سُلَّمًا فِى ٱلسَّمَآءِ فَتَأْتِيَهُم بِـَٔايَةٍ وَلَوْ شَآءَ ٱللَّهُ لَجَمَعَهُمْ عَلَى ٱلْهُدَىٰ فَلَا تَكُونَنَّ مِنَ ٱلْجَٰهِلِينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@dcccxxv{إِنَّمَا يَسْتَجِيبُ ٱلَّذِينَ يَسْمَعُونَ وَٱلْمَوْتَىٰ يَبْعَثُهُمُ ٱللَّهُ ثُمَّ إِلَيْهِ يُرْجَعُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@dcccxxvi{وَقَالُوا۟ لَوْلَا نُزِّلَ عَلَيْهِ ءَايَةٌ مِّن رَّبِّهِۦ قُلْ إِنَّ ٱللَّهَ قَادِرٌ عَلَىٰٓ أَن يُنَزِّلَ ءَايَةً وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَعْلَمُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@dcccxxvii{وَمَا مِن دَآبَّةٍ فِى ٱلْأَرْضِ وَلَا طَٰٓئِرٍ يَطِيرُ بِجَنَاحَيْهِ إِلَّآ أُمَمٌ أَمْثَالُكُم مَّا فَرَّطْنَا فِى ٱلْكِتَٰبِ مِن شَىْءٍ ثُمَّ إِلَىٰ رَبِّهِمْ يُحْشَرُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@dcccxxviii{وَٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا صُمٌّ وَبُكْمٌ فِى ٱلظُّلُمَٰتِ مَن يَشَإِ ٱللَّهُ يُضْلِلْهُ وَمَن يَشَأْ يَجْعَلْهُ عَلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@dcccxxix{قُلْ أَرَءَيْتَكُمْ إِنْ أَتَىٰكُمْ عَذَابُ ٱللَّهِ أَوْ أَتَتْكُمُ ٱلسَّاعَةُ أَغَيْرَ ٱللَّهِ تَدْعُونَ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@dcccxxx{بَلْ إِيَّاهُ تَدْعُونَ فَيَكْشِفُ مَا تَدْعُونَ إِلَيْهِ إِن شَآءَ وَتَنسَوْنَ مَا تُشْرِكُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@dcccxxxi{وَلَقَدْ أَرْسَلْنَآ إِلَىٰٓ أُمَمٍ مِّن قَبْلِكَ فَأَخَذْنَٰهُم بِٱلْبَأْسَآءِ وَٱلضَّرَّآءِ لَعَلَّهُمْ يَتَضَرَّعُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@dcccxxxii{فَلَوْلَآ إِذْ جَآءَهُم بَأْسُنَا تَضَرَّعُوا۟ وَلَٰكِن قَسَتْ قُلُوبُهُمْ وَزَيَّنَ لَهُمُ ٱلشَّيْطَٰنُ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@dcccxxxiii{فَلَمَّا نَسُوا۟ مَا ذُكِّرُوا۟ بِهِۦ فَتَحْنَا عَلَيْهِمْ أَبْوَٰبَ كُلِّ شَىْءٍ حَتَّىٰٓ إِذَا فَرِحُوا۟ بِمَآ أُوتُوٓا۟ أَخَذْنَٰهُم بَغْتَةً فَإِذَا هُم مُّبْلِسُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@dcccxxxiv{فَقُطِعَ دَابِرُ ٱلْقَوْمِ ٱلَّذِينَ ظَلَمُوا۟ وَٱلْحَمْدُ لِلَّهِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@dcccxxxv{قُلْ أَرَءَيْتُمْ إِنْ أَخَذَ ٱللَّهُ سَمْعَكُمْ وَأَبْصَٰرَكُمْ وَخَتَمَ عَلَىٰ قُلُوبِكُم مَّنْ إِلَٰهٌ غَيْرُ ٱللَّهِ يَأْتِيكُم بِهِ ٱنظُرْ كَيْفَ نُصَرِّفُ ٱلْءَايَٰتِ ثُمَّ هُمْ يَصْدِفُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@dcccxxxvi{قُلْ أَرَءَيْتَكُمْ إِنْ أَتَىٰكُمْ عَذَابُ ٱللَّهِ بَغْتَةً أَوْ جَهْرَةً هَلْ يُهْلَكُ إِلَّا ٱلْقَوْمُ ٱلظَّٰلِمُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@dcccxxxvii{وَمَا نُرْسِلُ ٱلْمُرْسَلِينَ إِلَّا مُبَشِّرِينَ وَمُنذِرِينَ فَمَنْ ءَامَنَ وَأَصْلَحَ فَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@dcccxxxviii{وَٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا يَمَسُّهُمُ ٱلْعَذَابُ بِمَا كَانُوا۟ يَفْسُقُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@dcccxxxix{قُل لَّآ أَقُولُ لَكُمْ عِندِى خَزَآئِنُ ٱللَّهِ وَلَآ أَعْلَمُ ٱلْغَيْبَ وَلَآ أَقُولُ لَكُمْ إِنِّى مَلَكٌ إِنْ أَتَّبِعُ إِلَّا مَا يُوحَىٰٓ إِلَىَّ قُلْ هَلْ يَسْتَوِى ٱلْأَعْمَىٰ وَٱلْبَصِيرُ أَفَلَا تَتَفَكَّرُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@dcccxl{وَأَنذِرْ بِهِ ٱلَّذِينَ يَخَافُونَ أَن يُحْشَرُوٓا۟ إِلَىٰ رَبِّهِمْ لَيْسَ لَهُم مِّن دُونِهِۦ وَلِىٌّ وَلَا شَفِيعٌ لَّعَلَّهُمْ يَتَّقُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@dcccxli{وَلَا تَطْرُدِ ٱلَّذِينَ يَدْعُونَ رَبَّهُم بِٱلْغَدَوٰةِ وَٱلْعَشِىِّ يُرِيدُونَ وَجْهَهُۥ مَا عَلَيْكَ مِنْ حِسَابِهِم مِّن شَىْءٍ وَمَا مِنْ حِسَابِكَ عَلَيْهِم مِّن شَىْءٍ فَتَطْرُدَهُمْ فَتَكُونَ مِنَ ٱلظَّٰلِمِينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@dcccxlii{وَكَذَٰلِكَ فَتَنَّا بَعْضَهُم بِبَعْضٍ لِّيَقُولُوٓا۟ أَهَٰٓؤُلَآءِ مَنَّ ٱللَّهُ عَلَيْهِم مِّنۢ بَيْنِنَآ أَلَيْسَ ٱللَّهُ بِأَعْلَمَ بِٱلشَّٰكِرِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@dcccxliii{وَإِذَا جَآءَكَ ٱلَّذِينَ يُؤْمِنُونَ بِـَٔايَٰتِنَا فَقُلْ سَلَٰمٌ عَلَيْكُمْ كَتَبَ رَبُّكُمْ عَلَىٰ نَفْسِهِ ٱلرَّحْمَةَ أَنَّهُۥ مَنْ عَمِلَ مِنكُمْ سُوٓءًۢا بِجَهَٰلَةٍ ثُمَّ تَابَ مِنۢ بَعْدِهِۦ وَأَصْلَحَ فَأَنَّهُۥ غَفُورٌ رَّحِيمٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@dcccxliv{وَكَذَٰلِكَ نُفَصِّلُ ٱلْءَايَٰتِ وَلِتَسْتَبِينَ سَبِيلُ ٱلْمُجْرِمِينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@dcccxlv{قُلْ إِنِّى نُهِيتُ أَنْ أَعْبُدَ ٱلَّذِينَ تَدْعُونَ مِن دُونِ ٱللَّهِ قُل لَّآ أَتَّبِعُ أَهْوَآءَكُمْ قَدْ ضَلَلْتُ إِذًا وَمَآ أَنَا۠ مِنَ ٱلْمُهْتَدِينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@dcccxlvi{قُلْ إِنِّى عَلَىٰ بَيِّنَةٍ مِّن رَّبِّى وَكَذَّبْتُم بِهِۦ مَا عِندِى مَا تَسْتَعْجِلُونَ بِهِۦٓ إِنِ ٱلْحُكْمُ إِلَّا لِلَّهِ يَقُصُّ ٱلْحَقَّ وَهُوَ خَيْرُ ٱلْفَٰصِلِينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@dcccxlvii{قُل لَّوْ أَنَّ عِندِى مَا تَسْتَعْجِلُونَ بِهِۦ لَقُضِىَ ٱلْأَمْرُ بَيْنِى وَبَيْنَكُمْ وَٱللَّهُ أَعْلَمُ بِٱلظَّٰلِمِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@dcccxlviii{وَعِندَهُۥ مَفَاتِحُ ٱلْغَيْبِ لَا يَعْلَمُهَآ إِلَّا هُوَ وَيَعْلَمُ مَا فِى ٱلْبَرِّ وَٱلْبَحْرِ وَمَا تَسْقُطُ مِن وَرَقَةٍ إِلَّا يَعْلَمُهَا وَلَا حَبَّةٍ فِى ظُلُمَٰتِ ٱلْأَرْضِ وَلَا رَطْبٍ وَلَا يَابِسٍ إِلَّا فِى كِتَٰبٍ مُّبِينٍ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@dcccxlix{وَهُوَ ٱلَّذِى يَتَوَفَّىٰكُم بِٱلَّيْلِ وَيَعْلَمُ مَا جَرَحْتُم بِٱلنَّهَارِ ثُمَّ يَبْعَثُكُمْ فِيهِ لِيُقْضَىٰٓ أَجَلٌ مُّسَمًّى ثُمَّ إِلَيْهِ مَرْجِعُكُمْ ثُمَّ يُنَبِّئُكُم بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@dcccl{وَهُوَ ٱلْقَاهِرُ فَوْقَ عِبَادِهِۦ وَيُرْسِلُ عَلَيْكُمْ حَفَظَةً حَتَّىٰٓ إِذَا جَآءَ أَحَدَكُمُ ٱلْمَوْتُ تَوَفَّتْهُ رُسُلُنَا وَهُمْ لَا يُفَرِّطُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@dcccli{ثُمَّ رُدُّوٓا۟ إِلَى ٱللَّهِ مَوْلَىٰهُمُ ٱلْحَقِّ أَلَا لَهُ ٱلْحُكْمُ وَهُوَ أَسْرَعُ ٱلْحَٰسِبِينَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@dccclii{قُلْ مَن يُنَجِّيكُم مِّن ظُلُمَٰتِ ٱلْبَرِّ وَٱلْبَحْرِ تَدْعُونَهُۥ تَضَرُّعًا وَخُفْيَةً لَّئِنْ أَنجَىٰنَا مِنْ هَٰذِهِۦ لَنَكُونَنَّ مِنَ ٱلشَّٰكِرِينَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@dcccliii{قُلِ ٱللَّهُ يُنَجِّيكُم مِّنْهَا وَمِن كُلِّ كَرْبٍ ثُمَّ أَنتُمْ تُشْرِكُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@dcccliv{قُلْ هُوَ ٱلْقَادِرُ عَلَىٰٓ أَن يَبْعَثَ عَلَيْكُمْ عَذَابًا مِّن فَوْقِكُمْ أَوْ مِن تَحْتِ أَرْجُلِكُمْ أَوْ يَلْبِسَكُمْ شِيَعًا وَيُذِيقَ بَعْضَكُم بَأْسَ بَعْضٍ ٱنظُرْ كَيْفَ نُصَرِّفُ ٱلْءَايَٰتِ لَعَلَّهُمْ يَفْقَهُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@dccclv{وَكَذَّبَ بِهِۦ قَوْمُكَ وَهُوَ ٱلْحَقُّ قُل لَّسْتُ عَلَيْكُم بِوَكِيلٍ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@dccclvi{لِّكُلِّ نَبَإٍ مُّسْتَقَرٌّ وَسَوْفَ تَعْلَمُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@dccclvii{وَإِذَا رَأَيْتَ ٱلَّذِينَ يَخُوضُونَ فِىٓ ءَايَٰتِنَا فَأَعْرِضْ عَنْهُمْ حَتَّىٰ يَخُوضُوا۟ فِى حَدِيثٍ غَيْرِهِۦ وَإِمَّا يُنسِيَنَّكَ ٱلشَّيْطَٰنُ فَلَا تَقْعُدْ بَعْدَ ٱلذِّكْرَىٰ مَعَ ٱلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@dccclviii{وَمَا عَلَى ٱلَّذِينَ يَتَّقُونَ مِنْ حِسَابِهِم مِّن شَىْءٍ وَلَٰكِن ذِكْرَىٰ لَعَلَّهُمْ يَتَّقُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@dccclix{وَذَرِ ٱلَّذِينَ ٱتَّخَذُوا۟ دِينَهُمْ لَعِبًا وَلَهْوًا وَغَرَّتْهُمُ ٱلْحَيَوٰةُ ٱلدُّنْيَا وَذَكِّرْ بِهِۦٓ أَن تُبْسَلَ نَفْسٌۢ بِمَا كَسَبَتْ لَيْسَ لَهَا مِن دُونِ ٱللَّهِ وَلِىٌّ وَلَا شَفِيعٌ وَإِن تَعْدِلْ كُلَّ عَدْلٍ لَّا يُؤْخَذْ مِنْهَآ أُو۟لَٰٓئِكَ ٱلَّذِينَ أُبْسِلُوا۟ بِمَا كَسَبُوا۟ لَهُمْ شَرَابٌ مِّنْ حَمِيمٍ وَعَذَابٌ أَلِيمٌۢ بِمَا كَانُوا۟ يَكْفُرُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@dccclx{قُلْ أَنَدْعُوا۟ مِن دُونِ ٱللَّهِ مَا لَا يَنفَعُنَا وَلَا يَضُرُّنَا وَنُرَدُّ عَلَىٰٓ أَعْقَابِنَا بَعْدَ إِذْ هَدَىٰنَا ٱللَّهُ كَٱلَّذِى ٱسْتَهْوَتْهُ ٱلشَّيَٰطِينُ فِى ٱلْأَرْضِ حَيْرَانَ لَهُۥٓ أَصْحَٰبٌ يَدْعُونَهُۥٓ إِلَى ٱلْهُدَى ٱئْتِنَا قُلْ إِنَّ هُدَى ٱللَّهِ هُوَ ٱلْهُدَىٰ وَأُمِرْنَا لِنُسْلِمَ لِرَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@dccclxi{وَأَنْ أَقِيمُوا۟ ٱلصَّلَوٰةَ وَٱتَّقُوهُ وَهُوَ ٱلَّذِىٓ إِلَيْهِ تُحْشَرُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@dccclxii{وَهُوَ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ بِٱلْحَقِّ وَيَوْمَ يَقُولُ كُن فَيَكُونُ قَوْلُهُ ٱلْحَقُّ وَلَهُ ٱلْمُلْكُ يَوْمَ يُنفَخُ فِى ٱلصُّورِ عَٰلِمُ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ وَهُوَ ٱلْحَكِيمُ ٱلْخَبِيرُ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@dccclxiii{وَإِذْ قَالَ إِبْرَٰهِيمُ لِأَبِيهِ ءَازَرَ أَتَتَّخِذُ أَصْنَامًا ءَالِهَةً إِنِّىٓ أَرَىٰكَ وَقَوْمَكَ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@dccclxiv{وَكَذَٰلِكَ نُرِىٓ إِبْرَٰهِيمَ مَلَكُوتَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَلِيَكُونَ مِنَ ٱلْمُوقِنِينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@dccclxv{فَلَمَّا جَنَّ عَلَيْهِ ٱلَّيْلُ رَءَا كَوْكَبًا قَالَ هَٰذَا رَبِّى فَلَمَّآ أَفَلَ قَالَ لَآ أُحِبُّ ٱلْءَافِلِينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@dccclxvi{فَلَمَّا رَءَا ٱلْقَمَرَ بَازِغًا قَالَ هَٰذَا رَبِّى فَلَمَّآ أَفَلَ قَالَ لَئِن لَّمْ يَهْدِنِى رَبِّى لَأَكُونَنَّ مِنَ ٱلْقَوْمِ ٱلضَّآلِّينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@dccclxvii{فَلَمَّا رَءَا ٱلشَّمْسَ بَازِغَةً قَالَ هَٰذَا رَبِّى هَٰذَآ أَكْبَرُ فَلَمَّآ أَفَلَتْ قَالَ يَٰقَوْمِ إِنِّى بَرِىٓءٌ مِّمَّا تُشْرِكُونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@dccclxviii{إِنِّى وَجَّهْتُ وَجْهِىَ لِلَّذِى فَطَرَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ حَنِيفًا وَمَآ أَنَا۠ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@dccclxix{وَحَآجَّهُۥ قَوْمُهُۥ قَالَ أَتُحَٰٓجُّوٓنِّى فِى ٱللَّهِ وَقَدْ هَدَىٰنِ وَلَآ أَخَافُ مَا تُشْرِكُونَ بِهِۦٓ إِلَّآ أَن يَشَآءَ رَبِّى شَيْـًٔا وَسِعَ رَبِّى كُلَّ شَىْءٍ عِلْمًا أَفَلَا تَتَذَكَّرُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@dccclxx{وَكَيْفَ أَخَافُ مَآ أَشْرَكْتُمْ وَلَا تَخَافُونَ أَنَّكُمْ أَشْرَكْتُم بِٱللَّهِ مَا لَمْ يُنَزِّلْ بِهِۦ عَلَيْكُمْ سُلْطَٰنًا فَأَىُّ ٱلْفَرِيقَيْنِ أَحَقُّ بِٱلْأَمْنِ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@dccclxxi{ٱلَّذِينَ ءَامَنُوا۟ وَلَمْ يَلْبِسُوٓا۟ إِيمَٰنَهُم بِظُلْمٍ أُو۟لَٰٓئِكَ لَهُمُ ٱلْأَمْنُ وَهُم مُّهْتَدُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@dccclxxii{وَتِلْكَ حُجَّتُنَآ ءَاتَيْنَٰهَآ إِبْرَٰهِيمَ عَلَىٰ قَوْمِهِۦ نَرْفَعُ دَرَجَٰتٍ مَّن نَّشَآءُ إِنَّ رَبَّكَ حَكِيمٌ عَلِيمٌ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@dccclxxiii{وَوَهَبْنَا لَهُۥٓ إِسْحَٰقَ وَيَعْقُوبَ كُلًّا هَدَيْنَا وَنُوحًا هَدَيْنَا مِن قَبْلُ وَمِن ذُرِّيَّتِهِۦ دَاوُۥدَ وَسُلَيْمَٰنَ وَأَيُّوبَ وَيُوسُفَ وَمُوسَىٰ وَهَٰرُونَ وَكَذَٰلِكَ نَجْزِى ٱلْمُحْسِنِينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@dccclxxiv{وَزَكَرِيَّا وَيَحْيَىٰ وَعِيسَىٰ وَإِلْيَاسَ كُلٌّ مِّنَ ٱلصَّٰلِحِينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@dccclxxv{وَإِسْمَٰعِيلَ وَٱلْيَسَعَ وَيُونُسَ وَلُوطًا وَكُلًّا فَضَّلْنَا عَلَى ٱلْعَٰلَمِينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@dccclxxvi{وَمِنْ ءَابَآئِهِمْ وَذُرِّيَّٰتِهِمْ وَإِخْوَٰنِهِمْ وَٱجْتَبَيْنَٰهُمْ وَهَدَيْنَٰهُمْ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@dccclxxvii{ذَٰلِكَ هُدَى ٱللَّهِ يَهْدِى بِهِۦ مَن يَشَآءُ مِنْ عِبَادِهِۦ وَلَوْ أَشْرَكُوا۟ لَحَبِطَ عَنْهُم مَّا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@dccclxxviii{أُو۟لَٰٓئِكَ ٱلَّذِينَ ءَاتَيْنَٰهُمُ ٱلْكِتَٰبَ وَٱلْحُكْمَ وَٱلنُّبُوَّةَ فَإِن يَكْفُرْ بِهَا هَٰٓؤُلَآءِ فَقَدْ وَكَّلْنَا بِهَا قَوْمًا لَّيْسُوا۟ بِهَا بِكَٰفِرِينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@dccclxxix{أُو۟لَٰٓئِكَ ٱلَّذِينَ هَدَى ٱللَّهُ فَبِهُدَىٰهُمُ ٱقْتَدِهْ قُل لَّآ أَسْـَٔلُكُمْ عَلَيْهِ أَجْرًا إِنْ هُوَ إِلَّا ذِكْرَىٰ لِلْعَٰلَمِينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@dccclxxx{وَمَا قَدَرُوا۟ ٱللَّهَ حَقَّ قَدْرِهِۦٓ إِذْ قَالُوا۟ مَآ أَنزَلَ ٱللَّهُ عَلَىٰ بَشَرٍ مِّن شَىْءٍ قُلْ مَنْ أَنزَلَ ٱلْكِتَٰبَ ٱلَّذِى جَآءَ بِهِۦ مُوسَىٰ نُورًا وَهُدًى لِّلنَّاسِ تَجْعَلُونَهُۥ قَرَاطِيسَ تُبْدُونَهَا وَتُخْفُونَ كَثِيرًا وَعُلِّمْتُم مَّا لَمْ تَعْلَمُوٓا۟ أَنتُمْ وَلَآ ءَابَآؤُكُمْ قُلِ ٱللَّهُ ثُمَّ ذَرْهُمْ فِى خَوْضِهِمْ يَلْعَبُونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@dccclxxxi{وَهَٰذَا كِتَٰبٌ أَنزَلْنَٰهُ مُبَارَكٌ مُّصَدِّقُ ٱلَّذِى بَيْنَ يَدَيْهِ وَلِتُنذِرَ أُمَّ ٱلْقُرَىٰ وَمَنْ حَوْلَهَا وَٱلَّذِينَ يُؤْمِنُونَ بِٱلْءَاخِرَةِ يُؤْمِنُونَ بِهِۦ وَهُمْ عَلَىٰ صَلَاتِهِمْ يُحَافِظُونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@dccclxxxii{وَمَنْ أَظْلَمُ مِمَّنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا أَوْ قَالَ أُوحِىَ إِلَىَّ وَلَمْ يُوحَ إِلَيْهِ شَىْءٌ وَمَن قَالَ سَأُنزِلُ مِثْلَ مَآ أَنزَلَ ٱللَّهُ وَلَوْ تَرَىٰٓ إِذِ ٱلظَّٰلِمُونَ فِى غَمَرَٰتِ ٱلْمَوْتِ وَٱلْمَلَٰٓئِكَةُ بَاسِطُوٓا۟ أَيْدِيهِمْ أَخْرِجُوٓا۟ أَنفُسَكُمُ ٱلْيَوْمَ تُجْزَوْنَ عَذَابَ ٱلْهُونِ بِمَا كُنتُمْ تَقُولُونَ عَلَى ٱللَّهِ غَيْرَ ٱلْحَقِّ وَكُنتُمْ عَنْ ءَايَٰتِهِۦ تَسْتَكْبِرُونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@dccclxxxiii{وَلَقَدْ جِئْتُمُونَا فُرَٰدَىٰ كَمَا خَلَقْنَٰكُمْ أَوَّلَ مَرَّةٍ وَتَرَكْتُم مَّا خَوَّلْنَٰكُمْ وَرَآءَ ظُهُورِكُمْ وَمَا نَرَىٰ مَعَكُمْ شُفَعَآءَكُمُ ٱلَّذِينَ زَعَمْتُمْ أَنَّهُمْ فِيكُمْ شُرَكَٰٓؤُا۟ لَقَد تَّقَطَّعَ بَيْنَكُمْ وَضَلَّ عَنكُم مَّا كُنتُمْ تَزْعُمُونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@dccclxxxiv{إِنَّ ٱللَّهَ فَالِقُ ٱلْحَبِّ وَٱلنَّوَىٰ يُخْرِجُ ٱلْحَىَّ مِنَ ٱلْمَيِّتِ وَمُخْرِجُ ٱلْمَيِّتِ مِنَ ٱلْحَىِّ ذَٰلِكُمُ ٱللَّهُ فَأَنَّىٰ تُؤْفَكُونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@dccclxxxv{فَالِقُ ٱلْإِصْبَاحِ وَجَعَلَ ٱلَّيْلَ سَكَنًا وَٱلشَّمْسَ وَٱلْقَمَرَ حُسْبَانًا ذَٰلِكَ تَقْدِيرُ ٱلْعَزِيزِ ٱلْعَلِيمِ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@dccclxxxvi{وَهُوَ ٱلَّذِى جَعَلَ لَكُمُ ٱلنُّجُومَ لِتَهْتَدُوا۟ بِهَا فِى ظُلُمَٰتِ ٱلْبَرِّ وَٱلْبَحْرِ قَدْ فَصَّلْنَا ٱلْءَايَٰتِ لِقَوْمٍ يَعْلَمُونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@dccclxxxvii{وَهُوَ ٱلَّذِىٓ أَنشَأَكُم مِّن نَّفْسٍ وَٰحِدَةٍ فَمُسْتَقَرٌّ وَمُسْتَوْدَعٌ قَدْ فَصَّلْنَا ٱلْءَايَٰتِ لِقَوْمٍ يَفْقَهُونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@dccclxxxviii{وَهُوَ ٱلَّذِىٓ أَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً فَأَخْرَجْنَا بِهِۦ نَبَاتَ كُلِّ شَىْءٍ فَأَخْرَجْنَا مِنْهُ خَضِرًا نُّخْرِجُ مِنْهُ حَبًّا مُّتَرَاكِبًا وَمِنَ ٱلنَّخْلِ مِن طَلْعِهَا قِنْوَانٌ دَانِيَةٌ وَجَنَّٰتٍ مِّنْ أَعْنَابٍ وَٱلزَّيْتُونَ وَٱلرُّمَّانَ مُشْتَبِهًا وَغَيْرَ مُتَشَٰبِهٍ ٱنظُرُوٓا۟ إِلَىٰ ثَمَرِهِۦٓ إِذَآ أَثْمَرَ وَيَنْعِهِۦٓ إِنَّ فِى ذَٰلِكُمْ لَءَايَٰتٍ لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@dccclxxxix{وَجَعَلُوا۟ لِلَّهِ شُرَكَآءَ ٱلْجِنَّ وَخَلَقَهُمْ وَخَرَقُوا۟ لَهُۥ بَنِينَ وَبَنَٰتٍۭ بِغَيْرِ عِلْمٍ سُبْحَٰنَهُۥ وَتَعَٰلَىٰ عَمَّا يَصِفُونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@dcccxc{بَدِيعُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ أَنَّىٰ يَكُونُ لَهُۥ وَلَدٌ وَلَمْ تَكُن لَّهُۥ صَٰحِبَةٌ وَخَلَقَ كُلَّ شَىْءٍ وَهُوَ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@dcccxci{ذَٰلِكُمُ ٱللَّهُ رَبُّكُمْ لَآ إِلَٰهَ إِلَّا هُوَ خَٰلِقُ كُلِّ شَىْءٍ فَٱعْبُدُوهُ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ وَكِيلٌ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@dcccxcii{لَّا تُدْرِكُهُ ٱلْأَبْصَٰرُ وَهُوَ يُدْرِكُ ٱلْأَبْصَٰرَ وَهُوَ ٱللَّطِيفُ ٱلْخَبِيرُ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@dcccxciii{قَدْ جَآءَكُم بَصَآئِرُ مِن رَّبِّكُمْ فَمَنْ أَبْصَرَ فَلِنَفْسِهِۦ وَمَنْ عَمِىَ فَعَلَيْهَا وَمَآ أَنَا۠ عَلَيْكُم بِحَفِيظٍ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@dcccxciv{وَكَذَٰلِكَ نُصَرِّفُ ٱلْءَايَٰتِ وَلِيَقُولُوا۟ دَرَسْتَ وَلِنُبَيِّنَهُۥ لِقَوْمٍ يَعْلَمُونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@dcccxcv{ٱتَّبِعْ مَآ أُوحِىَ إِلَيْكَ مِن رَّبِّكَ لَآ إِلَٰهَ إِلَّا هُوَ وَأَعْرِضْ عَنِ ٱلْمُشْرِكِينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@dcccxcvi{وَلَوْ شَآءَ ٱللَّهُ مَآ أَشْرَكُوا۟ وَمَا جَعَلْنَٰكَ عَلَيْهِمْ حَفِيظًا وَمَآ أَنتَ عَلَيْهِم بِوَكِيلٍ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@dcccxcvii{وَلَا تَسُبُّوا۟ ٱلَّذِينَ يَدْعُونَ مِن دُونِ ٱللَّهِ فَيَسُبُّوا۟ ٱللَّهَ عَدْوًۢا بِغَيْرِ عِلْمٍ كَذَٰلِكَ زَيَّنَّا لِكُلِّ أُمَّةٍ عَمَلَهُمْ ثُمَّ إِلَىٰ رَبِّهِم مَّرْجِعُهُمْ فَيُنَبِّئُهُم بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@dcccxcviii{وَأَقْسَمُوا۟ بِٱللَّهِ جَهْدَ أَيْمَٰنِهِمْ لَئِن جَآءَتْهُمْ ءَايَةٌ لَّيُؤْمِنُنَّ بِهَا قُلْ إِنَّمَا ٱلْءَايَٰتُ عِندَ ٱللَّهِ وَمَا يُشْعِرُكُمْ أَنَّهَآ إِذَا جَآءَتْ لَا يُؤْمِنُونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@dcccxcix{وَنُقَلِّبُ أَفْـِٔدَتَهُمْ وَأَبْصَٰرَهُمْ كَمَا لَمْ يُؤْمِنُوا۟ بِهِۦٓ أَوَّلَ مَرَّةٍ وَنَذَرُهُمْ فِى طُغْيَٰنِهِمْ يَعْمَهُونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@cm{وَلَوْ أَنَّنَا نَزَّلْنَآ إِلَيْهِمُ ٱلْمَلَٰٓئِكَةَ وَكَلَّمَهُمُ ٱلْمَوْتَىٰ وَحَشَرْنَا عَلَيْهِمْ كُلَّ شَىْءٍ قُبُلًا مَّا كَانُوا۟ لِيُؤْمِنُوٓا۟ إِلَّآ أَن يَشَآءَ ٱللَّهُ وَلَٰكِنَّ أَكْثَرَهُمْ يَجْهَلُونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@cmi{وَكَذَٰلِكَ جَعَلْنَا لِكُلِّ نَبِىٍّ عَدُوًّا شَيَٰطِينَ ٱلْإِنسِ وَٱلْجِنِّ يُوحِى بَعْضُهُمْ إِلَىٰ بَعْضٍ زُخْرُفَ ٱلْقَوْلِ غُرُورًا وَلَوْ شَآءَ رَبُّكَ مَا فَعَلُوهُ فَذَرْهُمْ وَمَا يَفْتَرُونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@cmii{وَلِتَصْغَىٰٓ إِلَيْهِ أَفْـِٔدَةُ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ وَلِيَرْضَوْهُ وَلِيَقْتَرِفُوا۟ مَا هُم مُّقْتَرِفُونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@cmiii{أَفَغَيْرَ ٱللَّهِ أَبْتَغِى حَكَمًا وَهُوَ ٱلَّذِىٓ أَنزَلَ إِلَيْكُمُ ٱلْكِتَٰبَ مُفَصَّلًا وَٱلَّذِينَ ءَاتَيْنَٰهُمُ ٱلْكِتَٰبَ يَعْلَمُونَ أَنَّهُۥ مُنَزَّلٌ مِّن رَّبِّكَ بِٱلْحَقِّ فَلَا تَكُونَنَّ مِنَ ٱلْمُمْتَرِينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@cmiv{وَتَمَّتْ كَلِمَتُ رَبِّكَ صِدْقًا وَعَدْلًا لَّا مُبَدِّلَ لِكَلِمَٰتِهِۦ وَهُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@cmv{وَإِن تُطِعْ أَكْثَرَ مَن فِى ٱلْأَرْضِ يُضِلُّوكَ عَن سَبِيلِ ٱللَّهِ إِن يَتَّبِعُونَ إِلَّا ٱلظَّنَّ وَإِنْ هُمْ إِلَّا يَخْرُصُونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@cmvi{إِنَّ رَبَّكَ هُوَ أَعْلَمُ مَن يَضِلُّ عَن سَبِيلِهِۦ وَهُوَ أَعْلَمُ بِٱلْمُهْتَدِينَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@cmvii{فَكُلُوا۟ مِمَّا ذُكِرَ ٱسْمُ ٱللَّهِ عَلَيْهِ إِن كُنتُم بِـَٔايَٰتِهِۦ مُؤْمِنِينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@cmviii{وَمَا لَكُمْ أَلَّا تَأْكُلُوا۟ مِمَّا ذُكِرَ ٱسْمُ ٱللَّهِ عَلَيْهِ وَقَدْ فَصَّلَ لَكُم مَّا حَرَّمَ عَلَيْكُمْ إِلَّا مَا ٱضْطُرِرْتُمْ إِلَيْهِ وَإِنَّ كَثِيرًا لَّيُضِلُّونَ بِأَهْوَآئِهِم بِغَيْرِ عِلْمٍ إِنَّ رَبَّكَ هُوَ أَعْلَمُ بِٱلْمُعْتَدِينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@cmix{وَذَرُوا۟ ظَٰهِرَ ٱلْإِثْمِ وَبَاطِنَهُۥٓ إِنَّ ٱلَّذِينَ يَكْسِبُونَ ٱلْإِثْمَ سَيُجْزَوْنَ بِمَا كَانُوا۟ يَقْتَرِفُونَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@cmx{وَلَا تَأْكُلُوا۟ مِمَّا لَمْ يُذْكَرِ ٱسْمُ ٱللَّهِ عَلَيْهِ وَإِنَّهُۥ لَفِسْقٌ وَإِنَّ ٱلشَّيَٰطِينَ لَيُوحُونَ إِلَىٰٓ أَوْلِيَآئِهِمْ لِيُجَٰدِلُوكُمْ وَإِنْ أَطَعْتُمُوهُمْ إِنَّكُمْ لَمُشْرِكُونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@cmxi{أَوَمَن كَانَ مَيْتًا فَأَحْيَيْنَٰهُ وَجَعَلْنَا لَهُۥ نُورًا يَمْشِى بِهِۦ فِى ٱلنَّاسِ كَمَن مَّثَلُهُۥ فِى ٱلظُّلُمَٰتِ لَيْسَ بِخَارِجٍ مِّنْهَا كَذَٰلِكَ زُيِّنَ لِلْكَٰفِرِينَ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@cmxii{وَكَذَٰلِكَ جَعَلْنَا فِى كُلِّ قَرْيَةٍ أَكَٰبِرَ مُجْرِمِيهَا لِيَمْكُرُوا۟ فِيهَا وَمَا يَمْكُرُونَ إِلَّا بِأَنفُسِهِمْ وَمَا يَشْعُرُونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@cmxiii{وَإِذَا جَآءَتْهُمْ ءَايَةٌ قَالُوا۟ لَن نُّؤْمِنَ حَتَّىٰ نُؤْتَىٰ مِثْلَ مَآ أُوتِىَ رُسُلُ ٱللَّهِ ٱللَّهُ أَعْلَمُ حَيْثُ يَجْعَلُ رِسَالَتَهُۥ سَيُصِيبُ ٱلَّذِينَ أَجْرَمُوا۟ صَغَارٌ عِندَ ٱللَّهِ وَعَذَابٌ شَدِيدٌۢ بِمَا كَانُوا۟ يَمْكُرُونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@cmxiv{فَمَن يُرِدِ ٱللَّهُ أَن يَهْدِيَهُۥ يَشْرَحْ صَدْرَهُۥ لِلْإِسْلَٰمِ وَمَن يُرِدْ أَن يُضِلَّهُۥ يَجْعَلْ صَدْرَهُۥ ضَيِّقًا حَرَجًا كَأَنَّمَا يَصَّعَّدُ فِى ٱلسَّمَآءِ كَذَٰلِكَ يَجْعَلُ ٱللَّهُ ٱلرِّجْسَ عَلَى ٱلَّذِينَ لَا يُؤْمِنُونَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@cmxv{وَهَٰذَا صِرَٰطُ رَبِّكَ مُسْتَقِيمًا قَدْ فَصَّلْنَا ٱلْءَايَٰتِ لِقَوْمٍ يَذَّكَّرُونَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@cmxvi{لَهُمْ دَارُ ٱلسَّلَٰمِ عِندَ رَبِّهِمْ وَهُوَ وَلِيُّهُم بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@cmxvii{وَيَوْمَ يَحْشُرُهُمْ جَمِيعًا يَٰمَعْشَرَ ٱلْجِنِّ قَدِ ٱسْتَكْثَرْتُم مِّنَ ٱلْإِنسِ وَقَالَ أَوْلِيَآؤُهُم مِّنَ ٱلْإِنسِ رَبَّنَا ٱسْتَمْتَعَ بَعْضُنَا بِبَعْضٍ وَبَلَغْنَآ أَجَلَنَا ٱلَّذِىٓ أَجَّلْتَ لَنَا قَالَ ٱلنَّارُ مَثْوَىٰكُمْ خَٰلِدِينَ فِيهَآ إِلَّا مَا شَآءَ ٱللَّهُ إِنَّ رَبَّكَ حَكِيمٌ عَلِيمٌ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@cmxviii{وَكَذَٰلِكَ نُوَلِّى بَعْضَ ٱلظَّٰلِمِينَ بَعْضًۢا بِمَا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@cmxix{يَٰمَعْشَرَ ٱلْجِنِّ وَٱلْإِنسِ أَلَمْ يَأْتِكُمْ رُسُلٌ مِّنكُمْ يَقُصُّونَ عَلَيْكُمْ ءَايَٰتِى وَيُنذِرُونَكُمْ لِقَآءَ يَوْمِكُمْ هَٰذَا قَالُوا۟ شَهِدْنَا عَلَىٰٓ أَنفُسِنَا وَغَرَّتْهُمُ ٱلْحَيَوٰةُ ٱلدُّنْيَا وَشَهِدُوا۟ عَلَىٰٓ أَنفُسِهِمْ أَنَّهُمْ كَانُوا۟ كَٰفِرِينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@cmxx{ذَٰلِكَ أَن لَّمْ يَكُن رَّبُّكَ مُهْلِكَ ٱلْقُرَىٰ بِظُلْمٍ وَأَهْلُهَا غَٰفِلُونَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@cmxxi{وَلِكُلٍّ دَرَجَٰتٌ مِّمَّا عَمِلُوا۟ وَمَا رَبُّكَ بِغَٰفِلٍ عَمَّا يَعْمَلُونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@cmxxii{وَرَبُّكَ ٱلْغَنِىُّ ذُو ٱلرَّحْمَةِ إِن يَشَأْ يُذْهِبْكُمْ وَيَسْتَخْلِفْ مِنۢ بَعْدِكُم مَّا يَشَآءُ كَمَآ أَنشَأَكُم مِّن ذُرِّيَّةِ قَوْمٍ ءَاخَرِينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@cmxxiii{إِنَّ مَا تُوعَدُونَ لَءَاتٍ وَمَآ أَنتُم بِمُعْجِزِينَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@cmxxiv{قُلْ يَٰقَوْمِ ٱعْمَلُوا۟ عَلَىٰ مَكَانَتِكُمْ إِنِّى عَامِلٌ فَسَوْفَ تَعْلَمُونَ مَن تَكُونُ لَهُۥ عَٰقِبَةُ ٱلدَّارِ إِنَّهُۥ لَا يُفْلِحُ ٱلظَّٰلِمُونَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@cmxxv{وَجَعَلُوا۟ لِلَّهِ مِمَّا ذَرَأَ مِنَ ٱلْحَرْثِ وَٱلْأَنْعَٰمِ نَصِيبًا فَقَالُوا۟ هَٰذَا لِلَّهِ بِزَعْمِهِمْ وَهَٰذَا لِشُرَكَآئِنَا فَمَا كَانَ لِشُرَكَآئِهِمْ فَلَا يَصِلُ إِلَى ٱللَّهِ وَمَا كَانَ لِلَّهِ فَهُوَ يَصِلُ إِلَىٰ شُرَكَآئِهِمْ سَآءَ مَا يَحْكُمُونَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@cmxxvi{وَكَذَٰلِكَ زَيَّنَ لِكَثِيرٍ مِّنَ ٱلْمُشْرِكِينَ قَتْلَ أَوْلَٰدِهِمْ شُرَكَآؤُهُمْ لِيُرْدُوهُمْ وَلِيَلْبِسُوا۟ عَلَيْهِمْ دِينَهُمْ وَلَوْ شَآءَ ٱللَّهُ مَا فَعَلُوهُ فَذَرْهُمْ وَمَا يَفْتَرُونَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@cmxxvii{وَقَالُوا۟ هَٰذِهِۦٓ أَنْعَٰمٌ وَحَرْثٌ حِجْرٌ لَّا يَطْعَمُهَآ إِلَّا مَن نَّشَآءُ بِزَعْمِهِمْ وَأَنْعَٰمٌ حُرِّمَتْ ظُهُورُهَا وَأَنْعَٰمٌ لَّا يَذْكُرُونَ ٱسْمَ ٱللَّهِ عَلَيْهَا ٱفْتِرَآءً عَلَيْهِ سَيَجْزِيهِم بِمَا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@cmxxviii{وَقَالُوا۟ مَا فِى بُطُونِ هَٰذِهِ ٱلْأَنْعَٰمِ خَالِصَةٌ لِّذُكُورِنَا وَمُحَرَّمٌ عَلَىٰٓ أَزْوَٰجِنَا وَإِن يَكُن مَّيْتَةً فَهُمْ فِيهِ شُرَكَآءُ سَيَجْزِيهِمْ وَصْفَهُمْ إِنَّهُۥ حَكِيمٌ عَلِيمٌ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@cmxxix{قَدْ خَسِرَ ٱلَّذِينَ قَتَلُوٓا۟ أَوْلَٰدَهُمْ سَفَهًۢا بِغَيْرِ عِلْمٍ وَحَرَّمُوا۟ مَا رَزَقَهُمُ ٱللَّهُ ٱفْتِرَآءً عَلَى ٱللَّهِ قَدْ ضَلُّوا۟ وَمَا كَانُوا۟ مُهْتَدِينَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@cmxxx{وَهُوَ ٱلَّذِىٓ أَنشَأَ جَنَّٰتٍ مَّعْرُوشَٰتٍ وَغَيْرَ مَعْرُوشَٰتٍ وَٱلنَّخْلَ وَٱلزَّرْعَ مُخْتَلِفًا أُكُلُهُۥ وَٱلزَّيْتُونَ وَٱلرُّمَّانَ مُتَشَٰبِهًا وَغَيْرَ مُتَشَٰبِهٍ كُلُوا۟ مِن ثَمَرِهِۦٓ إِذَآ أَثْمَرَ وَءَاتُوا۟ حَقَّهُۥ يَوْمَ حَصَادِهِۦ وَلَا تُسْرِفُوٓا۟ إِنَّهُۥ لَا يُحِبُّ ٱلْمُسْرِفِينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@cmxxxi{وَمِنَ ٱلْأَنْعَٰمِ حَمُولَةً وَفَرْشًا كُلُوا۟ مِمَّا رَزَقَكُمُ ٱللَّهُ وَلَا تَتَّبِعُوا۟ خُطُوَٰتِ ٱلشَّيْطَٰنِ إِنَّهُۥ لَكُمْ عَدُوٌّ مُّبِينٌ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@cmxxxii{ثَمَٰنِيَةَ أَزْوَٰجٍ مِّنَ ٱلضَّأْنِ ٱثْنَيْنِ وَمِنَ ٱلْمَعْزِ ٱثْنَيْنِ قُلْ ءَآلذَّكَرَيْنِ حَرَّمَ أَمِ ٱلْأُنثَيَيْنِ أَمَّا ٱشْتَمَلَتْ عَلَيْهِ أَرْحَامُ ٱلْأُنثَيَيْنِ نَبِّـُٔونِى بِعِلْمٍ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@cmxxxiii{وَمِنَ ٱلْإِبِلِ ٱثْنَيْنِ وَمِنَ ٱلْبَقَرِ ٱثْنَيْنِ قُلْ ءَآلذَّكَرَيْنِ حَرَّمَ أَمِ ٱلْأُنثَيَيْنِ أَمَّا ٱشْتَمَلَتْ عَلَيْهِ أَرْحَامُ ٱلْأُنثَيَيْنِ أَمْ كُنتُمْ شُهَدَآءَ إِذْ وَصَّىٰكُمُ ٱللَّهُ بِهَٰذَا فَمَنْ أَظْلَمُ مِمَّنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا لِّيُضِلَّ ٱلنَّاسَ بِغَيْرِ عِلْمٍ إِنَّ ٱللَّهَ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@cmxxxiv{قُل لَّآ أَجِدُ فِى مَآ أُوحِىَ إِلَىَّ مُحَرَّمًا عَلَىٰ طَاعِمٍ يَطْعَمُهُۥٓ إِلَّآ أَن يَكُونَ مَيْتَةً أَوْ دَمًا مَّسْفُوحًا أَوْ لَحْمَ خِنزِيرٍ فَإِنَّهُۥ رِجْسٌ أَوْ فِسْقًا أُهِلَّ لِغَيْرِ ٱللَّهِ بِهِۦ فَمَنِ ٱضْطُرَّ غَيْرَ بَاغٍ وَلَا عَادٍ فَإِنَّ رَبَّكَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@cmxxxv{وَعَلَى ٱلَّذِينَ هَادُوا۟ حَرَّمْنَا كُلَّ ذِى ظُفُرٍ وَمِنَ ٱلْبَقَرِ وَٱلْغَنَمِ حَرَّمْنَا عَلَيْهِمْ شُحُومَهُمَآ إِلَّا مَا حَمَلَتْ ظُهُورُهُمَآ أَوِ ٱلْحَوَايَآ أَوْ مَا ٱخْتَلَطَ بِعَظْمٍ ذَٰلِكَ جَزَيْنَٰهُم بِبَغْيِهِمْ وَإِنَّا لَصَٰدِقُونَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@cmxxxvi{فَإِن كَذَّبُوكَ فَقُل رَّبُّكُمْ ذُو رَحْمَةٍ وَٰسِعَةٍ وَلَا يُرَدُّ بَأْسُهُۥ عَنِ ٱلْقَوْمِ ٱلْمُجْرِمِينَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@cmxxxvii{سَيَقُولُ ٱلَّذِينَ أَشْرَكُوا۟ لَوْ شَآءَ ٱللَّهُ مَآ أَشْرَكْنَا وَلَآ ءَابَآؤُنَا وَلَا حَرَّمْنَا مِن شَىْءٍ كَذَٰلِكَ كَذَّبَ ٱلَّذِينَ مِن قَبْلِهِمْ حَتَّىٰ ذَاقُوا۟ بَأْسَنَا قُلْ هَلْ عِندَكُم مِّنْ عِلْمٍ فَتُخْرِجُوهُ لَنَآ إِن تَتَّبِعُونَ إِلَّا ٱلظَّنَّ وَإِنْ أَنتُمْ إِلَّا تَخْرُصُونَ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@cmxxxviii{قُلْ فَلِلَّهِ ٱلْحُجَّةُ ٱلْبَٰلِغَةُ فَلَوْ شَآءَ لَهَدَىٰكُمْ أَجْمَعِينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@cmxxxix{قُلْ هَلُمَّ شُهَدَآءَكُمُ ٱلَّذِينَ يَشْهَدُونَ أَنَّ ٱللَّهَ حَرَّمَ هَٰذَا فَإِن شَهِدُوا۟ فَلَا تَشْهَدْ مَعَهُمْ وَلَا تَتَّبِعْ أَهْوَآءَ ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا وَٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ وَهُم بِرَبِّهِمْ يَعْدِلُونَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@cmxl{قُلْ تَعَالَوْا۟ أَتْلُ مَا حَرَّمَ رَبُّكُمْ عَلَيْكُمْ أَلَّا تُشْرِكُوا۟ بِهِۦ شَيْـًٔا وَبِٱلْوَٰلِدَيْنِ إِحْسَٰنًا وَلَا تَقْتُلُوٓا۟ أَوْلَٰدَكُم مِّنْ إِمْلَٰقٍ نَّحْنُ نَرْزُقُكُمْ وَإِيَّاهُمْ وَلَا تَقْرَبُوا۟ ٱلْفَوَٰحِشَ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ وَلَا تَقْتُلُوا۟ ٱلنَّفْسَ ٱلَّتِى حَرَّمَ ٱللَّهُ إِلَّا بِٱلْحَقِّ ذَٰلِكُمْ وَصَّىٰكُم بِهِۦ لَعَلَّكُمْ تَعْقِلُونَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@cmxli{وَلَا تَقْرَبُوا۟ مَالَ ٱلْيَتِيمِ إِلَّا بِٱلَّتِى هِىَ أَحْسَنُ حَتَّىٰ يَبْلُغَ أَشُدَّهُۥ وَأَوْفُوا۟ ٱلْكَيْلَ وَٱلْمِيزَانَ بِٱلْقِسْطِ لَا نُكَلِّفُ نَفْسًا إِلَّا وُسْعَهَا وَإِذَا قُلْتُمْ فَٱعْدِلُوا۟ وَلَوْ كَانَ ذَا قُرْبَىٰ وَبِعَهْدِ ٱللَّهِ أَوْفُوا۟ ذَٰلِكُمْ وَصَّىٰكُم بِهِۦ لَعَلَّكُمْ تَذَكَّرُونَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@cmxlii{وَأَنَّ هَٰذَا صِرَٰطِى مُسْتَقِيمًا فَٱتَّبِعُوهُ وَلَا تَتَّبِعُوا۟ ٱلسُّبُلَ فَتَفَرَّقَ بِكُمْ عَن سَبِيلِهِۦ ذَٰلِكُمْ وَصَّىٰكُم بِهِۦ لَعَلَّكُمْ تَتَّقُونَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@cmxliii{ثُمَّ ءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ تَمَامًا عَلَى ٱلَّذِىٓ أَحْسَنَ وَتَفْصِيلًا لِّكُلِّ شَىْءٍ وَهُدًى وَرَحْمَةً لَّعَلَّهُم بِلِقَآءِ رَبِّهِمْ يُؤْمِنُونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@cmxliv{وَهَٰذَا كِتَٰبٌ أَنزَلْنَٰهُ مُبَارَكٌ فَٱتَّبِعُوهُ وَٱتَّقُوا۟ لَعَلَّكُمْ تُرْحَمُونَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@cmxlv{أَن تَقُولُوٓا۟ إِنَّمَآ أُنزِلَ ٱلْكِتَٰبُ عَلَىٰ طَآئِفَتَيْنِ مِن قَبْلِنَا وَإِن كُنَّا عَن دِرَاسَتِهِمْ لَغَٰفِلِينَ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@cmxlvi{أَوْ تَقُولُوا۟ لَوْ أَنَّآ أُنزِلَ عَلَيْنَا ٱلْكِتَٰبُ لَكُنَّآ أَهْدَىٰ مِنْهُمْ فَقَدْ جَآءَكُم بَيِّنَةٌ مِّن رَّبِّكُمْ وَهُدًى وَرَحْمَةٌ فَمَنْ أَظْلَمُ مِمَّن كَذَّبَ بِـَٔايَٰتِ ٱللَّهِ وَصَدَفَ عَنْهَا سَنَجْزِى ٱلَّذِينَ يَصْدِفُونَ عَنْ ءَايَٰتِنَا سُوٓءَ ٱلْعَذَابِ بِمَا كَانُوا۟ يَصْدِفُونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@cmxlvii{هَلْ يَنظُرُونَ إِلَّآ أَن تَأْتِيَهُمُ ٱلْمَلَٰٓئِكَةُ أَوْ يَأْتِىَ رَبُّكَ أَوْ يَأْتِىَ بَعْضُ ءَايَٰتِ رَبِّكَ يَوْمَ يَأْتِى بَعْضُ ءَايَٰتِ رَبِّكَ لَا يَنفَعُ نَفْسًا إِيمَٰنُهَا لَمْ تَكُنْ ءَامَنَتْ مِن قَبْلُ أَوْ كَسَبَتْ فِىٓ إِيمَٰنِهَا خَيْرًا قُلِ ٱنتَظِرُوٓا۟ إِنَّا مُنتَظِرُونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@cmxlviii{إِنَّ ٱلَّذِينَ فَرَّقُوا۟ دِينَهُمْ وَكَانُوا۟ شِيَعًا لَّسْتَ مِنْهُمْ فِى شَىْءٍ إِنَّمَآ أَمْرُهُمْ إِلَى ٱللَّهِ ثُمَّ يُنَبِّئُهُم بِمَا كَانُوا۟ يَفْعَلُونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@cmxlix{مَن جَآءَ بِٱلْحَسَنَةِ فَلَهُۥ عَشْرُ أَمْثَالِهَا وَمَن جَآءَ بِٱلسَّيِّئَةِ فَلَا يُجْزَىٰٓ إِلَّا مِثْلَهَا وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@cml{قُلْ إِنَّنِى هَدَىٰنِى رَبِّىٓ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ دِينًا قِيَمًا مِّلَّةَ إِبْرَٰهِيمَ حَنِيفًا وَمَا كَانَ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@cmli{قُلْ إِنَّ صَلَاتِى وَنُسُكِى وَمَحْيَاىَ وَمَمَاتِى لِلَّهِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@cmlii{لَا شَرِيكَ لَهُۥ وَبِذَٰلِكَ أُمِرْتُ وَأَنَا۠ أَوَّلُ ٱلْمُسْلِمِينَ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@cmliii{قُلْ أَغَيْرَ ٱللَّهِ أَبْغِى رَبًّا وَهُوَ رَبُّ كُلِّ شَىْءٍ وَلَا تَكْسِبُ كُلُّ نَفْسٍ إِلَّا عَلَيْهَا وَلَا تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَىٰ ثُمَّ إِلَىٰ رَبِّكُم مَّرْجِعُكُمْ فَيُنَبِّئُكُم بِمَا كُنتُمْ فِيهِ تَخْتَلِفُونَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@cmliv{وَهُوَ ٱلَّذِى جَعَلَكُمْ خَلَٰٓئِفَ ٱلْأَرْضِ وَرَفَعَ بَعْضَكُمْ فَوْقَ بَعْضٍ دَرَجَٰتٍ لِّيَبْلُوَكُمْ فِى مَآ ءَاتَىٰكُمْ إِنَّ رَبَّكَ سَرِيعُ ٱلْعِقَابِ وَإِنَّهُۥ لَغَفُورٌ رَّحِيمٌۢ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@cmlv{\basmalah الٓمٓصٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@cmlvi{كِتَٰبٌ أُنزِلَ إِلَيْكَ فَلَا يَكُن فِى صَدْرِكَ حَرَجٌ مِّنْهُ لِتُنذِرَ بِهِۦ وَذِكْرَىٰ لِلْمُؤْمِنِينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@cmlvii{ٱتَّبِعُوا۟ مَآ أُنزِلَ إِلَيْكُم مِّن رَّبِّكُمْ وَلَا تَتَّبِعُوا۟ مِن دُونِهِۦٓ أَوْلِيَآءَ قَلِيلًا مَّا تَذَكَّرُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@cmlviii{وَكَم مِّن قَرْيَةٍ أَهْلَكْنَٰهَا فَجَآءَهَا بَأْسُنَا بَيَٰتًا أَوْ هُمْ قَآئِلُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@cmlix{فَمَا كَانَ دَعْوَىٰهُمْ إِذْ جَآءَهُم بَأْسُنَآ إِلَّآ أَن قَالُوٓا۟ إِنَّا كُنَّا ظَٰلِمِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@cmlx{فَلَنَسْـَٔلَنَّ ٱلَّذِينَ أُرْسِلَ إِلَيْهِمْ وَلَنَسْـَٔلَنَّ ٱلْمُرْسَلِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@cmlxi{فَلَنَقُصَّنَّ عَلَيْهِم بِعِلْمٍ وَمَا كُنَّا غَآئِبِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@cmlxii{وَٱلْوَزْنُ يَوْمَئِذٍ ٱلْحَقُّ فَمَن ثَقُلَتْ مَوَٰزِينُهُۥ فَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@cmlxiii{وَمَنْ خَفَّتْ مَوَٰزِينُهُۥ فَأُو۟لَٰٓئِكَ ٱلَّذِينَ خَسِرُوٓا۟ أَنفُسَهُم بِمَا كَانُوا۟ بِـَٔايَٰتِنَا يَظْلِمُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@cmlxiv{وَلَقَدْ مَكَّنَّٰكُمْ فِى ٱلْأَرْضِ وَجَعَلْنَا لَكُمْ فِيهَا مَعَٰيِشَ قَلِيلًا مَّا تَشْكُرُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@cmlxv{وَلَقَدْ خَلَقْنَٰكُمْ ثُمَّ صَوَّرْنَٰكُمْ ثُمَّ قُلْنَا لِلْمَلَٰٓئِكَةِ ٱسْجُدُوا۟ لِءَادَمَ فَسَجَدُوٓا۟ إِلَّآ إِبْلِيسَ لَمْ يَكُن مِّنَ ٱلسَّٰجِدِينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@cmlxvi{قَالَ مَا مَنَعَكَ أَلَّا تَسْجُدَ إِذْ أَمَرْتُكَ قَالَ أَنَا۠ خَيْرٌ مِّنْهُ خَلَقْتَنِى مِن نَّارٍ وَخَلَقْتَهُۥ مِن طِينٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@cmlxvii{قَالَ فَٱهْبِطْ مِنْهَا فَمَا يَكُونُ لَكَ أَن تَتَكَبَّرَ فِيهَا فَٱخْرُجْ إِنَّكَ مِنَ ٱلصَّٰغِرِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@cmlxviii{قَالَ أَنظِرْنِىٓ إِلَىٰ يَوْمِ يُبْعَثُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@cmlxix{قَالَ إِنَّكَ مِنَ ٱلْمُنظَرِينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@cmlxx{قَالَ فَبِمَآ أَغْوَيْتَنِى لَأَقْعُدَنَّ لَهُمْ صِرَٰطَكَ ٱلْمُسْتَقِيمَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@cmlxxi{ثُمَّ لَءَاتِيَنَّهُم مِّنۢ بَيْنِ أَيْدِيهِمْ وَمِنْ خَلْفِهِمْ وَعَنْ أَيْمَٰنِهِمْ وَعَن شَمَآئِلِهِمْ وَلَا تَجِدُ أَكْثَرَهُمْ شَٰكِرِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@cmlxxii{قَالَ ٱخْرُجْ مِنْهَا مَذْءُومًا مَّدْحُورًا لَّمَن تَبِعَكَ مِنْهُمْ لَأَمْلَأَنَّ جَهَنَّمَ مِنكُمْ أَجْمَعِينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@cmlxxiii{وَيَٰٓـَٔادَمُ ٱسْكُنْ أَنتَ وَزَوْجُكَ ٱلْجَنَّةَ فَكُلَا مِنْ حَيْثُ شِئْتُمَا وَلَا تَقْرَبَا هَٰذِهِ ٱلشَّجَرَةَ فَتَكُونَا مِنَ ٱلظَّٰلِمِينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@cmlxxiv{فَوَسْوَسَ لَهُمَا ٱلشَّيْطَٰنُ لِيُبْدِىَ لَهُمَا مَا وُۥرِىَ عَنْهُمَا مِن سَوْءَٰتِهِمَا وَقَالَ مَا نَهَىٰكُمَا رَبُّكُمَا عَنْ هَٰذِهِ ٱلشَّجَرَةِ إِلَّآ أَن تَكُونَا مَلَكَيْنِ أَوْ تَكُونَا مِنَ ٱلْخَٰلِدِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@cmlxxv{وَقَاسَمَهُمَآ إِنِّى لَكُمَا لَمِنَ ٱلنَّٰصِحِينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@cmlxxvi{فَدَلَّىٰهُمَا بِغُرُورٍ فَلَمَّا ذَاقَا ٱلشَّجَرَةَ بَدَتْ لَهُمَا سَوْءَٰتُهُمَا وَطَفِقَا يَخْصِفَانِ عَلَيْهِمَا مِن وَرَقِ ٱلْجَنَّةِ وَنَادَىٰهُمَا رَبُّهُمَآ أَلَمْ أَنْهَكُمَا عَن تِلْكُمَا ٱلشَّجَرَةِ وَأَقُل لَّكُمَآ إِنَّ ٱلشَّيْطَٰنَ لَكُمَا عَدُوٌّ مُّبِينٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@cmlxxvii{قَالَا رَبَّنَا ظَلَمْنَآ أَنفُسَنَا وَإِن لَّمْ تَغْفِرْ لَنَا وَتَرْحَمْنَا لَنَكُونَنَّ مِنَ ٱلْخَٰسِرِينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@cmlxxviii{قَالَ ٱهْبِطُوا۟ بَعْضُكُمْ لِبَعْضٍ عَدُوٌّ وَلَكُمْ فِى ٱلْأَرْضِ مُسْتَقَرٌّ وَمَتَٰعٌ إِلَىٰ حِينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@cmlxxix{قَالَ فِيهَا تَحْيَوْنَ وَفِيهَا تَمُوتُونَ وَمِنْهَا تُخْرَجُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@cmlxxx{يَٰبَنِىٓ ءَادَمَ قَدْ أَنزَلْنَا عَلَيْكُمْ لِبَاسًا يُوَٰرِى سَوْءَٰتِكُمْ وَرِيشًا وَلِبَاسُ ٱلتَّقْوَىٰ ذَٰلِكَ خَيْرٌ ذَٰلِكَ مِنْ ءَايَٰتِ ٱللَّهِ لَعَلَّهُمْ يَذَّكَّرُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@cmlxxxi{يَٰبَنِىٓ ءَادَمَ لَا يَفْتِنَنَّكُمُ ٱلشَّيْطَٰنُ كَمَآ أَخْرَجَ أَبَوَيْكُم مِّنَ ٱلْجَنَّةِ يَنزِعُ عَنْهُمَا لِبَاسَهُمَا لِيُرِيَهُمَا سَوْءَٰتِهِمَآ إِنَّهُۥ يَرَىٰكُمْ هُوَ وَقَبِيلُهُۥ مِنْ حَيْثُ لَا تَرَوْنَهُمْ إِنَّا جَعَلْنَا ٱلشَّيَٰطِينَ أَوْلِيَآءَ لِلَّذِينَ لَا يُؤْمِنُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@cmlxxxii{وَإِذَا فَعَلُوا۟ فَٰحِشَةً قَالُوا۟ وَجَدْنَا عَلَيْهَآ ءَابَآءَنَا وَٱللَّهُ أَمَرَنَا بِهَا قُلْ إِنَّ ٱللَّهَ لَا يَأْمُرُ بِٱلْفَحْشَآءِ أَتَقُولُونَ عَلَى ٱللَّهِ مَا لَا تَعْلَمُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@cmlxxxiii{قُلْ أَمَرَ رَبِّى بِٱلْقِسْطِ وَأَقِيمُوا۟ وُجُوهَكُمْ عِندَ كُلِّ مَسْجِدٍ وَٱدْعُوهُ مُخْلِصِينَ لَهُ ٱلدِّينَ كَمَا بَدَأَكُمْ تَعُودُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@cmlxxxiv{فَرِيقًا هَدَىٰ وَفَرِيقًا حَقَّ عَلَيْهِمُ ٱلضَّلَٰلَةُ إِنَّهُمُ ٱتَّخَذُوا۟ ٱلشَّيَٰطِينَ أَوْلِيَآءَ مِن دُونِ ٱللَّهِ وَيَحْسَبُونَ أَنَّهُم مُّهْتَدُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@cmlxxxv{يَٰبَنِىٓ ءَادَمَ خُذُوا۟ زِينَتَكُمْ عِندَ كُلِّ مَسْجِدٍ وَكُلُوا۟ وَٱشْرَبُوا۟ وَلَا تُسْرِفُوٓا۟ إِنَّهُۥ لَا يُحِبُّ ٱلْمُسْرِفِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@cmlxxxvi{قُلْ مَنْ حَرَّمَ زِينَةَ ٱللَّهِ ٱلَّتِىٓ أَخْرَجَ لِعِبَادِهِۦ وَٱلطَّيِّبَٰتِ مِنَ ٱلرِّزْقِ قُلْ هِىَ لِلَّذِينَ ءَامَنُوا۟ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا خَالِصَةً يَوْمَ ٱلْقِيَٰمَةِ كَذَٰلِكَ نُفَصِّلُ ٱلْءَايَٰتِ لِقَوْمٍ يَعْلَمُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@cmlxxxvii{قُلْ إِنَّمَا حَرَّمَ رَبِّىَ ٱلْفَوَٰحِشَ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ وَٱلْإِثْمَ وَٱلْبَغْىَ بِغَيْرِ ٱلْحَقِّ وَأَن تُشْرِكُوا۟ بِٱللَّهِ مَا لَمْ يُنَزِّلْ بِهِۦ سُلْطَٰنًا وَأَن تَقُولُوا۟ عَلَى ٱللَّهِ مَا لَا تَعْلَمُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@cmlxxxviii{وَلِكُلِّ أُمَّةٍ أَجَلٌ فَإِذَا جَآءَ أَجَلُهُمْ لَا يَسْتَأْخِرُونَ سَاعَةً وَلَا يَسْتَقْدِمُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@cmlxxxix{يَٰبَنِىٓ ءَادَمَ إِمَّا يَأْتِيَنَّكُمْ رُسُلٌ مِّنكُمْ يَقُصُّونَ عَلَيْكُمْ ءَايَٰتِى فَمَنِ ٱتَّقَىٰ وَأَصْلَحَ فَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@cmxc{وَٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا وَٱسْتَكْبَرُوا۟ عَنْهَآ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@cmxci{فَمَنْ أَظْلَمُ مِمَّنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا أَوْ كَذَّبَ بِـَٔايَٰتِهِۦٓ أُو۟لَٰٓئِكَ يَنَالُهُمْ نَصِيبُهُم مِّنَ ٱلْكِتَٰبِ حَتَّىٰٓ إِذَا جَآءَتْهُمْ رُسُلُنَا يَتَوَفَّوْنَهُمْ قَالُوٓا۟ أَيْنَ مَا كُنتُمْ تَدْعُونَ مِن دُونِ ٱللَّهِ قَالُوا۟ ضَلُّوا۟ عَنَّا وَشَهِدُوا۟ عَلَىٰٓ أَنفُسِهِمْ أَنَّهُمْ كَانُوا۟ كَٰفِرِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@cmxcii{قَالَ ٱدْخُلُوا۟ فِىٓ أُمَمٍ قَدْ خَلَتْ مِن قَبْلِكُم مِّنَ ٱلْجِنِّ وَٱلْإِنسِ فِى ٱلنَّارِ كُلَّمَا دَخَلَتْ أُمَّةٌ لَّعَنَتْ أُخْتَهَا حَتَّىٰٓ إِذَا ٱدَّارَكُوا۟ فِيهَا جَمِيعًا قَالَتْ أُخْرَىٰهُمْ لِأُولَىٰهُمْ رَبَّنَا هَٰٓؤُلَآءِ أَضَلُّونَا فَـَٔاتِهِمْ عَذَابًا ضِعْفًا مِّنَ ٱلنَّارِ قَالَ لِكُلٍّ ضِعْفٌ وَلَٰكِن لَّا تَعْلَمُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@cmxciii{وَقَالَتْ أُولَىٰهُمْ لِأُخْرَىٰهُمْ فَمَا كَانَ لَكُمْ عَلَيْنَا مِن فَضْلٍ فَذُوقُوا۟ ٱلْعَذَابَ بِمَا كُنتُمْ تَكْسِبُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@cmxciv{إِنَّ ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا وَٱسْتَكْبَرُوا۟ عَنْهَا لَا تُفَتَّحُ لَهُمْ أَبْوَٰبُ ٱلسَّمَآءِ وَلَا يَدْخُلُونَ ٱلْجَنَّةَ حَتَّىٰ يَلِجَ ٱلْجَمَلُ فِى سَمِّ ٱلْخِيَاطِ وَكَذَٰلِكَ نَجْزِى ٱلْمُجْرِمِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@cmxcv{لَهُم مِّن جَهَنَّمَ مِهَادٌ وَمِن فَوْقِهِمْ غَوَاشٍ وَكَذَٰلِكَ نَجْزِى ٱلظَّٰلِمِينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@cmxcvi{وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَا نُكَلِّفُ نَفْسًا إِلَّا وُسْعَهَآ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْجَنَّةِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@cmxcvii{وَنَزَعْنَا مَا فِى صُدُورِهِم مِّنْ غِلٍّ تَجْرِى مِن تَحْتِهِمُ ٱلْأَنْهَٰرُ وَقَالُوا۟ ٱلْحَمْدُ لِلَّهِ ٱلَّذِى هَدَىٰنَا لِهَٰذَا وَمَا كُنَّا لِنَهْتَدِىَ لَوْلَآ أَنْ هَدَىٰنَا ٱللَّهُ لَقَدْ جَآءَتْ رُسُلُ رَبِّنَا بِٱلْحَقِّ وَنُودُوٓا۟ أَن تِلْكُمُ ٱلْجَنَّةُ أُورِثْتُمُوهَا بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@cmxcviii{وَنَادَىٰٓ أَصْحَٰبُ ٱلْجَنَّةِ أَصْحَٰبَ ٱلنَّارِ أَن قَدْ وَجَدْنَا مَا وَعَدَنَا رَبُّنَا حَقًّا فَهَلْ وَجَدتُّم مَّا وَعَدَ رَبُّكُمْ حَقًّا قَالُوا۟ نَعَمْ فَأَذَّنَ مُؤَذِّنٌۢ بَيْنَهُمْ أَن لَّعْنَةُ ٱللَّهِ عَلَى ٱلظَّٰلِمِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@cmxcix{ٱلَّذِينَ يَصُدُّونَ عَن سَبِيلِ ٱللَّهِ وَيَبْغُونَهَا عِوَجًا وَهُم بِٱلْءَاخِرَةِ كَٰفِرُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@m{وَبَيْنَهُمَا حِجَابٌ وَعَلَى ٱلْأَعْرَافِ رِجَالٌ يَعْرِفُونَ كُلًّۢا بِسِيمَىٰهُمْ وَنَادَوْا۟ أَصْحَٰبَ ٱلْجَنَّةِ أَن سَلَٰمٌ عَلَيْكُمْ لَمْ يَدْخُلُوهَا وَهُمْ يَطْمَعُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mi{وَإِذَا صُرِفَتْ أَبْصَٰرُهُمْ تِلْقَآءَ أَصْحَٰبِ ٱلنَّارِ قَالُوا۟ رَبَّنَا لَا تَجْعَلْنَا مَعَ ٱلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mii{وَنَادَىٰٓ أَصْحَٰبُ ٱلْأَعْرَافِ رِجَالًا يَعْرِفُونَهُم بِسِيمَىٰهُمْ قَالُوا۟ مَآ أَغْنَىٰ عَنكُمْ جَمْعُكُمْ وَمَا كُنتُمْ تَسْتَكْبِرُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@miii{أَهَٰٓؤُلَآءِ ٱلَّذِينَ أَقْسَمْتُمْ لَا يَنَالُهُمُ ٱللَّهُ بِرَحْمَةٍ ٱدْخُلُوا۟ ٱلْجَنَّةَ لَا خَوْفٌ عَلَيْكُمْ وَلَآ أَنتُمْ تَحْزَنُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@miv{وَنَادَىٰٓ أَصْحَٰبُ ٱلنَّارِ أَصْحَٰبَ ٱلْجَنَّةِ أَنْ أَفِيضُوا۟ عَلَيْنَا مِنَ ٱلْمَآءِ أَوْ مِمَّا رَزَقَكُمُ ٱللَّهُ قَالُوٓا۟ إِنَّ ٱللَّهَ حَرَّمَهُمَا عَلَى ٱلْكَٰفِرِينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mv{ٱلَّذِينَ ٱتَّخَذُوا۟ دِينَهُمْ لَهْوًا وَلَعِبًا وَغَرَّتْهُمُ ٱلْحَيَوٰةُ ٱلدُّنْيَا فَٱلْيَوْمَ نَنسَىٰهُمْ كَمَا نَسُوا۟ لِقَآءَ يَوْمِهِمْ هَٰذَا وَمَا كَانُوا۟ بِـَٔايَٰتِنَا يَجْحَدُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mvi{وَلَقَدْ جِئْنَٰهُم بِكِتَٰبٍ فَصَّلْنَٰهُ عَلَىٰ عِلْمٍ هُدًى وَرَحْمَةً لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mvii{هَلْ يَنظُرُونَ إِلَّا تَأْوِيلَهُۥ يَوْمَ يَأْتِى تَأْوِيلُهُۥ يَقُولُ ٱلَّذِينَ نَسُوهُ مِن قَبْلُ قَدْ جَآءَتْ رُسُلُ رَبِّنَا بِٱلْحَقِّ فَهَل لَّنَا مِن شُفَعَآءَ فَيَشْفَعُوا۟ لَنَآ أَوْ نُرَدُّ فَنَعْمَلَ غَيْرَ ٱلَّذِى كُنَّا نَعْمَلُ قَدْ خَسِرُوٓا۟ أَنفُسَهُمْ وَضَلَّ عَنْهُم مَّا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mviii{إِنَّ رَبَّكُمُ ٱللَّهُ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ فِى سِتَّةِ أَيَّامٍ ثُمَّ ٱسْتَوَىٰ عَلَى ٱلْعَرْشِ يُغْشِى ٱلَّيْلَ ٱلنَّهَارَ يَطْلُبُهُۥ حَثِيثًا وَٱلشَّمْسَ وَٱلْقَمَرَ وَٱلنُّجُومَ مُسَخَّرَٰتٍۭ بِأَمْرِهِۦٓ أَلَا لَهُ ٱلْخَلْقُ وَٱلْأَمْرُ تَبَارَكَ ٱللَّهُ رَبُّ ٱلْعَٰلَمِينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mix{ٱدْعُوا۟ رَبَّكُمْ تَضَرُّعًا وَخُفْيَةً إِنَّهُۥ لَا يُحِبُّ ٱلْمُعْتَدِينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mx{وَلَا تُفْسِدُوا۟ فِى ٱلْأَرْضِ بَعْدَ إِصْلَٰحِهَا وَٱدْعُوهُ خَوْفًا وَطَمَعًا إِنَّ رَحْمَتَ ٱللَّهِ قَرِيبٌ مِّنَ ٱلْمُحْسِنِينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mxi{وَهُوَ ٱلَّذِى يُرْسِلُ ٱلرِّيَٰحَ بُشْرًۢا بَيْنَ يَدَىْ رَحْمَتِهِۦ حَتَّىٰٓ إِذَآ أَقَلَّتْ سَحَابًا ثِقَالًا سُقْنَٰهُ لِبَلَدٍ مَّيِّتٍ فَأَنزَلْنَا بِهِ ٱلْمَآءَ فَأَخْرَجْنَا بِهِۦ مِن كُلِّ ٱلثَّمَرَٰتِ كَذَٰلِكَ نُخْرِجُ ٱلْمَوْتَىٰ لَعَلَّكُمْ تَذَكَّرُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mxii{وَٱلْبَلَدُ ٱلطَّيِّبُ يَخْرُجُ نَبَاتُهُۥ بِإِذْنِ رَبِّهِۦ وَٱلَّذِى خَبُثَ لَا يَخْرُجُ إِلَّا نَكِدًا كَذَٰلِكَ نُصَرِّفُ ٱلْءَايَٰتِ لِقَوْمٍ يَشْكُرُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mxiii{لَقَدْ أَرْسَلْنَا نُوحًا إِلَىٰ قَوْمِهِۦ فَقَالَ يَٰقَوْمِ ٱعْبُدُوا۟ ٱللَّهَ مَا لَكُم مِّنْ إِلَٰهٍ غَيْرُهُۥٓ إِنِّىٓ أَخَافُ عَلَيْكُمْ عَذَابَ يَوْمٍ عَظِيمٍ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mxiv{قَالَ ٱلْمَلَأُ مِن قَوْمِهِۦٓ إِنَّا لَنَرَىٰكَ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mxv{قَالَ يَٰقَوْمِ لَيْسَ بِى ضَلَٰلَةٌ وَلَٰكِنِّى رَسُولٌ مِّن رَّبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mxvi{أُبَلِّغُكُمْ رِسَٰلَٰتِ رَبِّى وَأَنصَحُ لَكُمْ وَأَعْلَمُ مِنَ ٱللَّهِ مَا لَا تَعْلَمُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mxvii{أَوَعَجِبْتُمْ أَن جَآءَكُمْ ذِكْرٌ مِّن رَّبِّكُمْ عَلَىٰ رَجُلٍ مِّنكُمْ لِيُنذِرَكُمْ وَلِتَتَّقُوا۟ وَلَعَلَّكُمْ تُرْحَمُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mxviii{فَكَذَّبُوهُ فَأَنجَيْنَٰهُ وَٱلَّذِينَ مَعَهُۥ فِى ٱلْفُلْكِ وَأَغْرَقْنَا ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَآ إِنَّهُمْ كَانُوا۟ قَوْمًا عَمِينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mxix{وَإِلَىٰ عَادٍ أَخَاهُمْ هُودًا قَالَ يَٰقَوْمِ ٱعْبُدُوا۟ ٱللَّهَ مَا لَكُم مِّنْ إِلَٰهٍ غَيْرُهُۥٓ أَفَلَا تَتَّقُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mxx{قَالَ ٱلْمَلَأُ ٱلَّذِينَ كَفَرُوا۟ مِن قَوْمِهِۦٓ إِنَّا لَنَرَىٰكَ فِى سَفَاهَةٍ وَإِنَّا لَنَظُنُّكَ مِنَ ٱلْكَٰذِبِينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mxxi{قَالَ يَٰقَوْمِ لَيْسَ بِى سَفَاهَةٌ وَلَٰكِنِّى رَسُولٌ مِّن رَّبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mxxii{أُبَلِّغُكُمْ رِسَٰلَٰتِ رَبِّى وَأَنَا۠ لَكُمْ نَاصِحٌ أَمِينٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mxxiii{أَوَعَجِبْتُمْ أَن جَآءَكُمْ ذِكْرٌ مِّن رَّبِّكُمْ عَلَىٰ رَجُلٍ مِّنكُمْ لِيُنذِرَكُمْ وَٱذْكُرُوٓا۟ إِذْ جَعَلَكُمْ خُلَفَآءَ مِنۢ بَعْدِ قَوْمِ نُوحٍ وَزَادَكُمْ فِى ٱلْخَلْقِ بَصْۜطَةً فَٱذْكُرُوٓا۟ ءَالَآءَ ٱللَّهِ لَعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mxxiv{قَالُوٓا۟ أَجِئْتَنَا لِنَعْبُدَ ٱللَّهَ وَحْدَهُۥ وَنَذَرَ مَا كَانَ يَعْبُدُ ءَابَآؤُنَا فَأْتِنَا بِمَا تَعِدُنَآ إِن كُنتَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mxxv{قَالَ قَدْ وَقَعَ عَلَيْكُم مِّن رَّبِّكُمْ رِجْسٌ وَغَضَبٌ أَتُجَٰدِلُونَنِى فِىٓ أَسْمَآءٍ سَمَّيْتُمُوهَآ أَنتُمْ وَءَابَآؤُكُم مَّا نَزَّلَ ٱللَّهُ بِهَا مِن سُلْطَٰنٍ فَٱنتَظِرُوٓا۟ إِنِّى مَعَكُم مِّنَ ٱلْمُنتَظِرِينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mxxvi{فَأَنجَيْنَٰهُ وَٱلَّذِينَ مَعَهُۥ بِرَحْمَةٍ مِّنَّا وَقَطَعْنَا دَابِرَ ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا وَمَا كَانُوا۟ مُؤْمِنِينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mxxvii{وَإِلَىٰ ثَمُودَ أَخَاهُمْ صَٰلِحًا قَالَ يَٰقَوْمِ ٱعْبُدُوا۟ ٱللَّهَ مَا لَكُم مِّنْ إِلَٰهٍ غَيْرُهُۥ قَدْ جَآءَتْكُم بَيِّنَةٌ مِّن رَّبِّكُمْ هَٰذِهِۦ نَاقَةُ ٱللَّهِ لَكُمْ ءَايَةً فَذَرُوهَا تَأْكُلْ فِىٓ أَرْضِ ٱللَّهِ وَلَا تَمَسُّوهَا بِسُوٓءٍ فَيَأْخُذَكُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mxxviii{وَٱذْكُرُوٓا۟ إِذْ جَعَلَكُمْ خُلَفَآءَ مِنۢ بَعْدِ عَادٍ وَبَوَّأَكُمْ فِى ٱلْأَرْضِ تَتَّخِذُونَ مِن سُهُولِهَا قُصُورًا وَتَنْحِتُونَ ٱلْجِبَالَ بُيُوتًا فَٱذْكُرُوٓا۟ ءَالَآءَ ٱللَّهِ وَلَا تَعْثَوْا۟ فِى ٱلْأَرْضِ مُفْسِدِينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mxxix{قَالَ ٱلْمَلَأُ ٱلَّذِينَ ٱسْتَكْبَرُوا۟ مِن قَوْمِهِۦ لِلَّذِينَ ٱسْتُضْعِفُوا۟ لِمَنْ ءَامَنَ مِنْهُمْ أَتَعْلَمُونَ أَنَّ صَٰلِحًا مُّرْسَلٌ مِّن رَّبِّهِۦ قَالُوٓا۟ إِنَّا بِمَآ أُرْسِلَ بِهِۦ مُؤْمِنُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mxxx{قَالَ ٱلَّذِينَ ٱسْتَكْبَرُوٓا۟ إِنَّا بِٱلَّذِىٓ ءَامَنتُم بِهِۦ كَٰفِرُونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mxxxi{فَعَقَرُوا۟ ٱلنَّاقَةَ وَعَتَوْا۟ عَنْ أَمْرِ رَبِّهِمْ وَقَالُوا۟ يَٰصَٰلِحُ ٱئْتِنَا بِمَا تَعِدُنَآ إِن كُنتَ مِنَ ٱلْمُرْسَلِينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mxxxii{فَأَخَذَتْهُمُ ٱلرَّجْفَةُ فَأَصْبَحُوا۟ فِى دَارِهِمْ جَٰثِمِينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mxxxiii{فَتَوَلَّىٰ عَنْهُمْ وَقَالَ يَٰقَوْمِ لَقَدْ أَبْلَغْتُكُمْ رِسَالَةَ رَبِّى وَنَصَحْتُ لَكُمْ وَلَٰكِن لَّا تُحِبُّونَ ٱلنَّٰصِحِينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mxxxiv{وَلُوطًا إِذْ قَالَ لِقَوْمِهِۦٓ أَتَأْتُونَ ٱلْفَٰحِشَةَ مَا سَبَقَكُم بِهَا مِنْ أَحَدٍ مِّنَ ٱلْعَٰلَمِينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mxxxv{إِنَّكُمْ لَتَأْتُونَ ٱلرِّجَالَ شَهْوَةً مِّن دُونِ ٱلنِّسَآءِ بَلْ أَنتُمْ قَوْمٌ مُّسْرِفُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mxxxvi{وَمَا كَانَ جَوَابَ قَوْمِهِۦٓ إِلَّآ أَن قَالُوٓا۟ أَخْرِجُوهُم مِّن قَرْيَتِكُمْ إِنَّهُمْ أُنَاسٌ يَتَطَهَّرُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mxxxvii{فَأَنجَيْنَٰهُ وَأَهْلَهُۥٓ إِلَّا ٱمْرَأَتَهُۥ كَانَتْ مِنَ ٱلْغَٰبِرِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mxxxviii{وَأَمْطَرْنَا عَلَيْهِم مَّطَرًا فَٱنظُرْ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُجْرِمِينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mxxxix{وَإِلَىٰ مَدْيَنَ أَخَاهُمْ شُعَيْبًا قَالَ يَٰقَوْمِ ٱعْبُدُوا۟ ٱللَّهَ مَا لَكُم مِّنْ إِلَٰهٍ غَيْرُهُۥ قَدْ جَآءَتْكُم بَيِّنَةٌ مِّن رَّبِّكُمْ فَأَوْفُوا۟ ٱلْكَيْلَ وَٱلْمِيزَانَ وَلَا تَبْخَسُوا۟ ٱلنَّاسَ أَشْيَآءَهُمْ وَلَا تُفْسِدُوا۟ فِى ٱلْأَرْضِ بَعْدَ إِصْلَٰحِهَا ذَٰلِكُمْ خَيْرٌ لَّكُمْ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mxl{وَلَا تَقْعُدُوا۟ بِكُلِّ صِرَٰطٍ تُوعِدُونَ وَتَصُدُّونَ عَن سَبِيلِ ٱللَّهِ مَنْ ءَامَنَ بِهِۦ وَتَبْغُونَهَا عِوَجًا وَٱذْكُرُوٓا۟ إِذْ كُنتُمْ قَلِيلًا فَكَثَّرَكُمْ وَٱنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُفْسِدِينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mxli{وَإِن كَانَ طَآئِفَةٌ مِّنكُمْ ءَامَنُوا۟ بِٱلَّذِىٓ أُرْسِلْتُ بِهِۦ وَطَآئِفَةٌ لَّمْ يُؤْمِنُوا۟ فَٱصْبِرُوا۟ حَتَّىٰ يَحْكُمَ ٱللَّهُ بَيْنَنَا وَهُوَ خَيْرُ ٱلْحَٰكِمِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mxlii{قَالَ ٱلْمَلَأُ ٱلَّذِينَ ٱسْتَكْبَرُوا۟ مِن قَوْمِهِۦ لَنُخْرِجَنَّكَ يَٰشُعَيْبُ وَٱلَّذِينَ ءَامَنُوا۟ مَعَكَ مِن قَرْيَتِنَآ أَوْ لَتَعُودُنَّ فِى مِلَّتِنَا قَالَ أَوَلَوْ كُنَّا كَٰرِهِينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mxliii{قَدِ ٱفْتَرَيْنَا عَلَى ٱللَّهِ كَذِبًا إِنْ عُدْنَا فِى مِلَّتِكُم بَعْدَ إِذْ نَجَّىٰنَا ٱللَّهُ مِنْهَا وَمَا يَكُونُ لَنَآ أَن نَّعُودَ فِيهَآ إِلَّآ أَن يَشَآءَ ٱللَّهُ رَبُّنَا وَسِعَ رَبُّنَا كُلَّ شَىْءٍ عِلْمًا عَلَى ٱللَّهِ تَوَكَّلْنَا رَبَّنَا ٱفْتَحْ بَيْنَنَا وَبَيْنَ قَوْمِنَا بِٱلْحَقِّ وَأَنتَ خَيْرُ ٱلْفَٰتِحِينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mxliv{وَقَالَ ٱلْمَلَأُ ٱلَّذِينَ كَفَرُوا۟ مِن قَوْمِهِۦ لَئِنِ ٱتَّبَعْتُمْ شُعَيْبًا إِنَّكُمْ إِذًا لَّخَٰسِرُونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mxlv{فَأَخَذَتْهُمُ ٱلرَّجْفَةُ فَأَصْبَحُوا۟ فِى دَارِهِمْ جَٰثِمِينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mxlvi{ٱلَّذِينَ كَذَّبُوا۟ شُعَيْبًا كَأَن لَّمْ يَغْنَوْا۟ فِيهَا ٱلَّذِينَ كَذَّبُوا۟ شُعَيْبًا كَانُوا۟ هُمُ ٱلْخَٰسِرِينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mxlvii{فَتَوَلَّىٰ عَنْهُمْ وَقَالَ يَٰقَوْمِ لَقَدْ أَبْلَغْتُكُمْ رِسَٰلَٰتِ رَبِّى وَنَصَحْتُ لَكُمْ فَكَيْفَ ءَاسَىٰ عَلَىٰ قَوْمٍ كَٰفِرِينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mxlviii{وَمَآ أَرْسَلْنَا فِى قَرْيَةٍ مِّن نَّبِىٍّ إِلَّآ أَخَذْنَآ أَهْلَهَا بِٱلْبَأْسَآءِ وَٱلضَّرَّآءِ لَعَلَّهُمْ يَضَّرَّعُونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mxlix{ثُمَّ بَدَّلْنَا مَكَانَ ٱلسَّيِّئَةِ ٱلْحَسَنَةَ حَتَّىٰ عَفَوا۟ وَّقَالُوا۟ قَدْ مَسَّ ءَابَآءَنَا ٱلضَّرَّآءُ وَٱلسَّرَّآءُ فَأَخَذْنَٰهُم بَغْتَةً وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@ml{وَلَوْ أَنَّ أَهْلَ ٱلْقُرَىٰٓ ءَامَنُوا۟ وَٱتَّقَوْا۟ لَفَتَحْنَا عَلَيْهِم بَرَكَٰتٍ مِّنَ ٱلسَّمَآءِ وَٱلْأَرْضِ وَلَٰكِن كَذَّبُوا۟ فَأَخَذْنَٰهُم بِمَا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mli{أَفَأَمِنَ أَهْلُ ٱلْقُرَىٰٓ أَن يَأْتِيَهُم بَأْسُنَا بَيَٰتًا وَهُمْ نَآئِمُونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mlii{أَوَأَمِنَ أَهْلُ ٱلْقُرَىٰٓ أَن يَأْتِيَهُم بَأْسُنَا ضُحًى وَهُمْ يَلْعَبُونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mliii{أَفَأَمِنُوا۟ مَكْرَ ٱللَّهِ فَلَا يَأْمَنُ مَكْرَ ٱللَّهِ إِلَّا ٱلْقَوْمُ ٱلْخَٰسِرُونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mliv{أَوَلَمْ يَهْدِ لِلَّذِينَ يَرِثُونَ ٱلْأَرْضَ مِنۢ بَعْدِ أَهْلِهَآ أَن لَّوْ نَشَآءُ أَصَبْنَٰهُم بِذُنُوبِهِمْ وَنَطْبَعُ عَلَىٰ قُلُوبِهِمْ فَهُمْ لَا يَسْمَعُونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mlv{تِلْكَ ٱلْقُرَىٰ نَقُصُّ عَلَيْكَ مِنْ أَنۢبَآئِهَا وَلَقَدْ جَآءَتْهُمْ رُسُلُهُم بِٱلْبَيِّنَٰتِ فَمَا كَانُوا۟ لِيُؤْمِنُوا۟ بِمَا كَذَّبُوا۟ مِن قَبْلُ كَذَٰلِكَ يَطْبَعُ ٱللَّهُ عَلَىٰ قُلُوبِ ٱلْكَٰفِرِينَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mlvi{وَمَا وَجَدْنَا لِأَكْثَرِهِم مِّنْ عَهْدٍ وَإِن وَجَدْنَآ أَكْثَرَهُمْ لَفَٰسِقِينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mlvii{ثُمَّ بَعَثْنَا مِنۢ بَعْدِهِم مُّوسَىٰ بِـَٔايَٰتِنَآ إِلَىٰ فِرْعَوْنَ وَمَلَإِي۟هِۦ فَظَلَمُوا۟ بِهَا فَٱنظُرْ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُفْسِدِينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mlviii{وَقَالَ مُوسَىٰ يَٰفِرْعَوْنُ إِنِّى رَسُولٌ مِّن رَّبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mlix{حَقِيقٌ عَلَىٰٓ أَن لَّآ أَقُولَ عَلَى ٱللَّهِ إِلَّا ٱلْحَقَّ قَدْ جِئْتُكُم بِبَيِّنَةٍ مِّن رَّبِّكُمْ فَأَرْسِلْ مَعِىَ بَنِىٓ إِسْرَٰٓءِيلَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mlx{قَالَ إِن كُنتَ جِئْتَ بِـَٔايَةٍ فَأْتِ بِهَآ إِن كُنتَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mlxi{فَأَلْقَىٰ عَصَاهُ فَإِذَا هِىَ ثُعْبَانٌ مُّبِينٌ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mlxii{وَنَزَعَ يَدَهُۥ فَإِذَا هِىَ بَيْضَآءُ لِلنَّٰظِرِينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mlxiii{قَالَ ٱلْمَلَأُ مِن قَوْمِ فِرْعَوْنَ إِنَّ هَٰذَا لَسَٰحِرٌ عَلِيمٌ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mlxiv{يُرِيدُ أَن يُخْرِجَكُم مِّنْ أَرْضِكُمْ فَمَاذَا تَأْمُرُونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mlxv{قَالُوٓا۟ أَرْجِهْ وَأَخَاهُ وَأَرْسِلْ فِى ٱلْمَدَآئِنِ حَٰشِرِينَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mlxvi{يَأْتُوكَ بِكُلِّ سَٰحِرٍ عَلِيمٍ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mlxvii{وَجَآءَ ٱلسَّحَرَةُ فِرْعَوْنَ قَالُوٓا۟ إِنَّ لَنَا لَأَجْرًا إِن كُنَّا نَحْنُ ٱلْغَٰلِبِينَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mlxviii{قَالَ نَعَمْ وَإِنَّكُمْ لَمِنَ ٱلْمُقَرَّبِينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mlxix{قَالُوا۟ يَٰمُوسَىٰٓ إِمَّآ أَن تُلْقِىَ وَإِمَّآ أَن نَّكُونَ نَحْنُ ٱلْمُلْقِينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mlxx{قَالَ أَلْقُوا۟ فَلَمَّآ أَلْقَوْا۟ سَحَرُوٓا۟ أَعْيُنَ ٱلنَّاسِ وَٱسْتَرْهَبُوهُمْ وَجَآءُو بِسِحْرٍ عَظِيمٍ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mlxxi{وَأَوْحَيْنَآ إِلَىٰ مُوسَىٰٓ أَنْ أَلْقِ عَصَاكَ فَإِذَا هِىَ تَلْقَفُ مَا يَأْفِكُونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mlxxii{فَوَقَعَ ٱلْحَقُّ وَبَطَلَ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mlxxiii{فَغُلِبُوا۟ هُنَالِكَ وَٱنقَلَبُوا۟ صَٰغِرِينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mlxxiv{وَأُلْقِىَ ٱلسَّحَرَةُ سَٰجِدِينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mlxxv{قَالُوٓا۟ ءَامَنَّا بِرَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mlxxvi{رَبِّ مُوسَىٰ وَهَٰرُونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mlxxvii{قَالَ فِرْعَوْنُ ءَامَنتُم بِهِۦ قَبْلَ أَنْ ءَاذَنَ لَكُمْ إِنَّ هَٰذَا لَمَكْرٌ مَّكَرْتُمُوهُ فِى ٱلْمَدِينَةِ لِتُخْرِجُوا۟ مِنْهَآ أَهْلَهَا فَسَوْفَ تَعْلَمُونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mlxxviii{لَأُقَطِّعَنَّ أَيْدِيَكُمْ وَأَرْجُلَكُم مِّنْ خِلَٰفٍ ثُمَّ لَأُصَلِّبَنَّكُمْ أَجْمَعِينَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mlxxix{قَالُوٓا۟ إِنَّآ إِلَىٰ رَبِّنَا مُنقَلِبُونَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mlxxx{وَمَا تَنقِمُ مِنَّآ إِلَّآ أَنْ ءَامَنَّا بِـَٔايَٰتِ رَبِّنَا لَمَّا جَآءَتْنَا رَبَّنَآ أَفْرِغْ عَلَيْنَا صَبْرًا وَتَوَفَّنَا مُسْلِمِينَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mlxxxi{وَقَالَ ٱلْمَلَأُ مِن قَوْمِ فِرْعَوْنَ أَتَذَرُ مُوسَىٰ وَقَوْمَهُۥ لِيُفْسِدُوا۟ فِى ٱلْأَرْضِ وَيَذَرَكَ وَءَالِهَتَكَ قَالَ سَنُقَتِّلُ أَبْنَآءَهُمْ وَنَسْتَحْىِۦ نِسَآءَهُمْ وَإِنَّا فَوْقَهُمْ قَٰهِرُونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mlxxxii{قَالَ مُوسَىٰ لِقَوْمِهِ ٱسْتَعِينُوا۟ بِٱللَّهِ وَٱصْبِرُوٓا۟ إِنَّ ٱلْأَرْضَ لِلَّهِ يُورِثُهَا مَن يَشَآءُ مِنْ عِبَادِهِۦ وَٱلْعَٰقِبَةُ لِلْمُتَّقِينَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mlxxxiii{قَالُوٓا۟ أُوذِينَا مِن قَبْلِ أَن تَأْتِيَنَا وَمِنۢ بَعْدِ مَا جِئْتَنَا قَالَ عَسَىٰ رَبُّكُمْ أَن يُهْلِكَ عَدُوَّكُمْ وَيَسْتَخْلِفَكُمْ فِى ٱلْأَرْضِ فَيَنظُرَ كَيْفَ تَعْمَلُونَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mlxxxiv{وَلَقَدْ أَخَذْنَآ ءَالَ فِرْعَوْنَ بِٱلسِّنِينَ وَنَقْصٍ مِّنَ ٱلثَّمَرَٰتِ لَعَلَّهُمْ يَذَّكَّرُونَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mlxxxv{فَإِذَا جَآءَتْهُمُ ٱلْحَسَنَةُ قَالُوا۟ لَنَا هَٰذِهِۦ وَإِن تُصِبْهُمْ سَيِّئَةٌ يَطَّيَّرُوا۟ بِمُوسَىٰ وَمَن مَّعَهُۥٓ أَلَآ إِنَّمَا طَٰٓئِرُهُمْ عِندَ ٱللَّهِ وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَعْلَمُونَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mlxxxvi{وَقَالُوا۟ مَهْمَا تَأْتِنَا بِهِۦ مِنْ ءَايَةٍ لِّتَسْحَرَنَا بِهَا فَمَا نَحْنُ لَكَ بِمُؤْمِنِينَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mlxxxvii{فَأَرْسَلْنَا عَلَيْهِمُ ٱلطُّوفَانَ وَٱلْجَرَادَ وَٱلْقُمَّلَ وَٱلضَّفَادِعَ وَٱلدَّمَ ءَايَٰتٍ مُّفَصَّلَٰتٍ فَٱسْتَكْبَرُوا۟ وَكَانُوا۟ قَوْمًا مُّجْرِمِينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mlxxxviii{وَلَمَّا وَقَعَ عَلَيْهِمُ ٱلرِّجْزُ قَالُوا۟ يَٰمُوسَى ٱدْعُ لَنَا رَبَّكَ بِمَا عَهِدَ عِندَكَ لَئِن كَشَفْتَ عَنَّا ٱلرِّجْزَ لَنُؤْمِنَنَّ لَكَ وَلَنُرْسِلَنَّ مَعَكَ بَنِىٓ إِسْرَٰٓءِيلَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mlxxxix{فَلَمَّا كَشَفْنَا عَنْهُمُ ٱلرِّجْزَ إِلَىٰٓ أَجَلٍ هُم بَٰلِغُوهُ إِذَا هُمْ يَنكُثُونَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mxc{فَٱنتَقَمْنَا مِنْهُمْ فَأَغْرَقْنَٰهُمْ فِى ٱلْيَمِّ بِأَنَّهُمْ كَذَّبُوا۟ بِـَٔايَٰتِنَا وَكَانُوا۟ عَنْهَا غَٰفِلِينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@mxci{وَأَوْرَثْنَا ٱلْقَوْمَ ٱلَّذِينَ كَانُوا۟ يُسْتَضْعَفُونَ مَشَٰرِقَ ٱلْأَرْضِ وَمَغَٰرِبَهَا ٱلَّتِى بَٰرَكْنَا فِيهَا وَتَمَّتْ كَلِمَتُ رَبِّكَ ٱلْحُسْنَىٰ عَلَىٰ بَنِىٓ إِسْرَٰٓءِيلَ بِمَا صَبَرُوا۟ وَدَمَّرْنَا مَا كَانَ يَصْنَعُ فِرْعَوْنُ وَقَوْمُهُۥ وَمَا كَانُوا۟ يَعْرِشُونَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@mxcii{وَجَٰوَزْنَا بِبَنِىٓ إِسْرَٰٓءِيلَ ٱلْبَحْرَ فَأَتَوْا۟ عَلَىٰ قَوْمٍ يَعْكُفُونَ عَلَىٰٓ أَصْنَامٍ لَّهُمْ قَالُوا۟ يَٰمُوسَى ٱجْعَل لَّنَآ إِلَٰهًا كَمَا لَهُمْ ءَالِهَةٌ قَالَ إِنَّكُمْ قَوْمٌ تَجْهَلُونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@mxciii{إِنَّ هَٰٓؤُلَآءِ مُتَبَّرٌ مَّا هُمْ فِيهِ وَبَٰطِلٌ مَّا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@mxciv{قَالَ أَغَيْرَ ٱللَّهِ أَبْغِيكُمْ إِلَٰهًا وَهُوَ فَضَّلَكُمْ عَلَى ٱلْعَٰلَمِينَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@mxcv{وَإِذْ أَنجَيْنَٰكُم مِّنْ ءَالِ فِرْعَوْنَ يَسُومُونَكُمْ سُوٓءَ ٱلْعَذَابِ يُقَتِّلُونَ أَبْنَآءَكُمْ وَيَسْتَحْيُونَ نِسَآءَكُمْ وَفِى ذَٰلِكُم بَلَآءٌ مِّن رَّبِّكُمْ عَظِيمٌ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@mxcvi{وَوَٰعَدْنَا مُوسَىٰ ثَلَٰثِينَ لَيْلَةً وَأَتْمَمْنَٰهَا بِعَشْرٍ فَتَمَّ مِيقَٰتُ رَبِّهِۦٓ أَرْبَعِينَ لَيْلَةً وَقَالَ مُوسَىٰ لِأَخِيهِ هَٰرُونَ ٱخْلُفْنِى فِى قَوْمِى وَأَصْلِحْ وَلَا تَتَّبِعْ سَبِيلَ ٱلْمُفْسِدِينَ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@mxcvii{وَلَمَّا جَآءَ مُوسَىٰ لِمِيقَٰتِنَا وَكَلَّمَهُۥ رَبُّهُۥ قَالَ رَبِّ أَرِنِىٓ أَنظُرْ إِلَيْكَ قَالَ لَن تَرَىٰنِى وَلَٰكِنِ ٱنظُرْ إِلَى ٱلْجَبَلِ فَإِنِ ٱسْتَقَرَّ مَكَانَهُۥ فَسَوْفَ تَرَىٰنِى فَلَمَّا تَجَلَّىٰ رَبُّهُۥ لِلْجَبَلِ جَعَلَهُۥ دَكًّا وَخَرَّ مُوسَىٰ صَعِقًا فَلَمَّآ أَفَاقَ قَالَ سُبْحَٰنَكَ تُبْتُ إِلَيْكَ وَأَنَا۠ أَوَّلُ ٱلْمُؤْمِنِينَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@mxcviii{قَالَ يَٰمُوسَىٰٓ إِنِّى ٱصْطَفَيْتُكَ عَلَى ٱلنَّاسِ بِرِسَٰلَٰتِى وَبِكَلَٰمِى فَخُذْ مَآ ءَاتَيْتُكَ وَكُن مِّنَ ٱلشَّٰكِرِينَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@mxcix{وَكَتَبْنَا لَهُۥ فِى ٱلْأَلْوَاحِ مِن كُلِّ شَىْءٍ مَّوْعِظَةً وَتَفْصِيلًا لِّكُلِّ شَىْءٍ فَخُذْهَا بِقُوَّةٍ وَأْمُرْ قَوْمَكَ يَأْخُذُوا۟ بِأَحْسَنِهَا سَأُو۟رِيكُمْ دَارَ ٱلْفَٰسِقِينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@mc{سَأَصْرِفُ عَنْ ءَايَٰتِىَ ٱلَّذِينَ يَتَكَبَّرُونَ فِى ٱلْأَرْضِ بِغَيْرِ ٱلْحَقِّ وَإِن يَرَوْا۟ كُلَّ ءَايَةٍ لَّا يُؤْمِنُوا۟ بِهَا وَإِن يَرَوْا۟ سَبِيلَ ٱلرُّشْدِ لَا يَتَّخِذُوهُ سَبِيلًا وَإِن يَرَوْا۟ سَبِيلَ ٱلْغَىِّ يَتَّخِذُوهُ سَبِيلًا ذَٰلِكَ بِأَنَّهُمْ كَذَّبُوا۟ بِـَٔايَٰتِنَا وَكَانُوا۟ عَنْهَا غَٰفِلِينَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@mci{وَٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا وَلِقَآءِ ٱلْءَاخِرَةِ حَبِطَتْ أَعْمَٰلُهُمْ هَلْ يُجْزَوْنَ إِلَّا مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@mcii{وَٱتَّخَذَ قَوْمُ مُوسَىٰ مِنۢ بَعْدِهِۦ مِنْ حُلِيِّهِمْ عِجْلًا جَسَدًا لَّهُۥ خُوَارٌ أَلَمْ يَرَوْا۟ أَنَّهُۥ لَا يُكَلِّمُهُمْ وَلَا يَهْدِيهِمْ سَبِيلًا ٱتَّخَذُوهُ وَكَانُوا۟ ظَٰلِمِينَ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@mciii{وَلَمَّا سُقِطَ فِىٓ أَيْدِيهِمْ وَرَأَوْا۟ أَنَّهُمْ قَدْ ضَلُّوا۟ قَالُوا۟ لَئِن لَّمْ يَرْحَمْنَا رَبُّنَا وَيَغْفِرْ لَنَا لَنَكُونَنَّ مِنَ ٱلْخَٰسِرِينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@mciv{وَلَمَّا رَجَعَ مُوسَىٰٓ إِلَىٰ قَوْمِهِۦ غَضْبَٰنَ أَسِفًا قَالَ بِئْسَمَا خَلَفْتُمُونِى مِنۢ بَعْدِىٓ أَعَجِلْتُمْ أَمْرَ رَبِّكُمْ وَأَلْقَى ٱلْأَلْوَاحَ وَأَخَذَ بِرَأْسِ أَخِيهِ يَجُرُّهُۥٓ إِلَيْهِ قَالَ ٱبْنَ أُمَّ إِنَّ ٱلْقَوْمَ ٱسْتَضْعَفُونِى وَكَادُوا۟ يَقْتُلُونَنِى فَلَا تُشْمِتْ بِىَ ٱلْأَعْدَآءَ وَلَا تَجْعَلْنِى مَعَ ٱلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@mcv{قَالَ رَبِّ ٱغْفِرْ لِى وَلِأَخِى وَأَدْخِلْنَا فِى رَحْمَتِكَ وَأَنتَ أَرْحَمُ ٱلرَّٰحِمِينَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@mcvi{إِنَّ ٱلَّذِينَ ٱتَّخَذُوا۟ ٱلْعِجْلَ سَيَنَالُهُمْ غَضَبٌ مِّن رَّبِّهِمْ وَذِلَّةٌ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَكَذَٰلِكَ نَجْزِى ٱلْمُفْتَرِينَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@mcvii{وَٱلَّذِينَ عَمِلُوا۟ ٱلسَّيِّـَٔاتِ ثُمَّ تَابُوا۟ مِنۢ بَعْدِهَا وَءَامَنُوٓا۟ إِنَّ رَبَّكَ مِنۢ بَعْدِهَا لَغَفُورٌ رَّحِيمٌ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@mcviii{وَلَمَّا سَكَتَ عَن مُّوسَى ٱلْغَضَبُ أَخَذَ ٱلْأَلْوَاحَ وَفِى نُسْخَتِهَا هُدًى وَرَحْمَةٌ لِّلَّذِينَ هُمْ لِرَبِّهِمْ يَرْهَبُونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@mcix{وَٱخْتَارَ مُوسَىٰ قَوْمَهُۥ سَبْعِينَ رَجُلًا لِّمِيقَٰتِنَا فَلَمَّآ أَخَذَتْهُمُ ٱلرَّجْفَةُ قَالَ رَبِّ لَوْ شِئْتَ أَهْلَكْتَهُم مِّن قَبْلُ وَإِيَّٰىَ أَتُهْلِكُنَا بِمَا فَعَلَ ٱلسُّفَهَآءُ مِنَّآ إِنْ هِىَ إِلَّا فِتْنَتُكَ تُضِلُّ بِهَا مَن تَشَآءُ وَتَهْدِى مَن تَشَآءُ أَنتَ وَلِيُّنَا فَٱغْفِرْ لَنَا وَٱرْحَمْنَا وَأَنتَ خَيْرُ ٱلْغَٰفِرِينَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@mcx{وَٱكْتُبْ لَنَا فِى هَٰذِهِ ٱلدُّنْيَا حَسَنَةً وَفِى ٱلْءَاخِرَةِ إِنَّا هُدْنَآ إِلَيْكَ قَالَ عَذَابِىٓ أُصِيبُ بِهِۦ مَنْ أَشَآءُ وَرَحْمَتِى وَسِعَتْ كُلَّ شَىْءٍ فَسَأَكْتُبُهَا لِلَّذِينَ يَتَّقُونَ وَيُؤْتُونَ ٱلزَّكَوٰةَ وَٱلَّذِينَ هُم بِـَٔايَٰتِنَا يُؤْمِنُونَ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@mcxi{ٱلَّذِينَ يَتَّبِعُونَ ٱلرَّسُولَ ٱلنَّبِىَّ ٱلْأُمِّىَّ ٱلَّذِى يَجِدُونَهُۥ مَكْتُوبًا عِندَهُمْ فِى ٱلتَّوْرَىٰةِ وَٱلْإِنجِيلِ يَأْمُرُهُم بِٱلْمَعْرُوفِ وَيَنْهَىٰهُمْ عَنِ ٱلْمُنكَرِ وَيُحِلُّ لَهُمُ ٱلطَّيِّبَٰتِ وَيُحَرِّمُ عَلَيْهِمُ ٱلْخَبَٰٓئِثَ وَيَضَعُ عَنْهُمْ إِصْرَهُمْ وَٱلْأَغْلَٰلَ ٱلَّتِى كَانَتْ عَلَيْهِمْ فَٱلَّذِينَ ءَامَنُوا۟ بِهِۦ وَعَزَّرُوهُ وَنَصَرُوهُ وَٱتَّبَعُوا۟ ٱلنُّورَ ٱلَّذِىٓ أُنزِلَ مَعَهُۥٓ أُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@mcxii{قُلْ يَٰٓأَيُّهَا ٱلنَّاسُ إِنِّى رَسُولُ ٱللَّهِ إِلَيْكُمْ جَمِيعًا ٱلَّذِى لَهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ لَآ إِلَٰهَ إِلَّا هُوَ يُحْىِۦ وَيُمِيتُ فَـَٔامِنُوا۟ بِٱللَّهِ وَرَسُولِهِ ٱلنَّبِىِّ ٱلْأُمِّىِّ ٱلَّذِى يُؤْمِنُ بِٱللَّهِ وَكَلِمَٰتِهِۦ وَٱتَّبِعُوهُ لَعَلَّكُمْ تَهْتَدُونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@mcxiii{وَمِن قَوْمِ مُوسَىٰٓ أُمَّةٌ يَهْدُونَ بِٱلْحَقِّ وَبِهِۦ يَعْدِلُونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@mcxiv{وَقَطَّعْنَٰهُمُ ٱثْنَتَىْ عَشْرَةَ أَسْبَاطًا أُمَمًا وَأَوْحَيْنَآ إِلَىٰ مُوسَىٰٓ إِذِ ٱسْتَسْقَىٰهُ قَوْمُهُۥٓ أَنِ ٱضْرِب بِّعَصَاكَ ٱلْحَجَرَ فَٱنۢبَجَسَتْ مِنْهُ ٱثْنَتَا عَشْرَةَ عَيْنًا قَدْ عَلِمَ كُلُّ أُنَاسٍ مَّشْرَبَهُمْ وَظَلَّلْنَا عَلَيْهِمُ ٱلْغَمَٰمَ وَأَنزَلْنَا عَلَيْهِمُ ٱلْمَنَّ وَٱلسَّلْوَىٰ كُلُوا۟ مِن طَيِّبَٰتِ مَا رَزَقْنَٰكُمْ وَمَا ظَلَمُونَا وَلَٰكِن كَانُوٓا۟ أَنفُسَهُمْ يَظْلِمُونَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@mcxv{وَإِذْ قِيلَ لَهُمُ ٱسْكُنُوا۟ هَٰذِهِ ٱلْقَرْيَةَ وَكُلُوا۟ مِنْهَا حَيْثُ شِئْتُمْ وَقُولُوا۟ حِطَّةٌ وَٱدْخُلُوا۟ ٱلْبَابَ سُجَّدًا نَّغْفِرْ لَكُمْ خَطِيٓـَٰٔتِكُمْ سَنَزِيدُ ٱلْمُحْسِنِينَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@mcxvi{فَبَدَّلَ ٱلَّذِينَ ظَلَمُوا۟ مِنْهُمْ قَوْلًا غَيْرَ ٱلَّذِى قِيلَ لَهُمْ فَأَرْسَلْنَا عَلَيْهِمْ رِجْزًا مِّنَ ٱلسَّمَآءِ بِمَا كَانُوا۟ يَظْلِمُونَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@mcxvii{وَسْـَٔلْهُمْ عَنِ ٱلْقَرْيَةِ ٱلَّتِى كَانَتْ حَاضِرَةَ ٱلْبَحْرِ إِذْ يَعْدُونَ فِى ٱلسَّبْتِ إِذْ تَأْتِيهِمْ حِيتَانُهُمْ يَوْمَ سَبْتِهِمْ شُرَّعًا وَيَوْمَ لَا يَسْبِتُونَ لَا تَأْتِيهِمْ كَذَٰلِكَ نَبْلُوهُم بِمَا كَانُوا۟ يَفْسُقُونَ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@mcxviii{وَإِذْ قَالَتْ أُمَّةٌ مِّنْهُمْ لِمَ تَعِظُونَ قَوْمًا ٱللَّهُ مُهْلِكُهُمْ أَوْ مُعَذِّبُهُمْ عَذَابًا شَدِيدًا قَالُوا۟ مَعْذِرَةً إِلَىٰ رَبِّكُمْ وَلَعَلَّهُمْ يَتَّقُونَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@mcxix{فَلَمَّا نَسُوا۟ مَا ذُكِّرُوا۟ بِهِۦٓ أَنجَيْنَا ٱلَّذِينَ يَنْهَوْنَ عَنِ ٱلسُّوٓءِ وَأَخَذْنَا ٱلَّذِينَ ظَلَمُوا۟ بِعَذَابٍۭ بَـِٔيسٍۭ بِمَا كَانُوا۟ يَفْسُقُونَ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@mcxx{فَلَمَّا عَتَوْا۟ عَن مَّا نُهُوا۟ عَنْهُ قُلْنَا لَهُمْ كُونُوا۟ قِرَدَةً خَٰسِـِٔينَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@mcxxi{وَإِذْ تَأَذَّنَ رَبُّكَ لَيَبْعَثَنَّ عَلَيْهِمْ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ مَن يَسُومُهُمْ سُوٓءَ ٱلْعَذَابِ إِنَّ رَبَّكَ لَسَرِيعُ ٱلْعِقَابِ وَإِنَّهُۥ لَغَفُورٌ رَّحِيمٌ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@mcxxii{وَقَطَّعْنَٰهُمْ فِى ٱلْأَرْضِ أُمَمًا مِّنْهُمُ ٱلصَّٰلِحُونَ وَمِنْهُمْ دُونَ ذَٰلِكَ وَبَلَوْنَٰهُم بِٱلْحَسَنَٰتِ وَٱلسَّيِّـَٔاتِ لَعَلَّهُمْ يَرْجِعُونَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@mcxxiii{فَخَلَفَ مِنۢ بَعْدِهِمْ خَلْفٌ وَرِثُوا۟ ٱلْكِتَٰبَ يَأْخُذُونَ عَرَضَ هَٰذَا ٱلْأَدْنَىٰ وَيَقُولُونَ سَيُغْفَرُ لَنَا وَإِن يَأْتِهِمْ عَرَضٌ مِّثْلُهُۥ يَأْخُذُوهُ أَلَمْ يُؤْخَذْ عَلَيْهِم مِّيثَٰقُ ٱلْكِتَٰبِ أَن لَّا يَقُولُوا۟ عَلَى ٱللَّهِ إِلَّا ٱلْحَقَّ وَدَرَسُوا۟ مَا فِيهِ وَٱلدَّارُ ٱلْءَاخِرَةُ خَيْرٌ لِّلَّذِينَ يَتَّقُونَ أَفَلَا تَعْقِلُونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@mcxxiv{وَٱلَّذِينَ يُمَسِّكُونَ بِٱلْكِتَٰبِ وَأَقَامُوا۟ ٱلصَّلَوٰةَ إِنَّا لَا نُضِيعُ أَجْرَ ٱلْمُصْلِحِينَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@mcxxv{وَإِذْ نَتَقْنَا ٱلْجَبَلَ فَوْقَهُمْ كَأَنَّهُۥ ظُلَّةٌ وَظَنُّوٓا۟ أَنَّهُۥ وَاقِعٌۢ بِهِمْ خُذُوا۟ مَآ ءَاتَيْنَٰكُم بِقُوَّةٍ وَٱذْكُرُوا۟ مَا فِيهِ لَعَلَّكُمْ تَتَّقُونَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@mcxxvi{وَإِذْ أَخَذَ رَبُّكَ مِنۢ بَنِىٓ ءَادَمَ مِن ظُهُورِهِمْ ذُرِّيَّتَهُمْ وَأَشْهَدَهُمْ عَلَىٰٓ أَنفُسِهِمْ أَلَسْتُ بِرَبِّكُمْ قَالُوا۟ بَلَىٰ شَهِدْنَآ أَن تَقُولُوا۟ يَوْمَ ٱلْقِيَٰمَةِ إِنَّا كُنَّا عَنْ هَٰذَا غَٰفِلِينَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@mcxxvii{أَوْ تَقُولُوٓا۟ إِنَّمَآ أَشْرَكَ ءَابَآؤُنَا مِن قَبْلُ وَكُنَّا ذُرِّيَّةً مِّنۢ بَعْدِهِمْ أَفَتُهْلِكُنَا بِمَا فَعَلَ ٱلْمُبْطِلُونَ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@mcxxviii{وَكَذَٰلِكَ نُفَصِّلُ ٱلْءَايَٰتِ وَلَعَلَّهُمْ يَرْجِعُونَ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@mcxxix{وَٱتْلُ عَلَيْهِمْ نَبَأَ ٱلَّذِىٓ ءَاتَيْنَٰهُ ءَايَٰتِنَا فَٱنسَلَخَ مِنْهَا فَأَتْبَعَهُ ٱلشَّيْطَٰنُ فَكَانَ مِنَ ٱلْغَاوِينَ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@mcxxx{وَلَوْ شِئْنَا لَرَفَعْنَٰهُ بِهَا وَلَٰكِنَّهُۥٓ أَخْلَدَ إِلَى ٱلْأَرْضِ وَٱتَّبَعَ هَوَىٰهُ فَمَثَلُهُۥ كَمَثَلِ ٱلْكَلْبِ إِن تَحْمِلْ عَلَيْهِ يَلْهَثْ أَوْ تَتْرُكْهُ يَلْهَث ذَّٰلِكَ مَثَلُ ٱلْقَوْمِ ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا فَٱقْصُصِ ٱلْقَصَصَ لَعَلَّهُمْ يَتَفَكَّرُونَ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@mcxxxi{سَآءَ مَثَلًا ٱلْقَوْمُ ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا وَأَنفُسَهُمْ كَانُوا۟ يَظْلِمُونَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@mcxxxii{مَن يَهْدِ ٱللَّهُ فَهُوَ ٱلْمُهْتَدِى وَمَن يُضْلِلْ فَأُو۟لَٰٓئِكَ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@mcxxxiii{وَلَقَدْ ذَرَأْنَا لِجَهَنَّمَ كَثِيرًا مِّنَ ٱلْجِنِّ وَٱلْإِنسِ لَهُمْ قُلُوبٌ لَّا يَفْقَهُونَ بِهَا وَلَهُمْ أَعْيُنٌ لَّا يُبْصِرُونَ بِهَا وَلَهُمْ ءَاذَانٌ لَّا يَسْمَعُونَ بِهَآ أُو۟لَٰٓئِكَ كَٱلْأَنْعَٰمِ بَلْ هُمْ أَضَلُّ أُو۟لَٰٓئِكَ هُمُ ٱلْغَٰفِلُونَ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@mcxxxiv{وَلِلَّهِ ٱلْأَسْمَآءُ ٱلْحُسْنَىٰ فَٱدْعُوهُ بِهَا وَذَرُوا۟ ٱلَّذِينَ يُلْحِدُونَ فِىٓ أَسْمَٰٓئِهِۦ سَيُجْزَوْنَ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@mcxxxv{وَمِمَّنْ خَلَقْنَآ أُمَّةٌ يَهْدُونَ بِٱلْحَقِّ وَبِهِۦ يَعْدِلُونَ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@mcxxxvi{وَٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا سَنَسْتَدْرِجُهُم مِّنْ حَيْثُ لَا يَعْلَمُونَ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@mcxxxvii{وَأُمْلِى لَهُمْ إِنَّ كَيْدِى مَتِينٌ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@mcxxxviii{أَوَلَمْ يَتَفَكَّرُوا۟ مَا بِصَاحِبِهِم مِّن جِنَّةٍ إِنْ هُوَ إِلَّا نَذِيرٌ مُّبِينٌ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@mcxxxix{أَوَلَمْ يَنظُرُوا۟ فِى مَلَكُوتِ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا خَلَقَ ٱللَّهُ مِن شَىْءٍ وَأَنْ عَسَىٰٓ أَن يَكُونَ قَدِ ٱقْتَرَبَ أَجَلُهُمْ فَبِأَىِّ حَدِيثٍۭ بَعْدَهُۥ يُؤْمِنُونَ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@mcxl{مَن يُضْلِلِ ٱللَّهُ فَلَا هَادِىَ لَهُۥ وَيَذَرُهُمْ فِى طُغْيَٰنِهِمْ يَعْمَهُونَ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@mcxli{يَسْـَٔلُونَكَ عَنِ ٱلسَّاعَةِ أَيَّانَ مُرْسَىٰهَا قُلْ إِنَّمَا عِلْمُهَا عِندَ رَبِّى لَا يُجَلِّيهَا لِوَقْتِهَآ إِلَّا هُوَ ثَقُلَتْ فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ لَا تَأْتِيكُمْ إِلَّا بَغْتَةً يَسْـَٔلُونَكَ كَأَنَّكَ حَفِىٌّ عَنْهَا قُلْ إِنَّمَا عِلْمُهَا عِندَ ٱللَّهِ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@mcxlii{قُل لَّآ أَمْلِكُ لِنَفْسِى نَفْعًا وَلَا ضَرًّا إِلَّا مَا شَآءَ ٱللَّهُ وَلَوْ كُنتُ أَعْلَمُ ٱلْغَيْبَ لَٱسْتَكْثَرْتُ مِنَ ٱلْخَيْرِ وَمَا مَسَّنِىَ ٱلسُّوٓءُ إِنْ أَنَا۠ إِلَّا نَذِيرٌ وَبَشِيرٌ لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@mcxliii{هُوَ ٱلَّذِى خَلَقَكُم مِّن نَّفْسٍ وَٰحِدَةٍ وَجَعَلَ مِنْهَا زَوْجَهَا لِيَسْكُنَ إِلَيْهَا فَلَمَّا تَغَشَّىٰهَا حَمَلَتْ حَمْلًا خَفِيفًا فَمَرَّتْ بِهِۦ فَلَمَّآ أَثْقَلَت دَّعَوَا ٱللَّهَ رَبَّهُمَا لَئِنْ ءَاتَيْتَنَا صَٰلِحًا لَّنَكُونَنَّ مِنَ ٱلشَّٰكِرِينَ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@mcxliv{فَلَمَّآ ءَاتَىٰهُمَا صَٰلِحًا جَعَلَا لَهُۥ شُرَكَآءَ فِيمَآ ءَاتَىٰهُمَا فَتَعَٰلَى ٱللَّهُ عَمَّا يُشْرِكُونَ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@mcxlv{أَيُشْرِكُونَ مَا لَا يَخْلُقُ شَيْـًٔا وَهُمْ يُخْلَقُونَ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@mcxlvi{وَلَا يَسْتَطِيعُونَ لَهُمْ نَصْرًا وَلَآ أَنفُسَهُمْ يَنصُرُونَ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@mcxlvii{وَإِن تَدْعُوهُمْ إِلَى ٱلْهُدَىٰ لَا يَتَّبِعُوكُمْ سَوَآءٌ عَلَيْكُمْ أَدَعَوْتُمُوهُمْ أَمْ أَنتُمْ صَٰمِتُونَ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@mcxlviii{إِنَّ ٱلَّذِينَ تَدْعُونَ مِن دُونِ ٱللَّهِ عِبَادٌ أَمْثَالُكُمْ فَٱدْعُوهُمْ فَلْيَسْتَجِيبُوا۟ لَكُمْ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@mcxlix{أَلَهُمْ أَرْجُلٌ يَمْشُونَ بِهَآ أَمْ لَهُمْ أَيْدٍ يَبْطِشُونَ بِهَآ أَمْ لَهُمْ أَعْيُنٌ يُبْصِرُونَ بِهَآ أَمْ لَهُمْ ءَاذَانٌ يَسْمَعُونَ بِهَا قُلِ ٱدْعُوا۟ شُرَكَآءَكُمْ ثُمَّ كِيدُونِ فَلَا تُنظِرُونِ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@mcl{إِنَّ وَلِۦِّىَ ٱللَّهُ ٱلَّذِى نَزَّلَ ٱلْكِتَٰبَ وَهُوَ يَتَوَلَّى ٱلصَّٰلِحِينَ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@mcli{وَٱلَّذِينَ تَدْعُونَ مِن دُونِهِۦ لَا يَسْتَطِيعُونَ نَصْرَكُمْ وَلَآ أَنفُسَهُمْ يَنصُرُونَ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@mclii{وَإِن تَدْعُوهُمْ إِلَى ٱلْهُدَىٰ لَا يَسْمَعُوا۟ وَتَرَىٰهُمْ يَنظُرُونَ إِلَيْكَ وَهُمْ لَا يُبْصِرُونَ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@mcliii{خُذِ ٱلْعَفْوَ وَأْمُرْ بِٱلْعُرْفِ وَأَعْرِضْ عَنِ ٱلْجَٰهِلِينَ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@mcliv{وَإِمَّا يَنزَغَنَّكَ مِنَ ٱلشَّيْطَٰنِ نَزْغٌ فَٱسْتَعِذْ بِٱللَّهِ إِنَّهُۥ سَمِيعٌ عَلِيمٌ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@mclv{إِنَّ ٱلَّذِينَ ٱتَّقَوْا۟ إِذَا مَسَّهُمْ طَٰٓئِفٌ مِّنَ ٱلشَّيْطَٰنِ تَذَكَّرُوا۟ فَإِذَا هُم مُّبْصِرُونَ\qt@no{﴿٢٠١﴾}}
\qt@newcmd\qurantext@mclvi{وَإِخْوَٰنُهُمْ يَمُدُّونَهُمْ فِى ٱلْغَىِّ ثُمَّ لَا يُقْصِرُونَ\qt@no{﴿٢٠٢﴾}}
\qt@newcmd\qurantext@mclvii{وَإِذَا لَمْ تَأْتِهِم بِـَٔايَةٍ قَالُوا۟ لَوْلَا ٱجْتَبَيْتَهَا قُلْ إِنَّمَآ أَتَّبِعُ مَا يُوحَىٰٓ إِلَىَّ مِن رَّبِّى هَٰذَا بَصَآئِرُ مِن رَّبِّكُمْ وَهُدًى وَرَحْمَةٌ لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٢٠٣﴾}}
\qt@newcmd\qurantext@mclviii{وَإِذَا قُرِئَ ٱلْقُرْءَانُ فَٱسْتَمِعُوا۟ لَهُۥ وَأَنصِتُوا۟ لَعَلَّكُمْ تُرْحَمُونَ\qt@no{﴿٢٠٤﴾}}
\qt@newcmd\qurantext@mclix{وَٱذْكُر رَّبَّكَ فِى نَفْسِكَ تَضَرُّعًا وَخِيفَةً وَدُونَ ٱلْجَهْرِ مِنَ ٱلْقَوْلِ بِٱلْغُدُوِّ وَٱلْءَاصَالِ وَلَا تَكُن مِّنَ ٱلْغَٰفِلِينَ\qt@no{﴿٢٠٥﴾}}
\qt@newcmd\qurantext@mclx{إِنَّ ٱلَّذِينَ عِندَ رَبِّكَ لَا يَسْتَكْبِرُونَ عَنْ عِبَادَتِهِۦ وَيُسَبِّحُونَهُۥ وَلَهُۥ يَسْجُدُونَ\qt@no{﴿٢٠٦﴾}}
\qt@newcmd\qurantext@mclxi{\basmalah يَسْـَٔلُونَكَ عَنِ ٱلْأَنفَالِ قُلِ ٱلْأَنفَالُ لِلَّهِ وَٱلرَّسُولِ فَٱتَّقُوا۟ ٱللَّهَ وَأَصْلِحُوا۟ ذَاتَ بَيْنِكُمْ وَأَطِيعُوا۟ ٱللَّهَ وَرَسُولَهُۥٓ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mclxii{إِنَّمَا ٱلْمُؤْمِنُونَ ٱلَّذِينَ إِذَا ذُكِرَ ٱللَّهُ وَجِلَتْ قُلُوبُهُمْ وَإِذَا تُلِيَتْ عَلَيْهِمْ ءَايَٰتُهُۥ زَادَتْهُمْ إِيمَٰنًا وَعَلَىٰ رَبِّهِمْ يَتَوَكَّلُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mclxiii{ٱلَّذِينَ يُقِيمُونَ ٱلصَّلَوٰةَ وَمِمَّا رَزَقْنَٰهُمْ يُنفِقُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mclxiv{أُو۟لَٰٓئِكَ هُمُ ٱلْمُؤْمِنُونَ حَقًّا لَّهُمْ دَرَجَٰتٌ عِندَ رَبِّهِمْ وَمَغْفِرَةٌ وَرِزْقٌ كَرِيمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mclxv{كَمَآ أَخْرَجَكَ رَبُّكَ مِنۢ بَيْتِكَ بِٱلْحَقِّ وَإِنَّ فَرِيقًا مِّنَ ٱلْمُؤْمِنِينَ لَكَٰرِهُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mclxvi{يُجَٰدِلُونَكَ فِى ٱلْحَقِّ بَعْدَمَا تَبَيَّنَ كَأَنَّمَا يُسَاقُونَ إِلَى ٱلْمَوْتِ وَهُمْ يَنظُرُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mclxvii{وَإِذْ يَعِدُكُمُ ٱللَّهُ إِحْدَى ٱلطَّآئِفَتَيْنِ أَنَّهَا لَكُمْ وَتَوَدُّونَ أَنَّ غَيْرَ ذَاتِ ٱلشَّوْكَةِ تَكُونُ لَكُمْ وَيُرِيدُ ٱللَّهُ أَن يُحِقَّ ٱلْحَقَّ بِكَلِمَٰتِهِۦ وَيَقْطَعَ دَابِرَ ٱلْكَٰفِرِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mclxviii{لِيُحِقَّ ٱلْحَقَّ وَيُبْطِلَ ٱلْبَٰطِلَ وَلَوْ كَرِهَ ٱلْمُجْرِمُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mclxix{إِذْ تَسْتَغِيثُونَ رَبَّكُمْ فَٱسْتَجَابَ لَكُمْ أَنِّى مُمِدُّكُم بِأَلْفٍ مِّنَ ٱلْمَلَٰٓئِكَةِ مُرْدِفِينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mclxx{وَمَا جَعَلَهُ ٱللَّهُ إِلَّا بُشْرَىٰ وَلِتَطْمَئِنَّ بِهِۦ قُلُوبُكُمْ وَمَا ٱلنَّصْرُ إِلَّا مِنْ عِندِ ٱللَّهِ إِنَّ ٱللَّهَ عَزِيزٌ حَكِيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mclxxi{إِذْ يُغَشِّيكُمُ ٱلنُّعَاسَ أَمَنَةً مِّنْهُ وَيُنَزِّلُ عَلَيْكُم مِّنَ ٱلسَّمَآءِ مَآءً لِّيُطَهِّرَكُم بِهِۦ وَيُذْهِبَ عَنكُمْ رِجْزَ ٱلشَّيْطَٰنِ وَلِيَرْبِطَ عَلَىٰ قُلُوبِكُمْ وَيُثَبِّتَ بِهِ ٱلْأَقْدَامَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mclxxii{إِذْ يُوحِى رَبُّكَ إِلَى ٱلْمَلَٰٓئِكَةِ أَنِّى مَعَكُمْ فَثَبِّتُوا۟ ٱلَّذِينَ ءَامَنُوا۟ سَأُلْقِى فِى قُلُوبِ ٱلَّذِينَ كَفَرُوا۟ ٱلرُّعْبَ فَٱضْرِبُوا۟ فَوْقَ ٱلْأَعْنَاقِ وَٱضْرِبُوا۟ مِنْهُمْ كُلَّ بَنَانٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mclxxiii{ذَٰلِكَ بِأَنَّهُمْ شَآقُّوا۟ ٱللَّهَ وَرَسُولَهُۥ وَمَن يُشَاقِقِ ٱللَّهَ وَرَسُولَهُۥ فَإِنَّ ٱللَّهَ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mclxxiv{ذَٰلِكُمْ فَذُوقُوهُ وَأَنَّ لِلْكَٰفِرِينَ عَذَابَ ٱلنَّارِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mclxxv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا لَقِيتُمُ ٱلَّذِينَ كَفَرُوا۟ زَحْفًا فَلَا تُوَلُّوهُمُ ٱلْأَدْبَارَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mclxxvi{وَمَن يُوَلِّهِمْ يَوْمَئِذٍ دُبُرَهُۥٓ إِلَّا مُتَحَرِّفًا لِّقِتَالٍ أَوْ مُتَحَيِّزًا إِلَىٰ فِئَةٍ فَقَدْ بَآءَ بِغَضَبٍ مِّنَ ٱللَّهِ وَمَأْوَىٰهُ جَهَنَّمُ وَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mclxxvii{فَلَمْ تَقْتُلُوهُمْ وَلَٰكِنَّ ٱللَّهَ قَتَلَهُمْ وَمَا رَمَيْتَ إِذْ رَمَيْتَ وَلَٰكِنَّ ٱللَّهَ رَمَىٰ وَلِيُبْلِىَ ٱلْمُؤْمِنِينَ مِنْهُ بَلَآءً حَسَنًا إِنَّ ٱللَّهَ سَمِيعٌ عَلِيمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mclxxviii{ذَٰلِكُمْ وَأَنَّ ٱللَّهَ مُوهِنُ كَيْدِ ٱلْكَٰفِرِينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mclxxix{إِن تَسْتَفْتِحُوا۟ فَقَدْ جَآءَكُمُ ٱلْفَتْحُ وَإِن تَنتَهُوا۟ فَهُوَ خَيْرٌ لَّكُمْ وَإِن تَعُودُوا۟ نَعُدْ وَلَن تُغْنِىَ عَنكُمْ فِئَتُكُمْ شَيْـًٔا وَلَوْ كَثُرَتْ وَأَنَّ ٱللَّهَ مَعَ ٱلْمُؤْمِنِينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mclxxx{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ أَطِيعُوا۟ ٱللَّهَ وَرَسُولَهُۥ وَلَا تَوَلَّوْا۟ عَنْهُ وَأَنتُمْ تَسْمَعُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mclxxxi{وَلَا تَكُونُوا۟ كَٱلَّذِينَ قَالُوا۟ سَمِعْنَا وَهُمْ لَا يَسْمَعُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mclxxxii{إِنَّ شَرَّ ٱلدَّوَآبِّ عِندَ ٱللَّهِ ٱلصُّمُّ ٱلْبُكْمُ ٱلَّذِينَ لَا يَعْقِلُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mclxxxiii{وَلَوْ عَلِمَ ٱللَّهُ فِيهِمْ خَيْرًا لَّأَسْمَعَهُمْ وَلَوْ أَسْمَعَهُمْ لَتَوَلَّوا۟ وَّهُم مُّعْرِضُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mclxxxiv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱسْتَجِيبُوا۟ لِلَّهِ وَلِلرَّسُولِ إِذَا دَعَاكُمْ لِمَا يُحْيِيكُمْ وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ يَحُولُ بَيْنَ ٱلْمَرْءِ وَقَلْبِهِۦ وَأَنَّهُۥٓ إِلَيْهِ تُحْشَرُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mclxxxv{وَٱتَّقُوا۟ فِتْنَةً لَّا تُصِيبَنَّ ٱلَّذِينَ ظَلَمُوا۟ مِنكُمْ خَآصَّةً وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mclxxxvi{وَٱذْكُرُوٓا۟ إِذْ أَنتُمْ قَلِيلٌ مُّسْتَضْعَفُونَ فِى ٱلْأَرْضِ تَخَافُونَ أَن يَتَخَطَّفَكُمُ ٱلنَّاسُ فَـَٔاوَىٰكُمْ وَأَيَّدَكُم بِنَصْرِهِۦ وَرَزَقَكُم مِّنَ ٱلطَّيِّبَٰتِ لَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mclxxxvii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَخُونُوا۟ ٱللَّهَ وَٱلرَّسُولَ وَتَخُونُوٓا۟ أَمَٰنَٰتِكُمْ وَأَنتُمْ تَعْلَمُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mclxxxviii{وَٱعْلَمُوٓا۟ أَنَّمَآ أَمْوَٰلُكُمْ وَأَوْلَٰدُكُمْ فِتْنَةٌ وَأَنَّ ٱللَّهَ عِندَهُۥٓ أَجْرٌ عَظِيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mclxxxix{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِن تَتَّقُوا۟ ٱللَّهَ يَجْعَل لَّكُمْ فُرْقَانًا وَيُكَفِّرْ عَنكُمْ سَيِّـَٔاتِكُمْ وَيَغْفِرْ لَكُمْ وَٱللَّهُ ذُو ٱلْفَضْلِ ٱلْعَظِيمِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcxc{وَإِذْ يَمْكُرُ بِكَ ٱلَّذِينَ كَفَرُوا۟ لِيُثْبِتُوكَ أَوْ يَقْتُلُوكَ أَوْ يُخْرِجُوكَ وَيَمْكُرُونَ وَيَمْكُرُ ٱللَّهُ وَٱللَّهُ خَيْرُ ٱلْمَٰكِرِينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcxci{وَإِذَا تُتْلَىٰ عَلَيْهِمْ ءَايَٰتُنَا قَالُوا۟ قَدْ سَمِعْنَا لَوْ نَشَآءُ لَقُلْنَا مِثْلَ هَٰذَآ إِنْ هَٰذَآ إِلَّآ أَسَٰطِيرُ ٱلْأَوَّلِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcxcii{وَإِذْ قَالُوا۟ ٱللَّهُمَّ إِن كَانَ هَٰذَا هُوَ ٱلْحَقَّ مِنْ عِندِكَ فَأَمْطِرْ عَلَيْنَا حِجَارَةً مِّنَ ٱلسَّمَآءِ أَوِ ٱئْتِنَا بِعَذَابٍ أَلِيمٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcxciii{وَمَا كَانَ ٱللَّهُ لِيُعَذِّبَهُمْ وَأَنتَ فِيهِمْ وَمَا كَانَ ٱللَّهُ مُعَذِّبَهُمْ وَهُمْ يَسْتَغْفِرُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcxciv{وَمَا لَهُمْ أَلَّا يُعَذِّبَهُمُ ٱللَّهُ وَهُمْ يَصُدُّونَ عَنِ ٱلْمَسْجِدِ ٱلْحَرَامِ وَمَا كَانُوٓا۟ أَوْلِيَآءَهُۥٓ إِنْ أَوْلِيَآؤُهُۥٓ إِلَّا ٱلْمُتَّقُونَ وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَعْلَمُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcxcv{وَمَا كَانَ صَلَاتُهُمْ عِندَ ٱلْبَيْتِ إِلَّا مُكَآءً وَتَصْدِيَةً فَذُوقُوا۟ ٱلْعَذَابَ بِمَا كُنتُمْ تَكْفُرُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcxcvi{إِنَّ ٱلَّذِينَ كَفَرُوا۟ يُنفِقُونَ أَمْوَٰلَهُمْ لِيَصُدُّوا۟ عَن سَبِيلِ ٱللَّهِ فَسَيُنفِقُونَهَا ثُمَّ تَكُونُ عَلَيْهِمْ حَسْرَةً ثُمَّ يُغْلَبُونَ وَٱلَّذِينَ كَفَرُوٓا۟ إِلَىٰ جَهَنَّمَ يُحْشَرُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcxcvii{لِيَمِيزَ ٱللَّهُ ٱلْخَبِيثَ مِنَ ٱلطَّيِّبِ وَيَجْعَلَ ٱلْخَبِيثَ بَعْضَهُۥ عَلَىٰ بَعْضٍ فَيَرْكُمَهُۥ جَمِيعًا فَيَجْعَلَهُۥ فِى جَهَنَّمَ أُو۟لَٰٓئِكَ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcxcviii{قُل لِّلَّذِينَ كَفَرُوٓا۟ إِن يَنتَهُوا۟ يُغْفَرْ لَهُم مَّا قَدْ سَلَفَ وَإِن يَعُودُوا۟ فَقَدْ مَضَتْ سُنَّتُ ٱلْأَوَّلِينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcxcix{وَقَٰتِلُوهُمْ حَتَّىٰ لَا تَكُونَ فِتْنَةٌ وَيَكُونَ ٱلدِّينُ كُلُّهُۥ لِلَّهِ فَإِنِ ٱنتَهَوْا۟ فَإِنَّ ٱللَّهَ بِمَا يَعْمَلُونَ بَصِيرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcc{وَإِن تَوَلَّوْا۟ فَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ مَوْلَىٰكُمْ نِعْمَ ٱلْمَوْلَىٰ وَنِعْمَ ٱلنَّصِيرُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcci{وَٱعْلَمُوٓا۟ أَنَّمَا غَنِمْتُم مِّن شَىْءٍ فَأَنَّ لِلَّهِ خُمُسَهُۥ وَلِلرَّسُولِ وَلِذِى ٱلْقُرْبَىٰ وَٱلْيَتَٰمَىٰ وَٱلْمَسَٰكِينِ وَٱبْنِ ٱلسَّبِيلِ إِن كُنتُمْ ءَامَنتُم بِٱللَّهِ وَمَآ أَنزَلْنَا عَلَىٰ عَبْدِنَا يَوْمَ ٱلْفُرْقَانِ يَوْمَ ٱلْتَقَى ٱلْجَمْعَانِ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mccii{إِذْ أَنتُم بِٱلْعُدْوَةِ ٱلدُّنْيَا وَهُم بِٱلْعُدْوَةِ ٱلْقُصْوَىٰ وَٱلرَّكْبُ أَسْفَلَ مِنكُمْ وَلَوْ تَوَاعَدتُّمْ لَٱخْتَلَفْتُمْ فِى ٱلْمِيعَٰدِ وَلَٰكِن لِّيَقْضِىَ ٱللَّهُ أَمْرًا كَانَ مَفْعُولًا لِّيَهْلِكَ مَنْ هَلَكَ عَنۢ بَيِّنَةٍ وَيَحْيَىٰ مَنْ حَىَّ عَنۢ بَيِّنَةٍ وَإِنَّ ٱللَّهَ لَسَمِيعٌ عَلِيمٌ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcciii{إِذْ يُرِيكَهُمُ ٱللَّهُ فِى مَنَامِكَ قَلِيلًا وَلَوْ أَرَىٰكَهُمْ كَثِيرًا لَّفَشِلْتُمْ وَلَتَنَٰزَعْتُمْ فِى ٱلْأَمْرِ وَلَٰكِنَّ ٱللَّهَ سَلَّمَ إِنَّهُۥ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcciv{وَإِذْ يُرِيكُمُوهُمْ إِذِ ٱلْتَقَيْتُمْ فِىٓ أَعْيُنِكُمْ قَلِيلًا وَيُقَلِّلُكُمْ فِىٓ أَعْيُنِهِمْ لِيَقْضِىَ ٱللَّهُ أَمْرًا كَانَ مَفْعُولًا وَإِلَى ٱللَّهِ تُرْجَعُ ٱلْأُمُورُ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mccv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا لَقِيتُمْ فِئَةً فَٱثْبُتُوا۟ وَٱذْكُرُوا۟ ٱللَّهَ كَثِيرًا لَّعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mccvi{وَأَطِيعُوا۟ ٱللَّهَ وَرَسُولَهُۥ وَلَا تَنَٰزَعُوا۟ فَتَفْشَلُوا۟ وَتَذْهَبَ رِيحُكُمْ وَٱصْبِرُوٓا۟ إِنَّ ٱللَّهَ مَعَ ٱلصَّٰبِرِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mccvii{وَلَا تَكُونُوا۟ كَٱلَّذِينَ خَرَجُوا۟ مِن دِيَٰرِهِم بَطَرًا وَرِئَآءَ ٱلنَّاسِ وَيَصُدُّونَ عَن سَبِيلِ ٱللَّهِ وَٱللَّهُ بِمَا يَعْمَلُونَ مُحِيطٌ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mccviii{وَإِذْ زَيَّنَ لَهُمُ ٱلشَّيْطَٰنُ أَعْمَٰلَهُمْ وَقَالَ لَا غَالِبَ لَكُمُ ٱلْيَوْمَ مِنَ ٱلنَّاسِ وَإِنِّى جَارٌ لَّكُمْ فَلَمَّا تَرَآءَتِ ٱلْفِئَتَانِ نَكَصَ عَلَىٰ عَقِبَيْهِ وَقَالَ إِنِّى بَرِىٓءٌ مِّنكُمْ إِنِّىٓ أَرَىٰ مَا لَا تَرَوْنَ إِنِّىٓ أَخَافُ ٱللَّهَ وَٱللَّهُ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mccix{إِذْ يَقُولُ ٱلْمُنَٰفِقُونَ وَٱلَّذِينَ فِى قُلُوبِهِم مَّرَضٌ غَرَّ هَٰٓؤُلَآءِ دِينُهُمْ وَمَن يَتَوَكَّلْ عَلَى ٱللَّهِ فَإِنَّ ٱللَّهَ عَزِيزٌ حَكِيمٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mccx{وَلَوْ تَرَىٰٓ إِذْ يَتَوَفَّى ٱلَّذِينَ كَفَرُوا۟ ٱلْمَلَٰٓئِكَةُ يَضْرِبُونَ وُجُوهَهُمْ وَأَدْبَٰرَهُمْ وَذُوقُوا۟ عَذَابَ ٱلْحَرِيقِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mccxi{ذَٰلِكَ بِمَا قَدَّمَتْ أَيْدِيكُمْ وَأَنَّ ٱللَّهَ لَيْسَ بِظَلَّٰمٍ لِّلْعَبِيدِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mccxii{كَدَأْبِ ءَالِ فِرْعَوْنَ وَٱلَّذِينَ مِن قَبْلِهِمْ كَفَرُوا۟ بِـَٔايَٰتِ ٱللَّهِ فَأَخَذَهُمُ ٱللَّهُ بِذُنُوبِهِمْ إِنَّ ٱللَّهَ قَوِىٌّ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mccxiii{ذَٰلِكَ بِأَنَّ ٱللَّهَ لَمْ يَكُ مُغَيِّرًا نِّعْمَةً أَنْعَمَهَا عَلَىٰ قَوْمٍ حَتَّىٰ يُغَيِّرُوا۟ مَا بِأَنفُسِهِمْ وَأَنَّ ٱللَّهَ سَمِيعٌ عَلِيمٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mccxiv{كَدَأْبِ ءَالِ فِرْعَوْنَ وَٱلَّذِينَ مِن قَبْلِهِمْ كَذَّبُوا۟ بِـَٔايَٰتِ رَبِّهِمْ فَأَهْلَكْنَٰهُم بِذُنُوبِهِمْ وَأَغْرَقْنَآ ءَالَ فِرْعَوْنَ وَكُلٌّ كَانُوا۟ ظَٰلِمِينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mccxv{إِنَّ شَرَّ ٱلدَّوَآبِّ عِندَ ٱللَّهِ ٱلَّذِينَ كَفَرُوا۟ فَهُمْ لَا يُؤْمِنُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mccxvi{ٱلَّذِينَ عَٰهَدتَّ مِنْهُمْ ثُمَّ يَنقُضُونَ عَهْدَهُمْ فِى كُلِّ مَرَّةٍ وَهُمْ لَا يَتَّقُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mccxvii{فَإِمَّا تَثْقَفَنَّهُمْ فِى ٱلْحَرْبِ فَشَرِّدْ بِهِم مَّنْ خَلْفَهُمْ لَعَلَّهُمْ يَذَّكَّرُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mccxviii{وَإِمَّا تَخَافَنَّ مِن قَوْمٍ خِيَانَةً فَٱنۢبِذْ إِلَيْهِمْ عَلَىٰ سَوَآءٍ إِنَّ ٱللَّهَ لَا يُحِبُّ ٱلْخَآئِنِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mccxix{وَلَا يَحْسَبَنَّ ٱلَّذِينَ كَفَرُوا۟ سَبَقُوٓا۟ إِنَّهُمْ لَا يُعْجِزُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mccxx{وَأَعِدُّوا۟ لَهُم مَّا ٱسْتَطَعْتُم مِّن قُوَّةٍ وَمِن رِّبَاطِ ٱلْخَيْلِ تُرْهِبُونَ بِهِۦ عَدُوَّ ٱللَّهِ وَعَدُوَّكُمْ وَءَاخَرِينَ مِن دُونِهِمْ لَا تَعْلَمُونَهُمُ ٱللَّهُ يَعْلَمُهُمْ وَمَا تُنفِقُوا۟ مِن شَىْءٍ فِى سَبِيلِ ٱللَّهِ يُوَفَّ إِلَيْكُمْ وَأَنتُمْ لَا تُظْلَمُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mccxxi{وَإِن جَنَحُوا۟ لِلسَّلْمِ فَٱجْنَحْ لَهَا وَتَوَكَّلْ عَلَى ٱللَّهِ إِنَّهُۥ هُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mccxxii{وَإِن يُرِيدُوٓا۟ أَن يَخْدَعُوكَ فَإِنَّ حَسْبَكَ ٱللَّهُ هُوَ ٱلَّذِىٓ أَيَّدَكَ بِنَصْرِهِۦ وَبِٱلْمُؤْمِنِينَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mccxxiii{وَأَلَّفَ بَيْنَ قُلُوبِهِمْ لَوْ أَنفَقْتَ مَا فِى ٱلْأَرْضِ جَمِيعًا مَّآ أَلَّفْتَ بَيْنَ قُلُوبِهِمْ وَلَٰكِنَّ ٱللَّهَ أَلَّفَ بَيْنَهُمْ إِنَّهُۥ عَزِيزٌ حَكِيمٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mccxxiv{يَٰٓأَيُّهَا ٱلنَّبِىُّ حَسْبُكَ ٱللَّهُ وَمَنِ ٱتَّبَعَكَ مِنَ ٱلْمُؤْمِنِينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mccxxv{يَٰٓأَيُّهَا ٱلنَّبِىُّ حَرِّضِ ٱلْمُؤْمِنِينَ عَلَى ٱلْقِتَالِ إِن يَكُن مِّنكُمْ عِشْرُونَ صَٰبِرُونَ يَغْلِبُوا۟ مِا۟ئَتَيْنِ وَإِن يَكُن مِّنكُم مِّا۟ئَةٌ يَغْلِبُوٓا۟ أَلْفًا مِّنَ ٱلَّذِينَ كَفَرُوا۟ بِأَنَّهُمْ قَوْمٌ لَّا يَفْقَهُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mccxxvi{ٱلْـَٰٔنَ خَفَّفَ ٱللَّهُ عَنكُمْ وَعَلِمَ أَنَّ فِيكُمْ ضَعْفًا فَإِن يَكُن مِّنكُم مِّا۟ئَةٌ صَابِرَةٌ يَغْلِبُوا۟ مِا۟ئَتَيْنِ وَإِن يَكُن مِّنكُمْ أَلْفٌ يَغْلِبُوٓا۟ أَلْفَيْنِ بِإِذْنِ ٱللَّهِ وَٱللَّهُ مَعَ ٱلصَّٰبِرِينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mccxxvii{مَا كَانَ لِنَبِىٍّ أَن يَكُونَ لَهُۥٓ أَسْرَىٰ حَتَّىٰ يُثْخِنَ فِى ٱلْأَرْضِ تُرِيدُونَ عَرَضَ ٱلدُّنْيَا وَٱللَّهُ يُرِيدُ ٱلْءَاخِرَةَ وَٱللَّهُ عَزِيزٌ حَكِيمٌ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mccxxviii{لَّوْلَا كِتَٰبٌ مِّنَ ٱللَّهِ سَبَقَ لَمَسَّكُمْ فِيمَآ أَخَذْتُمْ عَذَابٌ عَظِيمٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mccxxix{فَكُلُوا۟ مِمَّا غَنِمْتُمْ حَلَٰلًا طَيِّبًا وَٱتَّقُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mccxxx{يَٰٓأَيُّهَا ٱلنَّبِىُّ قُل لِّمَن فِىٓ أَيْدِيكُم مِّنَ ٱلْأَسْرَىٰٓ إِن يَعْلَمِ ٱللَّهُ فِى قُلُوبِكُمْ خَيْرًا يُؤْتِكُمْ خَيْرًا مِّمَّآ أُخِذَ مِنكُمْ وَيَغْفِرْ لَكُمْ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mccxxxi{وَإِن يُرِيدُوا۟ خِيَانَتَكَ فَقَدْ خَانُوا۟ ٱللَّهَ مِن قَبْلُ فَأَمْكَنَ مِنْهُمْ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mccxxxii{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَهَاجَرُوا۟ وَجَٰهَدُوا۟ بِأَمْوَٰلِهِمْ وَأَنفُسِهِمْ فِى سَبِيلِ ٱللَّهِ وَٱلَّذِينَ ءَاوَوا۟ وَّنَصَرُوٓا۟ أُو۟لَٰٓئِكَ بَعْضُهُمْ أَوْلِيَآءُ بَعْضٍ وَٱلَّذِينَ ءَامَنُوا۟ وَلَمْ يُهَاجِرُوا۟ مَا لَكُم مِّن وَلَٰيَتِهِم مِّن شَىْءٍ حَتَّىٰ يُهَاجِرُوا۟ وَإِنِ ٱسْتَنصَرُوكُمْ فِى ٱلدِّينِ فَعَلَيْكُمُ ٱلنَّصْرُ إِلَّا عَلَىٰ قَوْمٍۭ بَيْنَكُمْ وَبَيْنَهُم مِّيثَٰقٌ وَٱللَّهُ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mccxxxiii{وَٱلَّذِينَ كَفَرُوا۟ بَعْضُهُمْ أَوْلِيَآءُ بَعْضٍ إِلَّا تَفْعَلُوهُ تَكُن فِتْنَةٌ فِى ٱلْأَرْضِ وَفَسَادٌ كَبِيرٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mccxxxiv{وَٱلَّذِينَ ءَامَنُوا۟ وَهَاجَرُوا۟ وَجَٰهَدُوا۟ فِى سَبِيلِ ٱللَّهِ وَٱلَّذِينَ ءَاوَوا۟ وَّنَصَرُوٓا۟ أُو۟لَٰٓئِكَ هُمُ ٱلْمُؤْمِنُونَ حَقًّا لَّهُم مَّغْفِرَةٌ وَرِزْقٌ كَرِيمٌ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mccxxxv{وَٱلَّذِينَ ءَامَنُوا۟ مِنۢ بَعْدُ وَهَاجَرُوا۟ وَجَٰهَدُوا۟ مَعَكُمْ فَأُو۟لَٰٓئِكَ مِنكُمْ وَأُو۟لُوا۟ ٱلْأَرْحَامِ بَعْضُهُمْ أَوْلَىٰ بِبَعْضٍ فِى كِتَٰبِ ٱللَّهِ إِنَّ ٱللَّهَ بِكُلِّ شَىْءٍ عَلِيمٌۢ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mccxxxvi{بَرَآءَةٌ مِّنَ ٱللَّهِ وَرَسُولِهِۦٓ إِلَى ٱلَّذِينَ عَٰهَدتُّم مِّنَ ٱلْمُشْرِكِينَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mccxxxvii{فَسِيحُوا۟ فِى ٱلْأَرْضِ أَرْبَعَةَ أَشْهُرٍ وَٱعْلَمُوٓا۟ أَنَّكُمْ غَيْرُ مُعْجِزِى ٱللَّهِ وَأَنَّ ٱللَّهَ مُخْزِى ٱلْكَٰفِرِينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mccxxxviii{وَأَذَٰنٌ مِّنَ ٱللَّهِ وَرَسُولِهِۦٓ إِلَى ٱلنَّاسِ يَوْمَ ٱلْحَجِّ ٱلْأَكْبَرِ أَنَّ ٱللَّهَ بَرِىٓءٌ مِّنَ ٱلْمُشْرِكِينَ وَرَسُولُهُۥ فَإِن تُبْتُمْ فَهُوَ خَيْرٌ لَّكُمْ وَإِن تَوَلَّيْتُمْ فَٱعْلَمُوٓا۟ أَنَّكُمْ غَيْرُ مُعْجِزِى ٱللَّهِ وَبَشِّرِ ٱلَّذِينَ كَفَرُوا۟ بِعَذَابٍ أَلِيمٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mccxxxix{إِلَّا ٱلَّذِينَ عَٰهَدتُّم مِّنَ ٱلْمُشْرِكِينَ ثُمَّ لَمْ يَنقُصُوكُمْ شَيْـًٔا وَلَمْ يُظَٰهِرُوا۟ عَلَيْكُمْ أَحَدًا فَأَتِمُّوٓا۟ إِلَيْهِمْ عَهْدَهُمْ إِلَىٰ مُدَّتِهِمْ إِنَّ ٱللَّهَ يُحِبُّ ٱلْمُتَّقِينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mccxl{فَإِذَا ٱنسَلَخَ ٱلْأَشْهُرُ ٱلْحُرُمُ فَٱقْتُلُوا۟ ٱلْمُشْرِكِينَ حَيْثُ وَجَدتُّمُوهُمْ وَخُذُوهُمْ وَٱحْصُرُوهُمْ وَٱقْعُدُوا۟ لَهُمْ كُلَّ مَرْصَدٍ فَإِن تَابُوا۟ وَأَقَامُوا۟ ٱلصَّلَوٰةَ وَءَاتَوُا۟ ٱلزَّكَوٰةَ فَخَلُّوا۟ سَبِيلَهُمْ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mccxli{وَإِنْ أَحَدٌ مِّنَ ٱلْمُشْرِكِينَ ٱسْتَجَارَكَ فَأَجِرْهُ حَتَّىٰ يَسْمَعَ كَلَٰمَ ٱللَّهِ ثُمَّ أَبْلِغْهُ مَأْمَنَهُۥ ذَٰلِكَ بِأَنَّهُمْ قَوْمٌ لَّا يَعْلَمُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mccxlii{كَيْفَ يَكُونُ لِلْمُشْرِكِينَ عَهْدٌ عِندَ ٱللَّهِ وَعِندَ رَسُولِهِۦٓ إِلَّا ٱلَّذِينَ عَٰهَدتُّمْ عِندَ ٱلْمَسْجِدِ ٱلْحَرَامِ فَمَا ٱسْتَقَٰمُوا۟ لَكُمْ فَٱسْتَقِيمُوا۟ لَهُمْ إِنَّ ٱللَّهَ يُحِبُّ ٱلْمُتَّقِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mccxliii{كَيْفَ وَإِن يَظْهَرُوا۟ عَلَيْكُمْ لَا يَرْقُبُوا۟ فِيكُمْ إِلًّا وَلَا ذِمَّةً يُرْضُونَكُم بِأَفْوَٰهِهِمْ وَتَأْبَىٰ قُلُوبُهُمْ وَأَكْثَرُهُمْ فَٰسِقُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mccxliv{ٱشْتَرَوْا۟ بِـَٔايَٰتِ ٱللَّهِ ثَمَنًا قَلِيلًا فَصَدُّوا۟ عَن سَبِيلِهِۦٓ إِنَّهُمْ سَآءَ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mccxlv{لَا يَرْقُبُونَ فِى مُؤْمِنٍ إِلًّا وَلَا ذِمَّةً وَأُو۟لَٰٓئِكَ هُمُ ٱلْمُعْتَدُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mccxlvi{فَإِن تَابُوا۟ وَأَقَامُوا۟ ٱلصَّلَوٰةَ وَءَاتَوُا۟ ٱلزَّكَوٰةَ فَإِخْوَٰنُكُمْ فِى ٱلدِّينِ وَنُفَصِّلُ ٱلْءَايَٰتِ لِقَوْمٍ يَعْلَمُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mccxlvii{وَإِن نَّكَثُوٓا۟ أَيْمَٰنَهُم مِّنۢ بَعْدِ عَهْدِهِمْ وَطَعَنُوا۟ فِى دِينِكُمْ فَقَٰتِلُوٓا۟ أَئِمَّةَ ٱلْكُفْرِ إِنَّهُمْ لَآ أَيْمَٰنَ لَهُمْ لَعَلَّهُمْ يَنتَهُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mccxlviii{أَلَا تُقَٰتِلُونَ قَوْمًا نَّكَثُوٓا۟ أَيْمَٰنَهُمْ وَهَمُّوا۟ بِإِخْرَاجِ ٱلرَّسُولِ وَهُم بَدَءُوكُمْ أَوَّلَ مَرَّةٍ أَتَخْشَوْنَهُمْ فَٱللَّهُ أَحَقُّ أَن تَخْشَوْهُ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mccxlix{قَٰتِلُوهُمْ يُعَذِّبْهُمُ ٱللَّهُ بِأَيْدِيكُمْ وَيُخْزِهِمْ وَيَنصُرْكُمْ عَلَيْهِمْ وَيَشْفِ صُدُورَ قَوْمٍ مُّؤْمِنِينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mccl{وَيُذْهِبْ غَيْظَ قُلُوبِهِمْ وَيَتُوبُ ٱللَّهُ عَلَىٰ مَن يَشَآءُ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mccli{أَمْ حَسِبْتُمْ أَن تُتْرَكُوا۟ وَلَمَّا يَعْلَمِ ٱللَّهُ ٱلَّذِينَ جَٰهَدُوا۟ مِنكُمْ وَلَمْ يَتَّخِذُوا۟ مِن دُونِ ٱللَّهِ وَلَا رَسُولِهِۦ وَلَا ٱلْمُؤْمِنِينَ وَلِيجَةً وَٱللَّهُ خَبِيرٌۢ بِمَا تَعْمَلُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mcclii{مَا كَانَ لِلْمُشْرِكِينَ أَن يَعْمُرُوا۟ مَسَٰجِدَ ٱللَّهِ شَٰهِدِينَ عَلَىٰٓ أَنفُسِهِم بِٱلْكُفْرِ أُو۟لَٰٓئِكَ حَبِطَتْ أَعْمَٰلُهُمْ وَفِى ٱلنَّارِ هُمْ خَٰلِدُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mccliii{إِنَّمَا يَعْمُرُ مَسَٰجِدَ ٱللَّهِ مَنْ ءَامَنَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَأَقَامَ ٱلصَّلَوٰةَ وَءَاتَى ٱلزَّكَوٰةَ وَلَمْ يَخْشَ إِلَّا ٱللَّهَ فَعَسَىٰٓ أُو۟لَٰٓئِكَ أَن يَكُونُوا۟ مِنَ ٱلْمُهْتَدِينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mccliv{أَجَعَلْتُمْ سِقَايَةَ ٱلْحَآجِّ وَعِمَارَةَ ٱلْمَسْجِدِ ٱلْحَرَامِ كَمَنْ ءَامَنَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَجَٰهَدَ فِى سَبِيلِ ٱللَّهِ لَا يَسْتَوُۥنَ عِندَ ٱللَّهِ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mcclv{ٱلَّذِينَ ءَامَنُوا۟ وَهَاجَرُوا۟ وَجَٰهَدُوا۟ فِى سَبِيلِ ٱللَّهِ بِأَمْوَٰلِهِمْ وَأَنفُسِهِمْ أَعْظَمُ دَرَجَةً عِندَ ٱللَّهِ وَأُو۟لَٰٓئِكَ هُمُ ٱلْفَآئِزُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mcclvi{يُبَشِّرُهُمْ رَبُّهُم بِرَحْمَةٍ مِّنْهُ وَرِضْوَٰنٍ وَجَنَّٰتٍ لَّهُمْ فِيهَا نَعِيمٌ مُّقِيمٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mcclvii{خَٰلِدِينَ فِيهَآ أَبَدًا إِنَّ ٱللَّهَ عِندَهُۥٓ أَجْرٌ عَظِيمٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mcclviii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَتَّخِذُوٓا۟ ءَابَآءَكُمْ وَإِخْوَٰنَكُمْ أَوْلِيَآءَ إِنِ ٱسْتَحَبُّوا۟ ٱلْكُفْرَ عَلَى ٱلْإِيمَٰنِ وَمَن يَتَوَلَّهُم مِّنكُمْ فَأُو۟لَٰٓئِكَ هُمُ ٱلظَّٰلِمُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mcclix{قُلْ إِن كَانَ ءَابَآؤُكُمْ وَأَبْنَآؤُكُمْ وَإِخْوَٰنُكُمْ وَأَزْوَٰجُكُمْ وَعَشِيرَتُكُمْ وَأَمْوَٰلٌ ٱقْتَرَفْتُمُوهَا وَتِجَٰرَةٌ تَخْشَوْنَ كَسَادَهَا وَمَسَٰكِنُ تَرْضَوْنَهَآ أَحَبَّ إِلَيْكُم مِّنَ ٱللَّهِ وَرَسُولِهِۦ وَجِهَادٍ فِى سَبِيلِهِۦ فَتَرَبَّصُوا۟ حَتَّىٰ يَأْتِىَ ٱللَّهُ بِأَمْرِهِۦ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلْفَٰسِقِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mcclx{لَقَدْ نَصَرَكُمُ ٱللَّهُ فِى مَوَاطِنَ كَثِيرَةٍ وَيَوْمَ حُنَيْنٍ إِذْ أَعْجَبَتْكُمْ كَثْرَتُكُمْ فَلَمْ تُغْنِ عَنكُمْ شَيْـًٔا وَضَاقَتْ عَلَيْكُمُ ٱلْأَرْضُ بِمَا رَحُبَتْ ثُمَّ وَلَّيْتُم مُّدْبِرِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcclxi{ثُمَّ أَنزَلَ ٱللَّهُ سَكِينَتَهُۥ عَلَىٰ رَسُولِهِۦ وَعَلَى ٱلْمُؤْمِنِينَ وَأَنزَلَ جُنُودًا لَّمْ تَرَوْهَا وَعَذَّبَ ٱلَّذِينَ كَفَرُوا۟ وَذَٰلِكَ جَزَآءُ ٱلْكَٰفِرِينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mcclxii{ثُمَّ يَتُوبُ ٱللَّهُ مِنۢ بَعْدِ ذَٰلِكَ عَلَىٰ مَن يَشَآءُ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mcclxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِنَّمَا ٱلْمُشْرِكُونَ نَجَسٌ فَلَا يَقْرَبُوا۟ ٱلْمَسْجِدَ ٱلْحَرَامَ بَعْدَ عَامِهِمْ هَٰذَا وَإِنْ خِفْتُمْ عَيْلَةً فَسَوْفَ يُغْنِيكُمُ ٱللَّهُ مِن فَضْلِهِۦٓ إِن شَآءَ إِنَّ ٱللَّهَ عَلِيمٌ حَكِيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mcclxiv{قَٰتِلُوا۟ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱللَّهِ وَلَا بِٱلْيَوْمِ ٱلْءَاخِرِ وَلَا يُحَرِّمُونَ مَا حَرَّمَ ٱللَّهُ وَرَسُولُهُۥ وَلَا يَدِينُونَ دِينَ ٱلْحَقِّ مِنَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ حَتَّىٰ يُعْطُوا۟ ٱلْجِزْيَةَ عَن يَدٍ وَهُمْ صَٰغِرُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcclxv{وَقَالَتِ ٱلْيَهُودُ عُزَيْرٌ ٱبْنُ ٱللَّهِ وَقَالَتِ ٱلنَّصَٰرَى ٱلْمَسِيحُ ٱبْنُ ٱللَّهِ ذَٰلِكَ قَوْلُهُم بِأَفْوَٰهِهِمْ يُضَٰهِـُٔونَ قَوْلَ ٱلَّذِينَ كَفَرُوا۟ مِن قَبْلُ قَٰتَلَهُمُ ٱللَّهُ أَنَّىٰ يُؤْفَكُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcclxvi{ٱتَّخَذُوٓا۟ أَحْبَارَهُمْ وَرُهْبَٰنَهُمْ أَرْبَابًا مِّن دُونِ ٱللَّهِ وَٱلْمَسِيحَ ٱبْنَ مَرْيَمَ وَمَآ أُمِرُوٓا۟ إِلَّا لِيَعْبُدُوٓا۟ إِلَٰهًا وَٰحِدًا لَّآ إِلَٰهَ إِلَّا هُوَ سُبْحَٰنَهُۥ عَمَّا يُشْرِكُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcclxvii{يُرِيدُونَ أَن يُطْفِـُٔوا۟ نُورَ ٱللَّهِ بِأَفْوَٰهِهِمْ وَيَأْبَى ٱللَّهُ إِلَّآ أَن يُتِمَّ نُورَهُۥ وَلَوْ كَرِهَ ٱلْكَٰفِرُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcclxviii{هُوَ ٱلَّذِىٓ أَرْسَلَ رَسُولَهُۥ بِٱلْهُدَىٰ وَدِينِ ٱلْحَقِّ لِيُظْهِرَهُۥ عَلَى ٱلدِّينِ كُلِّهِۦ وَلَوْ كَرِهَ ٱلْمُشْرِكُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcclxix{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِنَّ كَثِيرًا مِّنَ ٱلْأَحْبَارِ وَٱلرُّهْبَانِ لَيَأْكُلُونَ أَمْوَٰلَ ٱلنَّاسِ بِٱلْبَٰطِلِ وَيَصُدُّونَ عَن سَبِيلِ ٱللَّهِ وَٱلَّذِينَ يَكْنِزُونَ ٱلذَّهَبَ وَٱلْفِضَّةَ وَلَا يُنفِقُونَهَا فِى سَبِيلِ ٱللَّهِ فَبَشِّرْهُم بِعَذَابٍ أَلِيمٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcclxx{يَوْمَ يُحْمَىٰ عَلَيْهَا فِى نَارِ جَهَنَّمَ فَتُكْوَىٰ بِهَا جِبَاهُهُمْ وَجُنُوبُهُمْ وَظُهُورُهُمْ هَٰذَا مَا كَنَزْتُمْ لِأَنفُسِكُمْ فَذُوقُوا۟ مَا كُنتُمْ تَكْنِزُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcclxxi{إِنَّ عِدَّةَ ٱلشُّهُورِ عِندَ ٱللَّهِ ٱثْنَا عَشَرَ شَهْرًا فِى كِتَٰبِ ٱللَّهِ يَوْمَ خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ مِنْهَآ أَرْبَعَةٌ حُرُمٌ ذَٰلِكَ ٱلدِّينُ ٱلْقَيِّمُ فَلَا تَظْلِمُوا۟ فِيهِنَّ أَنفُسَكُمْ وَقَٰتِلُوا۟ ٱلْمُشْرِكِينَ كَآفَّةً كَمَا يُقَٰتِلُونَكُمْ كَآفَّةً وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ مَعَ ٱلْمُتَّقِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcclxxii{إِنَّمَا ٱلنَّسِىٓءُ زِيَادَةٌ فِى ٱلْكُفْرِ يُضَلُّ بِهِ ٱلَّذِينَ كَفَرُوا۟ يُحِلُّونَهُۥ عَامًا وَيُحَرِّمُونَهُۥ عَامًا لِّيُوَاطِـُٔوا۟ عِدَّةَ مَا حَرَّمَ ٱللَّهُ فَيُحِلُّوا۟ مَا حَرَّمَ ٱللَّهُ زُيِّنَ لَهُمْ سُوٓءُ أَعْمَٰلِهِمْ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلْكَٰفِرِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcclxxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ مَا لَكُمْ إِذَا قِيلَ لَكُمُ ٱنفِرُوا۟ فِى سَبِيلِ ٱللَّهِ ٱثَّاقَلْتُمْ إِلَى ٱلْأَرْضِ أَرَضِيتُم بِٱلْحَيَوٰةِ ٱلدُّنْيَا مِنَ ٱلْءَاخِرَةِ فَمَا مَتَٰعُ ٱلْحَيَوٰةِ ٱلدُّنْيَا فِى ٱلْءَاخِرَةِ إِلَّا قَلِيلٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcclxxiv{إِلَّا تَنفِرُوا۟ يُعَذِّبْكُمْ عَذَابًا أَلِيمًا وَيَسْتَبْدِلْ قَوْمًا غَيْرَكُمْ وَلَا تَضُرُّوهُ شَيْـًٔا وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcclxxv{إِلَّا تَنصُرُوهُ فَقَدْ نَصَرَهُ ٱللَّهُ إِذْ أَخْرَجَهُ ٱلَّذِينَ كَفَرُوا۟ ثَانِىَ ٱثْنَيْنِ إِذْ هُمَا فِى ٱلْغَارِ إِذْ يَقُولُ لِصَٰحِبِهِۦ لَا تَحْزَنْ إِنَّ ٱللَّهَ مَعَنَا فَأَنزَلَ ٱللَّهُ سَكِينَتَهُۥ عَلَيْهِ وَأَيَّدَهُۥ بِجُنُودٍ لَّمْ تَرَوْهَا وَجَعَلَ كَلِمَةَ ٱلَّذِينَ كَفَرُوا۟ ٱلسُّفْلَىٰ وَكَلِمَةُ ٱللَّهِ هِىَ ٱلْعُلْيَا وَٱللَّهُ عَزِيزٌ حَكِيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcclxxvi{ٱنفِرُوا۟ خِفَافًا وَثِقَالًا وَجَٰهِدُوا۟ بِأَمْوَٰلِكُمْ وَأَنفُسِكُمْ فِى سَبِيلِ ٱللَّهِ ذَٰلِكُمْ خَيْرٌ لَّكُمْ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mcclxxvii{لَوْ كَانَ عَرَضًا قَرِيبًا وَسَفَرًا قَاصِدًا لَّٱتَّبَعُوكَ وَلَٰكِنۢ بَعُدَتْ عَلَيْهِمُ ٱلشُّقَّةُ وَسَيَحْلِفُونَ بِٱللَّهِ لَوِ ٱسْتَطَعْنَا لَخَرَجْنَا مَعَكُمْ يُهْلِكُونَ أَنفُسَهُمْ وَٱللَّهُ يَعْلَمُ إِنَّهُمْ لَكَٰذِبُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcclxxviii{عَفَا ٱللَّهُ عَنكَ لِمَ أَذِنتَ لَهُمْ حَتَّىٰ يَتَبَيَّنَ لَكَ ٱلَّذِينَ صَدَقُوا۟ وَتَعْلَمَ ٱلْكَٰذِبِينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcclxxix{لَا يَسْتَـْٔذِنُكَ ٱلَّذِينَ يُؤْمِنُونَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ أَن يُجَٰهِدُوا۟ بِأَمْوَٰلِهِمْ وَأَنفُسِهِمْ وَٱللَّهُ عَلِيمٌۢ بِٱلْمُتَّقِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mcclxxx{إِنَّمَا يَسْتَـْٔذِنُكَ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَٱرْتَابَتْ قُلُوبُهُمْ فَهُمْ فِى رَيْبِهِمْ يَتَرَدَّدُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mcclxxxi{وَلَوْ أَرَادُوا۟ ٱلْخُرُوجَ لَأَعَدُّوا۟ لَهُۥ عُدَّةً وَلَٰكِن كَرِهَ ٱللَّهُ ٱنۢبِعَاثَهُمْ فَثَبَّطَهُمْ وَقِيلَ ٱقْعُدُوا۟ مَعَ ٱلْقَٰعِدِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mcclxxxii{لَوْ خَرَجُوا۟ فِيكُم مَّا زَادُوكُمْ إِلَّا خَبَالًا وَلَأَوْضَعُوا۟ خِلَٰلَكُمْ يَبْغُونَكُمُ ٱلْفِتْنَةَ وَفِيكُمْ سَمَّٰعُونَ لَهُمْ وَٱللَّهُ عَلِيمٌۢ بِٱلظَّٰلِمِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mcclxxxiii{لَقَدِ ٱبْتَغَوُا۟ ٱلْفِتْنَةَ مِن قَبْلُ وَقَلَّبُوا۟ لَكَ ٱلْأُمُورَ حَتَّىٰ جَآءَ ٱلْحَقُّ وَظَهَرَ أَمْرُ ٱللَّهِ وَهُمْ كَٰرِهُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mcclxxxiv{وَمِنْهُم مَّن يَقُولُ ٱئْذَن لِّى وَلَا تَفْتِنِّىٓ أَلَا فِى ٱلْفِتْنَةِ سَقَطُوا۟ وَإِنَّ جَهَنَّمَ لَمُحِيطَةٌۢ بِٱلْكَٰفِرِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mcclxxxv{إِن تُصِبْكَ حَسَنَةٌ تَسُؤْهُمْ وَإِن تُصِبْكَ مُصِيبَةٌ يَقُولُوا۟ قَدْ أَخَذْنَآ أَمْرَنَا مِن قَبْلُ وَيَتَوَلَّوا۟ وَّهُمْ فَرِحُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mcclxxxvi{قُل لَّن يُصِيبَنَآ إِلَّا مَا كَتَبَ ٱللَّهُ لَنَا هُوَ مَوْلَىٰنَا وَعَلَى ٱللَّهِ فَلْيَتَوَكَّلِ ٱلْمُؤْمِنُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mcclxxxvii{قُلْ هَلْ تَرَبَّصُونَ بِنَآ إِلَّآ إِحْدَى ٱلْحُسْنَيَيْنِ وَنَحْنُ نَتَرَبَّصُ بِكُمْ أَن يُصِيبَكُمُ ٱللَّهُ بِعَذَابٍ مِّنْ عِندِهِۦٓ أَوْ بِأَيْدِينَا فَتَرَبَّصُوٓا۟ إِنَّا مَعَكُم مُّتَرَبِّصُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mcclxxxviii{قُلْ أَنفِقُوا۟ طَوْعًا أَوْ كَرْهًا لَّن يُتَقَبَّلَ مِنكُمْ إِنَّكُمْ كُنتُمْ قَوْمًا فَٰسِقِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mcclxxxix{وَمَا مَنَعَهُمْ أَن تُقْبَلَ مِنْهُمْ نَفَقَٰتُهُمْ إِلَّآ أَنَّهُمْ كَفَرُوا۟ بِٱللَّهِ وَبِرَسُولِهِۦ وَلَا يَأْتُونَ ٱلصَّلَوٰةَ إِلَّا وَهُمْ كُسَالَىٰ وَلَا يُنفِقُونَ إِلَّا وَهُمْ كَٰرِهُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mccxc{فَلَا تُعْجِبْكَ أَمْوَٰلُهُمْ وَلَآ أَوْلَٰدُهُمْ إِنَّمَا يُرِيدُ ٱللَّهُ لِيُعَذِّبَهُم بِهَا فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَتَزْهَقَ أَنفُسُهُمْ وَهُمْ كَٰفِرُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mccxci{وَيَحْلِفُونَ بِٱللَّهِ إِنَّهُمْ لَمِنكُمْ وَمَا هُم مِّنكُمْ وَلَٰكِنَّهُمْ قَوْمٌ يَفْرَقُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mccxcii{لَوْ يَجِدُونَ مَلْجَـًٔا أَوْ مَغَٰرَٰتٍ أَوْ مُدَّخَلًا لَّوَلَّوْا۟ إِلَيْهِ وَهُمْ يَجْمَحُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mccxciii{وَمِنْهُم مَّن يَلْمِزُكَ فِى ٱلصَّدَقَٰتِ فَإِنْ أُعْطُوا۟ مِنْهَا رَضُوا۟ وَإِن لَّمْ يُعْطَوْا۟ مِنْهَآ إِذَا هُمْ يَسْخَطُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mccxciv{وَلَوْ أَنَّهُمْ رَضُوا۟ مَآ ءَاتَىٰهُمُ ٱللَّهُ وَرَسُولُهُۥ وَقَالُوا۟ حَسْبُنَا ٱللَّهُ سَيُؤْتِينَا ٱللَّهُ مِن فَضْلِهِۦ وَرَسُولُهُۥٓ إِنَّآ إِلَى ٱللَّهِ رَٰغِبُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mccxcv{إِنَّمَا ٱلصَّدَقَٰتُ لِلْفُقَرَآءِ وَٱلْمَسَٰكِينِ وَٱلْعَٰمِلِينَ عَلَيْهَا وَٱلْمُؤَلَّفَةِ قُلُوبُهُمْ وَفِى ٱلرِّقَابِ وَٱلْغَٰرِمِينَ وَفِى سَبِيلِ ٱللَّهِ وَٱبْنِ ٱلسَّبِيلِ فَرِيضَةً مِّنَ ٱللَّهِ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mccxcvi{وَمِنْهُمُ ٱلَّذِينَ يُؤْذُونَ ٱلنَّبِىَّ وَيَقُولُونَ هُوَ أُذُنٌ قُلْ أُذُنُ خَيْرٍ لَّكُمْ يُؤْمِنُ بِٱللَّهِ وَيُؤْمِنُ لِلْمُؤْمِنِينَ وَرَحْمَةٌ لِّلَّذِينَ ءَامَنُوا۟ مِنكُمْ وَٱلَّذِينَ يُؤْذُونَ رَسُولَ ٱللَّهِ لَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mccxcvii{يَحْلِفُونَ بِٱللَّهِ لَكُمْ لِيُرْضُوكُمْ وَٱللَّهُ وَرَسُولُهُۥٓ أَحَقُّ أَن يُرْضُوهُ إِن كَانُوا۟ مُؤْمِنِينَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mccxcviii{أَلَمْ يَعْلَمُوٓا۟ أَنَّهُۥ مَن يُحَادِدِ ٱللَّهَ وَرَسُولَهُۥ فَأَنَّ لَهُۥ نَارَ جَهَنَّمَ خَٰلِدًا فِيهَا ذَٰلِكَ ٱلْخِزْىُ ٱلْعَظِيمُ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mccxcix{يَحْذَرُ ٱلْمُنَٰفِقُونَ أَن تُنَزَّلَ عَلَيْهِمْ سُورَةٌ تُنَبِّئُهُم بِمَا فِى قُلُوبِهِمْ قُلِ ٱسْتَهْزِءُوٓا۟ إِنَّ ٱللَّهَ مُخْرِجٌ مَّا تَحْذَرُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mccc{وَلَئِن سَأَلْتَهُمْ لَيَقُولُنَّ إِنَّمَا كُنَّا نَخُوضُ وَنَلْعَبُ قُلْ أَبِٱللَّهِ وَءَايَٰتِهِۦ وَرَسُولِهِۦ كُنتُمْ تَسْتَهْزِءُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mccci{لَا تَعْتَذِرُوا۟ قَدْ كَفَرْتُم بَعْدَ إِيمَٰنِكُمْ إِن نَّعْفُ عَن طَآئِفَةٍ مِّنكُمْ نُعَذِّبْ طَآئِفَةًۢ بِأَنَّهُمْ كَانُوا۟ مُجْرِمِينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mcccii{ٱلْمُنَٰفِقُونَ وَٱلْمُنَٰفِقَٰتُ بَعْضُهُم مِّنۢ بَعْضٍ يَأْمُرُونَ بِٱلْمُنكَرِ وَيَنْهَوْنَ عَنِ ٱلْمَعْرُوفِ وَيَقْبِضُونَ أَيْدِيَهُمْ نَسُوا۟ ٱللَّهَ فَنَسِيَهُمْ إِنَّ ٱلْمُنَٰفِقِينَ هُمُ ٱلْفَٰسِقُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mccciii{وَعَدَ ٱللَّهُ ٱلْمُنَٰفِقِينَ وَٱلْمُنَٰفِقَٰتِ وَٱلْكُفَّارَ نَارَ جَهَنَّمَ خَٰلِدِينَ فِيهَا هِىَ حَسْبُهُمْ وَلَعَنَهُمُ ٱللَّهُ وَلَهُمْ عَذَابٌ مُّقِيمٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mccciv{كَٱلَّذِينَ مِن قَبْلِكُمْ كَانُوٓا۟ أَشَدَّ مِنكُمْ قُوَّةً وَأَكْثَرَ أَمْوَٰلًا وَأَوْلَٰدًا فَٱسْتَمْتَعُوا۟ بِخَلَٰقِهِمْ فَٱسْتَمْتَعْتُم بِخَلَٰقِكُمْ كَمَا ٱسْتَمْتَعَ ٱلَّذِينَ مِن قَبْلِكُم بِخَلَٰقِهِمْ وَخُضْتُمْ كَٱلَّذِى خَاضُوٓا۟ أُو۟لَٰٓئِكَ حَبِطَتْ أَعْمَٰلُهُمْ فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَأُو۟لَٰٓئِكَ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mcccv{أَلَمْ يَأْتِهِمْ نَبَأُ ٱلَّذِينَ مِن قَبْلِهِمْ قَوْمِ نُوحٍ وَعَادٍ وَثَمُودَ وَقَوْمِ إِبْرَٰهِيمَ وَأَصْحَٰبِ مَدْيَنَ وَٱلْمُؤْتَفِكَٰتِ أَتَتْهُمْ رُسُلُهُم بِٱلْبَيِّنَٰتِ فَمَا كَانَ ٱللَّهُ لِيَظْلِمَهُمْ وَلَٰكِن كَانُوٓا۟ أَنفُسَهُمْ يَظْلِمُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mcccvi{وَٱلْمُؤْمِنُونَ وَٱلْمُؤْمِنَٰتُ بَعْضُهُمْ أَوْلِيَآءُ بَعْضٍ يَأْمُرُونَ بِٱلْمَعْرُوفِ وَيَنْهَوْنَ عَنِ ٱلْمُنكَرِ وَيُقِيمُونَ ٱلصَّلَوٰةَ وَيُؤْتُونَ ٱلزَّكَوٰةَ وَيُطِيعُونَ ٱللَّهَ وَرَسُولَهُۥٓ أُو۟لَٰٓئِكَ سَيَرْحَمُهُمُ ٱللَّهُ إِنَّ ٱللَّهَ عَزِيزٌ حَكِيمٌ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mcccvii{وَعَدَ ٱللَّهُ ٱلْمُؤْمِنِينَ وَٱلْمُؤْمِنَٰتِ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا وَمَسَٰكِنَ طَيِّبَةً فِى جَنَّٰتِ عَدْنٍ وَرِضْوَٰنٌ مِّنَ ٱللَّهِ أَكْبَرُ ذَٰلِكَ هُوَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mcccviii{يَٰٓأَيُّهَا ٱلنَّبِىُّ جَٰهِدِ ٱلْكُفَّارَ وَٱلْمُنَٰفِقِينَ وَٱغْلُظْ عَلَيْهِمْ وَمَأْوَىٰهُمْ جَهَنَّمُ وَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mcccix{يَحْلِفُونَ بِٱللَّهِ مَا قَالُوا۟ وَلَقَدْ قَالُوا۟ كَلِمَةَ ٱلْكُفْرِ وَكَفَرُوا۟ بَعْدَ إِسْلَٰمِهِمْ وَهَمُّوا۟ بِمَا لَمْ يَنَالُوا۟ وَمَا نَقَمُوٓا۟ إِلَّآ أَنْ أَغْنَىٰهُمُ ٱللَّهُ وَرَسُولُهُۥ مِن فَضْلِهِۦ فَإِن يَتُوبُوا۟ يَكُ خَيْرًا لَّهُمْ وَإِن يَتَوَلَّوْا۟ يُعَذِّبْهُمُ ٱللَّهُ عَذَابًا أَلِيمًا فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَمَا لَهُمْ فِى ٱلْأَرْضِ مِن وَلِىٍّ وَلَا نَصِيرٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mcccx{وَمِنْهُم مَّنْ عَٰهَدَ ٱللَّهَ لَئِنْ ءَاتَىٰنَا مِن فَضْلِهِۦ لَنَصَّدَّقَنَّ وَلَنَكُونَنَّ مِنَ ٱلصَّٰلِحِينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mcccxi{فَلَمَّآ ءَاتَىٰهُم مِّن فَضْلِهِۦ بَخِلُوا۟ بِهِۦ وَتَوَلَّوا۟ وَّهُم مُّعْرِضُونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mcccxii{فَأَعْقَبَهُمْ نِفَاقًا فِى قُلُوبِهِمْ إِلَىٰ يَوْمِ يَلْقَوْنَهُۥ بِمَآ أَخْلَفُوا۟ ٱللَّهَ مَا وَعَدُوهُ وَبِمَا كَانُوا۟ يَكْذِبُونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mcccxiii{أَلَمْ يَعْلَمُوٓا۟ أَنَّ ٱللَّهَ يَعْلَمُ سِرَّهُمْ وَنَجْوَىٰهُمْ وَأَنَّ ٱللَّهَ عَلَّٰمُ ٱلْغُيُوبِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mcccxiv{ٱلَّذِينَ يَلْمِزُونَ ٱلْمُطَّوِّعِينَ مِنَ ٱلْمُؤْمِنِينَ فِى ٱلصَّدَقَٰتِ وَٱلَّذِينَ لَا يَجِدُونَ إِلَّا جُهْدَهُمْ فَيَسْخَرُونَ مِنْهُمْ سَخِرَ ٱللَّهُ مِنْهُمْ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mcccxv{ٱسْتَغْفِرْ لَهُمْ أَوْ لَا تَسْتَغْفِرْ لَهُمْ إِن تَسْتَغْفِرْ لَهُمْ سَبْعِينَ مَرَّةً فَلَن يَغْفِرَ ٱللَّهُ لَهُمْ ذَٰلِكَ بِأَنَّهُمْ كَفَرُوا۟ بِٱللَّهِ وَرَسُولِهِۦ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلْفَٰسِقِينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mcccxvi{فَرِحَ ٱلْمُخَلَّفُونَ بِمَقْعَدِهِمْ خِلَٰفَ رَسُولِ ٱللَّهِ وَكَرِهُوٓا۟ أَن يُجَٰهِدُوا۟ بِأَمْوَٰلِهِمْ وَأَنفُسِهِمْ فِى سَبِيلِ ٱللَّهِ وَقَالُوا۟ لَا تَنفِرُوا۟ فِى ٱلْحَرِّ قُلْ نَارُ جَهَنَّمَ أَشَدُّ حَرًّا لَّوْ كَانُوا۟ يَفْقَهُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mcccxvii{فَلْيَضْحَكُوا۟ قَلِيلًا وَلْيَبْكُوا۟ كَثِيرًا جَزَآءًۢ بِمَا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mcccxviii{فَإِن رَّجَعَكَ ٱللَّهُ إِلَىٰ طَآئِفَةٍ مِّنْهُمْ فَٱسْتَـْٔذَنُوكَ لِلْخُرُوجِ فَقُل لَّن تَخْرُجُوا۟ مَعِىَ أَبَدًا وَلَن تُقَٰتِلُوا۟ مَعِىَ عَدُوًّا إِنَّكُمْ رَضِيتُم بِٱلْقُعُودِ أَوَّلَ مَرَّةٍ فَٱقْعُدُوا۟ مَعَ ٱلْخَٰلِفِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mcccxix{وَلَا تُصَلِّ عَلَىٰٓ أَحَدٍ مِّنْهُم مَّاتَ أَبَدًا وَلَا تَقُمْ عَلَىٰ قَبْرِهِۦٓ إِنَّهُمْ كَفَرُوا۟ بِٱللَّهِ وَرَسُولِهِۦ وَمَاتُوا۟ وَهُمْ فَٰسِقُونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mcccxx{وَلَا تُعْجِبْكَ أَمْوَٰلُهُمْ وَأَوْلَٰدُهُمْ إِنَّمَا يُرِيدُ ٱللَّهُ أَن يُعَذِّبَهُم بِهَا فِى ٱلدُّنْيَا وَتَزْهَقَ أَنفُسُهُمْ وَهُمْ كَٰفِرُونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mcccxxi{وَإِذَآ أُنزِلَتْ سُورَةٌ أَنْ ءَامِنُوا۟ بِٱللَّهِ وَجَٰهِدُوا۟ مَعَ رَسُولِهِ ٱسْتَـْٔذَنَكَ أُو۟لُوا۟ ٱلطَّوْلِ مِنْهُمْ وَقَالُوا۟ ذَرْنَا نَكُن مَّعَ ٱلْقَٰعِدِينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mcccxxii{رَضُوا۟ بِأَن يَكُونُوا۟ مَعَ ٱلْخَوَالِفِ وَطُبِعَ عَلَىٰ قُلُوبِهِمْ فَهُمْ لَا يَفْقَهُونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mcccxxiii{لَٰكِنِ ٱلرَّسُولُ وَٱلَّذِينَ ءَامَنُوا۟ مَعَهُۥ جَٰهَدُوا۟ بِأَمْوَٰلِهِمْ وَأَنفُسِهِمْ وَأُو۟لَٰٓئِكَ لَهُمُ ٱلْخَيْرَٰتُ وَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mcccxxiv{أَعَدَّ ٱللَّهُ لَهُمْ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا ذَٰلِكَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mcccxxv{وَجَآءَ ٱلْمُعَذِّرُونَ مِنَ ٱلْأَعْرَابِ لِيُؤْذَنَ لَهُمْ وَقَعَدَ ٱلَّذِينَ كَذَبُوا۟ ٱللَّهَ وَرَسُولَهُۥ سَيُصِيبُ ٱلَّذِينَ كَفَرُوا۟ مِنْهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mcccxxvi{لَّيْسَ عَلَى ٱلضُّعَفَآءِ وَلَا عَلَى ٱلْمَرْضَىٰ وَلَا عَلَى ٱلَّذِينَ لَا يَجِدُونَ مَا يُنفِقُونَ حَرَجٌ إِذَا نَصَحُوا۟ لِلَّهِ وَرَسُولِهِۦ مَا عَلَى ٱلْمُحْسِنِينَ مِن سَبِيلٍ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mcccxxvii{وَلَا عَلَى ٱلَّذِينَ إِذَا مَآ أَتَوْكَ لِتَحْمِلَهُمْ قُلْتَ لَآ أَجِدُ مَآ أَحْمِلُكُمْ عَلَيْهِ تَوَلَّوا۟ وَّأَعْيُنُهُمْ تَفِيضُ مِنَ ٱلدَّمْعِ حَزَنًا أَلَّا يَجِدُوا۟ مَا يُنفِقُونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mcccxxviii{إِنَّمَا ٱلسَّبِيلُ عَلَى ٱلَّذِينَ يَسْتَـْٔذِنُونَكَ وَهُمْ أَغْنِيَآءُ رَضُوا۟ بِأَن يَكُونُوا۟ مَعَ ٱلْخَوَالِفِ وَطَبَعَ ٱللَّهُ عَلَىٰ قُلُوبِهِمْ فَهُمْ لَا يَعْلَمُونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mcccxxix{يَعْتَذِرُونَ إِلَيْكُمْ إِذَا رَجَعْتُمْ إِلَيْهِمْ قُل لَّا تَعْتَذِرُوا۟ لَن نُّؤْمِنَ لَكُمْ قَدْ نَبَّأَنَا ٱللَّهُ مِنْ أَخْبَارِكُمْ وَسَيَرَى ٱللَّهُ عَمَلَكُمْ وَرَسُولُهُۥ ثُمَّ تُرَدُّونَ إِلَىٰ عَٰلِمِ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ فَيُنَبِّئُكُم بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mcccxxx{سَيَحْلِفُونَ بِٱللَّهِ لَكُمْ إِذَا ٱنقَلَبْتُمْ إِلَيْهِمْ لِتُعْرِضُوا۟ عَنْهُمْ فَأَعْرِضُوا۟ عَنْهُمْ إِنَّهُمْ رِجْسٌ وَمَأْوَىٰهُمْ جَهَنَّمُ جَزَآءًۢ بِمَا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mcccxxxi{يَحْلِفُونَ لَكُمْ لِتَرْضَوْا۟ عَنْهُمْ فَإِن تَرْضَوْا۟ عَنْهُمْ فَإِنَّ ٱللَّهَ لَا يَرْضَىٰ عَنِ ٱلْقَوْمِ ٱلْفَٰسِقِينَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mcccxxxii{ٱلْأَعْرَابُ أَشَدُّ كُفْرًا وَنِفَاقًا وَأَجْدَرُ أَلَّا يَعْلَمُوا۟ حُدُودَ مَآ أَنزَلَ ٱللَّهُ عَلَىٰ رَسُولِهِۦ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcccxxxiii{وَمِنَ ٱلْأَعْرَابِ مَن يَتَّخِذُ مَا يُنفِقُ مَغْرَمًا وَيَتَرَبَّصُ بِكُمُ ٱلدَّوَآئِرَ عَلَيْهِمْ دَآئِرَةُ ٱلسَّوْءِ وَٱللَّهُ سَمِيعٌ عَلِيمٌ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mcccxxxiv{وَمِنَ ٱلْأَعْرَابِ مَن يُؤْمِنُ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَيَتَّخِذُ مَا يُنفِقُ قُرُبَٰتٍ عِندَ ٱللَّهِ وَصَلَوَٰتِ ٱلرَّسُولِ أَلَآ إِنَّهَا قُرْبَةٌ لَّهُمْ سَيُدْخِلُهُمُ ٱللَّهُ فِى رَحْمَتِهِۦٓ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mcccxxxv{وَٱلسَّٰبِقُونَ ٱلْأَوَّلُونَ مِنَ ٱلْمُهَٰجِرِينَ وَٱلْأَنصَارِ وَٱلَّذِينَ ٱتَّبَعُوهُم بِإِحْسَٰنٍ رَّضِىَ ٱللَّهُ عَنْهُمْ وَرَضُوا۟ عَنْهُ وَأَعَدَّ لَهُمْ جَنَّٰتٍ تَجْرِى تَحْتَهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَآ أَبَدًا ذَٰلِكَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mcccxxxvi{وَمِمَّنْ حَوْلَكُم مِّنَ ٱلْأَعْرَابِ مُنَٰفِقُونَ وَمِنْ أَهْلِ ٱلْمَدِينَةِ مَرَدُوا۟ عَلَى ٱلنِّفَاقِ لَا تَعْلَمُهُمْ نَحْنُ نَعْلَمُهُمْ سَنُعَذِّبُهُم مَّرَّتَيْنِ ثُمَّ يُرَدُّونَ إِلَىٰ عَذَابٍ عَظِيمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mcccxxxvii{وَءَاخَرُونَ ٱعْتَرَفُوا۟ بِذُنُوبِهِمْ خَلَطُوا۟ عَمَلًا صَٰلِحًا وَءَاخَرَ سَيِّئًا عَسَى ٱللَّهُ أَن يَتُوبَ عَلَيْهِمْ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mcccxxxviii{خُذْ مِنْ أَمْوَٰلِهِمْ صَدَقَةً تُطَهِّرُهُمْ وَتُزَكِّيهِم بِهَا وَصَلِّ عَلَيْهِمْ إِنَّ صَلَوٰتَكَ سَكَنٌ لَّهُمْ وَٱللَّهُ سَمِيعٌ عَلِيمٌ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mcccxxxix{أَلَمْ يَعْلَمُوٓا۟ أَنَّ ٱللَّهَ هُوَ يَقْبَلُ ٱلتَّوْبَةَ عَنْ عِبَادِهِۦ وَيَأْخُذُ ٱلصَّدَقَٰتِ وَأَنَّ ٱللَّهَ هُوَ ٱلتَّوَّابُ ٱلرَّحِيمُ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mcccxl{وَقُلِ ٱعْمَلُوا۟ فَسَيَرَى ٱللَّهُ عَمَلَكُمْ وَرَسُولُهُۥ وَٱلْمُؤْمِنُونَ وَسَتُرَدُّونَ إِلَىٰ عَٰلِمِ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ فَيُنَبِّئُكُم بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mcccxli{وَءَاخَرُونَ مُرْجَوْنَ لِأَمْرِ ٱللَّهِ إِمَّا يُعَذِّبُهُمْ وَإِمَّا يَتُوبُ عَلَيْهِمْ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mcccxlii{وَٱلَّذِينَ ٱتَّخَذُوا۟ مَسْجِدًا ضِرَارًا وَكُفْرًا وَتَفْرِيقًۢا بَيْنَ ٱلْمُؤْمِنِينَ وَإِرْصَادًا لِّمَنْ حَارَبَ ٱللَّهَ وَرَسُولَهُۥ مِن قَبْلُ وَلَيَحْلِفُنَّ إِنْ أَرَدْنَآ إِلَّا ٱلْحُسْنَىٰ وَٱللَّهُ يَشْهَدُ إِنَّهُمْ لَكَٰذِبُونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mcccxliii{لَا تَقُمْ فِيهِ أَبَدًا لَّمَسْجِدٌ أُسِّسَ عَلَى ٱلتَّقْوَىٰ مِنْ أَوَّلِ يَوْمٍ أَحَقُّ أَن تَقُومَ فِيهِ فِيهِ رِجَالٌ يُحِبُّونَ أَن يَتَطَهَّرُوا۟ وَٱللَّهُ يُحِبُّ ٱلْمُطَّهِّرِينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mcccxliv{أَفَمَنْ أَسَّسَ بُنْيَٰنَهُۥ عَلَىٰ تَقْوَىٰ مِنَ ٱللَّهِ وَرِضْوَٰنٍ خَيْرٌ أَم مَّنْ أَسَّسَ بُنْيَٰنَهُۥ عَلَىٰ شَفَا جُرُفٍ هَارٍ فَٱنْهَارَ بِهِۦ فِى نَارِ جَهَنَّمَ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mcccxlv{لَا يَزَالُ بُنْيَٰنُهُمُ ٱلَّذِى بَنَوْا۟ رِيبَةً فِى قُلُوبِهِمْ إِلَّآ أَن تَقَطَّعَ قُلُوبُهُمْ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mcccxlvi{إِنَّ ٱللَّهَ ٱشْتَرَىٰ مِنَ ٱلْمُؤْمِنِينَ أَنفُسَهُمْ وَأَمْوَٰلَهُم بِأَنَّ لَهُمُ ٱلْجَنَّةَ يُقَٰتِلُونَ فِى سَبِيلِ ٱللَّهِ فَيَقْتُلُونَ وَيُقْتَلُونَ وَعْدًا عَلَيْهِ حَقًّا فِى ٱلتَّوْرَىٰةِ وَٱلْإِنجِيلِ وَٱلْقُرْءَانِ وَمَنْ أَوْفَىٰ بِعَهْدِهِۦ مِنَ ٱللَّهِ فَٱسْتَبْشِرُوا۟ بِبَيْعِكُمُ ٱلَّذِى بَايَعْتُم بِهِۦ وَذَٰلِكَ هُوَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mcccxlvii{ٱلتَّٰٓئِبُونَ ٱلْعَٰبِدُونَ ٱلْحَٰمِدُونَ ٱلسَّٰٓئِحُونَ ٱلرَّٰكِعُونَ ٱلسَّٰجِدُونَ ٱلْءَامِرُونَ بِٱلْمَعْرُوفِ وَٱلنَّاهُونَ عَنِ ٱلْمُنكَرِ وَٱلْحَٰفِظُونَ لِحُدُودِ ٱللَّهِ وَبَشِّرِ ٱلْمُؤْمِنِينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mcccxlviii{مَا كَانَ لِلنَّبِىِّ وَٱلَّذِينَ ءَامَنُوٓا۟ أَن يَسْتَغْفِرُوا۟ لِلْمُشْرِكِينَ وَلَوْ كَانُوٓا۟ أُو۟لِى قُرْبَىٰ مِنۢ بَعْدِ مَا تَبَيَّنَ لَهُمْ أَنَّهُمْ أَصْحَٰبُ ٱلْجَحِيمِ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mcccxlix{وَمَا كَانَ ٱسْتِغْفَارُ إِبْرَٰهِيمَ لِأَبِيهِ إِلَّا عَن مَّوْعِدَةٍ وَعَدَهَآ إِيَّاهُ فَلَمَّا تَبَيَّنَ لَهُۥٓ أَنَّهُۥ عَدُوٌّ لِّلَّهِ تَبَرَّأَ مِنْهُ إِنَّ إِبْرَٰهِيمَ لَأَوَّٰهٌ حَلِيمٌ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mcccl{وَمَا كَانَ ٱللَّهُ لِيُضِلَّ قَوْمًۢا بَعْدَ إِذْ هَدَىٰهُمْ حَتَّىٰ يُبَيِّنَ لَهُم مَّا يَتَّقُونَ إِنَّ ٱللَّهَ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mcccli{إِنَّ ٱللَّهَ لَهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ يُحْىِۦ وَيُمِيتُ وَمَا لَكُم مِّن دُونِ ٱللَّهِ مِن وَلِىٍّ وَلَا نَصِيرٍ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mccclii{لَّقَد تَّابَ ٱللَّهُ عَلَى ٱلنَّبِىِّ وَٱلْمُهَٰجِرِينَ وَٱلْأَنصَارِ ٱلَّذِينَ ٱتَّبَعُوهُ فِى سَاعَةِ ٱلْعُسْرَةِ مِنۢ بَعْدِ مَا كَادَ يَزِيغُ قُلُوبُ فَرِيقٍ مِّنْهُمْ ثُمَّ تَابَ عَلَيْهِمْ إِنَّهُۥ بِهِمْ رَءُوفٌ رَّحِيمٌ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mcccliii{وَعَلَى ٱلثَّلَٰثَةِ ٱلَّذِينَ خُلِّفُوا۟ حَتَّىٰٓ إِذَا ضَاقَتْ عَلَيْهِمُ ٱلْأَرْضُ بِمَا رَحُبَتْ وَضَاقَتْ عَلَيْهِمْ أَنفُسُهُمْ وَظَنُّوٓا۟ أَن لَّا مَلْجَأَ مِنَ ٱللَّهِ إِلَّآ إِلَيْهِ ثُمَّ تَابَ عَلَيْهِمْ لِيَتُوبُوٓا۟ إِنَّ ٱللَّهَ هُوَ ٱلتَّوَّابُ ٱلرَّحِيمُ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mcccliv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱتَّقُوا۟ ٱللَّهَ وَكُونُوا۟ مَعَ ٱلصَّٰدِقِينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mccclv{مَا كَانَ لِأَهْلِ ٱلْمَدِينَةِ وَمَنْ حَوْلَهُم مِّنَ ٱلْأَعْرَابِ أَن يَتَخَلَّفُوا۟ عَن رَّسُولِ ٱللَّهِ وَلَا يَرْغَبُوا۟ بِأَنفُسِهِمْ عَن نَّفْسِهِۦ ذَٰلِكَ بِأَنَّهُمْ لَا يُصِيبُهُمْ ظَمَأٌ وَلَا نَصَبٌ وَلَا مَخْمَصَةٌ فِى سَبِيلِ ٱللَّهِ وَلَا يَطَـُٔونَ مَوْطِئًا يَغِيظُ ٱلْكُفَّارَ وَلَا يَنَالُونَ مِنْ عَدُوٍّ نَّيْلًا إِلَّا كُتِبَ لَهُم بِهِۦ عَمَلٌ صَٰلِحٌ إِنَّ ٱللَّهَ لَا يُضِيعُ أَجْرَ ٱلْمُحْسِنِينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mccclvi{وَلَا يُنفِقُونَ نَفَقَةً صَغِيرَةً وَلَا كَبِيرَةً وَلَا يَقْطَعُونَ وَادِيًا إِلَّا كُتِبَ لَهُمْ لِيَجْزِيَهُمُ ٱللَّهُ أَحْسَنَ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mccclvii{وَمَا كَانَ ٱلْمُؤْمِنُونَ لِيَنفِرُوا۟ كَآفَّةً فَلَوْلَا نَفَرَ مِن كُلِّ فِرْقَةٍ مِّنْهُمْ طَآئِفَةٌ لِّيَتَفَقَّهُوا۟ فِى ٱلدِّينِ وَلِيُنذِرُوا۟ قَوْمَهُمْ إِذَا رَجَعُوٓا۟ إِلَيْهِمْ لَعَلَّهُمْ يَحْذَرُونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mccclviii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ قَٰتِلُوا۟ ٱلَّذِينَ يَلُونَكُم مِّنَ ٱلْكُفَّارِ وَلْيَجِدُوا۟ فِيكُمْ غِلْظَةً وَٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ مَعَ ٱلْمُتَّقِينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mccclix{وَإِذَا مَآ أُنزِلَتْ سُورَةٌ فَمِنْهُم مَّن يَقُولُ أَيُّكُمْ زَادَتْهُ هَٰذِهِۦٓ إِيمَٰنًا فَأَمَّا ٱلَّذِينَ ءَامَنُوا۟ فَزَادَتْهُمْ إِيمَٰنًا وَهُمْ يَسْتَبْشِرُونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mccclx{وَأَمَّا ٱلَّذِينَ فِى قُلُوبِهِم مَّرَضٌ فَزَادَتْهُمْ رِجْسًا إِلَىٰ رِجْسِهِمْ وَمَاتُوا۟ وَهُمْ كَٰفِرُونَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mccclxi{أَوَلَا يَرَوْنَ أَنَّهُمْ يُفْتَنُونَ فِى كُلِّ عَامٍ مَّرَّةً أَوْ مَرَّتَيْنِ ثُمَّ لَا يَتُوبُونَ وَلَا هُمْ يَذَّكَّرُونَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mccclxii{وَإِذَا مَآ أُنزِلَتْ سُورَةٌ نَّظَرَ بَعْضُهُمْ إِلَىٰ بَعْضٍ هَلْ يَرَىٰكُم مِّنْ أَحَدٍ ثُمَّ ٱنصَرَفُوا۟ صَرَفَ ٱللَّهُ قُلُوبَهُم بِأَنَّهُمْ قَوْمٌ لَّا يَفْقَهُونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mccclxiii{لَقَدْ جَآءَكُمْ رَسُولٌ مِّنْ أَنفُسِكُمْ عَزِيزٌ عَلَيْهِ مَا عَنِتُّمْ حَرِيصٌ عَلَيْكُم بِٱلْمُؤْمِنِينَ رَءُوفٌ رَّحِيمٌ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mccclxiv{فَإِن تَوَلَّوْا۟ فَقُلْ حَسْبِىَ ٱللَّهُ لَآ إِلَٰهَ إِلَّا هُوَ عَلَيْهِ تَوَكَّلْتُ وَهُوَ رَبُّ ٱلْعَرْشِ ٱلْعَظِيمِ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mccclxv{\basmalah الٓر تِلْكَ ءَايَٰتُ ٱلْكِتَٰبِ ٱلْحَكِيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mccclxvi{أَكَانَ لِلنَّاسِ عَجَبًا أَنْ أَوْحَيْنَآ إِلَىٰ رَجُلٍ مِّنْهُمْ أَنْ أَنذِرِ ٱلنَّاسَ وَبَشِّرِ ٱلَّذِينَ ءَامَنُوٓا۟ أَنَّ لَهُمْ قَدَمَ صِدْقٍ عِندَ رَبِّهِمْ قَالَ ٱلْكَٰفِرُونَ إِنَّ هَٰذَا لَسَٰحِرٌ مُّبِينٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mccclxvii{إِنَّ رَبَّكُمُ ٱللَّهُ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ فِى سِتَّةِ أَيَّامٍ ثُمَّ ٱسْتَوَىٰ عَلَى ٱلْعَرْشِ يُدَبِّرُ ٱلْأَمْرَ مَا مِن شَفِيعٍ إِلَّا مِنۢ بَعْدِ إِذْنِهِۦ ذَٰلِكُمُ ٱللَّهُ رَبُّكُمْ فَٱعْبُدُوهُ أَفَلَا تَذَكَّرُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mccclxviii{إِلَيْهِ مَرْجِعُكُمْ جَمِيعًا وَعْدَ ٱللَّهِ حَقًّا إِنَّهُۥ يَبْدَؤُا۟ ٱلْخَلْقَ ثُمَّ يُعِيدُهُۥ لِيَجْزِىَ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ بِٱلْقِسْطِ وَٱلَّذِينَ كَفَرُوا۟ لَهُمْ شَرَابٌ مِّنْ حَمِيمٍ وَعَذَابٌ أَلِيمٌۢ بِمَا كَانُوا۟ يَكْفُرُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mccclxix{هُوَ ٱلَّذِى جَعَلَ ٱلشَّمْسَ ضِيَآءً وَٱلْقَمَرَ نُورًا وَقَدَّرَهُۥ مَنَازِلَ لِتَعْلَمُوا۟ عَدَدَ ٱلسِّنِينَ وَٱلْحِسَابَ مَا خَلَقَ ٱللَّهُ ذَٰلِكَ إِلَّا بِٱلْحَقِّ يُفَصِّلُ ٱلْءَايَٰتِ لِقَوْمٍ يَعْلَمُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mccclxx{إِنَّ فِى ٱخْتِلَٰفِ ٱلَّيْلِ وَٱلنَّهَارِ وَمَا خَلَقَ ٱللَّهُ فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ لَءَايَٰتٍ لِّقَوْمٍ يَتَّقُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mccclxxi{إِنَّ ٱلَّذِينَ لَا يَرْجُونَ لِقَآءَنَا وَرَضُوا۟ بِٱلْحَيَوٰةِ ٱلدُّنْيَا وَٱطْمَأَنُّوا۟ بِهَا وَٱلَّذِينَ هُمْ عَنْ ءَايَٰتِنَا غَٰفِلُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mccclxxii{أُو۟لَٰٓئِكَ مَأْوَىٰهُمُ ٱلنَّارُ بِمَا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mccclxxiii{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ يَهْدِيهِمْ رَبُّهُم بِإِيمَٰنِهِمْ تَجْرِى مِن تَحْتِهِمُ ٱلْأَنْهَٰرُ فِى جَنَّٰتِ ٱلنَّعِيمِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mccclxxiv{دَعْوَىٰهُمْ فِيهَا سُبْحَٰنَكَ ٱللَّهُمَّ وَتَحِيَّتُهُمْ فِيهَا سَلَٰمٌ وَءَاخِرُ دَعْوَىٰهُمْ أَنِ ٱلْحَمْدُ لِلَّهِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mccclxxv{وَلَوْ يُعَجِّلُ ٱللَّهُ لِلنَّاسِ ٱلشَّرَّ ٱسْتِعْجَالَهُم بِٱلْخَيْرِ لَقُضِىَ إِلَيْهِمْ أَجَلُهُمْ فَنَذَرُ ٱلَّذِينَ لَا يَرْجُونَ لِقَآءَنَا فِى طُغْيَٰنِهِمْ يَعْمَهُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mccclxxvi{وَإِذَا مَسَّ ٱلْإِنسَٰنَ ٱلضُّرُّ دَعَانَا لِجَنۢبِهِۦٓ أَوْ قَاعِدًا أَوْ قَآئِمًا فَلَمَّا كَشَفْنَا عَنْهُ ضُرَّهُۥ مَرَّ كَأَن لَّمْ يَدْعُنَآ إِلَىٰ ضُرٍّ مَّسَّهُۥ كَذَٰلِكَ زُيِّنَ لِلْمُسْرِفِينَ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mccclxxvii{وَلَقَدْ أَهْلَكْنَا ٱلْقُرُونَ مِن قَبْلِكُمْ لَمَّا ظَلَمُوا۟ وَجَآءَتْهُمْ رُسُلُهُم بِٱلْبَيِّنَٰتِ وَمَا كَانُوا۟ لِيُؤْمِنُوا۟ كَذَٰلِكَ نَجْزِى ٱلْقَوْمَ ٱلْمُجْرِمِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mccclxxviii{ثُمَّ جَعَلْنَٰكُمْ خَلَٰٓئِفَ فِى ٱلْأَرْضِ مِنۢ بَعْدِهِمْ لِنَنظُرَ كَيْفَ تَعْمَلُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mccclxxix{وَإِذَا تُتْلَىٰ عَلَيْهِمْ ءَايَاتُنَا بَيِّنَٰتٍ قَالَ ٱلَّذِينَ لَا يَرْجُونَ لِقَآءَنَا ٱئْتِ بِقُرْءَانٍ غَيْرِ هَٰذَآ أَوْ بَدِّلْهُ قُلْ مَا يَكُونُ لِىٓ أَنْ أُبَدِّلَهُۥ مِن تِلْقَآئِ نَفْسِىٓ إِنْ أَتَّبِعُ إِلَّا مَا يُوحَىٰٓ إِلَىَّ إِنِّىٓ أَخَافُ إِنْ عَصَيْتُ رَبِّى عَذَابَ يَوْمٍ عَظِيمٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mccclxxx{قُل لَّوْ شَآءَ ٱللَّهُ مَا تَلَوْتُهُۥ عَلَيْكُمْ وَلَآ أَدْرَىٰكُم بِهِۦ فَقَدْ لَبِثْتُ فِيكُمْ عُمُرًا مِّن قَبْلِهِۦٓ أَفَلَا تَعْقِلُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mccclxxxi{فَمَنْ أَظْلَمُ مِمَّنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا أَوْ كَذَّبَ بِـَٔايَٰتِهِۦٓ إِنَّهُۥ لَا يُفْلِحُ ٱلْمُجْرِمُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mccclxxxii{وَيَعْبُدُونَ مِن دُونِ ٱللَّهِ مَا لَا يَضُرُّهُمْ وَلَا يَنفَعُهُمْ وَيَقُولُونَ هَٰٓؤُلَآءِ شُفَعَٰٓؤُنَا عِندَ ٱللَّهِ قُلْ أَتُنَبِّـُٔونَ ٱللَّهَ بِمَا لَا يَعْلَمُ فِى ٱلسَّمَٰوَٰتِ وَلَا فِى ٱلْأَرْضِ سُبْحَٰنَهُۥ وَتَعَٰلَىٰ عَمَّا يُشْرِكُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mccclxxxiii{وَمَا كَانَ ٱلنَّاسُ إِلَّآ أُمَّةً وَٰحِدَةً فَٱخْتَلَفُوا۟ وَلَوْلَا كَلِمَةٌ سَبَقَتْ مِن رَّبِّكَ لَقُضِىَ بَيْنَهُمْ فِيمَا فِيهِ يَخْتَلِفُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mccclxxxiv{وَيَقُولُونَ لَوْلَآ أُنزِلَ عَلَيْهِ ءَايَةٌ مِّن رَّبِّهِۦ فَقُلْ إِنَّمَا ٱلْغَيْبُ لِلَّهِ فَٱنتَظِرُوٓا۟ إِنِّى مَعَكُم مِّنَ ٱلْمُنتَظِرِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mccclxxxv{وَإِذَآ أَذَقْنَا ٱلنَّاسَ رَحْمَةً مِّنۢ بَعْدِ ضَرَّآءَ مَسَّتْهُمْ إِذَا لَهُم مَّكْرٌ فِىٓ ءَايَاتِنَا قُلِ ٱللَّهُ أَسْرَعُ مَكْرًا إِنَّ رُسُلَنَا يَكْتُبُونَ مَا تَمْكُرُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mccclxxxvi{هُوَ ٱلَّذِى يُسَيِّرُكُمْ فِى ٱلْبَرِّ وَٱلْبَحْرِ حَتَّىٰٓ إِذَا كُنتُمْ فِى ٱلْفُلْكِ وَجَرَيْنَ بِهِم بِرِيحٍ طَيِّبَةٍ وَفَرِحُوا۟ بِهَا جَآءَتْهَا رِيحٌ عَاصِفٌ وَجَآءَهُمُ ٱلْمَوْجُ مِن كُلِّ مَكَانٍ وَظَنُّوٓا۟ أَنَّهُمْ أُحِيطَ بِهِمْ دَعَوُا۟ ٱللَّهَ مُخْلِصِينَ لَهُ ٱلدِّينَ لَئِنْ أَنجَيْتَنَا مِنْ هَٰذِهِۦ لَنَكُونَنَّ مِنَ ٱلشَّٰكِرِينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mccclxxxvii{فَلَمَّآ أَنجَىٰهُمْ إِذَا هُمْ يَبْغُونَ فِى ٱلْأَرْضِ بِغَيْرِ ٱلْحَقِّ يَٰٓأَيُّهَا ٱلنَّاسُ إِنَّمَا بَغْيُكُمْ عَلَىٰٓ أَنفُسِكُم مَّتَٰعَ ٱلْحَيَوٰةِ ٱلدُّنْيَا ثُمَّ إِلَيْنَا مَرْجِعُكُمْ فَنُنَبِّئُكُم بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mccclxxxviii{إِنَّمَا مَثَلُ ٱلْحَيَوٰةِ ٱلدُّنْيَا كَمَآءٍ أَنزَلْنَٰهُ مِنَ ٱلسَّمَآءِ فَٱخْتَلَطَ بِهِۦ نَبَاتُ ٱلْأَرْضِ مِمَّا يَأْكُلُ ٱلنَّاسُ وَٱلْأَنْعَٰمُ حَتَّىٰٓ إِذَآ أَخَذَتِ ٱلْأَرْضُ زُخْرُفَهَا وَٱزَّيَّنَتْ وَظَنَّ أَهْلُهَآ أَنَّهُمْ قَٰدِرُونَ عَلَيْهَآ أَتَىٰهَآ أَمْرُنَا لَيْلًا أَوْ نَهَارًا فَجَعَلْنَٰهَا حَصِيدًا كَأَن لَّمْ تَغْنَ بِٱلْأَمْسِ كَذَٰلِكَ نُفَصِّلُ ٱلْءَايَٰتِ لِقَوْمٍ يَتَفَكَّرُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mccclxxxix{وَٱللَّهُ يَدْعُوٓا۟ إِلَىٰ دَارِ ٱلسَّلَٰمِ وَيَهْدِى مَن يَشَآءُ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcccxc{لِّلَّذِينَ أَحْسَنُوا۟ ٱلْحُسْنَىٰ وَزِيَادَةٌ وَلَا يَرْهَقُ وُجُوهَهُمْ قَتَرٌ وَلَا ذِلَّةٌ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْجَنَّةِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mcccxci{وَٱلَّذِينَ كَسَبُوا۟ ٱلسَّيِّـَٔاتِ جَزَآءُ سَيِّئَةٍۭ بِمِثْلِهَا وَتَرْهَقُهُمْ ذِلَّةٌ مَّا لَهُم مِّنَ ٱللَّهِ مِنْ عَاصِمٍ كَأَنَّمَآ أُغْشِيَتْ وُجُوهُهُمْ قِطَعًا مِّنَ ٱلَّيْلِ مُظْلِمًا أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mcccxcii{وَيَوْمَ نَحْشُرُهُمْ جَمِيعًا ثُمَّ نَقُولُ لِلَّذِينَ أَشْرَكُوا۟ مَكَانَكُمْ أَنتُمْ وَشُرَكَآؤُكُمْ فَزَيَّلْنَا بَيْنَهُمْ وَقَالَ شُرَكَآؤُهُم مَّا كُنتُمْ إِيَّانَا تَعْبُدُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mcccxciii{فَكَفَىٰ بِٱللَّهِ شَهِيدًۢا بَيْنَنَا وَبَيْنَكُمْ إِن كُنَّا عَنْ عِبَادَتِكُمْ لَغَٰفِلِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcccxciv{هُنَالِكَ تَبْلُوا۟ كُلُّ نَفْسٍ مَّآ أَسْلَفَتْ وَرُدُّوٓا۟ إِلَى ٱللَّهِ مَوْلَىٰهُمُ ٱلْحَقِّ وَضَلَّ عَنْهُم مَّا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcccxcv{قُلْ مَن يَرْزُقُكُم مِّنَ ٱلسَّمَآءِ وَٱلْأَرْضِ أَمَّن يَمْلِكُ ٱلسَّمْعَ وَٱلْأَبْصَٰرَ وَمَن يُخْرِجُ ٱلْحَىَّ مِنَ ٱلْمَيِّتِ وَيُخْرِجُ ٱلْمَيِّتَ مِنَ ٱلْحَىِّ وَمَن يُدَبِّرُ ٱلْأَمْرَ فَسَيَقُولُونَ ٱللَّهُ فَقُلْ أَفَلَا تَتَّقُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcccxcvi{فَذَٰلِكُمُ ٱللَّهُ رَبُّكُمُ ٱلْحَقُّ فَمَاذَا بَعْدَ ٱلْحَقِّ إِلَّا ٱلضَّلَٰلُ فَأَنَّىٰ تُصْرَفُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcccxcvii{كَذَٰلِكَ حَقَّتْ كَلِمَتُ رَبِّكَ عَلَى ٱلَّذِينَ فَسَقُوٓا۟ أَنَّهُمْ لَا يُؤْمِنُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcccxcviii{قُلْ هَلْ مِن شُرَكَآئِكُم مَّن يَبْدَؤُا۟ ٱلْخَلْقَ ثُمَّ يُعِيدُهُۥ قُلِ ٱللَّهُ يَبْدَؤُا۟ ٱلْخَلْقَ ثُمَّ يُعِيدُهُۥ فَأَنَّىٰ تُؤْفَكُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcccxcix{قُلْ هَلْ مِن شُرَكَآئِكُم مَّن يَهْدِىٓ إِلَى ٱلْحَقِّ قُلِ ٱللَّهُ يَهْدِى لِلْحَقِّ أَفَمَن يَهْدِىٓ إِلَى ٱلْحَقِّ أَحَقُّ أَن يُتَّبَعَ أَمَّن لَّا يَهِدِّىٓ إِلَّآ أَن يُهْدَىٰ فَمَا لَكُمْ كَيْفَ تَحْكُمُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcd{وَمَا يَتَّبِعُ أَكْثَرُهُمْ إِلَّا ظَنًّا إِنَّ ٱلظَّنَّ لَا يُغْنِى مِنَ ٱلْحَقِّ شَيْـًٔا إِنَّ ٱللَّهَ عَلِيمٌۢ بِمَا يَفْعَلُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcdi{وَمَا كَانَ هَٰذَا ٱلْقُرْءَانُ أَن يُفْتَرَىٰ مِن دُونِ ٱللَّهِ وَلَٰكِن تَصْدِيقَ ٱلَّذِى بَيْنَ يَدَيْهِ وَتَفْصِيلَ ٱلْكِتَٰبِ لَا رَيْبَ فِيهِ مِن رَّبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcdii{أَمْ يَقُولُونَ ٱفْتَرَىٰهُ قُلْ فَأْتُوا۟ بِسُورَةٍ مِّثْلِهِۦ وَٱدْعُوا۟ مَنِ ٱسْتَطَعْتُم مِّن دُونِ ٱللَّهِ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcdiii{بَلْ كَذَّبُوا۟ بِمَا لَمْ يُحِيطُوا۟ بِعِلْمِهِۦ وَلَمَّا يَأْتِهِمْ تَأْوِيلُهُۥ كَذَٰلِكَ كَذَّبَ ٱلَّذِينَ مِن قَبْلِهِمْ فَٱنظُرْ كَيْفَ كَانَ عَٰقِبَةُ ٱلظَّٰلِمِينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcdiv{وَمِنْهُم مَّن يُؤْمِنُ بِهِۦ وَمِنْهُم مَّن لَّا يُؤْمِنُ بِهِۦ وَرَبُّكَ أَعْلَمُ بِٱلْمُفْسِدِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcdv{وَإِن كَذَّبُوكَ فَقُل لِّى عَمَلِى وَلَكُمْ عَمَلُكُمْ أَنتُم بَرِيٓـُٔونَ مِمَّآ أَعْمَلُ وَأَنَا۠ بَرِىٓءٌ مِّمَّا تَعْمَلُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mcdvi{وَمِنْهُم مَّن يَسْتَمِعُونَ إِلَيْكَ أَفَأَنتَ تُسْمِعُ ٱلصُّمَّ وَلَوْ كَانُوا۟ لَا يَعْقِلُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcdvii{وَمِنْهُم مَّن يَنظُرُ إِلَيْكَ أَفَأَنتَ تَهْدِى ٱلْعُمْىَ وَلَوْ كَانُوا۟ لَا يُبْصِرُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcdviii{إِنَّ ٱللَّهَ لَا يَظْلِمُ ٱلنَّاسَ شَيْـًٔا وَلَٰكِنَّ ٱلنَّاسَ أَنفُسَهُمْ يَظْلِمُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mcdix{وَيَوْمَ يَحْشُرُهُمْ كَأَن لَّمْ يَلْبَثُوٓا۟ إِلَّا سَاعَةً مِّنَ ٱلنَّهَارِ يَتَعَارَفُونَ بَيْنَهُمْ قَدْ خَسِرَ ٱلَّذِينَ كَذَّبُوا۟ بِلِقَآءِ ٱللَّهِ وَمَا كَانُوا۟ مُهْتَدِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mcdx{وَإِمَّا نُرِيَنَّكَ بَعْضَ ٱلَّذِى نَعِدُهُمْ أَوْ نَتَوَفَّيَنَّكَ فَإِلَيْنَا مَرْجِعُهُمْ ثُمَّ ٱللَّهُ شَهِيدٌ عَلَىٰ مَا يَفْعَلُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mcdxi{وَلِكُلِّ أُمَّةٍ رَّسُولٌ فَإِذَا جَآءَ رَسُولُهُمْ قُضِىَ بَيْنَهُم بِٱلْقِسْطِ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mcdxii{وَيَقُولُونَ مَتَىٰ هَٰذَا ٱلْوَعْدُ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mcdxiii{قُل لَّآ أَمْلِكُ لِنَفْسِى ضَرًّا وَلَا نَفْعًا إِلَّا مَا شَآءَ ٱللَّهُ لِكُلِّ أُمَّةٍ أَجَلٌ إِذَا جَآءَ أَجَلُهُمْ فَلَا يَسْتَـْٔخِرُونَ سَاعَةً وَلَا يَسْتَقْدِمُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mcdxiv{قُلْ أَرَءَيْتُمْ إِنْ أَتَىٰكُمْ عَذَابُهُۥ بَيَٰتًا أَوْ نَهَارًا مَّاذَا يَسْتَعْجِلُ مِنْهُ ٱلْمُجْرِمُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mcdxv{أَثُمَّ إِذَا مَا وَقَعَ ءَامَنتُم بِهِۦٓ ءَآلْـَٰٔنَ وَقَدْ كُنتُم بِهِۦ تَسْتَعْجِلُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mcdxvi{ثُمَّ قِيلَ لِلَّذِينَ ظَلَمُوا۟ ذُوقُوا۟ عَذَابَ ٱلْخُلْدِ هَلْ تُجْزَوْنَ إِلَّا بِمَا كُنتُمْ تَكْسِبُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mcdxvii{وَيَسْتَنۢبِـُٔونَكَ أَحَقٌّ هُوَ قُلْ إِى وَرَبِّىٓ إِنَّهُۥ لَحَقٌّ وَمَآ أَنتُم بِمُعْجِزِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mcdxviii{وَلَوْ أَنَّ لِكُلِّ نَفْسٍ ظَلَمَتْ مَا فِى ٱلْأَرْضِ لَٱفْتَدَتْ بِهِۦ وَأَسَرُّوا۟ ٱلنَّدَامَةَ لَمَّا رَأَوُا۟ ٱلْعَذَابَ وَقُضِىَ بَيْنَهُم بِٱلْقِسْطِ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mcdxix{أَلَآ إِنَّ لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ أَلَآ إِنَّ وَعْدَ ٱللَّهِ حَقٌّ وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَعْلَمُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mcdxx{هُوَ يُحْىِۦ وَيُمِيتُ وَإِلَيْهِ تُرْجَعُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mcdxxi{يَٰٓأَيُّهَا ٱلنَّاسُ قَدْ جَآءَتْكُم مَّوْعِظَةٌ مِّن رَّبِّكُمْ وَشِفَآءٌ لِّمَا فِى ٱلصُّدُورِ وَهُدًى وَرَحْمَةٌ لِّلْمُؤْمِنِينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mcdxxii{قُلْ بِفَضْلِ ٱللَّهِ وَبِرَحْمَتِهِۦ فَبِذَٰلِكَ فَلْيَفْرَحُوا۟ هُوَ خَيْرٌ مِّمَّا يَجْمَعُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mcdxxiii{قُلْ أَرَءَيْتُم مَّآ أَنزَلَ ٱللَّهُ لَكُم مِّن رِّزْقٍ فَجَعَلْتُم مِّنْهُ حَرَامًا وَحَلَٰلًا قُلْ ءَآللَّهُ أَذِنَ لَكُمْ أَمْ عَلَى ٱللَّهِ تَفْتَرُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mcdxxiv{وَمَا ظَنُّ ٱلَّذِينَ يَفْتَرُونَ عَلَى ٱللَّهِ ٱلْكَذِبَ يَوْمَ ٱلْقِيَٰمَةِ إِنَّ ٱللَّهَ لَذُو فَضْلٍ عَلَى ٱلنَّاسِ وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَشْكُرُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mcdxxv{وَمَا تَكُونُ فِى شَأْنٍ وَمَا تَتْلُوا۟ مِنْهُ مِن قُرْءَانٍ وَلَا تَعْمَلُونَ مِنْ عَمَلٍ إِلَّا كُنَّا عَلَيْكُمْ شُهُودًا إِذْ تُفِيضُونَ فِيهِ وَمَا يَعْزُبُ عَن رَّبِّكَ مِن مِّثْقَالِ ذَرَّةٍ فِى ٱلْأَرْضِ وَلَا فِى ٱلسَّمَآءِ وَلَآ أَصْغَرَ مِن ذَٰلِكَ وَلَآ أَكْبَرَ إِلَّا فِى كِتَٰبٍ مُّبِينٍ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mcdxxvi{أَلَآ إِنَّ أَوْلِيَآءَ ٱللَّهِ لَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mcdxxvii{ٱلَّذِينَ ءَامَنُوا۟ وَكَانُوا۟ يَتَّقُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mcdxxviii{لَهُمُ ٱلْبُشْرَىٰ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَفِى ٱلْءَاخِرَةِ لَا تَبْدِيلَ لِكَلِمَٰتِ ٱللَّهِ ذَٰلِكَ هُوَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mcdxxix{وَلَا يَحْزُنكَ قَوْلُهُمْ إِنَّ ٱلْعِزَّةَ لِلَّهِ جَمِيعًا هُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mcdxxx{أَلَآ إِنَّ لِلَّهِ مَن فِى ٱلسَّمَٰوَٰتِ وَمَن فِى ٱلْأَرْضِ وَمَا يَتَّبِعُ ٱلَّذِينَ يَدْعُونَ مِن دُونِ ٱللَّهِ شُرَكَآءَ إِن يَتَّبِعُونَ إِلَّا ٱلظَّنَّ وَإِنْ هُمْ إِلَّا يَخْرُصُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mcdxxxi{هُوَ ٱلَّذِى جَعَلَ لَكُمُ ٱلَّيْلَ لِتَسْكُنُوا۟ فِيهِ وَٱلنَّهَارَ مُبْصِرًا إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يَسْمَعُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mcdxxxii{قَالُوا۟ ٱتَّخَذَ ٱللَّهُ وَلَدًا سُبْحَٰنَهُۥ هُوَ ٱلْغَنِىُّ لَهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ إِنْ عِندَكُم مِّن سُلْطَٰنٍۭ بِهَٰذَآ أَتَقُولُونَ عَلَى ٱللَّهِ مَا لَا تَعْلَمُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mcdxxxiii{قُلْ إِنَّ ٱلَّذِينَ يَفْتَرُونَ عَلَى ٱللَّهِ ٱلْكَذِبَ لَا يُفْلِحُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mcdxxxiv{مَتَٰعٌ فِى ٱلدُّنْيَا ثُمَّ إِلَيْنَا مَرْجِعُهُمْ ثُمَّ نُذِيقُهُمُ ٱلْعَذَابَ ٱلشَّدِيدَ بِمَا كَانُوا۟ يَكْفُرُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mcdxxxv{وَٱتْلُ عَلَيْهِمْ نَبَأَ نُوحٍ إِذْ قَالَ لِقَوْمِهِۦ يَٰقَوْمِ إِن كَانَ كَبُرَ عَلَيْكُم مَّقَامِى وَتَذْكِيرِى بِـَٔايَٰتِ ٱللَّهِ فَعَلَى ٱللَّهِ تَوَكَّلْتُ فَأَجْمِعُوٓا۟ أَمْرَكُمْ وَشُرَكَآءَكُمْ ثُمَّ لَا يَكُنْ أَمْرُكُمْ عَلَيْكُمْ غُمَّةً ثُمَّ ٱقْضُوٓا۟ إِلَىَّ وَلَا تُنظِرُونِ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mcdxxxvi{فَإِن تَوَلَّيْتُمْ فَمَا سَأَلْتُكُم مِّنْ أَجْرٍ إِنْ أَجْرِىَ إِلَّا عَلَى ٱللَّهِ وَأُمِرْتُ أَنْ أَكُونَ مِنَ ٱلْمُسْلِمِينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mcdxxxvii{فَكَذَّبُوهُ فَنَجَّيْنَٰهُ وَمَن مَّعَهُۥ فِى ٱلْفُلْكِ وَجَعَلْنَٰهُمْ خَلَٰٓئِفَ وَأَغْرَقْنَا ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا فَٱنظُرْ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُنذَرِينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mcdxxxviii{ثُمَّ بَعَثْنَا مِنۢ بَعْدِهِۦ رُسُلًا إِلَىٰ قَوْمِهِمْ فَجَآءُوهُم بِٱلْبَيِّنَٰتِ فَمَا كَانُوا۟ لِيُؤْمِنُوا۟ بِمَا كَذَّبُوا۟ بِهِۦ مِن قَبْلُ كَذَٰلِكَ نَطْبَعُ عَلَىٰ قُلُوبِ ٱلْمُعْتَدِينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mcdxxxix{ثُمَّ بَعَثْنَا مِنۢ بَعْدِهِم مُّوسَىٰ وَهَٰرُونَ إِلَىٰ فِرْعَوْنَ وَمَلَإِي۟هِۦ بِـَٔايَٰتِنَا فَٱسْتَكْبَرُوا۟ وَكَانُوا۟ قَوْمًا مُّجْرِمِينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mcdxl{فَلَمَّا جَآءَهُمُ ٱلْحَقُّ مِنْ عِندِنَا قَالُوٓا۟ إِنَّ هَٰذَا لَسِحْرٌ مُّبِينٌ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mcdxli{قَالَ مُوسَىٰٓ أَتَقُولُونَ لِلْحَقِّ لَمَّا جَآءَكُمْ أَسِحْرٌ هَٰذَا وَلَا يُفْلِحُ ٱلسَّٰحِرُونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mcdxlii{قَالُوٓا۟ أَجِئْتَنَا لِتَلْفِتَنَا عَمَّا وَجَدْنَا عَلَيْهِ ءَابَآءَنَا وَتَكُونَ لَكُمَا ٱلْكِبْرِيَآءُ فِى ٱلْأَرْضِ وَمَا نَحْنُ لَكُمَا بِمُؤْمِنِينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mcdxliii{وَقَالَ فِرْعَوْنُ ٱئْتُونِى بِكُلِّ سَٰحِرٍ عَلِيمٍ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mcdxliv{فَلَمَّا جَآءَ ٱلسَّحَرَةُ قَالَ لَهُم مُّوسَىٰٓ أَلْقُوا۟ مَآ أَنتُم مُّلْقُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mcdxlv{فَلَمَّآ أَلْقَوْا۟ قَالَ مُوسَىٰ مَا جِئْتُم بِهِ ٱلسِّحْرُ إِنَّ ٱللَّهَ سَيُبْطِلُهُۥٓ إِنَّ ٱللَّهَ لَا يُصْلِحُ عَمَلَ ٱلْمُفْسِدِينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mcdxlvi{وَيُحِقُّ ٱللَّهُ ٱلْحَقَّ بِكَلِمَٰتِهِۦ وَلَوْ كَرِهَ ٱلْمُجْرِمُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mcdxlvii{فَمَآ ءَامَنَ لِمُوسَىٰٓ إِلَّا ذُرِّيَّةٌ مِّن قَوْمِهِۦ عَلَىٰ خَوْفٍ مِّن فِرْعَوْنَ وَمَلَإِي۟هِمْ أَن يَفْتِنَهُمْ وَإِنَّ فِرْعَوْنَ لَعَالٍ فِى ٱلْأَرْضِ وَإِنَّهُۥ لَمِنَ ٱلْمُسْرِفِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mcdxlviii{وَقَالَ مُوسَىٰ يَٰقَوْمِ إِن كُنتُمْ ءَامَنتُم بِٱللَّهِ فَعَلَيْهِ تَوَكَّلُوٓا۟ إِن كُنتُم مُّسْلِمِينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mcdxlix{فَقَالُوا۟ عَلَى ٱللَّهِ تَوَكَّلْنَا رَبَّنَا لَا تَجْعَلْنَا فِتْنَةً لِّلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mcdl{وَنَجِّنَا بِرَحْمَتِكَ مِنَ ٱلْقَوْمِ ٱلْكَٰفِرِينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mcdli{وَأَوْحَيْنَآ إِلَىٰ مُوسَىٰ وَأَخِيهِ أَن تَبَوَّءَا لِقَوْمِكُمَا بِمِصْرَ بُيُوتًا وَٱجْعَلُوا۟ بُيُوتَكُمْ قِبْلَةً وَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَبَشِّرِ ٱلْمُؤْمِنِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mcdlii{وَقَالَ مُوسَىٰ رَبَّنَآ إِنَّكَ ءَاتَيْتَ فِرْعَوْنَ وَمَلَأَهُۥ زِينَةً وَأَمْوَٰلًا فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا رَبَّنَا لِيُضِلُّوا۟ عَن سَبِيلِكَ رَبَّنَا ٱطْمِسْ عَلَىٰٓ أَمْوَٰلِهِمْ وَٱشْدُدْ عَلَىٰ قُلُوبِهِمْ فَلَا يُؤْمِنُوا۟ حَتَّىٰ يَرَوُا۟ ٱلْعَذَابَ ٱلْأَلِيمَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mcdliii{قَالَ قَدْ أُجِيبَت دَّعْوَتُكُمَا فَٱسْتَقِيمَا وَلَا تَتَّبِعَآنِّ سَبِيلَ ٱلَّذِينَ لَا يَعْلَمُونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mcdliv{وَجَٰوَزْنَا بِبَنِىٓ إِسْرَٰٓءِيلَ ٱلْبَحْرَ فَأَتْبَعَهُمْ فِرْعَوْنُ وَجُنُودُهُۥ بَغْيًا وَعَدْوًا حَتَّىٰٓ إِذَآ أَدْرَكَهُ ٱلْغَرَقُ قَالَ ءَامَنتُ أَنَّهُۥ لَآ إِلَٰهَ إِلَّا ٱلَّذِىٓ ءَامَنَتْ بِهِۦ بَنُوٓا۟ إِسْرَٰٓءِيلَ وَأَنَا۠ مِنَ ٱلْمُسْلِمِينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mcdlv{ءَآلْـَٰٔنَ وَقَدْ عَصَيْتَ قَبْلُ وَكُنتَ مِنَ ٱلْمُفْسِدِينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mcdlvi{فَٱلْيَوْمَ نُنَجِّيكَ بِبَدَنِكَ لِتَكُونَ لِمَنْ خَلْفَكَ ءَايَةً وَإِنَّ كَثِيرًا مِّنَ ٱلنَّاسِ عَنْ ءَايَٰتِنَا لَغَٰفِلُونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mcdlvii{وَلَقَدْ بَوَّأْنَا بَنِىٓ إِسْرَٰٓءِيلَ مُبَوَّأَ صِدْقٍ وَرَزَقْنَٰهُم مِّنَ ٱلطَّيِّبَٰتِ فَمَا ٱخْتَلَفُوا۟ حَتَّىٰ جَآءَهُمُ ٱلْعِلْمُ إِنَّ رَبَّكَ يَقْضِى بَيْنَهُمْ يَوْمَ ٱلْقِيَٰمَةِ فِيمَا كَانُوا۟ فِيهِ يَخْتَلِفُونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mcdlviii{فَإِن كُنتَ فِى شَكٍّ مِّمَّآ أَنزَلْنَآ إِلَيْكَ فَسْـَٔلِ ٱلَّذِينَ يَقْرَءُونَ ٱلْكِتَٰبَ مِن قَبْلِكَ لَقَدْ جَآءَكَ ٱلْحَقُّ مِن رَّبِّكَ فَلَا تَكُونَنَّ مِنَ ٱلْمُمْتَرِينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mcdlix{وَلَا تَكُونَنَّ مِنَ ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِ ٱللَّهِ فَتَكُونَ مِنَ ٱلْخَٰسِرِينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mcdlx{إِنَّ ٱلَّذِينَ حَقَّتْ عَلَيْهِمْ كَلِمَتُ رَبِّكَ لَا يُؤْمِنُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mcdlxi{وَلَوْ جَآءَتْهُمْ كُلُّ ءَايَةٍ حَتَّىٰ يَرَوُا۟ ٱلْعَذَابَ ٱلْأَلِيمَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcdlxii{فَلَوْلَا كَانَتْ قَرْيَةٌ ءَامَنَتْ فَنَفَعَهَآ إِيمَٰنُهَآ إِلَّا قَوْمَ يُونُسَ لَمَّآ ءَامَنُوا۟ كَشَفْنَا عَنْهُمْ عَذَابَ ٱلْخِزْىِ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَمَتَّعْنَٰهُمْ إِلَىٰ حِينٍ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mcdlxiii{وَلَوْ شَآءَ رَبُّكَ لَءَامَنَ مَن فِى ٱلْأَرْضِ كُلُّهُمْ جَمِيعًا أَفَأَنتَ تُكْرِهُ ٱلنَّاسَ حَتَّىٰ يَكُونُوا۟ مُؤْمِنِينَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mcdlxiv{وَمَا كَانَ لِنَفْسٍ أَن تُؤْمِنَ إِلَّا بِإِذْنِ ٱللَّهِ وَيَجْعَلُ ٱلرِّجْسَ عَلَى ٱلَّذِينَ لَا يَعْقِلُونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mcdlxv{قُلِ ٱنظُرُوا۟ مَاذَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا تُغْنِى ٱلْءَايَٰتُ وَٱلنُّذُرُ عَن قَوْمٍ لَّا يُؤْمِنُونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mcdlxvi{فَهَلْ يَنتَظِرُونَ إِلَّا مِثْلَ أَيَّامِ ٱلَّذِينَ خَلَوْا۟ مِن قَبْلِهِمْ قُلْ فَٱنتَظِرُوٓا۟ إِنِّى مَعَكُم مِّنَ ٱلْمُنتَظِرِينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mcdlxvii{ثُمَّ نُنَجِّى رُسُلَنَا وَٱلَّذِينَ ءَامَنُوا۟ كَذَٰلِكَ حَقًّا عَلَيْنَا نُنجِ ٱلْمُؤْمِنِينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mcdlxviii{قُلْ يَٰٓأَيُّهَا ٱلنَّاسُ إِن كُنتُمْ فِى شَكٍّ مِّن دِينِى فَلَآ أَعْبُدُ ٱلَّذِينَ تَعْبُدُونَ مِن دُونِ ٱللَّهِ وَلَٰكِنْ أَعْبُدُ ٱللَّهَ ٱلَّذِى يَتَوَفَّىٰكُمْ وَأُمِرْتُ أَنْ أَكُونَ مِنَ ٱلْمُؤْمِنِينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mcdlxix{وَأَنْ أَقِمْ وَجْهَكَ لِلدِّينِ حَنِيفًا وَلَا تَكُونَنَّ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mcdlxx{وَلَا تَدْعُ مِن دُونِ ٱللَّهِ مَا لَا يَنفَعُكَ وَلَا يَضُرُّكَ فَإِن فَعَلْتَ فَإِنَّكَ إِذًا مِّنَ ٱلظَّٰلِمِينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mcdlxxi{وَإِن يَمْسَسْكَ ٱللَّهُ بِضُرٍّ فَلَا كَاشِفَ لَهُۥٓ إِلَّا هُوَ وَإِن يُرِدْكَ بِخَيْرٍ فَلَا رَآدَّ لِفَضْلِهِۦ يُصِيبُ بِهِۦ مَن يَشَآءُ مِنْ عِبَادِهِۦ وَهُوَ ٱلْغَفُورُ ٱلرَّحِيمُ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mcdlxxii{قُلْ يَٰٓأَيُّهَا ٱلنَّاسُ قَدْ جَآءَكُمُ ٱلْحَقُّ مِن رَّبِّكُمْ فَمَنِ ٱهْتَدَىٰ فَإِنَّمَا يَهْتَدِى لِنَفْسِهِۦ وَمَن ضَلَّ فَإِنَّمَا يَضِلُّ عَلَيْهَا وَمَآ أَنَا۠ عَلَيْكُم بِوَكِيلٍ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mcdlxxiii{وَٱتَّبِعْ مَا يُوحَىٰٓ إِلَيْكَ وَٱصْبِرْ حَتَّىٰ يَحْكُمَ ٱللَّهُ وَهُوَ خَيْرُ ٱلْحَٰكِمِينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mcdlxxiv{\basmalah الٓر كِتَٰبٌ أُحْكِمَتْ ءَايَٰتُهُۥ ثُمَّ فُصِّلَتْ مِن لَّدُنْ حَكِيمٍ خَبِيرٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mcdlxxv{أَلَّا تَعْبُدُوٓا۟ إِلَّا ٱللَّهَ إِنَّنِى لَكُم مِّنْهُ نَذِيرٌ وَبَشِيرٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mcdlxxvi{وَأَنِ ٱسْتَغْفِرُوا۟ رَبَّكُمْ ثُمَّ تُوبُوٓا۟ إِلَيْهِ يُمَتِّعْكُم مَّتَٰعًا حَسَنًا إِلَىٰٓ أَجَلٍ مُّسَمًّى وَيُؤْتِ كُلَّ ذِى فَضْلٍ فَضْلَهُۥ وَإِن تَوَلَّوْا۟ فَإِنِّىٓ أَخَافُ عَلَيْكُمْ عَذَابَ يَوْمٍ كَبِيرٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mcdlxxvii{إِلَى ٱللَّهِ مَرْجِعُكُمْ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mcdlxxviii{أَلَآ إِنَّهُمْ يَثْنُونَ صُدُورَهُمْ لِيَسْتَخْفُوا۟ مِنْهُ أَلَا حِينَ يَسْتَغْشُونَ ثِيَابَهُمْ يَعْلَمُ مَا يُسِرُّونَ وَمَا يُعْلِنُونَ إِنَّهُۥ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mcdlxxix{وَمَا مِن دَآبَّةٍ فِى ٱلْأَرْضِ إِلَّا عَلَى ٱللَّهِ رِزْقُهَا وَيَعْلَمُ مُسْتَقَرَّهَا وَمُسْتَوْدَعَهَا كُلٌّ فِى كِتَٰبٍ مُّبِينٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mcdlxxx{وَهُوَ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ فِى سِتَّةِ أَيَّامٍ وَكَانَ عَرْشُهُۥ عَلَى ٱلْمَآءِ لِيَبْلُوَكُمْ أَيُّكُمْ أَحْسَنُ عَمَلًا وَلَئِن قُلْتَ إِنَّكُم مَّبْعُوثُونَ مِنۢ بَعْدِ ٱلْمَوْتِ لَيَقُولَنَّ ٱلَّذِينَ كَفَرُوٓا۟ إِنْ هَٰذَآ إِلَّا سِحْرٌ مُّبِينٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mcdlxxxi{وَلَئِنْ أَخَّرْنَا عَنْهُمُ ٱلْعَذَابَ إِلَىٰٓ أُمَّةٍ مَّعْدُودَةٍ لَّيَقُولُنَّ مَا يَحْبِسُهُۥٓ أَلَا يَوْمَ يَأْتِيهِمْ لَيْسَ مَصْرُوفًا عَنْهُمْ وَحَاقَ بِهِم مَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mcdlxxxii{وَلَئِنْ أَذَقْنَا ٱلْإِنسَٰنَ مِنَّا رَحْمَةً ثُمَّ نَزَعْنَٰهَا مِنْهُ إِنَّهُۥ لَيَـُٔوسٌ كَفُورٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mcdlxxxiii{وَلَئِنْ أَذَقْنَٰهُ نَعْمَآءَ بَعْدَ ضَرَّآءَ مَسَّتْهُ لَيَقُولَنَّ ذَهَبَ ٱلسَّيِّـَٔاتُ عَنِّىٓ إِنَّهُۥ لَفَرِحٌ فَخُورٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mcdlxxxiv{إِلَّا ٱلَّذِينَ صَبَرُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ أُو۟لَٰٓئِكَ لَهُم مَّغْفِرَةٌ وَأَجْرٌ كَبِيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mcdlxxxv{فَلَعَلَّكَ تَارِكٌۢ بَعْضَ مَا يُوحَىٰٓ إِلَيْكَ وَضَآئِقٌۢ بِهِۦ صَدْرُكَ أَن يَقُولُوا۟ لَوْلَآ أُنزِلَ عَلَيْهِ كَنزٌ أَوْ جَآءَ مَعَهُۥ مَلَكٌ إِنَّمَآ أَنتَ نَذِيرٌ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ وَكِيلٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mcdlxxxvi{أَمْ يَقُولُونَ ٱفْتَرَىٰهُ قُلْ فَأْتُوا۟ بِعَشْرِ سُوَرٍ مِّثْلِهِۦ مُفْتَرَيَٰتٍ وَٱدْعُوا۟ مَنِ ٱسْتَطَعْتُم مِّن دُونِ ٱللَّهِ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mcdlxxxvii{فَإِلَّمْ يَسْتَجِيبُوا۟ لَكُمْ فَٱعْلَمُوٓا۟ أَنَّمَآ أُنزِلَ بِعِلْمِ ٱللَّهِ وَأَن لَّآ إِلَٰهَ إِلَّا هُوَ فَهَلْ أَنتُم مُّسْلِمُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mcdlxxxviii{مَن كَانَ يُرِيدُ ٱلْحَيَوٰةَ ٱلدُّنْيَا وَزِينَتَهَا نُوَفِّ إِلَيْهِمْ أَعْمَٰلَهُمْ فِيهَا وَهُمْ فِيهَا لَا يُبْخَسُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mcdlxxxix{أُو۟لَٰٓئِكَ ٱلَّذِينَ لَيْسَ لَهُمْ فِى ٱلْءَاخِرَةِ إِلَّا ٱلنَّارُ وَحَبِطَ مَا صَنَعُوا۟ فِيهَا وَبَٰطِلٌ مَّا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mcdxc{أَفَمَن كَانَ عَلَىٰ بَيِّنَةٍ مِّن رَّبِّهِۦ وَيَتْلُوهُ شَاهِدٌ مِّنْهُ وَمِن قَبْلِهِۦ كِتَٰبُ مُوسَىٰٓ إِمَامًا وَرَحْمَةً أُو۟لَٰٓئِكَ يُؤْمِنُونَ بِهِۦ وَمَن يَكْفُرْ بِهِۦ مِنَ ٱلْأَحْزَابِ فَٱلنَّارُ مَوْعِدُهُۥ فَلَا تَكُ فِى مِرْيَةٍ مِّنْهُ إِنَّهُ ٱلْحَقُّ مِن رَّبِّكَ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يُؤْمِنُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mcdxci{وَمَنْ أَظْلَمُ مِمَّنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا أُو۟لَٰٓئِكَ يُعْرَضُونَ عَلَىٰ رَبِّهِمْ وَيَقُولُ ٱلْأَشْهَٰدُ هَٰٓؤُلَآءِ ٱلَّذِينَ كَذَبُوا۟ عَلَىٰ رَبِّهِمْ أَلَا لَعْنَةُ ٱللَّهِ عَلَى ٱلظَّٰلِمِينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mcdxcii{ٱلَّذِينَ يَصُدُّونَ عَن سَبِيلِ ٱللَّهِ وَيَبْغُونَهَا عِوَجًا وَهُم بِٱلْءَاخِرَةِ هُمْ كَٰفِرُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mcdxciii{أُو۟لَٰٓئِكَ لَمْ يَكُونُوا۟ مُعْجِزِينَ فِى ٱلْأَرْضِ وَمَا كَانَ لَهُم مِّن دُونِ ٱللَّهِ مِنْ أَوْلِيَآءَ يُضَٰعَفُ لَهُمُ ٱلْعَذَابُ مَا كَانُوا۟ يَسْتَطِيعُونَ ٱلسَّمْعَ وَمَا كَانُوا۟ يُبْصِرُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mcdxciv{أُو۟لَٰٓئِكَ ٱلَّذِينَ خَسِرُوٓا۟ أَنفُسَهُمْ وَضَلَّ عَنْهُم مَّا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mcdxcv{لَا جَرَمَ أَنَّهُمْ فِى ٱلْءَاخِرَةِ هُمُ ٱلْأَخْسَرُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mcdxcvi{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ وَأَخْبَتُوٓا۟ إِلَىٰ رَبِّهِمْ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْجَنَّةِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mcdxcvii{مَثَلُ ٱلْفَرِيقَيْنِ كَٱلْأَعْمَىٰ وَٱلْأَصَمِّ وَٱلْبَصِيرِ وَٱلسَّمِيعِ هَلْ يَسْتَوِيَانِ مَثَلًا أَفَلَا تَذَكَّرُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mcdxcviii{وَلَقَدْ أَرْسَلْنَا نُوحًا إِلَىٰ قَوْمِهِۦٓ إِنِّى لَكُمْ نَذِيرٌ مُّبِينٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcdxcix{أَن لَّا تَعْبُدُوٓا۟ إِلَّا ٱللَّهَ إِنِّىٓ أَخَافُ عَلَيْكُمْ عَذَابَ يَوْمٍ أَلِيمٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@md{فَقَالَ ٱلْمَلَأُ ٱلَّذِينَ كَفَرُوا۟ مِن قَوْمِهِۦ مَا نَرَىٰكَ إِلَّا بَشَرًا مِّثْلَنَا وَمَا نَرَىٰكَ ٱتَّبَعَكَ إِلَّا ٱلَّذِينَ هُمْ أَرَاذِلُنَا بَادِىَ ٱلرَّأْىِ وَمَا نَرَىٰ لَكُمْ عَلَيْنَا مِن فَضْلٍۭ بَلْ نَظُنُّكُمْ كَٰذِبِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdi{قَالَ يَٰقَوْمِ أَرَءَيْتُمْ إِن كُنتُ عَلَىٰ بَيِّنَةٍ مِّن رَّبِّى وَءَاتَىٰنِى رَحْمَةً مِّنْ عِندِهِۦ فَعُمِّيَتْ عَلَيْكُمْ أَنُلْزِمُكُمُوهَا وَأَنتُمْ لَهَا كَٰرِهُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdii{وَيَٰقَوْمِ لَآ أَسْـَٔلُكُمْ عَلَيْهِ مَالًا إِنْ أَجْرِىَ إِلَّا عَلَى ٱللَّهِ وَمَآ أَنَا۠ بِطَارِدِ ٱلَّذِينَ ءَامَنُوٓا۟ إِنَّهُم مُّلَٰقُوا۟ رَبِّهِمْ وَلَٰكِنِّىٓ أَرَىٰكُمْ قَوْمًا تَجْهَلُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdiii{وَيَٰقَوْمِ مَن يَنصُرُنِى مِنَ ٱللَّهِ إِن طَرَدتُّهُمْ أَفَلَا تَذَكَّرُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdiv{وَلَآ أَقُولُ لَكُمْ عِندِى خَزَآئِنُ ٱللَّهِ وَلَآ أَعْلَمُ ٱلْغَيْبَ وَلَآ أَقُولُ إِنِّى مَلَكٌ وَلَآ أَقُولُ لِلَّذِينَ تَزْدَرِىٓ أَعْيُنُكُمْ لَن يُؤْتِيَهُمُ ٱللَّهُ خَيْرًا ٱللَّهُ أَعْلَمُ بِمَا فِىٓ أَنفُسِهِمْ إِنِّىٓ إِذًا لَّمِنَ ٱلظَّٰلِمِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdv{قَالُوا۟ يَٰنُوحُ قَدْ جَٰدَلْتَنَا فَأَكْثَرْتَ جِدَٰلَنَا فَأْتِنَا بِمَا تَعِدُنَآ إِن كُنتَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdvi{قَالَ إِنَّمَا يَأْتِيكُم بِهِ ٱللَّهُ إِن شَآءَ وَمَآ أَنتُم بِمُعْجِزِينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdvii{وَلَا يَنفَعُكُمْ نُصْحِىٓ إِنْ أَرَدتُّ أَنْ أَنصَحَ لَكُمْ إِن كَانَ ٱللَّهُ يُرِيدُ أَن يُغْوِيَكُمْ هُوَ رَبُّكُمْ وَإِلَيْهِ تُرْجَعُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdviii{أَمْ يَقُولُونَ ٱفْتَرَىٰهُ قُلْ إِنِ ٱفْتَرَيْتُهُۥ فَعَلَىَّ إِجْرَامِى وَأَنَا۠ بَرِىٓءٌ مِّمَّا تُجْرِمُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdix{وَأُوحِىَ إِلَىٰ نُوحٍ أَنَّهُۥ لَن يُؤْمِنَ مِن قَوْمِكَ إِلَّا مَن قَدْ ءَامَنَ فَلَا تَبْتَئِسْ بِمَا كَانُوا۟ يَفْعَلُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdx{وَٱصْنَعِ ٱلْفُلْكَ بِأَعْيُنِنَا وَوَحْيِنَا وَلَا تُخَٰطِبْنِى فِى ٱلَّذِينَ ظَلَمُوٓا۟ إِنَّهُم مُّغْرَقُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdxi{وَيَصْنَعُ ٱلْفُلْكَ وَكُلَّمَا مَرَّ عَلَيْهِ مَلَأٌ مِّن قَوْمِهِۦ سَخِرُوا۟ مِنْهُ قَالَ إِن تَسْخَرُوا۟ مِنَّا فَإِنَّا نَسْخَرُ مِنكُمْ كَمَا تَسْخَرُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdxii{فَسَوْفَ تَعْلَمُونَ مَن يَأْتِيهِ عَذَابٌ يُخْزِيهِ وَيَحِلُّ عَلَيْهِ عَذَابٌ مُّقِيمٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdxiii{حَتَّىٰٓ إِذَا جَآءَ أَمْرُنَا وَفَارَ ٱلتَّنُّورُ قُلْنَا ٱحْمِلْ فِيهَا مِن كُلٍّ زَوْجَيْنِ ٱثْنَيْنِ وَأَهْلَكَ إِلَّا مَن سَبَقَ عَلَيْهِ ٱلْقَوْلُ وَمَنْ ءَامَنَ وَمَآ ءَامَنَ مَعَهُۥٓ إِلَّا قَلِيلٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdxiv{وَقَالَ ٱرْكَبُوا۟ فِيهَا بِسْمِ ٱللَّهِ مَجْر۪ىٰهَا وَمُرْسَىٰهَآ إِنَّ رَبِّى لَغَفُورٌ رَّحِيمٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdxv{وَهِىَ تَجْرِى بِهِمْ فِى مَوْجٍ كَٱلْجِبَالِ وَنَادَىٰ نُوحٌ ٱبْنَهُۥ وَكَانَ فِى مَعْزِلٍ يَٰبُنَىَّ ٱرْكَب مَّعَنَا وَلَا تَكُن مَّعَ ٱلْكَٰفِرِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdxvi{قَالَ سَـَٔاوِىٓ إِلَىٰ جَبَلٍ يَعْصِمُنِى مِنَ ٱلْمَآءِ قَالَ لَا عَاصِمَ ٱلْيَوْمَ مِنْ أَمْرِ ٱللَّهِ إِلَّا مَن رَّحِمَ وَحَالَ بَيْنَهُمَا ٱلْمَوْجُ فَكَانَ مِنَ ٱلْمُغْرَقِينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdxvii{وَقِيلَ يَٰٓأَرْضُ ٱبْلَعِى مَآءَكِ وَيَٰسَمَآءُ أَقْلِعِى وَغِيضَ ٱلْمَآءُ وَقُضِىَ ٱلْأَمْرُ وَٱسْتَوَتْ عَلَى ٱلْجُودِىِّ وَقِيلَ بُعْدًا لِّلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdxviii{وَنَادَىٰ نُوحٌ رَّبَّهُۥ فَقَالَ رَبِّ إِنَّ ٱبْنِى مِنْ أَهْلِى وَإِنَّ وَعْدَكَ ٱلْحَقُّ وَأَنتَ أَحْكَمُ ٱلْحَٰكِمِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdxix{قَالَ يَٰنُوحُ إِنَّهُۥ لَيْسَ مِنْ أَهْلِكَ إِنَّهُۥ عَمَلٌ غَيْرُ صَٰلِحٍ فَلَا تَسْـَٔلْنِ مَا لَيْسَ لَكَ بِهِۦ عِلْمٌ إِنِّىٓ أَعِظُكَ أَن تَكُونَ مِنَ ٱلْجَٰهِلِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdxx{قَالَ رَبِّ إِنِّىٓ أَعُوذُ بِكَ أَنْ أَسْـَٔلَكَ مَا لَيْسَ لِى بِهِۦ عِلْمٌ وَإِلَّا تَغْفِرْ لِى وَتَرْحَمْنِىٓ أَكُن مِّنَ ٱلْخَٰسِرِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdxxi{قِيلَ يَٰنُوحُ ٱهْبِطْ بِسَلَٰمٍ مِّنَّا وَبَرَكَٰتٍ عَلَيْكَ وَعَلَىٰٓ أُمَمٍ مِّمَّن مَّعَكَ وَأُمَمٌ سَنُمَتِّعُهُمْ ثُمَّ يَمَسُّهُم مِّنَّا عَذَابٌ أَلِيمٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdxxii{تِلْكَ مِنْ أَنۢبَآءِ ٱلْغَيْبِ نُوحِيهَآ إِلَيْكَ مَا كُنتَ تَعْلَمُهَآ أَنتَ وَلَا قَوْمُكَ مِن قَبْلِ هَٰذَا فَٱصْبِرْ إِنَّ ٱلْعَٰقِبَةَ لِلْمُتَّقِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdxxiii{وَإِلَىٰ عَادٍ أَخَاهُمْ هُودًا قَالَ يَٰقَوْمِ ٱعْبُدُوا۟ ٱللَّهَ مَا لَكُم مِّنْ إِلَٰهٍ غَيْرُهُۥٓ إِنْ أَنتُمْ إِلَّا مُفْتَرُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdxxiv{يَٰقَوْمِ لَآ أَسْـَٔلُكُمْ عَلَيْهِ أَجْرًا إِنْ أَجْرِىَ إِلَّا عَلَى ٱلَّذِى فَطَرَنِىٓ أَفَلَا تَعْقِلُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdxxv{وَيَٰقَوْمِ ٱسْتَغْفِرُوا۟ رَبَّكُمْ ثُمَّ تُوبُوٓا۟ إِلَيْهِ يُرْسِلِ ٱلسَّمَآءَ عَلَيْكُم مِّدْرَارًا وَيَزِدْكُمْ قُوَّةً إِلَىٰ قُوَّتِكُمْ وَلَا تَتَوَلَّوْا۟ مُجْرِمِينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdxxvi{قَالُوا۟ يَٰهُودُ مَا جِئْتَنَا بِبَيِّنَةٍ وَمَا نَحْنُ بِتَارِكِىٓ ءَالِهَتِنَا عَن قَوْلِكَ وَمَا نَحْنُ لَكَ بِمُؤْمِنِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mdxxvii{إِن نَّقُولُ إِلَّا ٱعْتَرَىٰكَ بَعْضُ ءَالِهَتِنَا بِسُوٓءٍ قَالَ إِنِّىٓ أُشْهِدُ ٱللَّهَ وَٱشْهَدُوٓا۟ أَنِّى بَرِىٓءٌ مِّمَّا تُشْرِكُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mdxxviii{مِن دُونِهِۦ فَكِيدُونِى جَمِيعًا ثُمَّ لَا تُنظِرُونِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mdxxix{إِنِّى تَوَكَّلْتُ عَلَى ٱللَّهِ رَبِّى وَرَبِّكُم مَّا مِن دَآبَّةٍ إِلَّا هُوَ ءَاخِذٌۢ بِنَاصِيَتِهَآ إِنَّ رَبِّى عَلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mdxxx{فَإِن تَوَلَّوْا۟ فَقَدْ أَبْلَغْتُكُم مَّآ أُرْسِلْتُ بِهِۦٓ إِلَيْكُمْ وَيَسْتَخْلِفُ رَبِّى قَوْمًا غَيْرَكُمْ وَلَا تَضُرُّونَهُۥ شَيْـًٔا إِنَّ رَبِّى عَلَىٰ كُلِّ شَىْءٍ حَفِيظٌ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mdxxxi{وَلَمَّا جَآءَ أَمْرُنَا نَجَّيْنَا هُودًا وَٱلَّذِينَ ءَامَنُوا۟ مَعَهُۥ بِرَحْمَةٍ مِّنَّا وَنَجَّيْنَٰهُم مِّنْ عَذَابٍ غَلِيظٍ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mdxxxii{وَتِلْكَ عَادٌ جَحَدُوا۟ بِـَٔايَٰتِ رَبِّهِمْ وَعَصَوْا۟ رُسُلَهُۥ وَٱتَّبَعُوٓا۟ أَمْرَ كُلِّ جَبَّارٍ عَنِيدٍ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mdxxxiii{وَأُتْبِعُوا۟ فِى هَٰذِهِ ٱلدُّنْيَا لَعْنَةً وَيَوْمَ ٱلْقِيَٰمَةِ أَلَآ إِنَّ عَادًا كَفَرُوا۟ رَبَّهُمْ أَلَا بُعْدًا لِّعَادٍ قَوْمِ هُودٍ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mdxxxiv{وَإِلَىٰ ثَمُودَ أَخَاهُمْ صَٰلِحًا قَالَ يَٰقَوْمِ ٱعْبُدُوا۟ ٱللَّهَ مَا لَكُم مِّنْ إِلَٰهٍ غَيْرُهُۥ هُوَ أَنشَأَكُم مِّنَ ٱلْأَرْضِ وَٱسْتَعْمَرَكُمْ فِيهَا فَٱسْتَغْفِرُوهُ ثُمَّ تُوبُوٓا۟ إِلَيْهِ إِنَّ رَبِّى قَرِيبٌ مُّجِيبٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mdxxxv{قَالُوا۟ يَٰصَٰلِحُ قَدْ كُنتَ فِينَا مَرْجُوًّا قَبْلَ هَٰذَآ أَتَنْهَىٰنَآ أَن نَّعْبُدَ مَا يَعْبُدُ ءَابَآؤُنَا وَإِنَّنَا لَفِى شَكٍّ مِّمَّا تَدْعُونَآ إِلَيْهِ مُرِيبٍ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mdxxxvi{قَالَ يَٰقَوْمِ أَرَءَيْتُمْ إِن كُنتُ عَلَىٰ بَيِّنَةٍ مِّن رَّبِّى وَءَاتَىٰنِى مِنْهُ رَحْمَةً فَمَن يَنصُرُنِى مِنَ ٱللَّهِ إِنْ عَصَيْتُهُۥ فَمَا تَزِيدُونَنِى غَيْرَ تَخْسِيرٍ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mdxxxvii{وَيَٰقَوْمِ هَٰذِهِۦ نَاقَةُ ٱللَّهِ لَكُمْ ءَايَةً فَذَرُوهَا تَأْكُلْ فِىٓ أَرْضِ ٱللَّهِ وَلَا تَمَسُّوهَا بِسُوٓءٍ فَيَأْخُذَكُمْ عَذَابٌ قَرِيبٌ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mdxxxviii{فَعَقَرُوهَا فَقَالَ تَمَتَّعُوا۟ فِى دَارِكُمْ ثَلَٰثَةَ أَيَّامٍ ذَٰلِكَ وَعْدٌ غَيْرُ مَكْذُوبٍ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mdxxxix{فَلَمَّا جَآءَ أَمْرُنَا نَجَّيْنَا صَٰلِحًا وَٱلَّذِينَ ءَامَنُوا۟ مَعَهُۥ بِرَحْمَةٍ مِّنَّا وَمِنْ خِزْىِ يَوْمِئِذٍ إِنَّ رَبَّكَ هُوَ ٱلْقَوِىُّ ٱلْعَزِيزُ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mdxl{وَأَخَذَ ٱلَّذِينَ ظَلَمُوا۟ ٱلصَّيْحَةُ فَأَصْبَحُوا۟ فِى دِيَٰرِهِمْ جَٰثِمِينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mdxli{كَأَن لَّمْ يَغْنَوْا۟ فِيهَآ أَلَآ إِنَّ ثَمُودَا۟ كَفَرُوا۟ رَبَّهُمْ أَلَا بُعْدًا لِّثَمُودَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mdxlii{وَلَقَدْ جَآءَتْ رُسُلُنَآ إِبْرَٰهِيمَ بِٱلْبُشْرَىٰ قَالُوا۟ سَلَٰمًا قَالَ سَلَٰمٌ فَمَا لَبِثَ أَن جَآءَ بِعِجْلٍ حَنِيذٍ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mdxliii{فَلَمَّا رَءَآ أَيْدِيَهُمْ لَا تَصِلُ إِلَيْهِ نَكِرَهُمْ وَأَوْجَسَ مِنْهُمْ خِيفَةً قَالُوا۟ لَا تَخَفْ إِنَّآ أُرْسِلْنَآ إِلَىٰ قَوْمِ لُوطٍ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mdxliv{وَٱمْرَأَتُهُۥ قَآئِمَةٌ فَضَحِكَتْ فَبَشَّرْنَٰهَا بِإِسْحَٰقَ وَمِن وَرَآءِ إِسْحَٰقَ يَعْقُوبَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mdxlv{قَالَتْ يَٰوَيْلَتَىٰٓ ءَأَلِدُ وَأَنَا۠ عَجُوزٌ وَهَٰذَا بَعْلِى شَيْخًا إِنَّ هَٰذَا لَشَىْءٌ عَجِيبٌ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mdxlvi{قَالُوٓا۟ أَتَعْجَبِينَ مِنْ أَمْرِ ٱللَّهِ رَحْمَتُ ٱللَّهِ وَبَرَكَٰتُهُۥ عَلَيْكُمْ أَهْلَ ٱلْبَيْتِ إِنَّهُۥ حَمِيدٌ مَّجِيدٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mdxlvii{فَلَمَّا ذَهَبَ عَنْ إِبْرَٰهِيمَ ٱلرَّوْعُ وَجَآءَتْهُ ٱلْبُشْرَىٰ يُجَٰدِلُنَا فِى قَوْمِ لُوطٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mdxlviii{إِنَّ إِبْرَٰهِيمَ لَحَلِيمٌ أَوَّٰهٌ مُّنِيبٌ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mdxlix{يَٰٓإِبْرَٰهِيمُ أَعْرِضْ عَنْ هَٰذَآ إِنَّهُۥ قَدْ جَآءَ أَمْرُ رَبِّكَ وَإِنَّهُمْ ءَاتِيهِمْ عَذَابٌ غَيْرُ مَرْدُودٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mdl{وَلَمَّا جَآءَتْ رُسُلُنَا لُوطًا سِىٓءَ بِهِمْ وَضَاقَ بِهِمْ ذَرْعًا وَقَالَ هَٰذَا يَوْمٌ عَصِيبٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mdli{وَجَآءَهُۥ قَوْمُهُۥ يُهْرَعُونَ إِلَيْهِ وَمِن قَبْلُ كَانُوا۟ يَعْمَلُونَ ٱلسَّيِّـَٔاتِ قَالَ يَٰقَوْمِ هَٰٓؤُلَآءِ بَنَاتِى هُنَّ أَطْهَرُ لَكُمْ فَٱتَّقُوا۟ ٱللَّهَ وَلَا تُخْزُونِ فِى ضَيْفِىٓ أَلَيْسَ مِنكُمْ رَجُلٌ رَّشِيدٌ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mdlii{قَالُوا۟ لَقَدْ عَلِمْتَ مَا لَنَا فِى بَنَاتِكَ مِنْ حَقٍّ وَإِنَّكَ لَتَعْلَمُ مَا نُرِيدُ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mdliii{قَالَ لَوْ أَنَّ لِى بِكُمْ قُوَّةً أَوْ ءَاوِىٓ إِلَىٰ رُكْنٍ شَدِيدٍ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mdliv{قَالُوا۟ يَٰلُوطُ إِنَّا رُسُلُ رَبِّكَ لَن يَصِلُوٓا۟ إِلَيْكَ فَأَسْرِ بِأَهْلِكَ بِقِطْعٍ مِّنَ ٱلَّيْلِ وَلَا يَلْتَفِتْ مِنكُمْ أَحَدٌ إِلَّا ٱمْرَأَتَكَ إِنَّهُۥ مُصِيبُهَا مَآ أَصَابَهُمْ إِنَّ مَوْعِدَهُمُ ٱلصُّبْحُ أَلَيْسَ ٱلصُّبْحُ بِقَرِيبٍ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mdlv{فَلَمَّا جَآءَ أَمْرُنَا جَعَلْنَا عَٰلِيَهَا سَافِلَهَا وَأَمْطَرْنَا عَلَيْهَا حِجَارَةً مِّن سِجِّيلٍ مَّنضُودٍ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mdlvi{مُّسَوَّمَةً عِندَ رَبِّكَ وَمَا هِىَ مِنَ ٱلظَّٰلِمِينَ بِبَعِيدٍ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mdlvii{وَإِلَىٰ مَدْيَنَ أَخَاهُمْ شُعَيْبًا قَالَ يَٰقَوْمِ ٱعْبُدُوا۟ ٱللَّهَ مَا لَكُم مِّنْ إِلَٰهٍ غَيْرُهُۥ وَلَا تَنقُصُوا۟ ٱلْمِكْيَالَ وَٱلْمِيزَانَ إِنِّىٓ أَرَىٰكُم بِخَيْرٍ وَإِنِّىٓ أَخَافُ عَلَيْكُمْ عَذَابَ يَوْمٍ مُّحِيطٍ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mdlviii{وَيَٰقَوْمِ أَوْفُوا۟ ٱلْمِكْيَالَ وَٱلْمِيزَانَ بِٱلْقِسْطِ وَلَا تَبْخَسُوا۟ ٱلنَّاسَ أَشْيَآءَهُمْ وَلَا تَعْثَوْا۟ فِى ٱلْأَرْضِ مُفْسِدِينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mdlix{بَقِيَّتُ ٱللَّهِ خَيْرٌ لَّكُمْ إِن كُنتُم مُّؤْمِنِينَ وَمَآ أَنَا۠ عَلَيْكُم بِحَفِيظٍ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mdlx{قَالُوا۟ يَٰشُعَيْبُ أَصَلَوٰتُكَ تَأْمُرُكَ أَن نَّتْرُكَ مَا يَعْبُدُ ءَابَآؤُنَآ أَوْ أَن نَّفْعَلَ فِىٓ أَمْوَٰلِنَا مَا نَشَٰٓؤُا۟ إِنَّكَ لَأَنتَ ٱلْحَلِيمُ ٱلرَّشِيدُ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mdlxi{قَالَ يَٰقَوْمِ أَرَءَيْتُمْ إِن كُنتُ عَلَىٰ بَيِّنَةٍ مِّن رَّبِّى وَرَزَقَنِى مِنْهُ رِزْقًا حَسَنًا وَمَآ أُرِيدُ أَنْ أُخَالِفَكُمْ إِلَىٰ مَآ أَنْهَىٰكُمْ عَنْهُ إِنْ أُرِيدُ إِلَّا ٱلْإِصْلَٰحَ مَا ٱسْتَطَعْتُ وَمَا تَوْفِيقِىٓ إِلَّا بِٱللَّهِ عَلَيْهِ تَوَكَّلْتُ وَإِلَيْهِ أُنِيبُ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mdlxii{وَيَٰقَوْمِ لَا يَجْرِمَنَّكُمْ شِقَاقِىٓ أَن يُصِيبَكُم مِّثْلُ مَآ أَصَابَ قَوْمَ نُوحٍ أَوْ قَوْمَ هُودٍ أَوْ قَوْمَ صَٰلِحٍ وَمَا قَوْمُ لُوطٍ مِّنكُم بِبَعِيدٍ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mdlxiii{وَٱسْتَغْفِرُوا۟ رَبَّكُمْ ثُمَّ تُوبُوٓا۟ إِلَيْهِ إِنَّ رَبِّى رَحِيمٌ وَدُودٌ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mdlxiv{قَالُوا۟ يَٰشُعَيْبُ مَا نَفْقَهُ كَثِيرًا مِّمَّا تَقُولُ وَإِنَّا لَنَرَىٰكَ فِينَا ضَعِيفًا وَلَوْلَا رَهْطُكَ لَرَجَمْنَٰكَ وَمَآ أَنتَ عَلَيْنَا بِعَزِيزٍ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mdlxv{قَالَ يَٰقَوْمِ أَرَهْطِىٓ أَعَزُّ عَلَيْكُم مِّنَ ٱللَّهِ وَٱتَّخَذْتُمُوهُ وَرَآءَكُمْ ظِهْرِيًّا إِنَّ رَبِّى بِمَا تَعْمَلُونَ مُحِيطٌ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mdlxvi{وَيَٰقَوْمِ ٱعْمَلُوا۟ عَلَىٰ مَكَانَتِكُمْ إِنِّى عَٰمِلٌ سَوْفَ تَعْلَمُونَ مَن يَأْتِيهِ عَذَابٌ يُخْزِيهِ وَمَنْ هُوَ كَٰذِبٌ وَٱرْتَقِبُوٓا۟ إِنِّى مَعَكُمْ رَقِيبٌ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mdlxvii{وَلَمَّا جَآءَ أَمْرُنَا نَجَّيْنَا شُعَيْبًا وَٱلَّذِينَ ءَامَنُوا۟ مَعَهُۥ بِرَحْمَةٍ مِّنَّا وَأَخَذَتِ ٱلَّذِينَ ظَلَمُوا۟ ٱلصَّيْحَةُ فَأَصْبَحُوا۟ فِى دِيَٰرِهِمْ جَٰثِمِينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mdlxviii{كَأَن لَّمْ يَغْنَوْا۟ فِيهَآ أَلَا بُعْدًا لِّمَدْيَنَ كَمَا بَعِدَتْ ثَمُودُ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mdlxix{وَلَقَدْ أَرْسَلْنَا مُوسَىٰ بِـَٔايَٰتِنَا وَسُلْطَٰنٍ مُّبِينٍ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mdlxx{إِلَىٰ فِرْعَوْنَ وَمَلَإِي۟هِۦ فَٱتَّبَعُوٓا۟ أَمْرَ فِرْعَوْنَ وَمَآ أَمْرُ فِرْعَوْنَ بِرَشِيدٍ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mdlxxi{يَقْدُمُ قَوْمَهُۥ يَوْمَ ٱلْقِيَٰمَةِ فَأَوْرَدَهُمُ ٱلنَّارَ وَبِئْسَ ٱلْوِرْدُ ٱلْمَوْرُودُ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mdlxxii{وَأُتْبِعُوا۟ فِى هَٰذِهِۦ لَعْنَةً وَيَوْمَ ٱلْقِيَٰمَةِ بِئْسَ ٱلرِّفْدُ ٱلْمَرْفُودُ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mdlxxiii{ذَٰلِكَ مِنْ أَنۢبَآءِ ٱلْقُرَىٰ نَقُصُّهُۥ عَلَيْكَ مِنْهَا قَآئِمٌ وَحَصِيدٌ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mdlxxiv{وَمَا ظَلَمْنَٰهُمْ وَلَٰكِن ظَلَمُوٓا۟ أَنفُسَهُمْ فَمَآ أَغْنَتْ عَنْهُمْ ءَالِهَتُهُمُ ٱلَّتِى يَدْعُونَ مِن دُونِ ٱللَّهِ مِن شَىْءٍ لَّمَّا جَآءَ أَمْرُ رَبِّكَ وَمَا زَادُوهُمْ غَيْرَ تَتْبِيبٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mdlxxv{وَكَذَٰلِكَ أَخْذُ رَبِّكَ إِذَآ أَخَذَ ٱلْقُرَىٰ وَهِىَ ظَٰلِمَةٌ إِنَّ أَخْذَهُۥٓ أَلِيمٌ شَدِيدٌ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mdlxxvi{إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّمَنْ خَافَ عَذَابَ ٱلْءَاخِرَةِ ذَٰلِكَ يَوْمٌ مَّجْمُوعٌ لَّهُ ٱلنَّاسُ وَذَٰلِكَ يَوْمٌ مَّشْهُودٌ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mdlxxvii{وَمَا نُؤَخِّرُهُۥٓ إِلَّا لِأَجَلٍ مَّعْدُودٍ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mdlxxviii{يَوْمَ يَأْتِ لَا تَكَلَّمُ نَفْسٌ إِلَّا بِإِذْنِهِۦ فَمِنْهُمْ شَقِىٌّ وَسَعِيدٌ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mdlxxix{فَأَمَّا ٱلَّذِينَ شَقُوا۟ فَفِى ٱلنَّارِ لَهُمْ فِيهَا زَفِيرٌ وَشَهِيقٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mdlxxx{خَٰلِدِينَ فِيهَا مَا دَامَتِ ٱلسَّمَٰوَٰتُ وَٱلْأَرْضُ إِلَّا مَا شَآءَ رَبُّكَ إِنَّ رَبَّكَ فَعَّالٌ لِّمَا يُرِيدُ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mdlxxxi{وَأَمَّا ٱلَّذِينَ سُعِدُوا۟ فَفِى ٱلْجَنَّةِ خَٰلِدِينَ فِيهَا مَا دَامَتِ ٱلسَّمَٰوَٰتُ وَٱلْأَرْضُ إِلَّا مَا شَآءَ رَبُّكَ عَطَآءً غَيْرَ مَجْذُوذٍ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mdlxxxii{فَلَا تَكُ فِى مِرْيَةٍ مِّمَّا يَعْبُدُ هَٰٓؤُلَآءِ مَا يَعْبُدُونَ إِلَّا كَمَا يَعْبُدُ ءَابَآؤُهُم مِّن قَبْلُ وَإِنَّا لَمُوَفُّوهُمْ نَصِيبَهُمْ غَيْرَ مَنقُوصٍ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mdlxxxiii{وَلَقَدْ ءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ فَٱخْتُلِفَ فِيهِ وَلَوْلَا كَلِمَةٌ سَبَقَتْ مِن رَّبِّكَ لَقُضِىَ بَيْنَهُمْ وَإِنَّهُمْ لَفِى شَكٍّ مِّنْهُ مُرِيبٍ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mdlxxxiv{وَإِنَّ كُلًّا لَّمَّا لَيُوَفِّيَنَّهُمْ رَبُّكَ أَعْمَٰلَهُمْ إِنَّهُۥ بِمَا يَعْمَلُونَ خَبِيرٌ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mdlxxxv{فَٱسْتَقِمْ كَمَآ أُمِرْتَ وَمَن تَابَ مَعَكَ وَلَا تَطْغَوْا۟ إِنَّهُۥ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mdlxxxvi{وَلَا تَرْكَنُوٓا۟ إِلَى ٱلَّذِينَ ظَلَمُوا۟ فَتَمَسَّكُمُ ٱلنَّارُ وَمَا لَكُم مِّن دُونِ ٱللَّهِ مِنْ أَوْلِيَآءَ ثُمَّ لَا تُنصَرُونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mdlxxxvii{وَأَقِمِ ٱلصَّلَوٰةَ طَرَفَىِ ٱلنَّهَارِ وَزُلَفًا مِّنَ ٱلَّيْلِ إِنَّ ٱلْحَسَنَٰتِ يُذْهِبْنَ ٱلسَّيِّـَٔاتِ ذَٰلِكَ ذِكْرَىٰ لِلذَّٰكِرِينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mdlxxxviii{وَٱصْبِرْ فَإِنَّ ٱللَّهَ لَا يُضِيعُ أَجْرَ ٱلْمُحْسِنِينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mdlxxxix{فَلَوْلَا كَانَ مِنَ ٱلْقُرُونِ مِن قَبْلِكُمْ أُو۟لُوا۟ بَقِيَّةٍ يَنْهَوْنَ عَنِ ٱلْفَسَادِ فِى ٱلْأَرْضِ إِلَّا قَلِيلًا مِّمَّنْ أَنجَيْنَا مِنْهُمْ وَٱتَّبَعَ ٱلَّذِينَ ظَلَمُوا۟ مَآ أُتْرِفُوا۟ فِيهِ وَكَانُوا۟ مُجْرِمِينَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mdxc{وَمَا كَانَ رَبُّكَ لِيُهْلِكَ ٱلْقُرَىٰ بِظُلْمٍ وَأَهْلُهَا مُصْلِحُونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mdxci{وَلَوْ شَآءَ رَبُّكَ لَجَعَلَ ٱلنَّاسَ أُمَّةً وَٰحِدَةً وَلَا يَزَالُونَ مُخْتَلِفِينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mdxcii{إِلَّا مَن رَّحِمَ رَبُّكَ وَلِذَٰلِكَ خَلَقَهُمْ وَتَمَّتْ كَلِمَةُ رَبِّكَ لَأَمْلَأَنَّ جَهَنَّمَ مِنَ ٱلْجِنَّةِ وَٱلنَّاسِ أَجْمَعِينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mdxciii{وَكُلًّا نَّقُصُّ عَلَيْكَ مِنْ أَنۢبَآءِ ٱلرُّسُلِ مَا نُثَبِّتُ بِهِۦ فُؤَادَكَ وَجَآءَكَ فِى هَٰذِهِ ٱلْحَقُّ وَمَوْعِظَةٌ وَذِكْرَىٰ لِلْمُؤْمِنِينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mdxciv{وَقُل لِّلَّذِينَ لَا يُؤْمِنُونَ ٱعْمَلُوا۟ عَلَىٰ مَكَانَتِكُمْ إِنَّا عَٰمِلُونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mdxcv{وَٱنتَظِرُوٓا۟ إِنَّا مُنتَظِرُونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mdxcvi{وَلِلَّهِ غَيْبُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَإِلَيْهِ يُرْجَعُ ٱلْأَمْرُ كُلُّهُۥ فَٱعْبُدْهُ وَتَوَكَّلْ عَلَيْهِ وَمَا رَبُّكَ بِغَٰفِلٍ عَمَّا تَعْمَلُونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mdxcvii{\basmalah الٓر تِلْكَ ءَايَٰتُ ٱلْكِتَٰبِ ٱلْمُبِينِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdxcviii{إِنَّآ أَنزَلْنَٰهُ قُرْءَٰنًا عَرَبِيًّا لَّعَلَّكُمْ تَعْقِلُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdxcix{نَحْنُ نَقُصُّ عَلَيْكَ أَحْسَنَ ٱلْقَصَصِ بِمَآ أَوْحَيْنَآ إِلَيْكَ هَٰذَا ٱلْقُرْءَانَ وَإِن كُنتَ مِن قَبْلِهِۦ لَمِنَ ٱلْغَٰفِلِينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdc{إِذْ قَالَ يُوسُفُ لِأَبِيهِ يَٰٓأَبَتِ إِنِّى رَأَيْتُ أَحَدَ عَشَرَ كَوْكَبًا وَٱلشَّمْسَ وَٱلْقَمَرَ رَأَيْتُهُمْ لِى سَٰجِدِينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdci{قَالَ يَٰبُنَىَّ لَا تَقْصُصْ رُءْيَاكَ عَلَىٰٓ إِخْوَتِكَ فَيَكِيدُوا۟ لَكَ كَيْدًا إِنَّ ٱلشَّيْطَٰنَ لِلْإِنسَٰنِ عَدُوٌّ مُّبِينٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdcii{وَكَذَٰلِكَ يَجْتَبِيكَ رَبُّكَ وَيُعَلِّمُكَ مِن تَأْوِيلِ ٱلْأَحَادِيثِ وَيُتِمُّ نِعْمَتَهُۥ عَلَيْكَ وَعَلَىٰٓ ءَالِ يَعْقُوبَ كَمَآ أَتَمَّهَا عَلَىٰٓ أَبَوَيْكَ مِن قَبْلُ إِبْرَٰهِيمَ وَإِسْحَٰقَ إِنَّ رَبَّكَ عَلِيمٌ حَكِيمٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdciii{لَّقَدْ كَانَ فِى يُوسُفَ وَإِخْوَتِهِۦٓ ءَايَٰتٌ لِّلسَّآئِلِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdciv{إِذْ قَالُوا۟ لَيُوسُفُ وَأَخُوهُ أَحَبُّ إِلَىٰٓ أَبِينَا مِنَّا وَنَحْنُ عُصْبَةٌ إِنَّ أَبَانَا لَفِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdcv{ٱقْتُلُوا۟ يُوسُفَ أَوِ ٱطْرَحُوهُ أَرْضًا يَخْلُ لَكُمْ وَجْهُ أَبِيكُمْ وَتَكُونُوا۟ مِنۢ بَعْدِهِۦ قَوْمًا صَٰلِحِينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdcvi{قَالَ قَآئِلٌ مِّنْهُمْ لَا تَقْتُلُوا۟ يُوسُفَ وَأَلْقُوهُ فِى غَيَٰبَتِ ٱلْجُبِّ يَلْتَقِطْهُ بَعْضُ ٱلسَّيَّارَةِ إِن كُنتُمْ فَٰعِلِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdcvii{قَالُوا۟ يَٰٓأَبَانَا مَا لَكَ لَا تَأْمَ۫نَّا عَلَىٰ يُوسُفَ وَإِنَّا لَهُۥ لَنَٰصِحُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdcviii{أَرْسِلْهُ مَعَنَا غَدًا يَرْتَعْ وَيَلْعَبْ وَإِنَّا لَهُۥ لَحَٰفِظُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdcix{قَالَ إِنِّى لَيَحْزُنُنِىٓ أَن تَذْهَبُوا۟ بِهِۦ وَأَخَافُ أَن يَأْكُلَهُ ٱلذِّئْبُ وَأَنتُمْ عَنْهُ غَٰفِلُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdcx{قَالُوا۟ لَئِنْ أَكَلَهُ ٱلذِّئْبُ وَنَحْنُ عُصْبَةٌ إِنَّآ إِذًا لَّخَٰسِرُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdcxi{فَلَمَّا ذَهَبُوا۟ بِهِۦ وَأَجْمَعُوٓا۟ أَن يَجْعَلُوهُ فِى غَيَٰبَتِ ٱلْجُبِّ وَأَوْحَيْنَآ إِلَيْهِ لَتُنَبِّئَنَّهُم بِأَمْرِهِمْ هَٰذَا وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdcxii{وَجَآءُوٓ أَبَاهُمْ عِشَآءً يَبْكُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdcxiii{قَالُوا۟ يَٰٓأَبَانَآ إِنَّا ذَهَبْنَا نَسْتَبِقُ وَتَرَكْنَا يُوسُفَ عِندَ مَتَٰعِنَا فَأَكَلَهُ ٱلذِّئْبُ وَمَآ أَنتَ بِمُؤْمِنٍ لَّنَا وَلَوْ كُنَّا صَٰدِقِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdcxiv{وَجَآءُو عَلَىٰ قَمِيصِهِۦ بِدَمٍ كَذِبٍ قَالَ بَلْ سَوَّلَتْ لَكُمْ أَنفُسُكُمْ أَمْرًا فَصَبْرٌ جَمِيلٌ وَٱللَّهُ ٱلْمُسْتَعَانُ عَلَىٰ مَا تَصِفُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdcxv{وَجَآءَتْ سَيَّارَةٌ فَأَرْسَلُوا۟ وَارِدَهُمْ فَأَدْلَىٰ دَلْوَهُۥ قَالَ يَٰبُشْرَىٰ هَٰذَا غُلَٰمٌ وَأَسَرُّوهُ بِضَٰعَةً وَٱللَّهُ عَلِيمٌۢ بِمَا يَعْمَلُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdcxvi{وَشَرَوْهُ بِثَمَنٍۭ بَخْسٍ دَرَٰهِمَ مَعْدُودَةٍ وَكَانُوا۟ فِيهِ مِنَ ٱلزَّٰهِدِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdcxvii{وَقَالَ ٱلَّذِى ٱشْتَرَىٰهُ مِن مِّصْرَ لِٱمْرَأَتِهِۦٓ أَكْرِمِى مَثْوَىٰهُ عَسَىٰٓ أَن يَنفَعَنَآ أَوْ نَتَّخِذَهُۥ وَلَدًا وَكَذَٰلِكَ مَكَّنَّا لِيُوسُفَ فِى ٱلْأَرْضِ وَلِنُعَلِّمَهُۥ مِن تَأْوِيلِ ٱلْأَحَادِيثِ وَٱللَّهُ غَالِبٌ عَلَىٰٓ أَمْرِهِۦ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdcxviii{وَلَمَّا بَلَغَ أَشُدَّهُۥٓ ءَاتَيْنَٰهُ حُكْمًا وَعِلْمًا وَكَذَٰلِكَ نَجْزِى ٱلْمُحْسِنِينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdcxix{وَرَٰوَدَتْهُ ٱلَّتِى هُوَ فِى بَيْتِهَا عَن نَّفْسِهِۦ وَغَلَّقَتِ ٱلْأَبْوَٰبَ وَقَالَتْ هَيْتَ لَكَ قَالَ مَعَاذَ ٱللَّهِ إِنَّهُۥ رَبِّىٓ أَحْسَنَ مَثْوَاىَ إِنَّهُۥ لَا يُفْلِحُ ٱلظَّٰلِمُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdcxx{وَلَقَدْ هَمَّتْ بِهِۦ وَهَمَّ بِهَا لَوْلَآ أَن رَّءَا بُرْهَٰنَ رَبِّهِۦ كَذَٰلِكَ لِنَصْرِفَ عَنْهُ ٱلسُّوٓءَ وَٱلْفَحْشَآءَ إِنَّهُۥ مِنْ عِبَادِنَا ٱلْمُخْلَصِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdcxxi{وَٱسْتَبَقَا ٱلْبَابَ وَقَدَّتْ قَمِيصَهُۥ مِن دُبُرٍ وَأَلْفَيَا سَيِّدَهَا لَدَا ٱلْبَابِ قَالَتْ مَا جَزَآءُ مَنْ أَرَادَ بِأَهْلِكَ سُوٓءًا إِلَّآ أَن يُسْجَنَ أَوْ عَذَابٌ أَلِيمٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdcxxii{قَالَ هِىَ رَٰوَدَتْنِى عَن نَّفْسِى وَشَهِدَ شَاهِدٌ مِّنْ أَهْلِهَآ إِن كَانَ قَمِيصُهُۥ قُدَّ مِن قُبُلٍ فَصَدَقَتْ وَهُوَ مِنَ ٱلْكَٰذِبِينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdcxxiii{وَإِن كَانَ قَمِيصُهُۥ قُدَّ مِن دُبُرٍ فَكَذَبَتْ وَهُوَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdcxxiv{فَلَمَّا رَءَا قَمِيصَهُۥ قُدَّ مِن دُبُرٍ قَالَ إِنَّهُۥ مِن كَيْدِكُنَّ إِنَّ كَيْدَكُنَّ عَظِيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdcxxv{يُوسُفُ أَعْرِضْ عَنْ هَٰذَا وَٱسْتَغْفِرِى لِذَنۢبِكِ إِنَّكِ كُنتِ مِنَ ٱلْخَاطِـِٔينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdcxxvi{وَقَالَ نِسْوَةٌ فِى ٱلْمَدِينَةِ ٱمْرَأَتُ ٱلْعَزِيزِ تُرَٰوِدُ فَتَىٰهَا عَن نَّفْسِهِۦ قَدْ شَغَفَهَا حُبًّا إِنَّا لَنَرَىٰهَا فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdcxxvii{فَلَمَّا سَمِعَتْ بِمَكْرِهِنَّ أَرْسَلَتْ إِلَيْهِنَّ وَأَعْتَدَتْ لَهُنَّ مُتَّكَـًٔا وَءَاتَتْ كُلَّ وَٰحِدَةٍ مِّنْهُنَّ سِكِّينًا وَقَالَتِ ٱخْرُجْ عَلَيْهِنَّ فَلَمَّا رَأَيْنَهُۥٓ أَكْبَرْنَهُۥ وَقَطَّعْنَ أَيْدِيَهُنَّ وَقُلْنَ حَٰشَ لِلَّهِ مَا هَٰذَا بَشَرًا إِنْ هَٰذَآ إِلَّا مَلَكٌ كَرِيمٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdcxxviii{قَالَتْ فَذَٰلِكُنَّ ٱلَّذِى لُمْتُنَّنِى فِيهِ وَلَقَدْ رَٰوَدتُّهُۥ عَن نَّفْسِهِۦ فَٱسْتَعْصَمَ وَلَئِن لَّمْ يَفْعَلْ مَآ ءَامُرُهُۥ لَيُسْجَنَنَّ وَلَيَكُونًا مِّنَ ٱلصَّٰغِرِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdcxxix{قَالَ رَبِّ ٱلسِّجْنُ أَحَبُّ إِلَىَّ مِمَّا يَدْعُونَنِىٓ إِلَيْهِ وَإِلَّا تَصْرِفْ عَنِّى كَيْدَهُنَّ أَصْبُ إِلَيْهِنَّ وَأَكُن مِّنَ ٱلْجَٰهِلِينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdcxxx{فَٱسْتَجَابَ لَهُۥ رَبُّهُۥ فَصَرَفَ عَنْهُ كَيْدَهُنَّ إِنَّهُۥ هُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdcxxxi{ثُمَّ بَدَا لَهُم مِّنۢ بَعْدِ مَا رَأَوُا۟ ٱلْءَايَٰتِ لَيَسْجُنُنَّهُۥ حَتَّىٰ حِينٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdcxxxii{وَدَخَلَ مَعَهُ ٱلسِّجْنَ فَتَيَانِ قَالَ أَحَدُهُمَآ إِنِّىٓ أَرَىٰنِىٓ أَعْصِرُ خَمْرًا وَقَالَ ٱلْءَاخَرُ إِنِّىٓ أَرَىٰنِىٓ أَحْمِلُ فَوْقَ رَأْسِى خُبْزًا تَأْكُلُ ٱلطَّيْرُ مِنْهُ نَبِّئْنَا بِتَأْوِيلِهِۦٓ إِنَّا نَرَىٰكَ مِنَ ٱلْمُحْسِنِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdcxxxiii{قَالَ لَا يَأْتِيكُمَا طَعَامٌ تُرْزَقَانِهِۦٓ إِلَّا نَبَّأْتُكُمَا بِتَأْوِيلِهِۦ قَبْلَ أَن يَأْتِيَكُمَا ذَٰلِكُمَا مِمَّا عَلَّمَنِى رَبِّىٓ إِنِّى تَرَكْتُ مِلَّةَ قَوْمٍ لَّا يُؤْمِنُونَ بِٱللَّهِ وَهُم بِٱلْءَاخِرَةِ هُمْ كَٰفِرُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdcxxxiv{وَٱتَّبَعْتُ مِلَّةَ ءَابَآءِىٓ إِبْرَٰهِيمَ وَإِسْحَٰقَ وَيَعْقُوبَ مَا كَانَ لَنَآ أَن نُّشْرِكَ بِٱللَّهِ مِن شَىْءٍ ذَٰلِكَ مِن فَضْلِ ٱللَّهِ عَلَيْنَا وَعَلَى ٱلنَّاسِ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَشْكُرُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdcxxxv{يَٰصَىٰحِبَىِ ٱلسِّجْنِ ءَأَرْبَابٌ مُّتَفَرِّقُونَ خَيْرٌ أَمِ ٱللَّهُ ٱلْوَٰحِدُ ٱلْقَهَّارُ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdcxxxvi{مَا تَعْبُدُونَ مِن دُونِهِۦٓ إِلَّآ أَسْمَآءً سَمَّيْتُمُوهَآ أَنتُمْ وَءَابَآؤُكُم مَّآ أَنزَلَ ٱللَّهُ بِهَا مِن سُلْطَٰنٍ إِنِ ٱلْحُكْمُ إِلَّا لِلَّهِ أَمَرَ أَلَّا تَعْبُدُوٓا۟ إِلَّآ إِيَّاهُ ذَٰلِكَ ٱلدِّينُ ٱلْقَيِّمُ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdcxxxvii{يَٰصَىٰحِبَىِ ٱلسِّجْنِ أَمَّآ أَحَدُكُمَا فَيَسْقِى رَبَّهُۥ خَمْرًا وَأَمَّا ٱلْءَاخَرُ فَيُصْلَبُ فَتَأْكُلُ ٱلطَّيْرُ مِن رَّأْسِهِۦ قُضِىَ ٱلْأَمْرُ ٱلَّذِى فِيهِ تَسْتَفْتِيَانِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdcxxxviii{وَقَالَ لِلَّذِى ظَنَّ أَنَّهُۥ نَاجٍ مِّنْهُمَا ٱذْكُرْنِى عِندَ رَبِّكَ فَأَنسَىٰهُ ٱلشَّيْطَٰنُ ذِكْرَ رَبِّهِۦ فَلَبِثَ فِى ٱلسِّجْنِ بِضْعَ سِنِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdcxxxix{وَقَالَ ٱلْمَلِكُ إِنِّىٓ أَرَىٰ سَبْعَ بَقَرَٰتٍ سِمَانٍ يَأْكُلُهُنَّ سَبْعٌ عِجَافٌ وَسَبْعَ سُنۢبُلَٰتٍ خُضْرٍ وَأُخَرَ يَابِسَٰتٍ يَٰٓأَيُّهَا ٱلْمَلَأُ أَفْتُونِى فِى رُءْيَٰىَ إِن كُنتُمْ لِلرُّءْيَا تَعْبُرُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdcxl{قَالُوٓا۟ أَضْغَٰثُ أَحْلَٰمٍ وَمَا نَحْنُ بِتَأْوِيلِ ٱلْأَحْلَٰمِ بِعَٰلِمِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdcxli{وَقَالَ ٱلَّذِى نَجَا مِنْهُمَا وَٱدَّكَرَ بَعْدَ أُمَّةٍ أَنَا۠ أُنَبِّئُكُم بِتَأْوِيلِهِۦ فَأَرْسِلُونِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdcxlii{يُوسُفُ أَيُّهَا ٱلصِّدِّيقُ أَفْتِنَا فِى سَبْعِ بَقَرَٰتٍ سِمَانٍ يَأْكُلُهُنَّ سَبْعٌ عِجَافٌ وَسَبْعِ سُنۢبُلَٰتٍ خُضْرٍ وَأُخَرَ يَابِسَٰتٍ لَّعَلِّىٓ أَرْجِعُ إِلَى ٱلنَّاسِ لَعَلَّهُمْ يَعْلَمُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdcxliii{قَالَ تَزْرَعُونَ سَبْعَ سِنِينَ دَأَبًا فَمَا حَصَدتُّمْ فَذَرُوهُ فِى سُنۢبُلِهِۦٓ إِلَّا قَلِيلًا مِّمَّا تَأْكُلُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdcxliv{ثُمَّ يَأْتِى مِنۢ بَعْدِ ذَٰلِكَ سَبْعٌ شِدَادٌ يَأْكُلْنَ مَا قَدَّمْتُمْ لَهُنَّ إِلَّا قَلِيلًا مِّمَّا تُحْصِنُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdcxlv{ثُمَّ يَأْتِى مِنۢ بَعْدِ ذَٰلِكَ عَامٌ فِيهِ يُغَاثُ ٱلنَّاسُ وَفِيهِ يَعْصِرُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdcxlvi{وَقَالَ ٱلْمَلِكُ ٱئْتُونِى بِهِۦ فَلَمَّا جَآءَهُ ٱلرَّسُولُ قَالَ ٱرْجِعْ إِلَىٰ رَبِّكَ فَسْـَٔلْهُ مَا بَالُ ٱلنِّسْوَةِ ٱلَّٰتِى قَطَّعْنَ أَيْدِيَهُنَّ إِنَّ رَبِّى بِكَيْدِهِنَّ عَلِيمٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdcxlvii{قَالَ مَا خَطْبُكُنَّ إِذْ رَٰوَدتُّنَّ يُوسُفَ عَن نَّفْسِهِۦ قُلْنَ حَٰشَ لِلَّهِ مَا عَلِمْنَا عَلَيْهِ مِن سُوٓءٍ قَالَتِ ٱمْرَأَتُ ٱلْعَزِيزِ ٱلْـَٰٔنَ حَصْحَصَ ٱلْحَقُّ أَنَا۠ رَٰوَدتُّهُۥ عَن نَّفْسِهِۦ وَإِنَّهُۥ لَمِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdcxlviii{ذَٰلِكَ لِيَعْلَمَ أَنِّى لَمْ أَخُنْهُ بِٱلْغَيْبِ وَأَنَّ ٱللَّهَ لَا يَهْدِى كَيْدَ ٱلْخَآئِنِينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdcxlix{وَمَآ أُبَرِّئُ نَفْسِىٓ إِنَّ ٱلنَّفْسَ لَأَمَّارَةٌۢ بِٱلسُّوٓءِ إِلَّا مَا رَحِمَ رَبِّىٓ إِنَّ رَبِّى غَفُورٌ رَّحِيمٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mdcl{وَقَالَ ٱلْمَلِكُ ٱئْتُونِى بِهِۦٓ أَسْتَخْلِصْهُ لِنَفْسِى فَلَمَّا كَلَّمَهُۥ قَالَ إِنَّكَ ٱلْيَوْمَ لَدَيْنَا مَكِينٌ أَمِينٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mdcli{قَالَ ٱجْعَلْنِى عَلَىٰ خَزَآئِنِ ٱلْأَرْضِ إِنِّى حَفِيظٌ عَلِيمٌ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mdclii{وَكَذَٰلِكَ مَكَّنَّا لِيُوسُفَ فِى ٱلْأَرْضِ يَتَبَوَّأُ مِنْهَا حَيْثُ يَشَآءُ نُصِيبُ بِرَحْمَتِنَا مَن نَّشَآءُ وَلَا نُضِيعُ أَجْرَ ٱلْمُحْسِنِينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mdcliii{وَلَأَجْرُ ٱلْءَاخِرَةِ خَيْرٌ لِّلَّذِينَ ءَامَنُوا۟ وَكَانُوا۟ يَتَّقُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mdcliv{وَجَآءَ إِخْوَةُ يُوسُفَ فَدَخَلُوا۟ عَلَيْهِ فَعَرَفَهُمْ وَهُمْ لَهُۥ مُنكِرُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mdclv{وَلَمَّا جَهَّزَهُم بِجَهَازِهِمْ قَالَ ٱئْتُونِى بِأَخٍ لَّكُم مِّنْ أَبِيكُمْ أَلَا تَرَوْنَ أَنِّىٓ أُوفِى ٱلْكَيْلَ وَأَنَا۠ خَيْرُ ٱلْمُنزِلِينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mdclvi{فَإِن لَّمْ تَأْتُونِى بِهِۦ فَلَا كَيْلَ لَكُمْ عِندِى وَلَا تَقْرَبُونِ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mdclvii{قَالُوا۟ سَنُرَٰوِدُ عَنْهُ أَبَاهُ وَإِنَّا لَفَٰعِلُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mdclviii{وَقَالَ لِفِتْيَٰنِهِ ٱجْعَلُوا۟ بِضَٰعَتَهُمْ فِى رِحَالِهِمْ لَعَلَّهُمْ يَعْرِفُونَهَآ إِذَا ٱنقَلَبُوٓا۟ إِلَىٰٓ أَهْلِهِمْ لَعَلَّهُمْ يَرْجِعُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mdclix{فَلَمَّا رَجَعُوٓا۟ إِلَىٰٓ أَبِيهِمْ قَالُوا۟ يَٰٓأَبَانَا مُنِعَ مِنَّا ٱلْكَيْلُ فَأَرْسِلْ مَعَنَآ أَخَانَا نَكْتَلْ وَإِنَّا لَهُۥ لَحَٰفِظُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mdclx{قَالَ هَلْ ءَامَنُكُمْ عَلَيْهِ إِلَّا كَمَآ أَمِنتُكُمْ عَلَىٰٓ أَخِيهِ مِن قَبْلُ فَٱللَّهُ خَيْرٌ حَٰفِظًا وَهُوَ أَرْحَمُ ٱلرَّٰحِمِينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mdclxi{وَلَمَّا فَتَحُوا۟ مَتَٰعَهُمْ وَجَدُوا۟ بِضَٰعَتَهُمْ رُدَّتْ إِلَيْهِمْ قَالُوا۟ يَٰٓأَبَانَا مَا نَبْغِى هَٰذِهِۦ بِضَٰعَتُنَا رُدَّتْ إِلَيْنَا وَنَمِيرُ أَهْلَنَا وَنَحْفَظُ أَخَانَا وَنَزْدَادُ كَيْلَ بَعِيرٍ ذَٰلِكَ كَيْلٌ يَسِيرٌ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mdclxii{قَالَ لَنْ أُرْسِلَهُۥ مَعَكُمْ حَتَّىٰ تُؤْتُونِ مَوْثِقًا مِّنَ ٱللَّهِ لَتَأْتُنَّنِى بِهِۦٓ إِلَّآ أَن يُحَاطَ بِكُمْ فَلَمَّآ ءَاتَوْهُ مَوْثِقَهُمْ قَالَ ٱللَّهُ عَلَىٰ مَا نَقُولُ وَكِيلٌ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mdclxiii{وَقَالَ يَٰبَنِىَّ لَا تَدْخُلُوا۟ مِنۢ بَابٍ وَٰحِدٍ وَٱدْخُلُوا۟ مِنْ أَبْوَٰبٍ مُّتَفَرِّقَةٍ وَمَآ أُغْنِى عَنكُم مِّنَ ٱللَّهِ مِن شَىْءٍ إِنِ ٱلْحُكْمُ إِلَّا لِلَّهِ عَلَيْهِ تَوَكَّلْتُ وَعَلَيْهِ فَلْيَتَوَكَّلِ ٱلْمُتَوَكِّلُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mdclxiv{وَلَمَّا دَخَلُوا۟ مِنْ حَيْثُ أَمَرَهُمْ أَبُوهُم مَّا كَانَ يُغْنِى عَنْهُم مِّنَ ٱللَّهِ مِن شَىْءٍ إِلَّا حَاجَةً فِى نَفْسِ يَعْقُوبَ قَضَىٰهَا وَإِنَّهُۥ لَذُو عِلْمٍ لِّمَا عَلَّمْنَٰهُ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mdclxv{وَلَمَّا دَخَلُوا۟ عَلَىٰ يُوسُفَ ءَاوَىٰٓ إِلَيْهِ أَخَاهُ قَالَ إِنِّىٓ أَنَا۠ أَخُوكَ فَلَا تَبْتَئِسْ بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mdclxvi{فَلَمَّا جَهَّزَهُم بِجَهَازِهِمْ جَعَلَ ٱلسِّقَايَةَ فِى رَحْلِ أَخِيهِ ثُمَّ أَذَّنَ مُؤَذِّنٌ أَيَّتُهَا ٱلْعِيرُ إِنَّكُمْ لَسَٰرِقُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mdclxvii{قَالُوا۟ وَأَقْبَلُوا۟ عَلَيْهِم مَّاذَا تَفْقِدُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mdclxviii{قَالُوا۟ نَفْقِدُ صُوَاعَ ٱلْمَلِكِ وَلِمَن جَآءَ بِهِۦ حِمْلُ بَعِيرٍ وَأَنَا۠ بِهِۦ زَعِيمٌ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mdclxix{قَالُوا۟ تَٱللَّهِ لَقَدْ عَلِمْتُم مَّا جِئْنَا لِنُفْسِدَ فِى ٱلْأَرْضِ وَمَا كُنَّا سَٰرِقِينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mdclxx{قَالُوا۟ فَمَا جَزَٰٓؤُهُۥٓ إِن كُنتُمْ كَٰذِبِينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mdclxxi{قَالُوا۟ جَزَٰٓؤُهُۥ مَن وُجِدَ فِى رَحْلِهِۦ فَهُوَ جَزَٰٓؤُهُۥ كَذَٰلِكَ نَجْزِى ٱلظَّٰلِمِينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mdclxxii{فَبَدَأَ بِأَوْعِيَتِهِمْ قَبْلَ وِعَآءِ أَخِيهِ ثُمَّ ٱسْتَخْرَجَهَا مِن وِعَآءِ أَخِيهِ كَذَٰلِكَ كِدْنَا لِيُوسُفَ مَا كَانَ لِيَأْخُذَ أَخَاهُ فِى دِينِ ٱلْمَلِكِ إِلَّآ أَن يَشَآءَ ٱللَّهُ نَرْفَعُ دَرَجَٰتٍ مَّن نَّشَآءُ وَفَوْقَ كُلِّ ذِى عِلْمٍ عَلِيمٌ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mdclxxiii{قَالُوٓا۟ إِن يَسْرِقْ فَقَدْ سَرَقَ أَخٌ لَّهُۥ مِن قَبْلُ فَأَسَرَّهَا يُوسُفُ فِى نَفْسِهِۦ وَلَمْ يُبْدِهَا لَهُمْ قَالَ أَنتُمْ شَرٌّ مَّكَانًا وَٱللَّهُ أَعْلَمُ بِمَا تَصِفُونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mdclxxiv{قَالُوا۟ يَٰٓأَيُّهَا ٱلْعَزِيزُ إِنَّ لَهُۥٓ أَبًا شَيْخًا كَبِيرًا فَخُذْ أَحَدَنَا مَكَانَهُۥٓ إِنَّا نَرَىٰكَ مِنَ ٱلْمُحْسِنِينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mdclxxv{قَالَ مَعَاذَ ٱللَّهِ أَن نَّأْخُذَ إِلَّا مَن وَجَدْنَا مَتَٰعَنَا عِندَهُۥٓ إِنَّآ إِذًا لَّظَٰلِمُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mdclxxvi{فَلَمَّا ٱسْتَيْـَٔسُوا۟ مِنْهُ خَلَصُوا۟ نَجِيًّا قَالَ كَبِيرُهُمْ أَلَمْ تَعْلَمُوٓا۟ أَنَّ أَبَاكُمْ قَدْ أَخَذَ عَلَيْكُم مَّوْثِقًا مِّنَ ٱللَّهِ وَمِن قَبْلُ مَا فَرَّطتُمْ فِى يُوسُفَ فَلَنْ أَبْرَحَ ٱلْأَرْضَ حَتَّىٰ يَأْذَنَ لِىٓ أَبِىٓ أَوْ يَحْكُمَ ٱللَّهُ لِى وَهُوَ خَيْرُ ٱلْحَٰكِمِينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mdclxxvii{ٱرْجِعُوٓا۟ إِلَىٰٓ أَبِيكُمْ فَقُولُوا۟ يَٰٓأَبَانَآ إِنَّ ٱبْنَكَ سَرَقَ وَمَا شَهِدْنَآ إِلَّا بِمَا عَلِمْنَا وَمَا كُنَّا لِلْغَيْبِ حَٰفِظِينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mdclxxviii{وَسْـَٔلِ ٱلْقَرْيَةَ ٱلَّتِى كُنَّا فِيهَا وَٱلْعِيرَ ٱلَّتِىٓ أَقْبَلْنَا فِيهَا وَإِنَّا لَصَٰدِقُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mdclxxix{قَالَ بَلْ سَوَّلَتْ لَكُمْ أَنفُسُكُمْ أَمْرًا فَصَبْرٌ جَمِيلٌ عَسَى ٱللَّهُ أَن يَأْتِيَنِى بِهِمْ جَمِيعًا إِنَّهُۥ هُوَ ٱلْعَلِيمُ ٱلْحَكِيمُ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mdclxxx{وَتَوَلَّىٰ عَنْهُمْ وَقَالَ يَٰٓأَسَفَىٰ عَلَىٰ يُوسُفَ وَٱبْيَضَّتْ عَيْنَاهُ مِنَ ٱلْحُزْنِ فَهُوَ كَظِيمٌ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mdclxxxi{قَالُوا۟ تَٱللَّهِ تَفْتَؤُا۟ تَذْكُرُ يُوسُفَ حَتَّىٰ تَكُونَ حَرَضًا أَوْ تَكُونَ مِنَ ٱلْهَٰلِكِينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mdclxxxii{قَالَ إِنَّمَآ أَشْكُوا۟ بَثِّى وَحُزْنِىٓ إِلَى ٱللَّهِ وَأَعْلَمُ مِنَ ٱللَّهِ مَا لَا تَعْلَمُونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mdclxxxiii{يَٰبَنِىَّ ٱذْهَبُوا۟ فَتَحَسَّسُوا۟ مِن يُوسُفَ وَأَخِيهِ وَلَا تَا۟يْـَٔسُوا۟ مِن رَّوْحِ ٱللَّهِ إِنَّهُۥ لَا يَا۟يْـَٔسُ مِن رَّوْحِ ٱللَّهِ إِلَّا ٱلْقَوْمُ ٱلْكَٰفِرُونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mdclxxxiv{فَلَمَّا دَخَلُوا۟ عَلَيْهِ قَالُوا۟ يَٰٓأَيُّهَا ٱلْعَزِيزُ مَسَّنَا وَأَهْلَنَا ٱلضُّرُّ وَجِئْنَا بِبِضَٰعَةٍ مُّزْجَىٰةٍ فَأَوْفِ لَنَا ٱلْكَيْلَ وَتَصَدَّقْ عَلَيْنَآ إِنَّ ٱللَّهَ يَجْزِى ٱلْمُتَصَدِّقِينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mdclxxxv{قَالَ هَلْ عَلِمْتُم مَّا فَعَلْتُم بِيُوسُفَ وَأَخِيهِ إِذْ أَنتُمْ جَٰهِلُونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mdclxxxvi{قَالُوٓا۟ أَءِنَّكَ لَأَنتَ يُوسُفُ قَالَ أَنَا۠ يُوسُفُ وَهَٰذَآ أَخِى قَدْ مَنَّ ٱللَّهُ عَلَيْنَآ إِنَّهُۥ مَن يَتَّقِ وَيَصْبِرْ فَإِنَّ ٱللَّهَ لَا يُضِيعُ أَجْرَ ٱلْمُحْسِنِينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mdclxxxvii{قَالُوا۟ تَٱللَّهِ لَقَدْ ءَاثَرَكَ ٱللَّهُ عَلَيْنَا وَإِن كُنَّا لَخَٰطِـِٔينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mdclxxxviii{قَالَ لَا تَثْرِيبَ عَلَيْكُمُ ٱلْيَوْمَ يَغْفِرُ ٱللَّهُ لَكُمْ وَهُوَ أَرْحَمُ ٱلرَّٰحِمِينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mdclxxxix{ٱذْهَبُوا۟ بِقَمِيصِى هَٰذَا فَأَلْقُوهُ عَلَىٰ وَجْهِ أَبِى يَأْتِ بَصِيرًا وَأْتُونِى بِأَهْلِكُمْ أَجْمَعِينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mdcxc{وَلَمَّا فَصَلَتِ ٱلْعِيرُ قَالَ أَبُوهُمْ إِنِّى لَأَجِدُ رِيحَ يُوسُفَ لَوْلَآ أَن تُفَنِّدُونِ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mdcxci{قَالُوا۟ تَٱللَّهِ إِنَّكَ لَفِى ضَلَٰلِكَ ٱلْقَدِيمِ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mdcxcii{فَلَمَّآ أَن جَآءَ ٱلْبَشِيرُ أَلْقَىٰهُ عَلَىٰ وَجْهِهِۦ فَٱرْتَدَّ بَصِيرًا قَالَ أَلَمْ أَقُل لَّكُمْ إِنِّىٓ أَعْلَمُ مِنَ ٱللَّهِ مَا لَا تَعْلَمُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mdcxciii{قَالُوا۟ يَٰٓأَبَانَا ٱسْتَغْفِرْ لَنَا ذُنُوبَنَآ إِنَّا كُنَّا خَٰطِـِٔينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mdcxciv{قَالَ سَوْفَ أَسْتَغْفِرُ لَكُمْ رَبِّىٓ إِنَّهُۥ هُوَ ٱلْغَفُورُ ٱلرَّحِيمُ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mdcxcv{فَلَمَّا دَخَلُوا۟ عَلَىٰ يُوسُفَ ءَاوَىٰٓ إِلَيْهِ أَبَوَيْهِ وَقَالَ ٱدْخُلُوا۟ مِصْرَ إِن شَآءَ ٱللَّهُ ءَامِنِينَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mdcxcvi{وَرَفَعَ أَبَوَيْهِ عَلَى ٱلْعَرْشِ وَخَرُّوا۟ لَهُۥ سُجَّدًا وَقَالَ يَٰٓأَبَتِ هَٰذَا تَأْوِيلُ رُءْيَٰىَ مِن قَبْلُ قَدْ جَعَلَهَا رَبِّى حَقًّا وَقَدْ أَحْسَنَ بِىٓ إِذْ أَخْرَجَنِى مِنَ ٱلسِّجْنِ وَجَآءَ بِكُم مِّنَ ٱلْبَدْوِ مِنۢ بَعْدِ أَن نَّزَغَ ٱلشَّيْطَٰنُ بَيْنِى وَبَيْنَ إِخْوَتِىٓ إِنَّ رَبِّى لَطِيفٌ لِّمَا يَشَآءُ إِنَّهُۥ هُوَ ٱلْعَلِيمُ ٱلْحَكِيمُ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mdcxcvii{رَبِّ قَدْ ءَاتَيْتَنِى مِنَ ٱلْمُلْكِ وَعَلَّمْتَنِى مِن تَأْوِيلِ ٱلْأَحَادِيثِ فَاطِرَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ أَنتَ وَلِىِّۦ فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ تَوَفَّنِى مُسْلِمًا وَأَلْحِقْنِى بِٱلصَّٰلِحِينَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mdcxcviii{ذَٰلِكَ مِنْ أَنۢبَآءِ ٱلْغَيْبِ نُوحِيهِ إِلَيْكَ وَمَا كُنتَ لَدَيْهِمْ إِذْ أَجْمَعُوٓا۟ أَمْرَهُمْ وَهُمْ يَمْكُرُونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mdcxcix{وَمَآ أَكْثَرُ ٱلنَّاسِ وَلَوْ حَرَصْتَ بِمُؤْمِنِينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mdcc{وَمَا تَسْـَٔلُهُمْ عَلَيْهِ مِنْ أَجْرٍ إِنْ هُوَ إِلَّا ذِكْرٌ لِّلْعَٰلَمِينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mdcci{وَكَأَيِّن مِّنْ ءَايَةٍ فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ يَمُرُّونَ عَلَيْهَا وَهُمْ عَنْهَا مُعْرِضُونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mdccii{وَمَا يُؤْمِنُ أَكْثَرُهُم بِٱللَّهِ إِلَّا وَهُم مُّشْرِكُونَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mdcciii{أَفَأَمِنُوٓا۟ أَن تَأْتِيَهُمْ غَٰشِيَةٌ مِّنْ عَذَابِ ٱللَّهِ أَوْ تَأْتِيَهُمُ ٱلسَّاعَةُ بَغْتَةً وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mdcciv{قُلْ هَٰذِهِۦ سَبِيلِىٓ أَدْعُوٓا۟ إِلَى ٱللَّهِ عَلَىٰ بَصِيرَةٍ أَنَا۠ وَمَنِ ٱتَّبَعَنِى وَسُبْحَٰنَ ٱللَّهِ وَمَآ أَنَا۠ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mdccv{وَمَآ أَرْسَلْنَا مِن قَبْلِكَ إِلَّا رِجَالًا نُّوحِىٓ إِلَيْهِم مِّنْ أَهْلِ ٱلْقُرَىٰٓ أَفَلَمْ يَسِيرُوا۟ فِى ٱلْأَرْضِ فَيَنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلَّذِينَ مِن قَبْلِهِمْ وَلَدَارُ ٱلْءَاخِرَةِ خَيْرٌ لِّلَّذِينَ ٱتَّقَوْا۟ أَفَلَا تَعْقِلُونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mdccvi{حَتَّىٰٓ إِذَا ٱسْتَيْـَٔسَ ٱلرُّسُلُ وَظَنُّوٓا۟ أَنَّهُمْ قَدْ كُذِبُوا۟ جَآءَهُمْ نَصْرُنَا فَنُجِّىَ مَن نَّشَآءُ وَلَا يُرَدُّ بَأْسُنَا عَنِ ٱلْقَوْمِ ٱلْمُجْرِمِينَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mdccvii{لَقَدْ كَانَ فِى قَصَصِهِمْ عِبْرَةٌ لِّأُو۟لِى ٱلْأَلْبَٰبِ مَا كَانَ حَدِيثًا يُفْتَرَىٰ وَلَٰكِن تَصْدِيقَ ٱلَّذِى بَيْنَ يَدَيْهِ وَتَفْصِيلَ كُلِّ شَىْءٍ وَهُدًى وَرَحْمَةً لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mdccviii{\basmalah الٓمٓر تِلْكَ ءَايَٰتُ ٱلْكِتَٰبِ وَٱلَّذِىٓ أُنزِلَ إِلَيْكَ مِن رَّبِّكَ ٱلْحَقُّ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يُؤْمِنُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdccix{ٱللَّهُ ٱلَّذِى رَفَعَ ٱلسَّمَٰوَٰتِ بِغَيْرِ عَمَدٍ تَرَوْنَهَا ثُمَّ ٱسْتَوَىٰ عَلَى ٱلْعَرْشِ وَسَخَّرَ ٱلشَّمْسَ وَٱلْقَمَرَ كُلٌّ يَجْرِى لِأَجَلٍ مُّسَمًّى يُدَبِّرُ ٱلْأَمْرَ يُفَصِّلُ ٱلْءَايَٰتِ لَعَلَّكُم بِلِقَآءِ رَبِّكُمْ تُوقِنُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdccx{وَهُوَ ٱلَّذِى مَدَّ ٱلْأَرْضَ وَجَعَلَ فِيهَا رَوَٰسِىَ وَأَنْهَٰرًا وَمِن كُلِّ ٱلثَّمَرَٰتِ جَعَلَ فِيهَا زَوْجَيْنِ ٱثْنَيْنِ يُغْشِى ٱلَّيْلَ ٱلنَّهَارَ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يَتَفَكَّرُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdccxi{وَفِى ٱلْأَرْضِ قِطَعٌ مُّتَجَٰوِرَٰتٌ وَجَنَّٰتٌ مِّنْ أَعْنَٰبٍ وَزَرْعٌ وَنَخِيلٌ صِنْوَانٌ وَغَيْرُ صِنْوَانٍ يُسْقَىٰ بِمَآءٍ وَٰحِدٍ وَنُفَضِّلُ بَعْضَهَا عَلَىٰ بَعْضٍ فِى ٱلْأُكُلِ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يَعْقِلُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdccxii{وَإِن تَعْجَبْ فَعَجَبٌ قَوْلُهُمْ أَءِذَا كُنَّا تُرَٰبًا أَءِنَّا لَفِى خَلْقٍ جَدِيدٍ أُو۟لَٰٓئِكَ ٱلَّذِينَ كَفَرُوا۟ بِرَبِّهِمْ وَأُو۟لَٰٓئِكَ ٱلْأَغْلَٰلُ فِىٓ أَعْنَاقِهِمْ وَأُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdccxiii{وَيَسْتَعْجِلُونَكَ بِٱلسَّيِّئَةِ قَبْلَ ٱلْحَسَنَةِ وَقَدْ خَلَتْ مِن قَبْلِهِمُ ٱلْمَثُلَٰتُ وَإِنَّ رَبَّكَ لَذُو مَغْفِرَةٍ لِّلنَّاسِ عَلَىٰ ظُلْمِهِمْ وَإِنَّ رَبَّكَ لَشَدِيدُ ٱلْعِقَابِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdccxiv{وَيَقُولُ ٱلَّذِينَ كَفَرُوا۟ لَوْلَآ أُنزِلَ عَلَيْهِ ءَايَةٌ مِّن رَّبِّهِۦٓ إِنَّمَآ أَنتَ مُنذِرٌ وَلِكُلِّ قَوْمٍ هَادٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdccxv{ٱللَّهُ يَعْلَمُ مَا تَحْمِلُ كُلُّ أُنثَىٰ وَمَا تَغِيضُ ٱلْأَرْحَامُ وَمَا تَزْدَادُ وَكُلُّ شَىْءٍ عِندَهُۥ بِمِقْدَارٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdccxvi{عَٰلِمُ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ ٱلْكَبِيرُ ٱلْمُتَعَالِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdccxvii{سَوَآءٌ مِّنكُم مَّنْ أَسَرَّ ٱلْقَوْلَ وَمَن جَهَرَ بِهِۦ وَمَنْ هُوَ مُسْتَخْفٍۭ بِٱلَّيْلِ وَسَارِبٌۢ بِٱلنَّهَارِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdccxviii{لَهُۥ مُعَقِّبَٰتٌ مِّنۢ بَيْنِ يَدَيْهِ وَمِنْ خَلْفِهِۦ يَحْفَظُونَهُۥ مِنْ أَمْرِ ٱللَّهِ إِنَّ ٱللَّهَ لَا يُغَيِّرُ مَا بِقَوْمٍ حَتَّىٰ يُغَيِّرُوا۟ مَا بِأَنفُسِهِمْ وَإِذَآ أَرَادَ ٱللَّهُ بِقَوْمٍ سُوٓءًا فَلَا مَرَدَّ لَهُۥ وَمَا لَهُم مِّن دُونِهِۦ مِن وَالٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdccxix{هُوَ ٱلَّذِى يُرِيكُمُ ٱلْبَرْقَ خَوْفًا وَطَمَعًا وَيُنشِئُ ٱلسَّحَابَ ٱلثِّقَالَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdccxx{وَيُسَبِّحُ ٱلرَّعْدُ بِحَمْدِهِۦ وَٱلْمَلَٰٓئِكَةُ مِنْ خِيفَتِهِۦ وَيُرْسِلُ ٱلصَّوَٰعِقَ فَيُصِيبُ بِهَا مَن يَشَآءُ وَهُمْ يُجَٰدِلُونَ فِى ٱللَّهِ وَهُوَ شَدِيدُ ٱلْمِحَالِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdccxxi{لَهُۥ دَعْوَةُ ٱلْحَقِّ وَٱلَّذِينَ يَدْعُونَ مِن دُونِهِۦ لَا يَسْتَجِيبُونَ لَهُم بِشَىْءٍ إِلَّا كَبَٰسِطِ كَفَّيْهِ إِلَى ٱلْمَآءِ لِيَبْلُغَ فَاهُ وَمَا هُوَ بِبَٰلِغِهِۦ وَمَا دُعَآءُ ٱلْكَٰفِرِينَ إِلَّا فِى ضَلَٰلٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdccxxii{وَلِلَّهِ يَسْجُدُ مَن فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ طَوْعًا وَكَرْهًا وَظِلَٰلُهُم بِٱلْغُدُوِّ وَٱلْءَاصَالِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdccxxiii{قُلْ مَن رَّبُّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ قُلِ ٱللَّهُ قُلْ أَفَٱتَّخَذْتُم مِّن دُونِهِۦٓ أَوْلِيَآءَ لَا يَمْلِكُونَ لِأَنفُسِهِمْ نَفْعًا وَلَا ضَرًّا قُلْ هَلْ يَسْتَوِى ٱلْأَعْمَىٰ وَٱلْبَصِيرُ أَمْ هَلْ تَسْتَوِى ٱلظُّلُمَٰتُ وَٱلنُّورُ أَمْ جَعَلُوا۟ لِلَّهِ شُرَكَآءَ خَلَقُوا۟ كَخَلْقِهِۦ فَتَشَٰبَهَ ٱلْخَلْقُ عَلَيْهِمْ قُلِ ٱللَّهُ خَٰلِقُ كُلِّ شَىْءٍ وَهُوَ ٱلْوَٰحِدُ ٱلْقَهَّٰرُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdccxxiv{أَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً فَسَالَتْ أَوْدِيَةٌۢ بِقَدَرِهَا فَٱحْتَمَلَ ٱلسَّيْلُ زَبَدًا رَّابِيًا وَمِمَّا يُوقِدُونَ عَلَيْهِ فِى ٱلنَّارِ ٱبْتِغَآءَ حِلْيَةٍ أَوْ مَتَٰعٍ زَبَدٌ مِّثْلُهُۥ كَذَٰلِكَ يَضْرِبُ ٱللَّهُ ٱلْحَقَّ وَٱلْبَٰطِلَ فَأَمَّا ٱلزَّبَدُ فَيَذْهَبُ جُفَآءً وَأَمَّا مَا يَنفَعُ ٱلنَّاسَ فَيَمْكُثُ فِى ٱلْأَرْضِ كَذَٰلِكَ يَضْرِبُ ٱللَّهُ ٱلْأَمْثَالَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdccxxv{لِلَّذِينَ ٱسْتَجَابُوا۟ لِرَبِّهِمُ ٱلْحُسْنَىٰ وَٱلَّذِينَ لَمْ يَسْتَجِيبُوا۟ لَهُۥ لَوْ أَنَّ لَهُم مَّا فِى ٱلْأَرْضِ جَمِيعًا وَمِثْلَهُۥ مَعَهُۥ لَٱفْتَدَوْا۟ بِهِۦٓ أُو۟لَٰٓئِكَ لَهُمْ سُوٓءُ ٱلْحِسَابِ وَمَأْوَىٰهُمْ جَهَنَّمُ وَبِئْسَ ٱلْمِهَادُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdccxxvi{أَفَمَن يَعْلَمُ أَنَّمَآ أُنزِلَ إِلَيْكَ مِن رَّبِّكَ ٱلْحَقُّ كَمَنْ هُوَ أَعْمَىٰٓ إِنَّمَا يَتَذَكَّرُ أُو۟لُوا۟ ٱلْأَلْبَٰبِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdccxxvii{ٱلَّذِينَ يُوفُونَ بِعَهْدِ ٱللَّهِ وَلَا يَنقُضُونَ ٱلْمِيثَٰقَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdccxxviii{وَٱلَّذِينَ يَصِلُونَ مَآ أَمَرَ ٱللَّهُ بِهِۦٓ أَن يُوصَلَ وَيَخْشَوْنَ رَبَّهُمْ وَيَخَافُونَ سُوٓءَ ٱلْحِسَابِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdccxxix{وَٱلَّذِينَ صَبَرُوا۟ ٱبْتِغَآءَ وَجْهِ رَبِّهِمْ وَأَقَامُوا۟ ٱلصَّلَوٰةَ وَأَنفَقُوا۟ مِمَّا رَزَقْنَٰهُمْ سِرًّا وَعَلَانِيَةً وَيَدْرَءُونَ بِٱلْحَسَنَةِ ٱلسَّيِّئَةَ أُو۟لَٰٓئِكَ لَهُمْ عُقْبَى ٱلدَّارِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdccxxx{جَنَّٰتُ عَدْنٍ يَدْخُلُونَهَا وَمَن صَلَحَ مِنْ ءَابَآئِهِمْ وَأَزْوَٰجِهِمْ وَذُرِّيَّٰتِهِمْ وَٱلْمَلَٰٓئِكَةُ يَدْخُلُونَ عَلَيْهِم مِّن كُلِّ بَابٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdccxxxi{سَلَٰمٌ عَلَيْكُم بِمَا صَبَرْتُمْ فَنِعْمَ عُقْبَى ٱلدَّارِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdccxxxii{وَٱلَّذِينَ يَنقُضُونَ عَهْدَ ٱللَّهِ مِنۢ بَعْدِ مِيثَٰقِهِۦ وَيَقْطَعُونَ مَآ أَمَرَ ٱللَّهُ بِهِۦٓ أَن يُوصَلَ وَيُفْسِدُونَ فِى ٱلْأَرْضِ أُو۟لَٰٓئِكَ لَهُمُ ٱللَّعْنَةُ وَلَهُمْ سُوٓءُ ٱلدَّارِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdccxxxiii{ٱللَّهُ يَبْسُطُ ٱلرِّزْقَ لِمَن يَشَآءُ وَيَقْدِرُ وَفَرِحُوا۟ بِٱلْحَيَوٰةِ ٱلدُّنْيَا وَمَا ٱلْحَيَوٰةُ ٱلدُّنْيَا فِى ٱلْءَاخِرَةِ إِلَّا مَتَٰعٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdccxxxiv{وَيَقُولُ ٱلَّذِينَ كَفَرُوا۟ لَوْلَآ أُنزِلَ عَلَيْهِ ءَايَةٌ مِّن رَّبِّهِۦ قُلْ إِنَّ ٱللَّهَ يُضِلُّ مَن يَشَآءُ وَيَهْدِىٓ إِلَيْهِ مَنْ أَنَابَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdccxxxv{ٱلَّذِينَ ءَامَنُوا۟ وَتَطْمَئِنُّ قُلُوبُهُم بِذِكْرِ ٱللَّهِ أَلَا بِذِكْرِ ٱللَّهِ تَطْمَئِنُّ ٱلْقُلُوبُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdccxxxvi{ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ طُوبَىٰ لَهُمْ وَحُسْنُ مَـَٔابٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdccxxxvii{كَذَٰلِكَ أَرْسَلْنَٰكَ فِىٓ أُمَّةٍ قَدْ خَلَتْ مِن قَبْلِهَآ أُمَمٌ لِّتَتْلُوَا۟ عَلَيْهِمُ ٱلَّذِىٓ أَوْحَيْنَآ إِلَيْكَ وَهُمْ يَكْفُرُونَ بِٱلرَّحْمَٰنِ قُلْ هُوَ رَبِّى لَآ إِلَٰهَ إِلَّا هُوَ عَلَيْهِ تَوَكَّلْتُ وَإِلَيْهِ مَتَابِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdccxxxviii{وَلَوْ أَنَّ قُرْءَانًا سُيِّرَتْ بِهِ ٱلْجِبَالُ أَوْ قُطِّعَتْ بِهِ ٱلْأَرْضُ أَوْ كُلِّمَ بِهِ ٱلْمَوْتَىٰ بَل لِّلَّهِ ٱلْأَمْرُ جَمِيعًا أَفَلَمْ يَا۟يْـَٔسِ ٱلَّذِينَ ءَامَنُوٓا۟ أَن لَّوْ يَشَآءُ ٱللَّهُ لَهَدَى ٱلنَّاسَ جَمِيعًا وَلَا يَزَالُ ٱلَّذِينَ كَفَرُوا۟ تُصِيبُهُم بِمَا صَنَعُوا۟ قَارِعَةٌ أَوْ تَحُلُّ قَرِيبًا مِّن دَارِهِمْ حَتَّىٰ يَأْتِىَ وَعْدُ ٱللَّهِ إِنَّ ٱللَّهَ لَا يُخْلِفُ ٱلْمِيعَادَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdccxxxix{وَلَقَدِ ٱسْتُهْزِئَ بِرُسُلٍ مِّن قَبْلِكَ فَأَمْلَيْتُ لِلَّذِينَ كَفَرُوا۟ ثُمَّ أَخَذْتُهُمْ فَكَيْفَ كَانَ عِقَابِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdccxl{أَفَمَنْ هُوَ قَآئِمٌ عَلَىٰ كُلِّ نَفْسٍۭ بِمَا كَسَبَتْ وَجَعَلُوا۟ لِلَّهِ شُرَكَآءَ قُلْ سَمُّوهُمْ أَمْ تُنَبِّـُٔونَهُۥ بِمَا لَا يَعْلَمُ فِى ٱلْأَرْضِ أَم بِظَٰهِرٍ مِّنَ ٱلْقَوْلِ بَلْ زُيِّنَ لِلَّذِينَ كَفَرُوا۟ مَكْرُهُمْ وَصُدُّوا۟ عَنِ ٱلسَّبِيلِ وَمَن يُضْلِلِ ٱللَّهُ فَمَا لَهُۥ مِنْ هَادٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdccxli{لَّهُمْ عَذَابٌ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَلَعَذَابُ ٱلْءَاخِرَةِ أَشَقُّ وَمَا لَهُم مِّنَ ٱللَّهِ مِن وَاقٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdccxlii{مَّثَلُ ٱلْجَنَّةِ ٱلَّتِى وُعِدَ ٱلْمُتَّقُونَ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ أُكُلُهَا دَآئِمٌ وَظِلُّهَا تِلْكَ عُقْبَى ٱلَّذِينَ ٱتَّقَوا۟ وَّعُقْبَى ٱلْكَٰفِرِينَ ٱلنَّارُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdccxliii{وَٱلَّذِينَ ءَاتَيْنَٰهُمُ ٱلْكِتَٰبَ يَفْرَحُونَ بِمَآ أُنزِلَ إِلَيْكَ وَمِنَ ٱلْأَحْزَابِ مَن يُنكِرُ بَعْضَهُۥ قُلْ إِنَّمَآ أُمِرْتُ أَنْ أَعْبُدَ ٱللَّهَ وَلَآ أُشْرِكَ بِهِۦٓ إِلَيْهِ أَدْعُوا۟ وَإِلَيْهِ مَـَٔابِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdccxliv{وَكَذَٰلِكَ أَنزَلْنَٰهُ حُكْمًا عَرَبِيًّا وَلَئِنِ ٱتَّبَعْتَ أَهْوَآءَهُم بَعْدَمَا جَآءَكَ مِنَ ٱلْعِلْمِ مَا لَكَ مِنَ ٱللَّهِ مِن وَلِىٍّ وَلَا وَاقٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdccxlv{وَلَقَدْ أَرْسَلْنَا رُسُلًا مِّن قَبْلِكَ وَجَعَلْنَا لَهُمْ أَزْوَٰجًا وَذُرِّيَّةً وَمَا كَانَ لِرَسُولٍ أَن يَأْتِىَ بِـَٔايَةٍ إِلَّا بِإِذْنِ ٱللَّهِ لِكُلِّ أَجَلٍ كِتَابٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdccxlvi{يَمْحُوا۟ ٱللَّهُ مَا يَشَآءُ وَيُثْبِتُ وَعِندَهُۥٓ أُمُّ ٱلْكِتَٰبِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdccxlvii{وَإِن مَّا نُرِيَنَّكَ بَعْضَ ٱلَّذِى نَعِدُهُمْ أَوْ نَتَوَفَّيَنَّكَ فَإِنَّمَا عَلَيْكَ ٱلْبَلَٰغُ وَعَلَيْنَا ٱلْحِسَابُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdccxlviii{أَوَلَمْ يَرَوْا۟ أَنَّا نَأْتِى ٱلْأَرْضَ نَنقُصُهَا مِنْ أَطْرَافِهَا وَٱللَّهُ يَحْكُمُ لَا مُعَقِّبَ لِحُكْمِهِۦ وَهُوَ سَرِيعُ ٱلْحِسَابِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdccxlix{وَقَدْ مَكَرَ ٱلَّذِينَ مِن قَبْلِهِمْ فَلِلَّهِ ٱلْمَكْرُ جَمِيعًا يَعْلَمُ مَا تَكْسِبُ كُلُّ نَفْسٍ وَسَيَعْلَمُ ٱلْكُفَّٰرُ لِمَنْ عُقْبَى ٱلدَّارِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdccl{وَيَقُولُ ٱلَّذِينَ كَفَرُوا۟ لَسْتَ مُرْسَلًا قُلْ كَفَىٰ بِٱللَّهِ شَهِيدًۢا بَيْنِى وَبَيْنَكُمْ وَمَنْ عِندَهُۥ عِلْمُ ٱلْكِتَٰبِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdccli{\basmalah الٓر كِتَٰبٌ أَنزَلْنَٰهُ إِلَيْكَ لِتُخْرِجَ ٱلنَّاسَ مِنَ ٱلظُّلُمَٰتِ إِلَى ٱلنُّورِ بِإِذْنِ رَبِّهِمْ إِلَىٰ صِرَٰطِ ٱلْعَزِيزِ ٱلْحَمِيدِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdcclii{ٱللَّهِ ٱلَّذِى لَهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَوَيْلٌ لِّلْكَٰفِرِينَ مِنْ عَذَابٍ شَدِيدٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdccliii{ٱلَّذِينَ يَسْتَحِبُّونَ ٱلْحَيَوٰةَ ٱلدُّنْيَا عَلَى ٱلْءَاخِرَةِ وَيَصُدُّونَ عَن سَبِيلِ ٱللَّهِ وَيَبْغُونَهَا عِوَجًا أُو۟لَٰٓئِكَ فِى ضَلَٰلٍۭ بَعِيدٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdccliv{وَمَآ أَرْسَلْنَا مِن رَّسُولٍ إِلَّا بِلِسَانِ قَوْمِهِۦ لِيُبَيِّنَ لَهُمْ فَيُضِلُّ ٱللَّهُ مَن يَشَآءُ وَيَهْدِى مَن يَشَآءُ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdcclv{وَلَقَدْ أَرْسَلْنَا مُوسَىٰ بِـَٔايَٰتِنَآ أَنْ أَخْرِجْ قَوْمَكَ مِنَ ٱلظُّلُمَٰتِ إِلَى ٱلنُّورِ وَذَكِّرْهُم بِأَيَّىٰمِ ٱللَّهِ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّكُلِّ صَبَّارٍ شَكُورٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdcclvi{وَإِذْ قَالَ مُوسَىٰ لِقَوْمِهِ ٱذْكُرُوا۟ نِعْمَةَ ٱللَّهِ عَلَيْكُمْ إِذْ أَنجَىٰكُم مِّنْ ءَالِ فِرْعَوْنَ يَسُومُونَكُمْ سُوٓءَ ٱلْعَذَابِ وَيُذَبِّحُونَ أَبْنَآءَكُمْ وَيَسْتَحْيُونَ نِسَآءَكُمْ وَفِى ذَٰلِكُم بَلَآءٌ مِّن رَّبِّكُمْ عَظِيمٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdcclvii{وَإِذْ تَأَذَّنَ رَبُّكُمْ لَئِن شَكَرْتُمْ لَأَزِيدَنَّكُمْ وَلَئِن كَفَرْتُمْ إِنَّ عَذَابِى لَشَدِيدٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdcclviii{وَقَالَ مُوسَىٰٓ إِن تَكْفُرُوٓا۟ أَنتُمْ وَمَن فِى ٱلْأَرْضِ جَمِيعًا فَإِنَّ ٱللَّهَ لَغَنِىٌّ حَمِيدٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdcclix{أَلَمْ يَأْتِكُمْ نَبَؤُا۟ ٱلَّذِينَ مِن قَبْلِكُمْ قَوْمِ نُوحٍ وَعَادٍ وَثَمُودَ وَٱلَّذِينَ مِنۢ بَعْدِهِمْ لَا يَعْلَمُهُمْ إِلَّا ٱللَّهُ جَآءَتْهُمْ رُسُلُهُم بِٱلْبَيِّنَٰتِ فَرَدُّوٓا۟ أَيْدِيَهُمْ فِىٓ أَفْوَٰهِهِمْ وَقَالُوٓا۟ إِنَّا كَفَرْنَا بِمَآ أُرْسِلْتُم بِهِۦ وَإِنَّا لَفِى شَكٍّ مِّمَّا تَدْعُونَنَآ إِلَيْهِ مُرِيبٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdcclx{قَالَتْ رُسُلُهُمْ أَفِى ٱللَّهِ شَكٌّ فَاطِرِ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ يَدْعُوكُمْ لِيَغْفِرَ لَكُم مِّن ذُنُوبِكُمْ وَيُؤَخِّرَكُمْ إِلَىٰٓ أَجَلٍ مُّسَمًّى قَالُوٓا۟ إِنْ أَنتُمْ إِلَّا بَشَرٌ مِّثْلُنَا تُرِيدُونَ أَن تَصُدُّونَا عَمَّا كَانَ يَعْبُدُ ءَابَآؤُنَا فَأْتُونَا بِسُلْطَٰنٍ مُّبِينٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdcclxi{قَالَتْ لَهُمْ رُسُلُهُمْ إِن نَّحْنُ إِلَّا بَشَرٌ مِّثْلُكُمْ وَلَٰكِنَّ ٱللَّهَ يَمُنُّ عَلَىٰ مَن يَشَآءُ مِنْ عِبَادِهِۦ وَمَا كَانَ لَنَآ أَن نَّأْتِيَكُم بِسُلْطَٰنٍ إِلَّا بِإِذْنِ ٱللَّهِ وَعَلَى ٱللَّهِ فَلْيَتَوَكَّلِ ٱلْمُؤْمِنُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdcclxii{وَمَا لَنَآ أَلَّا نَتَوَكَّلَ عَلَى ٱللَّهِ وَقَدْ هَدَىٰنَا سُبُلَنَا وَلَنَصْبِرَنَّ عَلَىٰ مَآ ءَاذَيْتُمُونَا وَعَلَى ٱللَّهِ فَلْيَتَوَكَّلِ ٱلْمُتَوَكِّلُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdcclxiii{وَقَالَ ٱلَّذِينَ كَفَرُوا۟ لِرُسُلِهِمْ لَنُخْرِجَنَّكُم مِّنْ أَرْضِنَآ أَوْ لَتَعُودُنَّ فِى مِلَّتِنَا فَأَوْحَىٰٓ إِلَيْهِمْ رَبُّهُمْ لَنُهْلِكَنَّ ٱلظَّٰلِمِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdcclxiv{وَلَنُسْكِنَنَّكُمُ ٱلْأَرْضَ مِنۢ بَعْدِهِمْ ذَٰلِكَ لِمَنْ خَافَ مَقَامِى وَخَافَ وَعِيدِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdcclxv{وَٱسْتَفْتَحُوا۟ وَخَابَ كُلُّ جَبَّارٍ عَنِيدٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdcclxvi{مِّن وَرَآئِهِۦ جَهَنَّمُ وَيُسْقَىٰ مِن مَّآءٍ صَدِيدٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdcclxvii{يَتَجَرَّعُهُۥ وَلَا يَكَادُ يُسِيغُهُۥ وَيَأْتِيهِ ٱلْمَوْتُ مِن كُلِّ مَكَانٍ وَمَا هُوَ بِمَيِّتٍ وَمِن وَرَآئِهِۦ عَذَابٌ غَلِيظٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdcclxviii{مَّثَلُ ٱلَّذِينَ كَفَرُوا۟ بِرَبِّهِمْ أَعْمَٰلُهُمْ كَرَمَادٍ ٱشْتَدَّتْ بِهِ ٱلرِّيحُ فِى يَوْمٍ عَاصِفٍ لَّا يَقْدِرُونَ مِمَّا كَسَبُوا۟ عَلَىٰ شَىْءٍ ذَٰلِكَ هُوَ ٱلضَّلَٰلُ ٱلْبَعِيدُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdcclxix{أَلَمْ تَرَ أَنَّ ٱللَّهَ خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ بِٱلْحَقِّ إِن يَشَأْ يُذْهِبْكُمْ وَيَأْتِ بِخَلْقٍ جَدِيدٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdcclxx{وَمَا ذَٰلِكَ عَلَى ٱللَّهِ بِعَزِيزٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdcclxxi{وَبَرَزُوا۟ لِلَّهِ جَمِيعًا فَقَالَ ٱلضُّعَفَٰٓؤُا۟ لِلَّذِينَ ٱسْتَكْبَرُوٓا۟ إِنَّا كُنَّا لَكُمْ تَبَعًا فَهَلْ أَنتُم مُّغْنُونَ عَنَّا مِنْ عَذَابِ ٱللَّهِ مِن شَىْءٍ قَالُوا۟ لَوْ هَدَىٰنَا ٱللَّهُ لَهَدَيْنَٰكُمْ سَوَآءٌ عَلَيْنَآ أَجَزِعْنَآ أَمْ صَبَرْنَا مَا لَنَا مِن مَّحِيصٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdcclxxii{وَقَالَ ٱلشَّيْطَٰنُ لَمَّا قُضِىَ ٱلْأَمْرُ إِنَّ ٱللَّهَ وَعَدَكُمْ وَعْدَ ٱلْحَقِّ وَوَعَدتُّكُمْ فَأَخْلَفْتُكُمْ وَمَا كَانَ لِىَ عَلَيْكُم مِّن سُلْطَٰنٍ إِلَّآ أَن دَعَوْتُكُمْ فَٱسْتَجَبْتُمْ لِى فَلَا تَلُومُونِى وَلُومُوٓا۟ أَنفُسَكُم مَّآ أَنَا۠ بِمُصْرِخِكُمْ وَمَآ أَنتُم بِمُصْرِخِىَّ إِنِّى كَفَرْتُ بِمَآ أَشْرَكْتُمُونِ مِن قَبْلُ إِنَّ ٱلظَّٰلِمِينَ لَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdcclxxiii{وَأُدْخِلَ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا بِإِذْنِ رَبِّهِمْ تَحِيَّتُهُمْ فِيهَا سَلَٰمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdcclxxiv{أَلَمْ تَرَ كَيْفَ ضَرَبَ ٱللَّهُ مَثَلًا كَلِمَةً طَيِّبَةً كَشَجَرَةٍ طَيِّبَةٍ أَصْلُهَا ثَابِتٌ وَفَرْعُهَا فِى ٱلسَّمَآءِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdcclxxv{تُؤْتِىٓ أُكُلَهَا كُلَّ حِينٍۭ بِإِذْنِ رَبِّهَا وَيَضْرِبُ ٱللَّهُ ٱلْأَمْثَالَ لِلنَّاسِ لَعَلَّهُمْ يَتَذَكَّرُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdcclxxvi{وَمَثَلُ كَلِمَةٍ خَبِيثَةٍ كَشَجَرَةٍ خَبِيثَةٍ ٱجْتُثَّتْ مِن فَوْقِ ٱلْأَرْضِ مَا لَهَا مِن قَرَارٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdcclxxvii{يُثَبِّتُ ٱللَّهُ ٱلَّذِينَ ءَامَنُوا۟ بِٱلْقَوْلِ ٱلثَّابِتِ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَفِى ٱلْءَاخِرَةِ وَيُضِلُّ ٱللَّهُ ٱلظَّٰلِمِينَ وَيَفْعَلُ ٱللَّهُ مَا يَشَآءُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdcclxxviii{أَلَمْ تَرَ إِلَى ٱلَّذِينَ بَدَّلُوا۟ نِعْمَتَ ٱللَّهِ كُفْرًا وَأَحَلُّوا۟ قَوْمَهُمْ دَارَ ٱلْبَوَارِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdcclxxix{جَهَنَّمَ يَصْلَوْنَهَا وَبِئْسَ ٱلْقَرَارُ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdcclxxx{وَجَعَلُوا۟ لِلَّهِ أَندَادًا لِّيُضِلُّوا۟ عَن سَبِيلِهِۦ قُلْ تَمَتَّعُوا۟ فَإِنَّ مَصِيرَكُمْ إِلَى ٱلنَّارِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdcclxxxi{قُل لِّعِبَادِىَ ٱلَّذِينَ ءَامَنُوا۟ يُقِيمُوا۟ ٱلصَّلَوٰةَ وَيُنفِقُوا۟ مِمَّا رَزَقْنَٰهُمْ سِرًّا وَعَلَانِيَةً مِّن قَبْلِ أَن يَأْتِىَ يَوْمٌ لَّا بَيْعٌ فِيهِ وَلَا خِلَٰلٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdcclxxxii{ٱللَّهُ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَأَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً فَأَخْرَجَ بِهِۦ مِنَ ٱلثَّمَرَٰتِ رِزْقًا لَّكُمْ وَسَخَّرَ لَكُمُ ٱلْفُلْكَ لِتَجْرِىَ فِى ٱلْبَحْرِ بِأَمْرِهِۦ وَسَخَّرَ لَكُمُ ٱلْأَنْهَٰرَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdcclxxxiii{وَسَخَّرَ لَكُمُ ٱلشَّمْسَ وَٱلْقَمَرَ دَآئِبَيْنِ وَسَخَّرَ لَكُمُ ٱلَّيْلَ وَٱلنَّهَارَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdcclxxxiv{وَءَاتَىٰكُم مِّن كُلِّ مَا سَأَلْتُمُوهُ وَإِن تَعُدُّوا۟ نِعْمَتَ ٱللَّهِ لَا تُحْصُوهَآ إِنَّ ٱلْإِنسَٰنَ لَظَلُومٌ كَفَّارٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdcclxxxv{وَإِذْ قَالَ إِبْرَٰهِيمُ رَبِّ ٱجْعَلْ هَٰذَا ٱلْبَلَدَ ءَامِنًا وَٱجْنُبْنِى وَبَنِىَّ أَن نَّعْبُدَ ٱلْأَصْنَامَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdcclxxxvi{رَبِّ إِنَّهُنَّ أَضْلَلْنَ كَثِيرًا مِّنَ ٱلنَّاسِ فَمَن تَبِعَنِى فَإِنَّهُۥ مِنِّى وَمَنْ عَصَانِى فَإِنَّكَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdcclxxxvii{رَّبَّنَآ إِنِّىٓ أَسْكَنتُ مِن ذُرِّيَّتِى بِوَادٍ غَيْرِ ذِى زَرْعٍ عِندَ بَيْتِكَ ٱلْمُحَرَّمِ رَبَّنَا لِيُقِيمُوا۟ ٱلصَّلَوٰةَ فَٱجْعَلْ أَفْـِٔدَةً مِّنَ ٱلنَّاسِ تَهْوِىٓ إِلَيْهِمْ وَٱرْزُقْهُم مِّنَ ٱلثَّمَرَٰتِ لَعَلَّهُمْ يَشْكُرُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdcclxxxviii{رَبَّنَآ إِنَّكَ تَعْلَمُ مَا نُخْفِى وَمَا نُعْلِنُ وَمَا يَخْفَىٰ عَلَى ٱللَّهِ مِن شَىْءٍ فِى ٱلْأَرْضِ وَلَا فِى ٱلسَّمَآءِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdcclxxxix{ٱلْحَمْدُ لِلَّهِ ٱلَّذِى وَهَبَ لِى عَلَى ٱلْكِبَرِ إِسْمَٰعِيلَ وَإِسْحَٰقَ إِنَّ رَبِّى لَسَمِيعُ ٱلدُّعَآءِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdccxc{رَبِّ ٱجْعَلْنِى مُقِيمَ ٱلصَّلَوٰةِ وَمِن ذُرِّيَّتِى رَبَّنَا وَتَقَبَّلْ دُعَآءِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdccxci{رَبَّنَا ٱغْفِرْ لِى وَلِوَٰلِدَىَّ وَلِلْمُؤْمِنِينَ يَوْمَ يَقُومُ ٱلْحِسَابُ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdccxcii{وَلَا تَحْسَبَنَّ ٱللَّهَ غَٰفِلًا عَمَّا يَعْمَلُ ٱلظَّٰلِمُونَ إِنَّمَا يُؤَخِّرُهُمْ لِيَوْمٍ تَشْخَصُ فِيهِ ٱلْأَبْصَٰرُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdccxciii{مُهْطِعِينَ مُقْنِعِى رُءُوسِهِمْ لَا يَرْتَدُّ إِلَيْهِمْ طَرْفُهُمْ وَأَفْـِٔدَتُهُمْ هَوَآءٌ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdccxciv{وَأَنذِرِ ٱلنَّاسَ يَوْمَ يَأْتِيهِمُ ٱلْعَذَابُ فَيَقُولُ ٱلَّذِينَ ظَلَمُوا۟ رَبَّنَآ أَخِّرْنَآ إِلَىٰٓ أَجَلٍ قَرِيبٍ نُّجِبْ دَعْوَتَكَ وَنَتَّبِعِ ٱلرُّسُلَ أَوَلَمْ تَكُونُوٓا۟ أَقْسَمْتُم مِّن قَبْلُ مَا لَكُم مِّن زَوَالٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdccxcv{وَسَكَنتُمْ فِى مَسَٰكِنِ ٱلَّذِينَ ظَلَمُوٓا۟ أَنفُسَهُمْ وَتَبَيَّنَ لَكُمْ كَيْفَ فَعَلْنَا بِهِمْ وَضَرَبْنَا لَكُمُ ٱلْأَمْثَالَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdccxcvi{وَقَدْ مَكَرُوا۟ مَكْرَهُمْ وَعِندَ ٱللَّهِ مَكْرُهُمْ وَإِن كَانَ مَكْرُهُمْ لِتَزُولَ مِنْهُ ٱلْجِبَالُ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdccxcvii{فَلَا تَحْسَبَنَّ ٱللَّهَ مُخْلِفَ وَعْدِهِۦ رُسُلَهُۥٓ إِنَّ ٱللَّهَ عَزِيزٌ ذُو ٱنتِقَامٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdccxcviii{يَوْمَ تُبَدَّلُ ٱلْأَرْضُ غَيْرَ ٱلْأَرْضِ وَٱلسَّمَٰوَٰتُ وَبَرَزُوا۟ لِلَّهِ ٱلْوَٰحِدِ ٱلْقَهَّارِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdccxcix{وَتَرَى ٱلْمُجْرِمِينَ يَوْمَئِذٍ مُّقَرَّنِينَ فِى ٱلْأَصْفَادِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdccc{سَرَابِيلُهُم مِّن قَطِرَانٍ وَتَغْشَىٰ وُجُوهَهُمُ ٱلنَّارُ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdccci{لِيَجْزِىَ ٱللَّهُ كُلَّ نَفْسٍ مَّا كَسَبَتْ إِنَّ ٱللَّهَ سَرِيعُ ٱلْحِسَابِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdcccii{هَٰذَا بَلَٰغٌ لِّلنَّاسِ وَلِيُنذَرُوا۟ بِهِۦ وَلِيَعْلَمُوٓا۟ أَنَّمَا هُوَ إِلَٰهٌ وَٰحِدٌ وَلِيَذَّكَّرَ أُو۟لُوا۟ ٱلْأَلْبَٰبِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdccciii{\basmalah الٓر تِلْكَ ءَايَٰتُ ٱلْكِتَٰبِ وَقُرْءَانٍ مُّبِينٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdccciv{رُّبَمَا يَوَدُّ ٱلَّذِينَ كَفَرُوا۟ لَوْ كَانُوا۟ مُسْلِمِينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdcccv{ذَرْهُمْ يَأْكُلُوا۟ وَيَتَمَتَّعُوا۟ وَيُلْهِهِمُ ٱلْأَمَلُ فَسَوْفَ يَعْلَمُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdcccvi{وَمَآ أَهْلَكْنَا مِن قَرْيَةٍ إِلَّا وَلَهَا كِتَابٌ مَّعْلُومٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdcccvii{مَّا تَسْبِقُ مِنْ أُمَّةٍ أَجَلَهَا وَمَا يَسْتَـْٔخِرُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdcccviii{وَقَالُوا۟ يَٰٓأَيُّهَا ٱلَّذِى نُزِّلَ عَلَيْهِ ٱلذِّكْرُ إِنَّكَ لَمَجْنُونٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdcccix{لَّوْ مَا تَأْتِينَا بِٱلْمَلَٰٓئِكَةِ إِن كُنتَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdcccx{مَا نُنَزِّلُ ٱلْمَلَٰٓئِكَةَ إِلَّا بِٱلْحَقِّ وَمَا كَانُوٓا۟ إِذًا مُّنظَرِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdcccxi{إِنَّا نَحْنُ نَزَّلْنَا ٱلذِّكْرَ وَإِنَّا لَهُۥ لَحَٰفِظُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdcccxii{وَلَقَدْ أَرْسَلْنَا مِن قَبْلِكَ فِى شِيَعِ ٱلْأَوَّلِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdcccxiii{وَمَا يَأْتِيهِم مِّن رَّسُولٍ إِلَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdcccxiv{كَذَٰلِكَ نَسْلُكُهُۥ فِى قُلُوبِ ٱلْمُجْرِمِينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdcccxv{لَا يُؤْمِنُونَ بِهِۦ وَقَدْ خَلَتْ سُنَّةُ ٱلْأَوَّلِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdcccxvi{وَلَوْ فَتَحْنَا عَلَيْهِم بَابًا مِّنَ ٱلسَّمَآءِ فَظَلُّوا۟ فِيهِ يَعْرُجُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdcccxvii{لَقَالُوٓا۟ إِنَّمَا سُكِّرَتْ أَبْصَٰرُنَا بَلْ نَحْنُ قَوْمٌ مَّسْحُورُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdcccxviii{وَلَقَدْ جَعَلْنَا فِى ٱلسَّمَآءِ بُرُوجًا وَزَيَّنَّٰهَا لِلنَّٰظِرِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdcccxix{وَحَفِظْنَٰهَا مِن كُلِّ شَيْطَٰنٍ رَّجِيمٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdcccxx{إِلَّا مَنِ ٱسْتَرَقَ ٱلسَّمْعَ فَأَتْبَعَهُۥ شِهَابٌ مُّبِينٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdcccxxi{وَٱلْأَرْضَ مَدَدْنَٰهَا وَأَلْقَيْنَا فِيهَا رَوَٰسِىَ وَأَنۢبَتْنَا فِيهَا مِن كُلِّ شَىْءٍ مَّوْزُونٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdcccxxii{وَجَعَلْنَا لَكُمْ فِيهَا مَعَٰيِشَ وَمَن لَّسْتُمْ لَهُۥ بِرَٰزِقِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdcccxxiii{وَإِن مِّن شَىْءٍ إِلَّا عِندَنَا خَزَآئِنُهُۥ وَمَا نُنَزِّلُهُۥٓ إِلَّا بِقَدَرٍ مَّعْلُومٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdcccxxiv{وَأَرْسَلْنَا ٱلرِّيَٰحَ لَوَٰقِحَ فَأَنزَلْنَا مِنَ ٱلسَّمَآءِ مَآءً فَأَسْقَيْنَٰكُمُوهُ وَمَآ أَنتُمْ لَهُۥ بِخَٰزِنِينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdcccxxv{وَإِنَّا لَنَحْنُ نُحْىِۦ وَنُمِيتُ وَنَحْنُ ٱلْوَٰرِثُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdcccxxvi{وَلَقَدْ عَلِمْنَا ٱلْمُسْتَقْدِمِينَ مِنكُمْ وَلَقَدْ عَلِمْنَا ٱلْمُسْتَـْٔخِرِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdcccxxvii{وَإِنَّ رَبَّكَ هُوَ يَحْشُرُهُمْ إِنَّهُۥ حَكِيمٌ عَلِيمٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdcccxxviii{وَلَقَدْ خَلَقْنَا ٱلْإِنسَٰنَ مِن صَلْصَٰلٍ مِّنْ حَمَإٍ مَّسْنُونٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdcccxxix{وَٱلْجَآنَّ خَلَقْنَٰهُ مِن قَبْلُ مِن نَّارِ ٱلسَّمُومِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdcccxxx{وَإِذْ قَالَ رَبُّكَ لِلْمَلَٰٓئِكَةِ إِنِّى خَٰلِقٌۢ بَشَرًا مِّن صَلْصَٰلٍ مِّنْ حَمَإٍ مَّسْنُونٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdcccxxxi{فَإِذَا سَوَّيْتُهُۥ وَنَفَخْتُ فِيهِ مِن رُّوحِى فَقَعُوا۟ لَهُۥ سَٰجِدِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdcccxxxii{فَسَجَدَ ٱلْمَلَٰٓئِكَةُ كُلُّهُمْ أَجْمَعُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdcccxxxiii{إِلَّآ إِبْلِيسَ أَبَىٰٓ أَن يَكُونَ مَعَ ٱلسَّٰجِدِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdcccxxxiv{قَالَ يَٰٓإِبْلِيسُ مَا لَكَ أَلَّا تَكُونَ مَعَ ٱلسَّٰجِدِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdcccxxxv{قَالَ لَمْ أَكُن لِّأَسْجُدَ لِبَشَرٍ خَلَقْتَهُۥ مِن صَلْصَٰلٍ مِّنْ حَمَإٍ مَّسْنُونٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdcccxxxvi{قَالَ فَٱخْرُجْ مِنْهَا فَإِنَّكَ رَجِيمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdcccxxxvii{وَإِنَّ عَلَيْكَ ٱللَّعْنَةَ إِلَىٰ يَوْمِ ٱلدِّينِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdcccxxxviii{قَالَ رَبِّ فَأَنظِرْنِىٓ إِلَىٰ يَوْمِ يُبْعَثُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdcccxxxix{قَالَ فَإِنَّكَ مِنَ ٱلْمُنظَرِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdcccxl{إِلَىٰ يَوْمِ ٱلْوَقْتِ ٱلْمَعْلُومِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdcccxli{قَالَ رَبِّ بِمَآ أَغْوَيْتَنِى لَأُزَيِّنَنَّ لَهُمْ فِى ٱلْأَرْضِ وَلَأُغْوِيَنَّهُمْ أَجْمَعِينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdcccxlii{إِلَّا عِبَادَكَ مِنْهُمُ ٱلْمُخْلَصِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdcccxliii{قَالَ هَٰذَا صِرَٰطٌ عَلَىَّ مُسْتَقِيمٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdcccxliv{إِنَّ عِبَادِى لَيْسَ لَكَ عَلَيْهِمْ سُلْطَٰنٌ إِلَّا مَنِ ٱتَّبَعَكَ مِنَ ٱلْغَاوِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdcccxlv{وَإِنَّ جَهَنَّمَ لَمَوْعِدُهُمْ أَجْمَعِينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdcccxlvi{لَهَا سَبْعَةُ أَبْوَٰبٍ لِّكُلِّ بَابٍ مِّنْهُمْ جُزْءٌ مَّقْسُومٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdcccxlvii{إِنَّ ٱلْمُتَّقِينَ فِى جَنَّٰتٍ وَعُيُونٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdcccxlviii{ٱدْخُلُوهَا بِسَلَٰمٍ ءَامِنِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdcccxlix{وَنَزَعْنَا مَا فِى صُدُورِهِم مِّنْ غِلٍّ إِخْوَٰنًا عَلَىٰ سُرُرٍ مُّتَقَٰبِلِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdcccl{لَا يَمَسُّهُمْ فِيهَا نَصَبٌ وَمَا هُم مِّنْهَا بِمُخْرَجِينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdcccli{نَبِّئْ عِبَادِىٓ أَنِّىٓ أَنَا ٱلْغَفُورُ ٱلرَّحِيمُ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdccclii{وَأَنَّ عَذَابِى هُوَ ٱلْعَذَابُ ٱلْأَلِيمُ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdcccliii{وَنَبِّئْهُمْ عَن ضَيْفِ إِبْرَٰهِيمَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdcccliv{إِذْ دَخَلُوا۟ عَلَيْهِ فَقَالُوا۟ سَلَٰمًا قَالَ إِنَّا مِنكُمْ وَجِلُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdccclv{قَالُوا۟ لَا تَوْجَلْ إِنَّا نُبَشِّرُكَ بِغُلَٰمٍ عَلِيمٍ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mdccclvi{قَالَ أَبَشَّرْتُمُونِى عَلَىٰٓ أَن مَّسَّنِىَ ٱلْكِبَرُ فَبِمَ تُبَشِّرُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mdccclvii{قَالُوا۟ بَشَّرْنَٰكَ بِٱلْحَقِّ فَلَا تَكُن مِّنَ ٱلْقَٰنِطِينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mdccclviii{قَالَ وَمَن يَقْنَطُ مِن رَّحْمَةِ رَبِّهِۦٓ إِلَّا ٱلضَّآلُّونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mdccclix{قَالَ فَمَا خَطْبُكُمْ أَيُّهَا ٱلْمُرْسَلُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mdccclx{قَالُوٓا۟ إِنَّآ أُرْسِلْنَآ إِلَىٰ قَوْمٍ مُّجْرِمِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mdccclxi{إِلَّآ ءَالَ لُوطٍ إِنَّا لَمُنَجُّوهُمْ أَجْمَعِينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mdccclxii{إِلَّا ٱمْرَأَتَهُۥ قَدَّرْنَآ إِنَّهَا لَمِنَ ٱلْغَٰبِرِينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mdccclxiii{فَلَمَّا جَآءَ ءَالَ لُوطٍ ٱلْمُرْسَلُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mdccclxiv{قَالَ إِنَّكُمْ قَوْمٌ مُّنكَرُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mdccclxv{قَالُوا۟ بَلْ جِئْنَٰكَ بِمَا كَانُوا۟ فِيهِ يَمْتَرُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mdccclxvi{وَأَتَيْنَٰكَ بِٱلْحَقِّ وَإِنَّا لَصَٰدِقُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mdccclxvii{فَأَسْرِ بِأَهْلِكَ بِقِطْعٍ مِّنَ ٱلَّيْلِ وَٱتَّبِعْ أَدْبَٰرَهُمْ وَلَا يَلْتَفِتْ مِنكُمْ أَحَدٌ وَٱمْضُوا۟ حَيْثُ تُؤْمَرُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mdccclxviii{وَقَضَيْنَآ إِلَيْهِ ذَٰلِكَ ٱلْأَمْرَ أَنَّ دَابِرَ هَٰٓؤُلَآءِ مَقْطُوعٌ مُّصْبِحِينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mdccclxix{وَجَآءَ أَهْلُ ٱلْمَدِينَةِ يَسْتَبْشِرُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mdccclxx{قَالَ إِنَّ هَٰٓؤُلَآءِ ضَيْفِى فَلَا تَفْضَحُونِ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mdccclxxi{وَٱتَّقُوا۟ ٱللَّهَ وَلَا تُخْزُونِ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mdccclxxii{قَالُوٓا۟ أَوَلَمْ نَنْهَكَ عَنِ ٱلْعَٰلَمِينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mdccclxxiii{قَالَ هَٰٓؤُلَآءِ بَنَاتِىٓ إِن كُنتُمْ فَٰعِلِينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mdccclxxiv{لَعَمْرُكَ إِنَّهُمْ لَفِى سَكْرَتِهِمْ يَعْمَهُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mdccclxxv{فَأَخَذَتْهُمُ ٱلصَّيْحَةُ مُشْرِقِينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mdccclxxvi{فَجَعَلْنَا عَٰلِيَهَا سَافِلَهَا وَأَمْطَرْنَا عَلَيْهِمْ حِجَارَةً مِّن سِجِّيلٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mdccclxxvii{إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّلْمُتَوَسِّمِينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mdccclxxviii{وَإِنَّهَا لَبِسَبِيلٍ مُّقِيمٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mdccclxxix{إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّلْمُؤْمِنِينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mdccclxxx{وَإِن كَانَ أَصْحَٰبُ ٱلْأَيْكَةِ لَظَٰلِمِينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mdccclxxxi{فَٱنتَقَمْنَا مِنْهُمْ وَإِنَّهُمَا لَبِإِمَامٍ مُّبِينٍ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mdccclxxxii{وَلَقَدْ كَذَّبَ أَصْحَٰبُ ٱلْحِجْرِ ٱلْمُرْسَلِينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mdccclxxxiii{وَءَاتَيْنَٰهُمْ ءَايَٰتِنَا فَكَانُوا۟ عَنْهَا مُعْرِضِينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mdccclxxxiv{وَكَانُوا۟ يَنْحِتُونَ مِنَ ٱلْجِبَالِ بُيُوتًا ءَامِنِينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mdccclxxxv{فَأَخَذَتْهُمُ ٱلصَّيْحَةُ مُصْبِحِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mdccclxxxvi{فَمَآ أَغْنَىٰ عَنْهُم مَّا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mdccclxxxvii{وَمَا خَلَقْنَا ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَمَا بَيْنَهُمَآ إِلَّا بِٱلْحَقِّ وَإِنَّ ٱلسَّاعَةَ لَءَاتِيَةٌ فَٱصْفَحِ ٱلصَّفْحَ ٱلْجَمِيلَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mdccclxxxviii{إِنَّ رَبَّكَ هُوَ ٱلْخَلَّٰقُ ٱلْعَلِيمُ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mdccclxxxix{وَلَقَدْ ءَاتَيْنَٰكَ سَبْعًا مِّنَ ٱلْمَثَانِى وَٱلْقُرْءَانَ ٱلْعَظِيمَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mdcccxc{لَا تَمُدَّنَّ عَيْنَيْكَ إِلَىٰ مَا مَتَّعْنَا بِهِۦٓ أَزْوَٰجًا مِّنْهُمْ وَلَا تَحْزَنْ عَلَيْهِمْ وَٱخْفِضْ جَنَاحَكَ لِلْمُؤْمِنِينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mdcccxci{وَقُلْ إِنِّىٓ أَنَا ٱلنَّذِيرُ ٱلْمُبِينُ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mdcccxcii{كَمَآ أَنزَلْنَا عَلَى ٱلْمُقْتَسِمِينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mdcccxciii{ٱلَّذِينَ جَعَلُوا۟ ٱلْقُرْءَانَ عِضِينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mdcccxciv{فَوَرَبِّكَ لَنَسْـَٔلَنَّهُمْ أَجْمَعِينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mdcccxcv{عَمَّا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mdcccxcvi{فَٱصْدَعْ بِمَا تُؤْمَرُ وَأَعْرِضْ عَنِ ٱلْمُشْرِكِينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mdcccxcvii{إِنَّا كَفَيْنَٰكَ ٱلْمُسْتَهْزِءِينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mdcccxcviii{ٱلَّذِينَ يَجْعَلُونَ مَعَ ٱللَّهِ إِلَٰهًا ءَاخَرَ فَسَوْفَ يَعْلَمُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mdcccxcix{وَلَقَدْ نَعْلَمُ أَنَّكَ يَضِيقُ صَدْرُكَ بِمَا يَقُولُونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcm{فَسَبِّحْ بِحَمْدِ رَبِّكَ وَكُن مِّنَ ٱلسَّٰجِدِينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mcmi{وَٱعْبُدْ رَبَّكَ حَتَّىٰ يَأْتِيَكَ ٱلْيَقِينُ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mcmii{\basmalah أَتَىٰٓ أَمْرُ ٱللَّهِ فَلَا تَسْتَعْجِلُوهُ سُبْحَٰنَهُۥ وَتَعَٰلَىٰ عَمَّا يُشْرِكُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mcmiii{يُنَزِّلُ ٱلْمَلَٰٓئِكَةَ بِٱلرُّوحِ مِنْ أَمْرِهِۦ عَلَىٰ مَن يَشَآءُ مِنْ عِبَادِهِۦٓ أَنْ أَنذِرُوٓا۟ أَنَّهُۥ لَآ إِلَٰهَ إِلَّآ أَنَا۠ فَٱتَّقُونِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mcmiv{خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ بِٱلْحَقِّ تَعَٰلَىٰ عَمَّا يُشْرِكُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mcmv{خَلَقَ ٱلْإِنسَٰنَ مِن نُّطْفَةٍ فَإِذَا هُوَ خَصِيمٌ مُّبِينٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mcmvi{وَٱلْأَنْعَٰمَ خَلَقَهَا لَكُمْ فِيهَا دِفْءٌ وَمَنَٰفِعُ وَمِنْهَا تَأْكُلُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mcmvii{وَلَكُمْ فِيهَا جَمَالٌ حِينَ تُرِيحُونَ وَحِينَ تَسْرَحُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mcmviii{وَتَحْمِلُ أَثْقَالَكُمْ إِلَىٰ بَلَدٍ لَّمْ تَكُونُوا۟ بَٰلِغِيهِ إِلَّا بِشِقِّ ٱلْأَنفُسِ إِنَّ رَبَّكُمْ لَرَءُوفٌ رَّحِيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mcmix{وَٱلْخَيْلَ وَٱلْبِغَالَ وَٱلْحَمِيرَ لِتَرْكَبُوهَا وَزِينَةً وَيَخْلُقُ مَا لَا تَعْلَمُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mcmx{وَعَلَى ٱللَّهِ قَصْدُ ٱلسَّبِيلِ وَمِنْهَا جَآئِرٌ وَلَوْ شَآءَ لَهَدَىٰكُمْ أَجْمَعِينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mcmxi{هُوَ ٱلَّذِىٓ أَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً لَّكُم مِّنْهُ شَرَابٌ وَمِنْهُ شَجَرٌ فِيهِ تُسِيمُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mcmxii{يُنۢبِتُ لَكُم بِهِ ٱلزَّرْعَ وَٱلزَّيْتُونَ وَٱلنَّخِيلَ وَٱلْأَعْنَٰبَ وَمِن كُلِّ ٱلثَّمَرَٰتِ إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّقَوْمٍ يَتَفَكَّرُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mcmxiii{وَسَخَّرَ لَكُمُ ٱلَّيْلَ وَٱلنَّهَارَ وَٱلشَّمْسَ وَٱلْقَمَرَ وَٱلنُّجُومُ مُسَخَّرَٰتٌۢ بِأَمْرِهِۦٓ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يَعْقِلُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mcmxiv{وَمَا ذَرَأَ لَكُمْ فِى ٱلْأَرْضِ مُخْتَلِفًا أَلْوَٰنُهُۥٓ إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّقَوْمٍ يَذَّكَّرُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mcmxv{وَهُوَ ٱلَّذِى سَخَّرَ ٱلْبَحْرَ لِتَأْكُلُوا۟ مِنْهُ لَحْمًا طَرِيًّا وَتَسْتَخْرِجُوا۟ مِنْهُ حِلْيَةً تَلْبَسُونَهَا وَتَرَى ٱلْفُلْكَ مَوَاخِرَ فِيهِ وَلِتَبْتَغُوا۟ مِن فَضْلِهِۦ وَلَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mcmxvi{وَأَلْقَىٰ فِى ٱلْأَرْضِ رَوَٰسِىَ أَن تَمِيدَ بِكُمْ وَأَنْهَٰرًا وَسُبُلًا لَّعَلَّكُمْ تَهْتَدُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mcmxvii{وَعَلَٰمَٰتٍ وَبِٱلنَّجْمِ هُمْ يَهْتَدُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mcmxviii{أَفَمَن يَخْلُقُ كَمَن لَّا يَخْلُقُ أَفَلَا تَذَكَّرُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mcmxix{وَإِن تَعُدُّوا۟ نِعْمَةَ ٱللَّهِ لَا تُحْصُوهَآ إِنَّ ٱللَّهَ لَغَفُورٌ رَّحِيمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mcmxx{وَٱللَّهُ يَعْلَمُ مَا تُسِرُّونَ وَمَا تُعْلِنُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mcmxxi{وَٱلَّذِينَ يَدْعُونَ مِن دُونِ ٱللَّهِ لَا يَخْلُقُونَ شَيْـًٔا وَهُمْ يُخْلَقُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mcmxxii{أَمْوَٰتٌ غَيْرُ أَحْيَآءٍ وَمَا يَشْعُرُونَ أَيَّانَ يُبْعَثُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mcmxxiii{إِلَٰهُكُمْ إِلَٰهٌ وَٰحِدٌ فَٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ قُلُوبُهُم مُّنكِرَةٌ وَهُم مُّسْتَكْبِرُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mcmxxiv{لَا جَرَمَ أَنَّ ٱللَّهَ يَعْلَمُ مَا يُسِرُّونَ وَمَا يُعْلِنُونَ إِنَّهُۥ لَا يُحِبُّ ٱلْمُسْتَكْبِرِينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mcmxxv{وَإِذَا قِيلَ لَهُم مَّاذَآ أَنزَلَ رَبُّكُمْ قَالُوٓا۟ أَسَٰطِيرُ ٱلْأَوَّلِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mcmxxvi{لِيَحْمِلُوٓا۟ أَوْزَارَهُمْ كَامِلَةً يَوْمَ ٱلْقِيَٰمَةِ وَمِنْ أَوْزَارِ ٱلَّذِينَ يُضِلُّونَهُم بِغَيْرِ عِلْمٍ أَلَا سَآءَ مَا يَزِرُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcmxxvii{قَدْ مَكَرَ ٱلَّذِينَ مِن قَبْلِهِمْ فَأَتَى ٱللَّهُ بُنْيَٰنَهُم مِّنَ ٱلْقَوَاعِدِ فَخَرَّ عَلَيْهِمُ ٱلسَّقْفُ مِن فَوْقِهِمْ وَأَتَىٰهُمُ ٱلْعَذَابُ مِنْ حَيْثُ لَا يَشْعُرُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mcmxxviii{ثُمَّ يَوْمَ ٱلْقِيَٰمَةِ يُخْزِيهِمْ وَيَقُولُ أَيْنَ شُرَكَآءِىَ ٱلَّذِينَ كُنتُمْ تُشَٰٓقُّونَ فِيهِمْ قَالَ ٱلَّذِينَ أُوتُوا۟ ٱلْعِلْمَ إِنَّ ٱلْخِزْىَ ٱلْيَوْمَ وَٱلسُّوٓءَ عَلَى ٱلْكَٰفِرِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mcmxxix{ٱلَّذِينَ تَتَوَفَّىٰهُمُ ٱلْمَلَٰٓئِكَةُ ظَالِمِىٓ أَنفُسِهِمْ فَأَلْقَوُا۟ ٱلسَّلَمَ مَا كُنَّا نَعْمَلُ مِن سُوٓءٍۭ بَلَىٰٓ إِنَّ ٱللَّهَ عَلِيمٌۢ بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mcmxxx{فَٱدْخُلُوٓا۟ أَبْوَٰبَ جَهَنَّمَ خَٰلِدِينَ فِيهَا فَلَبِئْسَ مَثْوَى ٱلْمُتَكَبِّرِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcmxxxi{وَقِيلَ لِلَّذِينَ ٱتَّقَوْا۟ مَاذَآ أَنزَلَ رَبُّكُمْ قَالُوا۟ خَيْرًا لِّلَّذِينَ أَحْسَنُوا۟ فِى هَٰذِهِ ٱلدُّنْيَا حَسَنَةٌ وَلَدَارُ ٱلْءَاخِرَةِ خَيْرٌ وَلَنِعْمَ دَارُ ٱلْمُتَّقِينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcmxxxii{جَنَّٰتُ عَدْنٍ يَدْخُلُونَهَا تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ لَهُمْ فِيهَا مَا يَشَآءُونَ كَذَٰلِكَ يَجْزِى ٱللَّهُ ٱلْمُتَّقِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcmxxxiii{ٱلَّذِينَ تَتَوَفَّىٰهُمُ ٱلْمَلَٰٓئِكَةُ طَيِّبِينَ يَقُولُونَ سَلَٰمٌ عَلَيْكُمُ ٱدْخُلُوا۟ ٱلْجَنَّةَ بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcmxxxiv{هَلْ يَنظُرُونَ إِلَّآ أَن تَأْتِيَهُمُ ٱلْمَلَٰٓئِكَةُ أَوْ يَأْتِىَ أَمْرُ رَبِّكَ كَذَٰلِكَ فَعَلَ ٱلَّذِينَ مِن قَبْلِهِمْ وَمَا ظَلَمَهُمُ ٱللَّهُ وَلَٰكِن كَانُوٓا۟ أَنفُسَهُمْ يَظْلِمُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcmxxxv{فَأَصَابَهُمْ سَيِّـَٔاتُ مَا عَمِلُوا۟ وَحَاقَ بِهِم مَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcmxxxvi{وَقَالَ ٱلَّذِينَ أَشْرَكُوا۟ لَوْ شَآءَ ٱللَّهُ مَا عَبَدْنَا مِن دُونِهِۦ مِن شَىْءٍ نَّحْنُ وَلَآ ءَابَآؤُنَا وَلَا حَرَّمْنَا مِن دُونِهِۦ مِن شَىْءٍ كَذَٰلِكَ فَعَلَ ٱلَّذِينَ مِن قَبْلِهِمْ فَهَلْ عَلَى ٱلرُّسُلِ إِلَّا ٱلْبَلَٰغُ ٱلْمُبِينُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcmxxxvii{وَلَقَدْ بَعَثْنَا فِى كُلِّ أُمَّةٍ رَّسُولًا أَنِ ٱعْبُدُوا۟ ٱللَّهَ وَٱجْتَنِبُوا۟ ٱلطَّٰغُوتَ فَمِنْهُم مَّنْ هَدَى ٱللَّهُ وَمِنْهُم مَّنْ حَقَّتْ عَلَيْهِ ٱلضَّلَٰلَةُ فَسِيرُوا۟ فِى ٱلْأَرْضِ فَٱنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُكَذِّبِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcmxxxviii{إِن تَحْرِصْ عَلَىٰ هُدَىٰهُمْ فَإِنَّ ٱللَّهَ لَا يَهْدِى مَن يُضِلُّ وَمَا لَهُم مِّن نَّٰصِرِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcmxxxix{وَأَقْسَمُوا۟ بِٱللَّهِ جَهْدَ أَيْمَٰنِهِمْ لَا يَبْعَثُ ٱللَّهُ مَن يَمُوتُ بَلَىٰ وَعْدًا عَلَيْهِ حَقًّا وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcmxl{لِيُبَيِّنَ لَهُمُ ٱلَّذِى يَخْتَلِفُونَ فِيهِ وَلِيَعْلَمَ ٱلَّذِينَ كَفَرُوٓا۟ أَنَّهُمْ كَانُوا۟ كَٰذِبِينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcmxli{إِنَّمَا قَوْلُنَا لِشَىْءٍ إِذَآ أَرَدْنَٰهُ أَن نَّقُولَ لَهُۥ كُن فَيَكُونُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcmxlii{وَٱلَّذِينَ هَاجَرُوا۟ فِى ٱللَّهِ مِنۢ بَعْدِ مَا ظُلِمُوا۟ لَنُبَوِّئَنَّهُمْ فِى ٱلدُّنْيَا حَسَنَةً وَلَأَجْرُ ٱلْءَاخِرَةِ أَكْبَرُ لَوْ كَانُوا۟ يَعْلَمُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mcmxliii{ٱلَّذِينَ صَبَرُوا۟ وَعَلَىٰ رَبِّهِمْ يَتَوَكَّلُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcmxliv{وَمَآ أَرْسَلْنَا مِن قَبْلِكَ إِلَّا رِجَالًا نُّوحِىٓ إِلَيْهِمْ فَسْـَٔلُوٓا۟ أَهْلَ ٱلذِّكْرِ إِن كُنتُمْ لَا تَعْلَمُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcmxlv{بِٱلْبَيِّنَٰتِ وَٱلزُّبُرِ وَأَنزَلْنَآ إِلَيْكَ ٱلذِّكْرَ لِتُبَيِّنَ لِلنَّاسِ مَا نُزِّلَ إِلَيْهِمْ وَلَعَلَّهُمْ يَتَفَكَّرُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mcmxlvi{أَفَأَمِنَ ٱلَّذِينَ مَكَرُوا۟ ٱلسَّيِّـَٔاتِ أَن يَخْسِفَ ٱللَّهُ بِهِمُ ٱلْأَرْضَ أَوْ يَأْتِيَهُمُ ٱلْعَذَابُ مِنْ حَيْثُ لَا يَشْعُرُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mcmxlvii{أَوْ يَأْخُذَهُمْ فِى تَقَلُّبِهِمْ فَمَا هُم بِمُعْجِزِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mcmxlviii{أَوْ يَأْخُذَهُمْ عَلَىٰ تَخَوُّفٍ فَإِنَّ رَبَّكُمْ لَرَءُوفٌ رَّحِيمٌ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mcmxlix{أَوَلَمْ يَرَوْا۟ إِلَىٰ مَا خَلَقَ ٱللَّهُ مِن شَىْءٍ يَتَفَيَّؤُا۟ ظِلَٰلُهُۥ عَنِ ٱلْيَمِينِ وَٱلشَّمَآئِلِ سُجَّدًا لِّلَّهِ وَهُمْ دَٰخِرُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mcml{وَلِلَّهِ يَسْجُدُ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ مِن دَآبَّةٍ وَٱلْمَلَٰٓئِكَةُ وَهُمْ لَا يَسْتَكْبِرُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mcmli{يَخَافُونَ رَبَّهُم مِّن فَوْقِهِمْ وَيَفْعَلُونَ مَا يُؤْمَرُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mcmlii{وَقَالَ ٱللَّهُ لَا تَتَّخِذُوٓا۟ إِلَٰهَيْنِ ٱثْنَيْنِ إِنَّمَا هُوَ إِلَٰهٌ وَٰحِدٌ فَإِيَّٰىَ فَٱرْهَبُونِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mcmliii{وَلَهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَلَهُ ٱلدِّينُ وَاصِبًا أَفَغَيْرَ ٱللَّهِ تَتَّقُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mcmliv{وَمَا بِكُم مِّن نِّعْمَةٍ فَمِنَ ٱللَّهِ ثُمَّ إِذَا مَسَّكُمُ ٱلضُّرُّ فَإِلَيْهِ تَجْـَٔرُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mcmlv{ثُمَّ إِذَا كَشَفَ ٱلضُّرَّ عَنكُمْ إِذَا فَرِيقٌ مِّنكُم بِرَبِّهِمْ يُشْرِكُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mcmlvi{لِيَكْفُرُوا۟ بِمَآ ءَاتَيْنَٰهُمْ فَتَمَتَّعُوا۟ فَسَوْفَ تَعْلَمُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mcmlvii{وَيَجْعَلُونَ لِمَا لَا يَعْلَمُونَ نَصِيبًا مِّمَّا رَزَقْنَٰهُمْ تَٱللَّهِ لَتُسْـَٔلُنَّ عَمَّا كُنتُمْ تَفْتَرُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mcmlviii{وَيَجْعَلُونَ لِلَّهِ ٱلْبَنَٰتِ سُبْحَٰنَهُۥ وَلَهُم مَّا يَشْتَهُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mcmlix{وَإِذَا بُشِّرَ أَحَدُهُم بِٱلْأُنثَىٰ ظَلَّ وَجْهُهُۥ مُسْوَدًّا وَهُوَ كَظِيمٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mcmlx{يَتَوَٰرَىٰ مِنَ ٱلْقَوْمِ مِن سُوٓءِ مَا بُشِّرَ بِهِۦٓ أَيُمْسِكُهُۥ عَلَىٰ هُونٍ أَمْ يَدُسُّهُۥ فِى ٱلتُّرَابِ أَلَا سَآءَ مَا يَحْكُمُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mcmlxi{لِلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ مَثَلُ ٱلسَّوْءِ وَلِلَّهِ ٱلْمَثَلُ ٱلْأَعْلَىٰ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mcmlxii{وَلَوْ يُؤَاخِذُ ٱللَّهُ ٱلنَّاسَ بِظُلْمِهِم مَّا تَرَكَ عَلَيْهَا مِن دَآبَّةٍ وَلَٰكِن يُؤَخِّرُهُمْ إِلَىٰٓ أَجَلٍ مُّسَمًّى فَإِذَا جَآءَ أَجَلُهُمْ لَا يَسْتَـْٔخِرُونَ سَاعَةً وَلَا يَسْتَقْدِمُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mcmlxiii{وَيَجْعَلُونَ لِلَّهِ مَا يَكْرَهُونَ وَتَصِفُ أَلْسِنَتُهُمُ ٱلْكَذِبَ أَنَّ لَهُمُ ٱلْحُسْنَىٰ لَا جَرَمَ أَنَّ لَهُمُ ٱلنَّارَ وَأَنَّهُم مُّفْرَطُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mcmlxiv{تَٱللَّهِ لَقَدْ أَرْسَلْنَآ إِلَىٰٓ أُمَمٍ مِّن قَبْلِكَ فَزَيَّنَ لَهُمُ ٱلشَّيْطَٰنُ أَعْمَٰلَهُمْ فَهُوَ وَلِيُّهُمُ ٱلْيَوْمَ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mcmlxv{وَمَآ أَنزَلْنَا عَلَيْكَ ٱلْكِتَٰبَ إِلَّا لِتُبَيِّنَ لَهُمُ ٱلَّذِى ٱخْتَلَفُوا۟ فِيهِ وَهُدًى وَرَحْمَةً لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mcmlxvi{وَٱللَّهُ أَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً فَأَحْيَا بِهِ ٱلْأَرْضَ بَعْدَ مَوْتِهَآ إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّقَوْمٍ يَسْمَعُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mcmlxvii{وَإِنَّ لَكُمْ فِى ٱلْأَنْعَٰمِ لَعِبْرَةً نُّسْقِيكُم مِّمَّا فِى بُطُونِهِۦ مِنۢ بَيْنِ فَرْثٍ وَدَمٍ لَّبَنًا خَالِصًا سَآئِغًا لِّلشَّٰرِبِينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mcmlxviii{وَمِن ثَمَرَٰتِ ٱلنَّخِيلِ وَٱلْأَعْنَٰبِ تَتَّخِذُونَ مِنْهُ سَكَرًا وَرِزْقًا حَسَنًا إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّقَوْمٍ يَعْقِلُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mcmlxix{وَأَوْحَىٰ رَبُّكَ إِلَى ٱلنَّحْلِ أَنِ ٱتَّخِذِى مِنَ ٱلْجِبَالِ بُيُوتًا وَمِنَ ٱلشَّجَرِ وَمِمَّا يَعْرِشُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mcmlxx{ثُمَّ كُلِى مِن كُلِّ ٱلثَّمَرَٰتِ فَٱسْلُكِى سُبُلَ رَبِّكِ ذُلُلًا يَخْرُجُ مِنۢ بُطُونِهَا شَرَابٌ مُّخْتَلِفٌ أَلْوَٰنُهُۥ فِيهِ شِفَآءٌ لِّلنَّاسِ إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّقَوْمٍ يَتَفَكَّرُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mcmlxxi{وَٱللَّهُ خَلَقَكُمْ ثُمَّ يَتَوَفَّىٰكُمْ وَمِنكُم مَّن يُرَدُّ إِلَىٰٓ أَرْذَلِ ٱلْعُمُرِ لِكَىْ لَا يَعْلَمَ بَعْدَ عِلْمٍ شَيْـًٔا إِنَّ ٱللَّهَ عَلِيمٌ قَدِيرٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mcmlxxii{وَٱللَّهُ فَضَّلَ بَعْضَكُمْ عَلَىٰ بَعْضٍ فِى ٱلرِّزْقِ فَمَا ٱلَّذِينَ فُضِّلُوا۟ بِرَآدِّى رِزْقِهِمْ عَلَىٰ مَا مَلَكَتْ أَيْمَٰنُهُمْ فَهُمْ فِيهِ سَوَآءٌ أَفَبِنِعْمَةِ ٱللَّهِ يَجْحَدُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mcmlxxiii{وَٱللَّهُ جَعَلَ لَكُم مِّنْ أَنفُسِكُمْ أَزْوَٰجًا وَجَعَلَ لَكُم مِّنْ أَزْوَٰجِكُم بَنِينَ وَحَفَدَةً وَرَزَقَكُم مِّنَ ٱلطَّيِّبَٰتِ أَفَبِٱلْبَٰطِلِ يُؤْمِنُونَ وَبِنِعْمَتِ ٱللَّهِ هُمْ يَكْفُرُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mcmlxxiv{وَيَعْبُدُونَ مِن دُونِ ٱللَّهِ مَا لَا يَمْلِكُ لَهُمْ رِزْقًا مِّنَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ شَيْـًٔا وَلَا يَسْتَطِيعُونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mcmlxxv{فَلَا تَضْرِبُوا۟ لِلَّهِ ٱلْأَمْثَالَ إِنَّ ٱللَّهَ يَعْلَمُ وَأَنتُمْ لَا تَعْلَمُونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mcmlxxvi{ضَرَبَ ٱللَّهُ مَثَلًا عَبْدًا مَّمْلُوكًا لَّا يَقْدِرُ عَلَىٰ شَىْءٍ وَمَن رَّزَقْنَٰهُ مِنَّا رِزْقًا حَسَنًا فَهُوَ يُنفِقُ مِنْهُ سِرًّا وَجَهْرًا هَلْ يَسْتَوُۥنَ ٱلْحَمْدُ لِلَّهِ بَلْ أَكْثَرُهُمْ لَا يَعْلَمُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mcmlxxvii{وَضَرَبَ ٱللَّهُ مَثَلًا رَّجُلَيْنِ أَحَدُهُمَآ أَبْكَمُ لَا يَقْدِرُ عَلَىٰ شَىْءٍ وَهُوَ كَلٌّ عَلَىٰ مَوْلَىٰهُ أَيْنَمَا يُوَجِّههُّ لَا يَأْتِ بِخَيْرٍ هَلْ يَسْتَوِى هُوَ وَمَن يَأْمُرُ بِٱلْعَدْلِ وَهُوَ عَلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mcmlxxviii{وَلِلَّهِ غَيْبُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَآ أَمْرُ ٱلسَّاعَةِ إِلَّا كَلَمْحِ ٱلْبَصَرِ أَوْ هُوَ أَقْرَبُ إِنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mcmlxxix{وَٱللَّهُ أَخْرَجَكُم مِّنۢ بُطُونِ أُمَّهَٰتِكُمْ لَا تَعْلَمُونَ شَيْـًٔا وَجَعَلَ لَكُمُ ٱلسَّمْعَ وَٱلْأَبْصَٰرَ وَٱلْأَفْـِٔدَةَ لَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mcmlxxx{أَلَمْ يَرَوْا۟ إِلَى ٱلطَّيْرِ مُسَخَّرَٰتٍ فِى جَوِّ ٱلسَّمَآءِ مَا يُمْسِكُهُنَّ إِلَّا ٱللَّهُ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mcmlxxxi{وَٱللَّهُ جَعَلَ لَكُم مِّنۢ بُيُوتِكُمْ سَكَنًا وَجَعَلَ لَكُم مِّن جُلُودِ ٱلْأَنْعَٰمِ بُيُوتًا تَسْتَخِفُّونَهَا يَوْمَ ظَعْنِكُمْ وَيَوْمَ إِقَامَتِكُمْ وَمِنْ أَصْوَافِهَا وَأَوْبَارِهَا وَأَشْعَارِهَآ أَثَٰثًا وَمَتَٰعًا إِلَىٰ حِينٍ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mcmlxxxii{وَٱللَّهُ جَعَلَ لَكُم مِّمَّا خَلَقَ ظِلَٰلًا وَجَعَلَ لَكُم مِّنَ ٱلْجِبَالِ أَكْنَٰنًا وَجَعَلَ لَكُمْ سَرَٰبِيلَ تَقِيكُمُ ٱلْحَرَّ وَسَرَٰبِيلَ تَقِيكُم بَأْسَكُمْ كَذَٰلِكَ يُتِمُّ نِعْمَتَهُۥ عَلَيْكُمْ لَعَلَّكُمْ تُسْلِمُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mcmlxxxiii{فَإِن تَوَلَّوْا۟ فَإِنَّمَا عَلَيْكَ ٱلْبَلَٰغُ ٱلْمُبِينُ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mcmlxxxiv{يَعْرِفُونَ نِعْمَتَ ٱللَّهِ ثُمَّ يُنكِرُونَهَا وَأَكْثَرُهُمُ ٱلْكَٰفِرُونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mcmlxxxv{وَيَوْمَ نَبْعَثُ مِن كُلِّ أُمَّةٍ شَهِيدًا ثُمَّ لَا يُؤْذَنُ لِلَّذِينَ كَفَرُوا۟ وَلَا هُمْ يُسْتَعْتَبُونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mcmlxxxvi{وَإِذَا رَءَا ٱلَّذِينَ ظَلَمُوا۟ ٱلْعَذَابَ فَلَا يُخَفَّفُ عَنْهُمْ وَلَا هُمْ يُنظَرُونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mcmlxxxvii{وَإِذَا رَءَا ٱلَّذِينَ أَشْرَكُوا۟ شُرَكَآءَهُمْ قَالُوا۟ رَبَّنَا هَٰٓؤُلَآءِ شُرَكَآؤُنَا ٱلَّذِينَ كُنَّا نَدْعُوا۟ مِن دُونِكَ فَأَلْقَوْا۟ إِلَيْهِمُ ٱلْقَوْلَ إِنَّكُمْ لَكَٰذِبُونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mcmlxxxviii{وَأَلْقَوْا۟ إِلَى ٱللَّهِ يَوْمَئِذٍ ٱلسَّلَمَ وَضَلَّ عَنْهُم مَّا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mcmlxxxix{ٱلَّذِينَ كَفَرُوا۟ وَصَدُّوا۟ عَن سَبِيلِ ٱللَّهِ زِدْنَٰهُمْ عَذَابًا فَوْقَ ٱلْعَذَابِ بِمَا كَانُوا۟ يُفْسِدُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mcmxc{وَيَوْمَ نَبْعَثُ فِى كُلِّ أُمَّةٍ شَهِيدًا عَلَيْهِم مِّنْ أَنفُسِهِمْ وَجِئْنَا بِكَ شَهِيدًا عَلَىٰ هَٰٓؤُلَآءِ وَنَزَّلْنَا عَلَيْكَ ٱلْكِتَٰبَ تِبْيَٰنًا لِّكُلِّ شَىْءٍ وَهُدًى وَرَحْمَةً وَبُشْرَىٰ لِلْمُسْلِمِينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mcmxci{إِنَّ ٱللَّهَ يَأْمُرُ بِٱلْعَدْلِ وَٱلْإِحْسَٰنِ وَإِيتَآئِ ذِى ٱلْقُرْبَىٰ وَيَنْهَىٰ عَنِ ٱلْفَحْشَآءِ وَٱلْمُنكَرِ وَٱلْبَغْىِ يَعِظُكُمْ لَعَلَّكُمْ تَذَكَّرُونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mcmxcii{وَأَوْفُوا۟ بِعَهْدِ ٱللَّهِ إِذَا عَٰهَدتُّمْ وَلَا تَنقُضُوا۟ ٱلْأَيْمَٰنَ بَعْدَ تَوْكِيدِهَا وَقَدْ جَعَلْتُمُ ٱللَّهَ عَلَيْكُمْ كَفِيلًا إِنَّ ٱللَّهَ يَعْلَمُ مَا تَفْعَلُونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mcmxciii{وَلَا تَكُونُوا۟ كَٱلَّتِى نَقَضَتْ غَزْلَهَا مِنۢ بَعْدِ قُوَّةٍ أَنكَٰثًا تَتَّخِذُونَ أَيْمَٰنَكُمْ دَخَلًۢا بَيْنَكُمْ أَن تَكُونَ أُمَّةٌ هِىَ أَرْبَىٰ مِنْ أُمَّةٍ إِنَّمَا يَبْلُوكُمُ ٱللَّهُ بِهِۦ وَلَيُبَيِّنَنَّ لَكُمْ يَوْمَ ٱلْقِيَٰمَةِ مَا كُنتُمْ فِيهِ تَخْتَلِفُونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mcmxciv{وَلَوْ شَآءَ ٱللَّهُ لَجَعَلَكُمْ أُمَّةً وَٰحِدَةً وَلَٰكِن يُضِلُّ مَن يَشَآءُ وَيَهْدِى مَن يَشَآءُ وَلَتُسْـَٔلُنَّ عَمَّا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mcmxcv{وَلَا تَتَّخِذُوٓا۟ أَيْمَٰنَكُمْ دَخَلًۢا بَيْنَكُمْ فَتَزِلَّ قَدَمٌۢ بَعْدَ ثُبُوتِهَا وَتَذُوقُوا۟ ٱلسُّوٓءَ بِمَا صَدَدتُّمْ عَن سَبِيلِ ٱللَّهِ وَلَكُمْ عَذَابٌ عَظِيمٌ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mcmxcvi{وَلَا تَشْتَرُوا۟ بِعَهْدِ ٱللَّهِ ثَمَنًا قَلِيلًا إِنَّمَا عِندَ ٱللَّهِ هُوَ خَيْرٌ لَّكُمْ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mcmxcvii{مَا عِندَكُمْ يَنفَدُ وَمَا عِندَ ٱللَّهِ بَاقٍ وَلَنَجْزِيَنَّ ٱلَّذِينَ صَبَرُوٓا۟ أَجْرَهُم بِأَحْسَنِ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mcmxcviii{مَنْ عَمِلَ صَٰلِحًا مِّن ذَكَرٍ أَوْ أُنثَىٰ وَهُوَ مُؤْمِنٌ فَلَنُحْيِيَنَّهُۥ حَيَوٰةً طَيِّبَةً وَلَنَجْزِيَنَّهُمْ أَجْرَهُم بِأَحْسَنِ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcmxcix{فَإِذَا قَرَأْتَ ٱلْقُرْءَانَ فَٱسْتَعِذْ بِٱللَّهِ مِنَ ٱلشَّيْطَٰنِ ٱلرَّجِيمِ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mm{إِنَّهُۥ لَيْسَ لَهُۥ سُلْطَٰنٌ عَلَى ٱلَّذِينَ ءَامَنُوا۟ وَعَلَىٰ رَبِّهِمْ يَتَوَكَّلُونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmi{إِنَّمَا سُلْطَٰنُهُۥ عَلَى ٱلَّذِينَ يَتَوَلَّوْنَهُۥ وَٱلَّذِينَ هُم بِهِۦ مُشْرِكُونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmii{وَإِذَا بَدَّلْنَآ ءَايَةً مَّكَانَ ءَايَةٍ وَٱللَّهُ أَعْلَمُ بِمَا يُنَزِّلُ قَالُوٓا۟ إِنَّمَآ أَنتَ مُفْتَرٍۭ بَلْ أَكْثَرُهُمْ لَا يَعْلَمُونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmiii{قُلْ نَزَّلَهُۥ رُوحُ ٱلْقُدُسِ مِن رَّبِّكَ بِٱلْحَقِّ لِيُثَبِّتَ ٱلَّذِينَ ءَامَنُوا۟ وَهُدًى وَبُشْرَىٰ لِلْمُسْلِمِينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmiv{وَلَقَدْ نَعْلَمُ أَنَّهُمْ يَقُولُونَ إِنَّمَا يُعَلِّمُهُۥ بَشَرٌ لِّسَانُ ٱلَّذِى يُلْحِدُونَ إِلَيْهِ أَعْجَمِىٌّ وَهَٰذَا لِسَانٌ عَرَبِىٌّ مُّبِينٌ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmv{إِنَّ ٱلَّذِينَ لَا يُؤْمِنُونَ بِـَٔايَٰتِ ٱللَّهِ لَا يَهْدِيهِمُ ٱللَّهُ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmvi{إِنَّمَا يَفْتَرِى ٱلْكَذِبَ ٱلَّذِينَ لَا يُؤْمِنُونَ بِـَٔايَٰتِ ٱللَّهِ وَأُو۟لَٰٓئِكَ هُمُ ٱلْكَٰذِبُونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmvii{مَن كَفَرَ بِٱللَّهِ مِنۢ بَعْدِ إِيمَٰنِهِۦٓ إِلَّا مَنْ أُكْرِهَ وَقَلْبُهُۥ مُطْمَئِنٌّۢ بِٱلْإِيمَٰنِ وَلَٰكِن مَّن شَرَحَ بِٱلْكُفْرِ صَدْرًا فَعَلَيْهِمْ غَضَبٌ مِّنَ ٱللَّهِ وَلَهُمْ عَذَابٌ عَظِيمٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmviii{ذَٰلِكَ بِأَنَّهُمُ ٱسْتَحَبُّوا۟ ٱلْحَيَوٰةَ ٱلدُّنْيَا عَلَى ٱلْءَاخِرَةِ وَأَنَّ ٱللَّهَ لَا يَهْدِى ٱلْقَوْمَ ٱلْكَٰفِرِينَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmix{أُو۟لَٰٓئِكَ ٱلَّذِينَ طَبَعَ ٱللَّهُ عَلَىٰ قُلُوبِهِمْ وَسَمْعِهِمْ وَأَبْصَٰرِهِمْ وَأُو۟لَٰٓئِكَ هُمُ ٱلْغَٰفِلُونَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmx{لَا جَرَمَ أَنَّهُمْ فِى ٱلْءَاخِرَةِ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmxi{ثُمَّ إِنَّ رَبَّكَ لِلَّذِينَ هَاجَرُوا۟ مِنۢ بَعْدِ مَا فُتِنُوا۟ ثُمَّ جَٰهَدُوا۟ وَصَبَرُوٓا۟ إِنَّ رَبَّكَ مِنۢ بَعْدِهَا لَغَفُورٌ رَّحِيمٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmxii{يَوْمَ تَأْتِى كُلُّ نَفْسٍ تُجَٰدِلُ عَن نَّفْسِهَا وَتُوَفَّىٰ كُلُّ نَفْسٍ مَّا عَمِلَتْ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmxiii{وَضَرَبَ ٱللَّهُ مَثَلًا قَرْيَةً كَانَتْ ءَامِنَةً مُّطْمَئِنَّةً يَأْتِيهَا رِزْقُهَا رَغَدًا مِّن كُلِّ مَكَانٍ فَكَفَرَتْ بِأَنْعُمِ ٱللَّهِ فَأَذَٰقَهَا ٱللَّهُ لِبَاسَ ٱلْجُوعِ وَٱلْخَوْفِ بِمَا كَانُوا۟ يَصْنَعُونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmxiv{وَلَقَدْ جَآءَهُمْ رَسُولٌ مِّنْهُمْ فَكَذَّبُوهُ فَأَخَذَهُمُ ٱلْعَذَابُ وَهُمْ ظَٰلِمُونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmxv{فَكُلُوا۟ مِمَّا رَزَقَكُمُ ٱللَّهُ حَلَٰلًا طَيِّبًا وَٱشْكُرُوا۟ نِعْمَتَ ٱللَّهِ إِن كُنتُمْ إِيَّاهُ تَعْبُدُونَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmxvi{إِنَّمَا حَرَّمَ عَلَيْكُمُ ٱلْمَيْتَةَ وَٱلدَّمَ وَلَحْمَ ٱلْخِنزِيرِ وَمَآ أُهِلَّ لِغَيْرِ ٱللَّهِ بِهِۦ فَمَنِ ٱضْطُرَّ غَيْرَ بَاغٍ وَلَا عَادٍ فَإِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmxvii{وَلَا تَقُولُوا۟ لِمَا تَصِفُ أَلْسِنَتُكُمُ ٱلْكَذِبَ هَٰذَا حَلَٰلٌ وَهَٰذَا حَرَامٌ لِّتَفْتَرُوا۟ عَلَى ٱللَّهِ ٱلْكَذِبَ إِنَّ ٱلَّذِينَ يَفْتَرُونَ عَلَى ٱللَّهِ ٱلْكَذِبَ لَا يُفْلِحُونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmxviii{مَتَٰعٌ قَلِيلٌ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmxix{وَعَلَى ٱلَّذِينَ هَادُوا۟ حَرَّمْنَا مَا قَصَصْنَا عَلَيْكَ مِن قَبْلُ وَمَا ظَلَمْنَٰهُمْ وَلَٰكِن كَانُوٓا۟ أَنفُسَهُمْ يَظْلِمُونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmxx{ثُمَّ إِنَّ رَبَّكَ لِلَّذِينَ عَمِلُوا۟ ٱلسُّوٓءَ بِجَهَٰلَةٍ ثُمَّ تَابُوا۟ مِنۢ بَعْدِ ذَٰلِكَ وَأَصْلَحُوٓا۟ إِنَّ رَبَّكَ مِنۢ بَعْدِهَا لَغَفُورٌ رَّحِيمٌ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmxxi{إِنَّ إِبْرَٰهِيمَ كَانَ أُمَّةً قَانِتًا لِّلَّهِ حَنِيفًا وَلَمْ يَكُ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmxxii{شَاكِرًا لِّأَنْعُمِهِ ٱجْتَبَىٰهُ وَهَدَىٰهُ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmxxiii{وَءَاتَيْنَٰهُ فِى ٱلدُّنْيَا حَسَنَةً وَإِنَّهُۥ فِى ٱلْءَاخِرَةِ لَمِنَ ٱلصَّٰلِحِينَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmxxiv{ثُمَّ أَوْحَيْنَآ إِلَيْكَ أَنِ ٱتَّبِعْ مِلَّةَ إِبْرَٰهِيمَ حَنِيفًا وَمَا كَانَ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmxxv{إِنَّمَا جُعِلَ ٱلسَّبْتُ عَلَى ٱلَّذِينَ ٱخْتَلَفُوا۟ فِيهِ وَإِنَّ رَبَّكَ لَيَحْكُمُ بَيْنَهُمْ يَوْمَ ٱلْقِيَٰمَةِ فِيمَا كَانُوا۟ فِيهِ يَخْتَلِفُونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmxxvi{ٱدْعُ إِلَىٰ سَبِيلِ رَبِّكَ بِٱلْحِكْمَةِ وَٱلْمَوْعِظَةِ ٱلْحَسَنَةِ وَجَٰدِلْهُم بِٱلَّتِى هِىَ أَحْسَنُ إِنَّ رَبَّكَ هُوَ أَعْلَمُ بِمَن ضَلَّ عَن سَبِيلِهِۦ وَهُوَ أَعْلَمُ بِٱلْمُهْتَدِينَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmxxvii{وَإِنْ عَاقَبْتُمْ فَعَاقِبُوا۟ بِمِثْلِ مَا عُوقِبْتُم بِهِۦ وَلَئِن صَبَرْتُمْ لَهُوَ خَيْرٌ لِّلصَّٰبِرِينَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmxxviii{وَٱصْبِرْ وَمَا صَبْرُكَ إِلَّا بِٱللَّهِ وَلَا تَحْزَنْ عَلَيْهِمْ وَلَا تَكُ فِى ضَيْقٍ مِّمَّا يَمْكُرُونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmxxix{إِنَّ ٱللَّهَ مَعَ ٱلَّذِينَ ٱتَّقَوا۟ وَّٱلَّذِينَ هُم مُّحْسِنُونَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmxxx{\basmalah سُبْحَٰنَ ٱلَّذِىٓ أَسْرَىٰ بِعَبْدِهِۦ لَيْلًا مِّنَ ٱلْمَسْجِدِ ٱلْحَرَامِ إِلَى ٱلْمَسْجِدِ ٱلْأَقْصَا ٱلَّذِى بَٰرَكْنَا حَوْلَهُۥ لِنُرِيَهُۥ مِنْ ءَايَٰتِنَآ إِنَّهُۥ هُوَ ٱلسَّمِيعُ ٱلْبَصِيرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmxxxi{وَءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ وَجَعَلْنَٰهُ هُدًى لِّبَنِىٓ إِسْرَٰٓءِيلَ أَلَّا تَتَّخِذُوا۟ مِن دُونِى وَكِيلًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmxxxii{ذُرِّيَّةَ مَنْ حَمَلْنَا مَعَ نُوحٍ إِنَّهُۥ كَانَ عَبْدًا شَكُورًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmxxxiii{وَقَضَيْنَآ إِلَىٰ بَنِىٓ إِسْرَٰٓءِيلَ فِى ٱلْكِتَٰبِ لَتُفْسِدُنَّ فِى ٱلْأَرْضِ مَرَّتَيْنِ وَلَتَعْلُنَّ عُلُوًّا كَبِيرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmxxxiv{فَإِذَا جَآءَ وَعْدُ أُولَىٰهُمَا بَعَثْنَا عَلَيْكُمْ عِبَادًا لَّنَآ أُو۟لِى بَأْسٍ شَدِيدٍ فَجَاسُوا۟ خِلَٰلَ ٱلدِّيَارِ وَكَانَ وَعْدًا مَّفْعُولًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmxxxv{ثُمَّ رَدَدْنَا لَكُمُ ٱلْكَرَّةَ عَلَيْهِمْ وَأَمْدَدْنَٰكُم بِأَمْوَٰلٍ وَبَنِينَ وَجَعَلْنَٰكُمْ أَكْثَرَ نَفِيرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmxxxvi{إِنْ أَحْسَنتُمْ أَحْسَنتُمْ لِأَنفُسِكُمْ وَإِنْ أَسَأْتُمْ فَلَهَا فَإِذَا جَآءَ وَعْدُ ٱلْءَاخِرَةِ لِيَسُۥٓـُٔوا۟ وُجُوهَكُمْ وَلِيَدْخُلُوا۟ ٱلْمَسْجِدَ كَمَا دَخَلُوهُ أَوَّلَ مَرَّةٍ وَلِيُتَبِّرُوا۟ مَا عَلَوْا۟ تَتْبِيرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmxxxvii{عَسَىٰ رَبُّكُمْ أَن يَرْحَمَكُمْ وَإِنْ عُدتُّمْ عُدْنَا وَجَعَلْنَا جَهَنَّمَ لِلْكَٰفِرِينَ حَصِيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmxxxviii{إِنَّ هَٰذَا ٱلْقُرْءَانَ يَهْدِى لِلَّتِى هِىَ أَقْوَمُ وَيُبَشِّرُ ٱلْمُؤْمِنِينَ ٱلَّذِينَ يَعْمَلُونَ ٱلصَّٰلِحَٰتِ أَنَّ لَهُمْ أَجْرًا كَبِيرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmxxxix{وَأَنَّ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ أَعْتَدْنَا لَهُمْ عَذَابًا أَلِيمًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmxl{وَيَدْعُ ٱلْإِنسَٰنُ بِٱلشَّرِّ دُعَآءَهُۥ بِٱلْخَيْرِ وَكَانَ ٱلْإِنسَٰنُ عَجُولًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmxli{وَجَعَلْنَا ٱلَّيْلَ وَٱلنَّهَارَ ءَايَتَيْنِ فَمَحَوْنَآ ءَايَةَ ٱلَّيْلِ وَجَعَلْنَآ ءَايَةَ ٱلنَّهَارِ مُبْصِرَةً لِّتَبْتَغُوا۟ فَضْلًا مِّن رَّبِّكُمْ وَلِتَعْلَمُوا۟ عَدَدَ ٱلسِّنِينَ وَٱلْحِسَابَ وَكُلَّ شَىْءٍ فَصَّلْنَٰهُ تَفْصِيلًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmxlii{وَكُلَّ إِنسَٰنٍ أَلْزَمْنَٰهُ طَٰٓئِرَهُۥ فِى عُنُقِهِۦ وَنُخْرِجُ لَهُۥ يَوْمَ ٱلْقِيَٰمَةِ كِتَٰبًا يَلْقَىٰهُ مَنشُورًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmxliii{ٱقْرَأْ كِتَٰبَكَ كَفَىٰ بِنَفْسِكَ ٱلْيَوْمَ عَلَيْكَ حَسِيبًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmxliv{مَّنِ ٱهْتَدَىٰ فَإِنَّمَا يَهْتَدِى لِنَفْسِهِۦ وَمَن ضَلَّ فَإِنَّمَا يَضِلُّ عَلَيْهَا وَلَا تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَىٰ وَمَا كُنَّا مُعَذِّبِينَ حَتَّىٰ نَبْعَثَ رَسُولًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmxlv{وَإِذَآ أَرَدْنَآ أَن نُّهْلِكَ قَرْيَةً أَمَرْنَا مُتْرَفِيهَا فَفَسَقُوا۟ فِيهَا فَحَقَّ عَلَيْهَا ٱلْقَوْلُ فَدَمَّرْنَٰهَا تَدْمِيرًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmxlvi{وَكَمْ أَهْلَكْنَا مِنَ ٱلْقُرُونِ مِنۢ بَعْدِ نُوحٍ وَكَفَىٰ بِرَبِّكَ بِذُنُوبِ عِبَادِهِۦ خَبِيرًۢا بَصِيرًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmxlvii{مَّن كَانَ يُرِيدُ ٱلْعَاجِلَةَ عَجَّلْنَا لَهُۥ فِيهَا مَا نَشَآءُ لِمَن نُّرِيدُ ثُمَّ جَعَلْنَا لَهُۥ جَهَنَّمَ يَصْلَىٰهَا مَذْمُومًا مَّدْحُورًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmxlviii{وَمَنْ أَرَادَ ٱلْءَاخِرَةَ وَسَعَىٰ لَهَا سَعْيَهَا وَهُوَ مُؤْمِنٌ فَأُو۟لَٰٓئِكَ كَانَ سَعْيُهُم مَّشْكُورًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmxlix{كُلًّا نُّمِدُّ هَٰٓؤُلَآءِ وَهَٰٓؤُلَآءِ مِنْ عَطَآءِ رَبِّكَ وَمَا كَانَ عَطَآءُ رَبِّكَ مَحْظُورًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mml{ٱنظُرْ كَيْفَ فَضَّلْنَا بَعْضَهُمْ عَلَىٰ بَعْضٍ وَلَلْءَاخِرَةُ أَكْبَرُ دَرَجَٰتٍ وَأَكْبَرُ تَفْضِيلًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmli{لَّا تَجْعَلْ مَعَ ٱللَّهِ إِلَٰهًا ءَاخَرَ فَتَقْعُدَ مَذْمُومًا مَّخْذُولًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmlii{وَقَضَىٰ رَبُّكَ أَلَّا تَعْبُدُوٓا۟ إِلَّآ إِيَّاهُ وَبِٱلْوَٰلِدَيْنِ إِحْسَٰنًا إِمَّا يَبْلُغَنَّ عِندَكَ ٱلْكِبَرَ أَحَدُهُمَآ أَوْ كِلَاهُمَا فَلَا تَقُل لَّهُمَآ أُفٍّ وَلَا تَنْهَرْهُمَا وَقُل لَّهُمَا قَوْلًا كَرِيمًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmliii{وَٱخْفِضْ لَهُمَا جَنَاحَ ٱلذُّلِّ مِنَ ٱلرَّحْمَةِ وَقُل رَّبِّ ٱرْحَمْهُمَا كَمَا رَبَّيَانِى صَغِيرًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmliv{رَّبُّكُمْ أَعْلَمُ بِمَا فِى نُفُوسِكُمْ إِن تَكُونُوا۟ صَٰلِحِينَ فَإِنَّهُۥ كَانَ لِلْأَوَّٰبِينَ غَفُورًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmlv{وَءَاتِ ذَا ٱلْقُرْبَىٰ حَقَّهُۥ وَٱلْمِسْكِينَ وَٱبْنَ ٱلسَّبِيلِ وَلَا تُبَذِّرْ تَبْذِيرًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmlvi{إِنَّ ٱلْمُبَذِّرِينَ كَانُوٓا۟ إِخْوَٰنَ ٱلشَّيَٰطِينِ وَكَانَ ٱلشَّيْطَٰنُ لِرَبِّهِۦ كَفُورًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmlvii{وَإِمَّا تُعْرِضَنَّ عَنْهُمُ ٱبْتِغَآءَ رَحْمَةٍ مِّن رَّبِّكَ تَرْجُوهَا فَقُل لَّهُمْ قَوْلًا مَّيْسُورًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmlviii{وَلَا تَجْعَلْ يَدَكَ مَغْلُولَةً إِلَىٰ عُنُقِكَ وَلَا تَبْسُطْهَا كُلَّ ٱلْبَسْطِ فَتَقْعُدَ مَلُومًا مَّحْسُورًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmlix{إِنَّ رَبَّكَ يَبْسُطُ ٱلرِّزْقَ لِمَن يَشَآءُ وَيَقْدِرُ إِنَّهُۥ كَانَ بِعِبَادِهِۦ خَبِيرًۢا بَصِيرًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmlx{وَلَا تَقْتُلُوٓا۟ أَوْلَٰدَكُمْ خَشْيَةَ إِمْلَٰقٍ نَّحْنُ نَرْزُقُهُمْ وَإِيَّاكُمْ إِنَّ قَتْلَهُمْ كَانَ خِطْـًٔا كَبِيرًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmlxi{وَلَا تَقْرَبُوا۟ ٱلزِّنَىٰٓ إِنَّهُۥ كَانَ فَٰحِشَةً وَسَآءَ سَبِيلًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmlxii{وَلَا تَقْتُلُوا۟ ٱلنَّفْسَ ٱلَّتِى حَرَّمَ ٱللَّهُ إِلَّا بِٱلْحَقِّ وَمَن قُتِلَ مَظْلُومًا فَقَدْ جَعَلْنَا لِوَلِيِّهِۦ سُلْطَٰنًا فَلَا يُسْرِف فِّى ٱلْقَتْلِ إِنَّهُۥ كَانَ مَنصُورًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmlxiii{وَلَا تَقْرَبُوا۟ مَالَ ٱلْيَتِيمِ إِلَّا بِٱلَّتِى هِىَ أَحْسَنُ حَتَّىٰ يَبْلُغَ أَشُدَّهُۥ وَأَوْفُوا۟ بِٱلْعَهْدِ إِنَّ ٱلْعَهْدَ كَانَ مَسْـُٔولًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmlxiv{وَأَوْفُوا۟ ٱلْكَيْلَ إِذَا كِلْتُمْ وَزِنُوا۟ بِٱلْقِسْطَاسِ ٱلْمُسْتَقِيمِ ذَٰلِكَ خَيْرٌ وَأَحْسَنُ تَأْوِيلًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmlxv{وَلَا تَقْفُ مَا لَيْسَ لَكَ بِهِۦ عِلْمٌ إِنَّ ٱلسَّمْعَ وَٱلْبَصَرَ وَٱلْفُؤَادَ كُلُّ أُو۟لَٰٓئِكَ كَانَ عَنْهُ مَسْـُٔولًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmlxvi{وَلَا تَمْشِ فِى ٱلْأَرْضِ مَرَحًا إِنَّكَ لَن تَخْرِقَ ٱلْأَرْضَ وَلَن تَبْلُغَ ٱلْجِبَالَ طُولًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmlxvii{كُلُّ ذَٰلِكَ كَانَ سَيِّئُهُۥ عِندَ رَبِّكَ مَكْرُوهًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmlxviii{ذَٰلِكَ مِمَّآ أَوْحَىٰٓ إِلَيْكَ رَبُّكَ مِنَ ٱلْحِكْمَةِ وَلَا تَجْعَلْ مَعَ ٱللَّهِ إِلَٰهًا ءَاخَرَ فَتُلْقَىٰ فِى جَهَنَّمَ مَلُومًا مَّدْحُورًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmlxix{أَفَأَصْفَىٰكُمْ رَبُّكُم بِٱلْبَنِينَ وَٱتَّخَذَ مِنَ ٱلْمَلَٰٓئِكَةِ إِنَٰثًا إِنَّكُمْ لَتَقُولُونَ قَوْلًا عَظِيمًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmlxx{وَلَقَدْ صَرَّفْنَا فِى هَٰذَا ٱلْقُرْءَانِ لِيَذَّكَّرُوا۟ وَمَا يَزِيدُهُمْ إِلَّا نُفُورًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmlxxi{قُل لَّوْ كَانَ مَعَهُۥٓ ءَالِهَةٌ كَمَا يَقُولُونَ إِذًا لَّٱبْتَغَوْا۟ إِلَىٰ ذِى ٱلْعَرْشِ سَبِيلًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmlxxii{سُبْحَٰنَهُۥ وَتَعَٰلَىٰ عَمَّا يَقُولُونَ عُلُوًّا كَبِيرًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmlxxiii{تُسَبِّحُ لَهُ ٱلسَّمَٰوَٰتُ ٱلسَّبْعُ وَٱلْأَرْضُ وَمَن فِيهِنَّ وَإِن مِّن شَىْءٍ إِلَّا يُسَبِّحُ بِحَمْدِهِۦ وَلَٰكِن لَّا تَفْقَهُونَ تَسْبِيحَهُمْ إِنَّهُۥ كَانَ حَلِيمًا غَفُورًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmlxxiv{وَإِذَا قَرَأْتَ ٱلْقُرْءَانَ جَعَلْنَا بَيْنَكَ وَبَيْنَ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ حِجَابًا مَّسْتُورًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmlxxv{وَجَعَلْنَا عَلَىٰ قُلُوبِهِمْ أَكِنَّةً أَن يَفْقَهُوهُ وَفِىٓ ءَاذَانِهِمْ وَقْرًا وَإِذَا ذَكَرْتَ رَبَّكَ فِى ٱلْقُرْءَانِ وَحْدَهُۥ وَلَّوْا۟ عَلَىٰٓ أَدْبَٰرِهِمْ نُفُورًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmlxxvi{نَّحْنُ أَعْلَمُ بِمَا يَسْتَمِعُونَ بِهِۦٓ إِذْ يَسْتَمِعُونَ إِلَيْكَ وَإِذْ هُمْ نَجْوَىٰٓ إِذْ يَقُولُ ٱلظَّٰلِمُونَ إِن تَتَّبِعُونَ إِلَّا رَجُلًا مَّسْحُورًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmlxxvii{ٱنظُرْ كَيْفَ ضَرَبُوا۟ لَكَ ٱلْأَمْثَالَ فَضَلُّوا۟ فَلَا يَسْتَطِيعُونَ سَبِيلًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmlxxviii{وَقَالُوٓا۟ أَءِذَا كُنَّا عِظَٰمًا وَرُفَٰتًا أَءِنَّا لَمَبْعُوثُونَ خَلْقًا جَدِيدًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmlxxix{قُلْ كُونُوا۟ حِجَارَةً أَوْ حَدِيدًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmlxxx{أَوْ خَلْقًا مِّمَّا يَكْبُرُ فِى صُدُورِكُمْ فَسَيَقُولُونَ مَن يُعِيدُنَا قُلِ ٱلَّذِى فَطَرَكُمْ أَوَّلَ مَرَّةٍ فَسَيُنْغِضُونَ إِلَيْكَ رُءُوسَهُمْ وَيَقُولُونَ مَتَىٰ هُوَ قُلْ عَسَىٰٓ أَن يَكُونَ قَرِيبًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmlxxxi{يَوْمَ يَدْعُوكُمْ فَتَسْتَجِيبُونَ بِحَمْدِهِۦ وَتَظُنُّونَ إِن لَّبِثْتُمْ إِلَّا قَلِيلًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmlxxxii{وَقُل لِّعِبَادِى يَقُولُوا۟ ٱلَّتِى هِىَ أَحْسَنُ إِنَّ ٱلشَّيْطَٰنَ يَنزَغُ بَيْنَهُمْ إِنَّ ٱلشَّيْطَٰنَ كَانَ لِلْإِنسَٰنِ عَدُوًّا مُّبِينًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmlxxxiii{رَّبُّكُمْ أَعْلَمُ بِكُمْ إِن يَشَأْ يَرْحَمْكُمْ أَوْ إِن يَشَأْ يُعَذِّبْكُمْ وَمَآ أَرْسَلْنَٰكَ عَلَيْهِمْ وَكِيلًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmlxxxiv{وَرَبُّكَ أَعْلَمُ بِمَن فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَلَقَدْ فَضَّلْنَا بَعْضَ ٱلنَّبِيِّۦنَ عَلَىٰ بَعْضٍ وَءَاتَيْنَا دَاوُۥدَ زَبُورًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmlxxxv{قُلِ ٱدْعُوا۟ ٱلَّذِينَ زَعَمْتُم مِّن دُونِهِۦ فَلَا يَمْلِكُونَ كَشْفَ ٱلضُّرِّ عَنكُمْ وَلَا تَحْوِيلًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmlxxxvi{أُو۟لَٰٓئِكَ ٱلَّذِينَ يَدْعُونَ يَبْتَغُونَ إِلَىٰ رَبِّهِمُ ٱلْوَسِيلَةَ أَيُّهُمْ أَقْرَبُ وَيَرْجُونَ رَحْمَتَهُۥ وَيَخَافُونَ عَذَابَهُۥٓ إِنَّ عَذَابَ رَبِّكَ كَانَ مَحْذُورًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmlxxxvii{وَإِن مِّن قَرْيَةٍ إِلَّا نَحْنُ مُهْلِكُوهَا قَبْلَ يَوْمِ ٱلْقِيَٰمَةِ أَوْ مُعَذِّبُوهَا عَذَابًا شَدِيدًا كَانَ ذَٰلِكَ فِى ٱلْكِتَٰبِ مَسْطُورًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmlxxxviii{وَمَا مَنَعَنَآ أَن نُّرْسِلَ بِٱلْءَايَٰتِ إِلَّآ أَن كَذَّبَ بِهَا ٱلْأَوَّلُونَ وَءَاتَيْنَا ثَمُودَ ٱلنَّاقَةَ مُبْصِرَةً فَظَلَمُوا۟ بِهَا وَمَا نُرْسِلُ بِٱلْءَايَٰتِ إِلَّا تَخْوِيفًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmlxxxix{وَإِذْ قُلْنَا لَكَ إِنَّ رَبَّكَ أَحَاطَ بِٱلنَّاسِ وَمَا جَعَلْنَا ٱلرُّءْيَا ٱلَّتِىٓ أَرَيْنَٰكَ إِلَّا فِتْنَةً لِّلنَّاسِ وَٱلشَّجَرَةَ ٱلْمَلْعُونَةَ فِى ٱلْقُرْءَانِ وَنُخَوِّفُهُمْ فَمَا يَزِيدُهُمْ إِلَّا طُغْيَٰنًا كَبِيرًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmxc{وَإِذْ قُلْنَا لِلْمَلَٰٓئِكَةِ ٱسْجُدُوا۟ لِءَادَمَ فَسَجَدُوٓا۟ إِلَّآ إِبْلِيسَ قَالَ ءَأَسْجُدُ لِمَنْ خَلَقْتَ طِينًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmxci{قَالَ أَرَءَيْتَكَ هَٰذَا ٱلَّذِى كَرَّمْتَ عَلَىَّ لَئِنْ أَخَّرْتَنِ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ لَأَحْتَنِكَنَّ ذُرِّيَّتَهُۥٓ إِلَّا قَلِيلًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmxcii{قَالَ ٱذْهَبْ فَمَن تَبِعَكَ مِنْهُمْ فَإِنَّ جَهَنَّمَ جَزَآؤُكُمْ جَزَآءً مَّوْفُورًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmxciii{وَٱسْتَفْزِزْ مَنِ ٱسْتَطَعْتَ مِنْهُم بِصَوْتِكَ وَأَجْلِبْ عَلَيْهِم بِخَيْلِكَ وَرَجِلِكَ وَشَارِكْهُمْ فِى ٱلْأَمْوَٰلِ وَٱلْأَوْلَٰدِ وَعِدْهُمْ وَمَا يَعِدُهُمُ ٱلشَّيْطَٰنُ إِلَّا غُرُورًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmxciv{إِنَّ عِبَادِى لَيْسَ لَكَ عَلَيْهِمْ سُلْطَٰنٌ وَكَفَىٰ بِرَبِّكَ وَكِيلًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmxcv{رَّبُّكُمُ ٱلَّذِى يُزْجِى لَكُمُ ٱلْفُلْكَ فِى ٱلْبَحْرِ لِتَبْتَغُوا۟ مِن فَضْلِهِۦٓ إِنَّهُۥ كَانَ بِكُمْ رَحِيمًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmxcvi{وَإِذَا مَسَّكُمُ ٱلضُّرُّ فِى ٱلْبَحْرِ ضَلَّ مَن تَدْعُونَ إِلَّآ إِيَّاهُ فَلَمَّا نَجَّىٰكُمْ إِلَى ٱلْبَرِّ أَعْرَضْتُمْ وَكَانَ ٱلْإِنسَٰنُ كَفُورًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmxcvii{أَفَأَمِنتُمْ أَن يَخْسِفَ بِكُمْ جَانِبَ ٱلْبَرِّ أَوْ يُرْسِلَ عَلَيْكُمْ حَاصِبًا ثُمَّ لَا تَجِدُوا۟ لَكُمْ وَكِيلًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmxcviii{أَمْ أَمِنتُمْ أَن يُعِيدَكُمْ فِيهِ تَارَةً أُخْرَىٰ فَيُرْسِلَ عَلَيْكُمْ قَاصِفًا مِّنَ ٱلرِّيحِ فَيُغْرِقَكُم بِمَا كَفَرْتُمْ ثُمَّ لَا تَجِدُوا۟ لَكُمْ عَلَيْنَا بِهِۦ تَبِيعًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmxcix{وَلَقَدْ كَرَّمْنَا بَنِىٓ ءَادَمَ وَحَمَلْنَٰهُمْ فِى ٱلْبَرِّ وَٱلْبَحْرِ وَرَزَقْنَٰهُم مِّنَ ٱلطَّيِّبَٰتِ وَفَضَّلْنَٰهُمْ عَلَىٰ كَثِيرٍ مِّمَّنْ خَلَقْنَا تَفْضِيلًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmc{يَوْمَ نَدْعُوا۟ كُلَّ أُنَاسٍۭ بِإِمَٰمِهِمْ فَمَنْ أُوتِىَ كِتَٰبَهُۥ بِيَمِينِهِۦ فَأُو۟لَٰٓئِكَ يَقْرَءُونَ كِتَٰبَهُمْ وَلَا يُظْلَمُونَ فَتِيلًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmci{وَمَن كَانَ فِى هَٰذِهِۦٓ أَعْمَىٰ فَهُوَ فِى ٱلْءَاخِرَةِ أَعْمَىٰ وَأَضَلُّ سَبِيلًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcii{وَإِن كَادُوا۟ لَيَفْتِنُونَكَ عَنِ ٱلَّذِىٓ أَوْحَيْنَآ إِلَيْكَ لِتَفْتَرِىَ عَلَيْنَا غَيْرَهُۥ وَإِذًا لَّٱتَّخَذُوكَ خَلِيلًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmciii{وَلَوْلَآ أَن ثَبَّتْنَٰكَ لَقَدْ كِدتَّ تَرْكَنُ إِلَيْهِمْ شَيْـًٔا قَلِيلًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmciv{إِذًا لَّأَذَقْنَٰكَ ضِعْفَ ٱلْحَيَوٰةِ وَضِعْفَ ٱلْمَمَاتِ ثُمَّ لَا تَجِدُ لَكَ عَلَيْنَا نَصِيرًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcv{وَإِن كَادُوا۟ لَيَسْتَفِزُّونَكَ مِنَ ٱلْأَرْضِ لِيُخْرِجُوكَ مِنْهَا وَإِذًا لَّا يَلْبَثُونَ خِلَٰفَكَ إِلَّا قَلِيلًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcvi{سُنَّةَ مَن قَدْ أَرْسَلْنَا قَبْلَكَ مِن رُّسُلِنَا وَلَا تَجِدُ لِسُنَّتِنَا تَحْوِيلًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcvii{أَقِمِ ٱلصَّلَوٰةَ لِدُلُوكِ ٱلشَّمْسِ إِلَىٰ غَسَقِ ٱلَّيْلِ وَقُرْءَانَ ٱلْفَجْرِ إِنَّ قُرْءَانَ ٱلْفَجْرِ كَانَ مَشْهُودًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmcviii{وَمِنَ ٱلَّيْلِ فَتَهَجَّدْ بِهِۦ نَافِلَةً لَّكَ عَسَىٰٓ أَن يَبْعَثَكَ رَبُّكَ مَقَامًا مَّحْمُودًا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmcix{وَقُل رَّبِّ أَدْخِلْنِى مُدْخَلَ صِدْقٍ وَأَخْرِجْنِى مُخْرَجَ صِدْقٍ وَٱجْعَل لِّى مِن لَّدُنكَ سُلْطَٰنًا نَّصِيرًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmcx{وَقُلْ جَآءَ ٱلْحَقُّ وَزَهَقَ ٱلْبَٰطِلُ إِنَّ ٱلْبَٰطِلَ كَانَ زَهُوقًا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmcxi{وَنُنَزِّلُ مِنَ ٱلْقُرْءَانِ مَا هُوَ شِفَآءٌ وَرَحْمَةٌ لِّلْمُؤْمِنِينَ وَلَا يَزِيدُ ٱلظَّٰلِمِينَ إِلَّا خَسَارًا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmcxii{وَإِذَآ أَنْعَمْنَا عَلَى ٱلْإِنسَٰنِ أَعْرَضَ وَنَـَٔا بِجَانِبِهِۦ وَإِذَا مَسَّهُ ٱلشَّرُّ كَانَ يَـُٔوسًا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmcxiii{قُلْ كُلٌّ يَعْمَلُ عَلَىٰ شَاكِلَتِهِۦ فَرَبُّكُمْ أَعْلَمُ بِمَنْ هُوَ أَهْدَىٰ سَبِيلًا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmcxiv{وَيَسْـَٔلُونَكَ عَنِ ٱلرُّوحِ قُلِ ٱلرُّوحُ مِنْ أَمْرِ رَبِّى وَمَآ أُوتِيتُم مِّنَ ٱلْعِلْمِ إِلَّا قَلِيلًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmcxv{وَلَئِن شِئْنَا لَنَذْهَبَنَّ بِٱلَّذِىٓ أَوْحَيْنَآ إِلَيْكَ ثُمَّ لَا تَجِدُ لَكَ بِهِۦ عَلَيْنَا وَكِيلًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmcxvi{إِلَّا رَحْمَةً مِّن رَّبِّكَ إِنَّ فَضْلَهُۥ كَانَ عَلَيْكَ كَبِيرًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmcxvii{قُل لَّئِنِ ٱجْتَمَعَتِ ٱلْإِنسُ وَٱلْجِنُّ عَلَىٰٓ أَن يَأْتُوا۟ بِمِثْلِ هَٰذَا ٱلْقُرْءَانِ لَا يَأْتُونَ بِمِثْلِهِۦ وَلَوْ كَانَ بَعْضُهُمْ لِبَعْضٍ ظَهِيرًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmcxviii{وَلَقَدْ صَرَّفْنَا لِلنَّاسِ فِى هَٰذَا ٱلْقُرْءَانِ مِن كُلِّ مَثَلٍ فَأَبَىٰٓ أَكْثَرُ ٱلنَّاسِ إِلَّا كُفُورًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmcxix{وَقَالُوا۟ لَن نُّؤْمِنَ لَكَ حَتَّىٰ تَفْجُرَ لَنَا مِنَ ٱلْأَرْضِ يَنۢبُوعًا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmcxx{أَوْ تَكُونَ لَكَ جَنَّةٌ مِّن نَّخِيلٍ وَعِنَبٍ فَتُفَجِّرَ ٱلْأَنْهَٰرَ خِلَٰلَهَا تَفْجِيرًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmcxxi{أَوْ تُسْقِطَ ٱلسَّمَآءَ كَمَا زَعَمْتَ عَلَيْنَا كِسَفًا أَوْ تَأْتِىَ بِٱللَّهِ وَٱلْمَلَٰٓئِكَةِ قَبِيلًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmcxxii{أَوْ يَكُونَ لَكَ بَيْتٌ مِّن زُخْرُفٍ أَوْ تَرْقَىٰ فِى ٱلسَّمَآءِ وَلَن نُّؤْمِنَ لِرُقِيِّكَ حَتَّىٰ تُنَزِّلَ عَلَيْنَا كِتَٰبًا نَّقْرَؤُهُۥ قُلْ سُبْحَانَ رَبِّى هَلْ كُنتُ إِلَّا بَشَرًا رَّسُولًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmcxxiii{وَمَا مَنَعَ ٱلنَّاسَ أَن يُؤْمِنُوٓا۟ إِذْ جَآءَهُمُ ٱلْهُدَىٰٓ إِلَّآ أَن قَالُوٓا۟ أَبَعَثَ ٱللَّهُ بَشَرًا رَّسُولًا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmcxxiv{قُل لَّوْ كَانَ فِى ٱلْأَرْضِ مَلَٰٓئِكَةٌ يَمْشُونَ مُطْمَئِنِّينَ لَنَزَّلْنَا عَلَيْهِم مِّنَ ٱلسَّمَآءِ مَلَكًا رَّسُولًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmcxxv{قُلْ كَفَىٰ بِٱللَّهِ شَهِيدًۢا بَيْنِى وَبَيْنَكُمْ إِنَّهُۥ كَانَ بِعِبَادِهِۦ خَبِيرًۢا بَصِيرًا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmcxxvi{وَمَن يَهْدِ ٱللَّهُ فَهُوَ ٱلْمُهْتَدِ وَمَن يُضْلِلْ فَلَن تَجِدَ لَهُمْ أَوْلِيَآءَ مِن دُونِهِۦ وَنَحْشُرُهُمْ يَوْمَ ٱلْقِيَٰمَةِ عَلَىٰ وُجُوهِهِمْ عُمْيًا وَبُكْمًا وَصُمًّا مَّأْوَىٰهُمْ جَهَنَّمُ كُلَّمَا خَبَتْ زِدْنَٰهُمْ سَعِيرًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmcxxvii{ذَٰلِكَ جَزَآؤُهُم بِأَنَّهُمْ كَفَرُوا۟ بِـَٔايَٰتِنَا وَقَالُوٓا۟ أَءِذَا كُنَّا عِظَٰمًا وَرُفَٰتًا أَءِنَّا لَمَبْعُوثُونَ خَلْقًا جَدِيدًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmcxxviii{أَوَلَمْ يَرَوْا۟ أَنَّ ٱللَّهَ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ قَادِرٌ عَلَىٰٓ أَن يَخْلُقَ مِثْلَهُمْ وَجَعَلَ لَهُمْ أَجَلًا لَّا رَيْبَ فِيهِ فَأَبَى ٱلظَّٰلِمُونَ إِلَّا كُفُورًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmcxxix{قُل لَّوْ أَنتُمْ تَمْلِكُونَ خَزَآئِنَ رَحْمَةِ رَبِّىٓ إِذًا لَّأَمْسَكْتُمْ خَشْيَةَ ٱلْإِنفَاقِ وَكَانَ ٱلْإِنسَٰنُ قَتُورًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmcxxx{وَلَقَدْ ءَاتَيْنَا مُوسَىٰ تِسْعَ ءَايَٰتٍۭ بَيِّنَٰتٍ فَسْـَٔلْ بَنِىٓ إِسْرَٰٓءِيلَ إِذْ جَآءَهُمْ فَقَالَ لَهُۥ فِرْعَوْنُ إِنِّى لَأَظُنُّكَ يَٰمُوسَىٰ مَسْحُورًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmcxxxi{قَالَ لَقَدْ عَلِمْتَ مَآ أَنزَلَ هَٰٓؤُلَآءِ إِلَّا رَبُّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ بَصَآئِرَ وَإِنِّى لَأَظُنُّكَ يَٰفِرْعَوْنُ مَثْبُورًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmcxxxii{فَأَرَادَ أَن يَسْتَفِزَّهُم مِّنَ ٱلْأَرْضِ فَأَغْرَقْنَٰهُ وَمَن مَّعَهُۥ جَمِيعًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmcxxxiii{وَقُلْنَا مِنۢ بَعْدِهِۦ لِبَنِىٓ إِسْرَٰٓءِيلَ ٱسْكُنُوا۟ ٱلْأَرْضَ فَإِذَا جَآءَ وَعْدُ ٱلْءَاخِرَةِ جِئْنَا بِكُمْ لَفِيفًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmcxxxiv{وَبِٱلْحَقِّ أَنزَلْنَٰهُ وَبِٱلْحَقِّ نَزَلَ وَمَآ أَرْسَلْنَٰكَ إِلَّا مُبَشِّرًا وَنَذِيرًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmcxxxv{وَقُرْءَانًا فَرَقْنَٰهُ لِتَقْرَأَهُۥ عَلَى ٱلنَّاسِ عَلَىٰ مُكْثٍ وَنَزَّلْنَٰهُ تَنزِيلًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmcxxxvi{قُلْ ءَامِنُوا۟ بِهِۦٓ أَوْ لَا تُؤْمِنُوٓا۟ إِنَّ ٱلَّذِينَ أُوتُوا۟ ٱلْعِلْمَ مِن قَبْلِهِۦٓ إِذَا يُتْلَىٰ عَلَيْهِمْ يَخِرُّونَ لِلْأَذْقَانِ سُجَّدًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmcxxxvii{وَيَقُولُونَ سُبْحَٰنَ رَبِّنَآ إِن كَانَ وَعْدُ رَبِّنَا لَمَفْعُولًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmcxxxviii{وَيَخِرُّونَ لِلْأَذْقَانِ يَبْكُونَ وَيَزِيدُهُمْ خُشُوعًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmcxxxix{قُلِ ٱدْعُوا۟ ٱللَّهَ أَوِ ٱدْعُوا۟ ٱلرَّحْمَٰنَ أَيًّا مَّا تَدْعُوا۟ فَلَهُ ٱلْأَسْمَآءُ ٱلْحُسْنَىٰ وَلَا تَجْهَرْ بِصَلَاتِكَ وَلَا تُخَافِتْ بِهَا وَٱبْتَغِ بَيْنَ ذَٰلِكَ سَبِيلًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmcxl{وَقُلِ ٱلْحَمْدُ لِلَّهِ ٱلَّذِى لَمْ يَتَّخِذْ وَلَدًا وَلَمْ يَكُن لَّهُۥ شَرِيكٌ فِى ٱلْمُلْكِ وَلَمْ يَكُن لَّهُۥ وَلِىٌّ مِّنَ ٱلذُّلِّ وَكَبِّرْهُ تَكْبِيرًۢا\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmcxli{\basmalah ٱلْحَمْدُ لِلَّهِ ٱلَّذِىٓ أَنزَلَ عَلَىٰ عَبْدِهِ ٱلْكِتَٰبَ وَلَمْ يَجْعَل لَّهُۥ عِوَجَا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcxlii{قَيِّمًا لِّيُنذِرَ بَأْسًا شَدِيدًا مِّن لَّدُنْهُ وَيُبَشِّرَ ٱلْمُؤْمِنِينَ ٱلَّذِينَ يَعْمَلُونَ ٱلصَّٰلِحَٰتِ أَنَّ لَهُمْ أَجْرًا حَسَنًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcxliii{مَّٰكِثِينَ فِيهِ أَبَدًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmcxliv{وَيُنذِرَ ٱلَّذِينَ قَالُوا۟ ٱتَّخَذَ ٱللَّهُ وَلَدًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcxlv{مَّا لَهُم بِهِۦ مِنْ عِلْمٍ وَلَا لِءَابَآئِهِمْ كَبُرَتْ كَلِمَةً تَخْرُجُ مِنْ أَفْوَٰهِهِمْ إِن يَقُولُونَ إِلَّا كَذِبًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcxlvi{فَلَعَلَّكَ بَٰخِعٌ نَّفْسَكَ عَلَىٰٓ ءَاثَٰرِهِمْ إِن لَّمْ يُؤْمِنُوا۟ بِهَٰذَا ٱلْحَدِيثِ أَسَفًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcxlvii{إِنَّا جَعَلْنَا مَا عَلَى ٱلْأَرْضِ زِينَةً لَّهَا لِنَبْلُوَهُمْ أَيُّهُمْ أَحْسَنُ عَمَلًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcxlviii{وَإِنَّا لَجَٰعِلُونَ مَا عَلَيْهَا صَعِيدًا جُرُزًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcxlix{أَمْ حَسِبْتَ أَنَّ أَصْحَٰبَ ٱلْكَهْفِ وَٱلرَّقِيمِ كَانُوا۟ مِنْ ءَايَٰتِنَا عَجَبًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcl{إِذْ أَوَى ٱلْفِتْيَةُ إِلَى ٱلْكَهْفِ فَقَالُوا۟ رَبَّنَآ ءَاتِنَا مِن لَّدُنكَ رَحْمَةً وَهَيِّئْ لَنَا مِنْ أَمْرِنَا رَشَدًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcli{فَضَرَبْنَا عَلَىٰٓ ءَاذَانِهِمْ فِى ٱلْكَهْفِ سِنِينَ عَدَدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmclii{ثُمَّ بَعَثْنَٰهُمْ لِنَعْلَمَ أَىُّ ٱلْحِزْبَيْنِ أَحْصَىٰ لِمَا لَبِثُوٓا۟ أَمَدًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcliii{نَّحْنُ نَقُصُّ عَلَيْكَ نَبَأَهُم بِٱلْحَقِّ إِنَّهُمْ فِتْيَةٌ ءَامَنُوا۟ بِرَبِّهِمْ وَزِدْنَٰهُمْ هُدًى\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcliv{وَرَبَطْنَا عَلَىٰ قُلُوبِهِمْ إِذْ قَامُوا۟ فَقَالُوا۟ رَبُّنَا رَبُّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ لَن نَّدْعُوَا۟ مِن دُونِهِۦٓ إِلَٰهًا لَّقَدْ قُلْنَآ إِذًا شَطَطًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmclv{هَٰٓؤُلَآءِ قَوْمُنَا ٱتَّخَذُوا۟ مِن دُونِهِۦٓ ءَالِهَةً لَّوْلَا يَأْتُونَ عَلَيْهِم بِسُلْطَٰنٍۭ بَيِّنٍ فَمَنْ أَظْلَمُ مِمَّنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmclvi{وَإِذِ ٱعْتَزَلْتُمُوهُمْ وَمَا يَعْبُدُونَ إِلَّا ٱللَّهَ فَأْوُۥٓا۟ إِلَى ٱلْكَهْفِ يَنشُرْ لَكُمْ رَبُّكُم مِّن رَّحْمَتِهِۦ وَيُهَيِّئْ لَكُم مِّنْ أَمْرِكُم مِّرْفَقًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmclvii{وَتَرَى ٱلشَّمْسَ إِذَا طَلَعَت تَّزَٰوَرُ عَن كَهْفِهِمْ ذَاتَ ٱلْيَمِينِ وَإِذَا غَرَبَت تَّقْرِضُهُمْ ذَاتَ ٱلشِّمَالِ وَهُمْ فِى فَجْوَةٍ مِّنْهُ ذَٰلِكَ مِنْ ءَايَٰتِ ٱللَّهِ مَن يَهْدِ ٱللَّهُ فَهُوَ ٱلْمُهْتَدِ وَمَن يُضْلِلْ فَلَن تَجِدَ لَهُۥ وَلِيًّا مُّرْشِدًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmclviii{وَتَحْسَبُهُمْ أَيْقَاظًا وَهُمْ رُقُودٌ وَنُقَلِّبُهُمْ ذَاتَ ٱلْيَمِينِ وَذَاتَ ٱلشِّمَالِ وَكَلْبُهُم بَٰسِطٌ ذِرَاعَيْهِ بِٱلْوَصِيدِ لَوِ ٱطَّلَعْتَ عَلَيْهِمْ لَوَلَّيْتَ مِنْهُمْ فِرَارًا وَلَمُلِئْتَ مِنْهُمْ رُعْبًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmclix{وَكَذَٰلِكَ بَعَثْنَٰهُمْ لِيَتَسَآءَلُوا۟ بَيْنَهُمْ قَالَ قَآئِلٌ مِّنْهُمْ كَمْ لَبِثْتُمْ قَالُوا۟ لَبِثْنَا يَوْمًا أَوْ بَعْضَ يَوْمٍ قَالُوا۟ رَبُّكُمْ أَعْلَمُ بِمَا لَبِثْتُمْ فَٱبْعَثُوٓا۟ أَحَدَكُم بِوَرِقِكُمْ هَٰذِهِۦٓ إِلَى ٱلْمَدِينَةِ فَلْيَنظُرْ أَيُّهَآ أَزْكَىٰ طَعَامًا فَلْيَأْتِكُم بِرِزْقٍ مِّنْهُ وَلْيَتَلَطَّفْ وَلَا يُشْعِرَنَّ بِكُمْ أَحَدًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmclx{إِنَّهُمْ إِن يَظْهَرُوا۟ عَلَيْكُمْ يَرْجُمُوكُمْ أَوْ يُعِيدُوكُمْ فِى مِلَّتِهِمْ وَلَن تُفْلِحُوٓا۟ إِذًا أَبَدًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmclxi{وَكَذَٰلِكَ أَعْثَرْنَا عَلَيْهِمْ لِيَعْلَمُوٓا۟ أَنَّ وَعْدَ ٱللَّهِ حَقٌّ وَأَنَّ ٱلسَّاعَةَ لَا رَيْبَ فِيهَآ إِذْ يَتَنَٰزَعُونَ بَيْنَهُمْ أَمْرَهُمْ فَقَالُوا۟ ٱبْنُوا۟ عَلَيْهِم بُنْيَٰنًا رَّبُّهُمْ أَعْلَمُ بِهِمْ قَالَ ٱلَّذِينَ غَلَبُوا۟ عَلَىٰٓ أَمْرِهِمْ لَنَتَّخِذَنَّ عَلَيْهِم مَّسْجِدًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmclxii{سَيَقُولُونَ ثَلَٰثَةٌ رَّابِعُهُمْ كَلْبُهُمْ وَيَقُولُونَ خَمْسَةٌ سَادِسُهُمْ كَلْبُهُمْ رَجْمًۢا بِٱلْغَيْبِ وَيَقُولُونَ سَبْعَةٌ وَثَامِنُهُمْ كَلْبُهُمْ قُل رَّبِّىٓ أَعْلَمُ بِعِدَّتِهِم مَّا يَعْلَمُهُمْ إِلَّا قَلِيلٌ فَلَا تُمَارِ فِيهِمْ إِلَّا مِرَآءً ظَٰهِرًا وَلَا تَسْتَفْتِ فِيهِم مِّنْهُمْ أَحَدًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmclxiii{وَلَا تَقُولَنَّ لِشَا۟ىْءٍ إِنِّى فَاعِلٌ ذَٰلِكَ غَدًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmclxiv{إِلَّآ أَن يَشَآءَ ٱللَّهُ وَٱذْكُر رَّبَّكَ إِذَا نَسِيتَ وَقُلْ عَسَىٰٓ أَن يَهْدِيَنِ رَبِّى لِأَقْرَبَ مِنْ هَٰذَا رَشَدًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmclxv{وَلَبِثُوا۟ فِى كَهْفِهِمْ ثَلَٰثَ مِا۟ئَةٍ سِنِينَ وَٱزْدَادُوا۟ تِسْعًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmclxvi{قُلِ ٱللَّهُ أَعْلَمُ بِمَا لَبِثُوا۟ لَهُۥ غَيْبُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ أَبْصِرْ بِهِۦ وَأَسْمِعْ مَا لَهُم مِّن دُونِهِۦ مِن وَلِىٍّ وَلَا يُشْرِكُ فِى حُكْمِهِۦٓ أَحَدًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmclxvii{وَٱتْلُ مَآ أُوحِىَ إِلَيْكَ مِن كِتَابِ رَبِّكَ لَا مُبَدِّلَ لِكَلِمَٰتِهِۦ وَلَن تَجِدَ مِن دُونِهِۦ مُلْتَحَدًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmclxviii{وَٱصْبِرْ نَفْسَكَ مَعَ ٱلَّذِينَ يَدْعُونَ رَبَّهُم بِٱلْغَدَوٰةِ وَٱلْعَشِىِّ يُرِيدُونَ وَجْهَهُۥ وَلَا تَعْدُ عَيْنَاكَ عَنْهُمْ تُرِيدُ زِينَةَ ٱلْحَيَوٰةِ ٱلدُّنْيَا وَلَا تُطِعْ مَنْ أَغْفَلْنَا قَلْبَهُۥ عَن ذِكْرِنَا وَٱتَّبَعَ هَوَىٰهُ وَكَانَ أَمْرُهُۥ فُرُطًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmclxix{وَقُلِ ٱلْحَقُّ مِن رَّبِّكُمْ فَمَن شَآءَ فَلْيُؤْمِن وَمَن شَآءَ فَلْيَكْفُرْ إِنَّآ أَعْتَدْنَا لِلظَّٰلِمِينَ نَارًا أَحَاطَ بِهِمْ سُرَادِقُهَا وَإِن يَسْتَغِيثُوا۟ يُغَاثُوا۟ بِمَآءٍ كَٱلْمُهْلِ يَشْوِى ٱلْوُجُوهَ بِئْسَ ٱلشَّرَابُ وَسَآءَتْ مُرْتَفَقًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmclxx{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ إِنَّا لَا نُضِيعُ أَجْرَ مَنْ أَحْسَنَ عَمَلًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmclxxi{أُو۟لَٰٓئِكَ لَهُمْ جَنَّٰتُ عَدْنٍ تَجْرِى مِن تَحْتِهِمُ ٱلْأَنْهَٰرُ يُحَلَّوْنَ فِيهَا مِنْ أَسَاوِرَ مِن ذَهَبٍ وَيَلْبَسُونَ ثِيَابًا خُضْرًا مِّن سُندُسٍ وَإِسْتَبْرَقٍ مُّتَّكِـِٔينَ فِيهَا عَلَى ٱلْأَرَآئِكِ نِعْمَ ٱلثَّوَابُ وَحَسُنَتْ مُرْتَفَقًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmclxxii{وَٱضْرِبْ لَهُم مَّثَلًا رَّجُلَيْنِ جَعَلْنَا لِأَحَدِهِمَا جَنَّتَيْنِ مِنْ أَعْنَٰبٍ وَحَفَفْنَٰهُمَا بِنَخْلٍ وَجَعَلْنَا بَيْنَهُمَا زَرْعًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmclxxiii{كِلْتَا ٱلْجَنَّتَيْنِ ءَاتَتْ أُكُلَهَا وَلَمْ تَظْلِم مِّنْهُ شَيْـًٔا وَفَجَّرْنَا خِلَٰلَهُمَا نَهَرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmclxxiv{وَكَانَ لَهُۥ ثَمَرٌ فَقَالَ لِصَٰحِبِهِۦ وَهُوَ يُحَاوِرُهُۥٓ أَنَا۠ أَكْثَرُ مِنكَ مَالًا وَأَعَزُّ نَفَرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmclxxv{وَدَخَلَ جَنَّتَهُۥ وَهُوَ ظَالِمٌ لِّنَفْسِهِۦ قَالَ مَآ أَظُنُّ أَن تَبِيدَ هَٰذِهِۦٓ أَبَدًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmclxxvi{وَمَآ أَظُنُّ ٱلسَّاعَةَ قَآئِمَةً وَلَئِن رُّدِدتُّ إِلَىٰ رَبِّى لَأَجِدَنَّ خَيْرًا مِّنْهَا مُنقَلَبًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmclxxvii{قَالَ لَهُۥ صَاحِبُهُۥ وَهُوَ يُحَاوِرُهُۥٓ أَكَفَرْتَ بِٱلَّذِى خَلَقَكَ مِن تُرَابٍ ثُمَّ مِن نُّطْفَةٍ ثُمَّ سَوَّىٰكَ رَجُلًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmclxxviii{لَّٰكِنَّا۠ هُوَ ٱللَّهُ رَبِّى وَلَآ أُشْرِكُ بِرَبِّىٓ أَحَدًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmclxxix{وَلَوْلَآ إِذْ دَخَلْتَ جَنَّتَكَ قُلْتَ مَا شَآءَ ٱللَّهُ لَا قُوَّةَ إِلَّا بِٱللَّهِ إِن تَرَنِ أَنَا۠ أَقَلَّ مِنكَ مَالًا وَوَلَدًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmclxxx{فَعَسَىٰ رَبِّىٓ أَن يُؤْتِيَنِ خَيْرًا مِّن جَنَّتِكَ وَيُرْسِلَ عَلَيْهَا حُسْبَانًا مِّنَ ٱلسَّمَآءِ فَتُصْبِحَ صَعِيدًا زَلَقًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmclxxxi{أَوْ يُصْبِحَ مَآؤُهَا غَوْرًا فَلَن تَسْتَطِيعَ لَهُۥ طَلَبًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmclxxxii{وَأُحِيطَ بِثَمَرِهِۦ فَأَصْبَحَ يُقَلِّبُ كَفَّيْهِ عَلَىٰ مَآ أَنفَقَ فِيهَا وَهِىَ خَاوِيَةٌ عَلَىٰ عُرُوشِهَا وَيَقُولُ يَٰلَيْتَنِى لَمْ أُشْرِكْ بِرَبِّىٓ أَحَدًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmclxxxiii{وَلَمْ تَكُن لَّهُۥ فِئَةٌ يَنصُرُونَهُۥ مِن دُونِ ٱللَّهِ وَمَا كَانَ مُنتَصِرًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmclxxxiv{هُنَالِكَ ٱلْوَلَٰيَةُ لِلَّهِ ٱلْحَقِّ هُوَ خَيْرٌ ثَوَابًا وَخَيْرٌ عُقْبًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmclxxxv{وَٱضْرِبْ لَهُم مَّثَلَ ٱلْحَيَوٰةِ ٱلدُّنْيَا كَمَآءٍ أَنزَلْنَٰهُ مِنَ ٱلسَّمَآءِ فَٱخْتَلَطَ بِهِۦ نَبَاتُ ٱلْأَرْضِ فَأَصْبَحَ هَشِيمًا تَذْرُوهُ ٱلرِّيَٰحُ وَكَانَ ٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ مُّقْتَدِرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmclxxxvi{ٱلْمَالُ وَٱلْبَنُونَ زِينَةُ ٱلْحَيَوٰةِ ٱلدُّنْيَا وَٱلْبَٰقِيَٰتُ ٱلصَّٰلِحَٰتُ خَيْرٌ عِندَ رَبِّكَ ثَوَابًا وَخَيْرٌ أَمَلًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmclxxxvii{وَيَوْمَ نُسَيِّرُ ٱلْجِبَالَ وَتَرَى ٱلْأَرْضَ بَارِزَةً وَحَشَرْنَٰهُمْ فَلَمْ نُغَادِرْ مِنْهُمْ أَحَدًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmclxxxviii{وَعُرِضُوا۟ عَلَىٰ رَبِّكَ صَفًّا لَّقَدْ جِئْتُمُونَا كَمَا خَلَقْنَٰكُمْ أَوَّلَ مَرَّةٍۭ بَلْ زَعَمْتُمْ أَلَّن نَّجْعَلَ لَكُم مَّوْعِدًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmclxxxix{وَوُضِعَ ٱلْكِتَٰبُ فَتَرَى ٱلْمُجْرِمِينَ مُشْفِقِينَ مِمَّا فِيهِ وَيَقُولُونَ يَٰوَيْلَتَنَا مَالِ هَٰذَا ٱلْكِتَٰبِ لَا يُغَادِرُ صَغِيرَةً وَلَا كَبِيرَةً إِلَّآ أَحْصَىٰهَا وَوَجَدُوا۟ مَا عَمِلُوا۟ حَاضِرًا وَلَا يَظْلِمُ رَبُّكَ أَحَدًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcxc{وَإِذْ قُلْنَا لِلْمَلَٰٓئِكَةِ ٱسْجُدُوا۟ لِءَادَمَ فَسَجَدُوٓا۟ إِلَّآ إِبْلِيسَ كَانَ مِنَ ٱلْجِنِّ فَفَسَقَ عَنْ أَمْرِ رَبِّهِۦٓ أَفَتَتَّخِذُونَهُۥ وَذُرِّيَّتَهُۥٓ أَوْلِيَآءَ مِن دُونِى وَهُمْ لَكُمْ عَدُوٌّۢ بِئْسَ لِلظَّٰلِمِينَ بَدَلًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcxci{مَّآ أَشْهَدتُّهُمْ خَلْقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَلَا خَلْقَ أَنفُسِهِمْ وَمَا كُنتُ مُتَّخِذَ ٱلْمُضِلِّينَ عَضُدًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcxcii{وَيَوْمَ يَقُولُ نَادُوا۟ شُرَكَآءِىَ ٱلَّذِينَ زَعَمْتُمْ فَدَعَوْهُمْ فَلَمْ يَسْتَجِيبُوا۟ لَهُمْ وَجَعَلْنَا بَيْنَهُم مَّوْبِقًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcxciii{وَرَءَا ٱلْمُجْرِمُونَ ٱلنَّارَ فَظَنُّوٓا۟ أَنَّهُم مُّوَاقِعُوهَا وَلَمْ يَجِدُوا۟ عَنْهَا مَصْرِفًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcxciv{وَلَقَدْ صَرَّفْنَا فِى هَٰذَا ٱلْقُرْءَانِ لِلنَّاسِ مِن كُلِّ مَثَلٍ وَكَانَ ٱلْإِنسَٰنُ أَكْثَرَ شَىْءٍ جَدَلًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcxcv{وَمَا مَنَعَ ٱلنَّاسَ أَن يُؤْمِنُوٓا۟ إِذْ جَآءَهُمُ ٱلْهُدَىٰ وَيَسْتَغْفِرُوا۟ رَبَّهُمْ إِلَّآ أَن تَأْتِيَهُمْ سُنَّةُ ٱلْأَوَّلِينَ أَوْ يَأْتِيَهُمُ ٱلْعَذَابُ قُبُلًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcxcvi{وَمَا نُرْسِلُ ٱلْمُرْسَلِينَ إِلَّا مُبَشِّرِينَ وَمُنذِرِينَ وَيُجَٰدِلُ ٱلَّذِينَ كَفَرُوا۟ بِٱلْبَٰطِلِ لِيُدْحِضُوا۟ بِهِ ٱلْحَقَّ وَٱتَّخَذُوٓا۟ ءَايَٰتِى وَمَآ أُنذِرُوا۟ هُزُوًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcxcvii{وَمَنْ أَظْلَمُ مِمَّن ذُكِّرَ بِـَٔايَٰتِ رَبِّهِۦ فَأَعْرَضَ عَنْهَا وَنَسِىَ مَا قَدَّمَتْ يَدَاهُ إِنَّا جَعَلْنَا عَلَىٰ قُلُوبِهِمْ أَكِنَّةً أَن يَفْقَهُوهُ وَفِىٓ ءَاذَانِهِمْ وَقْرًا وَإِن تَدْعُهُمْ إِلَى ٱلْهُدَىٰ فَلَن يَهْتَدُوٓا۟ إِذًا أَبَدًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcxcviii{وَرَبُّكَ ٱلْغَفُورُ ذُو ٱلرَّحْمَةِ لَوْ يُؤَاخِذُهُم بِمَا كَسَبُوا۟ لَعَجَّلَ لَهُمُ ٱلْعَذَابَ بَل لَّهُم مَّوْعِدٌ لَّن يَجِدُوا۟ مِن دُونِهِۦ مَوْئِلًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcxcix{وَتِلْكَ ٱلْقُرَىٰٓ أَهْلَكْنَٰهُمْ لَمَّا ظَلَمُوا۟ وَجَعَلْنَا لِمَهْلِكِهِم مَّوْعِدًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcc{وَإِذْ قَالَ مُوسَىٰ لِفَتَىٰهُ لَآ أَبْرَحُ حَتَّىٰٓ أَبْلُغَ مَجْمَعَ ٱلْبَحْرَيْنِ أَوْ أَمْضِىَ حُقُبًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcci{فَلَمَّا بَلَغَا مَجْمَعَ بَيْنِهِمَا نَسِيَا حُوتَهُمَا فَٱتَّخَذَ سَبِيلَهُۥ فِى ٱلْبَحْرِ سَرَبًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmccii{فَلَمَّا جَاوَزَا قَالَ لِفَتَىٰهُ ءَاتِنَا غَدَآءَنَا لَقَدْ لَقِينَا مِن سَفَرِنَا هَٰذَا نَصَبًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcciii{قَالَ أَرَءَيْتَ إِذْ أَوَيْنَآ إِلَى ٱلصَّخْرَةِ فَإِنِّى نَسِيتُ ٱلْحُوتَ وَمَآ أَنسَىٰنِيهُ إِلَّا ٱلشَّيْطَٰنُ أَنْ أَذْكُرَهُۥ وَٱتَّخَذَ سَبِيلَهُۥ فِى ٱلْبَحْرِ عَجَبًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcciv{قَالَ ذَٰلِكَ مَا كُنَّا نَبْغِ فَٱرْتَدَّا عَلَىٰٓ ءَاثَارِهِمَا قَصَصًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmccv{فَوَجَدَا عَبْدًا مِّنْ عِبَادِنَآ ءَاتَيْنَٰهُ رَحْمَةً مِّنْ عِندِنَا وَعَلَّمْنَٰهُ مِن لَّدُنَّا عِلْمًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmccvi{قَالَ لَهُۥ مُوسَىٰ هَلْ أَتَّبِعُكَ عَلَىٰٓ أَن تُعَلِّمَنِ مِمَّا عُلِّمْتَ رُشْدًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmccvii{قَالَ إِنَّكَ لَن تَسْتَطِيعَ مَعِىَ صَبْرًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmccviii{وَكَيْفَ تَصْبِرُ عَلَىٰ مَا لَمْ تُحِطْ بِهِۦ خُبْرًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmccix{قَالَ سَتَجِدُنِىٓ إِن شَآءَ ٱللَّهُ صَابِرًا وَلَآ أَعْصِى لَكَ أَمْرًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmccx{قَالَ فَإِنِ ٱتَّبَعْتَنِى فَلَا تَسْـَٔلْنِى عَن شَىْءٍ حَتَّىٰٓ أُحْدِثَ لَكَ مِنْهُ ذِكْرًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmccxi{فَٱنطَلَقَا حَتَّىٰٓ إِذَا رَكِبَا فِى ٱلسَّفِينَةِ خَرَقَهَا قَالَ أَخَرَقْتَهَا لِتُغْرِقَ أَهْلَهَا لَقَدْ جِئْتَ شَيْـًٔا إِمْرًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmccxii{قَالَ أَلَمْ أَقُلْ إِنَّكَ لَن تَسْتَطِيعَ مَعِىَ صَبْرًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmccxiii{قَالَ لَا تُؤَاخِذْنِى بِمَا نَسِيتُ وَلَا تُرْهِقْنِى مِنْ أَمْرِى عُسْرًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmccxiv{فَٱنطَلَقَا حَتَّىٰٓ إِذَا لَقِيَا غُلَٰمًا فَقَتَلَهُۥ قَالَ أَقَتَلْتَ نَفْسًا زَكِيَّةًۢ بِغَيْرِ نَفْسٍ لَّقَدْ جِئْتَ شَيْـًٔا نُّكْرًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmccxv{قَالَ أَلَمْ أَقُل لَّكَ إِنَّكَ لَن تَسْتَطِيعَ مَعِىَ صَبْرًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmccxvi{قَالَ إِن سَأَلْتُكَ عَن شَىْءٍۭ بَعْدَهَا فَلَا تُصَٰحِبْنِى قَدْ بَلَغْتَ مِن لَّدُنِّى عُذْرًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmccxvii{فَٱنطَلَقَا حَتَّىٰٓ إِذَآ أَتَيَآ أَهْلَ قَرْيَةٍ ٱسْتَطْعَمَآ أَهْلَهَا فَأَبَوْا۟ أَن يُضَيِّفُوهُمَا فَوَجَدَا فِيهَا جِدَارًا يُرِيدُ أَن يَنقَضَّ فَأَقَامَهُۥ قَالَ لَوْ شِئْتَ لَتَّخَذْتَ عَلَيْهِ أَجْرًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmccxviii{قَالَ هَٰذَا فِرَاقُ بَيْنِى وَبَيْنِكَ سَأُنَبِّئُكَ بِتَأْوِيلِ مَا لَمْ تَسْتَطِع عَّلَيْهِ صَبْرًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmccxix{أَمَّا ٱلسَّفِينَةُ فَكَانَتْ لِمَسَٰكِينَ يَعْمَلُونَ فِى ٱلْبَحْرِ فَأَرَدتُّ أَنْ أَعِيبَهَا وَكَانَ وَرَآءَهُم مَّلِكٌ يَأْخُذُ كُلَّ سَفِينَةٍ غَصْبًا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmccxx{وَأَمَّا ٱلْغُلَٰمُ فَكَانَ أَبَوَاهُ مُؤْمِنَيْنِ فَخَشِينَآ أَن يُرْهِقَهُمَا طُغْيَٰنًا وَكُفْرًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmccxxi{فَأَرَدْنَآ أَن يُبْدِلَهُمَا رَبُّهُمَا خَيْرًا مِّنْهُ زَكَوٰةً وَأَقْرَبَ رُحْمًا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmccxxii{وَأَمَّا ٱلْجِدَارُ فَكَانَ لِغُلَٰمَيْنِ يَتِيمَيْنِ فِى ٱلْمَدِينَةِ وَكَانَ تَحْتَهُۥ كَنزٌ لَّهُمَا وَكَانَ أَبُوهُمَا صَٰلِحًا فَأَرَادَ رَبُّكَ أَن يَبْلُغَآ أَشُدَّهُمَا وَيَسْتَخْرِجَا كَنزَهُمَا رَحْمَةً مِّن رَّبِّكَ وَمَا فَعَلْتُهُۥ عَنْ أَمْرِى ذَٰلِكَ تَأْوِيلُ مَا لَمْ تَسْطِع عَّلَيْهِ صَبْرًا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmccxxiii{وَيَسْـَٔلُونَكَ عَن ذِى ٱلْقَرْنَيْنِ قُلْ سَأَتْلُوا۟ عَلَيْكُم مِّنْهُ ذِكْرًا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmccxxiv{إِنَّا مَكَّنَّا لَهُۥ فِى ٱلْأَرْضِ وَءَاتَيْنَٰهُ مِن كُلِّ شَىْءٍ سَبَبًا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmccxxv{فَأَتْبَعَ سَبَبًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmccxxvi{حَتَّىٰٓ إِذَا بَلَغَ مَغْرِبَ ٱلشَّمْسِ وَجَدَهَا تَغْرُبُ فِى عَيْنٍ حَمِئَةٍ وَوَجَدَ عِندَهَا قَوْمًا قُلْنَا يَٰذَا ٱلْقَرْنَيْنِ إِمَّآ أَن تُعَذِّبَ وَإِمَّآ أَن تَتَّخِذَ فِيهِمْ حُسْنًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmccxxvii{قَالَ أَمَّا مَن ظَلَمَ فَسَوْفَ نُعَذِّبُهُۥ ثُمَّ يُرَدُّ إِلَىٰ رَبِّهِۦ فَيُعَذِّبُهُۥ عَذَابًا نُّكْرًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmccxxviii{وَأَمَّا مَنْ ءَامَنَ وَعَمِلَ صَٰلِحًا فَلَهُۥ جَزَآءً ٱلْحُسْنَىٰ وَسَنَقُولُ لَهُۥ مِنْ أَمْرِنَا يُسْرًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmccxxix{ثُمَّ أَتْبَعَ سَبَبًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmccxxx{حَتَّىٰٓ إِذَا بَلَغَ مَطْلِعَ ٱلشَّمْسِ وَجَدَهَا تَطْلُعُ عَلَىٰ قَوْمٍ لَّمْ نَجْعَل لَّهُم مِّن دُونِهَا سِتْرًا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmccxxxi{كَذَٰلِكَ وَقَدْ أَحَطْنَا بِمَا لَدَيْهِ خُبْرًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmccxxxii{ثُمَّ أَتْبَعَ سَبَبًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmccxxxiii{حَتَّىٰٓ إِذَا بَلَغَ بَيْنَ ٱلسَّدَّيْنِ وَجَدَ مِن دُونِهِمَا قَوْمًا لَّا يَكَادُونَ يَفْقَهُونَ قَوْلًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmccxxxiv{قَالُوا۟ يَٰذَا ٱلْقَرْنَيْنِ إِنَّ يَأْجُوجَ وَمَأْجُوجَ مُفْسِدُونَ فِى ٱلْأَرْضِ فَهَلْ نَجْعَلُ لَكَ خَرْجًا عَلَىٰٓ أَن تَجْعَلَ بَيْنَنَا وَبَيْنَهُمْ سَدًّا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmccxxxv{قَالَ مَا مَكَّنِّى فِيهِ رَبِّى خَيْرٌ فَأَعِينُونِى بِقُوَّةٍ أَجْعَلْ بَيْنَكُمْ وَبَيْنَهُمْ رَدْمًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmccxxxvi{ءَاتُونِى زُبَرَ ٱلْحَدِيدِ حَتَّىٰٓ إِذَا سَاوَىٰ بَيْنَ ٱلصَّدَفَيْنِ قَالَ ٱنفُخُوا۟ حَتَّىٰٓ إِذَا جَعَلَهُۥ نَارًا قَالَ ءَاتُونِىٓ أُفْرِغْ عَلَيْهِ قِطْرًا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmccxxxvii{فَمَا ٱسْطَٰعُوٓا۟ أَن يَظْهَرُوهُ وَمَا ٱسْتَطَٰعُوا۟ لَهُۥ نَقْبًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmccxxxviii{قَالَ هَٰذَا رَحْمَةٌ مِّن رَّبِّى فَإِذَا جَآءَ وَعْدُ رَبِّى جَعَلَهُۥ دَكَّآءَ وَكَانَ وَعْدُ رَبِّى حَقًّا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmccxxxix{وَتَرَكْنَا بَعْضَهُمْ يَوْمَئِذٍ يَمُوجُ فِى بَعْضٍ وَنُفِخَ فِى ٱلصُّورِ فَجَمَعْنَٰهُمْ جَمْعًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmccxl{وَعَرَضْنَا جَهَنَّمَ يَوْمَئِذٍ لِّلْكَٰفِرِينَ عَرْضًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmccxli{ٱلَّذِينَ كَانَتْ أَعْيُنُهُمْ فِى غِطَآءٍ عَن ذِكْرِى وَكَانُوا۟ لَا يَسْتَطِيعُونَ سَمْعًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmccxlii{أَفَحَسِبَ ٱلَّذِينَ كَفَرُوٓا۟ أَن يَتَّخِذُوا۟ عِبَادِى مِن دُونِىٓ أَوْلِيَآءَ إِنَّآ أَعْتَدْنَا جَهَنَّمَ لِلْكَٰفِرِينَ نُزُلًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmccxliii{قُلْ هَلْ نُنَبِّئُكُم بِٱلْأَخْسَرِينَ أَعْمَٰلًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmccxliv{ٱلَّذِينَ ضَلَّ سَعْيُهُمْ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَهُمْ يَحْسَبُونَ أَنَّهُمْ يُحْسِنُونَ صُنْعًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmccxlv{أُو۟لَٰٓئِكَ ٱلَّذِينَ كَفَرُوا۟ بِـَٔايَٰتِ رَبِّهِمْ وَلِقَآئِهِۦ فَحَبِطَتْ أَعْمَٰلُهُمْ فَلَا نُقِيمُ لَهُمْ يَوْمَ ٱلْقِيَٰمَةِ وَزْنًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmccxlvi{ذَٰلِكَ جَزَآؤُهُمْ جَهَنَّمُ بِمَا كَفَرُوا۟ وَٱتَّخَذُوٓا۟ ءَايَٰتِى وَرُسُلِى هُزُوًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmccxlvii{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ كَانَتْ لَهُمْ جَنَّٰتُ ٱلْفِرْدَوْسِ نُزُلًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmccxlviii{خَٰلِدِينَ فِيهَا لَا يَبْغُونَ عَنْهَا حِوَلًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmccxlix{قُل لَّوْ كَانَ ٱلْبَحْرُ مِدَادًا لِّكَلِمَٰتِ رَبِّى لَنَفِدَ ٱلْبَحْرُ قَبْلَ أَن تَنفَدَ كَلِمَٰتُ رَبِّى وَلَوْ جِئْنَا بِمِثْلِهِۦ مَدَدًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmccl{قُلْ إِنَّمَآ أَنَا۠ بَشَرٌ مِّثْلُكُمْ يُوحَىٰٓ إِلَىَّ أَنَّمَآ إِلَٰهُكُمْ إِلَٰهٌ وَٰحِدٌ فَمَن كَانَ يَرْجُوا۟ لِقَآءَ رَبِّهِۦ فَلْيَعْمَلْ عَمَلًا صَٰلِحًا وَلَا يُشْرِكْ بِعِبَادَةِ رَبِّهِۦٓ أَحَدًۢا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmccli{\basmalah كٓهيعٓصٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcclii{ذِكْرُ رَحْمَتِ رَبِّكَ عَبْدَهُۥ زَكَرِيَّآ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmccliii{إِذْ نَادَىٰ رَبَّهُۥ نِدَآءً خَفِيًّا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmccliv{قَالَ رَبِّ إِنِّى وَهَنَ ٱلْعَظْمُ مِنِّى وَٱشْتَعَلَ ٱلرَّأْسُ شَيْبًا وَلَمْ أَكُنۢ بِدُعَآئِكَ رَبِّ شَقِيًّا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcclv{وَإِنِّى خِفْتُ ٱلْمَوَٰلِىَ مِن وَرَآءِى وَكَانَتِ ٱمْرَأَتِى عَاقِرًا فَهَبْ لِى مِن لَّدُنكَ وَلِيًّا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcclvi{يَرِثُنِى وَيَرِثُ مِنْ ءَالِ يَعْقُوبَ وَٱجْعَلْهُ رَبِّ رَضِيًّا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcclvii{يَٰزَكَرِيَّآ إِنَّا نُبَشِّرُكَ بِغُلَٰمٍ ٱسْمُهُۥ يَحْيَىٰ لَمْ نَجْعَل لَّهُۥ مِن قَبْلُ سَمِيًّا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcclviii{قَالَ رَبِّ أَنَّىٰ يَكُونُ لِى غُلَٰمٌ وَكَانَتِ ٱمْرَأَتِى عَاقِرًا وَقَدْ بَلَغْتُ مِنَ ٱلْكِبَرِ عِتِيًّا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcclix{قَالَ كَذَٰلِكَ قَالَ رَبُّكَ هُوَ عَلَىَّ هَيِّنٌ وَقَدْ خَلَقْتُكَ مِن قَبْلُ وَلَمْ تَكُ شَيْـًٔا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcclx{قَالَ رَبِّ ٱجْعَل لِّىٓ ءَايَةً قَالَ ءَايَتُكَ أَلَّا تُكَلِّمَ ٱلنَّاسَ ثَلَٰثَ لَيَالٍ سَوِيًّا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcclxi{فَخَرَجَ عَلَىٰ قَوْمِهِۦ مِنَ ٱلْمِحْرَابِ فَأَوْحَىٰٓ إِلَيْهِمْ أَن سَبِّحُوا۟ بُكْرَةً وَعَشِيًّا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmcclxii{يَٰيَحْيَىٰ خُذِ ٱلْكِتَٰبَ بِقُوَّةٍ وَءَاتَيْنَٰهُ ٱلْحُكْمَ صَبِيًّا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcclxiii{وَحَنَانًا مِّن لَّدُنَّا وَزَكَوٰةً وَكَانَ تَقِيًّا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcclxiv{وَبَرًّۢا بِوَٰلِدَيْهِ وَلَمْ يَكُن جَبَّارًا عَصِيًّا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmcclxv{وَسَلَٰمٌ عَلَيْهِ يَوْمَ وُلِدَ وَيَوْمَ يَمُوتُ وَيَوْمَ يُبْعَثُ حَيًّا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmcclxvi{وَٱذْكُرْ فِى ٱلْكِتَٰبِ مَرْيَمَ إِذِ ٱنتَبَذَتْ مِنْ أَهْلِهَا مَكَانًا شَرْقِيًّا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmcclxvii{فَٱتَّخَذَتْ مِن دُونِهِمْ حِجَابًا فَأَرْسَلْنَآ إِلَيْهَا رُوحَنَا فَتَمَثَّلَ لَهَا بَشَرًا سَوِيًّا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmcclxviii{قَالَتْ إِنِّىٓ أَعُوذُ بِٱلرَّحْمَٰنِ مِنكَ إِن كُنتَ تَقِيًّا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmcclxix{قَالَ إِنَّمَآ أَنَا۠ رَسُولُ رَبِّكِ لِأَهَبَ لَكِ غُلَٰمًا زَكِيًّا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmcclxx{قَالَتْ أَنَّىٰ يَكُونُ لِى غُلَٰمٌ وَلَمْ يَمْسَسْنِى بَشَرٌ وَلَمْ أَكُ بَغِيًّا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmcclxxi{قَالَ كَذَٰلِكِ قَالَ رَبُّكِ هُوَ عَلَىَّ هَيِّنٌ وَلِنَجْعَلَهُۥٓ ءَايَةً لِّلنَّاسِ وَرَحْمَةً مِّنَّا وَكَانَ أَمْرًا مَّقْضِيًّا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmcclxxii{فَحَمَلَتْهُ فَٱنتَبَذَتْ بِهِۦ مَكَانًا قَصِيًّا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmcclxxiii{فَأَجَآءَهَا ٱلْمَخَاضُ إِلَىٰ جِذْعِ ٱلنَّخْلَةِ قَالَتْ يَٰلَيْتَنِى مِتُّ قَبْلَ هَٰذَا وَكُنتُ نَسْيًا مَّنسِيًّا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmcclxxiv{فَنَادَىٰهَا مِن تَحْتِهَآ أَلَّا تَحْزَنِى قَدْ جَعَلَ رَبُّكِ تَحْتَكِ سَرِيًّا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmcclxxv{وَهُزِّىٓ إِلَيْكِ بِجِذْعِ ٱلنَّخْلَةِ تُسَٰقِطْ عَلَيْكِ رُطَبًا جَنِيًّا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmcclxxvi{فَكُلِى وَٱشْرَبِى وَقَرِّى عَيْنًا فَإِمَّا تَرَيِنَّ مِنَ ٱلْبَشَرِ أَحَدًا فَقُولِىٓ إِنِّى نَذَرْتُ لِلرَّحْمَٰنِ صَوْمًا فَلَنْ أُكَلِّمَ ٱلْيَوْمَ إِنسِيًّا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmcclxxvii{فَأَتَتْ بِهِۦ قَوْمَهَا تَحْمِلُهُۥ قَالُوا۟ يَٰمَرْيَمُ لَقَدْ جِئْتِ شَيْـًٔا فَرِيًّا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmcclxxviii{يَٰٓأُخْتَ هَٰرُونَ مَا كَانَ أَبُوكِ ٱمْرَأَ سَوْءٍ وَمَا كَانَتْ أُمُّكِ بَغِيًّا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmcclxxix{فَأَشَارَتْ إِلَيْهِ قَالُوا۟ كَيْفَ نُكَلِّمُ مَن كَانَ فِى ٱلْمَهْدِ صَبِيًّا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmcclxxx{قَالَ إِنِّى عَبْدُ ٱللَّهِ ءَاتَىٰنِىَ ٱلْكِتَٰبَ وَجَعَلَنِى نَبِيًّا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmcclxxxi{وَجَعَلَنِى مُبَارَكًا أَيْنَ مَا كُنتُ وَأَوْصَٰنِى بِٱلصَّلَوٰةِ وَٱلزَّكَوٰةِ مَا دُمْتُ حَيًّا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmcclxxxii{وَبَرًّۢا بِوَٰلِدَتِى وَلَمْ يَجْعَلْنِى جَبَّارًا شَقِيًّا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmcclxxxiii{وَٱلسَّلَٰمُ عَلَىَّ يَوْمَ وُلِدتُّ وَيَوْمَ أَمُوتُ وَيَوْمَ أُبْعَثُ حَيًّا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmcclxxxiv{ذَٰلِكَ عِيسَى ٱبْنُ مَرْيَمَ قَوْلَ ٱلْحَقِّ ٱلَّذِى فِيهِ يَمْتَرُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmcclxxxv{مَا كَانَ لِلَّهِ أَن يَتَّخِذَ مِن وَلَدٍ سُبْحَٰنَهُۥٓ إِذَا قَضَىٰٓ أَمْرًا فَإِنَّمَا يَقُولُ لَهُۥ كُن فَيَكُونُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmcclxxxvi{وَإِنَّ ٱللَّهَ رَبِّى وَرَبُّكُمْ فَٱعْبُدُوهُ هَٰذَا صِرَٰطٌ مُّسْتَقِيمٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmcclxxxvii{فَٱخْتَلَفَ ٱلْأَحْزَابُ مِنۢ بَيْنِهِمْ فَوَيْلٌ لِّلَّذِينَ كَفَرُوا۟ مِن مَّشْهَدِ يَوْمٍ عَظِيمٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmcclxxxviii{أَسْمِعْ بِهِمْ وَأَبْصِرْ يَوْمَ يَأْتُونَنَا لَٰكِنِ ٱلظَّٰلِمُونَ ٱلْيَوْمَ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmcclxxxix{وَأَنذِرْهُمْ يَوْمَ ٱلْحَسْرَةِ إِذْ قُضِىَ ٱلْأَمْرُ وَهُمْ فِى غَفْلَةٍ وَهُمْ لَا يُؤْمِنُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmccxc{إِنَّا نَحْنُ نَرِثُ ٱلْأَرْضَ وَمَنْ عَلَيْهَا وَإِلَيْنَا يُرْجَعُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmccxci{وَٱذْكُرْ فِى ٱلْكِتَٰبِ إِبْرَٰهِيمَ إِنَّهُۥ كَانَ صِدِّيقًا نَّبِيًّا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmccxcii{إِذْ قَالَ لِأَبِيهِ يَٰٓأَبَتِ لِمَ تَعْبُدُ مَا لَا يَسْمَعُ وَلَا يُبْصِرُ وَلَا يُغْنِى عَنكَ شَيْـًٔا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmccxciii{يَٰٓأَبَتِ إِنِّى قَدْ جَآءَنِى مِنَ ٱلْعِلْمِ مَا لَمْ يَأْتِكَ فَٱتَّبِعْنِىٓ أَهْدِكَ صِرَٰطًا سَوِيًّا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmccxciv{يَٰٓأَبَتِ لَا تَعْبُدِ ٱلشَّيْطَٰنَ إِنَّ ٱلشَّيْطَٰنَ كَانَ لِلرَّحْمَٰنِ عَصِيًّا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmccxcv{يَٰٓأَبَتِ إِنِّىٓ أَخَافُ أَن يَمَسَّكَ عَذَابٌ مِّنَ ٱلرَّحْمَٰنِ فَتَكُونَ لِلشَّيْطَٰنِ وَلِيًّا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmccxcvi{قَالَ أَرَاغِبٌ أَنتَ عَنْ ءَالِهَتِى يَٰٓإِبْرَٰهِيمُ لَئِن لَّمْ تَنتَهِ لَأَرْجُمَنَّكَ وَٱهْجُرْنِى مَلِيًّا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmccxcvii{قَالَ سَلَٰمٌ عَلَيْكَ سَأَسْتَغْفِرُ لَكَ رَبِّىٓ إِنَّهُۥ كَانَ بِى حَفِيًّا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmccxcviii{وَأَعْتَزِلُكُمْ وَمَا تَدْعُونَ مِن دُونِ ٱللَّهِ وَأَدْعُوا۟ رَبِّى عَسَىٰٓ أَلَّآ أَكُونَ بِدُعَآءِ رَبِّى شَقِيًّا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmccxcix{فَلَمَّا ٱعْتَزَلَهُمْ وَمَا يَعْبُدُونَ مِن دُونِ ٱللَّهِ وَهَبْنَا لَهُۥٓ إِسْحَٰقَ وَيَعْقُوبَ وَكُلًّا جَعَلْنَا نَبِيًّا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmccc{وَوَهَبْنَا لَهُم مِّن رَّحْمَتِنَا وَجَعَلْنَا لَهُمْ لِسَانَ صِدْقٍ عَلِيًّا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmccci{وَٱذْكُرْ فِى ٱلْكِتَٰبِ مُوسَىٰٓ إِنَّهُۥ كَانَ مُخْلَصًا وَكَانَ رَسُولًا نَّبِيًّا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcccii{وَنَٰدَيْنَٰهُ مِن جَانِبِ ٱلطُّورِ ٱلْأَيْمَنِ وَقَرَّبْنَٰهُ نَجِيًّا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmccciii{وَوَهَبْنَا لَهُۥ مِن رَّحْمَتِنَآ أَخَاهُ هَٰرُونَ نَبِيًّا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmccciv{وَٱذْكُرْ فِى ٱلْكِتَٰبِ إِسْمَٰعِيلَ إِنَّهُۥ كَانَ صَادِقَ ٱلْوَعْدِ وَكَانَ رَسُولًا نَّبِيًّا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcccv{وَكَانَ يَأْمُرُ أَهْلَهُۥ بِٱلصَّلَوٰةِ وَٱلزَّكَوٰةِ وَكَانَ عِندَ رَبِّهِۦ مَرْضِيًّا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcccvi{وَٱذْكُرْ فِى ٱلْكِتَٰبِ إِدْرِيسَ إِنَّهُۥ كَانَ صِدِّيقًا نَّبِيًّا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcccvii{وَرَفَعْنَٰهُ مَكَانًا عَلِيًّا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcccviii{أُو۟لَٰٓئِكَ ٱلَّذِينَ أَنْعَمَ ٱللَّهُ عَلَيْهِم مِّنَ ٱلنَّبِيِّۦنَ مِن ذُرِّيَّةِ ءَادَمَ وَمِمَّنْ حَمَلْنَا مَعَ نُوحٍ وَمِن ذُرِّيَّةِ إِبْرَٰهِيمَ وَإِسْرَٰٓءِيلَ وَمِمَّنْ هَدَيْنَا وَٱجْتَبَيْنَآ إِذَا تُتْلَىٰ عَلَيْهِمْ ءَايَٰتُ ٱلرَّحْمَٰنِ خَرُّوا۟ سُجَّدًا وَبُكِيًّا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcccix{فَخَلَفَ مِنۢ بَعْدِهِمْ خَلْفٌ أَضَاعُوا۟ ٱلصَّلَوٰةَ وَٱتَّبَعُوا۟ ٱلشَّهَوَٰتِ فَسَوْفَ يَلْقَوْنَ غَيًّا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcccx{إِلَّا مَن تَابَ وَءَامَنَ وَعَمِلَ صَٰلِحًا فَأُو۟لَٰٓئِكَ يَدْخُلُونَ ٱلْجَنَّةَ وَلَا يُظْلَمُونَ شَيْـًٔا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcccxi{جَنَّٰتِ عَدْنٍ ٱلَّتِى وَعَدَ ٱلرَّحْمَٰنُ عِبَادَهُۥ بِٱلْغَيْبِ إِنَّهُۥ كَانَ وَعْدُهُۥ مَأْتِيًّا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcccxii{لَّا يَسْمَعُونَ فِيهَا لَغْوًا إِلَّا سَلَٰمًا وَلَهُمْ رِزْقُهُمْ فِيهَا بُكْرَةً وَعَشِيًّا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcccxiii{تِلْكَ ٱلْجَنَّةُ ٱلَّتِى نُورِثُ مِنْ عِبَادِنَا مَن كَانَ تَقِيًّا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcccxiv{وَمَا نَتَنَزَّلُ إِلَّا بِأَمْرِ رَبِّكَ لَهُۥ مَا بَيْنَ أَيْدِينَا وَمَا خَلْفَنَا وَمَا بَيْنَ ذَٰلِكَ وَمَا كَانَ رَبُّكَ نَسِيًّا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcccxv{رَّبُّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَا فَٱعْبُدْهُ وَٱصْطَبِرْ لِعِبَٰدَتِهِۦ هَلْ تَعْلَمُ لَهُۥ سَمِيًّا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcccxvi{وَيَقُولُ ٱلْإِنسَٰنُ أَءِذَا مَا مِتُّ لَسَوْفَ أُخْرَجُ حَيًّا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcccxvii{أَوَلَا يَذْكُرُ ٱلْإِنسَٰنُ أَنَّا خَلَقْنَٰهُ مِن قَبْلُ وَلَمْ يَكُ شَيْـًٔا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmcccxviii{فَوَرَبِّكَ لَنَحْشُرَنَّهُمْ وَٱلشَّيَٰطِينَ ثُمَّ لَنُحْضِرَنَّهُمْ حَوْلَ جَهَنَّمَ جِثِيًّا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmcccxix{ثُمَّ لَنَنزِعَنَّ مِن كُلِّ شِيعَةٍ أَيُّهُمْ أَشَدُّ عَلَى ٱلرَّحْمَٰنِ عِتِيًّا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmcccxx{ثُمَّ لَنَحْنُ أَعْلَمُ بِٱلَّذِينَ هُمْ أَوْلَىٰ بِهَا صِلِيًّا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmcccxxi{وَإِن مِّنكُمْ إِلَّا وَارِدُهَا كَانَ عَلَىٰ رَبِّكَ حَتْمًا مَّقْضِيًّا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmcccxxii{ثُمَّ نُنَجِّى ٱلَّذِينَ ٱتَّقَوا۟ وَّنَذَرُ ٱلظَّٰلِمِينَ فِيهَا جِثِيًّا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcccxxiii{وَإِذَا تُتْلَىٰ عَلَيْهِمْ ءَايَٰتُنَا بَيِّنَٰتٍ قَالَ ٱلَّذِينَ كَفَرُوا۟ لِلَّذِينَ ءَامَنُوٓا۟ أَىُّ ٱلْفَرِيقَيْنِ خَيْرٌ مَّقَامًا وَأَحْسَنُ نَدِيًّا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmcccxxiv{وَكَمْ أَهْلَكْنَا قَبْلَهُم مِّن قَرْنٍ هُمْ أَحْسَنُ أَثَٰثًا وَرِءْيًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmcccxxv{قُلْ مَن كَانَ فِى ٱلضَّلَٰلَةِ فَلْيَمْدُدْ لَهُ ٱلرَّحْمَٰنُ مَدًّا حَتَّىٰٓ إِذَا رَأَوْا۟ مَا يُوعَدُونَ إِمَّا ٱلْعَذَابَ وَإِمَّا ٱلسَّاعَةَ فَسَيَعْلَمُونَ مَنْ هُوَ شَرٌّ مَّكَانًا وَأَضْعَفُ جُندًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcccxxvi{وَيَزِيدُ ٱللَّهُ ٱلَّذِينَ ٱهْتَدَوْا۟ هُدًى وَٱلْبَٰقِيَٰتُ ٱلصَّٰلِحَٰتُ خَيْرٌ عِندَ رَبِّكَ ثَوَابًا وَخَيْرٌ مَّرَدًّا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcccxxvii{أَفَرَءَيْتَ ٱلَّذِى كَفَرَ بِـَٔايَٰتِنَا وَقَالَ لَأُوتَيَنَّ مَالًا وَوَلَدًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcccxxviii{أَطَّلَعَ ٱلْغَيْبَ أَمِ ٱتَّخَذَ عِندَ ٱلرَّحْمَٰنِ عَهْدًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmcccxxix{كَلَّا سَنَكْتُبُ مَا يَقُولُ وَنَمُدُّ لَهُۥ مِنَ ٱلْعَذَابِ مَدًّا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmcccxxx{وَنَرِثُهُۥ مَا يَقُولُ وَيَأْتِينَا فَرْدًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmcccxxxi{وَٱتَّخَذُوا۟ مِن دُونِ ٱللَّهِ ءَالِهَةً لِّيَكُونُوا۟ لَهُمْ عِزًّا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmcccxxxii{كَلَّا سَيَكْفُرُونَ بِعِبَادَتِهِمْ وَيَكُونُونَ عَلَيْهِمْ ضِدًّا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmcccxxxiii{أَلَمْ تَرَ أَنَّآ أَرْسَلْنَا ٱلشَّيَٰطِينَ عَلَى ٱلْكَٰفِرِينَ تَؤُزُّهُمْ أَزًّا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmcccxxxiv{فَلَا تَعْجَلْ عَلَيْهِمْ إِنَّمَا نَعُدُّ لَهُمْ عَدًّا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmcccxxxv{يَوْمَ نَحْشُرُ ٱلْمُتَّقِينَ إِلَى ٱلرَّحْمَٰنِ وَفْدًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmcccxxxvi{وَنَسُوقُ ٱلْمُجْرِمِينَ إِلَىٰ جَهَنَّمَ وِرْدًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmcccxxxvii{لَّا يَمْلِكُونَ ٱلشَّفَٰعَةَ إِلَّا مَنِ ٱتَّخَذَ عِندَ ٱلرَّحْمَٰنِ عَهْدًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmcccxxxviii{وَقَالُوا۟ ٱتَّخَذَ ٱلرَّحْمَٰنُ وَلَدًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmcccxxxix{لَّقَدْ جِئْتُمْ شَيْـًٔا إِدًّا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmcccxl{تَكَادُ ٱلسَّمَٰوَٰتُ يَتَفَطَّرْنَ مِنْهُ وَتَنشَقُّ ٱلْأَرْضُ وَتَخِرُّ ٱلْجِبَالُ هَدًّا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmcccxli{أَن دَعَوْا۟ لِلرَّحْمَٰنِ وَلَدًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmcccxlii{وَمَا يَنۢبَغِى لِلرَّحْمَٰنِ أَن يَتَّخِذَ وَلَدًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmcccxliii{إِن كُلُّ مَن فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ إِلَّآ ءَاتِى ٱلرَّحْمَٰنِ عَبْدًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmcccxliv{لَّقَدْ أَحْصَىٰهُمْ وَعَدَّهُمْ عَدًّا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmcccxlv{وَكُلُّهُمْ ءَاتِيهِ يَوْمَ ٱلْقِيَٰمَةِ فَرْدًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmcccxlvi{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ سَيَجْعَلُ لَهُمُ ٱلرَّحْمَٰنُ وُدًّا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmcccxlvii{فَإِنَّمَا يَسَّرْنَٰهُ بِلِسَانِكَ لِتُبَشِّرَ بِهِ ٱلْمُتَّقِينَ وَتُنذِرَ بِهِۦ قَوْمًا لُّدًّا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmcccxlviii{وَكَمْ أَهْلَكْنَا قَبْلَهُم مِّن قَرْنٍ هَلْ تُحِسُّ مِنْهُم مِّنْ أَحَدٍ أَوْ تَسْمَعُ لَهُمْ رِكْزًۢا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmcccxlix{\basmalah طه\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcccl{مَآ أَنزَلْنَا عَلَيْكَ ٱلْقُرْءَانَ لِتَشْقَىٰٓ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcccli{إِلَّا تَذْكِرَةً لِّمَن يَخْشَىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmccclii{تَنزِيلًا مِّمَّنْ خَلَقَ ٱلْأَرْضَ وَٱلسَّمَٰوَٰتِ ٱلْعُلَى\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcccliii{ٱلرَّحْمَٰنُ عَلَى ٱلْعَرْشِ ٱسْتَوَىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcccliv{لَهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَمَا بَيْنَهُمَا وَمَا تَحْتَ ٱلثَّرَىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmccclv{وَإِن تَجْهَرْ بِٱلْقَوْلِ فَإِنَّهُۥ يَعْلَمُ ٱلسِّرَّ وَأَخْفَى\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmccclvi{ٱللَّهُ لَآ إِلَٰهَ إِلَّا هُوَ لَهُ ٱلْأَسْمَآءُ ٱلْحُسْنَىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmccclvii{وَهَلْ أَتَىٰكَ حَدِيثُ مُوسَىٰٓ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmccclviii{إِذْ رَءَا نَارًا فَقَالَ لِأَهْلِهِ ٱمْكُثُوٓا۟ إِنِّىٓ ءَانَسْتُ نَارًا لَّعَلِّىٓ ءَاتِيكُم مِّنْهَا بِقَبَسٍ أَوْ أَجِدُ عَلَى ٱلنَّارِ هُدًى\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmccclix{فَلَمَّآ أَتَىٰهَا نُودِىَ يَٰمُوسَىٰٓ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmccclx{إِنِّىٓ أَنَا۠ رَبُّكَ فَٱخْلَعْ نَعْلَيْكَ إِنَّكَ بِٱلْوَادِ ٱلْمُقَدَّسِ طُوًى\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmccclxi{وَأَنَا ٱخْتَرْتُكَ فَٱسْتَمِعْ لِمَا يُوحَىٰٓ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmccclxii{إِنَّنِىٓ أَنَا ٱللَّهُ لَآ إِلَٰهَ إِلَّآ أَنَا۠ فَٱعْبُدْنِى وَأَقِمِ ٱلصَّلَوٰةَ لِذِكْرِىٓ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmccclxiii{إِنَّ ٱلسَّاعَةَ ءَاتِيَةٌ أَكَادُ أُخْفِيهَا لِتُجْزَىٰ كُلُّ نَفْسٍۭ بِمَا تَسْعَىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmccclxiv{فَلَا يَصُدَّنَّكَ عَنْهَا مَن لَّا يُؤْمِنُ بِهَا وَٱتَّبَعَ هَوَىٰهُ فَتَرْدَىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmccclxv{وَمَا تِلْكَ بِيَمِينِكَ يَٰمُوسَىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmccclxvi{قَالَ هِىَ عَصَاىَ أَتَوَكَّؤُا۟ عَلَيْهَا وَأَهُشُّ بِهَا عَلَىٰ غَنَمِى وَلِىَ فِيهَا مَـَٔارِبُ أُخْرَىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmccclxvii{قَالَ أَلْقِهَا يَٰمُوسَىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmccclxviii{فَأَلْقَىٰهَا فَإِذَا هِىَ حَيَّةٌ تَسْعَىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmccclxix{قَالَ خُذْهَا وَلَا تَخَفْ سَنُعِيدُهَا سِيرَتَهَا ٱلْأُولَىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmccclxx{وَٱضْمُمْ يَدَكَ إِلَىٰ جَنَاحِكَ تَخْرُجْ بَيْضَآءَ مِنْ غَيْرِ سُوٓءٍ ءَايَةً أُخْرَىٰ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmccclxxi{لِنُرِيَكَ مِنْ ءَايَٰتِنَا ٱلْكُبْرَى\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmccclxxii{ٱذْهَبْ إِلَىٰ فِرْعَوْنَ إِنَّهُۥ طَغَىٰ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmccclxxiii{قَالَ رَبِّ ٱشْرَحْ لِى صَدْرِى\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmccclxxiv{وَيَسِّرْ لِىٓ أَمْرِى\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmccclxxv{وَٱحْلُلْ عُقْدَةً مِّن لِّسَانِى\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmccclxxvi{يَفْقَهُوا۟ قَوْلِى\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmccclxxvii{وَٱجْعَل لِّى وَزِيرًا مِّنْ أَهْلِى\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmccclxxviii{هَٰرُونَ أَخِى\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmccclxxix{ٱشْدُدْ بِهِۦٓ أَزْرِى\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmccclxxx{وَأَشْرِكْهُ فِىٓ أَمْرِى\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmccclxxxi{كَىْ نُسَبِّحَكَ كَثِيرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmccclxxxii{وَنَذْكُرَكَ كَثِيرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmccclxxxiii{إِنَّكَ كُنتَ بِنَا بَصِيرًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmccclxxxiv{قَالَ قَدْ أُوتِيتَ سُؤْلَكَ يَٰمُوسَىٰ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmccclxxxv{وَلَقَدْ مَنَنَّا عَلَيْكَ مَرَّةً أُخْرَىٰٓ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmccclxxxvi{إِذْ أَوْحَيْنَآ إِلَىٰٓ أُمِّكَ مَا يُوحَىٰٓ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmccclxxxvii{أَنِ ٱقْذِفِيهِ فِى ٱلتَّابُوتِ فَٱقْذِفِيهِ فِى ٱلْيَمِّ فَلْيُلْقِهِ ٱلْيَمُّ بِٱلسَّاحِلِ يَأْخُذْهُ عَدُوٌّ لِّى وَعَدُوٌّ لَّهُۥ وَأَلْقَيْتُ عَلَيْكَ مَحَبَّةً مِّنِّى وَلِتُصْنَعَ عَلَىٰ عَيْنِىٓ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmccclxxxviii{إِذْ تَمْشِىٓ أُخْتُكَ فَتَقُولُ هَلْ أَدُلُّكُمْ عَلَىٰ مَن يَكْفُلُهُۥ فَرَجَعْنَٰكَ إِلَىٰٓ أُمِّكَ كَىْ تَقَرَّ عَيْنُهَا وَلَا تَحْزَنَ وَقَتَلْتَ نَفْسًا فَنَجَّيْنَٰكَ مِنَ ٱلْغَمِّ وَفَتَنَّٰكَ فُتُونًا فَلَبِثْتَ سِنِينَ فِىٓ أَهْلِ مَدْيَنَ ثُمَّ جِئْتَ عَلَىٰ قَدَرٍ يَٰمُوسَىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmccclxxxix{وَٱصْطَنَعْتُكَ لِنَفْسِى\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmcccxc{ٱذْهَبْ أَنتَ وَأَخُوكَ بِـَٔايَٰتِى وَلَا تَنِيَا فِى ذِكْرِى\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmcccxci{ٱذْهَبَآ إِلَىٰ فِرْعَوْنَ إِنَّهُۥ طَغَىٰ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmcccxcii{فَقُولَا لَهُۥ قَوْلًا لَّيِّنًا لَّعَلَّهُۥ يَتَذَكَّرُ أَوْ يَخْشَىٰ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmcccxciii{قَالَا رَبَّنَآ إِنَّنَا نَخَافُ أَن يَفْرُطَ عَلَيْنَآ أَوْ أَن يَطْغَىٰ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmcccxciv{قَالَ لَا تَخَافَآ إِنَّنِى مَعَكُمَآ أَسْمَعُ وَأَرَىٰ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmcccxcv{فَأْتِيَاهُ فَقُولَآ إِنَّا رَسُولَا رَبِّكَ فَأَرْسِلْ مَعَنَا بَنِىٓ إِسْرَٰٓءِيلَ وَلَا تُعَذِّبْهُمْ قَدْ جِئْنَٰكَ بِـَٔايَةٍ مِّن رَّبِّكَ وَٱلسَّلَٰمُ عَلَىٰ مَنِ ٱتَّبَعَ ٱلْهُدَىٰٓ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmcccxcvi{إِنَّا قَدْ أُوحِىَ إِلَيْنَآ أَنَّ ٱلْعَذَابَ عَلَىٰ مَن كَذَّبَ وَتَوَلَّىٰ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmcccxcvii{قَالَ فَمَن رَّبُّكُمَا يَٰمُوسَىٰ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcccxcviii{قَالَ رَبُّنَا ٱلَّذِىٓ أَعْطَىٰ كُلَّ شَىْءٍ خَلْقَهُۥ ثُمَّ هَدَىٰ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcccxcix{قَالَ فَمَا بَالُ ٱلْقُرُونِ ٱلْأُولَىٰ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcd{قَالَ عِلْمُهَا عِندَ رَبِّى فِى كِتَٰبٍ لَّا يَضِلُّ رَبِّى وَلَا يَنسَى\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcdi{ٱلَّذِى جَعَلَ لَكُمُ ٱلْأَرْضَ مَهْدًا وَسَلَكَ لَكُمْ فِيهَا سُبُلًا وَأَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً فَأَخْرَجْنَا بِهِۦٓ أَزْوَٰجًا مِّن نَّبَاتٍ شَتَّىٰ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcdii{كُلُوا۟ وَٱرْعَوْا۟ أَنْعَٰمَكُمْ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّأُو۟لِى ٱلنُّهَىٰ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcdiii{مِنْهَا خَلَقْنَٰكُمْ وَفِيهَا نُعِيدُكُمْ وَمِنْهَا نُخْرِجُكُمْ تَارَةً أُخْرَىٰ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcdiv{وَلَقَدْ أَرَيْنَٰهُ ءَايَٰتِنَا كُلَّهَا فَكَذَّبَ وَأَبَىٰ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcdv{قَالَ أَجِئْتَنَا لِتُخْرِجَنَا مِنْ أَرْضِنَا بِسِحْرِكَ يَٰمُوسَىٰ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcdvi{فَلَنَأْتِيَنَّكَ بِسِحْرٍ مِّثْلِهِۦ فَٱجْعَلْ بَيْنَنَا وَبَيْنَكَ مَوْعِدًا لَّا نُخْلِفُهُۥ نَحْنُ وَلَآ أَنتَ مَكَانًا سُوًى\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcdvii{قَالَ مَوْعِدُكُمْ يَوْمُ ٱلزِّينَةِ وَأَن يُحْشَرَ ٱلنَّاسُ ضُحًى\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcdviii{فَتَوَلَّىٰ فِرْعَوْنُ فَجَمَعَ كَيْدَهُۥ ثُمَّ أَتَىٰ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcdix{قَالَ لَهُم مُّوسَىٰ وَيْلَكُمْ لَا تَفْتَرُوا۟ عَلَى ٱللَّهِ كَذِبًا فَيُسْحِتَكُم بِعَذَابٍ وَقَدْ خَابَ مَنِ ٱفْتَرَىٰ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcdx{فَتَنَٰزَعُوٓا۟ أَمْرَهُم بَيْنَهُمْ وَأَسَرُّوا۟ ٱلنَّجْوَىٰ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcdxi{قَالُوٓا۟ إِنْ هَٰذَٰنِ لَسَٰحِرَٰنِ يُرِيدَانِ أَن يُخْرِجَاكُم مِّنْ أَرْضِكُم بِسِحْرِهِمَا وَيَذْهَبَا بِطَرِيقَتِكُمُ ٱلْمُثْلَىٰ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcdxii{فَأَجْمِعُوا۟ كَيْدَكُمْ ثُمَّ ٱئْتُوا۟ صَفًّا وَقَدْ أَفْلَحَ ٱلْيَوْمَ مَنِ ٱسْتَعْلَىٰ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcdxiii{قَالُوا۟ يَٰمُوسَىٰٓ إِمَّآ أَن تُلْقِىَ وَإِمَّآ أَن نَّكُونَ أَوَّلَ مَنْ أَلْقَىٰ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcdxiv{قَالَ بَلْ أَلْقُوا۟ فَإِذَا حِبَالُهُمْ وَعِصِيُّهُمْ يُخَيَّلُ إِلَيْهِ مِن سِحْرِهِمْ أَنَّهَا تَسْعَىٰ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcdxv{فَأَوْجَسَ فِى نَفْسِهِۦ خِيفَةً مُّوسَىٰ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmcdxvi{قُلْنَا لَا تَخَفْ إِنَّكَ أَنتَ ٱلْأَعْلَىٰ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmcdxvii{وَأَلْقِ مَا فِى يَمِينِكَ تَلْقَفْ مَا صَنَعُوٓا۟ إِنَّمَا صَنَعُوا۟ كَيْدُ سَٰحِرٍ وَلَا يُفْلِحُ ٱلسَّاحِرُ حَيْثُ أَتَىٰ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmcdxviii{فَأُلْقِىَ ٱلسَّحَرَةُ سُجَّدًا قَالُوٓا۟ ءَامَنَّا بِرَبِّ هَٰرُونَ وَمُوسَىٰ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmcdxix{قَالَ ءَامَنتُمْ لَهُۥ قَبْلَ أَنْ ءَاذَنَ لَكُمْ إِنَّهُۥ لَكَبِيرُكُمُ ٱلَّذِى عَلَّمَكُمُ ٱلسِّحْرَ فَلَأُقَطِّعَنَّ أَيْدِيَكُمْ وَأَرْجُلَكُم مِّنْ خِلَٰفٍ وَلَأُصَلِّبَنَّكُمْ فِى جُذُوعِ ٱلنَّخْلِ وَلَتَعْلَمُنَّ أَيُّنَآ أَشَدُّ عَذَابًا وَأَبْقَىٰ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmcdxx{قَالُوا۟ لَن نُّؤْثِرَكَ عَلَىٰ مَا جَآءَنَا مِنَ ٱلْبَيِّنَٰتِ وَٱلَّذِى فَطَرَنَا فَٱقْضِ مَآ أَنتَ قَاضٍ إِنَّمَا تَقْضِى هَٰذِهِ ٱلْحَيَوٰةَ ٱلدُّنْيَآ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcdxxi{إِنَّآ ءَامَنَّا بِرَبِّنَا لِيَغْفِرَ لَنَا خَطَٰيَٰنَا وَمَآ أَكْرَهْتَنَا عَلَيْهِ مِنَ ٱلسِّحْرِ وَٱللَّهُ خَيْرٌ وَأَبْقَىٰٓ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmcdxxii{إِنَّهُۥ مَن يَأْتِ رَبَّهُۥ مُجْرِمًا فَإِنَّ لَهُۥ جَهَنَّمَ لَا يَمُوتُ فِيهَا وَلَا يَحْيَىٰ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmcdxxiii{وَمَن يَأْتِهِۦ مُؤْمِنًا قَدْ عَمِلَ ٱلصَّٰلِحَٰتِ فَأُو۟لَٰٓئِكَ لَهُمُ ٱلدَّرَجَٰتُ ٱلْعُلَىٰ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcdxxiv{جَنَّٰتُ عَدْنٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا وَذَٰلِكَ جَزَآءُ مَن تَزَكَّىٰ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcdxxv{وَلَقَدْ أَوْحَيْنَآ إِلَىٰ مُوسَىٰٓ أَنْ أَسْرِ بِعِبَادِى فَٱضْرِبْ لَهُمْ طَرِيقًا فِى ٱلْبَحْرِ يَبَسًا لَّا تَخَٰفُ دَرَكًا وَلَا تَخْشَىٰ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcdxxvi{فَأَتْبَعَهُمْ فِرْعَوْنُ بِجُنُودِهِۦ فَغَشِيَهُم مِّنَ ٱلْيَمِّ مَا غَشِيَهُمْ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmcdxxvii{وَأَضَلَّ فِرْعَوْنُ قَوْمَهُۥ وَمَا هَدَىٰ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmcdxxviii{يَٰبَنِىٓ إِسْرَٰٓءِيلَ قَدْ أَنجَيْنَٰكُم مِّنْ عَدُوِّكُمْ وَوَٰعَدْنَٰكُمْ جَانِبَ ٱلطُّورِ ٱلْأَيْمَنَ وَنَزَّلْنَا عَلَيْكُمُ ٱلْمَنَّ وَٱلسَّلْوَىٰ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmcdxxix{كُلُوا۟ مِن طَيِّبَٰتِ مَا رَزَقْنَٰكُمْ وَلَا تَطْغَوْا۟ فِيهِ فَيَحِلَّ عَلَيْكُمْ غَضَبِى وَمَن يَحْلِلْ عَلَيْهِ غَضَبِى فَقَدْ هَوَىٰ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmcdxxx{وَإِنِّى لَغَفَّارٌ لِّمَن تَابَ وَءَامَنَ وَعَمِلَ صَٰلِحًا ثُمَّ ٱهْتَدَىٰ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmcdxxxi{وَمَآ أَعْجَلَكَ عَن قَوْمِكَ يَٰمُوسَىٰ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmcdxxxii{قَالَ هُمْ أُو۟لَآءِ عَلَىٰٓ أَثَرِى وَعَجِلْتُ إِلَيْكَ رَبِّ لِتَرْضَىٰ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmcdxxxiii{قَالَ فَإِنَّا قَدْ فَتَنَّا قَوْمَكَ مِنۢ بَعْدِكَ وَأَضَلَّهُمُ ٱلسَّامِرِىُّ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmcdxxxiv{فَرَجَعَ مُوسَىٰٓ إِلَىٰ قَوْمِهِۦ غَضْبَٰنَ أَسِفًا قَالَ يَٰقَوْمِ أَلَمْ يَعِدْكُمْ رَبُّكُمْ وَعْدًا حَسَنًا أَفَطَالَ عَلَيْكُمُ ٱلْعَهْدُ أَمْ أَرَدتُّمْ أَن يَحِلَّ عَلَيْكُمْ غَضَبٌ مِّن رَّبِّكُمْ فَأَخْلَفْتُم مَّوْعِدِى\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmcdxxxv{قَالُوا۟ مَآ أَخْلَفْنَا مَوْعِدَكَ بِمَلْكِنَا وَلَٰكِنَّا حُمِّلْنَآ أَوْزَارًا مِّن زِينَةِ ٱلْقَوْمِ فَقَذَفْنَٰهَا فَكَذَٰلِكَ أَلْقَى ٱلسَّامِرِىُّ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmcdxxxvi{فَأَخْرَجَ لَهُمْ عِجْلًا جَسَدًا لَّهُۥ خُوَارٌ فَقَالُوا۟ هَٰذَآ إِلَٰهُكُمْ وَإِلَٰهُ مُوسَىٰ فَنَسِىَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmcdxxxvii{أَفَلَا يَرَوْنَ أَلَّا يَرْجِعُ إِلَيْهِمْ قَوْلًا وَلَا يَمْلِكُ لَهُمْ ضَرًّا وَلَا نَفْعًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmcdxxxviii{وَلَقَدْ قَالَ لَهُمْ هَٰرُونُ مِن قَبْلُ يَٰقَوْمِ إِنَّمَا فُتِنتُم بِهِۦ وَإِنَّ رَبَّكُمُ ٱلرَّحْمَٰنُ فَٱتَّبِعُونِى وَأَطِيعُوٓا۟ أَمْرِى\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmcdxxxix{قَالُوا۟ لَن نَّبْرَحَ عَلَيْهِ عَٰكِفِينَ حَتَّىٰ يَرْجِعَ إِلَيْنَا مُوسَىٰ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmcdxl{قَالَ يَٰهَٰرُونُ مَا مَنَعَكَ إِذْ رَأَيْتَهُمْ ضَلُّوٓا۟\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmcdxli{أَلَّا تَتَّبِعَنِ أَفَعَصَيْتَ أَمْرِى\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmcdxlii{قَالَ يَبْنَؤُمَّ لَا تَأْخُذْ بِلِحْيَتِى وَلَا بِرَأْسِىٓ إِنِّى خَشِيتُ أَن تَقُولَ فَرَّقْتَ بَيْنَ بَنِىٓ إِسْرَٰٓءِيلَ وَلَمْ تَرْقُبْ قَوْلِى\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmcdxliii{قَالَ فَمَا خَطْبُكَ يَٰسَٰمِرِىُّ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmcdxliv{قَالَ بَصُرْتُ بِمَا لَمْ يَبْصُرُوا۟ بِهِۦ فَقَبَضْتُ قَبْضَةً مِّنْ أَثَرِ ٱلرَّسُولِ فَنَبَذْتُهَا وَكَذَٰلِكَ سَوَّلَتْ لِى نَفْسِى\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmcdxlv{قَالَ فَٱذْهَبْ فَإِنَّ لَكَ فِى ٱلْحَيَوٰةِ أَن تَقُولَ لَا مِسَاسَ وَإِنَّ لَكَ مَوْعِدًا لَّن تُخْلَفَهُۥ وَٱنظُرْ إِلَىٰٓ إِلَٰهِكَ ٱلَّذِى ظَلْتَ عَلَيْهِ عَاكِفًا لَّنُحَرِّقَنَّهُۥ ثُمَّ لَنَنسِفَنَّهُۥ فِى ٱلْيَمِّ نَسْفًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmcdxlvi{إِنَّمَآ إِلَٰهُكُمُ ٱللَّهُ ٱلَّذِى لَآ إِلَٰهَ إِلَّا هُوَ وَسِعَ كُلَّ شَىْءٍ عِلْمًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmcdxlvii{كَذَٰلِكَ نَقُصُّ عَلَيْكَ مِنْ أَنۢبَآءِ مَا قَدْ سَبَقَ وَقَدْ ءَاتَيْنَٰكَ مِن لَّدُنَّا ذِكْرًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmcdxlviii{مَّنْ أَعْرَضَ عَنْهُ فَإِنَّهُۥ يَحْمِلُ يَوْمَ ٱلْقِيَٰمَةِ وِزْرًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmcdxlix{خَٰلِدِينَ فِيهِ وَسَآءَ لَهُمْ يَوْمَ ٱلْقِيَٰمَةِ حِمْلًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmcdl{يَوْمَ يُنفَخُ فِى ٱلصُّورِ وَنَحْشُرُ ٱلْمُجْرِمِينَ يَوْمَئِذٍ زُرْقًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmcdli{يَتَخَٰفَتُونَ بَيْنَهُمْ إِن لَّبِثْتُمْ إِلَّا عَشْرًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmcdlii{نَّحْنُ أَعْلَمُ بِمَا يَقُولُونَ إِذْ يَقُولُ أَمْثَلُهُمْ طَرِيقَةً إِن لَّبِثْتُمْ إِلَّا يَوْمًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmcdliii{وَيَسْـَٔلُونَكَ عَنِ ٱلْجِبَالِ فَقُلْ يَنسِفُهَا رَبِّى نَسْفًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmcdliv{فَيَذَرُهَا قَاعًا صَفْصَفًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmcdlv{لَّا تَرَىٰ فِيهَا عِوَجًا وَلَآ أَمْتًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmcdlvi{يَوْمَئِذٍ يَتَّبِعُونَ ٱلدَّاعِىَ لَا عِوَجَ لَهُۥ وَخَشَعَتِ ٱلْأَصْوَاتُ لِلرَّحْمَٰنِ فَلَا تَسْمَعُ إِلَّا هَمْسًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmcdlvii{يَوْمَئِذٍ لَّا تَنفَعُ ٱلشَّفَٰعَةُ إِلَّا مَنْ أَذِنَ لَهُ ٱلرَّحْمَٰنُ وَرَضِىَ لَهُۥ قَوْلًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmcdlviii{يَعْلَمُ مَا بَيْنَ أَيْدِيهِمْ وَمَا خَلْفَهُمْ وَلَا يُحِيطُونَ بِهِۦ عِلْمًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmcdlix{وَعَنَتِ ٱلْوُجُوهُ لِلْحَىِّ ٱلْقَيُّومِ وَقَدْ خَابَ مَنْ حَمَلَ ظُلْمًا\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmcdlx{وَمَن يَعْمَلْ مِنَ ٱلصَّٰلِحَٰتِ وَهُوَ مُؤْمِنٌ فَلَا يَخَافُ ظُلْمًا وَلَا هَضْمًا\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmcdlxi{وَكَذَٰلِكَ أَنزَلْنَٰهُ قُرْءَانًا عَرَبِيًّا وَصَرَّفْنَا فِيهِ مِنَ ٱلْوَعِيدِ لَعَلَّهُمْ يَتَّقُونَ أَوْ يُحْدِثُ لَهُمْ ذِكْرًا\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmcdlxii{فَتَعَٰلَى ٱللَّهُ ٱلْمَلِكُ ٱلْحَقُّ وَلَا تَعْجَلْ بِٱلْقُرْءَانِ مِن قَبْلِ أَن يُقْضَىٰٓ إِلَيْكَ وَحْيُهُۥ وَقُل رَّبِّ زِدْنِى عِلْمًا\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmcdlxiii{وَلَقَدْ عَهِدْنَآ إِلَىٰٓ ءَادَمَ مِن قَبْلُ فَنَسِىَ وَلَمْ نَجِدْ لَهُۥ عَزْمًا\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmcdlxiv{وَإِذْ قُلْنَا لِلْمَلَٰٓئِكَةِ ٱسْجُدُوا۟ لِءَادَمَ فَسَجَدُوٓا۟ إِلَّآ إِبْلِيسَ أَبَىٰ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmcdlxv{فَقُلْنَا يَٰٓـَٔادَمُ إِنَّ هَٰذَا عَدُوٌّ لَّكَ وَلِزَوْجِكَ فَلَا يُخْرِجَنَّكُمَا مِنَ ٱلْجَنَّةِ فَتَشْقَىٰٓ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmcdlxvi{إِنَّ لَكَ أَلَّا تَجُوعَ فِيهَا وَلَا تَعْرَىٰ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmcdlxvii{وَأَنَّكَ لَا تَظْمَؤُا۟ فِيهَا وَلَا تَضْحَىٰ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmcdlxviii{فَوَسْوَسَ إِلَيْهِ ٱلشَّيْطَٰنُ قَالَ يَٰٓـَٔادَمُ هَلْ أَدُلُّكَ عَلَىٰ شَجَرَةِ ٱلْخُلْدِ وَمُلْكٍ لَّا يَبْلَىٰ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmcdlxix{فَأَكَلَا مِنْهَا فَبَدَتْ لَهُمَا سَوْءَٰتُهُمَا وَطَفِقَا يَخْصِفَانِ عَلَيْهِمَا مِن وَرَقِ ٱلْجَنَّةِ وَعَصَىٰٓ ءَادَمُ رَبَّهُۥ فَغَوَىٰ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmcdlxx{ثُمَّ ٱجْتَبَٰهُ رَبُّهُۥ فَتَابَ عَلَيْهِ وَهَدَىٰ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmcdlxxi{قَالَ ٱهْبِطَا مِنْهَا جَمِيعًۢا بَعْضُكُمْ لِبَعْضٍ عَدُوٌّ فَإِمَّا يَأْتِيَنَّكُم مِّنِّى هُدًى فَمَنِ ٱتَّبَعَ هُدَاىَ فَلَا يَضِلُّ وَلَا يَشْقَىٰ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmcdlxxii{وَمَنْ أَعْرَضَ عَن ذِكْرِى فَإِنَّ لَهُۥ مَعِيشَةً ضَنكًا وَنَحْشُرُهُۥ يَوْمَ ٱلْقِيَٰمَةِ أَعْمَىٰ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmcdlxxiii{قَالَ رَبِّ لِمَ حَشَرْتَنِىٓ أَعْمَىٰ وَقَدْ كُنتُ بَصِيرًا\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmcdlxxiv{قَالَ كَذَٰلِكَ أَتَتْكَ ءَايَٰتُنَا فَنَسِيتَهَا وَكَذَٰلِكَ ٱلْيَوْمَ تُنسَىٰ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmcdlxxv{وَكَذَٰلِكَ نَجْزِى مَنْ أَسْرَفَ وَلَمْ يُؤْمِنۢ بِـَٔايَٰتِ رَبِّهِۦ وَلَعَذَابُ ٱلْءَاخِرَةِ أَشَدُّ وَأَبْقَىٰٓ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmcdlxxvi{أَفَلَمْ يَهْدِ لَهُمْ كَمْ أَهْلَكْنَا قَبْلَهُم مِّنَ ٱلْقُرُونِ يَمْشُونَ فِى مَسَٰكِنِهِمْ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّأُو۟لِى ٱلنُّهَىٰ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmcdlxxvii{وَلَوْلَا كَلِمَةٌ سَبَقَتْ مِن رَّبِّكَ لَكَانَ لِزَامًا وَأَجَلٌ مُّسَمًّى\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mmcdlxxviii{فَٱصْبِرْ عَلَىٰ مَا يَقُولُونَ وَسَبِّحْ بِحَمْدِ رَبِّكَ قَبْلَ طُلُوعِ ٱلشَّمْسِ وَقَبْلَ غُرُوبِهَا وَمِنْ ءَانَآئِ ٱلَّيْلِ فَسَبِّحْ وَأَطْرَافَ ٱلنَّهَارِ لَعَلَّكَ تَرْضَىٰ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mmcdlxxix{وَلَا تَمُدَّنَّ عَيْنَيْكَ إِلَىٰ مَا مَتَّعْنَا بِهِۦٓ أَزْوَٰجًا مِّنْهُمْ زَهْرَةَ ٱلْحَيَوٰةِ ٱلدُّنْيَا لِنَفْتِنَهُمْ فِيهِ وَرِزْقُ رَبِّكَ خَيْرٌ وَأَبْقَىٰ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mmcdlxxx{وَأْمُرْ أَهْلَكَ بِٱلصَّلَوٰةِ وَٱصْطَبِرْ عَلَيْهَا لَا نَسْـَٔلُكَ رِزْقًا نَّحْنُ نَرْزُقُكَ وَٱلْعَٰقِبَةُ لِلتَّقْوَىٰ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mmcdlxxxi{وَقَالُوا۟ لَوْلَا يَأْتِينَا بِـَٔايَةٍ مِّن رَّبِّهِۦٓ أَوَلَمْ تَأْتِهِم بَيِّنَةُ مَا فِى ٱلصُّحُفِ ٱلْأُولَىٰ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mmcdlxxxii{وَلَوْ أَنَّآ أَهْلَكْنَٰهُم بِعَذَابٍ مِّن قَبْلِهِۦ لَقَالُوا۟ رَبَّنَا لَوْلَآ أَرْسَلْتَ إِلَيْنَا رَسُولًا فَنَتَّبِعَ ءَايَٰتِكَ مِن قَبْلِ أَن نَّذِلَّ وَنَخْزَىٰ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mmcdlxxxiii{قُلْ كُلٌّ مُّتَرَبِّصٌ فَتَرَبَّصُوا۟ فَسَتَعْلَمُونَ مَنْ أَصْحَٰبُ ٱلصِّرَٰطِ ٱلسَّوِىِّ وَمَنِ ٱهْتَدَىٰ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mmcdlxxxiv{\basmalah ٱقْتَرَبَ لِلنَّاسِ حِسَابُهُمْ وَهُمْ فِى غَفْلَةٍ مُّعْرِضُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcdlxxxv{مَا يَأْتِيهِم مِّن ذِكْرٍ مِّن رَّبِّهِم مُّحْدَثٍ إِلَّا ٱسْتَمَعُوهُ وَهُمْ يَلْعَبُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcdlxxxvi{لَاهِيَةً قُلُوبُهُمْ وَأَسَرُّوا۟ ٱلنَّجْوَى ٱلَّذِينَ ظَلَمُوا۟ هَلْ هَٰذَآ إِلَّا بَشَرٌ مِّثْلُكُمْ أَفَتَأْتُونَ ٱلسِّحْرَ وَأَنتُمْ تُبْصِرُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmcdlxxxvii{قَالَ رَبِّى يَعْلَمُ ٱلْقَوْلَ فِى ٱلسَّمَآءِ وَٱلْأَرْضِ وَهُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcdlxxxviii{بَلْ قَالُوٓا۟ أَضْغَٰثُ أَحْلَٰمٍۭ بَلِ ٱفْتَرَىٰهُ بَلْ هُوَ شَاعِرٌ فَلْيَأْتِنَا بِـَٔايَةٍ كَمَآ أُرْسِلَ ٱلْأَوَّلُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcdlxxxix{مَآ ءَامَنَتْ قَبْلَهُم مِّن قَرْيَةٍ أَهْلَكْنَٰهَآ أَفَهُمْ يُؤْمِنُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcdxc{وَمَآ أَرْسَلْنَا قَبْلَكَ إِلَّا رِجَالًا نُّوحِىٓ إِلَيْهِمْ فَسْـَٔلُوٓا۟ أَهْلَ ٱلذِّكْرِ إِن كُنتُمْ لَا تَعْلَمُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcdxci{وَمَا جَعَلْنَٰهُمْ جَسَدًا لَّا يَأْكُلُونَ ٱلطَّعَامَ وَمَا كَانُوا۟ خَٰلِدِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcdxcii{ثُمَّ صَدَقْنَٰهُمُ ٱلْوَعْدَ فَأَنجَيْنَٰهُمْ وَمَن نَّشَآءُ وَأَهْلَكْنَا ٱلْمُسْرِفِينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcdxciii{لَقَدْ أَنزَلْنَآ إِلَيْكُمْ كِتَٰبًا فِيهِ ذِكْرُكُمْ أَفَلَا تَعْقِلُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcdxciv{وَكَمْ قَصَمْنَا مِن قَرْيَةٍ كَانَتْ ظَالِمَةً وَأَنشَأْنَا بَعْدَهَا قَوْمًا ءَاخَرِينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmcdxcv{فَلَمَّآ أَحَسُّوا۟ بَأْسَنَآ إِذَا هُم مِّنْهَا يَرْكُضُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcdxcvi{لَا تَرْكُضُوا۟ وَٱرْجِعُوٓا۟ إِلَىٰ مَآ أُتْرِفْتُمْ فِيهِ وَمَسَٰكِنِكُمْ لَعَلَّكُمْ تُسْـَٔلُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcdxcvii{قَالُوا۟ يَٰوَيْلَنَآ إِنَّا كُنَّا ظَٰلِمِينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmcdxcviii{فَمَا زَالَت تِّلْكَ دَعْوَىٰهُمْ حَتَّىٰ جَعَلْنَٰهُمْ حَصِيدًا خَٰمِدِينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmcdxcix{وَمَا خَلَقْنَا ٱلسَّمَآءَ وَٱلْأَرْضَ وَمَا بَيْنَهُمَا لَٰعِبِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmd{لَوْ أَرَدْنَآ أَن نَّتَّخِذَ لَهْوًا لَّٱتَّخَذْنَٰهُ مِن لَّدُنَّآ إِن كُنَّا فَٰعِلِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdi{بَلْ نَقْذِفُ بِٱلْحَقِّ عَلَى ٱلْبَٰطِلِ فَيَدْمَغُهُۥ فَإِذَا هُوَ زَاهِقٌ وَلَكُمُ ٱلْوَيْلُ مِمَّا تَصِفُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdii{وَلَهُۥ مَن فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَنْ عِندَهُۥ لَا يَسْتَكْبِرُونَ عَنْ عِبَادَتِهِۦ وَلَا يَسْتَحْسِرُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdiii{يُسَبِّحُونَ ٱلَّيْلَ وَٱلنَّهَارَ لَا يَفْتُرُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdiv{أَمِ ٱتَّخَذُوٓا۟ ءَالِهَةً مِّنَ ٱلْأَرْضِ هُمْ يُنشِرُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdv{لَوْ كَانَ فِيهِمَآ ءَالِهَةٌ إِلَّا ٱللَّهُ لَفَسَدَتَا فَسُبْحَٰنَ ٱللَّهِ رَبِّ ٱلْعَرْشِ عَمَّا يَصِفُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdvi{لَا يُسْـَٔلُ عَمَّا يَفْعَلُ وَهُمْ يُسْـَٔلُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdvii{أَمِ ٱتَّخَذُوا۟ مِن دُونِهِۦٓ ءَالِهَةً قُلْ هَاتُوا۟ بُرْهَٰنَكُمْ هَٰذَا ذِكْرُ مَن مَّعِىَ وَذِكْرُ مَن قَبْلِى بَلْ أَكْثَرُهُمْ لَا يَعْلَمُونَ ٱلْحَقَّ فَهُم مُّعْرِضُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdviii{وَمَآ أَرْسَلْنَا مِن قَبْلِكَ مِن رَّسُولٍ إِلَّا نُوحِىٓ إِلَيْهِ أَنَّهُۥ لَآ إِلَٰهَ إِلَّآ أَنَا۠ فَٱعْبُدُونِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdix{وَقَالُوا۟ ٱتَّخَذَ ٱلرَّحْمَٰنُ وَلَدًا سُبْحَٰنَهُۥ بَلْ عِبَادٌ مُّكْرَمُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdx{لَا يَسْبِقُونَهُۥ بِٱلْقَوْلِ وَهُم بِأَمْرِهِۦ يَعْمَلُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdxi{يَعْلَمُ مَا بَيْنَ أَيْدِيهِمْ وَمَا خَلْفَهُمْ وَلَا يَشْفَعُونَ إِلَّا لِمَنِ ٱرْتَضَىٰ وَهُم مِّنْ خَشْيَتِهِۦ مُشْفِقُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdxii{وَمَن يَقُلْ مِنْهُمْ إِنِّىٓ إِلَٰهٌ مِّن دُونِهِۦ فَذَٰلِكَ نَجْزِيهِ جَهَنَّمَ كَذَٰلِكَ نَجْزِى ٱلظَّٰلِمِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdxiii{أَوَلَمْ يَرَ ٱلَّذِينَ كَفَرُوٓا۟ أَنَّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ كَانَتَا رَتْقًا فَفَتَقْنَٰهُمَا وَجَعَلْنَا مِنَ ٱلْمَآءِ كُلَّ شَىْءٍ حَىٍّ أَفَلَا يُؤْمِنُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdxiv{وَجَعَلْنَا فِى ٱلْأَرْضِ رَوَٰسِىَ أَن تَمِيدَ بِهِمْ وَجَعَلْنَا فِيهَا فِجَاجًا سُبُلًا لَّعَلَّهُمْ يَهْتَدُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdxv{وَجَعَلْنَا ٱلسَّمَآءَ سَقْفًا مَّحْفُوظًا وَهُمْ عَنْ ءَايَٰتِهَا مُعْرِضُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdxvi{وَهُوَ ٱلَّذِى خَلَقَ ٱلَّيْلَ وَٱلنَّهَارَ وَٱلشَّمْسَ وَٱلْقَمَرَ كُلٌّ فِى فَلَكٍ يَسْبَحُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdxvii{وَمَا جَعَلْنَا لِبَشَرٍ مِّن قَبْلِكَ ٱلْخُلْدَ أَفَإِي۟ن مِّتَّ فَهُمُ ٱلْخَٰلِدُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdxviii{كُلُّ نَفْسٍ ذَآئِقَةُ ٱلْمَوْتِ وَنَبْلُوكُم بِٱلشَّرِّ وَٱلْخَيْرِ فِتْنَةً وَإِلَيْنَا تُرْجَعُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdxix{وَإِذَا رَءَاكَ ٱلَّذِينَ كَفَرُوٓا۟ إِن يَتَّخِذُونَكَ إِلَّا هُزُوًا أَهَٰذَا ٱلَّذِى يَذْكُرُ ءَالِهَتَكُمْ وَهُم بِذِكْرِ ٱلرَّحْمَٰنِ هُمْ كَٰفِرُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdxx{خُلِقَ ٱلْإِنسَٰنُ مِنْ عَجَلٍ سَأُو۟رِيكُمْ ءَايَٰتِى فَلَا تَسْتَعْجِلُونِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdxxi{وَيَقُولُونَ مَتَىٰ هَٰذَا ٱلْوَعْدُ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdxxii{لَوْ يَعْلَمُ ٱلَّذِينَ كَفَرُوا۟ حِينَ لَا يَكُفُّونَ عَن وُجُوهِهِمُ ٱلنَّارَ وَلَا عَن ظُهُورِهِمْ وَلَا هُمْ يُنصَرُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdxxiii{بَلْ تَأْتِيهِم بَغْتَةً فَتَبْهَتُهُمْ فَلَا يَسْتَطِيعُونَ رَدَّهَا وَلَا هُمْ يُنظَرُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdxxiv{وَلَقَدِ ٱسْتُهْزِئَ بِرُسُلٍ مِّن قَبْلِكَ فَحَاقَ بِٱلَّذِينَ سَخِرُوا۟ مِنْهُم مَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdxxv{قُلْ مَن يَكْلَؤُكُم بِٱلَّيْلِ وَٱلنَّهَارِ مِنَ ٱلرَّحْمَٰنِ بَلْ هُمْ عَن ذِكْرِ رَبِّهِم مُّعْرِضُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdxxvi{أَمْ لَهُمْ ءَالِهَةٌ تَمْنَعُهُم مِّن دُونِنَا لَا يَسْتَطِيعُونَ نَصْرَ أَنفُسِهِمْ وَلَا هُم مِّنَّا يُصْحَبُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdxxvii{بَلْ مَتَّعْنَا هَٰٓؤُلَآءِ وَءَابَآءَهُمْ حَتَّىٰ طَالَ عَلَيْهِمُ ٱلْعُمُرُ أَفَلَا يَرَوْنَ أَنَّا نَأْتِى ٱلْأَرْضَ نَنقُصُهَا مِنْ أَطْرَافِهَآ أَفَهُمُ ٱلْغَٰلِبُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdxxviii{قُلْ إِنَّمَآ أُنذِرُكُم بِٱلْوَحْىِ وَلَا يَسْمَعُ ٱلصُّمُّ ٱلدُّعَآءَ إِذَا مَا يُنذَرُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdxxix{وَلَئِن مَّسَّتْهُمْ نَفْحَةٌ مِّنْ عَذَابِ رَبِّكَ لَيَقُولُنَّ يَٰوَيْلَنَآ إِنَّا كُنَّا ظَٰلِمِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdxxx{وَنَضَعُ ٱلْمَوَٰزِينَ ٱلْقِسْطَ لِيَوْمِ ٱلْقِيَٰمَةِ فَلَا تُظْلَمُ نَفْسٌ شَيْـًٔا وَإِن كَانَ مِثْقَالَ حَبَّةٍ مِّنْ خَرْدَلٍ أَتَيْنَا بِهَا وَكَفَىٰ بِنَا حَٰسِبِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdxxxi{وَلَقَدْ ءَاتَيْنَا مُوسَىٰ وَهَٰرُونَ ٱلْفُرْقَانَ وَضِيَآءً وَذِكْرًا لِّلْمُتَّقِينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdxxxii{ٱلَّذِينَ يَخْشَوْنَ رَبَّهُم بِٱلْغَيْبِ وَهُم مِّنَ ٱلسَّاعَةِ مُشْفِقُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdxxxiii{وَهَٰذَا ذِكْرٌ مُّبَارَكٌ أَنزَلْنَٰهُ أَفَأَنتُمْ لَهُۥ مُنكِرُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdxxxiv{وَلَقَدْ ءَاتَيْنَآ إِبْرَٰهِيمَ رُشْدَهُۥ مِن قَبْلُ وَكُنَّا بِهِۦ عَٰلِمِينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdxxxv{إِذْ قَالَ لِأَبِيهِ وَقَوْمِهِۦ مَا هَٰذِهِ ٱلتَّمَاثِيلُ ٱلَّتِىٓ أَنتُمْ لَهَا عَٰكِفُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdxxxvi{قَالُوا۟ وَجَدْنَآ ءَابَآءَنَا لَهَا عَٰبِدِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdxxxvii{قَالَ لَقَدْ كُنتُمْ أَنتُمْ وَءَابَآؤُكُمْ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdxxxviii{قَالُوٓا۟ أَجِئْتَنَا بِٱلْحَقِّ أَمْ أَنتَ مِنَ ٱللَّٰعِبِينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdxxxix{قَالَ بَل رَّبُّكُمْ رَبُّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ ٱلَّذِى فَطَرَهُنَّ وَأَنَا۠ عَلَىٰ ذَٰلِكُم مِّنَ ٱلشَّٰهِدِينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdxl{وَتَٱللَّهِ لَأَكِيدَنَّ أَصْنَٰمَكُم بَعْدَ أَن تُوَلُّوا۟ مُدْبِرِينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdxli{فَجَعَلَهُمْ جُذَٰذًا إِلَّا كَبِيرًا لَّهُمْ لَعَلَّهُمْ إِلَيْهِ يَرْجِعُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdxlii{قَالُوا۟ مَن فَعَلَ هَٰذَا بِـَٔالِهَتِنَآ إِنَّهُۥ لَمِنَ ٱلظَّٰلِمِينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdxliii{قَالُوا۟ سَمِعْنَا فَتًى يَذْكُرُهُمْ يُقَالُ لَهُۥٓ إِبْرَٰهِيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdxliv{قَالُوا۟ فَأْتُوا۟ بِهِۦ عَلَىٰٓ أَعْيُنِ ٱلنَّاسِ لَعَلَّهُمْ يَشْهَدُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdxlv{قَالُوٓا۟ ءَأَنتَ فَعَلْتَ هَٰذَا بِـَٔالِهَتِنَا يَٰٓإِبْرَٰهِيمُ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdxlvi{قَالَ بَلْ فَعَلَهُۥ كَبِيرُهُمْ هَٰذَا فَسْـَٔلُوهُمْ إِن كَانُوا۟ يَنطِقُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdxlvii{فَرَجَعُوٓا۟ إِلَىٰٓ أَنفُسِهِمْ فَقَالُوٓا۟ إِنَّكُمْ أَنتُمُ ٱلظَّٰلِمُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdxlviii{ثُمَّ نُكِسُوا۟ عَلَىٰ رُءُوسِهِمْ لَقَدْ عَلِمْتَ مَا هَٰٓؤُلَآءِ يَنطِقُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmdxlix{قَالَ أَفَتَعْبُدُونَ مِن دُونِ ٱللَّهِ مَا لَا يَنفَعُكُمْ شَيْـًٔا وَلَا يَضُرُّكُمْ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmdl{أُفٍّ لَّكُمْ وَلِمَا تَعْبُدُونَ مِن دُونِ ٱللَّهِ أَفَلَا تَعْقِلُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmdli{قَالُوا۟ حَرِّقُوهُ وَٱنصُرُوٓا۟ ءَالِهَتَكُمْ إِن كُنتُمْ فَٰعِلِينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmdlii{قُلْنَا يَٰنَارُ كُونِى بَرْدًا وَسَلَٰمًا عَلَىٰٓ إِبْرَٰهِيمَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmdliii{وَأَرَادُوا۟ بِهِۦ كَيْدًا فَجَعَلْنَٰهُمُ ٱلْأَخْسَرِينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmdliv{وَنَجَّيْنَٰهُ وَلُوطًا إِلَى ٱلْأَرْضِ ٱلَّتِى بَٰرَكْنَا فِيهَا لِلْعَٰلَمِينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmdlv{وَوَهَبْنَا لَهُۥٓ إِسْحَٰقَ وَيَعْقُوبَ نَافِلَةً وَكُلًّا جَعَلْنَا صَٰلِحِينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmdlvi{وَجَعَلْنَٰهُمْ أَئِمَّةً يَهْدُونَ بِأَمْرِنَا وَأَوْحَيْنَآ إِلَيْهِمْ فِعْلَ ٱلْخَيْرَٰتِ وَإِقَامَ ٱلصَّلَوٰةِ وَإِيتَآءَ ٱلزَّكَوٰةِ وَكَانُوا۟ لَنَا عَٰبِدِينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmdlvii{وَلُوطًا ءَاتَيْنَٰهُ حُكْمًا وَعِلْمًا وَنَجَّيْنَٰهُ مِنَ ٱلْقَرْيَةِ ٱلَّتِى كَانَت تَّعْمَلُ ٱلْخَبَٰٓئِثَ إِنَّهُمْ كَانُوا۟ قَوْمَ سَوْءٍ فَٰسِقِينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmdlviii{وَأَدْخَلْنَٰهُ فِى رَحْمَتِنَآ إِنَّهُۥ مِنَ ٱلصَّٰلِحِينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmdlix{وَنُوحًا إِذْ نَادَىٰ مِن قَبْلُ فَٱسْتَجَبْنَا لَهُۥ فَنَجَّيْنَٰهُ وَأَهْلَهُۥ مِنَ ٱلْكَرْبِ ٱلْعَظِيمِ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmdlx{وَنَصَرْنَٰهُ مِنَ ٱلْقَوْمِ ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَآ إِنَّهُمْ كَانُوا۟ قَوْمَ سَوْءٍ فَأَغْرَقْنَٰهُمْ أَجْمَعِينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmdlxi{وَدَاوُۥدَ وَسُلَيْمَٰنَ إِذْ يَحْكُمَانِ فِى ٱلْحَرْثِ إِذْ نَفَشَتْ فِيهِ غَنَمُ ٱلْقَوْمِ وَكُنَّا لِحُكْمِهِمْ شَٰهِدِينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmdlxii{فَفَهَّمْنَٰهَا سُلَيْمَٰنَ وَكُلًّا ءَاتَيْنَا حُكْمًا وَعِلْمًا وَسَخَّرْنَا مَعَ دَاوُۥدَ ٱلْجِبَالَ يُسَبِّحْنَ وَٱلطَّيْرَ وَكُنَّا فَٰعِلِينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmdlxiii{وَعَلَّمْنَٰهُ صَنْعَةَ لَبُوسٍ لَّكُمْ لِتُحْصِنَكُم مِّنۢ بَأْسِكُمْ فَهَلْ أَنتُمْ شَٰكِرُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmdlxiv{وَلِسُلَيْمَٰنَ ٱلرِّيحَ عَاصِفَةً تَجْرِى بِأَمْرِهِۦٓ إِلَى ٱلْأَرْضِ ٱلَّتِى بَٰرَكْنَا فِيهَا وَكُنَّا بِكُلِّ شَىْءٍ عَٰلِمِينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmdlxv{وَمِنَ ٱلشَّيَٰطِينِ مَن يَغُوصُونَ لَهُۥ وَيَعْمَلُونَ عَمَلًا دُونَ ذَٰلِكَ وَكُنَّا لَهُمْ حَٰفِظِينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmdlxvi{وَأَيُّوبَ إِذْ نَادَىٰ رَبَّهُۥٓ أَنِّى مَسَّنِىَ ٱلضُّرُّ وَأَنتَ أَرْحَمُ ٱلرَّٰحِمِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmdlxvii{فَٱسْتَجَبْنَا لَهُۥ فَكَشَفْنَا مَا بِهِۦ مِن ضُرٍّ وَءَاتَيْنَٰهُ أَهْلَهُۥ وَمِثْلَهُم مَّعَهُمْ رَحْمَةً مِّنْ عِندِنَا وَذِكْرَىٰ لِلْعَٰبِدِينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmdlxviii{وَإِسْمَٰعِيلَ وَإِدْرِيسَ وَذَا ٱلْكِفْلِ كُلٌّ مِّنَ ٱلصَّٰبِرِينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmdlxix{وَأَدْخَلْنَٰهُمْ فِى رَحْمَتِنَآ إِنَّهُم مِّنَ ٱلصَّٰلِحِينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmdlxx{وَذَا ٱلنُّونِ إِذ ذَّهَبَ مُغَٰضِبًا فَظَنَّ أَن لَّن نَّقْدِرَ عَلَيْهِ فَنَادَىٰ فِى ٱلظُّلُمَٰتِ أَن لَّآ إِلَٰهَ إِلَّآ أَنتَ سُبْحَٰنَكَ إِنِّى كُنتُ مِنَ ٱلظَّٰلِمِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmdlxxi{فَٱسْتَجَبْنَا لَهُۥ وَنَجَّيْنَٰهُ مِنَ ٱلْغَمِّ وَكَذَٰلِكَ نُۨجِى ٱلْمُؤْمِنِينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmdlxxii{وَزَكَرِيَّآ إِذْ نَادَىٰ رَبَّهُۥ رَبِّ لَا تَذَرْنِى فَرْدًا وَأَنتَ خَيْرُ ٱلْوَٰرِثِينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmdlxxiii{فَٱسْتَجَبْنَا لَهُۥ وَوَهَبْنَا لَهُۥ يَحْيَىٰ وَأَصْلَحْنَا لَهُۥ زَوْجَهُۥٓ إِنَّهُمْ كَانُوا۟ يُسَٰرِعُونَ فِى ٱلْخَيْرَٰتِ وَيَدْعُونَنَا رَغَبًا وَرَهَبًا وَكَانُوا۟ لَنَا خَٰشِعِينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmdlxxiv{وَٱلَّتِىٓ أَحْصَنَتْ فَرْجَهَا فَنَفَخْنَا فِيهَا مِن رُّوحِنَا وَجَعَلْنَٰهَا وَٱبْنَهَآ ءَايَةً لِّلْعَٰلَمِينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmdlxxv{إِنَّ هَٰذِهِۦٓ أُمَّتُكُمْ أُمَّةً وَٰحِدَةً وَأَنَا۠ رَبُّكُمْ فَٱعْبُدُونِ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmdlxxvi{وَتَقَطَّعُوٓا۟ أَمْرَهُم بَيْنَهُمْ كُلٌّ إِلَيْنَا رَٰجِعُونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmdlxxvii{فَمَن يَعْمَلْ مِنَ ٱلصَّٰلِحَٰتِ وَهُوَ مُؤْمِنٌ فَلَا كُفْرَانَ لِسَعْيِهِۦ وَإِنَّا لَهُۥ كَٰتِبُونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmdlxxviii{وَحَرَٰمٌ عَلَىٰ قَرْيَةٍ أَهْلَكْنَٰهَآ أَنَّهُمْ لَا يَرْجِعُونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmdlxxix{حَتَّىٰٓ إِذَا فُتِحَتْ يَأْجُوجُ وَمَأْجُوجُ وَهُم مِّن كُلِّ حَدَبٍ يَنسِلُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmdlxxx{وَٱقْتَرَبَ ٱلْوَعْدُ ٱلْحَقُّ فَإِذَا هِىَ شَٰخِصَةٌ أَبْصَٰرُ ٱلَّذِينَ كَفَرُوا۟ يَٰوَيْلَنَا قَدْ كُنَّا فِى غَفْلَةٍ مِّنْ هَٰذَا بَلْ كُنَّا ظَٰلِمِينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmdlxxxi{إِنَّكُمْ وَمَا تَعْبُدُونَ مِن دُونِ ٱللَّهِ حَصَبُ جَهَنَّمَ أَنتُمْ لَهَا وَٰرِدُونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmdlxxxii{لَوْ كَانَ هَٰٓؤُلَآءِ ءَالِهَةً مَّا وَرَدُوهَا وَكُلٌّ فِيهَا خَٰلِدُونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmdlxxxiii{لَهُمْ فِيهَا زَفِيرٌ وَهُمْ فِيهَا لَا يَسْمَعُونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmdlxxxiv{إِنَّ ٱلَّذِينَ سَبَقَتْ لَهُم مِّنَّا ٱلْحُسْنَىٰٓ أُو۟لَٰٓئِكَ عَنْهَا مُبْعَدُونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmdlxxxv{لَا يَسْمَعُونَ حَسِيسَهَا وَهُمْ فِى مَا ٱشْتَهَتْ أَنفُسُهُمْ خَٰلِدُونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmdlxxxvi{لَا يَحْزُنُهُمُ ٱلْفَزَعُ ٱلْأَكْبَرُ وَتَتَلَقَّىٰهُمُ ٱلْمَلَٰٓئِكَةُ هَٰذَا يَوْمُكُمُ ٱلَّذِى كُنتُمْ تُوعَدُونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmdlxxxvii{يَوْمَ نَطْوِى ٱلسَّمَآءَ كَطَىِّ ٱلسِّجِلِّ لِلْكُتُبِ كَمَا بَدَأْنَآ أَوَّلَ خَلْقٍ نُّعِيدُهُۥ وَعْدًا عَلَيْنَآ إِنَّا كُنَّا فَٰعِلِينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmdlxxxviii{وَلَقَدْ كَتَبْنَا فِى ٱلزَّبُورِ مِنۢ بَعْدِ ٱلذِّكْرِ أَنَّ ٱلْأَرْضَ يَرِثُهَا عِبَادِىَ ٱلصَّٰلِحُونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmdlxxxix{إِنَّ فِى هَٰذَا لَبَلَٰغًا لِّقَوْمٍ عَٰبِدِينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmdxc{وَمَآ أَرْسَلْنَٰكَ إِلَّا رَحْمَةً لِّلْعَٰلَمِينَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmdxci{قُلْ إِنَّمَا يُوحَىٰٓ إِلَىَّ أَنَّمَآ إِلَٰهُكُمْ إِلَٰهٌ وَٰحِدٌ فَهَلْ أَنتُم مُّسْلِمُونَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmdxcii{فَإِن تَوَلَّوْا۟ فَقُلْ ءَاذَنتُكُمْ عَلَىٰ سَوَآءٍ وَإِنْ أَدْرِىٓ أَقَرِيبٌ أَم بَعِيدٌ مَّا تُوعَدُونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmdxciii{إِنَّهُۥ يَعْلَمُ ٱلْجَهْرَ مِنَ ٱلْقَوْلِ وَيَعْلَمُ مَا تَكْتُمُونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmdxciv{وَإِنْ أَدْرِى لَعَلَّهُۥ فِتْنَةٌ لَّكُمْ وَمَتَٰعٌ إِلَىٰ حِينٍ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmdxcv{قَٰلَ رَبِّ ٱحْكُم بِٱلْحَقِّ وَرَبُّنَا ٱلرَّحْمَٰنُ ٱلْمُسْتَعَانُ عَلَىٰ مَا تَصِفُونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmdxcvi{\basmalah يَٰٓأَيُّهَا ٱلنَّاسُ ٱتَّقُوا۟ رَبَّكُمْ إِنَّ زَلْزَلَةَ ٱلسَّاعَةِ شَىْءٌ عَظِيمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdxcvii{يَوْمَ تَرَوْنَهَا تَذْهَلُ كُلُّ مُرْضِعَةٍ عَمَّآ أَرْضَعَتْ وَتَضَعُ كُلُّ ذَاتِ حَمْلٍ حَمْلَهَا وَتَرَى ٱلنَّاسَ سُكَٰرَىٰ وَمَا هُم بِسُكَٰرَىٰ وَلَٰكِنَّ عَذَابَ ٱللَّهِ شَدِيدٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdxcviii{وَمِنَ ٱلنَّاسِ مَن يُجَٰدِلُ فِى ٱللَّهِ بِغَيْرِ عِلْمٍ وَيَتَّبِعُ كُلَّ شَيْطَٰنٍ مَّرِيدٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdxcix{كُتِبَ عَلَيْهِ أَنَّهُۥ مَن تَوَلَّاهُ فَأَنَّهُۥ يُضِلُّهُۥ وَيَهْدِيهِ إِلَىٰ عَذَابِ ٱلسَّعِيرِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdc{يَٰٓأَيُّهَا ٱلنَّاسُ إِن كُنتُمْ فِى رَيْبٍ مِّنَ ٱلْبَعْثِ فَإِنَّا خَلَقْنَٰكُم مِّن تُرَابٍ ثُمَّ مِن نُّطْفَةٍ ثُمَّ مِنْ عَلَقَةٍ ثُمَّ مِن مُّضْغَةٍ مُّخَلَّقَةٍ وَغَيْرِ مُخَلَّقَةٍ لِّنُبَيِّنَ لَكُمْ وَنُقِرُّ فِى ٱلْأَرْحَامِ مَا نَشَآءُ إِلَىٰٓ أَجَلٍ مُّسَمًّى ثُمَّ نُخْرِجُكُمْ طِفْلًا ثُمَّ لِتَبْلُغُوٓا۟ أَشُدَّكُمْ وَمِنكُم مَّن يُتَوَفَّىٰ وَمِنكُم مَّن يُرَدُّ إِلَىٰٓ أَرْذَلِ ٱلْعُمُرِ لِكَيْلَا يَعْلَمَ مِنۢ بَعْدِ عِلْمٍ شَيْـًٔا وَتَرَى ٱلْأَرْضَ هَامِدَةً فَإِذَآ أَنزَلْنَا عَلَيْهَا ٱلْمَآءَ ٱهْتَزَّتْ وَرَبَتْ وَأَنۢبَتَتْ مِن كُلِّ زَوْجٍۭ بَهِيجٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdci{ذَٰلِكَ بِأَنَّ ٱللَّهَ هُوَ ٱلْحَقُّ وَأَنَّهُۥ يُحْىِ ٱلْمَوْتَىٰ وَأَنَّهُۥ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdcii{وَأَنَّ ٱلسَّاعَةَ ءَاتِيَةٌ لَّا رَيْبَ فِيهَا وَأَنَّ ٱللَّهَ يَبْعَثُ مَن فِى ٱلْقُبُورِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdciii{وَمِنَ ٱلنَّاسِ مَن يُجَٰدِلُ فِى ٱللَّهِ بِغَيْرِ عِلْمٍ وَلَا هُدًى وَلَا كِتَٰبٍ مُّنِيرٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdciv{ثَانِىَ عِطْفِهِۦ لِيُضِلَّ عَن سَبِيلِ ٱللَّهِ لَهُۥ فِى ٱلدُّنْيَا خِزْىٌ وَنُذِيقُهُۥ يَوْمَ ٱلْقِيَٰمَةِ عَذَابَ ٱلْحَرِيقِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdcv{ذَٰلِكَ بِمَا قَدَّمَتْ يَدَاكَ وَأَنَّ ٱللَّهَ لَيْسَ بِظَلَّٰمٍ لِّلْعَبِيدِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdcvi{وَمِنَ ٱلنَّاسِ مَن يَعْبُدُ ٱللَّهَ عَلَىٰ حَرْفٍ فَإِنْ أَصَابَهُۥ خَيْرٌ ٱطْمَأَنَّ بِهِۦ وَإِنْ أَصَابَتْهُ فِتْنَةٌ ٱنقَلَبَ عَلَىٰ وَجْهِهِۦ خَسِرَ ٱلدُّنْيَا وَٱلْءَاخِرَةَ ذَٰلِكَ هُوَ ٱلْخُسْرَانُ ٱلْمُبِينُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdcvii{يَدْعُوا۟ مِن دُونِ ٱللَّهِ مَا لَا يَضُرُّهُۥ وَمَا لَا يَنفَعُهُۥ ذَٰلِكَ هُوَ ٱلضَّلَٰلُ ٱلْبَعِيدُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdcviii{يَدْعُوا۟ لَمَن ضَرُّهُۥٓ أَقْرَبُ مِن نَّفْعِهِۦ لَبِئْسَ ٱلْمَوْلَىٰ وَلَبِئْسَ ٱلْعَشِيرُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdcix{إِنَّ ٱللَّهَ يُدْخِلُ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ إِنَّ ٱللَّهَ يَفْعَلُ مَا يُرِيدُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdcx{مَن كَانَ يَظُنُّ أَن لَّن يَنصُرَهُ ٱللَّهُ فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ فَلْيَمْدُدْ بِسَبَبٍ إِلَى ٱلسَّمَآءِ ثُمَّ لْيَقْطَعْ فَلْيَنظُرْ هَلْ يُذْهِبَنَّ كَيْدُهُۥ مَا يَغِيظُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdcxi{وَكَذَٰلِكَ أَنزَلْنَٰهُ ءَايَٰتٍۭ بَيِّنَٰتٍ وَأَنَّ ٱللَّهَ يَهْدِى مَن يُرِيدُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdcxii{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَٱلَّذِينَ هَادُوا۟ وَٱلصَّٰبِـِٔينَ وَٱلنَّصَٰرَىٰ وَٱلْمَجُوسَ وَٱلَّذِينَ أَشْرَكُوٓا۟ إِنَّ ٱللَّهَ يَفْصِلُ بَيْنَهُمْ يَوْمَ ٱلْقِيَٰمَةِ إِنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ شَهِيدٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdcxiii{أَلَمْ تَرَ أَنَّ ٱللَّهَ يَسْجُدُ لَهُۥ مَن فِى ٱلسَّمَٰوَٰتِ وَمَن فِى ٱلْأَرْضِ وَٱلشَّمْسُ وَٱلْقَمَرُ وَٱلنُّجُومُ وَٱلْجِبَالُ وَٱلشَّجَرُ وَٱلدَّوَآبُّ وَكَثِيرٌ مِّنَ ٱلنَّاسِ وَكَثِيرٌ حَقَّ عَلَيْهِ ٱلْعَذَابُ وَمَن يُهِنِ ٱللَّهُ فَمَا لَهُۥ مِن مُّكْرِمٍ إِنَّ ٱللَّهَ يَفْعَلُ مَا يَشَآءُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdcxiv{هَٰذَانِ خَصْمَانِ ٱخْتَصَمُوا۟ فِى رَبِّهِمْ فَٱلَّذِينَ كَفَرُوا۟ قُطِّعَتْ لَهُمْ ثِيَابٌ مِّن نَّارٍ يُصَبُّ مِن فَوْقِ رُءُوسِهِمُ ٱلْحَمِيمُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdcxv{يُصْهَرُ بِهِۦ مَا فِى بُطُونِهِمْ وَٱلْجُلُودُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdcxvi{وَلَهُم مَّقَٰمِعُ مِنْ حَدِيدٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdcxvii{كُلَّمَآ أَرَادُوٓا۟ أَن يَخْرُجُوا۟ مِنْهَا مِنْ غَمٍّ أُعِيدُوا۟ فِيهَا وَذُوقُوا۟ عَذَابَ ٱلْحَرِيقِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdcxviii{إِنَّ ٱللَّهَ يُدْخِلُ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ يُحَلَّوْنَ فِيهَا مِنْ أَسَاوِرَ مِن ذَهَبٍ وَلُؤْلُؤًا وَلِبَاسُهُمْ فِيهَا حَرِيرٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdcxix{وَهُدُوٓا۟ إِلَى ٱلطَّيِّبِ مِنَ ٱلْقَوْلِ وَهُدُوٓا۟ إِلَىٰ صِرَٰطِ ٱلْحَمِيدِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdcxx{إِنَّ ٱلَّذِينَ كَفَرُوا۟ وَيَصُدُّونَ عَن سَبِيلِ ٱللَّهِ وَٱلْمَسْجِدِ ٱلْحَرَامِ ٱلَّذِى جَعَلْنَٰهُ لِلنَّاسِ سَوَآءً ٱلْعَٰكِفُ فِيهِ وَٱلْبَادِ وَمَن يُرِدْ فِيهِ بِإِلْحَادٍۭ بِظُلْمٍ نُّذِقْهُ مِنْ عَذَابٍ أَلِيمٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdcxxi{وَإِذْ بَوَّأْنَا لِإِبْرَٰهِيمَ مَكَانَ ٱلْبَيْتِ أَن لَّا تُشْرِكْ بِى شَيْـًٔا وَطَهِّرْ بَيْتِىَ لِلطَّآئِفِينَ وَٱلْقَآئِمِينَ وَٱلرُّكَّعِ ٱلسُّجُودِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdcxxii{وَأَذِّن فِى ٱلنَّاسِ بِٱلْحَجِّ يَأْتُوكَ رِجَالًا وَعَلَىٰ كُلِّ ضَامِرٍ يَأْتِينَ مِن كُلِّ فَجٍّ عَمِيقٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdcxxiii{لِّيَشْهَدُوا۟ مَنَٰفِعَ لَهُمْ وَيَذْكُرُوا۟ ٱسْمَ ٱللَّهِ فِىٓ أَيَّامٍ مَّعْلُومَٰتٍ عَلَىٰ مَا رَزَقَهُم مِّنۢ بَهِيمَةِ ٱلْأَنْعَٰمِ فَكُلُوا۟ مِنْهَا وَأَطْعِمُوا۟ ٱلْبَآئِسَ ٱلْفَقِيرَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdcxxiv{ثُمَّ لْيَقْضُوا۟ تَفَثَهُمْ وَلْيُوفُوا۟ نُذُورَهُمْ وَلْيَطَّوَّفُوا۟ بِٱلْبَيْتِ ٱلْعَتِيقِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdcxxv{ذَٰلِكَ وَمَن يُعَظِّمْ حُرُمَٰتِ ٱللَّهِ فَهُوَ خَيْرٌ لَّهُۥ عِندَ رَبِّهِۦ وَأُحِلَّتْ لَكُمُ ٱلْأَنْعَٰمُ إِلَّا مَا يُتْلَىٰ عَلَيْكُمْ فَٱجْتَنِبُوا۟ ٱلرِّجْسَ مِنَ ٱلْأَوْثَٰنِ وَٱجْتَنِبُوا۟ قَوْلَ ٱلزُّورِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdcxxvi{حُنَفَآءَ لِلَّهِ غَيْرَ مُشْرِكِينَ بِهِۦ وَمَن يُشْرِكْ بِٱللَّهِ فَكَأَنَّمَا خَرَّ مِنَ ٱلسَّمَآءِ فَتَخْطَفُهُ ٱلطَّيْرُ أَوْ تَهْوِى بِهِ ٱلرِّيحُ فِى مَكَانٍ سَحِيقٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdcxxvii{ذَٰلِكَ وَمَن يُعَظِّمْ شَعَٰٓئِرَ ٱللَّهِ فَإِنَّهَا مِن تَقْوَى ٱلْقُلُوبِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdcxxviii{لَكُمْ فِيهَا مَنَٰفِعُ إِلَىٰٓ أَجَلٍ مُّسَمًّى ثُمَّ مَحِلُّهَآ إِلَى ٱلْبَيْتِ ٱلْعَتِيقِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdcxxix{وَلِكُلِّ أُمَّةٍ جَعَلْنَا مَنسَكًا لِّيَذْكُرُوا۟ ٱسْمَ ٱللَّهِ عَلَىٰ مَا رَزَقَهُم مِّنۢ بَهِيمَةِ ٱلْأَنْعَٰمِ فَإِلَٰهُكُمْ إِلَٰهٌ وَٰحِدٌ فَلَهُۥٓ أَسْلِمُوا۟ وَبَشِّرِ ٱلْمُخْبِتِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdcxxx{ٱلَّذِينَ إِذَا ذُكِرَ ٱللَّهُ وَجِلَتْ قُلُوبُهُمْ وَٱلصَّٰبِرِينَ عَلَىٰ مَآ أَصَابَهُمْ وَٱلْمُقِيمِى ٱلصَّلَوٰةِ وَمِمَّا رَزَقْنَٰهُمْ يُنفِقُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdcxxxi{وَٱلْبُدْنَ جَعَلْنَٰهَا لَكُم مِّن شَعَٰٓئِرِ ٱللَّهِ لَكُمْ فِيهَا خَيْرٌ فَٱذْكُرُوا۟ ٱسْمَ ٱللَّهِ عَلَيْهَا صَوَآفَّ فَإِذَا وَجَبَتْ جُنُوبُهَا فَكُلُوا۟ مِنْهَا وَأَطْعِمُوا۟ ٱلْقَانِعَ وَٱلْمُعْتَرَّ كَذَٰلِكَ سَخَّرْنَٰهَا لَكُمْ لَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdcxxxii{لَن يَنَالَ ٱللَّهَ لُحُومُهَا وَلَا دِمَآؤُهَا وَلَٰكِن يَنَالُهُ ٱلتَّقْوَىٰ مِنكُمْ كَذَٰلِكَ سَخَّرَهَا لَكُمْ لِتُكَبِّرُوا۟ ٱللَّهَ عَلَىٰ مَا هَدَىٰكُمْ وَبَشِّرِ ٱلْمُحْسِنِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdcxxxiii{إِنَّ ٱللَّهَ يُدَٰفِعُ عَنِ ٱلَّذِينَ ءَامَنُوٓا۟ إِنَّ ٱللَّهَ لَا يُحِبُّ كُلَّ خَوَّانٍ كَفُورٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdcxxxiv{أُذِنَ لِلَّذِينَ يُقَٰتَلُونَ بِأَنَّهُمْ ظُلِمُوا۟ وَإِنَّ ٱللَّهَ عَلَىٰ نَصْرِهِمْ لَقَدِيرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdcxxxv{ٱلَّذِينَ أُخْرِجُوا۟ مِن دِيَٰرِهِم بِغَيْرِ حَقٍّ إِلَّآ أَن يَقُولُوا۟ رَبُّنَا ٱللَّهُ وَلَوْلَا دَفْعُ ٱللَّهِ ٱلنَّاسَ بَعْضَهُم بِبَعْضٍ لَّهُدِّمَتْ صَوَٰمِعُ وَبِيَعٌ وَصَلَوَٰتٌ وَمَسَٰجِدُ يُذْكَرُ فِيهَا ٱسْمُ ٱللَّهِ كَثِيرًا وَلَيَنصُرَنَّ ٱللَّهُ مَن يَنصُرُهُۥٓ إِنَّ ٱللَّهَ لَقَوِىٌّ عَزِيزٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdcxxxvi{ٱلَّذِينَ إِن مَّكَّنَّٰهُمْ فِى ٱلْأَرْضِ أَقَامُوا۟ ٱلصَّلَوٰةَ وَءَاتَوُا۟ ٱلزَّكَوٰةَ وَأَمَرُوا۟ بِٱلْمَعْرُوفِ وَنَهَوْا۟ عَنِ ٱلْمُنكَرِ وَلِلَّهِ عَٰقِبَةُ ٱلْأُمُورِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdcxxxvii{وَإِن يُكَذِّبُوكَ فَقَدْ كَذَّبَتْ قَبْلَهُمْ قَوْمُ نُوحٍ وَعَادٌ وَثَمُودُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdcxxxviii{وَقَوْمُ إِبْرَٰهِيمَ وَقَوْمُ لُوطٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdcxxxix{وَأَصْحَٰبُ مَدْيَنَ وَكُذِّبَ مُوسَىٰ فَأَمْلَيْتُ لِلْكَٰفِرِينَ ثُمَّ أَخَذْتُهُمْ فَكَيْفَ كَانَ نَكِيرِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdcxl{فَكَأَيِّن مِّن قَرْيَةٍ أَهْلَكْنَٰهَا وَهِىَ ظَالِمَةٌ فَهِىَ خَاوِيَةٌ عَلَىٰ عُرُوشِهَا وَبِئْرٍ مُّعَطَّلَةٍ وَقَصْرٍ مَّشِيدٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdcxli{أَفَلَمْ يَسِيرُوا۟ فِى ٱلْأَرْضِ فَتَكُونَ لَهُمْ قُلُوبٌ يَعْقِلُونَ بِهَآ أَوْ ءَاذَانٌ يَسْمَعُونَ بِهَا فَإِنَّهَا لَا تَعْمَى ٱلْأَبْصَٰرُ وَلَٰكِن تَعْمَى ٱلْقُلُوبُ ٱلَّتِى فِى ٱلصُّدُورِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdcxlii{وَيَسْتَعْجِلُونَكَ بِٱلْعَذَابِ وَلَن يُخْلِفَ ٱللَّهُ وَعْدَهُۥ وَإِنَّ يَوْمًا عِندَ رَبِّكَ كَأَلْفِ سَنَةٍ مِّمَّا تَعُدُّونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdcxliii{وَكَأَيِّن مِّن قَرْيَةٍ أَمْلَيْتُ لَهَا وَهِىَ ظَالِمَةٌ ثُمَّ أَخَذْتُهَا وَإِلَىَّ ٱلْمَصِيرُ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdcxliv{قُلْ يَٰٓأَيُّهَا ٱلنَّاسُ إِنَّمَآ أَنَا۠ لَكُمْ نَذِيرٌ مُّبِينٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdcxlv{فَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَهُم مَّغْفِرَةٌ وَرِزْقٌ كَرِيمٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdcxlvi{وَٱلَّذِينَ سَعَوْا۟ فِىٓ ءَايَٰتِنَا مُعَٰجِزِينَ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْجَحِيمِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdcxlvii{وَمَآ أَرْسَلْنَا مِن قَبْلِكَ مِن رَّسُولٍ وَلَا نَبِىٍّ إِلَّآ إِذَا تَمَنَّىٰٓ أَلْقَى ٱلشَّيْطَٰنُ فِىٓ أُمْنِيَّتِهِۦ فَيَنسَخُ ٱللَّهُ مَا يُلْقِى ٱلشَّيْطَٰنُ ثُمَّ يُحْكِمُ ٱللَّهُ ءَايَٰتِهِۦ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdcxlviii{لِّيَجْعَلَ مَا يُلْقِى ٱلشَّيْطَٰنُ فِتْنَةً لِّلَّذِينَ فِى قُلُوبِهِم مَّرَضٌ وَٱلْقَاسِيَةِ قُلُوبُهُمْ وَإِنَّ ٱلظَّٰلِمِينَ لَفِى شِقَاقٍۭ بَعِيدٍ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdcxlix{وَلِيَعْلَمَ ٱلَّذِينَ أُوتُوا۟ ٱلْعِلْمَ أَنَّهُ ٱلْحَقُّ مِن رَّبِّكَ فَيُؤْمِنُوا۟ بِهِۦ فَتُخْبِتَ لَهُۥ قُلُوبُهُمْ وَإِنَّ ٱللَّهَ لَهَادِ ٱلَّذِينَ ءَامَنُوٓا۟ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdcl{وَلَا يَزَالُ ٱلَّذِينَ كَفَرُوا۟ فِى مِرْيَةٍ مِّنْهُ حَتَّىٰ تَأْتِيَهُمُ ٱلسَّاعَةُ بَغْتَةً أَوْ يَأْتِيَهُمْ عَذَابُ يَوْمٍ عَقِيمٍ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdcli{ٱلْمُلْكُ يَوْمَئِذٍ لِّلَّهِ يَحْكُمُ بَيْنَهُمْ فَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ فِى جَنَّٰتِ ٱلنَّعِيمِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdclii{وَٱلَّذِينَ كَفَرُوا۟ وَكَذَّبُوا۟ بِـَٔايَٰتِنَا فَأُو۟لَٰٓئِكَ لَهُمْ عَذَابٌ مُّهِينٌ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdcliii{وَٱلَّذِينَ هَاجَرُوا۟ فِى سَبِيلِ ٱللَّهِ ثُمَّ قُتِلُوٓا۟ أَوْ مَاتُوا۟ لَيَرْزُقَنَّهُمُ ٱللَّهُ رِزْقًا حَسَنًا وَإِنَّ ٱللَّهَ لَهُوَ خَيْرُ ٱلرَّٰزِقِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdcliv{لَيُدْخِلَنَّهُم مُّدْخَلًا يَرْضَوْنَهُۥ وَإِنَّ ٱللَّهَ لَعَلِيمٌ حَلِيمٌ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdclv{ذَٰلِكَ وَمَنْ عَاقَبَ بِمِثْلِ مَا عُوقِبَ بِهِۦ ثُمَّ بُغِىَ عَلَيْهِ لَيَنصُرَنَّهُ ٱللَّهُ إِنَّ ٱللَّهَ لَعَفُوٌّ غَفُورٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdclvi{ذَٰلِكَ بِأَنَّ ٱللَّهَ يُولِجُ ٱلَّيْلَ فِى ٱلنَّهَارِ وَيُولِجُ ٱلنَّهَارَ فِى ٱلَّيْلِ وَأَنَّ ٱللَّهَ سَمِيعٌۢ بَصِيرٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdclvii{ذَٰلِكَ بِأَنَّ ٱللَّهَ هُوَ ٱلْحَقُّ وَأَنَّ مَا يَدْعُونَ مِن دُونِهِۦ هُوَ ٱلْبَٰطِلُ وَأَنَّ ٱللَّهَ هُوَ ٱلْعَلِىُّ ٱلْكَبِيرُ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdclviii{أَلَمْ تَرَ أَنَّ ٱللَّهَ أَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً فَتُصْبِحُ ٱلْأَرْضُ مُخْضَرَّةً إِنَّ ٱللَّهَ لَطِيفٌ خَبِيرٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdclix{لَّهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَإِنَّ ٱللَّهَ لَهُوَ ٱلْغَنِىُّ ٱلْحَمِيدُ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdclx{أَلَمْ تَرَ أَنَّ ٱللَّهَ سَخَّرَ لَكُم مَّا فِى ٱلْأَرْضِ وَٱلْفُلْكَ تَجْرِى فِى ٱلْبَحْرِ بِأَمْرِهِۦ وَيُمْسِكُ ٱلسَّمَآءَ أَن تَقَعَ عَلَى ٱلْأَرْضِ إِلَّا بِإِذْنِهِۦٓ إِنَّ ٱللَّهَ بِٱلنَّاسِ لَرَءُوفٌ رَّحِيمٌ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmdclxi{وَهُوَ ٱلَّذِىٓ أَحْيَاكُمْ ثُمَّ يُمِيتُكُمْ ثُمَّ يُحْيِيكُمْ إِنَّ ٱلْإِنسَٰنَ لَكَفُورٌ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmdclxii{لِّكُلِّ أُمَّةٍ جَعَلْنَا مَنسَكًا هُمْ نَاسِكُوهُ فَلَا يُنَٰزِعُنَّكَ فِى ٱلْأَمْرِ وَٱدْعُ إِلَىٰ رَبِّكَ إِنَّكَ لَعَلَىٰ هُدًى مُّسْتَقِيمٍ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmdclxiii{وَإِن جَٰدَلُوكَ فَقُلِ ٱللَّهُ أَعْلَمُ بِمَا تَعْمَلُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmdclxiv{ٱللَّهُ يَحْكُمُ بَيْنَكُمْ يَوْمَ ٱلْقِيَٰمَةِ فِيمَا كُنتُمْ فِيهِ تَخْتَلِفُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmdclxv{أَلَمْ تَعْلَمْ أَنَّ ٱللَّهَ يَعْلَمُ مَا فِى ٱلسَّمَآءِ وَٱلْأَرْضِ إِنَّ ذَٰلِكَ فِى كِتَٰبٍ إِنَّ ذَٰلِكَ عَلَى ٱللَّهِ يَسِيرٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmdclxvi{وَيَعْبُدُونَ مِن دُونِ ٱللَّهِ مَا لَمْ يُنَزِّلْ بِهِۦ سُلْطَٰنًا وَمَا لَيْسَ لَهُم بِهِۦ عِلْمٌ وَمَا لِلظَّٰلِمِينَ مِن نَّصِيرٍ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmdclxvii{وَإِذَا تُتْلَىٰ عَلَيْهِمْ ءَايَٰتُنَا بَيِّنَٰتٍ تَعْرِفُ فِى وُجُوهِ ٱلَّذِينَ كَفَرُوا۟ ٱلْمُنكَرَ يَكَادُونَ يَسْطُونَ بِٱلَّذِينَ يَتْلُونَ عَلَيْهِمْ ءَايَٰتِنَا قُلْ أَفَأُنَبِّئُكُم بِشَرٍّ مِّن ذَٰلِكُمُ ٱلنَّارُ وَعَدَهَا ٱللَّهُ ٱلَّذِينَ كَفَرُوا۟ وَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmdclxviii{يَٰٓأَيُّهَا ٱلنَّاسُ ضُرِبَ مَثَلٌ فَٱسْتَمِعُوا۟ لَهُۥٓ إِنَّ ٱلَّذِينَ تَدْعُونَ مِن دُونِ ٱللَّهِ لَن يَخْلُقُوا۟ ذُبَابًا وَلَوِ ٱجْتَمَعُوا۟ لَهُۥ وَإِن يَسْلُبْهُمُ ٱلذُّبَابُ شَيْـًٔا لَّا يَسْتَنقِذُوهُ مِنْهُ ضَعُفَ ٱلطَّالِبُ وَٱلْمَطْلُوبُ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmdclxix{مَا قَدَرُوا۟ ٱللَّهَ حَقَّ قَدْرِهِۦٓ إِنَّ ٱللَّهَ لَقَوِىٌّ عَزِيزٌ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmdclxx{ٱللَّهُ يَصْطَفِى مِنَ ٱلْمَلَٰٓئِكَةِ رُسُلًا وَمِنَ ٱلنَّاسِ إِنَّ ٱللَّهَ سَمِيعٌۢ بَصِيرٌ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmdclxxi{يَعْلَمُ مَا بَيْنَ أَيْدِيهِمْ وَمَا خَلْفَهُمْ وَإِلَى ٱللَّهِ تُرْجَعُ ٱلْأُمُورُ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmdclxxii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱرْكَعُوا۟ وَٱسْجُدُوا۟ وَٱعْبُدُوا۟ رَبَّكُمْ وَٱفْعَلُوا۟ ٱلْخَيْرَ لَعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmdclxxiii{وَجَٰهِدُوا۟ فِى ٱللَّهِ حَقَّ جِهَادِهِۦ هُوَ ٱجْتَبَىٰكُمْ وَمَا جَعَلَ عَلَيْكُمْ فِى ٱلدِّينِ مِنْ حَرَجٍ مِّلَّةَ أَبِيكُمْ إِبْرَٰهِيمَ هُوَ سَمَّىٰكُمُ ٱلْمُسْلِمِينَ مِن قَبْلُ وَفِى هَٰذَا لِيَكُونَ ٱلرَّسُولُ شَهِيدًا عَلَيْكُمْ وَتَكُونُوا۟ شُهَدَآءَ عَلَى ٱلنَّاسِ فَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَءَاتُوا۟ ٱلزَّكَوٰةَ وَٱعْتَصِمُوا۟ بِٱللَّهِ هُوَ مَوْلَىٰكُمْ فَنِعْمَ ٱلْمَوْلَىٰ وَنِعْمَ ٱلنَّصِيرُ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmdclxxiv{\basmalah قَدْ أَفْلَحَ ٱلْمُؤْمِنُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdclxxv{ٱلَّذِينَ هُمْ فِى صَلَاتِهِمْ خَٰشِعُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdclxxvi{وَٱلَّذِينَ هُمْ عَنِ ٱللَّغْوِ مُعْرِضُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdclxxvii{وَٱلَّذِينَ هُمْ لِلزَّكَوٰةِ فَٰعِلُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdclxxviii{وَٱلَّذِينَ هُمْ لِفُرُوجِهِمْ حَٰفِظُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdclxxix{إِلَّا عَلَىٰٓ أَزْوَٰجِهِمْ أَوْ مَا مَلَكَتْ أَيْمَٰنُهُمْ فَإِنَّهُمْ غَيْرُ مَلُومِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdclxxx{فَمَنِ ٱبْتَغَىٰ وَرَآءَ ذَٰلِكَ فَأُو۟لَٰٓئِكَ هُمُ ٱلْعَادُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdclxxxi{وَٱلَّذِينَ هُمْ لِأَمَٰنَٰتِهِمْ وَعَهْدِهِمْ رَٰعُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdclxxxii{وَٱلَّذِينَ هُمْ عَلَىٰ صَلَوَٰتِهِمْ يُحَافِظُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdclxxxiii{أُو۟لَٰٓئِكَ هُمُ ٱلْوَٰرِثُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdclxxxiv{ٱلَّذِينَ يَرِثُونَ ٱلْفِرْدَوْسَ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdclxxxv{وَلَقَدْ خَلَقْنَا ٱلْإِنسَٰنَ مِن سُلَٰلَةٍ مِّن طِينٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdclxxxvi{ثُمَّ جَعَلْنَٰهُ نُطْفَةً فِى قَرَارٍ مَّكِينٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdclxxxvii{ثُمَّ خَلَقْنَا ٱلنُّطْفَةَ عَلَقَةً فَخَلَقْنَا ٱلْعَلَقَةَ مُضْغَةً فَخَلَقْنَا ٱلْمُضْغَةَ عِظَٰمًا فَكَسَوْنَا ٱلْعِظَٰمَ لَحْمًا ثُمَّ أَنشَأْنَٰهُ خَلْقًا ءَاخَرَ فَتَبَارَكَ ٱللَّهُ أَحْسَنُ ٱلْخَٰلِقِينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdclxxxviii{ثُمَّ إِنَّكُم بَعْدَ ذَٰلِكَ لَمَيِّتُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdclxxxix{ثُمَّ إِنَّكُمْ يَوْمَ ٱلْقِيَٰمَةِ تُبْعَثُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdcxc{وَلَقَدْ خَلَقْنَا فَوْقَكُمْ سَبْعَ طَرَآئِقَ وَمَا كُنَّا عَنِ ٱلْخَلْقِ غَٰفِلِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdcxci{وَأَنزَلْنَا مِنَ ٱلسَّمَآءِ مَآءًۢ بِقَدَرٍ فَأَسْكَنَّٰهُ فِى ٱلْأَرْضِ وَإِنَّا عَلَىٰ ذَهَابٍۭ بِهِۦ لَقَٰدِرُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdcxcii{فَأَنشَأْنَا لَكُم بِهِۦ جَنَّٰتٍ مِّن نَّخِيلٍ وَأَعْنَٰبٍ لَّكُمْ فِيهَا فَوَٰكِهُ كَثِيرَةٌ وَمِنْهَا تَأْكُلُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdcxciii{وَشَجَرَةً تَخْرُجُ مِن طُورِ سَيْنَآءَ تَنۢبُتُ بِٱلدُّهْنِ وَصِبْغٍ لِّلْءَاكِلِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdcxciv{وَإِنَّ لَكُمْ فِى ٱلْأَنْعَٰمِ لَعِبْرَةً نُّسْقِيكُم مِّمَّا فِى بُطُونِهَا وَلَكُمْ فِيهَا مَنَٰفِعُ كَثِيرَةٌ وَمِنْهَا تَأْكُلُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdcxcv{وَعَلَيْهَا وَعَلَى ٱلْفُلْكِ تُحْمَلُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdcxcvi{وَلَقَدْ أَرْسَلْنَا نُوحًا إِلَىٰ قَوْمِهِۦ فَقَالَ يَٰقَوْمِ ٱعْبُدُوا۟ ٱللَّهَ مَا لَكُم مِّنْ إِلَٰهٍ غَيْرُهُۥٓ أَفَلَا تَتَّقُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdcxcvii{فَقَالَ ٱلْمَلَؤُا۟ ٱلَّذِينَ كَفَرُوا۟ مِن قَوْمِهِۦ مَا هَٰذَآ إِلَّا بَشَرٌ مِّثْلُكُمْ يُرِيدُ أَن يَتَفَضَّلَ عَلَيْكُمْ وَلَوْ شَآءَ ٱللَّهُ لَأَنزَلَ مَلَٰٓئِكَةً مَّا سَمِعْنَا بِهَٰذَا فِىٓ ءَابَآئِنَا ٱلْأَوَّلِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdcxcviii{إِنْ هُوَ إِلَّا رَجُلٌۢ بِهِۦ جِنَّةٌ فَتَرَبَّصُوا۟ بِهِۦ حَتَّىٰ حِينٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdcxcix{قَالَ رَبِّ ٱنصُرْنِى بِمَا كَذَّبُونِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdcc{فَأَوْحَيْنَآ إِلَيْهِ أَنِ ٱصْنَعِ ٱلْفُلْكَ بِأَعْيُنِنَا وَوَحْيِنَا فَإِذَا جَآءَ أَمْرُنَا وَفَارَ ٱلتَّنُّورُ فَٱسْلُكْ فِيهَا مِن كُلٍّ زَوْجَيْنِ ٱثْنَيْنِ وَأَهْلَكَ إِلَّا مَن سَبَقَ عَلَيْهِ ٱلْقَوْلُ مِنْهُمْ وَلَا تُخَٰطِبْنِى فِى ٱلَّذِينَ ظَلَمُوٓا۟ إِنَّهُم مُّغْرَقُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdcci{فَإِذَا ٱسْتَوَيْتَ أَنتَ وَمَن مَّعَكَ عَلَى ٱلْفُلْكِ فَقُلِ ٱلْحَمْدُ لِلَّهِ ٱلَّذِى نَجَّىٰنَا مِنَ ٱلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdccii{وَقُل رَّبِّ أَنزِلْنِى مُنزَلًا مُّبَارَكًا وَأَنتَ خَيْرُ ٱلْمُنزِلِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdcciii{إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ وَإِن كُنَّا لَمُبْتَلِينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdcciv{ثُمَّ أَنشَأْنَا مِنۢ بَعْدِهِمْ قَرْنًا ءَاخَرِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdccv{فَأَرْسَلْنَا فِيهِمْ رَسُولًا مِّنْهُمْ أَنِ ٱعْبُدُوا۟ ٱللَّهَ مَا لَكُم مِّنْ إِلَٰهٍ غَيْرُهُۥٓ أَفَلَا تَتَّقُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdccvi{وَقَالَ ٱلْمَلَأُ مِن قَوْمِهِ ٱلَّذِينَ كَفَرُوا۟ وَكَذَّبُوا۟ بِلِقَآءِ ٱلْءَاخِرَةِ وَأَتْرَفْنَٰهُمْ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا مَا هَٰذَآ إِلَّا بَشَرٌ مِّثْلُكُمْ يَأْكُلُ مِمَّا تَأْكُلُونَ مِنْهُ وَيَشْرَبُ مِمَّا تَشْرَبُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdccvii{وَلَئِنْ أَطَعْتُم بَشَرًا مِّثْلَكُمْ إِنَّكُمْ إِذًا لَّخَٰسِرُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdccviii{أَيَعِدُكُمْ أَنَّكُمْ إِذَا مِتُّمْ وَكُنتُمْ تُرَابًا وَعِظَٰمًا أَنَّكُم مُّخْرَجُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdccix{هَيْهَاتَ هَيْهَاتَ لِمَا تُوعَدُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdccx{إِنْ هِىَ إِلَّا حَيَاتُنَا ٱلدُّنْيَا نَمُوتُ وَنَحْيَا وَمَا نَحْنُ بِمَبْعُوثِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdccxi{إِنْ هُوَ إِلَّا رَجُلٌ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا وَمَا نَحْنُ لَهُۥ بِمُؤْمِنِينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdccxii{قَالَ رَبِّ ٱنصُرْنِى بِمَا كَذَّبُونِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdccxiii{قَالَ عَمَّا قَلِيلٍ لَّيُصْبِحُنَّ نَٰدِمِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdccxiv{فَأَخَذَتْهُمُ ٱلصَّيْحَةُ بِٱلْحَقِّ فَجَعَلْنَٰهُمْ غُثَآءً فَبُعْدًا لِّلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdccxv{ثُمَّ أَنشَأْنَا مِنۢ بَعْدِهِمْ قُرُونًا ءَاخَرِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdccxvi{مَا تَسْبِقُ مِنْ أُمَّةٍ أَجَلَهَا وَمَا يَسْتَـْٔخِرُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdccxvii{ثُمَّ أَرْسَلْنَا رُسُلَنَا تَتْرَا كُلَّ مَا جَآءَ أُمَّةً رَّسُولُهَا كَذَّبُوهُ فَأَتْبَعْنَا بَعْضَهُم بَعْضًا وَجَعَلْنَٰهُمْ أَحَادِيثَ فَبُعْدًا لِّقَوْمٍ لَّا يُؤْمِنُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdccxviii{ثُمَّ أَرْسَلْنَا مُوسَىٰ وَأَخَاهُ هَٰرُونَ بِـَٔايَٰتِنَا وَسُلْطَٰنٍ مُّبِينٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdccxix{إِلَىٰ فِرْعَوْنَ وَمَلَإِي۟هِۦ فَٱسْتَكْبَرُوا۟ وَكَانُوا۟ قَوْمًا عَالِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdccxx{فَقَالُوٓا۟ أَنُؤْمِنُ لِبَشَرَيْنِ مِثْلِنَا وَقَوْمُهُمَا لَنَا عَٰبِدُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdccxxi{فَكَذَّبُوهُمَا فَكَانُوا۟ مِنَ ٱلْمُهْلَكِينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdccxxii{وَلَقَدْ ءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ لَعَلَّهُمْ يَهْتَدُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdccxxiii{وَجَعَلْنَا ٱبْنَ مَرْيَمَ وَأُمَّهُۥٓ ءَايَةً وَءَاوَيْنَٰهُمَآ إِلَىٰ رَبْوَةٍ ذَاتِ قَرَارٍ وَمَعِينٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdccxxiv{يَٰٓأَيُّهَا ٱلرُّسُلُ كُلُوا۟ مِنَ ٱلطَّيِّبَٰتِ وَٱعْمَلُوا۟ صَٰلِحًا إِنِّى بِمَا تَعْمَلُونَ عَلِيمٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdccxxv{وَإِنَّ هَٰذِهِۦٓ أُمَّتُكُمْ أُمَّةً وَٰحِدَةً وَأَنَا۠ رَبُّكُمْ فَٱتَّقُونِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdccxxvi{فَتَقَطَّعُوٓا۟ أَمْرَهُم بَيْنَهُمْ زُبُرًا كُلُّ حِزْبٍۭ بِمَا لَدَيْهِمْ فَرِحُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdccxxvii{فَذَرْهُمْ فِى غَمْرَتِهِمْ حَتَّىٰ حِينٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdccxxviii{أَيَحْسَبُونَ أَنَّمَا نُمِدُّهُم بِهِۦ مِن مَّالٍ وَبَنِينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdccxxix{نُسَارِعُ لَهُمْ فِى ٱلْخَيْرَٰتِ بَل لَّا يَشْعُرُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdccxxx{إِنَّ ٱلَّذِينَ هُم مِّنْ خَشْيَةِ رَبِّهِم مُّشْفِقُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdccxxxi{وَٱلَّذِينَ هُم بِـَٔايَٰتِ رَبِّهِمْ يُؤْمِنُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdccxxxii{وَٱلَّذِينَ هُم بِرَبِّهِمْ لَا يُشْرِكُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdccxxxiii{وَٱلَّذِينَ يُؤْتُونَ مَآ ءَاتَوا۟ وَّقُلُوبُهُمْ وَجِلَةٌ أَنَّهُمْ إِلَىٰ رَبِّهِمْ رَٰجِعُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdccxxxiv{أُو۟لَٰٓئِكَ يُسَٰرِعُونَ فِى ٱلْخَيْرَٰتِ وَهُمْ لَهَا سَٰبِقُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdccxxxv{وَلَا نُكَلِّفُ نَفْسًا إِلَّا وُسْعَهَا وَلَدَيْنَا كِتَٰبٌ يَنطِقُ بِٱلْحَقِّ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdccxxxvi{بَلْ قُلُوبُهُمْ فِى غَمْرَةٍ مِّنْ هَٰذَا وَلَهُمْ أَعْمَٰلٌ مِّن دُونِ ذَٰلِكَ هُمْ لَهَا عَٰمِلُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdccxxxvii{حَتَّىٰٓ إِذَآ أَخَذْنَا مُتْرَفِيهِم بِٱلْعَذَابِ إِذَا هُمْ يَجْـَٔرُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdccxxxviii{لَا تَجْـَٔرُوا۟ ٱلْيَوْمَ إِنَّكُم مِّنَّا لَا تُنصَرُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmdccxxxix{قَدْ كَانَتْ ءَايَٰتِى تُتْلَىٰ عَلَيْكُمْ فَكُنتُمْ عَلَىٰٓ أَعْقَٰبِكُمْ تَنكِصُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmdccxl{مُسْتَكْبِرِينَ بِهِۦ سَٰمِرًا تَهْجُرُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmdccxli{أَفَلَمْ يَدَّبَّرُوا۟ ٱلْقَوْلَ أَمْ جَآءَهُم مَّا لَمْ يَأْتِ ءَابَآءَهُمُ ٱلْأَوَّلِينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmdccxlii{أَمْ لَمْ يَعْرِفُوا۟ رَسُولَهُمْ فَهُمْ لَهُۥ مُنكِرُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmdccxliii{أَمْ يَقُولُونَ بِهِۦ جِنَّةٌۢ بَلْ جَآءَهُم بِٱلْحَقِّ وَأَكْثَرُهُمْ لِلْحَقِّ كَٰرِهُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmdccxliv{وَلَوِ ٱتَّبَعَ ٱلْحَقُّ أَهْوَآءَهُمْ لَفَسَدَتِ ٱلسَّمَٰوَٰتُ وَٱلْأَرْضُ وَمَن فِيهِنَّ بَلْ أَتَيْنَٰهُم بِذِكْرِهِمْ فَهُمْ عَن ذِكْرِهِم مُّعْرِضُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmdccxlv{أَمْ تَسْـَٔلُهُمْ خَرْجًا فَخَرَاجُ رَبِّكَ خَيْرٌ وَهُوَ خَيْرُ ٱلرَّٰزِقِينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmdccxlvi{وَإِنَّكَ لَتَدْعُوهُمْ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmdccxlvii{وَإِنَّ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ عَنِ ٱلصِّرَٰطِ لَنَٰكِبُونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmdccxlviii{وَلَوْ رَحِمْنَٰهُمْ وَكَشَفْنَا مَا بِهِم مِّن ضُرٍّ لَّلَجُّوا۟ فِى طُغْيَٰنِهِمْ يَعْمَهُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmdccxlix{وَلَقَدْ أَخَذْنَٰهُم بِٱلْعَذَابِ فَمَا ٱسْتَكَانُوا۟ لِرَبِّهِمْ وَمَا يَتَضَرَّعُونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmdccl{حَتَّىٰٓ إِذَا فَتَحْنَا عَلَيْهِم بَابًا ذَا عَذَابٍ شَدِيدٍ إِذَا هُمْ فِيهِ مُبْلِسُونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmdccli{وَهُوَ ٱلَّذِىٓ أَنشَأَ لَكُمُ ٱلسَّمْعَ وَٱلْأَبْصَٰرَ وَٱلْأَفْـِٔدَةَ قَلِيلًا مَّا تَشْكُرُونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmdcclii{وَهُوَ ٱلَّذِى ذَرَأَكُمْ فِى ٱلْأَرْضِ وَإِلَيْهِ تُحْشَرُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmdccliii{وَهُوَ ٱلَّذِى يُحْىِۦ وَيُمِيتُ وَلَهُ ٱخْتِلَٰفُ ٱلَّيْلِ وَٱلنَّهَارِ أَفَلَا تَعْقِلُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmdccliv{بَلْ قَالُوا۟ مِثْلَ مَا قَالَ ٱلْأَوَّلُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmdcclv{قَالُوٓا۟ أَءِذَا مِتْنَا وَكُنَّا تُرَابًا وَعِظَٰمًا أَءِنَّا لَمَبْعُوثُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmdcclvi{لَقَدْ وُعِدْنَا نَحْنُ وَءَابَآؤُنَا هَٰذَا مِن قَبْلُ إِنْ هَٰذَآ إِلَّآ أَسَٰطِيرُ ٱلْأَوَّلِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmdcclvii{قُل لِّمَنِ ٱلْأَرْضُ وَمَن فِيهَآ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmdcclviii{سَيَقُولُونَ لِلَّهِ قُلْ أَفَلَا تَذَكَّرُونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmdcclix{قُلْ مَن رَّبُّ ٱلسَّمَٰوَٰتِ ٱلسَّبْعِ وَرَبُّ ٱلْعَرْشِ ٱلْعَظِيمِ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmdcclx{سَيَقُولُونَ لِلَّهِ قُلْ أَفَلَا تَتَّقُونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmdcclxi{قُلْ مَنۢ بِيَدِهِۦ مَلَكُوتُ كُلِّ شَىْءٍ وَهُوَ يُجِيرُ وَلَا يُجَارُ عَلَيْهِ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmdcclxii{سَيَقُولُونَ لِلَّهِ قُلْ فَأَنَّىٰ تُسْحَرُونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmdcclxiii{بَلْ أَتَيْنَٰهُم بِٱلْحَقِّ وَإِنَّهُمْ لَكَٰذِبُونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmdcclxiv{مَا ٱتَّخَذَ ٱللَّهُ مِن وَلَدٍ وَمَا كَانَ مَعَهُۥ مِنْ إِلَٰهٍ إِذًا لَّذَهَبَ كُلُّ إِلَٰهٍۭ بِمَا خَلَقَ وَلَعَلَا بَعْضُهُمْ عَلَىٰ بَعْضٍ سُبْحَٰنَ ٱللَّهِ عَمَّا يَصِفُونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmdcclxv{عَٰلِمِ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ فَتَعَٰلَىٰ عَمَّا يُشْرِكُونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmdcclxvi{قُل رَّبِّ إِمَّا تُرِيَنِّى مَا يُوعَدُونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmdcclxvii{رَبِّ فَلَا تَجْعَلْنِى فِى ٱلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmdcclxviii{وَإِنَّا عَلَىٰٓ أَن نُّرِيَكَ مَا نَعِدُهُمْ لَقَٰدِرُونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmdcclxix{ٱدْفَعْ بِٱلَّتِى هِىَ أَحْسَنُ ٱلسَّيِّئَةَ نَحْنُ أَعْلَمُ بِمَا يَصِفُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmdcclxx{وَقُل رَّبِّ أَعُوذُ بِكَ مِنْ هَمَزَٰتِ ٱلشَّيَٰطِينِ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmdcclxxi{وَأَعُوذُ بِكَ رَبِّ أَن يَحْضُرُونِ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmdcclxxii{حَتَّىٰٓ إِذَا جَآءَ أَحَدَهُمُ ٱلْمَوْتُ قَالَ رَبِّ ٱرْجِعُونِ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmdcclxxiii{لَعَلِّىٓ أَعْمَلُ صَٰلِحًا فِيمَا تَرَكْتُ كَلَّآ إِنَّهَا كَلِمَةٌ هُوَ قَآئِلُهَا وَمِن وَرَآئِهِم بَرْزَخٌ إِلَىٰ يَوْمِ يُبْعَثُونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmdcclxxiv{فَإِذَا نُفِخَ فِى ٱلصُّورِ فَلَآ أَنسَابَ بَيْنَهُمْ يَوْمَئِذٍ وَلَا يَتَسَآءَلُونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmdcclxxv{فَمَن ثَقُلَتْ مَوَٰزِينُهُۥ فَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmdcclxxvi{وَمَنْ خَفَّتْ مَوَٰزِينُهُۥ فَأُو۟لَٰٓئِكَ ٱلَّذِينَ خَسِرُوٓا۟ أَنفُسَهُمْ فِى جَهَنَّمَ خَٰلِدُونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmdcclxxvii{تَلْفَحُ وُجُوهَهُمُ ٱلنَّارُ وَهُمْ فِيهَا كَٰلِحُونَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmdcclxxviii{أَلَمْ تَكُنْ ءَايَٰتِى تُتْلَىٰ عَلَيْكُمْ فَكُنتُم بِهَا تُكَذِّبُونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmdcclxxix{قَالُوا۟ رَبَّنَا غَلَبَتْ عَلَيْنَا شِقْوَتُنَا وَكُنَّا قَوْمًا ضَآلِّينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmdcclxxx{رَبَّنَآ أَخْرِجْنَا مِنْهَا فَإِنْ عُدْنَا فَإِنَّا ظَٰلِمُونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmdcclxxxi{قَالَ ٱخْسَـُٔوا۟ فِيهَا وَلَا تُكَلِّمُونِ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmdcclxxxii{إِنَّهُۥ كَانَ فَرِيقٌ مِّنْ عِبَادِى يَقُولُونَ رَبَّنَآ ءَامَنَّا فَٱغْفِرْ لَنَا وَٱرْحَمْنَا وَأَنتَ خَيْرُ ٱلرَّٰحِمِينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmdcclxxxiii{فَٱتَّخَذْتُمُوهُمْ سِخْرِيًّا حَتَّىٰٓ أَنسَوْكُمْ ذِكْرِى وَكُنتُم مِّنْهُمْ تَضْحَكُونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmdcclxxxiv{إِنِّى جَزَيْتُهُمُ ٱلْيَوْمَ بِمَا صَبَرُوٓا۟ أَنَّهُمْ هُمُ ٱلْفَآئِزُونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmdcclxxxv{قَٰلَ كَمْ لَبِثْتُمْ فِى ٱلْأَرْضِ عَدَدَ سِنِينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmdcclxxxvi{قَالُوا۟ لَبِثْنَا يَوْمًا أَوْ بَعْضَ يَوْمٍ فَسْـَٔلِ ٱلْعَآدِّينَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmdcclxxxvii{قَٰلَ إِن لَّبِثْتُمْ إِلَّا قَلِيلًا لَّوْ أَنَّكُمْ كُنتُمْ تَعْلَمُونَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmdcclxxxviii{أَفَحَسِبْتُمْ أَنَّمَا خَلَقْنَٰكُمْ عَبَثًا وَأَنَّكُمْ إِلَيْنَا لَا تُرْجَعُونَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmdcclxxxix{فَتَعَٰلَى ٱللَّهُ ٱلْمَلِكُ ٱلْحَقُّ لَآ إِلَٰهَ إِلَّا هُوَ رَبُّ ٱلْعَرْشِ ٱلْكَرِيمِ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmdccxc{وَمَن يَدْعُ مَعَ ٱللَّهِ إِلَٰهًا ءَاخَرَ لَا بُرْهَٰنَ لَهُۥ بِهِۦ فَإِنَّمَا حِسَابُهُۥ عِندَ رَبِّهِۦٓ إِنَّهُۥ لَا يُفْلِحُ ٱلْكَٰفِرُونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmdccxci{وَقُل رَّبِّ ٱغْفِرْ وَٱرْحَمْ وَأَنتَ خَيْرُ ٱلرَّٰحِمِينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmdccxcii{\basmalah سُورَةٌ أَنزَلْنَٰهَا وَفَرَضْنَٰهَا وَأَنزَلْنَا فِيهَآ ءَايَٰتٍۭ بَيِّنَٰتٍ لَّعَلَّكُمْ تَذَكَّرُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdccxciii{ٱلزَّانِيَةُ وَٱلزَّانِى فَٱجْلِدُوا۟ كُلَّ وَٰحِدٍ مِّنْهُمَا مِا۟ئَةَ جَلْدَةٍ وَلَا تَأْخُذْكُم بِهِمَا رَأْفَةٌ فِى دِينِ ٱللَّهِ إِن كُنتُمْ تُؤْمِنُونَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَلْيَشْهَدْ عَذَابَهُمَا طَآئِفَةٌ مِّنَ ٱلْمُؤْمِنِينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdccxciv{ٱلزَّانِى لَا يَنكِحُ إِلَّا زَانِيَةً أَوْ مُشْرِكَةً وَٱلزَّانِيَةُ لَا يَنكِحُهَآ إِلَّا زَانٍ أَوْ مُشْرِكٌ وَحُرِّمَ ذَٰلِكَ عَلَى ٱلْمُؤْمِنِينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdccxcv{وَٱلَّذِينَ يَرْمُونَ ٱلْمُحْصَنَٰتِ ثُمَّ لَمْ يَأْتُوا۟ بِأَرْبَعَةِ شُهَدَآءَ فَٱجْلِدُوهُمْ ثَمَٰنِينَ جَلْدَةً وَلَا تَقْبَلُوا۟ لَهُمْ شَهَٰدَةً أَبَدًا وَأُو۟لَٰٓئِكَ هُمُ ٱلْفَٰسِقُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdccxcvi{إِلَّا ٱلَّذِينَ تَابُوا۟ مِنۢ بَعْدِ ذَٰلِكَ وَأَصْلَحُوا۟ فَإِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdccxcvii{وَٱلَّذِينَ يَرْمُونَ أَزْوَٰجَهُمْ وَلَمْ يَكُن لَّهُمْ شُهَدَآءُ إِلَّآ أَنفُسُهُمْ فَشَهَٰدَةُ أَحَدِهِمْ أَرْبَعُ شَهَٰدَٰتٍۭ بِٱللَّهِ إِنَّهُۥ لَمِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdccxcviii{وَٱلْخَٰمِسَةُ أَنَّ لَعْنَتَ ٱللَّهِ عَلَيْهِ إِن كَانَ مِنَ ٱلْكَٰذِبِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdccxcix{وَيَدْرَؤُا۟ عَنْهَا ٱلْعَذَابَ أَن تَشْهَدَ أَرْبَعَ شَهَٰدَٰتٍۭ بِٱللَّهِ إِنَّهُۥ لَمِنَ ٱلْكَٰذِبِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdccc{وَٱلْخَٰمِسَةَ أَنَّ غَضَبَ ٱللَّهِ عَلَيْهَآ إِن كَانَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdccci{وَلَوْلَا فَضْلُ ٱللَّهِ عَلَيْكُمْ وَرَحْمَتُهُۥ وَأَنَّ ٱللَّهَ تَوَّابٌ حَكِيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdcccii{إِنَّ ٱلَّذِينَ جَآءُو بِٱلْإِفْكِ عُصْبَةٌ مِّنكُمْ لَا تَحْسَبُوهُ شَرًّا لَّكُم بَلْ هُوَ خَيْرٌ لَّكُمْ لِكُلِّ ٱمْرِئٍ مِّنْهُم مَّا ٱكْتَسَبَ مِنَ ٱلْإِثْمِ وَٱلَّذِى تَوَلَّىٰ كِبْرَهُۥ مِنْهُمْ لَهُۥ عَذَابٌ عَظِيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdccciii{لَّوْلَآ إِذْ سَمِعْتُمُوهُ ظَنَّ ٱلْمُؤْمِنُونَ وَٱلْمُؤْمِنَٰتُ بِأَنفُسِهِمْ خَيْرًا وَقَالُوا۟ هَٰذَآ إِفْكٌ مُّبِينٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdccciv{لَّوْلَا جَآءُو عَلَيْهِ بِأَرْبَعَةِ شُهَدَآءَ فَإِذْ لَمْ يَأْتُوا۟ بِٱلشُّهَدَآءِ فَأُو۟لَٰٓئِكَ عِندَ ٱللَّهِ هُمُ ٱلْكَٰذِبُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdcccv{وَلَوْلَا فَضْلُ ٱللَّهِ عَلَيْكُمْ وَرَحْمَتُهُۥ فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ لَمَسَّكُمْ فِى مَآ أَفَضْتُمْ فِيهِ عَذَابٌ عَظِيمٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdcccvi{إِذْ تَلَقَّوْنَهُۥ بِأَلْسِنَتِكُمْ وَتَقُولُونَ بِأَفْوَاهِكُم مَّا لَيْسَ لَكُم بِهِۦ عِلْمٌ وَتَحْسَبُونَهُۥ هَيِّنًا وَهُوَ عِندَ ٱللَّهِ عَظِيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdcccvii{وَلَوْلَآ إِذْ سَمِعْتُمُوهُ قُلْتُم مَّا يَكُونُ لَنَآ أَن نَّتَكَلَّمَ بِهَٰذَا سُبْحَٰنَكَ هَٰذَا بُهْتَٰنٌ عَظِيمٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdcccviii{يَعِظُكُمُ ٱللَّهُ أَن تَعُودُوا۟ لِمِثْلِهِۦٓ أَبَدًا إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdcccix{وَيُبَيِّنُ ٱللَّهُ لَكُمُ ٱلْءَايَٰتِ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdcccx{إِنَّ ٱلَّذِينَ يُحِبُّونَ أَن تَشِيعَ ٱلْفَٰحِشَةُ فِى ٱلَّذِينَ ءَامَنُوا۟ لَهُمْ عَذَابٌ أَلِيمٌ فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَٱللَّهُ يَعْلَمُ وَأَنتُمْ لَا تَعْلَمُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdcccxi{وَلَوْلَا فَضْلُ ٱللَّهِ عَلَيْكُمْ وَرَحْمَتُهُۥ وَأَنَّ ٱللَّهَ رَءُوفٌ رَّحِيمٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdcccxii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَتَّبِعُوا۟ خُطُوَٰتِ ٱلشَّيْطَٰنِ وَمَن يَتَّبِعْ خُطُوَٰتِ ٱلشَّيْطَٰنِ فَإِنَّهُۥ يَأْمُرُ بِٱلْفَحْشَآءِ وَٱلْمُنكَرِ وَلَوْلَا فَضْلُ ٱللَّهِ عَلَيْكُمْ وَرَحْمَتُهُۥ مَا زَكَىٰ مِنكُم مِّنْ أَحَدٍ أَبَدًا وَلَٰكِنَّ ٱللَّهَ يُزَكِّى مَن يَشَآءُ وَٱللَّهُ سَمِيعٌ عَلِيمٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdcccxiii{وَلَا يَأْتَلِ أُو۟لُوا۟ ٱلْفَضْلِ مِنكُمْ وَٱلسَّعَةِ أَن يُؤْتُوٓا۟ أُو۟لِى ٱلْقُرْبَىٰ وَٱلْمَسَٰكِينَ وَٱلْمُهَٰجِرِينَ فِى سَبِيلِ ٱللَّهِ وَلْيَعْفُوا۟ وَلْيَصْفَحُوٓا۟ أَلَا تُحِبُّونَ أَن يَغْفِرَ ٱللَّهُ لَكُمْ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdcccxiv{إِنَّ ٱلَّذِينَ يَرْمُونَ ٱلْمُحْصَنَٰتِ ٱلْغَٰفِلَٰتِ ٱلْمُؤْمِنَٰتِ لُعِنُوا۟ فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَلَهُمْ عَذَابٌ عَظِيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdcccxv{يَوْمَ تَشْهَدُ عَلَيْهِمْ أَلْسِنَتُهُمْ وَأَيْدِيهِمْ وَأَرْجُلُهُم بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdcccxvi{يَوْمَئِذٍ يُوَفِّيهِمُ ٱللَّهُ دِينَهُمُ ٱلْحَقَّ وَيَعْلَمُونَ أَنَّ ٱللَّهَ هُوَ ٱلْحَقُّ ٱلْمُبِينُ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdcccxvii{ٱلْخَبِيثَٰتُ لِلْخَبِيثِينَ وَٱلْخَبِيثُونَ لِلْخَبِيثَٰتِ وَٱلطَّيِّبَٰتُ لِلطَّيِّبِينَ وَٱلطَّيِّبُونَ لِلطَّيِّبَٰتِ أُو۟لَٰٓئِكَ مُبَرَّءُونَ مِمَّا يَقُولُونَ لَهُم مَّغْفِرَةٌ وَرِزْقٌ كَرِيمٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdcccxviii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَدْخُلُوا۟ بُيُوتًا غَيْرَ بُيُوتِكُمْ حَتَّىٰ تَسْتَأْنِسُوا۟ وَتُسَلِّمُوا۟ عَلَىٰٓ أَهْلِهَا ذَٰلِكُمْ خَيْرٌ لَّكُمْ لَعَلَّكُمْ تَذَكَّرُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdcccxix{فَإِن لَّمْ تَجِدُوا۟ فِيهَآ أَحَدًا فَلَا تَدْخُلُوهَا حَتَّىٰ يُؤْذَنَ لَكُمْ وَإِن قِيلَ لَكُمُ ٱرْجِعُوا۟ فَٱرْجِعُوا۟ هُوَ أَزْكَىٰ لَكُمْ وَٱللَّهُ بِمَا تَعْمَلُونَ عَلِيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdcccxx{لَّيْسَ عَلَيْكُمْ جُنَاحٌ أَن تَدْخُلُوا۟ بُيُوتًا غَيْرَ مَسْكُونَةٍ فِيهَا مَتَٰعٌ لَّكُمْ وَٱللَّهُ يَعْلَمُ مَا تُبْدُونَ وَمَا تَكْتُمُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdcccxxi{قُل لِّلْمُؤْمِنِينَ يَغُضُّوا۟ مِنْ أَبْصَٰرِهِمْ وَيَحْفَظُوا۟ فُرُوجَهُمْ ذَٰلِكَ أَزْكَىٰ لَهُمْ إِنَّ ٱللَّهَ خَبِيرٌۢ بِمَا يَصْنَعُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdcccxxii{وَقُل لِّلْمُؤْمِنَٰتِ يَغْضُضْنَ مِنْ أَبْصَٰرِهِنَّ وَيَحْفَظْنَ فُرُوجَهُنَّ وَلَا يُبْدِينَ زِينَتَهُنَّ إِلَّا مَا ظَهَرَ مِنْهَا وَلْيَضْرِبْنَ بِخُمُرِهِنَّ عَلَىٰ جُيُوبِهِنَّ وَلَا يُبْدِينَ زِينَتَهُنَّ إِلَّا لِبُعُولَتِهِنَّ أَوْ ءَابَآئِهِنَّ أَوْ ءَابَآءِ بُعُولَتِهِنَّ أَوْ أَبْنَآئِهِنَّ أَوْ أَبْنَآءِ بُعُولَتِهِنَّ أَوْ إِخْوَٰنِهِنَّ أَوْ بَنِىٓ إِخْوَٰنِهِنَّ أَوْ بَنِىٓ أَخَوَٰتِهِنَّ أَوْ نِسَآئِهِنَّ أَوْ مَا مَلَكَتْ أَيْمَٰنُهُنَّ أَوِ ٱلتَّٰبِعِينَ غَيْرِ أُو۟لِى ٱلْإِرْبَةِ مِنَ ٱلرِّجَالِ أَوِ ٱلطِّفْلِ ٱلَّذِينَ لَمْ يَظْهَرُوا۟ عَلَىٰ عَوْرَٰتِ ٱلنِّسَآءِ وَلَا يَضْرِبْنَ بِأَرْجُلِهِنَّ لِيُعْلَمَ مَا يُخْفِينَ مِن زِينَتِهِنَّ وَتُوبُوٓا۟ إِلَى ٱللَّهِ جَمِيعًا أَيُّهَ ٱلْمُؤْمِنُونَ لَعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdcccxxiii{وَأَنكِحُوا۟ ٱلْأَيَٰمَىٰ مِنكُمْ وَٱلصَّٰلِحِينَ مِنْ عِبَادِكُمْ وَإِمَآئِكُمْ إِن يَكُونُوا۟ فُقَرَآءَ يُغْنِهِمُ ٱللَّهُ مِن فَضْلِهِۦ وَٱللَّهُ وَٰسِعٌ عَلِيمٌ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdcccxxiv{وَلْيَسْتَعْفِفِ ٱلَّذِينَ لَا يَجِدُونَ نِكَاحًا حَتَّىٰ يُغْنِيَهُمُ ٱللَّهُ مِن فَضْلِهِۦ وَٱلَّذِينَ يَبْتَغُونَ ٱلْكِتَٰبَ مِمَّا مَلَكَتْ أَيْمَٰنُكُمْ فَكَاتِبُوهُمْ إِنْ عَلِمْتُمْ فِيهِمْ خَيْرًا وَءَاتُوهُم مِّن مَّالِ ٱللَّهِ ٱلَّذِىٓ ءَاتَىٰكُمْ وَلَا تُكْرِهُوا۟ فَتَيَٰتِكُمْ عَلَى ٱلْبِغَآءِ إِنْ أَرَدْنَ تَحَصُّنًا لِّتَبْتَغُوا۟ عَرَضَ ٱلْحَيَوٰةِ ٱلدُّنْيَا وَمَن يُكْرِههُّنَّ فَإِنَّ ٱللَّهَ مِنۢ بَعْدِ إِكْرَٰهِهِنَّ غَفُورٌ رَّحِيمٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdcccxxv{وَلَقَدْ أَنزَلْنَآ إِلَيْكُمْ ءَايَٰتٍ مُّبَيِّنَٰتٍ وَمَثَلًا مِّنَ ٱلَّذِينَ خَلَوْا۟ مِن قَبْلِكُمْ وَمَوْعِظَةً لِّلْمُتَّقِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdcccxxvi{ٱللَّهُ نُورُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ مَثَلُ نُورِهِۦ كَمِشْكَوٰةٍ فِيهَا مِصْبَاحٌ ٱلْمِصْبَاحُ فِى زُجَاجَةٍ ٱلزُّجَاجَةُ كَأَنَّهَا كَوْكَبٌ دُرِّىٌّ يُوقَدُ مِن شَجَرَةٍ مُّبَٰرَكَةٍ زَيْتُونَةٍ لَّا شَرْقِيَّةٍ وَلَا غَرْبِيَّةٍ يَكَادُ زَيْتُهَا يُضِىٓءُ وَلَوْ لَمْ تَمْسَسْهُ نَارٌ نُّورٌ عَلَىٰ نُورٍ يَهْدِى ٱللَّهُ لِنُورِهِۦ مَن يَشَآءُ وَيَضْرِبُ ٱللَّهُ ٱلْأَمْثَٰلَ لِلنَّاسِ وَٱللَّهُ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdcccxxvii{فِى بُيُوتٍ أَذِنَ ٱللَّهُ أَن تُرْفَعَ وَيُذْكَرَ فِيهَا ٱسْمُهُۥ يُسَبِّحُ لَهُۥ فِيهَا بِٱلْغُدُوِّ وَٱلْءَاصَالِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdcccxxviii{رِجَالٌ لَّا تُلْهِيهِمْ تِجَٰرَةٌ وَلَا بَيْعٌ عَن ذِكْرِ ٱللَّهِ وَإِقَامِ ٱلصَّلَوٰةِ وَإِيتَآءِ ٱلزَّكَوٰةِ يَخَافُونَ يَوْمًا تَتَقَلَّبُ فِيهِ ٱلْقُلُوبُ وَٱلْأَبْصَٰرُ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdcccxxix{لِيَجْزِيَهُمُ ٱللَّهُ أَحْسَنَ مَا عَمِلُوا۟ وَيَزِيدَهُم مِّن فَضْلِهِۦ وَٱللَّهُ يَرْزُقُ مَن يَشَآءُ بِغَيْرِ حِسَابٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdcccxxx{وَٱلَّذِينَ كَفَرُوٓا۟ أَعْمَٰلُهُمْ كَسَرَابٍۭ بِقِيعَةٍ يَحْسَبُهُ ٱلظَّمْـَٔانُ مَآءً حَتَّىٰٓ إِذَا جَآءَهُۥ لَمْ يَجِدْهُ شَيْـًٔا وَوَجَدَ ٱللَّهَ عِندَهُۥ فَوَفَّىٰهُ حِسَابَهُۥ وَٱللَّهُ سَرِيعُ ٱلْحِسَابِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdcccxxxi{أَوْ كَظُلُمَٰتٍ فِى بَحْرٍ لُّجِّىٍّ يَغْشَىٰهُ مَوْجٌ مِّن فَوْقِهِۦ مَوْجٌ مِّن فَوْقِهِۦ سَحَابٌ ظُلُمَٰتٌۢ بَعْضُهَا فَوْقَ بَعْضٍ إِذَآ أَخْرَجَ يَدَهُۥ لَمْ يَكَدْ يَرَىٰهَا وَمَن لَّمْ يَجْعَلِ ٱللَّهُ لَهُۥ نُورًا فَمَا لَهُۥ مِن نُّورٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdcccxxxii{أَلَمْ تَرَ أَنَّ ٱللَّهَ يُسَبِّحُ لَهُۥ مَن فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱلطَّيْرُ صَٰٓفَّٰتٍ كُلٌّ قَدْ عَلِمَ صَلَاتَهُۥ وَتَسْبِيحَهُۥ وَٱللَّهُ عَلِيمٌۢ بِمَا يَفْعَلُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdcccxxxiii{وَلِلَّهِ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَإِلَى ٱللَّهِ ٱلْمَصِيرُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdcccxxxiv{أَلَمْ تَرَ أَنَّ ٱللَّهَ يُزْجِى سَحَابًا ثُمَّ يُؤَلِّفُ بَيْنَهُۥ ثُمَّ يَجْعَلُهُۥ رُكَامًا فَتَرَى ٱلْوَدْقَ يَخْرُجُ مِنْ خِلَٰلِهِۦ وَيُنَزِّلُ مِنَ ٱلسَّمَآءِ مِن جِبَالٍ فِيهَا مِنۢ بَرَدٍ فَيُصِيبُ بِهِۦ مَن يَشَآءُ وَيَصْرِفُهُۥ عَن مَّن يَشَآءُ يَكَادُ سَنَا بَرْقِهِۦ يَذْهَبُ بِٱلْأَبْصَٰرِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdcccxxxv{يُقَلِّبُ ٱللَّهُ ٱلَّيْلَ وَٱلنَّهَارَ إِنَّ فِى ذَٰلِكَ لَعِبْرَةً لِّأُو۟لِى ٱلْأَبْصَٰرِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdcccxxxvi{وَٱللَّهُ خَلَقَ كُلَّ دَآبَّةٍ مِّن مَّآءٍ فَمِنْهُم مَّن يَمْشِى عَلَىٰ بَطْنِهِۦ وَمِنْهُم مَّن يَمْشِى عَلَىٰ رِجْلَيْنِ وَمِنْهُم مَّن يَمْشِى عَلَىٰٓ أَرْبَعٍ يَخْلُقُ ٱللَّهُ مَا يَشَآءُ إِنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdcccxxxvii{لَّقَدْ أَنزَلْنَآ ءَايَٰتٍ مُّبَيِّنَٰتٍ وَٱللَّهُ يَهْدِى مَن يَشَآءُ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdcccxxxviii{وَيَقُولُونَ ءَامَنَّا بِٱللَّهِ وَبِٱلرَّسُولِ وَأَطَعْنَا ثُمَّ يَتَوَلَّىٰ فَرِيقٌ مِّنْهُم مِّنۢ بَعْدِ ذَٰلِكَ وَمَآ أُو۟لَٰٓئِكَ بِٱلْمُؤْمِنِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdcccxxxix{وَإِذَا دُعُوٓا۟ إِلَى ٱللَّهِ وَرَسُولِهِۦ لِيَحْكُمَ بَيْنَهُمْ إِذَا فَرِيقٌ مِّنْهُم مُّعْرِضُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdcccxl{وَإِن يَكُن لَّهُمُ ٱلْحَقُّ يَأْتُوٓا۟ إِلَيْهِ مُذْعِنِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdcccxli{أَفِى قُلُوبِهِم مَّرَضٌ أَمِ ٱرْتَابُوٓا۟ أَمْ يَخَافُونَ أَن يَحِيفَ ٱللَّهُ عَلَيْهِمْ وَرَسُولُهُۥ بَلْ أُو۟لَٰٓئِكَ هُمُ ٱلظَّٰلِمُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdcccxlii{إِنَّمَا كَانَ قَوْلَ ٱلْمُؤْمِنِينَ إِذَا دُعُوٓا۟ إِلَى ٱللَّهِ وَرَسُولِهِۦ لِيَحْكُمَ بَيْنَهُمْ أَن يَقُولُوا۟ سَمِعْنَا وَأَطَعْنَا وَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdcccxliii{وَمَن يُطِعِ ٱللَّهَ وَرَسُولَهُۥ وَيَخْشَ ٱللَّهَ وَيَتَّقْهِ فَأُو۟لَٰٓئِكَ هُمُ ٱلْفَآئِزُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdcccxliv{وَأَقْسَمُوا۟ بِٱللَّهِ جَهْدَ أَيْمَٰنِهِمْ لَئِنْ أَمَرْتَهُمْ لَيَخْرُجُنَّ قُل لَّا تُقْسِمُوا۟ طَاعَةٌ مَّعْرُوفَةٌ إِنَّ ٱللَّهَ خَبِيرٌۢ بِمَا تَعْمَلُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdcccxlv{قُلْ أَطِيعُوا۟ ٱللَّهَ وَأَطِيعُوا۟ ٱلرَّسُولَ فَإِن تَوَلَّوْا۟ فَإِنَّمَا عَلَيْهِ مَا حُمِّلَ وَعَلَيْكُم مَّا حُمِّلْتُمْ وَإِن تُطِيعُوهُ تَهْتَدُوا۟ وَمَا عَلَى ٱلرَّسُولِ إِلَّا ٱلْبَلَٰغُ ٱلْمُبِينُ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdcccxlvi{وَعَدَ ٱللَّهُ ٱلَّذِينَ ءَامَنُوا۟ مِنكُمْ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَيَسْتَخْلِفَنَّهُمْ فِى ٱلْأَرْضِ كَمَا ٱسْتَخْلَفَ ٱلَّذِينَ مِن قَبْلِهِمْ وَلَيُمَكِّنَنَّ لَهُمْ دِينَهُمُ ٱلَّذِى ٱرْتَضَىٰ لَهُمْ وَلَيُبَدِّلَنَّهُم مِّنۢ بَعْدِ خَوْفِهِمْ أَمْنًا يَعْبُدُونَنِى لَا يُشْرِكُونَ بِى شَيْـًٔا وَمَن كَفَرَ بَعْدَ ذَٰلِكَ فَأُو۟لَٰٓئِكَ هُمُ ٱلْفَٰسِقُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdcccxlvii{وَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَءَاتُوا۟ ٱلزَّكَوٰةَ وَأَطِيعُوا۟ ٱلرَّسُولَ لَعَلَّكُمْ تُرْحَمُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdcccxlviii{لَا تَحْسَبَنَّ ٱلَّذِينَ كَفَرُوا۟ مُعْجِزِينَ فِى ٱلْأَرْضِ وَمَأْوَىٰهُمُ ٱلنَّارُ وَلَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdcccxlix{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لِيَسْتَـْٔذِنكُمُ ٱلَّذِينَ مَلَكَتْ أَيْمَٰنُكُمْ وَٱلَّذِينَ لَمْ يَبْلُغُوا۟ ٱلْحُلُمَ مِنكُمْ ثَلَٰثَ مَرَّٰتٍ مِّن قَبْلِ صَلَوٰةِ ٱلْفَجْرِ وَحِينَ تَضَعُونَ ثِيَابَكُم مِّنَ ٱلظَّهِيرَةِ وَمِنۢ بَعْدِ صَلَوٰةِ ٱلْعِشَآءِ ثَلَٰثُ عَوْرَٰتٍ لَّكُمْ لَيْسَ عَلَيْكُمْ وَلَا عَلَيْهِمْ جُنَاحٌۢ بَعْدَهُنَّ طَوَّٰفُونَ عَلَيْكُم بَعْضُكُمْ عَلَىٰ بَعْضٍ كَذَٰلِكَ يُبَيِّنُ ٱللَّهُ لَكُمُ ٱلْءَايَٰتِ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdcccl{وَإِذَا بَلَغَ ٱلْأَطْفَٰلُ مِنكُمُ ٱلْحُلُمَ فَلْيَسْتَـْٔذِنُوا۟ كَمَا ٱسْتَـْٔذَنَ ٱلَّذِينَ مِن قَبْلِهِمْ كَذَٰلِكَ يُبَيِّنُ ٱللَّهُ لَكُمْ ءَايَٰتِهِۦ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdcccli{وَٱلْقَوَٰعِدُ مِنَ ٱلنِّسَآءِ ٱلَّٰتِى لَا يَرْجُونَ نِكَاحًا فَلَيْسَ عَلَيْهِنَّ جُنَاحٌ أَن يَضَعْنَ ثِيَابَهُنَّ غَيْرَ مُتَبَرِّجَٰتٍۭ بِزِينَةٍ وَأَن يَسْتَعْفِفْنَ خَيْرٌ لَّهُنَّ وَٱللَّهُ سَمِيعٌ عَلِيمٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdccclii{لَّيْسَ عَلَى ٱلْأَعْمَىٰ حَرَجٌ وَلَا عَلَى ٱلْأَعْرَجِ حَرَجٌ وَلَا عَلَى ٱلْمَرِيضِ حَرَجٌ وَلَا عَلَىٰٓ أَنفُسِكُمْ أَن تَأْكُلُوا۟ مِنۢ بُيُوتِكُمْ أَوْ بُيُوتِ ءَابَآئِكُمْ أَوْ بُيُوتِ أُمَّهَٰتِكُمْ أَوْ بُيُوتِ إِخْوَٰنِكُمْ أَوْ بُيُوتِ أَخَوَٰتِكُمْ أَوْ بُيُوتِ أَعْمَٰمِكُمْ أَوْ بُيُوتِ عَمَّٰتِكُمْ أَوْ بُيُوتِ أَخْوَٰلِكُمْ أَوْ بُيُوتِ خَٰلَٰتِكُمْ أَوْ مَا مَلَكْتُم مَّفَاتِحَهُۥٓ أَوْ صَدِيقِكُمْ لَيْسَ عَلَيْكُمْ جُنَاحٌ أَن تَأْكُلُوا۟ جَمِيعًا أَوْ أَشْتَاتًا فَإِذَا دَخَلْتُم بُيُوتًا فَسَلِّمُوا۟ عَلَىٰٓ أَنفُسِكُمْ تَحِيَّةً مِّنْ عِندِ ٱللَّهِ مُبَٰرَكَةً طَيِّبَةً كَذَٰلِكَ يُبَيِّنُ ٱللَّهُ لَكُمُ ٱلْءَايَٰتِ لَعَلَّكُمْ تَعْقِلُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdcccliii{إِنَّمَا ٱلْمُؤْمِنُونَ ٱلَّذِينَ ءَامَنُوا۟ بِٱللَّهِ وَرَسُولِهِۦ وَإِذَا كَانُوا۟ مَعَهُۥ عَلَىٰٓ أَمْرٍ جَامِعٍ لَّمْ يَذْهَبُوا۟ حَتَّىٰ يَسْتَـْٔذِنُوهُ إِنَّ ٱلَّذِينَ يَسْتَـْٔذِنُونَكَ أُو۟لَٰٓئِكَ ٱلَّذِينَ يُؤْمِنُونَ بِٱللَّهِ وَرَسُولِهِۦ فَإِذَا ٱسْتَـْٔذَنُوكَ لِبَعْضِ شَأْنِهِمْ فَأْذَن لِّمَن شِئْتَ مِنْهُمْ وَٱسْتَغْفِرْ لَهُمُ ٱللَّهَ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdcccliv{لَّا تَجْعَلُوا۟ دُعَآءَ ٱلرَّسُولِ بَيْنَكُمْ كَدُعَآءِ بَعْضِكُم بَعْضًا قَدْ يَعْلَمُ ٱللَّهُ ٱلَّذِينَ يَتَسَلَّلُونَ مِنكُمْ لِوَاذًا فَلْيَحْذَرِ ٱلَّذِينَ يُخَالِفُونَ عَنْ أَمْرِهِۦٓ أَن تُصِيبَهُمْ فِتْنَةٌ أَوْ يُصِيبَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdccclv{أَلَآ إِنَّ لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ قَدْ يَعْلَمُ مَآ أَنتُمْ عَلَيْهِ وَيَوْمَ يُرْجَعُونَ إِلَيْهِ فَيُنَبِّئُهُم بِمَا عَمِلُوا۟ وَٱللَّهُ بِكُلِّ شَىْءٍ عَلِيمٌۢ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdccclvi{\basmalah تَبَارَكَ ٱلَّذِى نَزَّلَ ٱلْفُرْقَانَ عَلَىٰ عَبْدِهِۦ لِيَكُونَ لِلْعَٰلَمِينَ نَذِيرًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdccclvii{ٱلَّذِى لَهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَلَمْ يَتَّخِذْ وَلَدًا وَلَمْ يَكُن لَّهُۥ شَرِيكٌ فِى ٱلْمُلْكِ وَخَلَقَ كُلَّ شَىْءٍ فَقَدَّرَهُۥ تَقْدِيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdccclviii{وَٱتَّخَذُوا۟ مِن دُونِهِۦٓ ءَالِهَةً لَّا يَخْلُقُونَ شَيْـًٔا وَهُمْ يُخْلَقُونَ وَلَا يَمْلِكُونَ لِأَنفُسِهِمْ ضَرًّا وَلَا نَفْعًا وَلَا يَمْلِكُونَ مَوْتًا وَلَا حَيَوٰةً وَلَا نُشُورًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdccclix{وَقَالَ ٱلَّذِينَ كَفَرُوٓا۟ إِنْ هَٰذَآ إِلَّآ إِفْكٌ ٱفْتَرَىٰهُ وَأَعَانَهُۥ عَلَيْهِ قَوْمٌ ءَاخَرُونَ فَقَدْ جَآءُو ظُلْمًا وَزُورًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdccclx{وَقَالُوٓا۟ أَسَٰطِيرُ ٱلْأَوَّلِينَ ٱكْتَتَبَهَا فَهِىَ تُمْلَىٰ عَلَيْهِ بُكْرَةً وَأَصِيلًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdccclxi{قُلْ أَنزَلَهُ ٱلَّذِى يَعْلَمُ ٱلسِّرَّ فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ إِنَّهُۥ كَانَ غَفُورًا رَّحِيمًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdccclxii{وَقَالُوا۟ مَالِ هَٰذَا ٱلرَّسُولِ يَأْكُلُ ٱلطَّعَامَ وَيَمْشِى فِى ٱلْأَسْوَاقِ لَوْلَآ أُنزِلَ إِلَيْهِ مَلَكٌ فَيَكُونَ مَعَهُۥ نَذِيرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdccclxiii{أَوْ يُلْقَىٰٓ إِلَيْهِ كَنزٌ أَوْ تَكُونُ لَهُۥ جَنَّةٌ يَأْكُلُ مِنْهَا وَقَالَ ٱلظَّٰلِمُونَ إِن تَتَّبِعُونَ إِلَّا رَجُلًا مَّسْحُورًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdccclxiv{ٱنظُرْ كَيْفَ ضَرَبُوا۟ لَكَ ٱلْأَمْثَٰلَ فَضَلُّوا۟ فَلَا يَسْتَطِيعُونَ سَبِيلًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdccclxv{تَبَارَكَ ٱلَّذِىٓ إِن شَآءَ جَعَلَ لَكَ خَيْرًا مِّن ذَٰلِكَ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ وَيَجْعَل لَّكَ قُصُورًۢا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdccclxvi{بَلْ كَذَّبُوا۟ بِٱلسَّاعَةِ وَأَعْتَدْنَا لِمَن كَذَّبَ بِٱلسَّاعَةِ سَعِيرًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdccclxvii{إِذَا رَأَتْهُم مِّن مَّكَانٍۭ بَعِيدٍ سَمِعُوا۟ لَهَا تَغَيُّظًا وَزَفِيرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdccclxviii{وَإِذَآ أُلْقُوا۟ مِنْهَا مَكَانًا ضَيِّقًا مُّقَرَّنِينَ دَعَوْا۟ هُنَالِكَ ثُبُورًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdccclxix{لَّا تَدْعُوا۟ ٱلْيَوْمَ ثُبُورًا وَٰحِدًا وَٱدْعُوا۟ ثُبُورًا كَثِيرًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdccclxx{قُلْ أَذَٰلِكَ خَيْرٌ أَمْ جَنَّةُ ٱلْخُلْدِ ٱلَّتِى وُعِدَ ٱلْمُتَّقُونَ كَانَتْ لَهُمْ جَزَآءً وَمَصِيرًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdccclxxi{لَّهُمْ فِيهَا مَا يَشَآءُونَ خَٰلِدِينَ كَانَ عَلَىٰ رَبِّكَ وَعْدًا مَّسْـُٔولًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdccclxxii{وَيَوْمَ يَحْشُرُهُمْ وَمَا يَعْبُدُونَ مِن دُونِ ٱللَّهِ فَيَقُولُ ءَأَنتُمْ أَضْلَلْتُمْ عِبَادِى هَٰٓؤُلَآءِ أَمْ هُمْ ضَلُّوا۟ ٱلسَّبِيلَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdccclxxiii{قَالُوا۟ سُبْحَٰنَكَ مَا كَانَ يَنۢبَغِى لَنَآ أَن نَّتَّخِذَ مِن دُونِكَ مِنْ أَوْلِيَآءَ وَلَٰكِن مَّتَّعْتَهُمْ وَءَابَآءَهُمْ حَتَّىٰ نَسُوا۟ ٱلذِّكْرَ وَكَانُوا۟ قَوْمًۢا بُورًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdccclxxiv{فَقَدْ كَذَّبُوكُم بِمَا تَقُولُونَ فَمَا تَسْتَطِيعُونَ صَرْفًا وَلَا نَصْرًا وَمَن يَظْلِم مِّنكُمْ نُذِقْهُ عَذَابًا كَبِيرًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdccclxxv{وَمَآ أَرْسَلْنَا قَبْلَكَ مِنَ ٱلْمُرْسَلِينَ إِلَّآ إِنَّهُمْ لَيَأْكُلُونَ ٱلطَّعَامَ وَيَمْشُونَ فِى ٱلْأَسْوَاقِ وَجَعَلْنَا بَعْضَكُمْ لِبَعْضٍ فِتْنَةً أَتَصْبِرُونَ وَكَانَ رَبُّكَ بَصِيرًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdccclxxvi{وَقَالَ ٱلَّذِينَ لَا يَرْجُونَ لِقَآءَنَا لَوْلَآ أُنزِلَ عَلَيْنَا ٱلْمَلَٰٓئِكَةُ أَوْ نَرَىٰ رَبَّنَا لَقَدِ ٱسْتَكْبَرُوا۟ فِىٓ أَنفُسِهِمْ وَعَتَوْ عُتُوًّا كَبِيرًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdccclxxvii{يَوْمَ يَرَوْنَ ٱلْمَلَٰٓئِكَةَ لَا بُشْرَىٰ يَوْمَئِذٍ لِّلْمُجْرِمِينَ وَيَقُولُونَ حِجْرًا مَّحْجُورًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdccclxxviii{وَقَدِمْنَآ إِلَىٰ مَا عَمِلُوا۟ مِنْ عَمَلٍ فَجَعَلْنَٰهُ هَبَآءً مَّنثُورًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdccclxxix{أَصْحَٰبُ ٱلْجَنَّةِ يَوْمَئِذٍ خَيْرٌ مُّسْتَقَرًّا وَأَحْسَنُ مَقِيلًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdccclxxx{وَيَوْمَ تَشَقَّقُ ٱلسَّمَآءُ بِٱلْغَمَٰمِ وَنُزِّلَ ٱلْمَلَٰٓئِكَةُ تَنزِيلًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdccclxxxi{ٱلْمُلْكُ يَوْمَئِذٍ ٱلْحَقُّ لِلرَّحْمَٰنِ وَكَانَ يَوْمًا عَلَى ٱلْكَٰفِرِينَ عَسِيرًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdccclxxxii{وَيَوْمَ يَعَضُّ ٱلظَّالِمُ عَلَىٰ يَدَيْهِ يَقُولُ يَٰلَيْتَنِى ٱتَّخَذْتُ مَعَ ٱلرَّسُولِ سَبِيلًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdccclxxxiii{يَٰوَيْلَتَىٰ لَيْتَنِى لَمْ أَتَّخِذْ فُلَانًا خَلِيلًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdccclxxxiv{لَّقَدْ أَضَلَّنِى عَنِ ٱلذِّكْرِ بَعْدَ إِذْ جَآءَنِى وَكَانَ ٱلشَّيْطَٰنُ لِلْإِنسَٰنِ خَذُولًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdccclxxxv{وَقَالَ ٱلرَّسُولُ يَٰرَبِّ إِنَّ قَوْمِى ٱتَّخَذُوا۟ هَٰذَا ٱلْقُرْءَانَ مَهْجُورًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdccclxxxvi{وَكَذَٰلِكَ جَعَلْنَا لِكُلِّ نَبِىٍّ عَدُوًّا مِّنَ ٱلْمُجْرِمِينَ وَكَفَىٰ بِرَبِّكَ هَادِيًا وَنَصِيرًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdccclxxxvii{وَقَالَ ٱلَّذِينَ كَفَرُوا۟ لَوْلَا نُزِّلَ عَلَيْهِ ٱلْقُرْءَانُ جُمْلَةً وَٰحِدَةً كَذَٰلِكَ لِنُثَبِّتَ بِهِۦ فُؤَادَكَ وَرَتَّلْنَٰهُ تَرْتِيلًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdccclxxxviii{وَلَا يَأْتُونَكَ بِمَثَلٍ إِلَّا جِئْنَٰكَ بِٱلْحَقِّ وَأَحْسَنَ تَفْسِيرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdccclxxxix{ٱلَّذِينَ يُحْشَرُونَ عَلَىٰ وُجُوهِهِمْ إِلَىٰ جَهَنَّمَ أُو۟لَٰٓئِكَ شَرٌّ مَّكَانًا وَأَضَلُّ سَبِيلًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdcccxc{وَلَقَدْ ءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ وَجَعَلْنَا مَعَهُۥٓ أَخَاهُ هَٰرُونَ وَزِيرًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdcccxci{فَقُلْنَا ٱذْهَبَآ إِلَى ٱلْقَوْمِ ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِنَا فَدَمَّرْنَٰهُمْ تَدْمِيرًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdcccxcii{وَقَوْمَ نُوحٍ لَّمَّا كَذَّبُوا۟ ٱلرُّسُلَ أَغْرَقْنَٰهُمْ وَجَعَلْنَٰهُمْ لِلنَّاسِ ءَايَةً وَأَعْتَدْنَا لِلظَّٰلِمِينَ عَذَابًا أَلِيمًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdcccxciii{وَعَادًا وَثَمُودَا۟ وَأَصْحَٰبَ ٱلرَّسِّ وَقُرُونًۢا بَيْنَ ذَٰلِكَ كَثِيرًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdcccxciv{وَكُلًّا ضَرَبْنَا لَهُ ٱلْأَمْثَٰلَ وَكُلًّا تَبَّرْنَا تَتْبِيرًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdcccxcv{وَلَقَدْ أَتَوْا۟ عَلَى ٱلْقَرْيَةِ ٱلَّتِىٓ أُمْطِرَتْ مَطَرَ ٱلسَّوْءِ أَفَلَمْ يَكُونُوا۟ يَرَوْنَهَا بَلْ كَانُوا۟ لَا يَرْجُونَ نُشُورًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdcccxcvi{وَإِذَا رَأَوْكَ إِن يَتَّخِذُونَكَ إِلَّا هُزُوًا أَهَٰذَا ٱلَّذِى بَعَثَ ٱللَّهُ رَسُولًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdcccxcvii{إِن كَادَ لَيُضِلُّنَا عَنْ ءَالِهَتِنَا لَوْلَآ أَن صَبَرْنَا عَلَيْهَا وَسَوْفَ يَعْلَمُونَ حِينَ يَرَوْنَ ٱلْعَذَابَ مَنْ أَضَلُّ سَبِيلًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdcccxcviii{أَرَءَيْتَ مَنِ ٱتَّخَذَ إِلَٰهَهُۥ هَوَىٰهُ أَفَأَنتَ تَكُونُ عَلَيْهِ وَكِيلًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdcccxcix{أَمْ تَحْسَبُ أَنَّ أَكْثَرَهُمْ يَسْمَعُونَ أَوْ يَعْقِلُونَ إِنْ هُمْ إِلَّا كَٱلْأَنْعَٰمِ بَلْ هُمْ أَضَلُّ سَبِيلًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmcm{أَلَمْ تَرَ إِلَىٰ رَبِّكَ كَيْفَ مَدَّ ٱلظِّلَّ وَلَوْ شَآءَ لَجَعَلَهُۥ سَاكِنًا ثُمَّ جَعَلْنَا ٱلشَّمْسَ عَلَيْهِ دَلِيلًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmcmi{ثُمَّ قَبَضْنَٰهُ إِلَيْنَا قَبْضًا يَسِيرًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmcmii{وَهُوَ ٱلَّذِى جَعَلَ لَكُمُ ٱلَّيْلَ لِبَاسًا وَٱلنَّوْمَ سُبَاتًا وَجَعَلَ ٱلنَّهَارَ نُشُورًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmcmiii{وَهُوَ ٱلَّذِىٓ أَرْسَلَ ٱلرِّيَٰحَ بُشْرًۢا بَيْنَ يَدَىْ رَحْمَتِهِۦ وَأَنزَلْنَا مِنَ ٱلسَّمَآءِ مَآءً طَهُورًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmcmiv{لِّنُحْۦِىَ بِهِۦ بَلْدَةً مَّيْتًا وَنُسْقِيَهُۥ مِمَّا خَلَقْنَآ أَنْعَٰمًا وَأَنَاسِىَّ كَثِيرًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcmv{وَلَقَدْ صَرَّفْنَٰهُ بَيْنَهُمْ لِيَذَّكَّرُوا۟ فَأَبَىٰٓ أَكْثَرُ ٱلنَّاسِ إِلَّا كُفُورًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcmvi{وَلَوْ شِئْنَا لَبَعَثْنَا فِى كُلِّ قَرْيَةٍ نَّذِيرًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcmvii{فَلَا تُطِعِ ٱلْكَٰفِرِينَ وَجَٰهِدْهُم بِهِۦ جِهَادًا كَبِيرًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcmviii{وَهُوَ ٱلَّذِى مَرَجَ ٱلْبَحْرَيْنِ هَٰذَا عَذْبٌ فُرَاتٌ وَهَٰذَا مِلْحٌ أُجَاجٌ وَجَعَلَ بَيْنَهُمَا بَرْزَخًا وَحِجْرًا مَّحْجُورًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcmix{وَهُوَ ٱلَّذِى خَلَقَ مِنَ ٱلْمَآءِ بَشَرًا فَجَعَلَهُۥ نَسَبًا وَصِهْرًا وَكَانَ رَبُّكَ قَدِيرًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcmx{وَيَعْبُدُونَ مِن دُونِ ٱللَّهِ مَا لَا يَنفَعُهُمْ وَلَا يَضُرُّهُمْ وَكَانَ ٱلْكَافِرُ عَلَىٰ رَبِّهِۦ ظَهِيرًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcmxi{وَمَآ أَرْسَلْنَٰكَ إِلَّا مُبَشِّرًا وَنَذِيرًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcmxii{قُلْ مَآ أَسْـَٔلُكُمْ عَلَيْهِ مِنْ أَجْرٍ إِلَّا مَن شَآءَ أَن يَتَّخِذَ إِلَىٰ رَبِّهِۦ سَبِيلًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcmxiii{وَتَوَكَّلْ عَلَى ٱلْحَىِّ ٱلَّذِى لَا يَمُوتُ وَسَبِّحْ بِحَمْدِهِۦ وَكَفَىٰ بِهِۦ بِذُنُوبِ عِبَادِهِۦ خَبِيرًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcmxiv{ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَمَا بَيْنَهُمَا فِى سِتَّةِ أَيَّامٍ ثُمَّ ٱسْتَوَىٰ عَلَى ٱلْعَرْشِ ٱلرَّحْمَٰنُ فَسْـَٔلْ بِهِۦ خَبِيرًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcmxv{وَإِذَا قِيلَ لَهُمُ ٱسْجُدُوا۟ لِلرَّحْمَٰنِ قَالُوا۟ وَمَا ٱلرَّحْمَٰنُ أَنَسْجُدُ لِمَا تَأْمُرُنَا وَزَادَهُمْ نُفُورًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcmxvi{تَبَارَكَ ٱلَّذِى جَعَلَ فِى ٱلسَّمَآءِ بُرُوجًا وَجَعَلَ فِيهَا سِرَٰجًا وَقَمَرًا مُّنِيرًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcmxvii{وَهُوَ ٱلَّذِى جَعَلَ ٱلَّيْلَ وَٱلنَّهَارَ خِلْفَةً لِّمَنْ أَرَادَ أَن يَذَّكَّرَ أَوْ أَرَادَ شُكُورًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcmxviii{وَعِبَادُ ٱلرَّحْمَٰنِ ٱلَّذِينَ يَمْشُونَ عَلَى ٱلْأَرْضِ هَوْنًا وَإِذَا خَاطَبَهُمُ ٱلْجَٰهِلُونَ قَالُوا۟ سَلَٰمًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcmxix{وَٱلَّذِينَ يَبِيتُونَ لِرَبِّهِمْ سُجَّدًا وَقِيَٰمًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcmxx{وَٱلَّذِينَ يَقُولُونَ رَبَّنَا ٱصْرِفْ عَنَّا عَذَابَ جَهَنَّمَ إِنَّ عَذَابَهَا كَانَ غَرَامًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcmxxi{إِنَّهَا سَآءَتْ مُسْتَقَرًّا وَمُقَامًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcmxxii{وَٱلَّذِينَ إِذَآ أَنفَقُوا۟ لَمْ يُسْرِفُوا۟ وَلَمْ يَقْتُرُوا۟ وَكَانَ بَيْنَ ذَٰلِكَ قَوَامًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmcmxxiii{وَٱلَّذِينَ لَا يَدْعُونَ مَعَ ٱللَّهِ إِلَٰهًا ءَاخَرَ وَلَا يَقْتُلُونَ ٱلنَّفْسَ ٱلَّتِى حَرَّمَ ٱللَّهُ إِلَّا بِٱلْحَقِّ وَلَا يَزْنُونَ وَمَن يَفْعَلْ ذَٰلِكَ يَلْقَ أَثَامًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmcmxxiv{يُضَٰعَفْ لَهُ ٱلْعَذَابُ يَوْمَ ٱلْقِيَٰمَةِ وَيَخْلُدْ فِيهِۦ مُهَانًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmcmxxv{إِلَّا مَن تَابَ وَءَامَنَ وَعَمِلَ عَمَلًا صَٰلِحًا فَأُو۟لَٰٓئِكَ يُبَدِّلُ ٱللَّهُ سَيِّـَٔاتِهِمْ حَسَنَٰتٍ وَكَانَ ٱللَّهُ غَفُورًا رَّحِيمًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmcmxxvi{وَمَن تَابَ وَعَمِلَ صَٰلِحًا فَإِنَّهُۥ يَتُوبُ إِلَى ٱللَّهِ مَتَابًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmcmxxvii{وَٱلَّذِينَ لَا يَشْهَدُونَ ٱلزُّورَ وَإِذَا مَرُّوا۟ بِٱللَّغْوِ مَرُّوا۟ كِرَامًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcmxxviii{وَٱلَّذِينَ إِذَا ذُكِّرُوا۟ بِـَٔايَٰتِ رَبِّهِمْ لَمْ يَخِرُّوا۟ عَلَيْهَا صُمًّا وَعُمْيَانًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmcmxxix{وَٱلَّذِينَ يَقُولُونَ رَبَّنَا هَبْ لَنَا مِنْ أَزْوَٰجِنَا وَذُرِّيَّٰتِنَا قُرَّةَ أَعْيُنٍ وَٱجْعَلْنَا لِلْمُتَّقِينَ إِمَامًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmcmxxx{أُو۟لَٰٓئِكَ يُجْزَوْنَ ٱلْغُرْفَةَ بِمَا صَبَرُوا۟ وَيُلَقَّوْنَ فِيهَا تَحِيَّةً وَسَلَٰمًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcmxxxi{خَٰلِدِينَ فِيهَا حَسُنَتْ مُسْتَقَرًّا وَمُقَامًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcmxxxii{قُلْ مَا يَعْبَؤُا۟ بِكُمْ رَبِّى لَوْلَا دُعَآؤُكُمْ فَقَدْ كَذَّبْتُمْ فَسَوْفَ يَكُونُ لِزَامًۢا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcmxxxiii{\basmalah طسٓمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcmxxxiv{تِلْكَ ءَايَٰتُ ٱلْكِتَٰبِ ٱلْمُبِينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcmxxxv{لَعَلَّكَ بَٰخِعٌ نَّفْسَكَ أَلَّا يَكُونُوا۟ مُؤْمِنِينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmcmxxxvi{إِن نَّشَأْ نُنَزِّلْ عَلَيْهِم مِّنَ ٱلسَّمَآءِ ءَايَةً فَظَلَّتْ أَعْنَٰقُهُمْ لَهَا خَٰضِعِينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcmxxxvii{وَمَا يَأْتِيهِم مِّن ذِكْرٍ مِّنَ ٱلرَّحْمَٰنِ مُحْدَثٍ إِلَّا كَانُوا۟ عَنْهُ مُعْرِضِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcmxxxviii{فَقَدْ كَذَّبُوا۟ فَسَيَأْتِيهِمْ أَنۢبَٰٓؤُا۟ مَا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcmxxxix{أَوَلَمْ يَرَوْا۟ إِلَى ٱلْأَرْضِ كَمْ أَنۢبَتْنَا فِيهَا مِن كُلِّ زَوْجٍ كَرِيمٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcmxl{إِنَّ فِى ذَٰلِكَ لَءَايَةً وَمَا كَانَ أَكْثَرُهُم مُّؤْمِنِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcmxli{وَإِنَّ رَبَّكَ لَهُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcmxlii{وَإِذْ نَادَىٰ رَبُّكَ مُوسَىٰٓ أَنِ ٱئْتِ ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcmxliii{قَوْمَ فِرْعَوْنَ أَلَا يَتَّقُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmcmxliv{قَالَ رَبِّ إِنِّىٓ أَخَافُ أَن يُكَذِّبُونِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcmxlv{وَيَضِيقُ صَدْرِى وَلَا يَنطَلِقُ لِسَانِى فَأَرْسِلْ إِلَىٰ هَٰرُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcmxlvi{وَلَهُمْ عَلَىَّ ذَنۢبٌ فَأَخَافُ أَن يَقْتُلُونِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmcmxlvii{قَالَ كَلَّا فَٱذْهَبَا بِـَٔايَٰتِنَآ إِنَّا مَعَكُم مُّسْتَمِعُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmcmxlviii{فَأْتِيَا فِرْعَوْنَ فَقُولَآ إِنَّا رَسُولُ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmcmxlix{أَنْ أَرْسِلْ مَعَنَا بَنِىٓ إِسْرَٰٓءِيلَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmcml{قَالَ أَلَمْ نُرَبِّكَ فِينَا وَلِيدًا وَلَبِثْتَ فِينَا مِنْ عُمُرِكَ سِنِينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmcmli{وَفَعَلْتَ فَعْلَتَكَ ٱلَّتِى فَعَلْتَ وَأَنتَ مِنَ ٱلْكَٰفِرِينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmcmlii{قَالَ فَعَلْتُهَآ إِذًا وَأَنَا۠ مِنَ ٱلضَّآلِّينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmcmliii{فَفَرَرْتُ مِنكُمْ لَمَّا خِفْتُكُمْ فَوَهَبَ لِى رَبِّى حُكْمًا وَجَعَلَنِى مِنَ ٱلْمُرْسَلِينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmcmliv{وَتِلْكَ نِعْمَةٌ تَمُنُّهَا عَلَىَّ أَنْ عَبَّدتَّ بَنِىٓ إِسْرَٰٓءِيلَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmcmlv{قَالَ فِرْعَوْنُ وَمَا رَبُّ ٱلْعَٰلَمِينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmcmlvi{قَالَ رَبُّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَآ إِن كُنتُم مُّوقِنِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmcmlvii{قَالَ لِمَنْ حَوْلَهُۥٓ أَلَا تَسْتَمِعُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmcmlviii{قَالَ رَبُّكُمْ وَرَبُّ ءَابَآئِكُمُ ٱلْأَوَّلِينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmcmlix{قَالَ إِنَّ رَسُولَكُمُ ٱلَّذِىٓ أُرْسِلَ إِلَيْكُمْ لَمَجْنُونٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmcmlx{قَالَ رَبُّ ٱلْمَشْرِقِ وَٱلْمَغْرِبِ وَمَا بَيْنَهُمَآ إِن كُنتُمْ تَعْقِلُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmcmlxi{قَالَ لَئِنِ ٱتَّخَذْتَ إِلَٰهًا غَيْرِى لَأَجْعَلَنَّكَ مِنَ ٱلْمَسْجُونِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmcmlxii{قَالَ أَوَلَوْ جِئْتُكَ بِشَىْءٍ مُّبِينٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmcmlxiii{قَالَ فَأْتِ بِهِۦٓ إِن كُنتَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmcmlxiv{فَأَلْقَىٰ عَصَاهُ فَإِذَا هِىَ ثُعْبَانٌ مُّبِينٌ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmcmlxv{وَنَزَعَ يَدَهُۥ فَإِذَا هِىَ بَيْضَآءُ لِلنَّٰظِرِينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmcmlxvi{قَالَ لِلْمَلَإِ حَوْلَهُۥٓ إِنَّ هَٰذَا لَسَٰحِرٌ عَلِيمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmcmlxvii{يُرِيدُ أَن يُخْرِجَكُم مِّنْ أَرْضِكُم بِسِحْرِهِۦ فَمَاذَا تَأْمُرُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmcmlxviii{قَالُوٓا۟ أَرْجِهْ وَأَخَاهُ وَٱبْعَثْ فِى ٱلْمَدَآئِنِ حَٰشِرِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmcmlxix{يَأْتُوكَ بِكُلِّ سَحَّارٍ عَلِيمٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmcmlxx{فَجُمِعَ ٱلسَّحَرَةُ لِمِيقَٰتِ يَوْمٍ مَّعْلُومٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmcmlxxi{وَقِيلَ لِلنَّاسِ هَلْ أَنتُم مُّجْتَمِعُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmcmlxxii{لَعَلَّنَا نَتَّبِعُ ٱلسَّحَرَةَ إِن كَانُوا۟ هُمُ ٱلْغَٰلِبِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmcmlxxiii{فَلَمَّا جَآءَ ٱلسَّحَرَةُ قَالُوا۟ لِفِرْعَوْنَ أَئِنَّ لَنَا لَأَجْرًا إِن كُنَّا نَحْنُ ٱلْغَٰلِبِينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmcmlxxiv{قَالَ نَعَمْ وَإِنَّكُمْ إِذًا لَّمِنَ ٱلْمُقَرَّبِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmcmlxxv{قَالَ لَهُم مُّوسَىٰٓ أَلْقُوا۟ مَآ أَنتُم مُّلْقُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmcmlxxvi{فَأَلْقَوْا۟ حِبَالَهُمْ وَعِصِيَّهُمْ وَقَالُوا۟ بِعِزَّةِ فِرْعَوْنَ إِنَّا لَنَحْنُ ٱلْغَٰلِبُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmcmlxxvii{فَأَلْقَىٰ مُوسَىٰ عَصَاهُ فَإِذَا هِىَ تَلْقَفُ مَا يَأْفِكُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmcmlxxviii{فَأُلْقِىَ ٱلسَّحَرَةُ سَٰجِدِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmcmlxxix{قَالُوٓا۟ ءَامَنَّا بِرَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmcmlxxx{رَبِّ مُوسَىٰ وَهَٰرُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmcmlxxxi{قَالَ ءَامَنتُمْ لَهُۥ قَبْلَ أَنْ ءَاذَنَ لَكُمْ إِنَّهُۥ لَكَبِيرُكُمُ ٱلَّذِى عَلَّمَكُمُ ٱلسِّحْرَ فَلَسَوْفَ تَعْلَمُونَ لَأُقَطِّعَنَّ أَيْدِيَكُمْ وَأَرْجُلَكُم مِّنْ خِلَٰفٍ وَلَأُصَلِّبَنَّكُمْ أَجْمَعِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcmlxxxii{قَالُوا۟ لَا ضَيْرَ إِنَّآ إِلَىٰ رَبِّنَا مُنقَلِبُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcmlxxxiii{إِنَّا نَطْمَعُ أَن يَغْفِرَ لَنَا رَبُّنَا خَطَٰيَٰنَآ أَن كُنَّآ أَوَّلَ ٱلْمُؤْمِنِينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcmlxxxiv{وَأَوْحَيْنَآ إِلَىٰ مُوسَىٰٓ أَنْ أَسْرِ بِعِبَادِىٓ إِنَّكُم مُّتَّبَعُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcmlxxxv{فَأَرْسَلَ فِرْعَوْنُ فِى ٱلْمَدَآئِنِ حَٰشِرِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcmlxxxvi{إِنَّ هَٰٓؤُلَآءِ لَشِرْذِمَةٌ قَلِيلُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcmlxxxvii{وَإِنَّهُمْ لَنَا لَغَآئِظُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcmlxxxviii{وَإِنَّا لَجَمِيعٌ حَٰذِرُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcmlxxxix{فَأَخْرَجْنَٰهُم مِّن جَنَّٰتٍ وَعُيُونٍ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcmxc{وَكُنُوزٍ وَمَقَامٍ كَرِيمٍ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcmxci{كَذَٰلِكَ وَأَوْرَثْنَٰهَا بَنِىٓ إِسْرَٰٓءِيلَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcmxcii{فَأَتْبَعُوهُم مُّشْرِقِينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcmxciii{فَلَمَّا تَرَٰٓءَا ٱلْجَمْعَانِ قَالَ أَصْحَٰبُ مُوسَىٰٓ إِنَّا لَمُدْرَكُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcmxciv{قَالَ كَلَّآ إِنَّ مَعِىَ رَبِّى سَيَهْدِينِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcmxcv{فَأَوْحَيْنَآ إِلَىٰ مُوسَىٰٓ أَنِ ٱضْرِب بِّعَصَاكَ ٱلْبَحْرَ فَٱنفَلَقَ فَكَانَ كُلُّ فِرْقٍ كَٱلطَّوْدِ ٱلْعَظِيمِ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcmxcvi{وَأَزْلَفْنَا ثَمَّ ٱلْءَاخَرِينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcmxcvii{وَأَنجَيْنَا مُوسَىٰ وَمَن مَّعَهُۥٓ أَجْمَعِينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcmxcviii{ثُمَّ أَغْرَقْنَا ٱلْءَاخَرِينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcmxcix{إِنَّ فِى ذَٰلِكَ لَءَايَةً وَمَا كَانَ أَكْثَرُهُم مُّؤْمِنِينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmm{وَإِنَّ رَبَّكَ لَهُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmi{وَٱتْلُ عَلَيْهِمْ نَبَأَ إِبْرَٰهِيمَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmii{إِذْ قَالَ لِأَبِيهِ وَقَوْمِهِۦ مَا تَعْبُدُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmiii{قَالُوا۟ نَعْبُدُ أَصْنَامًا فَنَظَلُّ لَهَا عَٰكِفِينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmiv{قَالَ هَلْ يَسْمَعُونَكُمْ إِذْ تَدْعُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmv{أَوْ يَنفَعُونَكُمْ أَوْ يَضُرُّونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmvi{قَالُوا۟ بَلْ وَجَدْنَآ ءَابَآءَنَا كَذَٰلِكَ يَفْعَلُونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmvii{قَالَ أَفَرَءَيْتُم مَّا كُنتُمْ تَعْبُدُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmviii{أَنتُمْ وَءَابَآؤُكُمُ ٱلْأَقْدَمُونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmix{فَإِنَّهُمْ عَدُوٌّ لِّىٓ إِلَّا رَبَّ ٱلْعَٰلَمِينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmx{ٱلَّذِى خَلَقَنِى فَهُوَ يَهْدِينِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmxi{وَٱلَّذِى هُوَ يُطْعِمُنِى وَيَسْقِينِ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmxii{وَإِذَا مَرِضْتُ فَهُوَ يَشْفِينِ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmxiii{وَٱلَّذِى يُمِيتُنِى ثُمَّ يُحْيِينِ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmxiv{وَٱلَّذِىٓ أَطْمَعُ أَن يَغْفِرَ لِى خَطِيٓـَٔتِى يَوْمَ ٱلدِّينِ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmxv{رَبِّ هَبْ لِى حُكْمًا وَأَلْحِقْنِى بِٱلصَّٰلِحِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmxvi{وَٱجْعَل لِّى لِسَانَ صِدْقٍ فِى ٱلْءَاخِرِينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmxvii{وَٱجْعَلْنِى مِن وَرَثَةِ جَنَّةِ ٱلنَّعِيمِ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmxviii{وَٱغْفِرْ لِأَبِىٓ إِنَّهُۥ كَانَ مِنَ ٱلضَّآلِّينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmxix{وَلَا تُخْزِنِى يَوْمَ يُبْعَثُونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmxx{يَوْمَ لَا يَنفَعُ مَالٌ وَلَا بَنُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmxxi{إِلَّا مَنْ أَتَى ٱللَّهَ بِقَلْبٍ سَلِيمٍ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmxxii{وَأُزْلِفَتِ ٱلْجَنَّةُ لِلْمُتَّقِينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmxxiii{وَبُرِّزَتِ ٱلْجَحِيمُ لِلْغَاوِينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmxxiv{وَقِيلَ لَهُمْ أَيْنَ مَا كُنتُمْ تَعْبُدُونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmxxv{مِن دُونِ ٱللَّهِ هَلْ يَنصُرُونَكُمْ أَوْ يَنتَصِرُونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmxxvi{فَكُبْكِبُوا۟ فِيهَا هُمْ وَٱلْغَاوُۥنَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmmxxvii{وَجُنُودُ إِبْلِيسَ أَجْمَعُونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmmxxviii{قَالُوا۟ وَهُمْ فِيهَا يَخْتَصِمُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmmxxix{تَٱللَّهِ إِن كُنَّا لَفِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmmxxx{إِذْ نُسَوِّيكُم بِرَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmmxxxi{وَمَآ أَضَلَّنَآ إِلَّا ٱلْمُجْرِمُونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmmxxxii{فَمَا لَنَا مِن شَٰفِعِينَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmmxxxiii{وَلَا صَدِيقٍ حَمِيمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmmxxxiv{فَلَوْ أَنَّ لَنَا كَرَّةً فَنَكُونَ مِنَ ٱلْمُؤْمِنِينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmmxxxv{إِنَّ فِى ذَٰلِكَ لَءَايَةً وَمَا كَانَ أَكْثَرُهُم مُّؤْمِنِينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmmxxxvi{وَإِنَّ رَبَّكَ لَهُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmmxxxvii{كَذَّبَتْ قَوْمُ نُوحٍ ٱلْمُرْسَلِينَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmmxxxviii{إِذْ قَالَ لَهُمْ أَخُوهُمْ نُوحٌ أَلَا تَتَّقُونَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmmxxxix{إِنِّى لَكُمْ رَسُولٌ أَمِينٌ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmmxl{فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmmxli{وَمَآ أَسْـَٔلُكُمْ عَلَيْهِ مِنْ أَجْرٍ إِنْ أَجْرِىَ إِلَّا عَلَىٰ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmmxlii{فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmmxliii{قَالُوٓا۟ أَنُؤْمِنُ لَكَ وَٱتَّبَعَكَ ٱلْأَرْذَلُونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmmxliv{قَالَ وَمَا عِلْمِى بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmmxlv{إِنْ حِسَابُهُمْ إِلَّا عَلَىٰ رَبِّى لَوْ تَشْعُرُونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmmxlvi{وَمَآ أَنَا۠ بِطَارِدِ ٱلْمُؤْمِنِينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmmxlvii{إِنْ أَنَا۠ إِلَّا نَذِيرٌ مُّبِينٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmmxlviii{قَالُوا۟ لَئِن لَّمْ تَنتَهِ يَٰنُوحُ لَتَكُونَنَّ مِنَ ٱلْمَرْجُومِينَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmmxlix{قَالَ رَبِّ إِنَّ قَوْمِى كَذَّبُونِ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmml{فَٱفْتَحْ بَيْنِى وَبَيْنَهُمْ فَتْحًا وَنَجِّنِى وَمَن مَّعِىَ مِنَ ٱلْمُؤْمِنِينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmmli{فَأَنجَيْنَٰهُ وَمَن مَّعَهُۥ فِى ٱلْفُلْكِ ٱلْمَشْحُونِ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmmlii{ثُمَّ أَغْرَقْنَا بَعْدُ ٱلْبَاقِينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmmliii{إِنَّ فِى ذَٰلِكَ لَءَايَةً وَمَا كَانَ أَكْثَرُهُم مُّؤْمِنِينَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmmliv{وَإِنَّ رَبَّكَ لَهُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmmlv{كَذَّبَتْ عَادٌ ٱلْمُرْسَلِينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmmlvi{إِذْ قَالَ لَهُمْ أَخُوهُمْ هُودٌ أَلَا تَتَّقُونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmmlvii{إِنِّى لَكُمْ رَسُولٌ أَمِينٌ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmmlviii{فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmmlix{وَمَآ أَسْـَٔلُكُمْ عَلَيْهِ مِنْ أَجْرٍ إِنْ أَجْرِىَ إِلَّا عَلَىٰ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmmlx{أَتَبْنُونَ بِكُلِّ رِيعٍ ءَايَةً تَعْبَثُونَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmmlxi{وَتَتَّخِذُونَ مَصَانِعَ لَعَلَّكُمْ تَخْلُدُونَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mmmlxii{وَإِذَا بَطَشْتُم بَطَشْتُمْ جَبَّارِينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mmmlxiii{فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mmmlxiv{وَٱتَّقُوا۟ ٱلَّذِىٓ أَمَدَّكُم بِمَا تَعْلَمُونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mmmlxv{أَمَدَّكُم بِأَنْعَٰمٍ وَبَنِينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mmmlxvi{وَجَنَّٰتٍ وَعُيُونٍ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mmmlxvii{إِنِّىٓ أَخَافُ عَلَيْكُمْ عَذَابَ يَوْمٍ عَظِيمٍ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mmmlxviii{قَالُوا۟ سَوَآءٌ عَلَيْنَآ أَوَعَظْتَ أَمْ لَمْ تَكُن مِّنَ ٱلْوَٰعِظِينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@mmmlxix{إِنْ هَٰذَآ إِلَّا خُلُقُ ٱلْأَوَّلِينَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@mmmlxx{وَمَا نَحْنُ بِمُعَذَّبِينَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@mmmlxxi{فَكَذَّبُوهُ فَأَهْلَكْنَٰهُمْ إِنَّ فِى ذَٰلِكَ لَءَايَةً وَمَا كَانَ أَكْثَرُهُم مُّؤْمِنِينَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@mmmlxxii{وَإِنَّ رَبَّكَ لَهُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@mmmlxxiii{كَذَّبَتْ ثَمُودُ ٱلْمُرْسَلِينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@mmmlxxiv{إِذْ قَالَ لَهُمْ أَخُوهُمْ صَٰلِحٌ أَلَا تَتَّقُونَ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@mmmlxxv{إِنِّى لَكُمْ رَسُولٌ أَمِينٌ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@mmmlxxvi{فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@mmmlxxvii{وَمَآ أَسْـَٔلُكُمْ عَلَيْهِ مِنْ أَجْرٍ إِنْ أَجْرِىَ إِلَّا عَلَىٰ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@mmmlxxviii{أَتُتْرَكُونَ فِى مَا هَٰهُنَآ ءَامِنِينَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@mmmlxxix{فِى جَنَّٰتٍ وَعُيُونٍ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@mmmlxxx{وَزُرُوعٍ وَنَخْلٍ طَلْعُهَا هَضِيمٌ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@mmmlxxxi{وَتَنْحِتُونَ مِنَ ٱلْجِبَالِ بُيُوتًا فَٰرِهِينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@mmmlxxxii{فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@mmmlxxxiii{وَلَا تُطِيعُوٓا۟ أَمْرَ ٱلْمُسْرِفِينَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@mmmlxxxiv{ٱلَّذِينَ يُفْسِدُونَ فِى ٱلْأَرْضِ وَلَا يُصْلِحُونَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@mmmlxxxv{قَالُوٓا۟ إِنَّمَآ أَنتَ مِنَ ٱلْمُسَحَّرِينَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@mmmlxxxvi{مَآ أَنتَ إِلَّا بَشَرٌ مِّثْلُنَا فَأْتِ بِـَٔايَةٍ إِن كُنتَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@mmmlxxxvii{قَالَ هَٰذِهِۦ نَاقَةٌ لَّهَا شِرْبٌ وَلَكُمْ شِرْبُ يَوْمٍ مَّعْلُومٍ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@mmmlxxxviii{وَلَا تَمَسُّوهَا بِسُوٓءٍ فَيَأْخُذَكُمْ عَذَابُ يَوْمٍ عَظِيمٍ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@mmmlxxxix{فَعَقَرُوهَا فَأَصْبَحُوا۟ نَٰدِمِينَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@mmmxc{فَأَخَذَهُمُ ٱلْعَذَابُ إِنَّ فِى ذَٰلِكَ لَءَايَةً وَمَا كَانَ أَكْثَرُهُم مُّؤْمِنِينَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@mmmxci{وَإِنَّ رَبَّكَ لَهُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@mmmxcii{كَذَّبَتْ قَوْمُ لُوطٍ ٱلْمُرْسَلِينَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@mmmxciii{إِذْ قَالَ لَهُمْ أَخُوهُمْ لُوطٌ أَلَا تَتَّقُونَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@mmmxciv{إِنِّى لَكُمْ رَسُولٌ أَمِينٌ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@mmmxcv{فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@mmmxcvi{وَمَآ أَسْـَٔلُكُمْ عَلَيْهِ مِنْ أَجْرٍ إِنْ أَجْرِىَ إِلَّا عَلَىٰ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@mmmxcvii{أَتَأْتُونَ ٱلذُّكْرَانَ مِنَ ٱلْعَٰلَمِينَ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@mmmxcviii{وَتَذَرُونَ مَا خَلَقَ لَكُمْ رَبُّكُم مِّنْ أَزْوَٰجِكُم بَلْ أَنتُمْ قَوْمٌ عَادُونَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@mmmxcix{قَالُوا۟ لَئِن لَّمْ تَنتَهِ يَٰلُوطُ لَتَكُونَنَّ مِنَ ٱلْمُخْرَجِينَ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@mmmc{قَالَ إِنِّى لِعَمَلِكُم مِّنَ ٱلْقَالِينَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@mmmci{رَبِّ نَجِّنِى وَأَهْلِى مِمَّا يَعْمَلُونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@mmmcii{فَنَجَّيْنَٰهُ وَأَهْلَهُۥٓ أَجْمَعِينَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@mmmciii{إِلَّا عَجُوزًا فِى ٱلْغَٰبِرِينَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@mmmciv{ثُمَّ دَمَّرْنَا ٱلْءَاخَرِينَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@mmmcv{وَأَمْطَرْنَا عَلَيْهِم مَّطَرًا فَسَآءَ مَطَرُ ٱلْمُنذَرِينَ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@mmmcvi{إِنَّ فِى ذَٰلِكَ لَءَايَةً وَمَا كَانَ أَكْثَرُهُم مُّؤْمِنِينَ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@mmmcvii{وَإِنَّ رَبَّكَ لَهُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@mmmcviii{كَذَّبَ أَصْحَٰبُ لْـَٔيْكَةِ ٱلْمُرْسَلِينَ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@mmmcix{إِذْ قَالَ لَهُمْ شُعَيْبٌ أَلَا تَتَّقُونَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@mmmcx{إِنِّى لَكُمْ رَسُولٌ أَمِينٌ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@mmmcxi{فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@mmmcxii{وَمَآ أَسْـَٔلُكُمْ عَلَيْهِ مِنْ أَجْرٍ إِنْ أَجْرِىَ إِلَّا عَلَىٰ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@mmmcxiii{أَوْفُوا۟ ٱلْكَيْلَ وَلَا تَكُونُوا۟ مِنَ ٱلْمُخْسِرِينَ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@mmmcxiv{وَزِنُوا۟ بِٱلْقِسْطَاسِ ٱلْمُسْتَقِيمِ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@mmmcxv{وَلَا تَبْخَسُوا۟ ٱلنَّاسَ أَشْيَآءَهُمْ وَلَا تَعْثَوْا۟ فِى ٱلْأَرْضِ مُفْسِدِينَ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@mmmcxvi{وَٱتَّقُوا۟ ٱلَّذِى خَلَقَكُمْ وَٱلْجِبِلَّةَ ٱلْأَوَّلِينَ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@mmmcxvii{قَالُوٓا۟ إِنَّمَآ أَنتَ مِنَ ٱلْمُسَحَّرِينَ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@mmmcxviii{وَمَآ أَنتَ إِلَّا بَشَرٌ مِّثْلُنَا وَإِن نَّظُنُّكَ لَمِنَ ٱلْكَٰذِبِينَ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@mmmcxix{فَأَسْقِطْ عَلَيْنَا كِسَفًا مِّنَ ٱلسَّمَآءِ إِن كُنتَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@mmmcxx{قَالَ رَبِّىٓ أَعْلَمُ بِمَا تَعْمَلُونَ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@mmmcxxi{فَكَذَّبُوهُ فَأَخَذَهُمْ عَذَابُ يَوْمِ ٱلظُّلَّةِ إِنَّهُۥ كَانَ عَذَابَ يَوْمٍ عَظِيمٍ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@mmmcxxii{إِنَّ فِى ذَٰلِكَ لَءَايَةً وَمَا كَانَ أَكْثَرُهُم مُّؤْمِنِينَ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@mmmcxxiii{وَإِنَّ رَبَّكَ لَهُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@mmmcxxiv{وَإِنَّهُۥ لَتَنزِيلُ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@mmmcxxv{نَزَلَ بِهِ ٱلرُّوحُ ٱلْأَمِينُ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@mmmcxxvi{عَلَىٰ قَلْبِكَ لِتَكُونَ مِنَ ٱلْمُنذِرِينَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@mmmcxxvii{بِلِسَانٍ عَرَبِىٍّ مُّبِينٍ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@mmmcxxviii{وَإِنَّهُۥ لَفِى زُبُرِ ٱلْأَوَّلِينَ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@mmmcxxix{أَوَلَمْ يَكُن لَّهُمْ ءَايَةً أَن يَعْلَمَهُۥ عُلَمَٰٓؤُا۟ بَنِىٓ إِسْرَٰٓءِيلَ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@mmmcxxx{وَلَوْ نَزَّلْنَٰهُ عَلَىٰ بَعْضِ ٱلْأَعْجَمِينَ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@mmmcxxxi{فَقَرَأَهُۥ عَلَيْهِم مَّا كَانُوا۟ بِهِۦ مُؤْمِنِينَ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@mmmcxxxii{كَذَٰلِكَ سَلَكْنَٰهُ فِى قُلُوبِ ٱلْمُجْرِمِينَ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@mmmcxxxiii{لَا يُؤْمِنُونَ بِهِۦ حَتَّىٰ يَرَوُا۟ ٱلْعَذَابَ ٱلْأَلِيمَ\qt@no{﴿٢٠١﴾}}
\qt@newcmd\qurantext@mmmcxxxiv{فَيَأْتِيَهُم بَغْتَةً وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿٢٠٢﴾}}
\qt@newcmd\qurantext@mmmcxxxv{فَيَقُولُوا۟ هَلْ نَحْنُ مُنظَرُونَ\qt@no{﴿٢٠٣﴾}}
\qt@newcmd\qurantext@mmmcxxxvi{أَفَبِعَذَابِنَا يَسْتَعْجِلُونَ\qt@no{﴿٢٠٤﴾}}
\qt@newcmd\qurantext@mmmcxxxvii{أَفَرَءَيْتَ إِن مَّتَّعْنَٰهُمْ سِنِينَ\qt@no{﴿٢٠٥﴾}}
\qt@newcmd\qurantext@mmmcxxxviii{ثُمَّ جَآءَهُم مَّا كَانُوا۟ يُوعَدُونَ\qt@no{﴿٢٠٦﴾}}
\qt@newcmd\qurantext@mmmcxxxix{مَآ أَغْنَىٰ عَنْهُم مَّا كَانُوا۟ يُمَتَّعُونَ\qt@no{﴿٢٠٧﴾}}
\qt@newcmd\qurantext@mmmcxl{وَمَآ أَهْلَكْنَا مِن قَرْيَةٍ إِلَّا لَهَا مُنذِرُونَ\qt@no{﴿٢٠٨﴾}}
\qt@newcmd\qurantext@mmmcxli{ذِكْرَىٰ وَمَا كُنَّا ظَٰلِمِينَ\qt@no{﴿٢٠٩﴾}}
\qt@newcmd\qurantext@mmmcxlii{وَمَا تَنَزَّلَتْ بِهِ ٱلشَّيَٰطِينُ\qt@no{﴿٢١٠﴾}}
\qt@newcmd\qurantext@mmmcxliii{وَمَا يَنۢبَغِى لَهُمْ وَمَا يَسْتَطِيعُونَ\qt@no{﴿٢١١﴾}}
\qt@newcmd\qurantext@mmmcxliv{إِنَّهُمْ عَنِ ٱلسَّمْعِ لَمَعْزُولُونَ\qt@no{﴿٢١٢﴾}}
\qt@newcmd\qurantext@mmmcxlv{فَلَا تَدْعُ مَعَ ٱللَّهِ إِلَٰهًا ءَاخَرَ فَتَكُونَ مِنَ ٱلْمُعَذَّبِينَ\qt@no{﴿٢١٣﴾}}
\qt@newcmd\qurantext@mmmcxlvi{وَأَنذِرْ عَشِيرَتَكَ ٱلْأَقْرَبِينَ\qt@no{﴿٢١٤﴾}}
\qt@newcmd\qurantext@mmmcxlvii{وَٱخْفِضْ جَنَاحَكَ لِمَنِ ٱتَّبَعَكَ مِنَ ٱلْمُؤْمِنِينَ\qt@no{﴿٢١٥﴾}}
\qt@newcmd\qurantext@mmmcxlviii{فَإِنْ عَصَوْكَ فَقُلْ إِنِّى بَرِىٓءٌ مِّمَّا تَعْمَلُونَ\qt@no{﴿٢١٦﴾}}
\qt@newcmd\qurantext@mmmcxlix{وَتَوَكَّلْ عَلَى ٱلْعَزِيزِ ٱلرَّحِيمِ\qt@no{﴿٢١٧﴾}}
\qt@newcmd\qurantext@mmmcl{ٱلَّذِى يَرَىٰكَ حِينَ تَقُومُ\qt@no{﴿٢١٨﴾}}
\qt@newcmd\qurantext@mmmcli{وَتَقَلُّبَكَ فِى ٱلسَّٰجِدِينَ\qt@no{﴿٢١٩﴾}}
\qt@newcmd\qurantext@mmmclii{إِنَّهُۥ هُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٢٢٠﴾}}
\qt@newcmd\qurantext@mmmcliii{هَلْ أُنَبِّئُكُمْ عَلَىٰ مَن تَنَزَّلُ ٱلشَّيَٰطِينُ\qt@no{﴿٢٢١﴾}}
\qt@newcmd\qurantext@mmmcliv{تَنَزَّلُ عَلَىٰ كُلِّ أَفَّاكٍ أَثِيمٍ\qt@no{﴿٢٢٢﴾}}
\qt@newcmd\qurantext@mmmclv{يُلْقُونَ ٱلسَّمْعَ وَأَكْثَرُهُمْ كَٰذِبُونَ\qt@no{﴿٢٢٣﴾}}
\qt@newcmd\qurantext@mmmclvi{وَٱلشُّعَرَآءُ يَتَّبِعُهُمُ ٱلْغَاوُۥنَ\qt@no{﴿٢٢٤﴾}}
\qt@newcmd\qurantext@mmmclvii{أَلَمْ تَرَ أَنَّهُمْ فِى كُلِّ وَادٍ يَهِيمُونَ\qt@no{﴿٢٢٥﴾}}
\qt@newcmd\qurantext@mmmclviii{وَأَنَّهُمْ يَقُولُونَ مَا لَا يَفْعَلُونَ\qt@no{﴿٢٢٦﴾}}
\qt@newcmd\qurantext@mmmclix{إِلَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ وَذَكَرُوا۟ ٱللَّهَ كَثِيرًا وَٱنتَصَرُوا۟ مِنۢ بَعْدِ مَا ظُلِمُوا۟ وَسَيَعْلَمُ ٱلَّذِينَ ظَلَمُوٓا۟ أَىَّ مُنقَلَبٍ يَنقَلِبُونَ\qt@no{﴿٢٢٧﴾}}
\qt@newcmd\qurantext@mmmclx{\basmalah طسٓ تِلْكَ ءَايَٰتُ ٱلْقُرْءَانِ وَكِتَابٍ مُّبِينٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmclxi{هُدًى وَبُشْرَىٰ لِلْمُؤْمِنِينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmclxii{ٱلَّذِينَ يُقِيمُونَ ٱلصَّلَوٰةَ وَيُؤْتُونَ ٱلزَّكَوٰةَ وَهُم بِٱلْءَاخِرَةِ هُمْ يُوقِنُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmclxiii{إِنَّ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ زَيَّنَّا لَهُمْ أَعْمَٰلَهُمْ فَهُمْ يَعْمَهُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmclxiv{أُو۟لَٰٓئِكَ ٱلَّذِينَ لَهُمْ سُوٓءُ ٱلْعَذَابِ وَهُمْ فِى ٱلْءَاخِرَةِ هُمُ ٱلْأَخْسَرُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmclxv{وَإِنَّكَ لَتُلَقَّى ٱلْقُرْءَانَ مِن لَّدُنْ حَكِيمٍ عَلِيمٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmclxvi{إِذْ قَالَ مُوسَىٰ لِأَهْلِهِۦٓ إِنِّىٓ ءَانَسْتُ نَارًا سَـَٔاتِيكُم مِّنْهَا بِخَبَرٍ أَوْ ءَاتِيكُم بِشِهَابٍ قَبَسٍ لَّعَلَّكُمْ تَصْطَلُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmclxvii{فَلَمَّا جَآءَهَا نُودِىَ أَنۢ بُورِكَ مَن فِى ٱلنَّارِ وَمَنْ حَوْلَهَا وَسُبْحَٰنَ ٱللَّهِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmclxviii{يَٰمُوسَىٰٓ إِنَّهُۥٓ أَنَا ٱللَّهُ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmclxix{وَأَلْقِ عَصَاكَ فَلَمَّا رَءَاهَا تَهْتَزُّ كَأَنَّهَا جَآنٌّ وَلَّىٰ مُدْبِرًا وَلَمْ يُعَقِّبْ يَٰمُوسَىٰ لَا تَخَفْ إِنِّى لَا يَخَافُ لَدَىَّ ٱلْمُرْسَلُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmclxx{إِلَّا مَن ظَلَمَ ثُمَّ بَدَّلَ حُسْنًۢا بَعْدَ سُوٓءٍ فَإِنِّى غَفُورٌ رَّحِيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmclxxi{وَأَدْخِلْ يَدَكَ فِى جَيْبِكَ تَخْرُجْ بَيْضَآءَ مِنْ غَيْرِ سُوٓءٍ فِى تِسْعِ ءَايَٰتٍ إِلَىٰ فِرْعَوْنَ وَقَوْمِهِۦٓ إِنَّهُمْ كَانُوا۟ قَوْمًا فَٰسِقِينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmclxxii{فَلَمَّا جَآءَتْهُمْ ءَايَٰتُنَا مُبْصِرَةً قَالُوا۟ هَٰذَا سِحْرٌ مُّبِينٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmclxxiii{وَجَحَدُوا۟ بِهَا وَٱسْتَيْقَنَتْهَآ أَنفُسُهُمْ ظُلْمًا وَعُلُوًّا فَٱنظُرْ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُفْسِدِينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmclxxiv{وَلَقَدْ ءَاتَيْنَا دَاوُۥدَ وَسُلَيْمَٰنَ عِلْمًا وَقَالَا ٱلْحَمْدُ لِلَّهِ ٱلَّذِى فَضَّلَنَا عَلَىٰ كَثِيرٍ مِّنْ عِبَادِهِ ٱلْمُؤْمِنِينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmclxxv{وَوَرِثَ سُلَيْمَٰنُ دَاوُۥدَ وَقَالَ يَٰٓأَيُّهَا ٱلنَّاسُ عُلِّمْنَا مَنطِقَ ٱلطَّيْرِ وَأُوتِينَا مِن كُلِّ شَىْءٍ إِنَّ هَٰذَا لَهُوَ ٱلْفَضْلُ ٱلْمُبِينُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmclxxvi{وَحُشِرَ لِسُلَيْمَٰنَ جُنُودُهُۥ مِنَ ٱلْجِنِّ وَٱلْإِنسِ وَٱلطَّيْرِ فَهُمْ يُوزَعُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmclxxvii{حَتَّىٰٓ إِذَآ أَتَوْا۟ عَلَىٰ وَادِ ٱلنَّمْلِ قَالَتْ نَمْلَةٌ يَٰٓأَيُّهَا ٱلنَّمْلُ ٱدْخُلُوا۟ مَسَٰكِنَكُمْ لَا يَحْطِمَنَّكُمْ سُلَيْمَٰنُ وَجُنُودُهُۥ وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmclxxviii{فَتَبَسَّمَ ضَاحِكًا مِّن قَوْلِهَا وَقَالَ رَبِّ أَوْزِعْنِىٓ أَنْ أَشْكُرَ نِعْمَتَكَ ٱلَّتِىٓ أَنْعَمْتَ عَلَىَّ وَعَلَىٰ وَٰلِدَىَّ وَأَنْ أَعْمَلَ صَٰلِحًا تَرْضَىٰهُ وَأَدْخِلْنِى بِرَحْمَتِكَ فِى عِبَادِكَ ٱلصَّٰلِحِينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmclxxix{وَتَفَقَّدَ ٱلطَّيْرَ فَقَالَ مَا لِىَ لَآ أَرَى ٱلْهُدْهُدَ أَمْ كَانَ مِنَ ٱلْغَآئِبِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmclxxx{لَأُعَذِّبَنَّهُۥ عَذَابًا شَدِيدًا أَوْ لَأَا۟ذْبَحَنَّهُۥٓ أَوْ لَيَأْتِيَنِّى بِسُلْطَٰنٍ مُّبِينٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmclxxxi{فَمَكَثَ غَيْرَ بَعِيدٍ فَقَالَ أَحَطتُ بِمَا لَمْ تُحِطْ بِهِۦ وَجِئْتُكَ مِن سَبَإٍۭ بِنَبَإٍ يَقِينٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmclxxxii{إِنِّى وَجَدتُّ ٱمْرَأَةً تَمْلِكُهُمْ وَأُوتِيَتْ مِن كُلِّ شَىْءٍ وَلَهَا عَرْشٌ عَظِيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmclxxxiii{وَجَدتُّهَا وَقَوْمَهَا يَسْجُدُونَ لِلشَّمْسِ مِن دُونِ ٱللَّهِ وَزَيَّنَ لَهُمُ ٱلشَّيْطَٰنُ أَعْمَٰلَهُمْ فَصَدَّهُمْ عَنِ ٱلسَّبِيلِ فَهُمْ لَا يَهْتَدُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmclxxxiv{أَلَّا يَسْجُدُوا۟ لِلَّهِ ٱلَّذِى يُخْرِجُ ٱلْخَبْءَ فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَيَعْلَمُ مَا تُخْفُونَ وَمَا تُعْلِنُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmclxxxv{ٱللَّهُ لَآ إِلَٰهَ إِلَّا هُوَ رَبُّ ٱلْعَرْشِ ٱلْعَظِيمِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmclxxxvi{قَالَ سَنَنظُرُ أَصَدَقْتَ أَمْ كُنتَ مِنَ ٱلْكَٰذِبِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmclxxxvii{ٱذْهَب بِّكِتَٰبِى هَٰذَا فَأَلْقِهْ إِلَيْهِمْ ثُمَّ تَوَلَّ عَنْهُمْ فَٱنظُرْ مَاذَا يَرْجِعُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmclxxxviii{قَالَتْ يَٰٓأَيُّهَا ٱلْمَلَؤُا۟ إِنِّىٓ أُلْقِىَ إِلَىَّ كِتَٰبٌ كَرِيمٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmclxxxix{إِنَّهُۥ مِن سُلَيْمَٰنَ وَإِنَّهُۥ بِسْمِ ٱللَّهِ ٱلرَّحْمَٰنِ ٱلرَّحِيمِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmcxc{أَلَّا تَعْلُوا۟ عَلَىَّ وَأْتُونِى مُسْلِمِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmcxci{قَالَتْ يَٰٓأَيُّهَا ٱلْمَلَؤُا۟ أَفْتُونِى فِىٓ أَمْرِى مَا كُنتُ قَاطِعَةً أَمْرًا حَتَّىٰ تَشْهَدُونِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmcxcii{قَالُوا۟ نَحْنُ أُو۟لُوا۟ قُوَّةٍ وَأُو۟لُوا۟ بَأْسٍ شَدِيدٍ وَٱلْأَمْرُ إِلَيْكِ فَٱنظُرِى مَاذَا تَأْمُرِينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmcxciii{قَالَتْ إِنَّ ٱلْمُلُوكَ إِذَا دَخَلُوا۟ قَرْيَةً أَفْسَدُوهَا وَجَعَلُوٓا۟ أَعِزَّةَ أَهْلِهَآ أَذِلَّةً وَكَذَٰلِكَ يَفْعَلُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmcxciv{وَإِنِّى مُرْسِلَةٌ إِلَيْهِم بِهَدِيَّةٍ فَنَاظِرَةٌۢ بِمَ يَرْجِعُ ٱلْمُرْسَلُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmcxcv{فَلَمَّا جَآءَ سُلَيْمَٰنَ قَالَ أَتُمِدُّونَنِ بِمَالٍ فَمَآ ءَاتَىٰنِۦَ ٱللَّهُ خَيْرٌ مِّمَّآ ءَاتَىٰكُم بَلْ أَنتُم بِهَدِيَّتِكُمْ تَفْرَحُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmcxcvi{ٱرْجِعْ إِلَيْهِمْ فَلَنَأْتِيَنَّهُم بِجُنُودٍ لَّا قِبَلَ لَهُم بِهَا وَلَنُخْرِجَنَّهُم مِّنْهَآ أَذِلَّةً وَهُمْ صَٰغِرُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmcxcvii{قَالَ يَٰٓأَيُّهَا ٱلْمَلَؤُا۟ أَيُّكُمْ يَأْتِينِى بِعَرْشِهَا قَبْلَ أَن يَأْتُونِى مُسْلِمِينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmcxcviii{قَالَ عِفْرِيتٌ مِّنَ ٱلْجِنِّ أَنَا۠ ءَاتِيكَ بِهِۦ قَبْلَ أَن تَقُومَ مِن مَّقَامِكَ وَإِنِّى عَلَيْهِ لَقَوِىٌّ أَمِينٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmcxcix{قَالَ ٱلَّذِى عِندَهُۥ عِلْمٌ مِّنَ ٱلْكِتَٰبِ أَنَا۠ ءَاتِيكَ بِهِۦ قَبْلَ أَن يَرْتَدَّ إِلَيْكَ طَرْفُكَ فَلَمَّا رَءَاهُ مُسْتَقِرًّا عِندَهُۥ قَالَ هَٰذَا مِن فَضْلِ رَبِّى لِيَبْلُوَنِىٓ ءَأَشْكُرُ أَمْ أَكْفُرُ وَمَن شَكَرَ فَإِنَّمَا يَشْكُرُ لِنَفْسِهِۦ وَمَن كَفَرَ فَإِنَّ رَبِّى غَنِىٌّ كَرِيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmcc{قَالَ نَكِّرُوا۟ لَهَا عَرْشَهَا نَنظُرْ أَتَهْتَدِىٓ أَمْ تَكُونُ مِنَ ٱلَّذِينَ لَا يَهْتَدُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmcci{فَلَمَّا جَآءَتْ قِيلَ أَهَٰكَذَا عَرْشُكِ قَالَتْ كَأَنَّهُۥ هُوَ وَأُوتِينَا ٱلْعِلْمَ مِن قَبْلِهَا وَكُنَّا مُسْلِمِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmccii{وَصَدَّهَا مَا كَانَت تَّعْبُدُ مِن دُونِ ٱللَّهِ إِنَّهَا كَانَتْ مِن قَوْمٍ كَٰفِرِينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmcciii{قِيلَ لَهَا ٱدْخُلِى ٱلصَّرْحَ فَلَمَّا رَأَتْهُ حَسِبَتْهُ لُجَّةً وَكَشَفَتْ عَن سَاقَيْهَا قَالَ إِنَّهُۥ صَرْحٌ مُّمَرَّدٌ مِّن قَوَارِيرَ قَالَتْ رَبِّ إِنِّى ظَلَمْتُ نَفْسِى وَأَسْلَمْتُ مَعَ سُلَيْمَٰنَ لِلَّهِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmcciv{وَلَقَدْ أَرْسَلْنَآ إِلَىٰ ثَمُودَ أَخَاهُمْ صَٰلِحًا أَنِ ٱعْبُدُوا۟ ٱللَّهَ فَإِذَا هُمْ فَرِيقَانِ يَخْتَصِمُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmccv{قَالَ يَٰقَوْمِ لِمَ تَسْتَعْجِلُونَ بِٱلسَّيِّئَةِ قَبْلَ ٱلْحَسَنَةِ لَوْلَا تَسْتَغْفِرُونَ ٱللَّهَ لَعَلَّكُمْ تُرْحَمُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmccvi{قَالُوا۟ ٱطَّيَّرْنَا بِكَ وَبِمَن مَّعَكَ قَالَ طَٰٓئِرُكُمْ عِندَ ٱللَّهِ بَلْ أَنتُمْ قَوْمٌ تُفْتَنُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmccvii{وَكَانَ فِى ٱلْمَدِينَةِ تِسْعَةُ رَهْطٍ يُفْسِدُونَ فِى ٱلْأَرْضِ وَلَا يُصْلِحُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmccviii{قَالُوا۟ تَقَاسَمُوا۟ بِٱللَّهِ لَنُبَيِّتَنَّهُۥ وَأَهْلَهُۥ ثُمَّ لَنَقُولَنَّ لِوَلِيِّهِۦ مَا شَهِدْنَا مَهْلِكَ أَهْلِهِۦ وَإِنَّا لَصَٰدِقُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmccix{وَمَكَرُوا۟ مَكْرًا وَمَكَرْنَا مَكْرًا وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmccx{فَٱنظُرْ كَيْفَ كَانَ عَٰقِبَةُ مَكْرِهِمْ أَنَّا دَمَّرْنَٰهُمْ وَقَوْمَهُمْ أَجْمَعِينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmccxi{فَتِلْكَ بُيُوتُهُمْ خَاوِيَةًۢ بِمَا ظَلَمُوٓا۟ إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّقَوْمٍ يَعْلَمُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmccxii{وَأَنجَيْنَا ٱلَّذِينَ ءَامَنُوا۟ وَكَانُوا۟ يَتَّقُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmccxiii{وَلُوطًا إِذْ قَالَ لِقَوْمِهِۦٓ أَتَأْتُونَ ٱلْفَٰحِشَةَ وَأَنتُمْ تُبْصِرُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmccxiv{أَئِنَّكُمْ لَتَأْتُونَ ٱلرِّجَالَ شَهْوَةً مِّن دُونِ ٱلنِّسَآءِ بَلْ أَنتُمْ قَوْمٌ تَجْهَلُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmccxv{فَمَا كَانَ جَوَابَ قَوْمِهِۦٓ إِلَّآ أَن قَالُوٓا۟ أَخْرِجُوٓا۟ ءَالَ لُوطٍ مِّن قَرْيَتِكُمْ إِنَّهُمْ أُنَاسٌ يَتَطَهَّرُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmccxvi{فَأَنجَيْنَٰهُ وَأَهْلَهُۥٓ إِلَّا ٱمْرَأَتَهُۥ قَدَّرْنَٰهَا مِنَ ٱلْغَٰبِرِينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmccxvii{وَأَمْطَرْنَا عَلَيْهِم مَّطَرًا فَسَآءَ مَطَرُ ٱلْمُنذَرِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmccxviii{قُلِ ٱلْحَمْدُ لِلَّهِ وَسَلَٰمٌ عَلَىٰ عِبَادِهِ ٱلَّذِينَ ٱصْطَفَىٰٓ ءَآللَّهُ خَيْرٌ أَمَّا يُشْرِكُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmccxix{أَمَّنْ خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَأَنزَلَ لَكُم مِّنَ ٱلسَّمَآءِ مَآءً فَأَنۢبَتْنَا بِهِۦ حَدَآئِقَ ذَاتَ بَهْجَةٍ مَّا كَانَ لَكُمْ أَن تُنۢبِتُوا۟ شَجَرَهَآ أَءِلَٰهٌ مَّعَ ٱللَّهِ بَلْ هُمْ قَوْمٌ يَعْدِلُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmccxx{أَمَّن جَعَلَ ٱلْأَرْضَ قَرَارًا وَجَعَلَ خِلَٰلَهَآ أَنْهَٰرًا وَجَعَلَ لَهَا رَوَٰسِىَ وَجَعَلَ بَيْنَ ٱلْبَحْرَيْنِ حَاجِزًا أَءِلَٰهٌ مَّعَ ٱللَّهِ بَلْ أَكْثَرُهُمْ لَا يَعْلَمُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmccxxi{أَمَّن يُجِيبُ ٱلْمُضْطَرَّ إِذَا دَعَاهُ وَيَكْشِفُ ٱلسُّوٓءَ وَيَجْعَلُكُمْ خُلَفَآءَ ٱلْأَرْضِ أَءِلَٰهٌ مَّعَ ٱللَّهِ قَلِيلًا مَّا تَذَكَّرُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmccxxii{أَمَّن يَهْدِيكُمْ فِى ظُلُمَٰتِ ٱلْبَرِّ وَٱلْبَحْرِ وَمَن يُرْسِلُ ٱلرِّيَٰحَ بُشْرًۢا بَيْنَ يَدَىْ رَحْمَتِهِۦٓ أَءِلَٰهٌ مَّعَ ٱللَّهِ تَعَٰلَى ٱللَّهُ عَمَّا يُشْرِكُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmccxxiii{أَمَّن يَبْدَؤُا۟ ٱلْخَلْقَ ثُمَّ يُعِيدُهُۥ وَمَن يَرْزُقُكُم مِّنَ ٱلسَّمَآءِ وَٱلْأَرْضِ أَءِلَٰهٌ مَّعَ ٱللَّهِ قُلْ هَاتُوا۟ بُرْهَٰنَكُمْ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmccxxiv{قُل لَّا يَعْلَمُ مَن فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ ٱلْغَيْبَ إِلَّا ٱللَّهُ وَمَا يَشْعُرُونَ أَيَّانَ يُبْعَثُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmccxxv{بَلِ ٱدَّٰرَكَ عِلْمُهُمْ فِى ٱلْءَاخِرَةِ بَلْ هُمْ فِى شَكٍّ مِّنْهَا بَلْ هُم مِّنْهَا عَمُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmccxxvi{وَقَالَ ٱلَّذِينَ كَفَرُوٓا۟ أَءِذَا كُنَّا تُرَٰبًا وَءَابَآؤُنَآ أَئِنَّا لَمُخْرَجُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmccxxvii{لَقَدْ وُعِدْنَا هَٰذَا نَحْنُ وَءَابَآؤُنَا مِن قَبْلُ إِنْ هَٰذَآ إِلَّآ أَسَٰطِيرُ ٱلْأَوَّلِينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmccxxviii{قُلْ سِيرُوا۟ فِى ٱلْأَرْضِ فَٱنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُجْرِمِينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmccxxix{وَلَا تَحْزَنْ عَلَيْهِمْ وَلَا تَكُن فِى ضَيْقٍ مِّمَّا يَمْكُرُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmccxxx{وَيَقُولُونَ مَتَىٰ هَٰذَا ٱلْوَعْدُ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmccxxxi{قُلْ عَسَىٰٓ أَن يَكُونَ رَدِفَ لَكُم بَعْضُ ٱلَّذِى تَسْتَعْجِلُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmccxxxii{وَإِنَّ رَبَّكَ لَذُو فَضْلٍ عَلَى ٱلنَّاسِ وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَشْكُرُونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmccxxxiii{وَإِنَّ رَبَّكَ لَيَعْلَمُ مَا تُكِنُّ صُدُورُهُمْ وَمَا يُعْلِنُونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmccxxxiv{وَمَا مِنْ غَآئِبَةٍ فِى ٱلسَّمَآءِ وَٱلْأَرْضِ إِلَّا فِى كِتَٰبٍ مُّبِينٍ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmccxxxv{إِنَّ هَٰذَا ٱلْقُرْءَانَ يَقُصُّ عَلَىٰ بَنِىٓ إِسْرَٰٓءِيلَ أَكْثَرَ ٱلَّذِى هُمْ فِيهِ يَخْتَلِفُونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmccxxxvi{وَإِنَّهُۥ لَهُدًى وَرَحْمَةٌ لِّلْمُؤْمِنِينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmccxxxvii{إِنَّ رَبَّكَ يَقْضِى بَيْنَهُم بِحُكْمِهِۦ وَهُوَ ٱلْعَزِيزُ ٱلْعَلِيمُ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmccxxxviii{فَتَوَكَّلْ عَلَى ٱللَّهِ إِنَّكَ عَلَى ٱلْحَقِّ ٱلْمُبِينِ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmccxxxix{إِنَّكَ لَا تُسْمِعُ ٱلْمَوْتَىٰ وَلَا تُسْمِعُ ٱلصُّمَّ ٱلدُّعَآءَ إِذَا وَلَّوْا۟ مُدْبِرِينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmccxl{وَمَآ أَنتَ بِهَٰدِى ٱلْعُمْىِ عَن ضَلَٰلَتِهِمْ إِن تُسْمِعُ إِلَّا مَن يُؤْمِنُ بِـَٔايَٰتِنَا فَهُم مُّسْلِمُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmccxli{وَإِذَا وَقَعَ ٱلْقَوْلُ عَلَيْهِمْ أَخْرَجْنَا لَهُمْ دَآبَّةً مِّنَ ٱلْأَرْضِ تُكَلِّمُهُمْ أَنَّ ٱلنَّاسَ كَانُوا۟ بِـَٔايَٰتِنَا لَا يُوقِنُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmccxlii{وَيَوْمَ نَحْشُرُ مِن كُلِّ أُمَّةٍ فَوْجًا مِّمَّن يُكَذِّبُ بِـَٔايَٰتِنَا فَهُمْ يُوزَعُونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmccxliii{حَتَّىٰٓ إِذَا جَآءُو قَالَ أَكَذَّبْتُم بِـَٔايَٰتِى وَلَمْ تُحِيطُوا۟ بِهَا عِلْمًا أَمَّاذَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmccxliv{وَوَقَعَ ٱلْقَوْلُ عَلَيْهِم بِمَا ظَلَمُوا۟ فَهُمْ لَا يَنطِقُونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmccxlv{أَلَمْ يَرَوْا۟ أَنَّا جَعَلْنَا ٱلَّيْلَ لِيَسْكُنُوا۟ فِيهِ وَٱلنَّهَارَ مُبْصِرًا إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmccxlvi{وَيَوْمَ يُنفَخُ فِى ٱلصُّورِ فَفَزِعَ مَن فِى ٱلسَّمَٰوَٰتِ وَمَن فِى ٱلْأَرْضِ إِلَّا مَن شَآءَ ٱللَّهُ وَكُلٌّ أَتَوْهُ دَٰخِرِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmccxlvii{وَتَرَى ٱلْجِبَالَ تَحْسَبُهَا جَامِدَةً وَهِىَ تَمُرُّ مَرَّ ٱلسَّحَابِ صُنْعَ ٱللَّهِ ٱلَّذِىٓ أَتْقَنَ كُلَّ شَىْءٍ إِنَّهُۥ خَبِيرٌۢ بِمَا تَفْعَلُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmccxlviii{مَن جَآءَ بِٱلْحَسَنَةِ فَلَهُۥ خَيْرٌ مِّنْهَا وَهُم مِّن فَزَعٍ يَوْمَئِذٍ ءَامِنُونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmccxlix{وَمَن جَآءَ بِٱلسَّيِّئَةِ فَكُبَّتْ وُجُوهُهُمْ فِى ٱلنَّارِ هَلْ تُجْزَوْنَ إِلَّا مَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmccl{إِنَّمَآ أُمِرْتُ أَنْ أَعْبُدَ رَبَّ هَٰذِهِ ٱلْبَلْدَةِ ٱلَّذِى حَرَّمَهَا وَلَهُۥ كُلُّ شَىْءٍ وَأُمِرْتُ أَنْ أَكُونَ مِنَ ٱلْمُسْلِمِينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmccli{وَأَنْ أَتْلُوَا۟ ٱلْقُرْءَانَ فَمَنِ ٱهْتَدَىٰ فَإِنَّمَا يَهْتَدِى لِنَفْسِهِۦ وَمَن ضَلَّ فَقُلْ إِنَّمَآ أَنَا۠ مِنَ ٱلْمُنذِرِينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmcclii{وَقُلِ ٱلْحَمْدُ لِلَّهِ سَيُرِيكُمْ ءَايَٰتِهِۦ فَتَعْرِفُونَهَا وَمَا رَبُّكَ بِغَٰفِلٍ عَمَّا تَعْمَلُونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmccliii{\basmalah طسٓمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmccliv{تِلْكَ ءَايَٰتُ ٱلْكِتَٰبِ ٱلْمُبِينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcclv{نَتْلُوا۟ عَلَيْكَ مِن نَّبَإِ مُوسَىٰ وَفِرْعَوْنَ بِٱلْحَقِّ لِقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcclvi{إِنَّ فِرْعَوْنَ عَلَا فِى ٱلْأَرْضِ وَجَعَلَ أَهْلَهَا شِيَعًا يَسْتَضْعِفُ طَآئِفَةً مِّنْهُمْ يُذَبِّحُ أَبْنَآءَهُمْ وَيَسْتَحْىِۦ نِسَآءَهُمْ إِنَّهُۥ كَانَ مِنَ ٱلْمُفْسِدِينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcclvii{وَنُرِيدُ أَن نَّمُنَّ عَلَى ٱلَّذِينَ ٱسْتُضْعِفُوا۟ فِى ٱلْأَرْضِ وَنَجْعَلَهُمْ أَئِمَّةً وَنَجْعَلَهُمُ ٱلْوَٰرِثِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcclviii{وَنُمَكِّنَ لَهُمْ فِى ٱلْأَرْضِ وَنُرِىَ فِرْعَوْنَ وَهَٰمَٰنَ وَجُنُودَهُمَا مِنْهُم مَّا كَانُوا۟ يَحْذَرُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcclix{وَأَوْحَيْنَآ إِلَىٰٓ أُمِّ مُوسَىٰٓ أَنْ أَرْضِعِيهِ فَإِذَا خِفْتِ عَلَيْهِ فَأَلْقِيهِ فِى ٱلْيَمِّ وَلَا تَخَافِى وَلَا تَحْزَنِىٓ إِنَّا رَآدُّوهُ إِلَيْكِ وَجَاعِلُوهُ مِنَ ٱلْمُرْسَلِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcclx{فَٱلْتَقَطَهُۥٓ ءَالُ فِرْعَوْنَ لِيَكُونَ لَهُمْ عَدُوًّا وَحَزَنًا إِنَّ فِرْعَوْنَ وَهَٰمَٰنَ وَجُنُودَهُمَا كَانُوا۟ خَٰطِـِٔينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcclxi{وَقَالَتِ ٱمْرَأَتُ فِرْعَوْنَ قُرَّتُ عَيْنٍ لِّى وَلَكَ لَا تَقْتُلُوهُ عَسَىٰٓ أَن يَنفَعَنَآ أَوْ نَتَّخِذَهُۥ وَلَدًا وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcclxii{وَأَصْبَحَ فُؤَادُ أُمِّ مُوسَىٰ فَٰرِغًا إِن كَادَتْ لَتُبْدِى بِهِۦ لَوْلَآ أَن رَّبَطْنَا عَلَىٰ قَلْبِهَا لِتَكُونَ مِنَ ٱلْمُؤْمِنِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcclxiii{وَقَالَتْ لِأُخْتِهِۦ قُصِّيهِ فَبَصُرَتْ بِهِۦ عَن جُنُبٍ وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcclxiv{وَحَرَّمْنَا عَلَيْهِ ٱلْمَرَاضِعَ مِن قَبْلُ فَقَالَتْ هَلْ أَدُلُّكُمْ عَلَىٰٓ أَهْلِ بَيْتٍ يَكْفُلُونَهُۥ لَكُمْ وَهُمْ لَهُۥ نَٰصِحُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcclxv{فَرَدَدْنَٰهُ إِلَىٰٓ أُمِّهِۦ كَىْ تَقَرَّ عَيْنُهَا وَلَا تَحْزَنَ وَلِتَعْلَمَ أَنَّ وَعْدَ ٱللَّهِ حَقٌّ وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَعْلَمُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcclxvi{وَلَمَّا بَلَغَ أَشُدَّهُۥ وَٱسْتَوَىٰٓ ءَاتَيْنَٰهُ حُكْمًا وَعِلْمًا وَكَذَٰلِكَ نَجْزِى ٱلْمُحْسِنِينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcclxvii{وَدَخَلَ ٱلْمَدِينَةَ عَلَىٰ حِينِ غَفْلَةٍ مِّنْ أَهْلِهَا فَوَجَدَ فِيهَا رَجُلَيْنِ يَقْتَتِلَانِ هَٰذَا مِن شِيعَتِهِۦ وَهَٰذَا مِنْ عَدُوِّهِۦ فَٱسْتَغَٰثَهُ ٱلَّذِى مِن شِيعَتِهِۦ عَلَى ٱلَّذِى مِنْ عَدُوِّهِۦ فَوَكَزَهُۥ مُوسَىٰ فَقَضَىٰ عَلَيْهِ قَالَ هَٰذَا مِنْ عَمَلِ ٱلشَّيْطَٰنِ إِنَّهُۥ عَدُوٌّ مُّضِلٌّ مُّبِينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcclxviii{قَالَ رَبِّ إِنِّى ظَلَمْتُ نَفْسِى فَٱغْفِرْ لِى فَغَفَرَ لَهُۥٓ إِنَّهُۥ هُوَ ٱلْغَفُورُ ٱلرَّحِيمُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcclxix{قَالَ رَبِّ بِمَآ أَنْعَمْتَ عَلَىَّ فَلَنْ أَكُونَ ظَهِيرًا لِّلْمُجْرِمِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcclxx{فَأَصْبَحَ فِى ٱلْمَدِينَةِ خَآئِفًا يَتَرَقَّبُ فَإِذَا ٱلَّذِى ٱسْتَنصَرَهُۥ بِٱلْأَمْسِ يَسْتَصْرِخُهُۥ قَالَ لَهُۥ مُوسَىٰٓ إِنَّكَ لَغَوِىٌّ مُّبِينٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcclxxi{فَلَمَّآ أَنْ أَرَادَ أَن يَبْطِشَ بِٱلَّذِى هُوَ عَدُوٌّ لَّهُمَا قَالَ يَٰمُوسَىٰٓ أَتُرِيدُ أَن تَقْتُلَنِى كَمَا قَتَلْتَ نَفْسًۢا بِٱلْأَمْسِ إِن تُرِيدُ إِلَّآ أَن تَكُونَ جَبَّارًا فِى ٱلْأَرْضِ وَمَا تُرِيدُ أَن تَكُونَ مِنَ ٱلْمُصْلِحِينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcclxxii{وَجَآءَ رَجُلٌ مِّنْ أَقْصَا ٱلْمَدِينَةِ يَسْعَىٰ قَالَ يَٰمُوسَىٰٓ إِنَّ ٱلْمَلَأَ يَأْتَمِرُونَ بِكَ لِيَقْتُلُوكَ فَٱخْرُجْ إِنِّى لَكَ مِنَ ٱلنَّٰصِحِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcclxxiii{فَخَرَجَ مِنْهَا خَآئِفًا يَتَرَقَّبُ قَالَ رَبِّ نَجِّنِى مِنَ ٱلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcclxxiv{وَلَمَّا تَوَجَّهَ تِلْقَآءَ مَدْيَنَ قَالَ عَسَىٰ رَبِّىٓ أَن يَهْدِيَنِى سَوَآءَ ٱلسَّبِيلِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcclxxv{وَلَمَّا وَرَدَ مَآءَ مَدْيَنَ وَجَدَ عَلَيْهِ أُمَّةً مِّنَ ٱلنَّاسِ يَسْقُونَ وَوَجَدَ مِن دُونِهِمُ ٱمْرَأَتَيْنِ تَذُودَانِ قَالَ مَا خَطْبُكُمَا قَالَتَا لَا نَسْقِى حَتَّىٰ يُصْدِرَ ٱلرِّعَآءُ وَأَبُونَا شَيْخٌ كَبِيرٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcclxxvi{فَسَقَىٰ لَهُمَا ثُمَّ تَوَلَّىٰٓ إِلَى ٱلظِّلِّ فَقَالَ رَبِّ إِنِّى لِمَآ أَنزَلْتَ إِلَىَّ مِنْ خَيْرٍ فَقِيرٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcclxxvii{فَجَآءَتْهُ إِحْدَىٰهُمَا تَمْشِى عَلَى ٱسْتِحْيَآءٍ قَالَتْ إِنَّ أَبِى يَدْعُوكَ لِيَجْزِيَكَ أَجْرَ مَا سَقَيْتَ لَنَا فَلَمَّا جَآءَهُۥ وَقَصَّ عَلَيْهِ ٱلْقَصَصَ قَالَ لَا تَخَفْ نَجَوْتَ مِنَ ٱلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcclxxviii{قَالَتْ إِحْدَىٰهُمَا يَٰٓأَبَتِ ٱسْتَـْٔجِرْهُ إِنَّ خَيْرَ مَنِ ٱسْتَـْٔجَرْتَ ٱلْقَوِىُّ ٱلْأَمِينُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcclxxix{قَالَ إِنِّىٓ أُرِيدُ أَنْ أُنكِحَكَ إِحْدَى ٱبْنَتَىَّ هَٰتَيْنِ عَلَىٰٓ أَن تَأْجُرَنِى ثَمَٰنِىَ حِجَجٍ فَإِنْ أَتْمَمْتَ عَشْرًا فَمِنْ عِندِكَ وَمَآ أُرِيدُ أَنْ أَشُقَّ عَلَيْكَ سَتَجِدُنِىٓ إِن شَآءَ ٱللَّهُ مِنَ ٱلصَّٰلِحِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcclxxx{قَالَ ذَٰلِكَ بَيْنِى وَبَيْنَكَ أَيَّمَا ٱلْأَجَلَيْنِ قَضَيْتُ فَلَا عُدْوَٰنَ عَلَىَّ وَٱللَّهُ عَلَىٰ مَا نَقُولُ وَكِيلٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcclxxxi{فَلَمَّا قَضَىٰ مُوسَى ٱلْأَجَلَ وَسَارَ بِأَهْلِهِۦٓ ءَانَسَ مِن جَانِبِ ٱلطُّورِ نَارًا قَالَ لِأَهْلِهِ ٱمْكُثُوٓا۟ إِنِّىٓ ءَانَسْتُ نَارًا لَّعَلِّىٓ ءَاتِيكُم مِّنْهَا بِخَبَرٍ أَوْ جَذْوَةٍ مِّنَ ٱلنَّارِ لَعَلَّكُمْ تَصْطَلُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmcclxxxii{فَلَمَّآ أَتَىٰهَا نُودِىَ مِن شَٰطِئِ ٱلْوَادِ ٱلْأَيْمَنِ فِى ٱلْبُقْعَةِ ٱلْمُبَٰرَكَةِ مِنَ ٱلشَّجَرَةِ أَن يَٰمُوسَىٰٓ إِنِّىٓ أَنَا ٱللَّهُ رَبُّ ٱلْعَٰلَمِينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmcclxxxiii{وَأَنْ أَلْقِ عَصَاكَ فَلَمَّا رَءَاهَا تَهْتَزُّ كَأَنَّهَا جَآنٌّ وَلَّىٰ مُدْبِرًا وَلَمْ يُعَقِّبْ يَٰمُوسَىٰٓ أَقْبِلْ وَلَا تَخَفْ إِنَّكَ مِنَ ٱلْءَامِنِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmcclxxxiv{ٱسْلُكْ يَدَكَ فِى جَيْبِكَ تَخْرُجْ بَيْضَآءَ مِنْ غَيْرِ سُوٓءٍ وَٱضْمُمْ إِلَيْكَ جَنَاحَكَ مِنَ ٱلرَّهْبِ فَذَٰنِكَ بُرْهَٰنَانِ مِن رَّبِّكَ إِلَىٰ فِرْعَوْنَ وَمَلَإِي۟هِۦٓ إِنَّهُمْ كَانُوا۟ قَوْمًا فَٰسِقِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmcclxxxv{قَالَ رَبِّ إِنِّى قَتَلْتُ مِنْهُمْ نَفْسًا فَأَخَافُ أَن يَقْتُلُونِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmcclxxxvi{وَأَخِى هَٰرُونُ هُوَ أَفْصَحُ مِنِّى لِسَانًا فَأَرْسِلْهُ مَعِىَ رِدْءًا يُصَدِّقُنِىٓ إِنِّىٓ أَخَافُ أَن يُكَذِّبُونِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmcclxxxvii{قَالَ سَنَشُدُّ عَضُدَكَ بِأَخِيكَ وَنَجْعَلُ لَكُمَا سُلْطَٰنًا فَلَا يَصِلُونَ إِلَيْكُمَا بِـَٔايَٰتِنَآ أَنتُمَا وَمَنِ ٱتَّبَعَكُمَا ٱلْغَٰلِبُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmcclxxxviii{فَلَمَّا جَآءَهُم مُّوسَىٰ بِـَٔايَٰتِنَا بَيِّنَٰتٍ قَالُوا۟ مَا هَٰذَآ إِلَّا سِحْرٌ مُّفْتَرًى وَمَا سَمِعْنَا بِهَٰذَا فِىٓ ءَابَآئِنَا ٱلْأَوَّلِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmcclxxxix{وَقَالَ مُوسَىٰ رَبِّىٓ أَعْلَمُ بِمَن جَآءَ بِٱلْهُدَىٰ مِنْ عِندِهِۦ وَمَن تَكُونُ لَهُۥ عَٰقِبَةُ ٱلدَّارِ إِنَّهُۥ لَا يُفْلِحُ ٱلظَّٰلِمُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmccxc{وَقَالَ فِرْعَوْنُ يَٰٓأَيُّهَا ٱلْمَلَأُ مَا عَلِمْتُ لَكُم مِّنْ إِلَٰهٍ غَيْرِى فَأَوْقِدْ لِى يَٰهَٰمَٰنُ عَلَى ٱلطِّينِ فَٱجْعَل لِّى صَرْحًا لَّعَلِّىٓ أَطَّلِعُ إِلَىٰٓ إِلَٰهِ مُوسَىٰ وَإِنِّى لَأَظُنُّهُۥ مِنَ ٱلْكَٰذِبِينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmccxci{وَٱسْتَكْبَرَ هُوَ وَجُنُودُهُۥ فِى ٱلْأَرْضِ بِغَيْرِ ٱلْحَقِّ وَظَنُّوٓا۟ أَنَّهُمْ إِلَيْنَا لَا يُرْجَعُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmccxcii{فَأَخَذْنَٰهُ وَجُنُودَهُۥ فَنَبَذْنَٰهُمْ فِى ٱلْيَمِّ فَٱنظُرْ كَيْفَ كَانَ عَٰقِبَةُ ٱلظَّٰلِمِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmccxciii{وَجَعَلْنَٰهُمْ أَئِمَّةً يَدْعُونَ إِلَى ٱلنَّارِ وَيَوْمَ ٱلْقِيَٰمَةِ لَا يُنصَرُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmccxciv{وَأَتْبَعْنَٰهُمْ فِى هَٰذِهِ ٱلدُّنْيَا لَعْنَةً وَيَوْمَ ٱلْقِيَٰمَةِ هُم مِّنَ ٱلْمَقْبُوحِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmccxcv{وَلَقَدْ ءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ مِنۢ بَعْدِ مَآ أَهْلَكْنَا ٱلْقُرُونَ ٱلْأُولَىٰ بَصَآئِرَ لِلنَّاسِ وَهُدًى وَرَحْمَةً لَّعَلَّهُمْ يَتَذَكَّرُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmccxcvi{وَمَا كُنتَ بِجَانِبِ ٱلْغَرْبِىِّ إِذْ قَضَيْنَآ إِلَىٰ مُوسَى ٱلْأَمْرَ وَمَا كُنتَ مِنَ ٱلشَّٰهِدِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmccxcvii{وَلَٰكِنَّآ أَنشَأْنَا قُرُونًا فَتَطَاوَلَ عَلَيْهِمُ ٱلْعُمُرُ وَمَا كُنتَ ثَاوِيًا فِىٓ أَهْلِ مَدْيَنَ تَتْلُوا۟ عَلَيْهِمْ ءَايَٰتِنَا وَلَٰكِنَّا كُنَّا مُرْسِلِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmccxcviii{وَمَا كُنتَ بِجَانِبِ ٱلطُّورِ إِذْ نَادَيْنَا وَلَٰكِن رَّحْمَةً مِّن رَّبِّكَ لِتُنذِرَ قَوْمًا مَّآ أَتَىٰهُم مِّن نَّذِيرٍ مِّن قَبْلِكَ لَعَلَّهُمْ يَتَذَكَّرُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmccxcix{وَلَوْلَآ أَن تُصِيبَهُم مُّصِيبَةٌۢ بِمَا قَدَّمَتْ أَيْدِيهِمْ فَيَقُولُوا۟ رَبَّنَا لَوْلَآ أَرْسَلْتَ إِلَيْنَا رَسُولًا فَنَتَّبِعَ ءَايَٰتِكَ وَنَكُونَ مِنَ ٱلْمُؤْمِنِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmccc{فَلَمَّا جَآءَهُمُ ٱلْحَقُّ مِنْ عِندِنَا قَالُوا۟ لَوْلَآ أُوتِىَ مِثْلَ مَآ أُوتِىَ مُوسَىٰٓ أَوَلَمْ يَكْفُرُوا۟ بِمَآ أُوتِىَ مُوسَىٰ مِن قَبْلُ قَالُوا۟ سِحْرَانِ تَظَٰهَرَا وَقَالُوٓا۟ إِنَّا بِكُلٍّ كَٰفِرُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmccci{قُلْ فَأْتُوا۟ بِكِتَٰبٍ مِّنْ عِندِ ٱللَّهِ هُوَ أَهْدَىٰ مِنْهُمَآ أَتَّبِعْهُ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmcccii{فَإِن لَّمْ يَسْتَجِيبُوا۟ لَكَ فَٱعْلَمْ أَنَّمَا يَتَّبِعُونَ أَهْوَآءَهُمْ وَمَنْ أَضَلُّ مِمَّنِ ٱتَّبَعَ هَوَىٰهُ بِغَيْرِ هُدًى مِّنَ ٱللَّهِ إِنَّ ٱللَّهَ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmccciii{وَلَقَدْ وَصَّلْنَا لَهُمُ ٱلْقَوْلَ لَعَلَّهُمْ يَتَذَكَّرُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmccciv{ٱلَّذِينَ ءَاتَيْنَٰهُمُ ٱلْكِتَٰبَ مِن قَبْلِهِۦ هُم بِهِۦ يُؤْمِنُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmcccv{وَإِذَا يُتْلَىٰ عَلَيْهِمْ قَالُوٓا۟ ءَامَنَّا بِهِۦٓ إِنَّهُ ٱلْحَقُّ مِن رَّبِّنَآ إِنَّا كُنَّا مِن قَبْلِهِۦ مُسْلِمِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmcccvi{أُو۟لَٰٓئِكَ يُؤْتَوْنَ أَجْرَهُم مَّرَّتَيْنِ بِمَا صَبَرُوا۟ وَيَدْرَءُونَ بِٱلْحَسَنَةِ ٱلسَّيِّئَةَ وَمِمَّا رَزَقْنَٰهُمْ يُنفِقُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmcccvii{وَإِذَا سَمِعُوا۟ ٱللَّغْوَ أَعْرَضُوا۟ عَنْهُ وَقَالُوا۟ لَنَآ أَعْمَٰلُنَا وَلَكُمْ أَعْمَٰلُكُمْ سَلَٰمٌ عَلَيْكُمْ لَا نَبْتَغِى ٱلْجَٰهِلِينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmcccviii{إِنَّكَ لَا تَهْدِى مَنْ أَحْبَبْتَ وَلَٰكِنَّ ٱللَّهَ يَهْدِى مَن يَشَآءُ وَهُوَ أَعْلَمُ بِٱلْمُهْتَدِينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmcccix{وَقَالُوٓا۟ إِن نَّتَّبِعِ ٱلْهُدَىٰ مَعَكَ نُتَخَطَّفْ مِنْ أَرْضِنَآ أَوَلَمْ نُمَكِّن لَّهُمْ حَرَمًا ءَامِنًا يُجْبَىٰٓ إِلَيْهِ ثَمَرَٰتُ كُلِّ شَىْءٍ رِّزْقًا مِّن لَّدُنَّا وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَعْلَمُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmcccx{وَكَمْ أَهْلَكْنَا مِن قَرْيَةٍۭ بَطِرَتْ مَعِيشَتَهَا فَتِلْكَ مَسَٰكِنُهُمْ لَمْ تُسْكَن مِّنۢ بَعْدِهِمْ إِلَّا قَلِيلًا وَكُنَّا نَحْنُ ٱلْوَٰرِثِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmcccxi{وَمَا كَانَ رَبُّكَ مُهْلِكَ ٱلْقُرَىٰ حَتَّىٰ يَبْعَثَ فِىٓ أُمِّهَا رَسُولًا يَتْلُوا۟ عَلَيْهِمْ ءَايَٰتِنَا وَمَا كُنَّا مُهْلِكِى ٱلْقُرَىٰٓ إِلَّا وَأَهْلُهَا ظَٰلِمُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmcccxii{وَمَآ أُوتِيتُم مِّن شَىْءٍ فَمَتَٰعُ ٱلْحَيَوٰةِ ٱلدُّنْيَا وَزِينَتُهَا وَمَا عِندَ ٱللَّهِ خَيْرٌ وَأَبْقَىٰٓ أَفَلَا تَعْقِلُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmcccxiii{أَفَمَن وَعَدْنَٰهُ وَعْدًا حَسَنًا فَهُوَ لَٰقِيهِ كَمَن مَّتَّعْنَٰهُ مَتَٰعَ ٱلْحَيَوٰةِ ٱلدُّنْيَا ثُمَّ هُوَ يَوْمَ ٱلْقِيَٰمَةِ مِنَ ٱلْمُحْضَرِينَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmcccxiv{وَيَوْمَ يُنَادِيهِمْ فَيَقُولُ أَيْنَ شُرَكَآءِىَ ٱلَّذِينَ كُنتُمْ تَزْعُمُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmcccxv{قَالَ ٱلَّذِينَ حَقَّ عَلَيْهِمُ ٱلْقَوْلُ رَبَّنَا هَٰٓؤُلَآءِ ٱلَّذِينَ أَغْوَيْنَآ أَغْوَيْنَٰهُمْ كَمَا غَوَيْنَا تَبَرَّأْنَآ إِلَيْكَ مَا كَانُوٓا۟ إِيَّانَا يَعْبُدُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmcccxvi{وَقِيلَ ٱدْعُوا۟ شُرَكَآءَكُمْ فَدَعَوْهُمْ فَلَمْ يَسْتَجِيبُوا۟ لَهُمْ وَرَأَوُا۟ ٱلْعَذَابَ لَوْ أَنَّهُمْ كَانُوا۟ يَهْتَدُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmcccxvii{وَيَوْمَ يُنَادِيهِمْ فَيَقُولُ مَاذَآ أَجَبْتُمُ ٱلْمُرْسَلِينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmcccxviii{فَعَمِيَتْ عَلَيْهِمُ ٱلْأَنۢبَآءُ يَوْمَئِذٍ فَهُمْ لَا يَتَسَآءَلُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmcccxix{فَأَمَّا مَن تَابَ وَءَامَنَ وَعَمِلَ صَٰلِحًا فَعَسَىٰٓ أَن يَكُونَ مِنَ ٱلْمُفْلِحِينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmcccxx{وَرَبُّكَ يَخْلُقُ مَا يَشَآءُ وَيَخْتَارُ مَا كَانَ لَهُمُ ٱلْخِيَرَةُ سُبْحَٰنَ ٱللَّهِ وَتَعَٰلَىٰ عَمَّا يُشْرِكُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmcccxxi{وَرَبُّكَ يَعْلَمُ مَا تُكِنُّ صُدُورُهُمْ وَمَا يُعْلِنُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmcccxxii{وَهُوَ ٱللَّهُ لَآ إِلَٰهَ إِلَّا هُوَ لَهُ ٱلْحَمْدُ فِى ٱلْأُولَىٰ وَٱلْءَاخِرَةِ وَلَهُ ٱلْحُكْمُ وَإِلَيْهِ تُرْجَعُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmcccxxiii{قُلْ أَرَءَيْتُمْ إِن جَعَلَ ٱللَّهُ عَلَيْكُمُ ٱلَّيْلَ سَرْمَدًا إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ مَنْ إِلَٰهٌ غَيْرُ ٱللَّهِ يَأْتِيكُم بِضِيَآءٍ أَفَلَا تَسْمَعُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmcccxxiv{قُلْ أَرَءَيْتُمْ إِن جَعَلَ ٱللَّهُ عَلَيْكُمُ ٱلنَّهَارَ سَرْمَدًا إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ مَنْ إِلَٰهٌ غَيْرُ ٱللَّهِ يَأْتِيكُم بِلَيْلٍ تَسْكُنُونَ فِيهِ أَفَلَا تُبْصِرُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmcccxxv{وَمِن رَّحْمَتِهِۦ جَعَلَ لَكُمُ ٱلَّيْلَ وَٱلنَّهَارَ لِتَسْكُنُوا۟ فِيهِ وَلِتَبْتَغُوا۟ مِن فَضْلِهِۦ وَلَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmcccxxvi{وَيَوْمَ يُنَادِيهِمْ فَيَقُولُ أَيْنَ شُرَكَآءِىَ ٱلَّذِينَ كُنتُمْ تَزْعُمُونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmcccxxvii{وَنَزَعْنَا مِن كُلِّ أُمَّةٍ شَهِيدًا فَقُلْنَا هَاتُوا۟ بُرْهَٰنَكُمْ فَعَلِمُوٓا۟ أَنَّ ٱلْحَقَّ لِلَّهِ وَضَلَّ عَنْهُم مَّا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmcccxxviii{إِنَّ قَٰرُونَ كَانَ مِن قَوْمِ مُوسَىٰ فَبَغَىٰ عَلَيْهِمْ وَءَاتَيْنَٰهُ مِنَ ٱلْكُنُوزِ مَآ إِنَّ مَفَاتِحَهُۥ لَتَنُوٓأُ بِٱلْعُصْبَةِ أُو۟لِى ٱلْقُوَّةِ إِذْ قَالَ لَهُۥ قَوْمُهُۥ لَا تَفْرَحْ إِنَّ ٱللَّهَ لَا يُحِبُّ ٱلْفَرِحِينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmcccxxix{وَٱبْتَغِ فِيمَآ ءَاتَىٰكَ ٱللَّهُ ٱلدَّارَ ٱلْءَاخِرَةَ وَلَا تَنسَ نَصِيبَكَ مِنَ ٱلدُّنْيَا وَأَحْسِن كَمَآ أَحْسَنَ ٱللَّهُ إِلَيْكَ وَلَا تَبْغِ ٱلْفَسَادَ فِى ٱلْأَرْضِ إِنَّ ٱللَّهَ لَا يُحِبُّ ٱلْمُفْسِدِينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmcccxxx{قَالَ إِنَّمَآ أُوتِيتُهُۥ عَلَىٰ عِلْمٍ عِندِىٓ أَوَلَمْ يَعْلَمْ أَنَّ ٱللَّهَ قَدْ أَهْلَكَ مِن قَبْلِهِۦ مِنَ ٱلْقُرُونِ مَنْ هُوَ أَشَدُّ مِنْهُ قُوَّةً وَأَكْثَرُ جَمْعًا وَلَا يُسْـَٔلُ عَن ذُنُوبِهِمُ ٱلْمُجْرِمُونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmcccxxxi{فَخَرَجَ عَلَىٰ قَوْمِهِۦ فِى زِينَتِهِۦ قَالَ ٱلَّذِينَ يُرِيدُونَ ٱلْحَيَوٰةَ ٱلدُّنْيَا يَٰلَيْتَ لَنَا مِثْلَ مَآ أُوتِىَ قَٰرُونُ إِنَّهُۥ لَذُو حَظٍّ عَظِيمٍ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmcccxxxii{وَقَالَ ٱلَّذِينَ أُوتُوا۟ ٱلْعِلْمَ وَيْلَكُمْ ثَوَابُ ٱللَّهِ خَيْرٌ لِّمَنْ ءَامَنَ وَعَمِلَ صَٰلِحًا وَلَا يُلَقَّىٰهَآ إِلَّا ٱلصَّٰبِرُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmcccxxxiii{فَخَسَفْنَا بِهِۦ وَبِدَارِهِ ٱلْأَرْضَ فَمَا كَانَ لَهُۥ مِن فِئَةٍ يَنصُرُونَهُۥ مِن دُونِ ٱللَّهِ وَمَا كَانَ مِنَ ٱلْمُنتَصِرِينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmcccxxxiv{وَأَصْبَحَ ٱلَّذِينَ تَمَنَّوْا۟ مَكَانَهُۥ بِٱلْأَمْسِ يَقُولُونَ وَيْكَأَنَّ ٱللَّهَ يَبْسُطُ ٱلرِّزْقَ لِمَن يَشَآءُ مِنْ عِبَادِهِۦ وَيَقْدِرُ لَوْلَآ أَن مَّنَّ ٱللَّهُ عَلَيْنَا لَخَسَفَ بِنَا وَيْكَأَنَّهُۥ لَا يُفْلِحُ ٱلْكَٰفِرُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmcccxxxv{تِلْكَ ٱلدَّارُ ٱلْءَاخِرَةُ نَجْعَلُهَا لِلَّذِينَ لَا يُرِيدُونَ عُلُوًّا فِى ٱلْأَرْضِ وَلَا فَسَادًا وَٱلْعَٰقِبَةُ لِلْمُتَّقِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmcccxxxvi{مَن جَآءَ بِٱلْحَسَنَةِ فَلَهُۥ خَيْرٌ مِّنْهَا وَمَن جَآءَ بِٱلسَّيِّئَةِ فَلَا يُجْزَى ٱلَّذِينَ عَمِلُوا۟ ٱلسَّيِّـَٔاتِ إِلَّا مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmcccxxxvii{إِنَّ ٱلَّذِى فَرَضَ عَلَيْكَ ٱلْقُرْءَانَ لَرَآدُّكَ إِلَىٰ مَعَادٍ قُل رَّبِّىٓ أَعْلَمُ مَن جَآءَ بِٱلْهُدَىٰ وَمَنْ هُوَ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmcccxxxviii{وَمَا كُنتَ تَرْجُوٓا۟ أَن يُلْقَىٰٓ إِلَيْكَ ٱلْكِتَٰبُ إِلَّا رَحْمَةً مِّن رَّبِّكَ فَلَا تَكُونَنَّ ظَهِيرًا لِّلْكَٰفِرِينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmcccxxxix{وَلَا يَصُدُّنَّكَ عَنْ ءَايَٰتِ ٱللَّهِ بَعْدَ إِذْ أُنزِلَتْ إِلَيْكَ وَٱدْعُ إِلَىٰ رَبِّكَ وَلَا تَكُونَنَّ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmcccxl{وَلَا تَدْعُ مَعَ ٱللَّهِ إِلَٰهًا ءَاخَرَ لَآ إِلَٰهَ إِلَّا هُوَ كُلُّ شَىْءٍ هَالِكٌ إِلَّا وَجْهَهُۥ لَهُ ٱلْحُكْمُ وَإِلَيْهِ تُرْجَعُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmcccxli{\basmalah الٓمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcccxlii{أَحَسِبَ ٱلنَّاسُ أَن يُتْرَكُوٓا۟ أَن يَقُولُوٓا۟ ءَامَنَّا وَهُمْ لَا يُفْتَنُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcccxliii{وَلَقَدْ فَتَنَّا ٱلَّذِينَ مِن قَبْلِهِمْ فَلَيَعْلَمَنَّ ٱللَّهُ ٱلَّذِينَ صَدَقُوا۟ وَلَيَعْلَمَنَّ ٱلْكَٰذِبِينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcccxliv{أَمْ حَسِبَ ٱلَّذِينَ يَعْمَلُونَ ٱلسَّيِّـَٔاتِ أَن يَسْبِقُونَا سَآءَ مَا يَحْكُمُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcccxlv{مَن كَانَ يَرْجُوا۟ لِقَآءَ ٱللَّهِ فَإِنَّ أَجَلَ ٱللَّهِ لَءَاتٍ وَهُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcccxlvi{وَمَن جَٰهَدَ فَإِنَّمَا يُجَٰهِدُ لِنَفْسِهِۦٓ إِنَّ ٱللَّهَ لَغَنِىٌّ عَنِ ٱلْعَٰلَمِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcccxlvii{وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَنُكَفِّرَنَّ عَنْهُمْ سَيِّـَٔاتِهِمْ وَلَنَجْزِيَنَّهُمْ أَحْسَنَ ٱلَّذِى كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcccxlviii{وَوَصَّيْنَا ٱلْإِنسَٰنَ بِوَٰلِدَيْهِ حُسْنًا وَإِن جَٰهَدَاكَ لِتُشْرِكَ بِى مَا لَيْسَ لَكَ بِهِۦ عِلْمٌ فَلَا تُطِعْهُمَآ إِلَىَّ مَرْجِعُكُمْ فَأُنَبِّئُكُم بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcccxlix{وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَنُدْخِلَنَّهُمْ فِى ٱلصَّٰلِحِينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcccl{وَمِنَ ٱلنَّاسِ مَن يَقُولُ ءَامَنَّا بِٱللَّهِ فَإِذَآ أُوذِىَ فِى ٱللَّهِ جَعَلَ فِتْنَةَ ٱلنَّاسِ كَعَذَابِ ٱللَّهِ وَلَئِن جَآءَ نَصْرٌ مِّن رَّبِّكَ لَيَقُولُنَّ إِنَّا كُنَّا مَعَكُمْ أَوَلَيْسَ ٱللَّهُ بِأَعْلَمَ بِمَا فِى صُدُورِ ٱلْعَٰلَمِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcccli{وَلَيَعْلَمَنَّ ٱللَّهُ ٱلَّذِينَ ءَامَنُوا۟ وَلَيَعْلَمَنَّ ٱلْمُنَٰفِقِينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmccclii{وَقَالَ ٱلَّذِينَ كَفَرُوا۟ لِلَّذِينَ ءَامَنُوا۟ ٱتَّبِعُوا۟ سَبِيلَنَا وَلْنَحْمِلْ خَطَٰيَٰكُمْ وَمَا هُم بِحَٰمِلِينَ مِنْ خَطَٰيَٰهُم مِّن شَىْءٍ إِنَّهُمْ لَكَٰذِبُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcccliii{وَلَيَحْمِلُنَّ أَثْقَالَهُمْ وَأَثْقَالًا مَّعَ أَثْقَالِهِمْ وَلَيُسْـَٔلُنَّ يَوْمَ ٱلْقِيَٰمَةِ عَمَّا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcccliv{وَلَقَدْ أَرْسَلْنَا نُوحًا إِلَىٰ قَوْمِهِۦ فَلَبِثَ فِيهِمْ أَلْفَ سَنَةٍ إِلَّا خَمْسِينَ عَامًا فَأَخَذَهُمُ ٱلطُّوفَانُ وَهُمْ ظَٰلِمُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmccclv{فَأَنجَيْنَٰهُ وَأَصْحَٰبَ ٱلسَّفِينَةِ وَجَعَلْنَٰهَآ ءَايَةً لِّلْعَٰلَمِينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmccclvi{وَإِبْرَٰهِيمَ إِذْ قَالَ لِقَوْمِهِ ٱعْبُدُوا۟ ٱللَّهَ وَٱتَّقُوهُ ذَٰلِكُمْ خَيْرٌ لَّكُمْ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmccclvii{إِنَّمَا تَعْبُدُونَ مِن دُونِ ٱللَّهِ أَوْثَٰنًا وَتَخْلُقُونَ إِفْكًا إِنَّ ٱلَّذِينَ تَعْبُدُونَ مِن دُونِ ٱللَّهِ لَا يَمْلِكُونَ لَكُمْ رِزْقًا فَٱبْتَغُوا۟ عِندَ ٱللَّهِ ٱلرِّزْقَ وَٱعْبُدُوهُ وَٱشْكُرُوا۟ لَهُۥٓ إِلَيْهِ تُرْجَعُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmccclviii{وَإِن تُكَذِّبُوا۟ فَقَدْ كَذَّبَ أُمَمٌ مِّن قَبْلِكُمْ وَمَا عَلَى ٱلرَّسُولِ إِلَّا ٱلْبَلَٰغُ ٱلْمُبِينُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmccclix{أَوَلَمْ يَرَوْا۟ كَيْفَ يُبْدِئُ ٱللَّهُ ٱلْخَلْقَ ثُمَّ يُعِيدُهُۥٓ إِنَّ ذَٰلِكَ عَلَى ٱللَّهِ يَسِيرٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmccclx{قُلْ سِيرُوا۟ فِى ٱلْأَرْضِ فَٱنظُرُوا۟ كَيْفَ بَدَأَ ٱلْخَلْقَ ثُمَّ ٱللَّهُ يُنشِئُ ٱلنَّشْأَةَ ٱلْءَاخِرَةَ إِنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmccclxi{يُعَذِّبُ مَن يَشَآءُ وَيَرْحَمُ مَن يَشَآءُ وَإِلَيْهِ تُقْلَبُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmccclxii{وَمَآ أَنتُم بِمُعْجِزِينَ فِى ٱلْأَرْضِ وَلَا فِى ٱلسَّمَآءِ وَمَا لَكُم مِّن دُونِ ٱللَّهِ مِن وَلِىٍّ وَلَا نَصِيرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmccclxiii{وَٱلَّذِينَ كَفَرُوا۟ بِـَٔايَٰتِ ٱللَّهِ وَلِقَآئِهِۦٓ أُو۟لَٰٓئِكَ يَئِسُوا۟ مِن رَّحْمَتِى وَأُو۟لَٰٓئِكَ لَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmccclxiv{فَمَا كَانَ جَوَابَ قَوْمِهِۦٓ إِلَّآ أَن قَالُوا۟ ٱقْتُلُوهُ أَوْ حَرِّقُوهُ فَأَنجَىٰهُ ٱللَّهُ مِنَ ٱلنَّارِ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmccclxv{وَقَالَ إِنَّمَا ٱتَّخَذْتُم مِّن دُونِ ٱللَّهِ أَوْثَٰنًا مَّوَدَّةَ بَيْنِكُمْ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا ثُمَّ يَوْمَ ٱلْقِيَٰمَةِ يَكْفُرُ بَعْضُكُم بِبَعْضٍ وَيَلْعَنُ بَعْضُكُم بَعْضًا وَمَأْوَىٰكُمُ ٱلنَّارُ وَمَا لَكُم مِّن نَّٰصِرِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmccclxvi{فَـَٔامَنَ لَهُۥ لُوطٌ وَقَالَ إِنِّى مُهَاجِرٌ إِلَىٰ رَبِّىٓ إِنَّهُۥ هُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmccclxvii{وَوَهَبْنَا لَهُۥٓ إِسْحَٰقَ وَيَعْقُوبَ وَجَعَلْنَا فِى ذُرِّيَّتِهِ ٱلنُّبُوَّةَ وَٱلْكِتَٰبَ وَءَاتَيْنَٰهُ أَجْرَهُۥ فِى ٱلدُّنْيَا وَإِنَّهُۥ فِى ٱلْءَاخِرَةِ لَمِنَ ٱلصَّٰلِحِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmccclxviii{وَلُوطًا إِذْ قَالَ لِقَوْمِهِۦٓ إِنَّكُمْ لَتَأْتُونَ ٱلْفَٰحِشَةَ مَا سَبَقَكُم بِهَا مِنْ أَحَدٍ مِّنَ ٱلْعَٰلَمِينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmccclxix{أَئِنَّكُمْ لَتَأْتُونَ ٱلرِّجَالَ وَتَقْطَعُونَ ٱلسَّبِيلَ وَتَأْتُونَ فِى نَادِيكُمُ ٱلْمُنكَرَ فَمَا كَانَ جَوَابَ قَوْمِهِۦٓ إِلَّآ أَن قَالُوا۟ ٱئْتِنَا بِعَذَابِ ٱللَّهِ إِن كُنتَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmccclxx{قَالَ رَبِّ ٱنصُرْنِى عَلَى ٱلْقَوْمِ ٱلْمُفْسِدِينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmccclxxi{وَلَمَّا جَآءَتْ رُسُلُنَآ إِبْرَٰهِيمَ بِٱلْبُشْرَىٰ قَالُوٓا۟ إِنَّا مُهْلِكُوٓا۟ أَهْلِ هَٰذِهِ ٱلْقَرْيَةِ إِنَّ أَهْلَهَا كَانُوا۟ ظَٰلِمِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmccclxxii{قَالَ إِنَّ فِيهَا لُوطًا قَالُوا۟ نَحْنُ أَعْلَمُ بِمَن فِيهَا لَنُنَجِّيَنَّهُۥ وَأَهْلَهُۥٓ إِلَّا ٱمْرَأَتَهُۥ كَانَتْ مِنَ ٱلْغَٰبِرِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmccclxxiii{وَلَمَّآ أَن جَآءَتْ رُسُلُنَا لُوطًا سِىٓءَ بِهِمْ وَضَاقَ بِهِمْ ذَرْعًا وَقَالُوا۟ لَا تَخَفْ وَلَا تَحْزَنْ إِنَّا مُنَجُّوكَ وَأَهْلَكَ إِلَّا ٱمْرَأَتَكَ كَانَتْ مِنَ ٱلْغَٰبِرِينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmccclxxiv{إِنَّا مُنزِلُونَ عَلَىٰٓ أَهْلِ هَٰذِهِ ٱلْقَرْيَةِ رِجْزًا مِّنَ ٱلسَّمَآءِ بِمَا كَانُوا۟ يَفْسُقُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmccclxxv{وَلَقَد تَّرَكْنَا مِنْهَآ ءَايَةًۢ بَيِّنَةً لِّقَوْمٍ يَعْقِلُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmccclxxvi{وَإِلَىٰ مَدْيَنَ أَخَاهُمْ شُعَيْبًا فَقَالَ يَٰقَوْمِ ٱعْبُدُوا۟ ٱللَّهَ وَٱرْجُوا۟ ٱلْيَوْمَ ٱلْءَاخِرَ وَلَا تَعْثَوْا۟ فِى ٱلْأَرْضِ مُفْسِدِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmccclxxvii{فَكَذَّبُوهُ فَأَخَذَتْهُمُ ٱلرَّجْفَةُ فَأَصْبَحُوا۟ فِى دَارِهِمْ جَٰثِمِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmccclxxviii{وَعَادًا وَثَمُودَا۟ وَقَد تَّبَيَّنَ لَكُم مِّن مَّسَٰكِنِهِمْ وَزَيَّنَ لَهُمُ ٱلشَّيْطَٰنُ أَعْمَٰلَهُمْ فَصَدَّهُمْ عَنِ ٱلسَّبِيلِ وَكَانُوا۟ مُسْتَبْصِرِينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmccclxxix{وَقَٰرُونَ وَفِرْعَوْنَ وَهَٰمَٰنَ وَلَقَدْ جَآءَهُم مُّوسَىٰ بِٱلْبَيِّنَٰتِ فَٱسْتَكْبَرُوا۟ فِى ٱلْأَرْضِ وَمَا كَانُوا۟ سَٰبِقِينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmccclxxx{فَكُلًّا أَخَذْنَا بِذَنۢبِهِۦ فَمِنْهُم مَّنْ أَرْسَلْنَا عَلَيْهِ حَاصِبًا وَمِنْهُم مَّنْ أَخَذَتْهُ ٱلصَّيْحَةُ وَمِنْهُم مَّنْ خَسَفْنَا بِهِ ٱلْأَرْضَ وَمِنْهُم مَّنْ أَغْرَقْنَا وَمَا كَانَ ٱللَّهُ لِيَظْلِمَهُمْ وَلَٰكِن كَانُوٓا۟ أَنفُسَهُمْ يَظْلِمُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmccclxxxi{مَثَلُ ٱلَّذِينَ ٱتَّخَذُوا۟ مِن دُونِ ٱللَّهِ أَوْلِيَآءَ كَمَثَلِ ٱلْعَنكَبُوتِ ٱتَّخَذَتْ بَيْتًا وَإِنَّ أَوْهَنَ ٱلْبُيُوتِ لَبَيْتُ ٱلْعَنكَبُوتِ لَوْ كَانُوا۟ يَعْلَمُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmccclxxxii{إِنَّ ٱللَّهَ يَعْلَمُ مَا يَدْعُونَ مِن دُونِهِۦ مِن شَىْءٍ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmccclxxxiii{وَتِلْكَ ٱلْأَمْثَٰلُ نَضْرِبُهَا لِلنَّاسِ وَمَا يَعْقِلُهَآ إِلَّا ٱلْعَٰلِمُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmccclxxxiv{خَلَقَ ٱللَّهُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ بِٱلْحَقِّ إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّلْمُؤْمِنِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmccclxxxv{ٱتْلُ مَآ أُوحِىَ إِلَيْكَ مِنَ ٱلْكِتَٰبِ وَأَقِمِ ٱلصَّلَوٰةَ إِنَّ ٱلصَّلَوٰةَ تَنْهَىٰ عَنِ ٱلْفَحْشَآءِ وَٱلْمُنكَرِ وَلَذِكْرُ ٱللَّهِ أَكْبَرُ وَٱللَّهُ يَعْلَمُ مَا تَصْنَعُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmccclxxxvi{وَلَا تُجَٰدِلُوٓا۟ أَهْلَ ٱلْكِتَٰبِ إِلَّا بِٱلَّتِى هِىَ أَحْسَنُ إِلَّا ٱلَّذِينَ ظَلَمُوا۟ مِنْهُمْ وَقُولُوٓا۟ ءَامَنَّا بِٱلَّذِىٓ أُنزِلَ إِلَيْنَا وَأُنزِلَ إِلَيْكُمْ وَإِلَٰهُنَا وَإِلَٰهُكُمْ وَٰحِدٌ وَنَحْنُ لَهُۥ مُسْلِمُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmccclxxxvii{وَكَذَٰلِكَ أَنزَلْنَآ إِلَيْكَ ٱلْكِتَٰبَ فَٱلَّذِينَ ءَاتَيْنَٰهُمُ ٱلْكِتَٰبَ يُؤْمِنُونَ بِهِۦ وَمِنْ هَٰٓؤُلَآءِ مَن يُؤْمِنُ بِهِۦ وَمَا يَجْحَدُ بِـَٔايَٰتِنَآ إِلَّا ٱلْكَٰفِرُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmccclxxxviii{وَمَا كُنتَ تَتْلُوا۟ مِن قَبْلِهِۦ مِن كِتَٰبٍ وَلَا تَخُطُّهُۥ بِيَمِينِكَ إِذًا لَّٱرْتَابَ ٱلْمُبْطِلُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmccclxxxix{بَلْ هُوَ ءَايَٰتٌۢ بَيِّنَٰتٌ فِى صُدُورِ ٱلَّذِينَ أُوتُوا۟ ٱلْعِلْمَ وَمَا يَجْحَدُ بِـَٔايَٰتِنَآ إِلَّا ٱلظَّٰلِمُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmcccxc{وَقَالُوا۟ لَوْلَآ أُنزِلَ عَلَيْهِ ءَايَٰتٌ مِّن رَّبِّهِۦ قُلْ إِنَّمَا ٱلْءَايَٰتُ عِندَ ٱللَّهِ وَإِنَّمَآ أَنَا۠ نَذِيرٌ مُّبِينٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmcccxci{أَوَلَمْ يَكْفِهِمْ أَنَّآ أَنزَلْنَا عَلَيْكَ ٱلْكِتَٰبَ يُتْلَىٰ عَلَيْهِمْ إِنَّ فِى ذَٰلِكَ لَرَحْمَةً وَذِكْرَىٰ لِقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmcccxcii{قُلْ كَفَىٰ بِٱللَّهِ بَيْنِى وَبَيْنَكُمْ شَهِيدًا يَعْلَمُ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱلَّذِينَ ءَامَنُوا۟ بِٱلْبَٰطِلِ وَكَفَرُوا۟ بِٱللَّهِ أُو۟لَٰٓئِكَ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmcccxciii{وَيَسْتَعْجِلُونَكَ بِٱلْعَذَابِ وَلَوْلَآ أَجَلٌ مُّسَمًّى لَّجَآءَهُمُ ٱلْعَذَابُ وَلَيَأْتِيَنَّهُم بَغْتَةً وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmcccxciv{يَسْتَعْجِلُونَكَ بِٱلْعَذَابِ وَإِنَّ جَهَنَّمَ لَمُحِيطَةٌۢ بِٱلْكَٰفِرِينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmcccxcv{يَوْمَ يَغْشَىٰهُمُ ٱلْعَذَابُ مِن فَوْقِهِمْ وَمِن تَحْتِ أَرْجُلِهِمْ وَيَقُولُ ذُوقُوا۟ مَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmcccxcvi{يَٰعِبَادِىَ ٱلَّذِينَ ءَامَنُوٓا۟ إِنَّ أَرْضِى وَٰسِعَةٌ فَإِيَّٰىَ فَٱعْبُدُونِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmcccxcvii{كُلُّ نَفْسٍ ذَآئِقَةُ ٱلْمَوْتِ ثُمَّ إِلَيْنَا تُرْجَعُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmcccxcviii{وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَنُبَوِّئَنَّهُم مِّنَ ٱلْجَنَّةِ غُرَفًا تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا نِعْمَ أَجْرُ ٱلْعَٰمِلِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmcccxcix{ٱلَّذِينَ صَبَرُوا۟ وَعَلَىٰ رَبِّهِمْ يَتَوَكَّلُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmcd{وَكَأَيِّن مِّن دَآبَّةٍ لَّا تَحْمِلُ رِزْقَهَا ٱللَّهُ يَرْزُقُهَا وَإِيَّاكُمْ وَهُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmcdi{وَلَئِن سَأَلْتَهُم مَّنْ خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَسَخَّرَ ٱلشَّمْسَ وَٱلْقَمَرَ لَيَقُولُنَّ ٱللَّهُ فَأَنَّىٰ يُؤْفَكُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmcdii{ٱللَّهُ يَبْسُطُ ٱلرِّزْقَ لِمَن يَشَآءُ مِنْ عِبَادِهِۦ وَيَقْدِرُ لَهُۥٓ إِنَّ ٱللَّهَ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmcdiii{وَلَئِن سَأَلْتَهُم مَّن نَّزَّلَ مِنَ ٱلسَّمَآءِ مَآءً فَأَحْيَا بِهِ ٱلْأَرْضَ مِنۢ بَعْدِ مَوْتِهَا لَيَقُولُنَّ ٱللَّهُ قُلِ ٱلْحَمْدُ لِلَّهِ بَلْ أَكْثَرُهُمْ لَا يَعْقِلُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmcdiv{وَمَا هَٰذِهِ ٱلْحَيَوٰةُ ٱلدُّنْيَآ إِلَّا لَهْوٌ وَلَعِبٌ وَإِنَّ ٱلدَّارَ ٱلْءَاخِرَةَ لَهِىَ ٱلْحَيَوَانُ لَوْ كَانُوا۟ يَعْلَمُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmcdv{فَإِذَا رَكِبُوا۟ فِى ٱلْفُلْكِ دَعَوُا۟ ٱللَّهَ مُخْلِصِينَ لَهُ ٱلدِّينَ فَلَمَّا نَجَّىٰهُمْ إِلَى ٱلْبَرِّ إِذَا هُمْ يُشْرِكُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmcdvi{لِيَكْفُرُوا۟ بِمَآ ءَاتَيْنَٰهُمْ وَلِيَتَمَتَّعُوا۟ فَسَوْفَ يَعْلَمُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmcdvii{أَوَلَمْ يَرَوْا۟ أَنَّا جَعَلْنَا حَرَمًا ءَامِنًا وَيُتَخَطَّفُ ٱلنَّاسُ مِنْ حَوْلِهِمْ أَفَبِٱلْبَٰطِلِ يُؤْمِنُونَ وَبِنِعْمَةِ ٱللَّهِ يَكْفُرُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmcdviii{وَمَنْ أَظْلَمُ مِمَّنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا أَوْ كَذَّبَ بِٱلْحَقِّ لَمَّا جَآءَهُۥٓ أَلَيْسَ فِى جَهَنَّمَ مَثْوًى لِّلْكَٰفِرِينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmcdix{وَٱلَّذِينَ جَٰهَدُوا۟ فِينَا لَنَهْدِيَنَّهُمْ سُبُلَنَا وَإِنَّ ٱللَّهَ لَمَعَ ٱلْمُحْسِنِينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmcdx{\basmalah الٓمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcdxi{غُلِبَتِ ٱلرُّومُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcdxii{فِىٓ أَدْنَى ٱلْأَرْضِ وَهُم مِّنۢ بَعْدِ غَلَبِهِمْ سَيَغْلِبُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcdxiii{فِى بِضْعِ سِنِينَ لِلَّهِ ٱلْأَمْرُ مِن قَبْلُ وَمِنۢ بَعْدُ وَيَوْمَئِذٍ يَفْرَحُ ٱلْمُؤْمِنُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcdxiv{بِنَصْرِ ٱللَّهِ يَنصُرُ مَن يَشَآءُ وَهُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcdxv{وَعْدَ ٱللَّهِ لَا يُخْلِفُ ٱللَّهُ وَعْدَهُۥ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcdxvi{يَعْلَمُونَ ظَٰهِرًا مِّنَ ٱلْحَيَوٰةِ ٱلدُّنْيَا وَهُمْ عَنِ ٱلْءَاخِرَةِ هُمْ غَٰفِلُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcdxvii{أَوَلَمْ يَتَفَكَّرُوا۟ فِىٓ أَنفُسِهِم مَّا خَلَقَ ٱللَّهُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَمَا بَيْنَهُمَآ إِلَّا بِٱلْحَقِّ وَأَجَلٍ مُّسَمًّى وَإِنَّ كَثِيرًا مِّنَ ٱلنَّاسِ بِلِقَآئِ رَبِّهِمْ لَكَٰفِرُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcdxviii{أَوَلَمْ يَسِيرُوا۟ فِى ٱلْأَرْضِ فَيَنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلَّذِينَ مِن قَبْلِهِمْ كَانُوٓا۟ أَشَدَّ مِنْهُمْ قُوَّةً وَأَثَارُوا۟ ٱلْأَرْضَ وَعَمَرُوهَآ أَكْثَرَ مِمَّا عَمَرُوهَا وَجَآءَتْهُمْ رُسُلُهُم بِٱلْبَيِّنَٰتِ فَمَا كَانَ ٱللَّهُ لِيَظْلِمَهُمْ وَلَٰكِن كَانُوٓا۟ أَنفُسَهُمْ يَظْلِمُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcdxix{ثُمَّ كَانَ عَٰقِبَةَ ٱلَّذِينَ أَسَٰٓـُٔوا۟ ٱلسُّوٓأَىٰٓ أَن كَذَّبُوا۟ بِـَٔايَٰتِ ٱللَّهِ وَكَانُوا۟ بِهَا يَسْتَهْزِءُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcdxx{ٱللَّهُ يَبْدَؤُا۟ ٱلْخَلْقَ ثُمَّ يُعِيدُهُۥ ثُمَّ إِلَيْهِ تُرْجَعُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcdxxi{وَيَوْمَ تَقُومُ ٱلسَّاعَةُ يُبْلِسُ ٱلْمُجْرِمُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcdxxii{وَلَمْ يَكُن لَّهُم مِّن شُرَكَآئِهِمْ شُفَعَٰٓؤُا۟ وَكَانُوا۟ بِشُرَكَآئِهِمْ كَٰفِرِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcdxxiii{وَيَوْمَ تَقُومُ ٱلسَّاعَةُ يَوْمَئِذٍ يَتَفَرَّقُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcdxxiv{فَأَمَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ فَهُمْ فِى رَوْضَةٍ يُحْبَرُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcdxxv{وَأَمَّا ٱلَّذِينَ كَفَرُوا۟ وَكَذَّبُوا۟ بِـَٔايَٰتِنَا وَلِقَآئِ ٱلْءَاخِرَةِ فَأُو۟لَٰٓئِكَ فِى ٱلْعَذَابِ مُحْضَرُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcdxxvi{فَسُبْحَٰنَ ٱللَّهِ حِينَ تُمْسُونَ وَحِينَ تُصْبِحُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcdxxvii{وَلَهُ ٱلْحَمْدُ فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَعَشِيًّا وَحِينَ تُظْهِرُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcdxxviii{يُخْرِجُ ٱلْحَىَّ مِنَ ٱلْمَيِّتِ وَيُخْرِجُ ٱلْمَيِّتَ مِنَ ٱلْحَىِّ وَيُحْىِ ٱلْأَرْضَ بَعْدَ مَوْتِهَا وَكَذَٰلِكَ تُخْرَجُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcdxxix{وَمِنْ ءَايَٰتِهِۦٓ أَنْ خَلَقَكُم مِّن تُرَابٍ ثُمَّ إِذَآ أَنتُم بَشَرٌ تَنتَشِرُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcdxxx{وَمِنْ ءَايَٰتِهِۦٓ أَنْ خَلَقَ لَكُم مِّنْ أَنفُسِكُمْ أَزْوَٰجًا لِّتَسْكُنُوٓا۟ إِلَيْهَا وَجَعَلَ بَيْنَكُم مَّوَدَّةً وَرَحْمَةً إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يَتَفَكَّرُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcdxxxi{وَمِنْ ءَايَٰتِهِۦ خَلْقُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱخْتِلَٰفُ أَلْسِنَتِكُمْ وَأَلْوَٰنِكُمْ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّلْعَٰلِمِينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcdxxxii{وَمِنْ ءَايَٰتِهِۦ مَنَامُكُم بِٱلَّيْلِ وَٱلنَّهَارِ وَٱبْتِغَآؤُكُم مِّن فَضْلِهِۦٓ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يَسْمَعُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcdxxxiii{وَمِنْ ءَايَٰتِهِۦ يُرِيكُمُ ٱلْبَرْقَ خَوْفًا وَطَمَعًا وَيُنَزِّلُ مِنَ ٱلسَّمَآءِ مَآءً فَيُحْىِۦ بِهِ ٱلْأَرْضَ بَعْدَ مَوْتِهَآ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يَعْقِلُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcdxxxiv{وَمِنْ ءَايَٰتِهِۦٓ أَن تَقُومَ ٱلسَّمَآءُ وَٱلْأَرْضُ بِأَمْرِهِۦ ثُمَّ إِذَا دَعَاكُمْ دَعْوَةً مِّنَ ٱلْأَرْضِ إِذَآ أَنتُمْ تَخْرُجُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcdxxxv{وَلَهُۥ مَن فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ كُلٌّ لَّهُۥ قَٰنِتُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcdxxxvi{وَهُوَ ٱلَّذِى يَبْدَؤُا۟ ٱلْخَلْقَ ثُمَّ يُعِيدُهُۥ وَهُوَ أَهْوَنُ عَلَيْهِ وَلَهُ ٱلْمَثَلُ ٱلْأَعْلَىٰ فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcdxxxvii{ضَرَبَ لَكُم مَّثَلًا مِّنْ أَنفُسِكُمْ هَل لَّكُم مِّن مَّا مَلَكَتْ أَيْمَٰنُكُم مِّن شُرَكَآءَ فِى مَا رَزَقْنَٰكُمْ فَأَنتُمْ فِيهِ سَوَآءٌ تَخَافُونَهُمْ كَخِيفَتِكُمْ أَنفُسَكُمْ كَذَٰلِكَ نُفَصِّلُ ٱلْءَايَٰتِ لِقَوْمٍ يَعْقِلُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcdxxxviii{بَلِ ٱتَّبَعَ ٱلَّذِينَ ظَلَمُوٓا۟ أَهْوَآءَهُم بِغَيْرِ عِلْمٍ فَمَن يَهْدِى مَنْ أَضَلَّ ٱللَّهُ وَمَا لَهُم مِّن نَّٰصِرِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmcdxxxix{فَأَقِمْ وَجْهَكَ لِلدِّينِ حَنِيفًا فِطْرَتَ ٱللَّهِ ٱلَّتِى فَطَرَ ٱلنَّاسَ عَلَيْهَا لَا تَبْدِيلَ لِخَلْقِ ٱللَّهِ ذَٰلِكَ ٱلدِّينُ ٱلْقَيِّمُ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmcdxl{مُنِيبِينَ إِلَيْهِ وَٱتَّقُوهُ وَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَلَا تَكُونُوا۟ مِنَ ٱلْمُشْرِكِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmcdxli{مِنَ ٱلَّذِينَ فَرَّقُوا۟ دِينَهُمْ وَكَانُوا۟ شِيَعًا كُلُّ حِزْبٍۭ بِمَا لَدَيْهِمْ فَرِحُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmcdxlii{وَإِذَا مَسَّ ٱلنَّاسَ ضُرٌّ دَعَوْا۟ رَبَّهُم مُّنِيبِينَ إِلَيْهِ ثُمَّ إِذَآ أَذَاقَهُم مِّنْهُ رَحْمَةً إِذَا فَرِيقٌ مِّنْهُم بِرَبِّهِمْ يُشْرِكُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmcdxliii{لِيَكْفُرُوا۟ بِمَآ ءَاتَيْنَٰهُمْ فَتَمَتَّعُوا۟ فَسَوْفَ تَعْلَمُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmcdxliv{أَمْ أَنزَلْنَا عَلَيْهِمْ سُلْطَٰنًا فَهُوَ يَتَكَلَّمُ بِمَا كَانُوا۟ بِهِۦ يُشْرِكُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmcdxlv{وَإِذَآ أَذَقْنَا ٱلنَّاسَ رَحْمَةً فَرِحُوا۟ بِهَا وَإِن تُصِبْهُمْ سَيِّئَةٌۢ بِمَا قَدَّمَتْ أَيْدِيهِمْ إِذَا هُمْ يَقْنَطُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmcdxlvi{أَوَلَمْ يَرَوْا۟ أَنَّ ٱللَّهَ يَبْسُطُ ٱلرِّزْقَ لِمَن يَشَآءُ وَيَقْدِرُ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmcdxlvii{فَـَٔاتِ ذَا ٱلْقُرْبَىٰ حَقَّهُۥ وَٱلْمِسْكِينَ وَٱبْنَ ٱلسَّبِيلِ ذَٰلِكَ خَيْرٌ لِّلَّذِينَ يُرِيدُونَ وَجْهَ ٱللَّهِ وَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmcdxlviii{وَمَآ ءَاتَيْتُم مِّن رِّبًا لِّيَرْبُوَا۟ فِىٓ أَمْوَٰلِ ٱلنَّاسِ فَلَا يَرْبُوا۟ عِندَ ٱللَّهِ وَمَآ ءَاتَيْتُم مِّن زَكَوٰةٍ تُرِيدُونَ وَجْهَ ٱللَّهِ فَأُو۟لَٰٓئِكَ هُمُ ٱلْمُضْعِفُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmcdxlix{ٱللَّهُ ٱلَّذِى خَلَقَكُمْ ثُمَّ رَزَقَكُمْ ثُمَّ يُمِيتُكُمْ ثُمَّ يُحْيِيكُمْ هَلْ مِن شُرَكَآئِكُم مَّن يَفْعَلُ مِن ذَٰلِكُم مِّن شَىْءٍ سُبْحَٰنَهُۥ وَتَعَٰلَىٰ عَمَّا يُشْرِكُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmcdl{ظَهَرَ ٱلْفَسَادُ فِى ٱلْبَرِّ وَٱلْبَحْرِ بِمَا كَسَبَتْ أَيْدِى ٱلنَّاسِ لِيُذِيقَهُم بَعْضَ ٱلَّذِى عَمِلُوا۟ لَعَلَّهُمْ يَرْجِعُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmcdli{قُلْ سِيرُوا۟ فِى ٱلْأَرْضِ فَٱنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلَّذِينَ مِن قَبْلُ كَانَ أَكْثَرُهُم مُّشْرِكِينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmcdlii{فَأَقِمْ وَجْهَكَ لِلدِّينِ ٱلْقَيِّمِ مِن قَبْلِ أَن يَأْتِىَ يَوْمٌ لَّا مَرَدَّ لَهُۥ مِنَ ٱللَّهِ يَوْمَئِذٍ يَصَّدَّعُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmcdliii{مَن كَفَرَ فَعَلَيْهِ كُفْرُهُۥ وَمَنْ عَمِلَ صَٰلِحًا فَلِأَنفُسِهِمْ يَمْهَدُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmcdliv{لِيَجْزِىَ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ مِن فَضْلِهِۦٓ إِنَّهُۥ لَا يُحِبُّ ٱلْكَٰفِرِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmcdlv{وَمِنْ ءَايَٰتِهِۦٓ أَن يُرْسِلَ ٱلرِّيَاحَ مُبَشِّرَٰتٍ وَلِيُذِيقَكُم مِّن رَّحْمَتِهِۦ وَلِتَجْرِىَ ٱلْفُلْكُ بِأَمْرِهِۦ وَلِتَبْتَغُوا۟ مِن فَضْلِهِۦ وَلَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmcdlvi{وَلَقَدْ أَرْسَلْنَا مِن قَبْلِكَ رُسُلًا إِلَىٰ قَوْمِهِمْ فَجَآءُوهُم بِٱلْبَيِّنَٰتِ فَٱنتَقَمْنَا مِنَ ٱلَّذِينَ أَجْرَمُوا۟ وَكَانَ حَقًّا عَلَيْنَا نَصْرُ ٱلْمُؤْمِنِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmcdlvii{ٱللَّهُ ٱلَّذِى يُرْسِلُ ٱلرِّيَٰحَ فَتُثِيرُ سَحَابًا فَيَبْسُطُهُۥ فِى ٱلسَّمَآءِ كَيْفَ يَشَآءُ وَيَجْعَلُهُۥ كِسَفًا فَتَرَى ٱلْوَدْقَ يَخْرُجُ مِنْ خِلَٰلِهِۦ فَإِذَآ أَصَابَ بِهِۦ مَن يَشَآءُ مِنْ عِبَادِهِۦٓ إِذَا هُمْ يَسْتَبْشِرُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmcdlviii{وَإِن كَانُوا۟ مِن قَبْلِ أَن يُنَزَّلَ عَلَيْهِم مِّن قَبْلِهِۦ لَمُبْلِسِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmcdlix{فَٱنظُرْ إِلَىٰٓ ءَاثَٰرِ رَحْمَتِ ٱللَّهِ كَيْفَ يُحْىِ ٱلْأَرْضَ بَعْدَ مَوْتِهَآ إِنَّ ذَٰلِكَ لَمُحْىِ ٱلْمَوْتَىٰ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmcdlx{وَلَئِنْ أَرْسَلْنَا رِيحًا فَرَأَوْهُ مُصْفَرًّا لَّظَلُّوا۟ مِنۢ بَعْدِهِۦ يَكْفُرُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmcdlxi{فَإِنَّكَ لَا تُسْمِعُ ٱلْمَوْتَىٰ وَلَا تُسْمِعُ ٱلصُّمَّ ٱلدُّعَآءَ إِذَا وَلَّوْا۟ مُدْبِرِينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmcdlxii{وَمَآ أَنتَ بِهَٰدِ ٱلْعُمْىِ عَن ضَلَٰلَتِهِمْ إِن تُسْمِعُ إِلَّا مَن يُؤْمِنُ بِـَٔايَٰتِنَا فَهُم مُّسْلِمُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmcdlxiii{ٱللَّهُ ٱلَّذِى خَلَقَكُم مِّن ضَعْفٍ ثُمَّ جَعَلَ مِنۢ بَعْدِ ضَعْفٍ قُوَّةً ثُمَّ جَعَلَ مِنۢ بَعْدِ قُوَّةٍ ضَعْفًا وَشَيْبَةً يَخْلُقُ مَا يَشَآءُ وَهُوَ ٱلْعَلِيمُ ٱلْقَدِيرُ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmcdlxiv{وَيَوْمَ تَقُومُ ٱلسَّاعَةُ يُقْسِمُ ٱلْمُجْرِمُونَ مَا لَبِثُوا۟ غَيْرَ سَاعَةٍ كَذَٰلِكَ كَانُوا۟ يُؤْفَكُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmcdlxv{وَقَالَ ٱلَّذِينَ أُوتُوا۟ ٱلْعِلْمَ وَٱلْإِيمَٰنَ لَقَدْ لَبِثْتُمْ فِى كِتَٰبِ ٱللَّهِ إِلَىٰ يَوْمِ ٱلْبَعْثِ فَهَٰذَا يَوْمُ ٱلْبَعْثِ وَلَٰكِنَّكُمْ كُنتُمْ لَا تَعْلَمُونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmcdlxvi{فَيَوْمَئِذٍ لَّا يَنفَعُ ٱلَّذِينَ ظَلَمُوا۟ مَعْذِرَتُهُمْ وَلَا هُمْ يُسْتَعْتَبُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmcdlxvii{وَلَقَدْ ضَرَبْنَا لِلنَّاسِ فِى هَٰذَا ٱلْقُرْءَانِ مِن كُلِّ مَثَلٍ وَلَئِن جِئْتَهُم بِـَٔايَةٍ لَّيَقُولَنَّ ٱلَّذِينَ كَفَرُوٓا۟ إِنْ أَنتُمْ إِلَّا مُبْطِلُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmcdlxviii{كَذَٰلِكَ يَطْبَعُ ٱللَّهُ عَلَىٰ قُلُوبِ ٱلَّذِينَ لَا يَعْلَمُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmcdlxix{فَٱصْبِرْ إِنَّ وَعْدَ ٱللَّهِ حَقٌّ وَلَا يَسْتَخِفَّنَّكَ ٱلَّذِينَ لَا يُوقِنُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmcdlxx{\basmalah الٓمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcdlxxi{تِلْكَ ءَايَٰتُ ٱلْكِتَٰبِ ٱلْحَكِيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcdlxxii{هُدًى وَرَحْمَةً لِّلْمُحْسِنِينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcdlxxiii{ٱلَّذِينَ يُقِيمُونَ ٱلصَّلَوٰةَ وَيُؤْتُونَ ٱلزَّكَوٰةَ وَهُم بِٱلْءَاخِرَةِ هُمْ يُوقِنُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcdlxxiv{أُو۟لَٰٓئِكَ عَلَىٰ هُدًى مِّن رَّبِّهِمْ وَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcdlxxv{وَمِنَ ٱلنَّاسِ مَن يَشْتَرِى لَهْوَ ٱلْحَدِيثِ لِيُضِلَّ عَن سَبِيلِ ٱللَّهِ بِغَيْرِ عِلْمٍ وَيَتَّخِذَهَا هُزُوًا أُو۟لَٰٓئِكَ لَهُمْ عَذَابٌ مُّهِينٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcdlxxvi{وَإِذَا تُتْلَىٰ عَلَيْهِ ءَايَٰتُنَا وَلَّىٰ مُسْتَكْبِرًا كَأَن لَّمْ يَسْمَعْهَا كَأَنَّ فِىٓ أُذُنَيْهِ وَقْرًا فَبَشِّرْهُ بِعَذَابٍ أَلِيمٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcdlxxvii{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَهُمْ جَنَّٰتُ ٱلنَّعِيمِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcdlxxviii{خَٰلِدِينَ فِيهَا وَعْدَ ٱللَّهِ حَقًّا وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcdlxxix{خَلَقَ ٱلسَّمَٰوَٰتِ بِغَيْرِ عَمَدٍ تَرَوْنَهَا وَأَلْقَىٰ فِى ٱلْأَرْضِ رَوَٰسِىَ أَن تَمِيدَ بِكُمْ وَبَثَّ فِيهَا مِن كُلِّ دَآبَّةٍ وَأَنزَلْنَا مِنَ ٱلسَّمَآءِ مَآءً فَأَنۢبَتْنَا فِيهَا مِن كُلِّ زَوْجٍ كَرِيمٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcdlxxx{هَٰذَا خَلْقُ ٱللَّهِ فَأَرُونِى مَاذَا خَلَقَ ٱلَّذِينَ مِن دُونِهِۦ بَلِ ٱلظَّٰلِمُونَ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcdlxxxi{وَلَقَدْ ءَاتَيْنَا لُقْمَٰنَ ٱلْحِكْمَةَ أَنِ ٱشْكُرْ لِلَّهِ وَمَن يَشْكُرْ فَإِنَّمَا يَشْكُرُ لِنَفْسِهِۦ وَمَن كَفَرَ فَإِنَّ ٱللَّهَ غَنِىٌّ حَمِيدٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcdlxxxii{وَإِذْ قَالَ لُقْمَٰنُ لِٱبْنِهِۦ وَهُوَ يَعِظُهُۥ يَٰبُنَىَّ لَا تُشْرِكْ بِٱللَّهِ إِنَّ ٱلشِّرْكَ لَظُلْمٌ عَظِيمٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcdlxxxiii{وَوَصَّيْنَا ٱلْإِنسَٰنَ بِوَٰلِدَيْهِ حَمَلَتْهُ أُمُّهُۥ وَهْنًا عَلَىٰ وَهْنٍ وَفِصَٰلُهُۥ فِى عَامَيْنِ أَنِ ٱشْكُرْ لِى وَلِوَٰلِدَيْكَ إِلَىَّ ٱلْمَصِيرُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcdlxxxiv{وَإِن جَٰهَدَاكَ عَلَىٰٓ أَن تُشْرِكَ بِى مَا لَيْسَ لَكَ بِهِۦ عِلْمٌ فَلَا تُطِعْهُمَا وَصَاحِبْهُمَا فِى ٱلدُّنْيَا مَعْرُوفًا وَٱتَّبِعْ سَبِيلَ مَنْ أَنَابَ إِلَىَّ ثُمَّ إِلَىَّ مَرْجِعُكُمْ فَأُنَبِّئُكُم بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcdlxxxv{يَٰبُنَىَّ إِنَّهَآ إِن تَكُ مِثْقَالَ حَبَّةٍ مِّنْ خَرْدَلٍ فَتَكُن فِى صَخْرَةٍ أَوْ فِى ٱلسَّمَٰوَٰتِ أَوْ فِى ٱلْأَرْضِ يَأْتِ بِهَا ٱللَّهُ إِنَّ ٱللَّهَ لَطِيفٌ خَبِيرٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcdlxxxvi{يَٰبُنَىَّ أَقِمِ ٱلصَّلَوٰةَ وَأْمُرْ بِٱلْمَعْرُوفِ وَٱنْهَ عَنِ ٱلْمُنكَرِ وَٱصْبِرْ عَلَىٰ مَآ أَصَابَكَ إِنَّ ذَٰلِكَ مِنْ عَزْمِ ٱلْأُمُورِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcdlxxxvii{وَلَا تُصَعِّرْ خَدَّكَ لِلنَّاسِ وَلَا تَمْشِ فِى ٱلْأَرْضِ مَرَحًا إِنَّ ٱللَّهَ لَا يُحِبُّ كُلَّ مُخْتَالٍ فَخُورٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcdlxxxviii{وَٱقْصِدْ فِى مَشْيِكَ وَٱغْضُضْ مِن صَوْتِكَ إِنَّ أَنكَرَ ٱلْأَصْوَٰتِ لَصَوْتُ ٱلْحَمِيرِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcdlxxxix{أَلَمْ تَرَوْا۟ أَنَّ ٱللَّهَ سَخَّرَ لَكُم مَّا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَأَسْبَغَ عَلَيْكُمْ نِعَمَهُۥ ظَٰهِرَةً وَبَاطِنَةً وَمِنَ ٱلنَّاسِ مَن يُجَٰدِلُ فِى ٱللَّهِ بِغَيْرِ عِلْمٍ وَلَا هُدًى وَلَا كِتَٰبٍ مُّنِيرٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcdxc{وَإِذَا قِيلَ لَهُمُ ٱتَّبِعُوا۟ مَآ أَنزَلَ ٱللَّهُ قَالُوا۟ بَلْ نَتَّبِعُ مَا وَجَدْنَا عَلَيْهِ ءَابَآءَنَآ أَوَلَوْ كَانَ ٱلشَّيْطَٰنُ يَدْعُوهُمْ إِلَىٰ عَذَابِ ٱلسَّعِيرِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcdxci{وَمَن يُسْلِمْ وَجْهَهُۥٓ إِلَى ٱللَّهِ وَهُوَ مُحْسِنٌ فَقَدِ ٱسْتَمْسَكَ بِٱلْعُرْوَةِ ٱلْوُثْقَىٰ وَإِلَى ٱللَّهِ عَٰقِبَةُ ٱلْأُمُورِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcdxcii{وَمَن كَفَرَ فَلَا يَحْزُنكَ كُفْرُهُۥٓ إِلَيْنَا مَرْجِعُهُمْ فَنُنَبِّئُهُم بِمَا عَمِلُوٓا۟ إِنَّ ٱللَّهَ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcdxciii{نُمَتِّعُهُمْ قَلِيلًا ثُمَّ نَضْطَرُّهُمْ إِلَىٰ عَذَابٍ غَلِيظٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcdxciv{وَلَئِن سَأَلْتَهُم مَّنْ خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ لَيَقُولُنَّ ٱللَّهُ قُلِ ٱلْحَمْدُ لِلَّهِ بَلْ أَكْثَرُهُمْ لَا يَعْلَمُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcdxcv{لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ إِنَّ ٱللَّهَ هُوَ ٱلْغَنِىُّ ٱلْحَمِيدُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcdxcvi{وَلَوْ أَنَّمَا فِى ٱلْأَرْضِ مِن شَجَرَةٍ أَقْلَٰمٌ وَٱلْبَحْرُ يَمُدُّهُۥ مِنۢ بَعْدِهِۦ سَبْعَةُ أَبْحُرٍ مَّا نَفِدَتْ كَلِمَٰتُ ٱللَّهِ إِنَّ ٱللَّهَ عَزِيزٌ حَكِيمٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcdxcvii{مَّا خَلْقُكُمْ وَلَا بَعْثُكُمْ إِلَّا كَنَفْسٍ وَٰحِدَةٍ إِنَّ ٱللَّهَ سَمِيعٌۢ بَصِيرٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcdxcviii{أَلَمْ تَرَ أَنَّ ٱللَّهَ يُولِجُ ٱلَّيْلَ فِى ٱلنَّهَارِ وَيُولِجُ ٱلنَّهَارَ فِى ٱلَّيْلِ وَسَخَّرَ ٱلشَّمْسَ وَٱلْقَمَرَ كُلٌّ يَجْرِىٓ إِلَىٰٓ أَجَلٍ مُّسَمًّى وَأَنَّ ٱللَّهَ بِمَا تَعْمَلُونَ خَبِيرٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmcdxcix{ذَٰلِكَ بِأَنَّ ٱللَّهَ هُوَ ٱلْحَقُّ وَأَنَّ مَا يَدْعُونَ مِن دُونِهِ ٱلْبَٰطِلُ وَأَنَّ ٱللَّهَ هُوَ ٱلْعَلِىُّ ٱلْكَبِيرُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmd{أَلَمْ تَرَ أَنَّ ٱلْفُلْكَ تَجْرِى فِى ٱلْبَحْرِ بِنِعْمَتِ ٱللَّهِ لِيُرِيَكُم مِّنْ ءَايَٰتِهِۦٓ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّكُلِّ صَبَّارٍ شَكُورٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdi{وَإِذَا غَشِيَهُم مَّوْجٌ كَٱلظُّلَلِ دَعَوُا۟ ٱللَّهَ مُخْلِصِينَ لَهُ ٱلدِّينَ فَلَمَّا نَجَّىٰهُمْ إِلَى ٱلْبَرِّ فَمِنْهُم مُّقْتَصِدٌ وَمَا يَجْحَدُ بِـَٔايَٰتِنَآ إِلَّا كُلُّ خَتَّارٍ كَفُورٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdii{يَٰٓأَيُّهَا ٱلنَّاسُ ٱتَّقُوا۟ رَبَّكُمْ وَٱخْشَوْا۟ يَوْمًا لَّا يَجْزِى وَالِدٌ عَن وَلَدِهِۦ وَلَا مَوْلُودٌ هُوَ جَازٍ عَن وَالِدِهِۦ شَيْـًٔا إِنَّ وَعْدَ ٱللَّهِ حَقٌّ فَلَا تَغُرَّنَّكُمُ ٱلْحَيَوٰةُ ٱلدُّنْيَا وَلَا يَغُرَّنَّكُم بِٱللَّهِ ٱلْغَرُورُ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdiii{إِنَّ ٱللَّهَ عِندَهُۥ عِلْمُ ٱلسَّاعَةِ وَيُنَزِّلُ ٱلْغَيْثَ وَيَعْلَمُ مَا فِى ٱلْأَرْحَامِ وَمَا تَدْرِى نَفْسٌ مَّاذَا تَكْسِبُ غَدًا وَمَا تَدْرِى نَفْسٌۢ بِأَىِّ أَرْضٍ تَمُوتُ إِنَّ ٱللَّهَ عَلِيمٌ خَبِيرٌۢ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdiv{\basmalah الٓمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdv{تَنزِيلُ ٱلْكِتَٰبِ لَا رَيْبَ فِيهِ مِن رَّبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdvi{أَمْ يَقُولُونَ ٱفْتَرَىٰهُ بَلْ هُوَ ٱلْحَقُّ مِن رَّبِّكَ لِتُنذِرَ قَوْمًا مَّآ أَتَىٰهُم مِّن نَّذِيرٍ مِّن قَبْلِكَ لَعَلَّهُمْ يَهْتَدُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdvii{ٱللَّهُ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَمَا بَيْنَهُمَا فِى سِتَّةِ أَيَّامٍ ثُمَّ ٱسْتَوَىٰ عَلَى ٱلْعَرْشِ مَا لَكُم مِّن دُونِهِۦ مِن وَلِىٍّ وَلَا شَفِيعٍ أَفَلَا تَتَذَكَّرُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdviii{يُدَبِّرُ ٱلْأَمْرَ مِنَ ٱلسَّمَآءِ إِلَى ٱلْأَرْضِ ثُمَّ يَعْرُجُ إِلَيْهِ فِى يَوْمٍ كَانَ مِقْدَارُهُۥٓ أَلْفَ سَنَةٍ مِّمَّا تَعُدُّونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdix{ذَٰلِكَ عَٰلِمُ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdx{ٱلَّذِىٓ أَحْسَنَ كُلَّ شَىْءٍ خَلَقَهُۥ وَبَدَأَ خَلْقَ ٱلْإِنسَٰنِ مِن طِينٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdxi{ثُمَّ جَعَلَ نَسْلَهُۥ مِن سُلَٰلَةٍ مِّن مَّآءٍ مَّهِينٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdxii{ثُمَّ سَوَّىٰهُ وَنَفَخَ فِيهِ مِن رُّوحِهِۦ وَجَعَلَ لَكُمُ ٱلسَّمْعَ وَٱلْأَبْصَٰرَ وَٱلْأَفْـِٔدَةَ قَلِيلًا مَّا تَشْكُرُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdxiii{وَقَالُوٓا۟ أَءِذَا ضَلَلْنَا فِى ٱلْأَرْضِ أَءِنَّا لَفِى خَلْقٍ جَدِيدٍۭ بَلْ هُم بِلِقَآءِ رَبِّهِمْ كَٰفِرُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdxiv{قُلْ يَتَوَفَّىٰكُم مَّلَكُ ٱلْمَوْتِ ٱلَّذِى وُكِّلَ بِكُمْ ثُمَّ إِلَىٰ رَبِّكُمْ تُرْجَعُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdxv{وَلَوْ تَرَىٰٓ إِذِ ٱلْمُجْرِمُونَ نَاكِسُوا۟ رُءُوسِهِمْ عِندَ رَبِّهِمْ رَبَّنَآ أَبْصَرْنَا وَسَمِعْنَا فَٱرْجِعْنَا نَعْمَلْ صَٰلِحًا إِنَّا مُوقِنُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdxvi{وَلَوْ شِئْنَا لَءَاتَيْنَا كُلَّ نَفْسٍ هُدَىٰهَا وَلَٰكِنْ حَقَّ ٱلْقَوْلُ مِنِّى لَأَمْلَأَنَّ جَهَنَّمَ مِنَ ٱلْجِنَّةِ وَٱلنَّاسِ أَجْمَعِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdxvii{فَذُوقُوا۟ بِمَا نَسِيتُمْ لِقَآءَ يَوْمِكُمْ هَٰذَآ إِنَّا نَسِينَٰكُمْ وَذُوقُوا۟ عَذَابَ ٱلْخُلْدِ بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdxviii{إِنَّمَا يُؤْمِنُ بِـَٔايَٰتِنَا ٱلَّذِينَ إِذَا ذُكِّرُوا۟ بِهَا خَرُّوا۟ سُجَّدًا وَسَبَّحُوا۟ بِحَمْدِ رَبِّهِمْ وَهُمْ لَا يَسْتَكْبِرُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdxix{تَتَجَافَىٰ جُنُوبُهُمْ عَنِ ٱلْمَضَاجِعِ يَدْعُونَ رَبَّهُمْ خَوْفًا وَطَمَعًا وَمِمَّا رَزَقْنَٰهُمْ يُنفِقُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdxx{فَلَا تَعْلَمُ نَفْسٌ مَّآ أُخْفِىَ لَهُم مِّن قُرَّةِ أَعْيُنٍ جَزَآءًۢ بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdxxi{أَفَمَن كَانَ مُؤْمِنًا كَمَن كَانَ فَاسِقًا لَّا يَسْتَوُۥنَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdxxii{أَمَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ فَلَهُمْ جَنَّٰتُ ٱلْمَأْوَىٰ نُزُلًۢا بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdxxiii{وَأَمَّا ٱلَّذِينَ فَسَقُوا۟ فَمَأْوَىٰهُمُ ٱلنَّارُ كُلَّمَآ أَرَادُوٓا۟ أَن يَخْرُجُوا۟ مِنْهَآ أُعِيدُوا۟ فِيهَا وَقِيلَ لَهُمْ ذُوقُوا۟ عَذَابَ ٱلنَّارِ ٱلَّذِى كُنتُم بِهِۦ تُكَذِّبُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdxxiv{وَلَنُذِيقَنَّهُم مِّنَ ٱلْعَذَابِ ٱلْأَدْنَىٰ دُونَ ٱلْعَذَابِ ٱلْأَكْبَرِ لَعَلَّهُمْ يَرْجِعُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdxxv{وَمَنْ أَظْلَمُ مِمَّن ذُكِّرَ بِـَٔايَٰتِ رَبِّهِۦ ثُمَّ أَعْرَضَ عَنْهَآ إِنَّا مِنَ ٱلْمُجْرِمِينَ مُنتَقِمُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdxxvi{وَلَقَدْ ءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ فَلَا تَكُن فِى مِرْيَةٍ مِّن لِّقَآئِهِۦ وَجَعَلْنَٰهُ هُدًى لِّبَنِىٓ إِسْرَٰٓءِيلَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdxxvii{وَجَعَلْنَا مِنْهُمْ أَئِمَّةً يَهْدُونَ بِأَمْرِنَا لَمَّا صَبَرُوا۟ وَكَانُوا۟ بِـَٔايَٰتِنَا يُوقِنُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdxxviii{إِنَّ رَبَّكَ هُوَ يَفْصِلُ بَيْنَهُمْ يَوْمَ ٱلْقِيَٰمَةِ فِيمَا كَانُوا۟ فِيهِ يَخْتَلِفُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdxxix{أَوَلَمْ يَهْدِ لَهُمْ كَمْ أَهْلَكْنَا مِن قَبْلِهِم مِّنَ ٱلْقُرُونِ يَمْشُونَ فِى مَسَٰكِنِهِمْ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ أَفَلَا يَسْمَعُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdxxx{أَوَلَمْ يَرَوْا۟ أَنَّا نَسُوقُ ٱلْمَآءَ إِلَى ٱلْأَرْضِ ٱلْجُرُزِ فَنُخْرِجُ بِهِۦ زَرْعًا تَأْكُلُ مِنْهُ أَنْعَٰمُهُمْ وَأَنفُسُهُمْ أَفَلَا يُبْصِرُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdxxxi{وَيَقُولُونَ مَتَىٰ هَٰذَا ٱلْفَتْحُ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdxxxii{قُلْ يَوْمَ ٱلْفَتْحِ لَا يَنفَعُ ٱلَّذِينَ كَفَرُوٓا۟ إِيمَٰنُهُمْ وَلَا هُمْ يُنظَرُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdxxxiii{فَأَعْرِضْ عَنْهُمْ وَٱنتَظِرْ إِنَّهُم مُّنتَظِرُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdxxxiv{\basmalah يَٰٓأَيُّهَا ٱلنَّبِىُّ ٱتَّقِ ٱللَّهَ وَلَا تُطِعِ ٱلْكَٰفِرِينَ وَٱلْمُنَٰفِقِينَ إِنَّ ٱللَّهَ كَانَ عَلِيمًا حَكِيمًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdxxxv{وَٱتَّبِعْ مَا يُوحَىٰٓ إِلَيْكَ مِن رَّبِّكَ إِنَّ ٱللَّهَ كَانَ بِمَا تَعْمَلُونَ خَبِيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdxxxvi{وَتَوَكَّلْ عَلَى ٱللَّهِ وَكَفَىٰ بِٱللَّهِ وَكِيلًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdxxxvii{مَّا جَعَلَ ٱللَّهُ لِرَجُلٍ مِّن قَلْبَيْنِ فِى جَوْفِهِۦ وَمَا جَعَلَ أَزْوَٰجَكُمُ ٱلَّٰٓـِٔى تُظَٰهِرُونَ مِنْهُنَّ أُمَّهَٰتِكُمْ وَمَا جَعَلَ أَدْعِيَآءَكُمْ أَبْنَآءَكُمْ ذَٰلِكُمْ قَوْلُكُم بِأَفْوَٰهِكُمْ وَٱللَّهُ يَقُولُ ٱلْحَقَّ وَهُوَ يَهْدِى ٱلسَّبِيلَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdxxxviii{ٱدْعُوهُمْ لِءَابَآئِهِمْ هُوَ أَقْسَطُ عِندَ ٱللَّهِ فَإِن لَّمْ تَعْلَمُوٓا۟ ءَابَآءَهُمْ فَإِخْوَٰنُكُمْ فِى ٱلدِّينِ وَمَوَٰلِيكُمْ وَلَيْسَ عَلَيْكُمْ جُنَاحٌ فِيمَآ أَخْطَأْتُم بِهِۦ وَلَٰكِن مَّا تَعَمَّدَتْ قُلُوبُكُمْ وَكَانَ ٱللَّهُ غَفُورًا رَّحِيمًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdxxxix{ٱلنَّبِىُّ أَوْلَىٰ بِٱلْمُؤْمِنِينَ مِنْ أَنفُسِهِمْ وَأَزْوَٰجُهُۥٓ أُمَّهَٰتُهُمْ وَأُو۟لُوا۟ ٱلْأَرْحَامِ بَعْضُهُمْ أَوْلَىٰ بِبَعْضٍ فِى كِتَٰبِ ٱللَّهِ مِنَ ٱلْمُؤْمِنِينَ وَٱلْمُهَٰجِرِينَ إِلَّآ أَن تَفْعَلُوٓا۟ إِلَىٰٓ أَوْلِيَآئِكُم مَّعْرُوفًا كَانَ ذَٰلِكَ فِى ٱلْكِتَٰبِ مَسْطُورًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdxl{وَإِذْ أَخَذْنَا مِنَ ٱلنَّبِيِّۦنَ مِيثَٰقَهُمْ وَمِنكَ وَمِن نُّوحٍ وَإِبْرَٰهِيمَ وَمُوسَىٰ وَعِيسَى ٱبْنِ مَرْيَمَ وَأَخَذْنَا مِنْهُم مِّيثَٰقًا غَلِيظًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdxli{لِّيَسْـَٔلَ ٱلصَّٰدِقِينَ عَن صِدْقِهِمْ وَأَعَدَّ لِلْكَٰفِرِينَ عَذَابًا أَلِيمًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdxlii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱذْكُرُوا۟ نِعْمَةَ ٱللَّهِ عَلَيْكُمْ إِذْ جَآءَتْكُمْ جُنُودٌ فَأَرْسَلْنَا عَلَيْهِمْ رِيحًا وَجُنُودًا لَّمْ تَرَوْهَا وَكَانَ ٱللَّهُ بِمَا تَعْمَلُونَ بَصِيرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdxliii{إِذْ جَآءُوكُم مِّن فَوْقِكُمْ وَمِنْ أَسْفَلَ مِنكُمْ وَإِذْ زَاغَتِ ٱلْأَبْصَٰرُ وَبَلَغَتِ ٱلْقُلُوبُ ٱلْحَنَاجِرَ وَتَظُنُّونَ بِٱللَّهِ ٱلظُّنُونَا۠\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdxliv{هُنَالِكَ ٱبْتُلِىَ ٱلْمُؤْمِنُونَ وَزُلْزِلُوا۟ زِلْزَالًا شَدِيدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdxlv{وَإِذْ يَقُولُ ٱلْمُنَٰفِقُونَ وَٱلَّذِينَ فِى قُلُوبِهِم مَّرَضٌ مَّا وَعَدَنَا ٱللَّهُ وَرَسُولُهُۥٓ إِلَّا غُرُورًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdxlvi{وَإِذْ قَالَت طَّآئِفَةٌ مِّنْهُمْ يَٰٓأَهْلَ يَثْرِبَ لَا مُقَامَ لَكُمْ فَٱرْجِعُوا۟ وَيَسْتَـْٔذِنُ فَرِيقٌ مِّنْهُمُ ٱلنَّبِىَّ يَقُولُونَ إِنَّ بُيُوتَنَا عَوْرَةٌ وَمَا هِىَ بِعَوْرَةٍ إِن يُرِيدُونَ إِلَّا فِرَارًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdxlvii{وَلَوْ دُخِلَتْ عَلَيْهِم مِّنْ أَقْطَارِهَا ثُمَّ سُئِلُوا۟ ٱلْفِتْنَةَ لَءَاتَوْهَا وَمَا تَلَبَّثُوا۟ بِهَآ إِلَّا يَسِيرًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdxlviii{وَلَقَدْ كَانُوا۟ عَٰهَدُوا۟ ٱللَّهَ مِن قَبْلُ لَا يُوَلُّونَ ٱلْأَدْبَٰرَ وَكَانَ عَهْدُ ٱللَّهِ مَسْـُٔولًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdxlix{قُل لَّن يَنفَعَكُمُ ٱلْفِرَارُ إِن فَرَرْتُم مِّنَ ٱلْمَوْتِ أَوِ ٱلْقَتْلِ وَإِذًا لَّا تُمَتَّعُونَ إِلَّا قَلِيلًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdl{قُلْ مَن ذَا ٱلَّذِى يَعْصِمُكُم مِّنَ ٱللَّهِ إِنْ أَرَادَ بِكُمْ سُوٓءًا أَوْ أَرَادَ بِكُمْ رَحْمَةً وَلَا يَجِدُونَ لَهُم مِّن دُونِ ٱللَّهِ وَلِيًّا وَلَا نَصِيرًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdli{قَدْ يَعْلَمُ ٱللَّهُ ٱلْمُعَوِّقِينَ مِنكُمْ وَٱلْقَآئِلِينَ لِإِخْوَٰنِهِمْ هَلُمَّ إِلَيْنَا وَلَا يَأْتُونَ ٱلْبَأْسَ إِلَّا قَلِيلًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdlii{أَشِحَّةً عَلَيْكُمْ فَإِذَا جَآءَ ٱلْخَوْفُ رَأَيْتَهُمْ يَنظُرُونَ إِلَيْكَ تَدُورُ أَعْيُنُهُمْ كَٱلَّذِى يُغْشَىٰ عَلَيْهِ مِنَ ٱلْمَوْتِ فَإِذَا ذَهَبَ ٱلْخَوْفُ سَلَقُوكُم بِأَلْسِنَةٍ حِدَادٍ أَشِحَّةً عَلَى ٱلْخَيْرِ أُو۟لَٰٓئِكَ لَمْ يُؤْمِنُوا۟ فَأَحْبَطَ ٱللَّهُ أَعْمَٰلَهُمْ وَكَانَ ذَٰلِكَ عَلَى ٱللَّهِ يَسِيرًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdliii{يَحْسَبُونَ ٱلْأَحْزَابَ لَمْ يَذْهَبُوا۟ وَإِن يَأْتِ ٱلْأَحْزَابُ يَوَدُّوا۟ لَوْ أَنَّهُم بَادُونَ فِى ٱلْأَعْرَابِ يَسْـَٔلُونَ عَنْ أَنۢبَآئِكُمْ وَلَوْ كَانُوا۟ فِيكُم مَّا قَٰتَلُوٓا۟ إِلَّا قَلِيلًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdliv{لَّقَدْ كَانَ لَكُمْ فِى رَسُولِ ٱللَّهِ أُسْوَةٌ حَسَنَةٌ لِّمَن كَانَ يَرْجُوا۟ ٱللَّهَ وَٱلْيَوْمَ ٱلْءَاخِرَ وَذَكَرَ ٱللَّهَ كَثِيرًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdlv{وَلَمَّا رَءَا ٱلْمُؤْمِنُونَ ٱلْأَحْزَابَ قَالُوا۟ هَٰذَا مَا وَعَدَنَا ٱللَّهُ وَرَسُولُهُۥ وَصَدَقَ ٱللَّهُ وَرَسُولُهُۥ وَمَا زَادَهُمْ إِلَّآ إِيمَٰنًا وَتَسْلِيمًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdlvi{مِّنَ ٱلْمُؤْمِنِينَ رِجَالٌ صَدَقُوا۟ مَا عَٰهَدُوا۟ ٱللَّهَ عَلَيْهِ فَمِنْهُم مَّن قَضَىٰ نَحْبَهُۥ وَمِنْهُم مَّن يَنتَظِرُ وَمَا بَدَّلُوا۟ تَبْدِيلًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdlvii{لِّيَجْزِىَ ٱللَّهُ ٱلصَّٰدِقِينَ بِصِدْقِهِمْ وَيُعَذِّبَ ٱلْمُنَٰفِقِينَ إِن شَآءَ أَوْ يَتُوبَ عَلَيْهِمْ إِنَّ ٱللَّهَ كَانَ غَفُورًا رَّحِيمًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdlviii{وَرَدَّ ٱللَّهُ ٱلَّذِينَ كَفَرُوا۟ بِغَيْظِهِمْ لَمْ يَنَالُوا۟ خَيْرًا وَكَفَى ٱللَّهُ ٱلْمُؤْمِنِينَ ٱلْقِتَالَ وَكَانَ ٱللَّهُ قَوِيًّا عَزِيزًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdlix{وَأَنزَلَ ٱلَّذِينَ ظَٰهَرُوهُم مِّنْ أَهْلِ ٱلْكِتَٰبِ مِن صَيَاصِيهِمْ وَقَذَفَ فِى قُلُوبِهِمُ ٱلرُّعْبَ فَرِيقًا تَقْتُلُونَ وَتَأْسِرُونَ فَرِيقًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdlx{وَأَوْرَثَكُمْ أَرْضَهُمْ وَدِيَٰرَهُمْ وَأَمْوَٰلَهُمْ وَأَرْضًا لَّمْ تَطَـُٔوهَا وَكَانَ ٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdlxi{يَٰٓأَيُّهَا ٱلنَّبِىُّ قُل لِّأَزْوَٰجِكَ إِن كُنتُنَّ تُرِدْنَ ٱلْحَيَوٰةَ ٱلدُّنْيَا وَزِينَتَهَا فَتَعَالَيْنَ أُمَتِّعْكُنَّ وَأُسَرِّحْكُنَّ سَرَاحًا جَمِيلًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdlxii{وَإِن كُنتُنَّ تُرِدْنَ ٱللَّهَ وَرَسُولَهُۥ وَٱلدَّارَ ٱلْءَاخِرَةَ فَإِنَّ ٱللَّهَ أَعَدَّ لِلْمُحْسِنَٰتِ مِنكُنَّ أَجْرًا عَظِيمًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdlxiii{يَٰنِسَآءَ ٱلنَّبِىِّ مَن يَأْتِ مِنكُنَّ بِفَٰحِشَةٍ مُّبَيِّنَةٍ يُضَٰعَفْ لَهَا ٱلْعَذَابُ ضِعْفَيْنِ وَكَانَ ذَٰلِكَ عَلَى ٱللَّهِ يَسِيرًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdlxiv{وَمَن يَقْنُتْ مِنكُنَّ لِلَّهِ وَرَسُولِهِۦ وَتَعْمَلْ صَٰلِحًا نُّؤْتِهَآ أَجْرَهَا مَرَّتَيْنِ وَأَعْتَدْنَا لَهَا رِزْقًا كَرِيمًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdlxv{يَٰنِسَآءَ ٱلنَّبِىِّ لَسْتُنَّ كَأَحَدٍ مِّنَ ٱلنِّسَآءِ إِنِ ٱتَّقَيْتُنَّ فَلَا تَخْضَعْنَ بِٱلْقَوْلِ فَيَطْمَعَ ٱلَّذِى فِى قَلْبِهِۦ مَرَضٌ وَقُلْنَ قَوْلًا مَّعْرُوفًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdlxvi{وَقَرْنَ فِى بُيُوتِكُنَّ وَلَا تَبَرَّجْنَ تَبَرُّجَ ٱلْجَٰهِلِيَّةِ ٱلْأُولَىٰ وَأَقِمْنَ ٱلصَّلَوٰةَ وَءَاتِينَ ٱلزَّكَوٰةَ وَأَطِعْنَ ٱللَّهَ وَرَسُولَهُۥٓ إِنَّمَا يُرِيدُ ٱللَّهُ لِيُذْهِبَ عَنكُمُ ٱلرِّجْسَ أَهْلَ ٱلْبَيْتِ وَيُطَهِّرَكُمْ تَطْهِيرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdlxvii{وَٱذْكُرْنَ مَا يُتْلَىٰ فِى بُيُوتِكُنَّ مِنْ ءَايَٰتِ ٱللَّهِ وَٱلْحِكْمَةِ إِنَّ ٱللَّهَ كَانَ لَطِيفًا خَبِيرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdlxviii{إِنَّ ٱلْمُسْلِمِينَ وَٱلْمُسْلِمَٰتِ وَٱلْمُؤْمِنِينَ وَٱلْمُؤْمِنَٰتِ وَٱلْقَٰنِتِينَ وَٱلْقَٰنِتَٰتِ وَٱلصَّٰدِقِينَ وَٱلصَّٰدِقَٰتِ وَٱلصَّٰبِرِينَ وَٱلصَّٰبِرَٰتِ وَٱلْخَٰشِعِينَ وَٱلْخَٰشِعَٰتِ وَٱلْمُتَصَدِّقِينَ وَٱلْمُتَصَدِّقَٰتِ وَٱلصَّٰٓئِمِينَ وَٱلصَّٰٓئِمَٰتِ وَٱلْحَٰفِظِينَ فُرُوجَهُمْ وَٱلْحَٰفِظَٰتِ وَٱلذَّٰكِرِينَ ٱللَّهَ كَثِيرًا وَٱلذَّٰكِرَٰتِ أَعَدَّ ٱللَّهُ لَهُم مَّغْفِرَةً وَأَجْرًا عَظِيمًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdlxix{وَمَا كَانَ لِمُؤْمِنٍ وَلَا مُؤْمِنَةٍ إِذَا قَضَى ٱللَّهُ وَرَسُولُهُۥٓ أَمْرًا أَن يَكُونَ لَهُمُ ٱلْخِيَرَةُ مِنْ أَمْرِهِمْ وَمَن يَعْصِ ٱللَّهَ وَرَسُولَهُۥ فَقَدْ ضَلَّ ضَلَٰلًا مُّبِينًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdlxx{وَإِذْ تَقُولُ لِلَّذِىٓ أَنْعَمَ ٱللَّهُ عَلَيْهِ وَأَنْعَمْتَ عَلَيْهِ أَمْسِكْ عَلَيْكَ زَوْجَكَ وَٱتَّقِ ٱللَّهَ وَتُخْفِى فِى نَفْسِكَ مَا ٱللَّهُ مُبْدِيهِ وَتَخْشَى ٱلنَّاسَ وَٱللَّهُ أَحَقُّ أَن تَخْشَىٰهُ فَلَمَّا قَضَىٰ زَيْدٌ مِّنْهَا وَطَرًا زَوَّجْنَٰكَهَا لِكَىْ لَا يَكُونَ عَلَى ٱلْمُؤْمِنِينَ حَرَجٌ فِىٓ أَزْوَٰجِ أَدْعِيَآئِهِمْ إِذَا قَضَوْا۟ مِنْهُنَّ وَطَرًا وَكَانَ أَمْرُ ٱللَّهِ مَفْعُولًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdlxxi{مَّا كَانَ عَلَى ٱلنَّبِىِّ مِنْ حَرَجٍ فِيمَا فَرَضَ ٱللَّهُ لَهُۥ سُنَّةَ ٱللَّهِ فِى ٱلَّذِينَ خَلَوْا۟ مِن قَبْلُ وَكَانَ أَمْرُ ٱللَّهِ قَدَرًا مَّقْدُورًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdlxxii{ٱلَّذِينَ يُبَلِّغُونَ رِسَٰلَٰتِ ٱللَّهِ وَيَخْشَوْنَهُۥ وَلَا يَخْشَوْنَ أَحَدًا إِلَّا ٱللَّهَ وَكَفَىٰ بِٱللَّهِ حَسِيبًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdlxxiii{مَّا كَانَ مُحَمَّدٌ أَبَآ أَحَدٍ مِّن رِّجَالِكُمْ وَلَٰكِن رَّسُولَ ٱللَّهِ وَخَاتَمَ ٱلنَّبِيِّۦنَ وَكَانَ ٱللَّهُ بِكُلِّ شَىْءٍ عَلِيمًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdlxxiv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱذْكُرُوا۟ ٱللَّهَ ذِكْرًا كَثِيرًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdlxxv{وَسَبِّحُوهُ بُكْرَةً وَأَصِيلًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdlxxvi{هُوَ ٱلَّذِى يُصَلِّى عَلَيْكُمْ وَمَلَٰٓئِكَتُهُۥ لِيُخْرِجَكُم مِّنَ ٱلظُّلُمَٰتِ إِلَى ٱلنُّورِ وَكَانَ بِٱلْمُؤْمِنِينَ رَحِيمًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdlxxvii{تَحِيَّتُهُمْ يَوْمَ يَلْقَوْنَهُۥ سَلَٰمٌ وَأَعَدَّ لَهُمْ أَجْرًا كَرِيمًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdlxxviii{يَٰٓأَيُّهَا ٱلنَّبِىُّ إِنَّآ أَرْسَلْنَٰكَ شَٰهِدًا وَمُبَشِّرًا وَنَذِيرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdlxxix{وَدَاعِيًا إِلَى ٱللَّهِ بِإِذْنِهِۦ وَسِرَاجًا مُّنِيرًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdlxxx{وَبَشِّرِ ٱلْمُؤْمِنِينَ بِأَنَّ لَهُم مِّنَ ٱللَّهِ فَضْلًا كَبِيرًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdlxxxi{وَلَا تُطِعِ ٱلْكَٰفِرِينَ وَٱلْمُنَٰفِقِينَ وَدَعْ أَذَىٰهُمْ وَتَوَكَّلْ عَلَى ٱللَّهِ وَكَفَىٰ بِٱللَّهِ وَكِيلًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdlxxxii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا نَكَحْتُمُ ٱلْمُؤْمِنَٰتِ ثُمَّ طَلَّقْتُمُوهُنَّ مِن قَبْلِ أَن تَمَسُّوهُنَّ فَمَا لَكُمْ عَلَيْهِنَّ مِنْ عِدَّةٍ تَعْتَدُّونَهَا فَمَتِّعُوهُنَّ وَسَرِّحُوهُنَّ سَرَاحًا جَمِيلًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdlxxxiii{يَٰٓأَيُّهَا ٱلنَّبِىُّ إِنَّآ أَحْلَلْنَا لَكَ أَزْوَٰجَكَ ٱلَّٰتِىٓ ءَاتَيْتَ أُجُورَهُنَّ وَمَا مَلَكَتْ يَمِينُكَ مِمَّآ أَفَآءَ ٱللَّهُ عَلَيْكَ وَبَنَاتِ عَمِّكَ وَبَنَاتِ عَمَّٰتِكَ وَبَنَاتِ خَالِكَ وَبَنَاتِ خَٰلَٰتِكَ ٱلَّٰتِى هَاجَرْنَ مَعَكَ وَٱمْرَأَةً مُّؤْمِنَةً إِن وَهَبَتْ نَفْسَهَا لِلنَّبِىِّ إِنْ أَرَادَ ٱلنَّبِىُّ أَن يَسْتَنكِحَهَا خَالِصَةً لَّكَ مِن دُونِ ٱلْمُؤْمِنِينَ قَدْ عَلِمْنَا مَا فَرَضْنَا عَلَيْهِمْ فِىٓ أَزْوَٰجِهِمْ وَمَا مَلَكَتْ أَيْمَٰنُهُمْ لِكَيْلَا يَكُونَ عَلَيْكَ حَرَجٌ وَكَانَ ٱللَّهُ غَفُورًا رَّحِيمًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdlxxxiv{تُرْجِى مَن تَشَآءُ مِنْهُنَّ وَتُـْٔوِىٓ إِلَيْكَ مَن تَشَآءُ وَمَنِ ٱبْتَغَيْتَ مِمَّنْ عَزَلْتَ فَلَا جُنَاحَ عَلَيْكَ ذَٰلِكَ أَدْنَىٰٓ أَن تَقَرَّ أَعْيُنُهُنَّ وَلَا يَحْزَنَّ وَيَرْضَيْنَ بِمَآ ءَاتَيْتَهُنَّ كُلُّهُنَّ وَٱللَّهُ يَعْلَمُ مَا فِى قُلُوبِكُمْ وَكَانَ ٱللَّهُ عَلِيمًا حَلِيمًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdlxxxv{لَّا يَحِلُّ لَكَ ٱلنِّسَآءُ مِنۢ بَعْدُ وَلَآ أَن تَبَدَّلَ بِهِنَّ مِنْ أَزْوَٰجٍ وَلَوْ أَعْجَبَكَ حُسْنُهُنَّ إِلَّا مَا مَلَكَتْ يَمِينُكَ وَكَانَ ٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ رَّقِيبًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdlxxxvi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَدْخُلُوا۟ بُيُوتَ ٱلنَّبِىِّ إِلَّآ أَن يُؤْذَنَ لَكُمْ إِلَىٰ طَعَامٍ غَيْرَ نَٰظِرِينَ إِنَىٰهُ وَلَٰكِنْ إِذَا دُعِيتُمْ فَٱدْخُلُوا۟ فَإِذَا طَعِمْتُمْ فَٱنتَشِرُوا۟ وَلَا مُسْتَـْٔنِسِينَ لِحَدِيثٍ إِنَّ ذَٰلِكُمْ كَانَ يُؤْذِى ٱلنَّبِىَّ فَيَسْتَحْىِۦ مِنكُمْ وَٱللَّهُ لَا يَسْتَحْىِۦ مِنَ ٱلْحَقِّ وَإِذَا سَأَلْتُمُوهُنَّ مَتَٰعًا فَسْـَٔلُوهُنَّ مِن وَرَآءِ حِجَابٍ ذَٰلِكُمْ أَطْهَرُ لِقُلُوبِكُمْ وَقُلُوبِهِنَّ وَمَا كَانَ لَكُمْ أَن تُؤْذُوا۟ رَسُولَ ٱللَّهِ وَلَآ أَن تَنكِحُوٓا۟ أَزْوَٰجَهُۥ مِنۢ بَعْدِهِۦٓ أَبَدًا إِنَّ ذَٰلِكُمْ كَانَ عِندَ ٱللَّهِ عَظِيمًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdlxxxvii{إِن تُبْدُوا۟ شَيْـًٔا أَوْ تُخْفُوهُ فَإِنَّ ٱللَّهَ كَانَ بِكُلِّ شَىْءٍ عَلِيمًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdlxxxviii{لَّا جُنَاحَ عَلَيْهِنَّ فِىٓ ءَابَآئِهِنَّ وَلَآ أَبْنَآئِهِنَّ وَلَآ إِخْوَٰنِهِنَّ وَلَآ أَبْنَآءِ إِخْوَٰنِهِنَّ وَلَآ أَبْنَآءِ أَخَوَٰتِهِنَّ وَلَا نِسَآئِهِنَّ وَلَا مَا مَلَكَتْ أَيْمَٰنُهُنَّ وَٱتَّقِينَ ٱللَّهَ إِنَّ ٱللَّهَ كَانَ عَلَىٰ كُلِّ شَىْءٍ شَهِيدًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmdlxxxix{إِنَّ ٱللَّهَ وَمَلَٰٓئِكَتَهُۥ يُصَلُّونَ عَلَى ٱلنَّبِىِّ يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ صَلُّوا۟ عَلَيْهِ وَسَلِّمُوا۟ تَسْلِيمًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmdxc{إِنَّ ٱلَّذِينَ يُؤْذُونَ ٱللَّهَ وَرَسُولَهُۥ لَعَنَهُمُ ٱللَّهُ فِى ٱلدُّنْيَا وَٱلْءَاخِرَةِ وَأَعَدَّ لَهُمْ عَذَابًا مُّهِينًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmdxci{وَٱلَّذِينَ يُؤْذُونَ ٱلْمُؤْمِنِينَ وَٱلْمُؤْمِنَٰتِ بِغَيْرِ مَا ٱكْتَسَبُوا۟ فَقَدِ ٱحْتَمَلُوا۟ بُهْتَٰنًا وَإِثْمًا مُّبِينًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmdxcii{يَٰٓأَيُّهَا ٱلنَّبِىُّ قُل لِّأَزْوَٰجِكَ وَبَنَاتِكَ وَنِسَآءِ ٱلْمُؤْمِنِينَ يُدْنِينَ عَلَيْهِنَّ مِن جَلَٰبِيبِهِنَّ ذَٰلِكَ أَدْنَىٰٓ أَن يُعْرَفْنَ فَلَا يُؤْذَيْنَ وَكَانَ ٱللَّهُ غَفُورًا رَّحِيمًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmdxciii{لَّئِن لَّمْ يَنتَهِ ٱلْمُنَٰفِقُونَ وَٱلَّذِينَ فِى قُلُوبِهِم مَّرَضٌ وَٱلْمُرْجِفُونَ فِى ٱلْمَدِينَةِ لَنُغْرِيَنَّكَ بِهِمْ ثُمَّ لَا يُجَاوِرُونَكَ فِيهَآ إِلَّا قَلِيلًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmdxciv{مَّلْعُونِينَ أَيْنَمَا ثُقِفُوٓا۟ أُخِذُوا۟ وَقُتِّلُوا۟ تَقْتِيلًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmdxcv{سُنَّةَ ٱللَّهِ فِى ٱلَّذِينَ خَلَوْا۟ مِن قَبْلُ وَلَن تَجِدَ لِسُنَّةِ ٱللَّهِ تَبْدِيلًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmdxcvi{يَسْـَٔلُكَ ٱلنَّاسُ عَنِ ٱلسَّاعَةِ قُلْ إِنَّمَا عِلْمُهَا عِندَ ٱللَّهِ وَمَا يُدْرِيكَ لَعَلَّ ٱلسَّاعَةَ تَكُونُ قَرِيبًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmdxcvii{إِنَّ ٱللَّهَ لَعَنَ ٱلْكَٰفِرِينَ وَأَعَدَّ لَهُمْ سَعِيرًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmdxcviii{خَٰلِدِينَ فِيهَآ أَبَدًا لَّا يَجِدُونَ وَلِيًّا وَلَا نَصِيرًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmdxcix{يَوْمَ تُقَلَّبُ وُجُوهُهُمْ فِى ٱلنَّارِ يَقُولُونَ يَٰلَيْتَنَآ أَطَعْنَا ٱللَّهَ وَأَطَعْنَا ٱلرَّسُولَا۠\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmdc{وَقَالُوا۟ رَبَّنَآ إِنَّآ أَطَعْنَا سَادَتَنَا وَكُبَرَآءَنَا فَأَضَلُّونَا ٱلسَّبِيلَا۠\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmdci{رَبَّنَآ ءَاتِهِمْ ضِعْفَيْنِ مِنَ ٱلْعَذَابِ وَٱلْعَنْهُمْ لَعْنًا كَبِيرًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmdcii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَكُونُوا۟ كَٱلَّذِينَ ءَاذَوْا۟ مُوسَىٰ فَبَرَّأَهُ ٱللَّهُ مِمَّا قَالُوا۟ وَكَانَ عِندَ ٱللَّهِ وَجِيهًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmdciii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱتَّقُوا۟ ٱللَّهَ وَقُولُوا۟ قَوْلًا سَدِيدًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmdciv{يُصْلِحْ لَكُمْ أَعْمَٰلَكُمْ وَيَغْفِرْ لَكُمْ ذُنُوبَكُمْ وَمَن يُطِعِ ٱللَّهَ وَرَسُولَهُۥ فَقَدْ فَازَ فَوْزًا عَظِيمًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmdcv{إِنَّا عَرَضْنَا ٱلْأَمَانَةَ عَلَى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱلْجِبَالِ فَأَبَيْنَ أَن يَحْمِلْنَهَا وَأَشْفَقْنَ مِنْهَا وَحَمَلَهَا ٱلْإِنسَٰنُ إِنَّهُۥ كَانَ ظَلُومًا جَهُولًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmdcvi{لِّيُعَذِّبَ ٱللَّهُ ٱلْمُنَٰفِقِينَ وَٱلْمُنَٰفِقَٰتِ وَٱلْمُشْرِكِينَ وَٱلْمُشْرِكَٰتِ وَيَتُوبَ ٱللَّهُ عَلَى ٱلْمُؤْمِنِينَ وَٱلْمُؤْمِنَٰتِ وَكَانَ ٱللَّهُ غَفُورًا رَّحِيمًۢا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmdcvii{\basmalah ٱلْحَمْدُ لِلَّهِ ٱلَّذِى لَهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَلَهُ ٱلْحَمْدُ فِى ٱلْءَاخِرَةِ وَهُوَ ٱلْحَكِيمُ ٱلْخَبِيرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdcviii{يَعْلَمُ مَا يَلِجُ فِى ٱلْأَرْضِ وَمَا يَخْرُجُ مِنْهَا وَمَا يَنزِلُ مِنَ ٱلسَّمَآءِ وَمَا يَعْرُجُ فِيهَا وَهُوَ ٱلرَّحِيمُ ٱلْغَفُورُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdcix{وَقَالَ ٱلَّذِينَ كَفَرُوا۟ لَا تَأْتِينَا ٱلسَّاعَةُ قُلْ بَلَىٰ وَرَبِّى لَتَأْتِيَنَّكُمْ عَٰلِمِ ٱلْغَيْبِ لَا يَعْزُبُ عَنْهُ مِثْقَالُ ذَرَّةٍ فِى ٱلسَّمَٰوَٰتِ وَلَا فِى ٱلْأَرْضِ وَلَآ أَصْغَرُ مِن ذَٰلِكَ وَلَآ أَكْبَرُ إِلَّا فِى كِتَٰبٍ مُّبِينٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdcx{لِّيَجْزِىَ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ أُو۟لَٰٓئِكَ لَهُم مَّغْفِرَةٌ وَرِزْقٌ كَرِيمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdcxi{وَٱلَّذِينَ سَعَوْ فِىٓ ءَايَٰتِنَا مُعَٰجِزِينَ أُو۟لَٰٓئِكَ لَهُمْ عَذَابٌ مِّن رِّجْزٍ أَلِيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdcxii{وَيَرَى ٱلَّذِينَ أُوتُوا۟ ٱلْعِلْمَ ٱلَّذِىٓ أُنزِلَ إِلَيْكَ مِن رَّبِّكَ هُوَ ٱلْحَقَّ وَيَهْدِىٓ إِلَىٰ صِرَٰطِ ٱلْعَزِيزِ ٱلْحَمِيدِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdcxiii{وَقَالَ ٱلَّذِينَ كَفَرُوا۟ هَلْ نَدُلُّكُمْ عَلَىٰ رَجُلٍ يُنَبِّئُكُمْ إِذَا مُزِّقْتُمْ كُلَّ مُمَزَّقٍ إِنَّكُمْ لَفِى خَلْقٍ جَدِيدٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdcxiv{أَفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا أَم بِهِۦ جِنَّةٌۢ بَلِ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ فِى ٱلْعَذَابِ وَٱلضَّلَٰلِ ٱلْبَعِيدِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdcxv{أَفَلَمْ يَرَوْا۟ إِلَىٰ مَا بَيْنَ أَيْدِيهِمْ وَمَا خَلْفَهُم مِّنَ ٱلسَّمَآءِ وَٱلْأَرْضِ إِن نَّشَأْ نَخْسِفْ بِهِمُ ٱلْأَرْضَ أَوْ نُسْقِطْ عَلَيْهِمْ كِسَفًا مِّنَ ٱلسَّمَآءِ إِنَّ فِى ذَٰلِكَ لَءَايَةً لِّكُلِّ عَبْدٍ مُّنِيبٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdcxvi{وَلَقَدْ ءَاتَيْنَا دَاوُۥدَ مِنَّا فَضْلًا يَٰجِبَالُ أَوِّبِى مَعَهُۥ وَٱلطَّيْرَ وَأَلَنَّا لَهُ ٱلْحَدِيدَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdcxvii{أَنِ ٱعْمَلْ سَٰبِغَٰتٍ وَقَدِّرْ فِى ٱلسَّرْدِ وَٱعْمَلُوا۟ صَٰلِحًا إِنِّى بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdcxviii{وَلِسُلَيْمَٰنَ ٱلرِّيحَ غُدُوُّهَا شَهْرٌ وَرَوَاحُهَا شَهْرٌ وَأَسَلْنَا لَهُۥ عَيْنَ ٱلْقِطْرِ وَمِنَ ٱلْجِنِّ مَن يَعْمَلُ بَيْنَ يَدَيْهِ بِإِذْنِ رَبِّهِۦ وَمَن يَزِغْ مِنْهُمْ عَنْ أَمْرِنَا نُذِقْهُ مِنْ عَذَابِ ٱلسَّعِيرِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdcxix{يَعْمَلُونَ لَهُۥ مَا يَشَآءُ مِن مَّحَٰرِيبَ وَتَمَٰثِيلَ وَجِفَانٍ كَٱلْجَوَابِ وَقُدُورٍ رَّاسِيَٰتٍ ٱعْمَلُوٓا۟ ءَالَ دَاوُۥدَ شُكْرًا وَقَلِيلٌ مِّنْ عِبَادِىَ ٱلشَّكُورُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdcxx{فَلَمَّا قَضَيْنَا عَلَيْهِ ٱلْمَوْتَ مَا دَلَّهُمْ عَلَىٰ مَوْتِهِۦٓ إِلَّا دَآبَّةُ ٱلْأَرْضِ تَأْكُلُ مِنسَأَتَهُۥ فَلَمَّا خَرَّ تَبَيَّنَتِ ٱلْجِنُّ أَن لَّوْ كَانُوا۟ يَعْلَمُونَ ٱلْغَيْبَ مَا لَبِثُوا۟ فِى ٱلْعَذَابِ ٱلْمُهِينِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdcxxi{لَقَدْ كَانَ لِسَبَإٍ فِى مَسْكَنِهِمْ ءَايَةٌ جَنَّتَانِ عَن يَمِينٍ وَشِمَالٍ كُلُوا۟ مِن رِّزْقِ رَبِّكُمْ وَٱشْكُرُوا۟ لَهُۥ بَلْدَةٌ طَيِّبَةٌ وَرَبٌّ غَفُورٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdcxxii{فَأَعْرَضُوا۟ فَأَرْسَلْنَا عَلَيْهِمْ سَيْلَ ٱلْعَرِمِ وَبَدَّلْنَٰهُم بِجَنَّتَيْهِمْ جَنَّتَيْنِ ذَوَاتَىْ أُكُلٍ خَمْطٍ وَأَثْلٍ وَشَىْءٍ مِّن سِدْرٍ قَلِيلٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdcxxiii{ذَٰلِكَ جَزَيْنَٰهُم بِمَا كَفَرُوا۟ وَهَلْ نُجَٰزِىٓ إِلَّا ٱلْكَفُورَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdcxxiv{وَجَعَلْنَا بَيْنَهُمْ وَبَيْنَ ٱلْقُرَى ٱلَّتِى بَٰرَكْنَا فِيهَا قُرًى ظَٰهِرَةً وَقَدَّرْنَا فِيهَا ٱلسَّيْرَ سِيرُوا۟ فِيهَا لَيَالِىَ وَأَيَّامًا ءَامِنِينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdcxxv{فَقَالُوا۟ رَبَّنَا بَٰعِدْ بَيْنَ أَسْفَارِنَا وَظَلَمُوٓا۟ أَنفُسَهُمْ فَجَعَلْنَٰهُمْ أَحَادِيثَ وَمَزَّقْنَٰهُمْ كُلَّ مُمَزَّقٍ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّكُلِّ صَبَّارٍ شَكُورٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdcxxvi{وَلَقَدْ صَدَّقَ عَلَيْهِمْ إِبْلِيسُ ظَنَّهُۥ فَٱتَّبَعُوهُ إِلَّا فَرِيقًا مِّنَ ٱلْمُؤْمِنِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdcxxvii{وَمَا كَانَ لَهُۥ عَلَيْهِم مِّن سُلْطَٰنٍ إِلَّا لِنَعْلَمَ مَن يُؤْمِنُ بِٱلْءَاخِرَةِ مِمَّنْ هُوَ مِنْهَا فِى شَكٍّ وَرَبُّكَ عَلَىٰ كُلِّ شَىْءٍ حَفِيظٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdcxxviii{قُلِ ٱدْعُوا۟ ٱلَّذِينَ زَعَمْتُم مِّن دُونِ ٱللَّهِ لَا يَمْلِكُونَ مِثْقَالَ ذَرَّةٍ فِى ٱلسَّمَٰوَٰتِ وَلَا فِى ٱلْأَرْضِ وَمَا لَهُمْ فِيهِمَا مِن شِرْكٍ وَمَا لَهُۥ مِنْهُم مِّن ظَهِيرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdcxxix{وَلَا تَنفَعُ ٱلشَّفَٰعَةُ عِندَهُۥٓ إِلَّا لِمَنْ أَذِنَ لَهُۥ حَتَّىٰٓ إِذَا فُزِّعَ عَن قُلُوبِهِمْ قَالُوا۟ مَاذَا قَالَ رَبُّكُمْ قَالُوا۟ ٱلْحَقَّ وَهُوَ ٱلْعَلِىُّ ٱلْكَبِيرُ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdcxxx{قُلْ مَن يَرْزُقُكُم مِّنَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ قُلِ ٱللَّهُ وَإِنَّآ أَوْ إِيَّاكُمْ لَعَلَىٰ هُدًى أَوْ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdcxxxi{قُل لَّا تُسْـَٔلُونَ عَمَّآ أَجْرَمْنَا وَلَا نُسْـَٔلُ عَمَّا تَعْمَلُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdcxxxii{قُلْ يَجْمَعُ بَيْنَنَا رَبُّنَا ثُمَّ يَفْتَحُ بَيْنَنَا بِٱلْحَقِّ وَهُوَ ٱلْفَتَّاحُ ٱلْعَلِيمُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdcxxxiii{قُلْ أَرُونِىَ ٱلَّذِينَ أَلْحَقْتُم بِهِۦ شُرَكَآءَ كَلَّا بَلْ هُوَ ٱللَّهُ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdcxxxiv{وَمَآ أَرْسَلْنَٰكَ إِلَّا كَآفَّةً لِّلنَّاسِ بَشِيرًا وَنَذِيرًا وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdcxxxv{وَيَقُولُونَ مَتَىٰ هَٰذَا ٱلْوَعْدُ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdcxxxvi{قُل لَّكُم مِّيعَادُ يَوْمٍ لَّا تَسْتَـْٔخِرُونَ عَنْهُ سَاعَةً وَلَا تَسْتَقْدِمُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdcxxxvii{وَقَالَ ٱلَّذِينَ كَفَرُوا۟ لَن نُّؤْمِنَ بِهَٰذَا ٱلْقُرْءَانِ وَلَا بِٱلَّذِى بَيْنَ يَدَيْهِ وَلَوْ تَرَىٰٓ إِذِ ٱلظَّٰلِمُونَ مَوْقُوفُونَ عِندَ رَبِّهِمْ يَرْجِعُ بَعْضُهُمْ إِلَىٰ بَعْضٍ ٱلْقَوْلَ يَقُولُ ٱلَّذِينَ ٱسْتُضْعِفُوا۟ لِلَّذِينَ ٱسْتَكْبَرُوا۟ لَوْلَآ أَنتُمْ لَكُنَّا مُؤْمِنِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdcxxxviii{قَالَ ٱلَّذِينَ ٱسْتَكْبَرُوا۟ لِلَّذِينَ ٱسْتُضْعِفُوٓا۟ أَنَحْنُ صَدَدْنَٰكُمْ عَنِ ٱلْهُدَىٰ بَعْدَ إِذْ جَآءَكُم بَلْ كُنتُم مُّجْرِمِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdcxxxix{وَقَالَ ٱلَّذِينَ ٱسْتُضْعِفُوا۟ لِلَّذِينَ ٱسْتَكْبَرُوا۟ بَلْ مَكْرُ ٱلَّيْلِ وَٱلنَّهَارِ إِذْ تَأْمُرُونَنَآ أَن نَّكْفُرَ بِٱللَّهِ وَنَجْعَلَ لَهُۥٓ أَندَادًا وَأَسَرُّوا۟ ٱلنَّدَامَةَ لَمَّا رَأَوُا۟ ٱلْعَذَابَ وَجَعَلْنَا ٱلْأَغْلَٰلَ فِىٓ أَعْنَاقِ ٱلَّذِينَ كَفَرُوا۟ هَلْ يُجْزَوْنَ إِلَّا مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdcxl{وَمَآ أَرْسَلْنَا فِى قَرْيَةٍ مِّن نَّذِيرٍ إِلَّا قَالَ مُتْرَفُوهَآ إِنَّا بِمَآ أُرْسِلْتُم بِهِۦ كَٰفِرُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdcxli{وَقَالُوا۟ نَحْنُ أَكْثَرُ أَمْوَٰلًا وَأَوْلَٰدًا وَمَا نَحْنُ بِمُعَذَّبِينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdcxlii{قُلْ إِنَّ رَبِّى يَبْسُطُ ٱلرِّزْقَ لِمَن يَشَآءُ وَيَقْدِرُ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdcxliii{وَمَآ أَمْوَٰلُكُمْ وَلَآ أَوْلَٰدُكُم بِٱلَّتِى تُقَرِّبُكُمْ عِندَنَا زُلْفَىٰٓ إِلَّا مَنْ ءَامَنَ وَعَمِلَ صَٰلِحًا فَأُو۟لَٰٓئِكَ لَهُمْ جَزَآءُ ٱلضِّعْفِ بِمَا عَمِلُوا۟ وَهُمْ فِى ٱلْغُرُفَٰتِ ءَامِنُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdcxliv{وَٱلَّذِينَ يَسْعَوْنَ فِىٓ ءَايَٰتِنَا مُعَٰجِزِينَ أُو۟لَٰٓئِكَ فِى ٱلْعَذَابِ مُحْضَرُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdcxlv{قُلْ إِنَّ رَبِّى يَبْسُطُ ٱلرِّزْقَ لِمَن يَشَآءُ مِنْ عِبَادِهِۦ وَيَقْدِرُ لَهُۥ وَمَآ أَنفَقْتُم مِّن شَىْءٍ فَهُوَ يُخْلِفُهُۥ وَهُوَ خَيْرُ ٱلرَّٰزِقِينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdcxlvi{وَيَوْمَ يَحْشُرُهُمْ جَمِيعًا ثُمَّ يَقُولُ لِلْمَلَٰٓئِكَةِ أَهَٰٓؤُلَآءِ إِيَّاكُمْ كَانُوا۟ يَعْبُدُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdcxlvii{قَالُوا۟ سُبْحَٰنَكَ أَنتَ وَلِيُّنَا مِن دُونِهِم بَلْ كَانُوا۟ يَعْبُدُونَ ٱلْجِنَّ أَكْثَرُهُم بِهِم مُّؤْمِنُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdcxlviii{فَٱلْيَوْمَ لَا يَمْلِكُ بَعْضُكُمْ لِبَعْضٍ نَّفْعًا وَلَا ضَرًّا وَنَقُولُ لِلَّذِينَ ظَلَمُوا۟ ذُوقُوا۟ عَذَابَ ٱلنَّارِ ٱلَّتِى كُنتُم بِهَا تُكَذِّبُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdcxlix{وَإِذَا تُتْلَىٰ عَلَيْهِمْ ءَايَٰتُنَا بَيِّنَٰتٍ قَالُوا۟ مَا هَٰذَآ إِلَّا رَجُلٌ يُرِيدُ أَن يَصُدَّكُمْ عَمَّا كَانَ يَعْبُدُ ءَابَآؤُكُمْ وَقَالُوا۟ مَا هَٰذَآ إِلَّآ إِفْكٌ مُّفْتَرًى وَقَالَ ٱلَّذِينَ كَفَرُوا۟ لِلْحَقِّ لَمَّا جَآءَهُمْ إِنْ هَٰذَآ إِلَّا سِحْرٌ مُّبِينٌ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdcl{وَمَآ ءَاتَيْنَٰهُم مِّن كُتُبٍ يَدْرُسُونَهَا وَمَآ أَرْسَلْنَآ إِلَيْهِمْ قَبْلَكَ مِن نَّذِيرٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdcli{وَكَذَّبَ ٱلَّذِينَ مِن قَبْلِهِمْ وَمَا بَلَغُوا۟ مِعْشَارَ مَآ ءَاتَيْنَٰهُمْ فَكَذَّبُوا۟ رُسُلِى فَكَيْفَ كَانَ نَكِيرِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdclii{قُلْ إِنَّمَآ أَعِظُكُم بِوَٰحِدَةٍ أَن تَقُومُوا۟ لِلَّهِ مَثْنَىٰ وَفُرَٰدَىٰ ثُمَّ تَتَفَكَّرُوا۟ مَا بِصَاحِبِكُم مِّن جِنَّةٍ إِنْ هُوَ إِلَّا نَذِيرٌ لَّكُم بَيْنَ يَدَىْ عَذَابٍ شَدِيدٍ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdcliii{قُلْ مَا سَأَلْتُكُم مِّنْ أَجْرٍ فَهُوَ لَكُمْ إِنْ أَجْرِىَ إِلَّا عَلَى ٱللَّهِ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ شَهِيدٌ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdcliv{قُلْ إِنَّ رَبِّى يَقْذِفُ بِٱلْحَقِّ عَلَّٰمُ ٱلْغُيُوبِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdclv{قُلْ جَآءَ ٱلْحَقُّ وَمَا يُبْدِئُ ٱلْبَٰطِلُ وَمَا يُعِيدُ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdclvi{قُلْ إِن ضَلَلْتُ فَإِنَّمَآ أَضِلُّ عَلَىٰ نَفْسِى وَإِنِ ٱهْتَدَيْتُ فَبِمَا يُوحِىٓ إِلَىَّ رَبِّىٓ إِنَّهُۥ سَمِيعٌ قَرِيبٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdclvii{وَلَوْ تَرَىٰٓ إِذْ فَزِعُوا۟ فَلَا فَوْتَ وَأُخِذُوا۟ مِن مَّكَانٍ قَرِيبٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdclviii{وَقَالُوٓا۟ ءَامَنَّا بِهِۦ وَأَنَّىٰ لَهُمُ ٱلتَّنَاوُشُ مِن مَّكَانٍۭ بَعِيدٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdclix{وَقَدْ كَفَرُوا۟ بِهِۦ مِن قَبْلُ وَيَقْذِفُونَ بِٱلْغَيْبِ مِن مَّكَانٍۭ بَعِيدٍ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdclx{وَحِيلَ بَيْنَهُمْ وَبَيْنَ مَا يَشْتَهُونَ كَمَا فُعِلَ بِأَشْيَاعِهِم مِّن قَبْلُ إِنَّهُمْ كَانُوا۟ فِى شَكٍّ مُّرِيبٍۭ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdclxi{\basmalah ٱلْحَمْدُ لِلَّهِ فَاطِرِ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ جَاعِلِ ٱلْمَلَٰٓئِكَةِ رُسُلًا أُو۟لِىٓ أَجْنِحَةٍ مَّثْنَىٰ وَثُلَٰثَ وَرُبَٰعَ يَزِيدُ فِى ٱلْخَلْقِ مَا يَشَآءُ إِنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdclxii{مَّا يَفْتَحِ ٱللَّهُ لِلنَّاسِ مِن رَّحْمَةٍ فَلَا مُمْسِكَ لَهَا وَمَا يُمْسِكْ فَلَا مُرْسِلَ لَهُۥ مِنۢ بَعْدِهِۦ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdclxiii{يَٰٓأَيُّهَا ٱلنَّاسُ ٱذْكُرُوا۟ نِعْمَتَ ٱللَّهِ عَلَيْكُمْ هَلْ مِنْ خَٰلِقٍ غَيْرُ ٱللَّهِ يَرْزُقُكُم مِّنَ ٱلسَّمَآءِ وَٱلْأَرْضِ لَآ إِلَٰهَ إِلَّا هُوَ فَأَنَّىٰ تُؤْفَكُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdclxiv{وَإِن يُكَذِّبُوكَ فَقَدْ كُذِّبَتْ رُسُلٌ مِّن قَبْلِكَ وَإِلَى ٱللَّهِ تُرْجَعُ ٱلْأُمُورُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdclxv{يَٰٓأَيُّهَا ٱلنَّاسُ إِنَّ وَعْدَ ٱللَّهِ حَقٌّ فَلَا تَغُرَّنَّكُمُ ٱلْحَيَوٰةُ ٱلدُّنْيَا وَلَا يَغُرَّنَّكُم بِٱللَّهِ ٱلْغَرُورُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdclxvi{إِنَّ ٱلشَّيْطَٰنَ لَكُمْ عَدُوٌّ فَٱتَّخِذُوهُ عَدُوًّا إِنَّمَا يَدْعُوا۟ حِزْبَهُۥ لِيَكُونُوا۟ مِنْ أَصْحَٰبِ ٱلسَّعِيرِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdclxvii{ٱلَّذِينَ كَفَرُوا۟ لَهُمْ عَذَابٌ شَدِيدٌ وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَهُم مَّغْفِرَةٌ وَأَجْرٌ كَبِيرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdclxviii{أَفَمَن زُيِّنَ لَهُۥ سُوٓءُ عَمَلِهِۦ فَرَءَاهُ حَسَنًا فَإِنَّ ٱللَّهَ يُضِلُّ مَن يَشَآءُ وَيَهْدِى مَن يَشَآءُ فَلَا تَذْهَبْ نَفْسُكَ عَلَيْهِمْ حَسَرَٰتٍ إِنَّ ٱللَّهَ عَلِيمٌۢ بِمَا يَصْنَعُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdclxix{وَٱللَّهُ ٱلَّذِىٓ أَرْسَلَ ٱلرِّيَٰحَ فَتُثِيرُ سَحَابًا فَسُقْنَٰهُ إِلَىٰ بَلَدٍ مَّيِّتٍ فَأَحْيَيْنَا بِهِ ٱلْأَرْضَ بَعْدَ مَوْتِهَا كَذَٰلِكَ ٱلنُّشُورُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdclxx{مَن كَانَ يُرِيدُ ٱلْعِزَّةَ فَلِلَّهِ ٱلْعِزَّةُ جَمِيعًا إِلَيْهِ يَصْعَدُ ٱلْكَلِمُ ٱلطَّيِّبُ وَٱلْعَمَلُ ٱلصَّٰلِحُ يَرْفَعُهُۥ وَٱلَّذِينَ يَمْكُرُونَ ٱلسَّيِّـَٔاتِ لَهُمْ عَذَابٌ شَدِيدٌ وَمَكْرُ أُو۟لَٰٓئِكَ هُوَ يَبُورُ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdclxxi{وَٱللَّهُ خَلَقَكُم مِّن تُرَابٍ ثُمَّ مِن نُّطْفَةٍ ثُمَّ جَعَلَكُمْ أَزْوَٰجًا وَمَا تَحْمِلُ مِنْ أُنثَىٰ وَلَا تَضَعُ إِلَّا بِعِلْمِهِۦ وَمَا يُعَمَّرُ مِن مُّعَمَّرٍ وَلَا يُنقَصُ مِنْ عُمُرِهِۦٓ إِلَّا فِى كِتَٰبٍ إِنَّ ذَٰلِكَ عَلَى ٱللَّهِ يَسِيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdclxxii{وَمَا يَسْتَوِى ٱلْبَحْرَانِ هَٰذَا عَذْبٌ فُرَاتٌ سَآئِغٌ شَرَابُهُۥ وَهَٰذَا مِلْحٌ أُجَاجٌ وَمِن كُلٍّ تَأْكُلُونَ لَحْمًا طَرِيًّا وَتَسْتَخْرِجُونَ حِلْيَةً تَلْبَسُونَهَا وَتَرَى ٱلْفُلْكَ فِيهِ مَوَاخِرَ لِتَبْتَغُوا۟ مِن فَضْلِهِۦ وَلَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdclxxiii{يُولِجُ ٱلَّيْلَ فِى ٱلنَّهَارِ وَيُولِجُ ٱلنَّهَارَ فِى ٱلَّيْلِ وَسَخَّرَ ٱلشَّمْسَ وَٱلْقَمَرَ كُلٌّ يَجْرِى لِأَجَلٍ مُّسَمًّى ذَٰلِكُمُ ٱللَّهُ رَبُّكُمْ لَهُ ٱلْمُلْكُ وَٱلَّذِينَ تَدْعُونَ مِن دُونِهِۦ مَا يَمْلِكُونَ مِن قِطْمِيرٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdclxxiv{إِن تَدْعُوهُمْ لَا يَسْمَعُوا۟ دُعَآءَكُمْ وَلَوْ سَمِعُوا۟ مَا ٱسْتَجَابُوا۟ لَكُمْ وَيَوْمَ ٱلْقِيَٰمَةِ يَكْفُرُونَ بِشِرْكِكُمْ وَلَا يُنَبِّئُكَ مِثْلُ خَبِيرٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdclxxv{يَٰٓأَيُّهَا ٱلنَّاسُ أَنتُمُ ٱلْفُقَرَآءُ إِلَى ٱللَّهِ وَٱللَّهُ هُوَ ٱلْغَنِىُّ ٱلْحَمِيدُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdclxxvi{إِن يَشَأْ يُذْهِبْكُمْ وَيَأْتِ بِخَلْقٍ جَدِيدٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdclxxvii{وَمَا ذَٰلِكَ عَلَى ٱللَّهِ بِعَزِيزٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdclxxviii{وَلَا تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَىٰ وَإِن تَدْعُ مُثْقَلَةٌ إِلَىٰ حِمْلِهَا لَا يُحْمَلْ مِنْهُ شَىْءٌ وَلَوْ كَانَ ذَا قُرْبَىٰٓ إِنَّمَا تُنذِرُ ٱلَّذِينَ يَخْشَوْنَ رَبَّهُم بِٱلْغَيْبِ وَأَقَامُوا۟ ٱلصَّلَوٰةَ وَمَن تَزَكَّىٰ فَإِنَّمَا يَتَزَكَّىٰ لِنَفْسِهِۦ وَإِلَى ٱللَّهِ ٱلْمَصِيرُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdclxxix{وَمَا يَسْتَوِى ٱلْأَعْمَىٰ وَٱلْبَصِيرُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdclxxx{وَلَا ٱلظُّلُمَٰتُ وَلَا ٱلنُّورُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdclxxxi{وَلَا ٱلظِّلُّ وَلَا ٱلْحَرُورُ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdclxxxii{وَمَا يَسْتَوِى ٱلْأَحْيَآءُ وَلَا ٱلْأَمْوَٰتُ إِنَّ ٱللَّهَ يُسْمِعُ مَن يَشَآءُ وَمَآ أَنتَ بِمُسْمِعٍ مَّن فِى ٱلْقُبُورِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdclxxxiii{إِنْ أَنتَ إِلَّا نَذِيرٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdclxxxiv{إِنَّآ أَرْسَلْنَٰكَ بِٱلْحَقِّ بَشِيرًا وَنَذِيرًا وَإِن مِّنْ أُمَّةٍ إِلَّا خَلَا فِيهَا نَذِيرٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdclxxxv{وَإِن يُكَذِّبُوكَ فَقَدْ كَذَّبَ ٱلَّذِينَ مِن قَبْلِهِمْ جَآءَتْهُمْ رُسُلُهُم بِٱلْبَيِّنَٰتِ وَبِٱلزُّبُرِ وَبِٱلْكِتَٰبِ ٱلْمُنِيرِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdclxxxvi{ثُمَّ أَخَذْتُ ٱلَّذِينَ كَفَرُوا۟ فَكَيْفَ كَانَ نَكِيرِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdclxxxvii{أَلَمْ تَرَ أَنَّ ٱللَّهَ أَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً فَأَخْرَجْنَا بِهِۦ ثَمَرَٰتٍ مُّخْتَلِفًا أَلْوَٰنُهَا وَمِنَ ٱلْجِبَالِ جُدَدٌۢ بِيضٌ وَحُمْرٌ مُّخْتَلِفٌ أَلْوَٰنُهَا وَغَرَابِيبُ سُودٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdclxxxviii{وَمِنَ ٱلنَّاسِ وَٱلدَّوَآبِّ وَٱلْأَنْعَٰمِ مُخْتَلِفٌ أَلْوَٰنُهُۥ كَذَٰلِكَ إِنَّمَا يَخْشَى ٱللَّهَ مِنْ عِبَادِهِ ٱلْعُلَمَٰٓؤُا۟ إِنَّ ٱللَّهَ عَزِيزٌ غَفُورٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdclxxxix{إِنَّ ٱلَّذِينَ يَتْلُونَ كِتَٰبَ ٱللَّهِ وَأَقَامُوا۟ ٱلصَّلَوٰةَ وَأَنفَقُوا۟ مِمَّا رَزَقْنَٰهُمْ سِرًّا وَعَلَانِيَةً يَرْجُونَ تِجَٰرَةً لَّن تَبُورَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdcxc{لِيُوَفِّيَهُمْ أُجُورَهُمْ وَيَزِيدَهُم مِّن فَضْلِهِۦٓ إِنَّهُۥ غَفُورٌ شَكُورٌ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdcxci{وَٱلَّذِىٓ أَوْحَيْنَآ إِلَيْكَ مِنَ ٱلْكِتَٰبِ هُوَ ٱلْحَقُّ مُصَدِّقًا لِّمَا بَيْنَ يَدَيْهِ إِنَّ ٱللَّهَ بِعِبَادِهِۦ لَخَبِيرٌۢ بَصِيرٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdcxcii{ثُمَّ أَوْرَثْنَا ٱلْكِتَٰبَ ٱلَّذِينَ ٱصْطَفَيْنَا مِنْ عِبَادِنَا فَمِنْهُمْ ظَالِمٌ لِّنَفْسِهِۦ وَمِنْهُم مُّقْتَصِدٌ وَمِنْهُمْ سَابِقٌۢ بِٱلْخَيْرَٰتِ بِإِذْنِ ٱللَّهِ ذَٰلِكَ هُوَ ٱلْفَضْلُ ٱلْكَبِيرُ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdcxciii{جَنَّٰتُ عَدْنٍ يَدْخُلُونَهَا يُحَلَّوْنَ فِيهَا مِنْ أَسَاوِرَ مِن ذَهَبٍ وَلُؤْلُؤًا وَلِبَاسُهُمْ فِيهَا حَرِيرٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdcxciv{وَقَالُوا۟ ٱلْحَمْدُ لِلَّهِ ٱلَّذِىٓ أَذْهَبَ عَنَّا ٱلْحَزَنَ إِنَّ رَبَّنَا لَغَفُورٌ شَكُورٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdcxcv{ٱلَّذِىٓ أَحَلَّنَا دَارَ ٱلْمُقَامَةِ مِن فَضْلِهِۦ لَا يَمَسُّنَا فِيهَا نَصَبٌ وَلَا يَمَسُّنَا فِيهَا لُغُوبٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdcxcvi{وَٱلَّذِينَ كَفَرُوا۟ لَهُمْ نَارُ جَهَنَّمَ لَا يُقْضَىٰ عَلَيْهِمْ فَيَمُوتُوا۟ وَلَا يُخَفَّفُ عَنْهُم مِّنْ عَذَابِهَا كَذَٰلِكَ نَجْزِى كُلَّ كَفُورٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdcxcvii{وَهُمْ يَصْطَرِخُونَ فِيهَا رَبَّنَآ أَخْرِجْنَا نَعْمَلْ صَٰلِحًا غَيْرَ ٱلَّذِى كُنَّا نَعْمَلُ أَوَلَمْ نُعَمِّرْكُم مَّا يَتَذَكَّرُ فِيهِ مَن تَذَكَّرَ وَجَآءَكُمُ ٱلنَّذِيرُ فَذُوقُوا۟ فَمَا لِلظَّٰلِمِينَ مِن نَّصِيرٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdcxcviii{إِنَّ ٱللَّهَ عَٰلِمُ غَيْبِ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ إِنَّهُۥ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdcxcix{هُوَ ٱلَّذِى جَعَلَكُمْ خَلَٰٓئِفَ فِى ٱلْأَرْضِ فَمَن كَفَرَ فَعَلَيْهِ كُفْرُهُۥ وَلَا يَزِيدُ ٱلْكَٰفِرِينَ كُفْرُهُمْ عِندَ رَبِّهِمْ إِلَّا مَقْتًا وَلَا يَزِيدُ ٱلْكَٰفِرِينَ كُفْرُهُمْ إِلَّا خَسَارًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdcc{قُلْ أَرَءَيْتُمْ شُرَكَآءَكُمُ ٱلَّذِينَ تَدْعُونَ مِن دُونِ ٱللَّهِ أَرُونِى مَاذَا خَلَقُوا۟ مِنَ ٱلْأَرْضِ أَمْ لَهُمْ شِرْكٌ فِى ٱلسَّمَٰوَٰتِ أَمْ ءَاتَيْنَٰهُمْ كِتَٰبًا فَهُمْ عَلَىٰ بَيِّنَتٍ مِّنْهُ بَلْ إِن يَعِدُ ٱلظَّٰلِمُونَ بَعْضُهُم بَعْضًا إِلَّا غُرُورًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdcci{إِنَّ ٱللَّهَ يُمْسِكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ أَن تَزُولَا وَلَئِن زَالَتَآ إِنْ أَمْسَكَهُمَا مِنْ أَحَدٍ مِّنۢ بَعْدِهِۦٓ إِنَّهُۥ كَانَ حَلِيمًا غَفُورًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdccii{وَأَقْسَمُوا۟ بِٱللَّهِ جَهْدَ أَيْمَٰنِهِمْ لَئِن جَآءَهُمْ نَذِيرٌ لَّيَكُونُنَّ أَهْدَىٰ مِنْ إِحْدَى ٱلْأُمَمِ فَلَمَّا جَآءَهُمْ نَذِيرٌ مَّا زَادَهُمْ إِلَّا نُفُورًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdcciii{ٱسْتِكْبَارًا فِى ٱلْأَرْضِ وَمَكْرَ ٱلسَّيِّئِ وَلَا يَحِيقُ ٱلْمَكْرُ ٱلسَّيِّئُ إِلَّا بِأَهْلِهِۦ فَهَلْ يَنظُرُونَ إِلَّا سُنَّتَ ٱلْأَوَّلِينَ فَلَن تَجِدَ لِسُنَّتِ ٱللَّهِ تَبْدِيلًا وَلَن تَجِدَ لِسُنَّتِ ٱللَّهِ تَحْوِيلًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdcciv{أَوَلَمْ يَسِيرُوا۟ فِى ٱلْأَرْضِ فَيَنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلَّذِينَ مِن قَبْلِهِمْ وَكَانُوٓا۟ أَشَدَّ مِنْهُمْ قُوَّةً وَمَا كَانَ ٱللَّهُ لِيُعْجِزَهُۥ مِن شَىْءٍ فِى ٱلسَّمَٰوَٰتِ وَلَا فِى ٱلْأَرْضِ إِنَّهُۥ كَانَ عَلِيمًا قَدِيرًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdccv{وَلَوْ يُؤَاخِذُ ٱللَّهُ ٱلنَّاسَ بِمَا كَسَبُوا۟ مَا تَرَكَ عَلَىٰ ظَهْرِهَا مِن دَآبَّةٍ وَلَٰكِن يُؤَخِّرُهُمْ إِلَىٰٓ أَجَلٍ مُّسَمًّى فَإِذَا جَآءَ أَجَلُهُمْ فَإِنَّ ٱللَّهَ كَانَ بِعِبَادِهِۦ بَصِيرًۢا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdccvi{\basmalah يسٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdccvii{وَٱلْقُرْءَانِ ٱلْحَكِيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdccviii{إِنَّكَ لَمِنَ ٱلْمُرْسَلِينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdccix{عَلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdccx{تَنزِيلَ ٱلْعَزِيزِ ٱلرَّحِيمِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdccxi{لِتُنذِرَ قَوْمًا مَّآ أُنذِرَ ءَابَآؤُهُمْ فَهُمْ غَٰفِلُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdccxii{لَقَدْ حَقَّ ٱلْقَوْلُ عَلَىٰٓ أَكْثَرِهِمْ فَهُمْ لَا يُؤْمِنُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdccxiii{إِنَّا جَعَلْنَا فِىٓ أَعْنَٰقِهِمْ أَغْلَٰلًا فَهِىَ إِلَى ٱلْأَذْقَانِ فَهُم مُّقْمَحُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdccxiv{وَجَعَلْنَا مِنۢ بَيْنِ أَيْدِيهِمْ سَدًّا وَمِنْ خَلْفِهِمْ سَدًّا فَأَغْشَيْنَٰهُمْ فَهُمْ لَا يُبْصِرُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdccxv{وَسَوَآءٌ عَلَيْهِمْ ءَأَنذَرْتَهُمْ أَمْ لَمْ تُنذِرْهُمْ لَا يُؤْمِنُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdccxvi{إِنَّمَا تُنذِرُ مَنِ ٱتَّبَعَ ٱلذِّكْرَ وَخَشِىَ ٱلرَّحْمَٰنَ بِٱلْغَيْبِ فَبَشِّرْهُ بِمَغْفِرَةٍ وَأَجْرٍ كَرِيمٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdccxvii{إِنَّا نَحْنُ نُحْىِ ٱلْمَوْتَىٰ وَنَكْتُبُ مَا قَدَّمُوا۟ وَءَاثَٰرَهُمْ وَكُلَّ شَىْءٍ أَحْصَيْنَٰهُ فِىٓ إِمَامٍ مُّبِينٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdccxviii{وَٱضْرِبْ لَهُم مَّثَلًا أَصْحَٰبَ ٱلْقَرْيَةِ إِذْ جَآءَهَا ٱلْمُرْسَلُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdccxix{إِذْ أَرْسَلْنَآ إِلَيْهِمُ ٱثْنَيْنِ فَكَذَّبُوهُمَا فَعَزَّزْنَا بِثَالِثٍ فَقَالُوٓا۟ إِنَّآ إِلَيْكُم مُّرْسَلُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdccxx{قَالُوا۟ مَآ أَنتُمْ إِلَّا بَشَرٌ مِّثْلُنَا وَمَآ أَنزَلَ ٱلرَّحْمَٰنُ مِن شَىْءٍ إِنْ أَنتُمْ إِلَّا تَكْذِبُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdccxxi{قَالُوا۟ رَبُّنَا يَعْلَمُ إِنَّآ إِلَيْكُمْ لَمُرْسَلُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdccxxii{وَمَا عَلَيْنَآ إِلَّا ٱلْبَلَٰغُ ٱلْمُبِينُ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdccxxiii{قَالُوٓا۟ إِنَّا تَطَيَّرْنَا بِكُمْ لَئِن لَّمْ تَنتَهُوا۟ لَنَرْجُمَنَّكُمْ وَلَيَمَسَّنَّكُم مِّنَّا عَذَابٌ أَلِيمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdccxxiv{قَالُوا۟ طَٰٓئِرُكُم مَّعَكُمْ أَئِن ذُكِّرْتُم بَلْ أَنتُمْ قَوْمٌ مُّسْرِفُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdccxxv{وَجَآءَ مِنْ أَقْصَا ٱلْمَدِينَةِ رَجُلٌ يَسْعَىٰ قَالَ يَٰقَوْمِ ٱتَّبِعُوا۟ ٱلْمُرْسَلِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdccxxvi{ٱتَّبِعُوا۟ مَن لَّا يَسْـَٔلُكُمْ أَجْرًا وَهُم مُّهْتَدُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdccxxvii{وَمَا لِىَ لَآ أَعْبُدُ ٱلَّذِى فَطَرَنِى وَإِلَيْهِ تُرْجَعُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdccxxviii{ءَأَتَّخِذُ مِن دُونِهِۦٓ ءَالِهَةً إِن يُرِدْنِ ٱلرَّحْمَٰنُ بِضُرٍّ لَّا تُغْنِ عَنِّى شَفَٰعَتُهُمْ شَيْـًٔا وَلَا يُنقِذُونِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdccxxix{إِنِّىٓ إِذًا لَّفِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdccxxx{إِنِّىٓ ءَامَنتُ بِرَبِّكُمْ فَٱسْمَعُونِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdccxxxi{قِيلَ ٱدْخُلِ ٱلْجَنَّةَ قَالَ يَٰلَيْتَ قَوْمِى يَعْلَمُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdccxxxii{بِمَا غَفَرَ لِى رَبِّى وَجَعَلَنِى مِنَ ٱلْمُكْرَمِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdccxxxiii{وَمَآ أَنزَلْنَا عَلَىٰ قَوْمِهِۦ مِنۢ بَعْدِهِۦ مِن جُندٍ مِّنَ ٱلسَّمَآءِ وَمَا كُنَّا مُنزِلِينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdccxxxiv{إِن كَانَتْ إِلَّا صَيْحَةً وَٰحِدَةً فَإِذَا هُمْ خَٰمِدُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdccxxxv{يَٰحَسْرَةً عَلَى ٱلْعِبَادِ مَا يَأْتِيهِم مِّن رَّسُولٍ إِلَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdccxxxvi{أَلَمْ يَرَوْا۟ كَمْ أَهْلَكْنَا قَبْلَهُم مِّنَ ٱلْقُرُونِ أَنَّهُمْ إِلَيْهِمْ لَا يَرْجِعُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdccxxxvii{وَإِن كُلٌّ لَّمَّا جَمِيعٌ لَّدَيْنَا مُحْضَرُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdccxxxviii{وَءَايَةٌ لَّهُمُ ٱلْأَرْضُ ٱلْمَيْتَةُ أَحْيَيْنَٰهَا وَأَخْرَجْنَا مِنْهَا حَبًّا فَمِنْهُ يَأْكُلُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdccxxxix{وَجَعَلْنَا فِيهَا جَنَّٰتٍ مِّن نَّخِيلٍ وَأَعْنَٰبٍ وَفَجَّرْنَا فِيهَا مِنَ ٱلْعُيُونِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdccxl{لِيَأْكُلُوا۟ مِن ثَمَرِهِۦ وَمَا عَمِلَتْهُ أَيْدِيهِمْ أَفَلَا يَشْكُرُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdccxli{سُبْحَٰنَ ٱلَّذِى خَلَقَ ٱلْأَزْوَٰجَ كُلَّهَا مِمَّا تُنۢبِتُ ٱلْأَرْضُ وَمِنْ أَنفُسِهِمْ وَمِمَّا لَا يَعْلَمُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdccxlii{وَءَايَةٌ لَّهُمُ ٱلَّيْلُ نَسْلَخُ مِنْهُ ٱلنَّهَارَ فَإِذَا هُم مُّظْلِمُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdccxliii{وَٱلشَّمْسُ تَجْرِى لِمُسْتَقَرٍّ لَّهَا ذَٰلِكَ تَقْدِيرُ ٱلْعَزِيزِ ٱلْعَلِيمِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdccxliv{وَٱلْقَمَرَ قَدَّرْنَٰهُ مَنَازِلَ حَتَّىٰ عَادَ كَٱلْعُرْجُونِ ٱلْقَدِيمِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdccxlv{لَا ٱلشَّمْسُ يَنۢبَغِى لَهَآ أَن تُدْرِكَ ٱلْقَمَرَ وَلَا ٱلَّيْلُ سَابِقُ ٱلنَّهَارِ وَكُلٌّ فِى فَلَكٍ يَسْبَحُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdccxlvi{وَءَايَةٌ لَّهُمْ أَنَّا حَمَلْنَا ذُرِّيَّتَهُمْ فِى ٱلْفُلْكِ ٱلْمَشْحُونِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdccxlvii{وَخَلَقْنَا لَهُم مِّن مِّثْلِهِۦ مَا يَرْكَبُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdccxlviii{وَإِن نَّشَأْ نُغْرِقْهُمْ فَلَا صَرِيخَ لَهُمْ وَلَا هُمْ يُنقَذُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdccxlix{إِلَّا رَحْمَةً مِّنَّا وَمَتَٰعًا إِلَىٰ حِينٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdccl{وَإِذَا قِيلَ لَهُمُ ٱتَّقُوا۟ مَا بَيْنَ أَيْدِيكُمْ وَمَا خَلْفَكُمْ لَعَلَّكُمْ تُرْحَمُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdccli{وَمَا تَأْتِيهِم مِّنْ ءَايَةٍ مِّنْ ءَايَٰتِ رَبِّهِمْ إِلَّا كَانُوا۟ عَنْهَا مُعْرِضِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdcclii{وَإِذَا قِيلَ لَهُمْ أَنفِقُوا۟ مِمَّا رَزَقَكُمُ ٱللَّهُ قَالَ ٱلَّذِينَ كَفَرُوا۟ لِلَّذِينَ ءَامَنُوٓا۟ أَنُطْعِمُ مَن لَّوْ يَشَآءُ ٱللَّهُ أَطْعَمَهُۥٓ إِنْ أَنتُمْ إِلَّا فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdccliii{وَيَقُولُونَ مَتَىٰ هَٰذَا ٱلْوَعْدُ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdccliv{مَا يَنظُرُونَ إِلَّا صَيْحَةً وَٰحِدَةً تَأْخُذُهُمْ وَهُمْ يَخِصِّمُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdcclv{فَلَا يَسْتَطِيعُونَ تَوْصِيَةً وَلَآ إِلَىٰٓ أَهْلِهِمْ يَرْجِعُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdcclvi{وَنُفِخَ فِى ٱلصُّورِ فَإِذَا هُم مِّنَ ٱلْأَجْدَاثِ إِلَىٰ رَبِّهِمْ يَنسِلُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdcclvii{قَالُوا۟ يَٰوَيْلَنَا مَنۢ بَعَثَنَا مِن مَّرْقَدِنَا هَٰذَا مَا وَعَدَ ٱلرَّحْمَٰنُ وَصَدَقَ ٱلْمُرْسَلُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdcclviii{إِن كَانَتْ إِلَّا صَيْحَةً وَٰحِدَةً فَإِذَا هُمْ جَمِيعٌ لَّدَيْنَا مُحْضَرُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdcclix{فَٱلْيَوْمَ لَا تُظْلَمُ نَفْسٌ شَيْـًٔا وَلَا تُجْزَوْنَ إِلَّا مَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdcclx{إِنَّ أَصْحَٰبَ ٱلْجَنَّةِ ٱلْيَوْمَ فِى شُغُلٍ فَٰكِهُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmdcclxi{هُمْ وَأَزْوَٰجُهُمْ فِى ظِلَٰلٍ عَلَى ٱلْأَرَآئِكِ مُتَّكِـُٔونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmdcclxii{لَهُمْ فِيهَا فَٰكِهَةٌ وَلَهُم مَّا يَدَّعُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmdcclxiii{سَلَٰمٌ قَوْلًا مِّن رَّبٍّ رَّحِيمٍ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmdcclxiv{وَٱمْتَٰزُوا۟ ٱلْيَوْمَ أَيُّهَا ٱلْمُجْرِمُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmdcclxv{أَلَمْ أَعْهَدْ إِلَيْكُمْ يَٰبَنِىٓ ءَادَمَ أَن لَّا تَعْبُدُوا۟ ٱلشَّيْطَٰنَ إِنَّهُۥ لَكُمْ عَدُوٌّ مُّبِينٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmdcclxvi{وَأَنِ ٱعْبُدُونِى هَٰذَا صِرَٰطٌ مُّسْتَقِيمٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmdcclxvii{وَلَقَدْ أَضَلَّ مِنكُمْ جِبِلًّا كَثِيرًا أَفَلَمْ تَكُونُوا۟ تَعْقِلُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmdcclxviii{هَٰذِهِۦ جَهَنَّمُ ٱلَّتِى كُنتُمْ تُوعَدُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmdcclxix{ٱصْلَوْهَا ٱلْيَوْمَ بِمَا كُنتُمْ تَكْفُرُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmdcclxx{ٱلْيَوْمَ نَخْتِمُ عَلَىٰٓ أَفْوَٰهِهِمْ وَتُكَلِّمُنَآ أَيْدِيهِمْ وَتَشْهَدُ أَرْجُلُهُم بِمَا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmdcclxxi{وَلَوْ نَشَآءُ لَطَمَسْنَا عَلَىٰٓ أَعْيُنِهِمْ فَٱسْتَبَقُوا۟ ٱلصِّرَٰطَ فَأَنَّىٰ يُبْصِرُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmdcclxxii{وَلَوْ نَشَآءُ لَمَسَخْنَٰهُمْ عَلَىٰ مَكَانَتِهِمْ فَمَا ٱسْتَطَٰعُوا۟ مُضِيًّا وَلَا يَرْجِعُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmdcclxxiii{وَمَن نُّعَمِّرْهُ نُنَكِّسْهُ فِى ٱلْخَلْقِ أَفَلَا يَعْقِلُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmdcclxxiv{وَمَا عَلَّمْنَٰهُ ٱلشِّعْرَ وَمَا يَنۢبَغِى لَهُۥٓ إِنْ هُوَ إِلَّا ذِكْرٌ وَقُرْءَانٌ مُّبِينٌ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmdcclxxv{لِّيُنذِرَ مَن كَانَ حَيًّا وَيَحِقَّ ٱلْقَوْلُ عَلَى ٱلْكَٰفِرِينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmdcclxxvi{أَوَلَمْ يَرَوْا۟ أَنَّا خَلَقْنَا لَهُم مِّمَّا عَمِلَتْ أَيْدِينَآ أَنْعَٰمًا فَهُمْ لَهَا مَٰلِكُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmdcclxxvii{وَذَلَّلْنَٰهَا لَهُمْ فَمِنْهَا رَكُوبُهُمْ وَمِنْهَا يَأْكُلُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmdcclxxviii{وَلَهُمْ فِيهَا مَنَٰفِعُ وَمَشَارِبُ أَفَلَا يَشْكُرُونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmdcclxxix{وَٱتَّخَذُوا۟ مِن دُونِ ٱللَّهِ ءَالِهَةً لَّعَلَّهُمْ يُنصَرُونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmdcclxxx{لَا يَسْتَطِيعُونَ نَصْرَهُمْ وَهُمْ لَهُمْ جُندٌ مُّحْضَرُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmdcclxxxi{فَلَا يَحْزُنكَ قَوْلُهُمْ إِنَّا نَعْلَمُ مَا يُسِرُّونَ وَمَا يُعْلِنُونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmdcclxxxii{أَوَلَمْ يَرَ ٱلْإِنسَٰنُ أَنَّا خَلَقْنَٰهُ مِن نُّطْفَةٍ فَإِذَا هُوَ خَصِيمٌ مُّبِينٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmdcclxxxiii{وَضَرَبَ لَنَا مَثَلًا وَنَسِىَ خَلْقَهُۥ قَالَ مَن يُحْىِ ٱلْعِظَٰمَ وَهِىَ رَمِيمٌ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmdcclxxxiv{قُلْ يُحْيِيهَا ٱلَّذِىٓ أَنشَأَهَآ أَوَّلَ مَرَّةٍ وَهُوَ بِكُلِّ خَلْقٍ عَلِيمٌ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmdcclxxxv{ٱلَّذِى جَعَلَ لَكُم مِّنَ ٱلشَّجَرِ ٱلْأَخْضَرِ نَارًا فَإِذَآ أَنتُم مِّنْهُ تُوقِدُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmdcclxxxvi{أَوَلَيْسَ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ بِقَٰدِرٍ عَلَىٰٓ أَن يَخْلُقَ مِثْلَهُم بَلَىٰ وَهُوَ ٱلْخَلَّٰقُ ٱلْعَلِيمُ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmdcclxxxvii{إِنَّمَآ أَمْرُهُۥٓ إِذَآ أَرَادَ شَيْـًٔا أَن يَقُولَ لَهُۥ كُن فَيَكُونُ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmdcclxxxviii{فَسُبْحَٰنَ ٱلَّذِى بِيَدِهِۦ مَلَكُوتُ كُلِّ شَىْءٍ وَإِلَيْهِ تُرْجَعُونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmdcclxxxix{\basmalah وَٱلصَّٰٓفَّٰتِ صَفًّا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdccxc{فَٱلزَّٰجِرَٰتِ زَجْرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdccxci{فَٱلتَّٰلِيَٰتِ ذِكْرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdccxcii{إِنَّ إِلَٰهَكُمْ لَوَٰحِدٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdccxciii{رَّبُّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَا وَرَبُّ ٱلْمَشَٰرِقِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdccxciv{إِنَّا زَيَّنَّا ٱلسَّمَآءَ ٱلدُّنْيَا بِزِينَةٍ ٱلْكَوَاكِبِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdccxcv{وَحِفْظًا مِّن كُلِّ شَيْطَٰنٍ مَّارِدٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdccxcvi{لَّا يَسَّمَّعُونَ إِلَى ٱلْمَلَإِ ٱلْأَعْلَىٰ وَيُقْذَفُونَ مِن كُلِّ جَانِبٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdccxcvii{دُحُورًا وَلَهُمْ عَذَابٌ وَاصِبٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdccxcviii{إِلَّا مَنْ خَطِفَ ٱلْخَطْفَةَ فَأَتْبَعَهُۥ شِهَابٌ ثَاقِبٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdccxcix{فَٱسْتَفْتِهِمْ أَهُمْ أَشَدُّ خَلْقًا أَم مَّنْ خَلَقْنَآ إِنَّا خَلَقْنَٰهُم مِّن طِينٍ لَّازِبٍۭ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdccc{بَلْ عَجِبْتَ وَيَسْخَرُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdccci{وَإِذَا ذُكِّرُوا۟ لَا يَذْكُرُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdcccii{وَإِذَا رَأَوْا۟ ءَايَةً يَسْتَسْخِرُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdccciii{وَقَالُوٓا۟ إِنْ هَٰذَآ إِلَّا سِحْرٌ مُّبِينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdccciv{أَءِذَا مِتْنَا وَكُنَّا تُرَابًا وَعِظَٰمًا أَءِنَّا لَمَبْعُوثُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdcccv{أَوَءَابَآؤُنَا ٱلْأَوَّلُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdcccvi{قُلْ نَعَمْ وَأَنتُمْ دَٰخِرُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdcccvii{فَإِنَّمَا هِىَ زَجْرَةٌ وَٰحِدَةٌ فَإِذَا هُمْ يَنظُرُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdcccviii{وَقَالُوا۟ يَٰوَيْلَنَا هَٰذَا يَوْمُ ٱلدِّينِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdcccix{هَٰذَا يَوْمُ ٱلْفَصْلِ ٱلَّذِى كُنتُم بِهِۦ تُكَذِّبُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdcccx{ٱحْشُرُوا۟ ٱلَّذِينَ ظَلَمُوا۟ وَأَزْوَٰجَهُمْ وَمَا كَانُوا۟ يَعْبُدُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdcccxi{مِن دُونِ ٱللَّهِ فَٱهْدُوهُمْ إِلَىٰ صِرَٰطِ ٱلْجَحِيمِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdcccxii{وَقِفُوهُمْ إِنَّهُم مَّسْـُٔولُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdcccxiii{مَا لَكُمْ لَا تَنَاصَرُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdcccxiv{بَلْ هُمُ ٱلْيَوْمَ مُسْتَسْلِمُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdcccxv{وَأَقْبَلَ بَعْضُهُمْ عَلَىٰ بَعْضٍ يَتَسَآءَلُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdcccxvi{قَالُوٓا۟ إِنَّكُمْ كُنتُمْ تَأْتُونَنَا عَنِ ٱلْيَمِينِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdcccxvii{قَالُوا۟ بَل لَّمْ تَكُونُوا۟ مُؤْمِنِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdcccxviii{وَمَا كَانَ لَنَا عَلَيْكُم مِّن سُلْطَٰنٍۭ بَلْ كُنتُمْ قَوْمًا طَٰغِينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdcccxix{فَحَقَّ عَلَيْنَا قَوْلُ رَبِّنَآ إِنَّا لَذَآئِقُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdcccxx{فَأَغْوَيْنَٰكُمْ إِنَّا كُنَّا غَٰوِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdcccxxi{فَإِنَّهُمْ يَوْمَئِذٍ فِى ٱلْعَذَابِ مُشْتَرِكُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdcccxxii{إِنَّا كَذَٰلِكَ نَفْعَلُ بِٱلْمُجْرِمِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdcccxxiii{إِنَّهُمْ كَانُوٓا۟ إِذَا قِيلَ لَهُمْ لَآ إِلَٰهَ إِلَّا ٱللَّهُ يَسْتَكْبِرُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdcccxxiv{وَيَقُولُونَ أَئِنَّا لَتَارِكُوٓا۟ ءَالِهَتِنَا لِشَاعِرٍ مَّجْنُونٍۭ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdcccxxv{بَلْ جَآءَ بِٱلْحَقِّ وَصَدَّقَ ٱلْمُرْسَلِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdcccxxvi{إِنَّكُمْ لَذَآئِقُوا۟ ٱلْعَذَابِ ٱلْأَلِيمِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdcccxxvii{وَمَا تُجْزَوْنَ إِلَّا مَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdcccxxviii{إِلَّا عِبَادَ ٱللَّهِ ٱلْمُخْلَصِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdcccxxix{أُو۟لَٰٓئِكَ لَهُمْ رِزْقٌ مَّعْلُومٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdcccxxx{فَوَٰكِهُ وَهُم مُّكْرَمُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdcccxxxi{فِى جَنَّٰتِ ٱلنَّعِيمِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdcccxxxii{عَلَىٰ سُرُرٍ مُّتَقَٰبِلِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdcccxxxiii{يُطَافُ عَلَيْهِم بِكَأْسٍ مِّن مَّعِينٍۭ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdcccxxxiv{بَيْضَآءَ لَذَّةٍ لِّلشَّٰرِبِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdcccxxxv{لَا فِيهَا غَوْلٌ وَلَا هُمْ عَنْهَا يُنزَفُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdcccxxxvi{وَعِندَهُمْ قَٰصِرَٰتُ ٱلطَّرْفِ عِينٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdcccxxxvii{كَأَنَّهُنَّ بَيْضٌ مَّكْنُونٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdcccxxxviii{فَأَقْبَلَ بَعْضُهُمْ عَلَىٰ بَعْضٍ يَتَسَآءَلُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdcccxxxix{قَالَ قَآئِلٌ مِّنْهُمْ إِنِّى كَانَ لِى قَرِينٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdcccxl{يَقُولُ أَءِنَّكَ لَمِنَ ٱلْمُصَدِّقِينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdcccxli{أَءِذَا مِتْنَا وَكُنَّا تُرَابًا وَعِظَٰمًا أَءِنَّا لَمَدِينُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdcccxlii{قَالَ هَلْ أَنتُم مُّطَّلِعُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdcccxliii{فَٱطَّلَعَ فَرَءَاهُ فِى سَوَآءِ ٱلْجَحِيمِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmdcccxliv{قَالَ تَٱللَّهِ إِن كِدتَّ لَتُرْدِينِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmdcccxlv{وَلَوْلَا نِعْمَةُ رَبِّى لَكُنتُ مِنَ ٱلْمُحْضَرِينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmdcccxlvi{أَفَمَا نَحْنُ بِمَيِّتِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmdcccxlvii{إِلَّا مَوْتَتَنَا ٱلْأُولَىٰ وَمَا نَحْنُ بِمُعَذَّبِينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmdcccxlviii{إِنَّ هَٰذَا لَهُوَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmdcccxlix{لِمِثْلِ هَٰذَا فَلْيَعْمَلِ ٱلْعَٰمِلُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmdcccl{أَذَٰلِكَ خَيْرٌ نُّزُلًا أَمْ شَجَرَةُ ٱلزَّقُّومِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmdcccli{إِنَّا جَعَلْنَٰهَا فِتْنَةً لِّلظَّٰلِمِينَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmdccclii{إِنَّهَا شَجَرَةٌ تَخْرُجُ فِىٓ أَصْلِ ٱلْجَحِيمِ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmdcccliii{طَلْعُهَا كَأَنَّهُۥ رُءُوسُ ٱلشَّيَٰطِينِ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmdcccliv{فَإِنَّهُمْ لَءَاكِلُونَ مِنْهَا فَمَالِـُٔونَ مِنْهَا ٱلْبُطُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmdccclv{ثُمَّ إِنَّ لَهُمْ عَلَيْهَا لَشَوْبًا مِّنْ حَمِيمٍ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmdccclvi{ثُمَّ إِنَّ مَرْجِعَهُمْ لَإِلَى ٱلْجَحِيمِ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmdccclvii{إِنَّهُمْ أَلْفَوْا۟ ءَابَآءَهُمْ ضَآلِّينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmdccclviii{فَهُمْ عَلَىٰٓ ءَاثَٰرِهِمْ يُهْرَعُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmdccclix{وَلَقَدْ ضَلَّ قَبْلَهُمْ أَكْثَرُ ٱلْأَوَّلِينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmdccclx{وَلَقَدْ أَرْسَلْنَا فِيهِم مُّنذِرِينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmdccclxi{فَٱنظُرْ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُنذَرِينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmdccclxii{إِلَّا عِبَادَ ٱللَّهِ ٱلْمُخْلَصِينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmdccclxiii{وَلَقَدْ نَادَىٰنَا نُوحٌ فَلَنِعْمَ ٱلْمُجِيبُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmdccclxiv{وَنَجَّيْنَٰهُ وَأَهْلَهُۥ مِنَ ٱلْكَرْبِ ٱلْعَظِيمِ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmdccclxv{وَجَعَلْنَا ذُرِّيَّتَهُۥ هُمُ ٱلْبَاقِينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmdccclxvi{وَتَرَكْنَا عَلَيْهِ فِى ٱلْءَاخِرِينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmdccclxvii{سَلَٰمٌ عَلَىٰ نُوحٍ فِى ٱلْعَٰلَمِينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmdccclxviii{إِنَّا كَذَٰلِكَ نَجْزِى ٱلْمُحْسِنِينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmdccclxix{إِنَّهُۥ مِنْ عِبَادِنَا ٱلْمُؤْمِنِينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmdccclxx{ثُمَّ أَغْرَقْنَا ٱلْءَاخَرِينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmdccclxxi{وَإِنَّ مِن شِيعَتِهِۦ لَإِبْرَٰهِيمَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmdccclxxii{إِذْ جَآءَ رَبَّهُۥ بِقَلْبٍ سَلِيمٍ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmdccclxxiii{إِذْ قَالَ لِأَبِيهِ وَقَوْمِهِۦ مَاذَا تَعْبُدُونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmdccclxxiv{أَئِفْكًا ءَالِهَةً دُونَ ٱللَّهِ تُرِيدُونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmdccclxxv{فَمَا ظَنُّكُم بِرَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmdccclxxvi{فَنَظَرَ نَظْرَةً فِى ٱلنُّجُومِ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmdccclxxvii{فَقَالَ إِنِّى سَقِيمٌ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmdccclxxviii{فَتَوَلَّوْا۟ عَنْهُ مُدْبِرِينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmdccclxxix{فَرَاغَ إِلَىٰٓ ءَالِهَتِهِمْ فَقَالَ أَلَا تَأْكُلُونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmdccclxxx{مَا لَكُمْ لَا تَنطِقُونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmdccclxxxi{فَرَاغَ عَلَيْهِمْ ضَرْبًۢا بِٱلْيَمِينِ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmdccclxxxii{فَأَقْبَلُوٓا۟ إِلَيْهِ يَزِفُّونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmmdccclxxxiii{قَالَ أَتَعْبُدُونَ مَا تَنْحِتُونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmmdccclxxxiv{وَٱللَّهُ خَلَقَكُمْ وَمَا تَعْمَلُونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmmdccclxxxv{قَالُوا۟ ٱبْنُوا۟ لَهُۥ بُنْيَٰنًا فَأَلْقُوهُ فِى ٱلْجَحِيمِ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmmdccclxxxvi{فَأَرَادُوا۟ بِهِۦ كَيْدًا فَجَعَلْنَٰهُمُ ٱلْأَسْفَلِينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmmdccclxxxvii{وَقَالَ إِنِّى ذَاهِبٌ إِلَىٰ رَبِّى سَيَهْدِينِ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmmdccclxxxviii{رَبِّ هَبْ لِى مِنَ ٱلصَّٰلِحِينَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmmdccclxxxix{فَبَشَّرْنَٰهُ بِغُلَٰمٍ حَلِيمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmmdcccxc{فَلَمَّا بَلَغَ مَعَهُ ٱلسَّعْىَ قَالَ يَٰبُنَىَّ إِنِّىٓ أَرَىٰ فِى ٱلْمَنَامِ أَنِّىٓ أَذْبَحُكَ فَٱنظُرْ مَاذَا تَرَىٰ قَالَ يَٰٓأَبَتِ ٱفْعَلْ مَا تُؤْمَرُ سَتَجِدُنِىٓ إِن شَآءَ ٱللَّهُ مِنَ ٱلصَّٰبِرِينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmmdcccxci{فَلَمَّآ أَسْلَمَا وَتَلَّهُۥ لِلْجَبِينِ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmmdcccxcii{وَنَٰدَيْنَٰهُ أَن يَٰٓإِبْرَٰهِيمُ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmmdcccxciii{قَدْ صَدَّقْتَ ٱلرُّءْيَآ إِنَّا كَذَٰلِكَ نَجْزِى ٱلْمُحْسِنِينَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmmdcccxciv{إِنَّ هَٰذَا لَهُوَ ٱلْبَلَٰٓؤُا۟ ٱلْمُبِينُ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmmdcccxcv{وَفَدَيْنَٰهُ بِذِبْحٍ عَظِيمٍ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmmdcccxcvi{وَتَرَكْنَا عَلَيْهِ فِى ٱلْءَاخِرِينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmmdcccxcvii{سَلَٰمٌ عَلَىٰٓ إِبْرَٰهِيمَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmmdcccxcviii{كَذَٰلِكَ نَجْزِى ٱلْمُحْسِنِينَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmmdcccxcix{إِنَّهُۥ مِنْ عِبَادِنَا ٱلْمُؤْمِنِينَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmmcm{وَبَشَّرْنَٰهُ بِإِسْحَٰقَ نَبِيًّا مِّنَ ٱلصَّٰلِحِينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmmcmi{وَبَٰرَكْنَا عَلَيْهِ وَعَلَىٰٓ إِسْحَٰقَ وَمِن ذُرِّيَّتِهِمَا مُحْسِنٌ وَظَالِمٌ لِّنَفْسِهِۦ مُبِينٌ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmmcmii{وَلَقَدْ مَنَنَّا عَلَىٰ مُوسَىٰ وَهَٰرُونَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmmcmiii{وَنَجَّيْنَٰهُمَا وَقَوْمَهُمَا مِنَ ٱلْكَرْبِ ٱلْعَظِيمِ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmmcmiv{وَنَصَرْنَٰهُمْ فَكَانُوا۟ هُمُ ٱلْغَٰلِبِينَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmmcmv{وَءَاتَيْنَٰهُمَا ٱلْكِتَٰبَ ٱلْمُسْتَبِينَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmmcmvi{وَهَدَيْنَٰهُمَا ٱلصِّرَٰطَ ٱلْمُسْتَقِيمَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmmcmvii{وَتَرَكْنَا عَلَيْهِمَا فِى ٱلْءَاخِرِينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmmcmviii{سَلَٰمٌ عَلَىٰ مُوسَىٰ وَهَٰرُونَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmmcmix{إِنَّا كَذَٰلِكَ نَجْزِى ٱلْمُحْسِنِينَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmmcmx{إِنَّهُمَا مِنْ عِبَادِنَا ٱلْمُؤْمِنِينَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmmcmxi{وَإِنَّ إِلْيَاسَ لَمِنَ ٱلْمُرْسَلِينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmmcmxii{إِذْ قَالَ لِقَوْمِهِۦٓ أَلَا تَتَّقُونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmmcmxiii{أَتَدْعُونَ بَعْلًا وَتَذَرُونَ أَحْسَنَ ٱلْخَٰلِقِينَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmmcmxiv{ٱللَّهَ رَبَّكُمْ وَرَبَّ ءَابَآئِكُمُ ٱلْأَوَّلِينَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmmcmxv{فَكَذَّبُوهُ فَإِنَّهُمْ لَمُحْضَرُونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmmcmxvi{إِلَّا عِبَادَ ٱللَّهِ ٱلْمُخْلَصِينَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmmcmxvii{وَتَرَكْنَا عَلَيْهِ فِى ٱلْءَاخِرِينَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mmmcmxviii{سَلَٰمٌ عَلَىٰٓ إِلْ يَاسِينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mmmcmxix{إِنَّا كَذَٰلِكَ نَجْزِى ٱلْمُحْسِنِينَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mmmcmxx{إِنَّهُۥ مِنْ عِبَادِنَا ٱلْمُؤْمِنِينَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mmmcmxxi{وَإِنَّ لُوطًا لَّمِنَ ٱلْمُرْسَلِينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mmmcmxxii{إِذْ نَجَّيْنَٰهُ وَأَهْلَهُۥٓ أَجْمَعِينَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mmmcmxxiii{إِلَّا عَجُوزًا فِى ٱلْغَٰبِرِينَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mmmcmxxiv{ثُمَّ دَمَّرْنَا ٱلْءَاخَرِينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@mmmcmxxv{وَإِنَّكُمْ لَتَمُرُّونَ عَلَيْهِم مُّصْبِحِينَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@mmmcmxxvi{وَبِٱلَّيْلِ أَفَلَا تَعْقِلُونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@mmmcmxxvii{وَإِنَّ يُونُسَ لَمِنَ ٱلْمُرْسَلِينَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@mmmcmxxviii{إِذْ أَبَقَ إِلَى ٱلْفُلْكِ ٱلْمَشْحُونِ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@mmmcmxxix{فَسَاهَمَ فَكَانَ مِنَ ٱلْمُدْحَضِينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@mmmcmxxx{فَٱلْتَقَمَهُ ٱلْحُوتُ وَهُوَ مُلِيمٌ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@mmmcmxxxi{فَلَوْلَآ أَنَّهُۥ كَانَ مِنَ ٱلْمُسَبِّحِينَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@mmmcmxxxii{لَلَبِثَ فِى بَطْنِهِۦٓ إِلَىٰ يَوْمِ يُبْعَثُونَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@mmmcmxxxiii{فَنَبَذْنَٰهُ بِٱلْعَرَآءِ وَهُوَ سَقِيمٌ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@mmmcmxxxiv{وَأَنۢبَتْنَا عَلَيْهِ شَجَرَةً مِّن يَقْطِينٍ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@mmmcmxxxv{وَأَرْسَلْنَٰهُ إِلَىٰ مِا۟ئَةِ أَلْفٍ أَوْ يَزِيدُونَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@mmmcmxxxvi{فَـَٔامَنُوا۟ فَمَتَّعْنَٰهُمْ إِلَىٰ حِينٍ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@mmmcmxxxvii{فَٱسْتَفْتِهِمْ أَلِرَبِّكَ ٱلْبَنَاتُ وَلَهُمُ ٱلْبَنُونَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@mmmcmxxxviii{أَمْ خَلَقْنَا ٱلْمَلَٰٓئِكَةَ إِنَٰثًا وَهُمْ شَٰهِدُونَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@mmmcmxxxix{أَلَآ إِنَّهُم مِّنْ إِفْكِهِمْ لَيَقُولُونَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@mmmcmxl{وَلَدَ ٱللَّهُ وَإِنَّهُمْ لَكَٰذِبُونَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@mmmcmxli{أَصْطَفَى ٱلْبَنَاتِ عَلَى ٱلْبَنِينَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@mmmcmxlii{مَا لَكُمْ كَيْفَ تَحْكُمُونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@mmmcmxliii{أَفَلَا تَذَكَّرُونَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@mmmcmxliv{أَمْ لَكُمْ سُلْطَٰنٌ مُّبِينٌ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@mmmcmxlv{فَأْتُوا۟ بِكِتَٰبِكُمْ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@mmmcmxlvi{وَجَعَلُوا۟ بَيْنَهُۥ وَبَيْنَ ٱلْجِنَّةِ نَسَبًا وَلَقَدْ عَلِمَتِ ٱلْجِنَّةُ إِنَّهُمْ لَمُحْضَرُونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@mmmcmxlvii{سُبْحَٰنَ ٱللَّهِ عَمَّا يَصِفُونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@mmmcmxlviii{إِلَّا عِبَادَ ٱللَّهِ ٱلْمُخْلَصِينَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@mmmcmxlix{فَإِنَّكُمْ وَمَا تَعْبُدُونَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@mmmcml{مَآ أَنتُمْ عَلَيْهِ بِفَٰتِنِينَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@mmmcmli{إِلَّا مَنْ هُوَ صَالِ ٱلْجَحِيمِ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@mmmcmlii{وَمَا مِنَّآ إِلَّا لَهُۥ مَقَامٌ مَّعْلُومٌ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@mmmcmliii{وَإِنَّا لَنَحْنُ ٱلصَّآفُّونَ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@mmmcmliv{وَإِنَّا لَنَحْنُ ٱلْمُسَبِّحُونَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@mmmcmlv{وَإِن كَانُوا۟ لَيَقُولُونَ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@mmmcmlvi{لَوْ أَنَّ عِندَنَا ذِكْرًا مِّنَ ٱلْأَوَّلِينَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@mmmcmlvii{لَكُنَّا عِبَادَ ٱللَّهِ ٱلْمُخْلَصِينَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@mmmcmlviii{فَكَفَرُوا۟ بِهِۦ فَسَوْفَ يَعْلَمُونَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@mmmcmlix{وَلَقَدْ سَبَقَتْ كَلِمَتُنَا لِعِبَادِنَا ٱلْمُرْسَلِينَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@mmmcmlx{إِنَّهُمْ لَهُمُ ٱلْمَنصُورُونَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@mmmcmlxi{وَإِنَّ جُندَنَا لَهُمُ ٱلْغَٰلِبُونَ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@mmmcmlxii{فَتَوَلَّ عَنْهُمْ حَتَّىٰ حِينٍ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@mmmcmlxiii{وَأَبْصِرْهُمْ فَسَوْفَ يُبْصِرُونَ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@mmmcmlxiv{أَفَبِعَذَابِنَا يَسْتَعْجِلُونَ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@mmmcmlxv{فَإِذَا نَزَلَ بِسَاحَتِهِمْ فَسَآءَ صَبَاحُ ٱلْمُنذَرِينَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@mmmcmlxvi{وَتَوَلَّ عَنْهُمْ حَتَّىٰ حِينٍ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@mmmcmlxvii{وَأَبْصِرْ فَسَوْفَ يُبْصِرُونَ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@mmmcmlxviii{سُبْحَٰنَ رَبِّكَ رَبِّ ٱلْعِزَّةِ عَمَّا يَصِفُونَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@mmmcmlxix{وَسَلَٰمٌ عَلَى ٱلْمُرْسَلِينَ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@mmmcmlxx{وَٱلْحَمْدُ لِلَّهِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@mmmcmlxxi{\basmalah صٓ وَٱلْقُرْءَانِ ذِى ٱلذِّكْرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcmlxxii{بَلِ ٱلَّذِينَ كَفَرُوا۟ فِى عِزَّةٍ وَشِقَاقٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcmlxxiii{كَمْ أَهْلَكْنَا مِن قَبْلِهِم مِّن قَرْنٍ فَنَادَوا۟ وَّلَاتَ حِينَ مَنَاصٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcmlxxiv{وَعَجِبُوٓا۟ أَن جَآءَهُم مُّنذِرٌ مِّنْهُمْ وَقَالَ ٱلْكَٰفِرُونَ هَٰذَا سَٰحِرٌ كَذَّابٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcmlxxv{أَجَعَلَ ٱلْءَالِهَةَ إِلَٰهًا وَٰحِدًا إِنَّ هَٰذَا لَشَىْءٌ عُجَابٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcmlxxvi{وَٱنطَلَقَ ٱلْمَلَأُ مِنْهُمْ أَنِ ٱمْشُوا۟ وَٱصْبِرُوا۟ عَلَىٰٓ ءَالِهَتِكُمْ إِنَّ هَٰذَا لَشَىْءٌ يُرَادُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcmlxxvii{مَا سَمِعْنَا بِهَٰذَا فِى ٱلْمِلَّةِ ٱلْءَاخِرَةِ إِنْ هَٰذَآ إِلَّا ٱخْتِلَٰقٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcmlxxviii{أَءُنزِلَ عَلَيْهِ ٱلذِّكْرُ مِنۢ بَيْنِنَا بَلْ هُمْ فِى شَكٍّ مِّن ذِكْرِى بَل لَّمَّا يَذُوقُوا۟ عَذَابِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcmlxxix{أَمْ عِندَهُمْ خَزَآئِنُ رَحْمَةِ رَبِّكَ ٱلْعَزِيزِ ٱلْوَهَّابِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcmlxxx{أَمْ لَهُم مُّلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَا فَلْيَرْتَقُوا۟ فِى ٱلْأَسْبَٰبِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcmlxxxi{جُندٌ مَّا هُنَالِكَ مَهْزُومٌ مِّنَ ٱلْأَحْزَابِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcmlxxxii{كَذَّبَتْ قَبْلَهُمْ قَوْمُ نُوحٍ وَعَادٌ وَفِرْعَوْنُ ذُو ٱلْأَوْتَادِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcmlxxxiii{وَثَمُودُ وَقَوْمُ لُوطٍ وَأَصْحَٰبُ لْـَٔيْكَةِ أُو۟لَٰٓئِكَ ٱلْأَحْزَابُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcmlxxxiv{إِن كُلٌّ إِلَّا كَذَّبَ ٱلرُّسُلَ فَحَقَّ عِقَابِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcmlxxxv{وَمَا يَنظُرُ هَٰٓؤُلَآءِ إِلَّا صَيْحَةً وَٰحِدَةً مَّا لَهَا مِن فَوَاقٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcmlxxxvi{وَقَالُوا۟ رَبَّنَا عَجِّل لَّنَا قِطَّنَا قَبْلَ يَوْمِ ٱلْحِسَابِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcmlxxxvii{ٱصْبِرْ عَلَىٰ مَا يَقُولُونَ وَٱذْكُرْ عَبْدَنَا دَاوُۥدَ ذَا ٱلْأَيْدِ إِنَّهُۥٓ أَوَّابٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcmlxxxviii{إِنَّا سَخَّرْنَا ٱلْجِبَالَ مَعَهُۥ يُسَبِّحْنَ بِٱلْعَشِىِّ وَٱلْإِشْرَاقِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcmlxxxix{وَٱلطَّيْرَ مَحْشُورَةً كُلٌّ لَّهُۥٓ أَوَّابٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcmxc{وَشَدَدْنَا مُلْكَهُۥ وَءَاتَيْنَٰهُ ٱلْحِكْمَةَ وَفَصْلَ ٱلْخِطَابِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcmxci{وَهَلْ أَتَىٰكَ نَبَؤُا۟ ٱلْخَصْمِ إِذْ تَسَوَّرُوا۟ ٱلْمِحْرَابَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcmxcii{إِذْ دَخَلُوا۟ عَلَىٰ دَاوُۥدَ فَفَزِعَ مِنْهُمْ قَالُوا۟ لَا تَخَفْ خَصْمَانِ بَغَىٰ بَعْضُنَا عَلَىٰ بَعْضٍ فَٱحْكُم بَيْنَنَا بِٱلْحَقِّ وَلَا تُشْطِطْ وَٱهْدِنَآ إِلَىٰ سَوَآءِ ٱلصِّرَٰطِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcmxciii{إِنَّ هَٰذَآ أَخِى لَهُۥ تِسْعٌ وَتِسْعُونَ نَعْجَةً وَلِىَ نَعْجَةٌ وَٰحِدَةٌ فَقَالَ أَكْفِلْنِيهَا وَعَزَّنِى فِى ٱلْخِطَابِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcmxciv{قَالَ لَقَدْ ظَلَمَكَ بِسُؤَالِ نَعْجَتِكَ إِلَىٰ نِعَاجِهِۦ وَإِنَّ كَثِيرًا مِّنَ ٱلْخُلَطَآءِ لَيَبْغِى بَعْضُهُمْ عَلَىٰ بَعْضٍ إِلَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ وَقَلِيلٌ مَّا هُمْ وَظَنَّ دَاوُۥدُ أَنَّمَا فَتَنَّٰهُ فَٱسْتَغْفَرَ رَبَّهُۥ وَخَرَّ رَاكِعًا وَأَنَابَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcmxcv{فَغَفَرْنَا لَهُۥ ذَٰلِكَ وَإِنَّ لَهُۥ عِندَنَا لَزُلْفَىٰ وَحُسْنَ مَـَٔابٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcmxcvi{يَٰدَاوُۥدُ إِنَّا جَعَلْنَٰكَ خَلِيفَةً فِى ٱلْأَرْضِ فَٱحْكُم بَيْنَ ٱلنَّاسِ بِٱلْحَقِّ وَلَا تَتَّبِعِ ٱلْهَوَىٰ فَيُضِلَّكَ عَن سَبِيلِ ٱللَّهِ إِنَّ ٱلَّذِينَ يَضِلُّونَ عَن سَبِيلِ ٱللَّهِ لَهُمْ عَذَابٌ شَدِيدٌۢ بِمَا نَسُوا۟ يَوْمَ ٱلْحِسَابِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcmxcvii{وَمَا خَلَقْنَا ٱلسَّمَآءَ وَٱلْأَرْضَ وَمَا بَيْنَهُمَا بَٰطِلًا ذَٰلِكَ ظَنُّ ٱلَّذِينَ كَفَرُوا۟ فَوَيْلٌ لِّلَّذِينَ كَفَرُوا۟ مِنَ ٱلنَّارِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcmxcviii{أَمْ نَجْعَلُ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ كَٱلْمُفْسِدِينَ فِى ٱلْأَرْضِ أَمْ نَجْعَلُ ٱلْمُتَّقِينَ كَٱلْفُجَّارِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcmxcix{كِتَٰبٌ أَنزَلْنَٰهُ إِلَيْكَ مُبَٰرَكٌ لِّيَدَّبَّرُوٓا۟ ءَايَٰتِهِۦ وَلِيَتَذَكَّرَ أُو۟لُوا۟ ٱلْأَلْبَٰبِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmm{وَوَهَبْنَا لِدَاوُۥدَ سُلَيْمَٰنَ نِعْمَ ٱلْعَبْدُ إِنَّهُۥٓ أَوَّابٌ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmi{إِذْ عُرِضَ عَلَيْهِ بِٱلْعَشِىِّ ٱلصَّٰفِنَٰتُ ٱلْجِيَادُ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmii{فَقَالَ إِنِّىٓ أَحْبَبْتُ حُبَّ ٱلْخَيْرِ عَن ذِكْرِ رَبِّى حَتَّىٰ تَوَارَتْ بِٱلْحِجَابِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmiii{رُدُّوهَا عَلَىَّ فَطَفِقَ مَسْحًۢا بِٱلسُّوقِ وَٱلْأَعْنَاقِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmiv{وَلَقَدْ فَتَنَّا سُلَيْمَٰنَ وَأَلْقَيْنَا عَلَىٰ كُرْسِيِّهِۦ جَسَدًا ثُمَّ أَنَابَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmv{قَالَ رَبِّ ٱغْفِرْ لِى وَهَبْ لِى مُلْكًا لَّا يَنۢبَغِى لِأَحَدٍ مِّنۢ بَعْدِىٓ إِنَّكَ أَنتَ ٱلْوَهَّابُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmvi{فَسَخَّرْنَا لَهُ ٱلرِّيحَ تَجْرِى بِأَمْرِهِۦ رُخَآءً حَيْثُ أَصَابَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmvii{وَٱلشَّيَٰطِينَ كُلَّ بَنَّآءٍ وَغَوَّاصٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmviii{وَءَاخَرِينَ مُقَرَّنِينَ فِى ٱلْأَصْفَادِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmix{هَٰذَا عَطَآؤُنَا فَٱمْنُنْ أَوْ أَمْسِكْ بِغَيْرِ حِسَابٍ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmx{وَإِنَّ لَهُۥ عِندَنَا لَزُلْفَىٰ وَحُسْنَ مَـَٔابٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmxi{وَٱذْكُرْ عَبْدَنَآ أَيُّوبَ إِذْ نَادَىٰ رَبَّهُۥٓ أَنِّى مَسَّنِىَ ٱلشَّيْطَٰنُ بِنُصْبٍ وَعَذَابٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmxii{ٱرْكُضْ بِرِجْلِكَ هَٰذَا مُغْتَسَلٌۢ بَارِدٌ وَشَرَابٌ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmxiii{وَوَهَبْنَا لَهُۥٓ أَهْلَهُۥ وَمِثْلَهُم مَّعَهُمْ رَحْمَةً مِّنَّا وَذِكْرَىٰ لِأُو۟لِى ٱلْأَلْبَٰبِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmxiv{وَخُذْ بِيَدِكَ ضِغْثًا فَٱضْرِب بِّهِۦ وَلَا تَحْنَثْ إِنَّا وَجَدْنَٰهُ صَابِرًا نِّعْمَ ٱلْعَبْدُ إِنَّهُۥٓ أَوَّابٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmxv{وَٱذْكُرْ عِبَٰدَنَآ إِبْرَٰهِيمَ وَإِسْحَٰقَ وَيَعْقُوبَ أُو۟لِى ٱلْأَيْدِى وَٱلْأَبْصَٰرِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmxvi{إِنَّآ أَخْلَصْنَٰهُم بِخَالِصَةٍ ذِكْرَى ٱلدَّارِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmxvii{وَإِنَّهُمْ عِندَنَا لَمِنَ ٱلْمُصْطَفَيْنَ ٱلْأَخْيَارِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmxviii{وَٱذْكُرْ إِسْمَٰعِيلَ وَٱلْيَسَعَ وَذَا ٱلْكِفْلِ وَكُلٌّ مِّنَ ٱلْأَخْيَارِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmxix{هَٰذَا ذِكْرٌ وَإِنَّ لِلْمُتَّقِينَ لَحُسْنَ مَـَٔابٍ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmxx{جَنَّٰتِ عَدْنٍ مُّفَتَّحَةً لَّهُمُ ٱلْأَبْوَٰبُ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmxxi{مُتَّكِـِٔينَ فِيهَا يَدْعُونَ فِيهَا بِفَٰكِهَةٍ كَثِيرَةٍ وَشَرَابٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmxxii{وَعِندَهُمْ قَٰصِرَٰتُ ٱلطَّرْفِ أَتْرَابٌ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmxxiii{هَٰذَا مَا تُوعَدُونَ لِيَوْمِ ٱلْحِسَابِ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmxxiv{إِنَّ هَٰذَا لَرِزْقُنَا مَا لَهُۥ مِن نَّفَادٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmxxv{هَٰذَا وَإِنَّ لِلطَّٰغِينَ لَشَرَّ مَـَٔابٍ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmxxvi{جَهَنَّمَ يَصْلَوْنَهَا فَبِئْسَ ٱلْمِهَادُ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmxxvii{هَٰذَا فَلْيَذُوقُوهُ حَمِيمٌ وَغَسَّاقٌ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmxxviii{وَءَاخَرُ مِن شَكْلِهِۦٓ أَزْوَٰجٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmxxix{هَٰذَا فَوْجٌ مُّقْتَحِمٌ مَّعَكُمْ لَا مَرْحَبًۢا بِهِمْ إِنَّهُمْ صَالُوا۟ ٱلنَّارِ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmxxx{قَالُوا۟ بَلْ أَنتُمْ لَا مَرْحَبًۢا بِكُمْ أَنتُمْ قَدَّمْتُمُوهُ لَنَا فَبِئْسَ ٱلْقَرَارُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmxxxi{قَالُوا۟ رَبَّنَا مَن قَدَّمَ لَنَا هَٰذَا فَزِدْهُ عَذَابًا ضِعْفًا فِى ٱلنَّارِ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmxxxii{وَقَالُوا۟ مَا لَنَا لَا نَرَىٰ رِجَالًا كُنَّا نَعُدُّهُم مِّنَ ٱلْأَشْرَارِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmxxxiii{أَتَّخَذْنَٰهُمْ سِخْرِيًّا أَمْ زَاغَتْ عَنْهُمُ ٱلْأَبْصَٰرُ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmxxxiv{إِنَّ ذَٰلِكَ لَحَقٌّ تَخَاصُمُ أَهْلِ ٱلنَّارِ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmxxxv{قُلْ إِنَّمَآ أَنَا۠ مُنذِرٌ وَمَا مِنْ إِلَٰهٍ إِلَّا ٱللَّهُ ٱلْوَٰحِدُ ٱلْقَهَّارُ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmxxxvi{رَبُّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَا ٱلْعَزِيزُ ٱلْغَفَّٰرُ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmxxxvii{قُلْ هُوَ نَبَؤٌا۟ عَظِيمٌ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmxxxviii{أَنتُمْ عَنْهُ مُعْرِضُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmxxxix{مَا كَانَ لِىَ مِنْ عِلْمٍۭ بِٱلْمَلَإِ ٱلْأَعْلَىٰٓ إِذْ يَخْتَصِمُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmxl{إِن يُوحَىٰٓ إِلَىَّ إِلَّآ أَنَّمَآ أَنَا۠ نَذِيرٌ مُّبِينٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmxli{إِذْ قَالَ رَبُّكَ لِلْمَلَٰٓئِكَةِ إِنِّى خَٰلِقٌۢ بَشَرًا مِّن طِينٍ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmxlii{فَإِذَا سَوَّيْتُهُۥ وَنَفَخْتُ فِيهِ مِن رُّوحِى فَقَعُوا۟ لَهُۥ سَٰجِدِينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmxliii{فَسَجَدَ ٱلْمَلَٰٓئِكَةُ كُلُّهُمْ أَجْمَعُونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmxliv{إِلَّآ إِبْلِيسَ ٱسْتَكْبَرَ وَكَانَ مِنَ ٱلْكَٰفِرِينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmxlv{قَالَ يَٰٓإِبْلِيسُ مَا مَنَعَكَ أَن تَسْجُدَ لِمَا خَلَقْتُ بِيَدَىَّ أَسْتَكْبَرْتَ أَمْ كُنتَ مِنَ ٱلْعَالِينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmxlvi{قَالَ أَنَا۠ خَيْرٌ مِّنْهُ خَلَقْتَنِى مِن نَّارٍ وَخَلَقْتَهُۥ مِن طِينٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmxlvii{قَالَ فَٱخْرُجْ مِنْهَا فَإِنَّكَ رَجِيمٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmxlviii{وَإِنَّ عَلَيْكَ لَعْنَتِىٓ إِلَىٰ يَوْمِ ٱلدِّينِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmxlix{قَالَ رَبِّ فَأَنظِرْنِىٓ إِلَىٰ يَوْمِ يُبْعَثُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmml{قَالَ فَإِنَّكَ مِنَ ٱلْمُنظَرِينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmli{إِلَىٰ يَوْمِ ٱلْوَقْتِ ٱلْمَعْلُومِ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmlii{قَالَ فَبِعِزَّتِكَ لَأُغْوِيَنَّهُمْ أَجْمَعِينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmliii{إِلَّا عِبَادَكَ مِنْهُمُ ٱلْمُخْلَصِينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmliv{قَالَ فَٱلْحَقُّ وَٱلْحَقَّ أَقُولُ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmlv{لَأَمْلَأَنَّ جَهَنَّمَ مِنكَ وَمِمَّن تَبِعَكَ مِنْهُمْ أَجْمَعِينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmlvi{قُلْ مَآ أَسْـَٔلُكُمْ عَلَيْهِ مِنْ أَجْرٍ وَمَآ أَنَا۠ مِنَ ٱلْمُتَكَلِّفِينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmmlvii{إِنْ هُوَ إِلَّا ذِكْرٌ لِّلْعَٰلَمِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmmlviii{وَلَتَعْلَمُنَّ نَبَأَهُۥ بَعْدَ حِينٍۭ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmmlix{\basmalah تَنزِيلُ ٱلْكِتَٰبِ مِنَ ٱللَّهِ ٱلْعَزِيزِ ٱلْحَكِيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmlx{إِنَّآ أَنزَلْنَآ إِلَيْكَ ٱلْكِتَٰبَ بِٱلْحَقِّ فَٱعْبُدِ ٱللَّهَ مُخْلِصًا لَّهُ ٱلدِّينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmlxi{أَلَا لِلَّهِ ٱلدِّينُ ٱلْخَالِصُ وَٱلَّذِينَ ٱتَّخَذُوا۟ مِن دُونِهِۦٓ أَوْلِيَآءَ مَا نَعْبُدُهُمْ إِلَّا لِيُقَرِّبُونَآ إِلَى ٱللَّهِ زُلْفَىٰٓ إِنَّ ٱللَّهَ يَحْكُمُ بَيْنَهُمْ فِى مَا هُمْ فِيهِ يَخْتَلِفُونَ إِنَّ ٱللَّهَ لَا يَهْدِى مَنْ هُوَ كَٰذِبٌ كَفَّارٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmlxii{لَّوْ أَرَادَ ٱللَّهُ أَن يَتَّخِذَ وَلَدًا لَّٱصْطَفَىٰ مِمَّا يَخْلُقُ مَا يَشَآءُ سُبْحَٰنَهُۥ هُوَ ٱللَّهُ ٱلْوَٰحِدُ ٱلْقَهَّارُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmlxiii{خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ بِٱلْحَقِّ يُكَوِّرُ ٱلَّيْلَ عَلَى ٱلنَّهَارِ وَيُكَوِّرُ ٱلنَّهَارَ عَلَى ٱلَّيْلِ وَسَخَّرَ ٱلشَّمْسَ وَٱلْقَمَرَ كُلٌّ يَجْرِى لِأَجَلٍ مُّسَمًّى أَلَا هُوَ ٱلْعَزِيزُ ٱلْغَفَّٰرُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmlxiv{خَلَقَكُم مِّن نَّفْسٍ وَٰحِدَةٍ ثُمَّ جَعَلَ مِنْهَا زَوْجَهَا وَأَنزَلَ لَكُم مِّنَ ٱلْأَنْعَٰمِ ثَمَٰنِيَةَ أَزْوَٰجٍ يَخْلُقُكُمْ فِى بُطُونِ أُمَّهَٰتِكُمْ خَلْقًا مِّنۢ بَعْدِ خَلْقٍ فِى ظُلُمَٰتٍ ثَلَٰثٍ ذَٰلِكُمُ ٱللَّهُ رَبُّكُمْ لَهُ ٱلْمُلْكُ لَآ إِلَٰهَ إِلَّا هُوَ فَأَنَّىٰ تُصْرَفُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmlxv{إِن تَكْفُرُوا۟ فَإِنَّ ٱللَّهَ غَنِىٌّ عَنكُمْ وَلَا يَرْضَىٰ لِعِبَادِهِ ٱلْكُفْرَ وَإِن تَشْكُرُوا۟ يَرْضَهُ لَكُمْ وَلَا تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَىٰ ثُمَّ إِلَىٰ رَبِّكُم مَّرْجِعُكُمْ فَيُنَبِّئُكُم بِمَا كُنتُمْ تَعْمَلُونَ إِنَّهُۥ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmlxvi{وَإِذَا مَسَّ ٱلْإِنسَٰنَ ضُرٌّ دَعَا رَبَّهُۥ مُنِيبًا إِلَيْهِ ثُمَّ إِذَا خَوَّلَهُۥ نِعْمَةً مِّنْهُ نَسِىَ مَا كَانَ يَدْعُوٓا۟ إِلَيْهِ مِن قَبْلُ وَجَعَلَ لِلَّهِ أَندَادًا لِّيُضِلَّ عَن سَبِيلِهِۦ قُلْ تَمَتَّعْ بِكُفْرِكَ قَلِيلًا إِنَّكَ مِنْ أَصْحَٰبِ ٱلنَّارِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmlxvii{أَمَّنْ هُوَ قَٰنِتٌ ءَانَآءَ ٱلَّيْلِ سَاجِدًا وَقَآئِمًا يَحْذَرُ ٱلْءَاخِرَةَ وَيَرْجُوا۟ رَحْمَةَ رَبِّهِۦ قُلْ هَلْ يَسْتَوِى ٱلَّذِينَ يَعْلَمُونَ وَٱلَّذِينَ لَا يَعْلَمُونَ إِنَّمَا يَتَذَكَّرُ أُو۟لُوا۟ ٱلْأَلْبَٰبِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmlxviii{قُلْ يَٰعِبَادِ ٱلَّذِينَ ءَامَنُوا۟ ٱتَّقُوا۟ رَبَّكُمْ لِلَّذِينَ أَحْسَنُوا۟ فِى هَٰذِهِ ٱلدُّنْيَا حَسَنَةٌ وَأَرْضُ ٱللَّهِ وَٰسِعَةٌ إِنَّمَا يُوَفَّى ٱلصَّٰبِرُونَ أَجْرَهُم بِغَيْرِ حِسَابٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmlxix{قُلْ إِنِّىٓ أُمِرْتُ أَنْ أَعْبُدَ ٱللَّهَ مُخْلِصًا لَّهُ ٱلدِّينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmlxx{وَأُمِرْتُ لِأَنْ أَكُونَ أَوَّلَ ٱلْمُسْلِمِينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmlxxi{قُلْ إِنِّىٓ أَخَافُ إِنْ عَصَيْتُ رَبِّى عَذَابَ يَوْمٍ عَظِيمٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmlxxii{قُلِ ٱللَّهَ أَعْبُدُ مُخْلِصًا لَّهُۥ دِينِى\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmlxxiii{فَٱعْبُدُوا۟ مَا شِئْتُم مِّن دُونِهِۦ قُلْ إِنَّ ٱلْخَٰسِرِينَ ٱلَّذِينَ خَسِرُوٓا۟ أَنفُسَهُمْ وَأَهْلِيهِمْ يَوْمَ ٱلْقِيَٰمَةِ أَلَا ذَٰلِكَ هُوَ ٱلْخُسْرَانُ ٱلْمُبِينُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmlxxiv{لَهُم مِّن فَوْقِهِمْ ظُلَلٌ مِّنَ ٱلنَّارِ وَمِن تَحْتِهِمْ ظُلَلٌ ذَٰلِكَ يُخَوِّفُ ٱللَّهُ بِهِۦ عِبَادَهُۥ يَٰعِبَادِ فَٱتَّقُونِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmlxxv{وَٱلَّذِينَ ٱجْتَنَبُوا۟ ٱلطَّٰغُوتَ أَن يَعْبُدُوهَا وَأَنَابُوٓا۟ إِلَى ٱللَّهِ لَهُمُ ٱلْبُشْرَىٰ فَبَشِّرْ عِبَادِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmlxxvi{ٱلَّذِينَ يَسْتَمِعُونَ ٱلْقَوْلَ فَيَتَّبِعُونَ أَحْسَنَهُۥٓ أُو۟لَٰٓئِكَ ٱلَّذِينَ هَدَىٰهُمُ ٱللَّهُ وَأُو۟لَٰٓئِكَ هُمْ أُو۟لُوا۟ ٱلْأَلْبَٰبِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmlxxvii{أَفَمَنْ حَقَّ عَلَيْهِ كَلِمَةُ ٱلْعَذَابِ أَفَأَنتَ تُنقِذُ مَن فِى ٱلنَّارِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmlxxviii{لَٰكِنِ ٱلَّذِينَ ٱتَّقَوْا۟ رَبَّهُمْ لَهُمْ غُرَفٌ مِّن فَوْقِهَا غُرَفٌ مَّبْنِيَّةٌ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ وَعْدَ ٱللَّهِ لَا يُخْلِفُ ٱللَّهُ ٱلْمِيعَادَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmlxxix{أَلَمْ تَرَ أَنَّ ٱللَّهَ أَنزَلَ مِنَ ٱلسَّمَآءِ مَآءً فَسَلَكَهُۥ يَنَٰبِيعَ فِى ٱلْأَرْضِ ثُمَّ يُخْرِجُ بِهِۦ زَرْعًا مُّخْتَلِفًا أَلْوَٰنُهُۥ ثُمَّ يَهِيجُ فَتَرَىٰهُ مُصْفَرًّا ثُمَّ يَجْعَلُهُۥ حُطَٰمًا إِنَّ فِى ذَٰلِكَ لَذِكْرَىٰ لِأُو۟لِى ٱلْأَلْبَٰبِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmlxxx{أَفَمَن شَرَحَ ٱللَّهُ صَدْرَهُۥ لِلْإِسْلَٰمِ فَهُوَ عَلَىٰ نُورٍ مِّن رَّبِّهِۦ فَوَيْلٌ لِّلْقَٰسِيَةِ قُلُوبُهُم مِّن ذِكْرِ ٱللَّهِ أُو۟لَٰٓئِكَ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmlxxxi{ٱللَّهُ نَزَّلَ أَحْسَنَ ٱلْحَدِيثِ كِتَٰبًا مُّتَشَٰبِهًا مَّثَانِىَ تَقْشَعِرُّ مِنْهُ جُلُودُ ٱلَّذِينَ يَخْشَوْنَ رَبَّهُمْ ثُمَّ تَلِينُ جُلُودُهُمْ وَقُلُوبُهُمْ إِلَىٰ ذِكْرِ ٱللَّهِ ذَٰلِكَ هُدَى ٱللَّهِ يَهْدِى بِهِۦ مَن يَشَآءُ وَمَن يُضْلِلِ ٱللَّهُ فَمَا لَهُۥ مِنْ هَادٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmlxxxii{أَفَمَن يَتَّقِى بِوَجْهِهِۦ سُوٓءَ ٱلْعَذَابِ يَوْمَ ٱلْقِيَٰمَةِ وَقِيلَ لِلظَّٰلِمِينَ ذُوقُوا۟ مَا كُنتُمْ تَكْسِبُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmlxxxiii{كَذَّبَ ٱلَّذِينَ مِن قَبْلِهِمْ فَأَتَىٰهُمُ ٱلْعَذَابُ مِنْ حَيْثُ لَا يَشْعُرُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmlxxxiv{فَأَذَاقَهُمُ ٱللَّهُ ٱلْخِزْىَ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَلَعَذَابُ ٱلْءَاخِرَةِ أَكْبَرُ لَوْ كَانُوا۟ يَعْلَمُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmlxxxv{وَلَقَدْ ضَرَبْنَا لِلنَّاسِ فِى هَٰذَا ٱلْقُرْءَانِ مِن كُلِّ مَثَلٍ لَّعَلَّهُمْ يَتَذَكَّرُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmlxxxvi{قُرْءَانًا عَرَبِيًّا غَيْرَ ذِى عِوَجٍ لَّعَلَّهُمْ يَتَّقُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmlxxxvii{ضَرَبَ ٱللَّهُ مَثَلًا رَّجُلًا فِيهِ شُرَكَآءُ مُتَشَٰكِسُونَ وَرَجُلًا سَلَمًا لِّرَجُلٍ هَلْ يَسْتَوِيَانِ مَثَلًا ٱلْحَمْدُ لِلَّهِ بَلْ أَكْثَرُهُمْ لَا يَعْلَمُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmlxxxviii{إِنَّكَ مَيِّتٌ وَإِنَّهُم مَّيِّتُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmlxxxix{ثُمَّ إِنَّكُمْ يَوْمَ ٱلْقِيَٰمَةِ عِندَ رَبِّكُمْ تَخْتَصِمُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmxc{فَمَنْ أَظْلَمُ مِمَّن كَذَبَ عَلَى ٱللَّهِ وَكَذَّبَ بِٱلصِّدْقِ إِذْ جَآءَهُۥٓ أَلَيْسَ فِى جَهَنَّمَ مَثْوًى لِّلْكَٰفِرِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmxci{وَٱلَّذِى جَآءَ بِٱلصِّدْقِ وَصَدَّقَ بِهِۦٓ أُو۟لَٰٓئِكَ هُمُ ٱلْمُتَّقُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmxcii{لَهُم مَّا يَشَآءُونَ عِندَ رَبِّهِمْ ذَٰلِكَ جَزَآءُ ٱلْمُحْسِنِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmxciii{لِيُكَفِّرَ ٱللَّهُ عَنْهُمْ أَسْوَأَ ٱلَّذِى عَمِلُوا۟ وَيَجْزِيَهُمْ أَجْرَهُم بِأَحْسَنِ ٱلَّذِى كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmxciv{أَلَيْسَ ٱللَّهُ بِكَافٍ عَبْدَهُۥ وَيُخَوِّفُونَكَ بِٱلَّذِينَ مِن دُونِهِۦ وَمَن يُضْلِلِ ٱللَّهُ فَمَا لَهُۥ مِنْ هَادٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmxcv{وَمَن يَهْدِ ٱللَّهُ فَمَا لَهُۥ مِن مُّضِلٍّ أَلَيْسَ ٱللَّهُ بِعَزِيزٍ ذِى ٱنتِقَامٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmxcvi{وَلَئِن سَأَلْتَهُم مَّنْ خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ لَيَقُولُنَّ ٱللَّهُ قُلْ أَفَرَءَيْتُم مَّا تَدْعُونَ مِن دُونِ ٱللَّهِ إِنْ أَرَادَنِىَ ٱللَّهُ بِضُرٍّ هَلْ هُنَّ كَٰشِفَٰتُ ضُرِّهِۦٓ أَوْ أَرَادَنِى بِرَحْمَةٍ هَلْ هُنَّ مُمْسِكَٰتُ رَحْمَتِهِۦ قُلْ حَسْبِىَ ٱللَّهُ عَلَيْهِ يَتَوَكَّلُ ٱلْمُتَوَكِّلُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmxcvii{قُلْ يَٰقَوْمِ ٱعْمَلُوا۟ عَلَىٰ مَكَانَتِكُمْ إِنِّى عَٰمِلٌ فَسَوْفَ تَعْلَمُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmxcviii{مَن يَأْتِيهِ عَذَابٌ يُخْزِيهِ وَيَحِلُّ عَلَيْهِ عَذَابٌ مُّقِيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmxcix{إِنَّآ أَنزَلْنَا عَلَيْكَ ٱلْكِتَٰبَ لِلنَّاسِ بِٱلْحَقِّ فَمَنِ ٱهْتَدَىٰ فَلِنَفْسِهِۦ وَمَن ضَلَّ فَإِنَّمَا يَضِلُّ عَلَيْهَا وَمَآ أَنتَ عَلَيْهِم بِوَكِيلٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmc{ٱللَّهُ يَتَوَفَّى ٱلْأَنفُسَ حِينَ مَوْتِهَا وَٱلَّتِى لَمْ تَمُتْ فِى مَنَامِهَا فَيُمْسِكُ ٱلَّتِى قَضَىٰ عَلَيْهَا ٱلْمَوْتَ وَيُرْسِلُ ٱلْأُخْرَىٰٓ إِلَىٰٓ أَجَلٍ مُّسَمًّى إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يَتَفَكَّرُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmci{أَمِ ٱتَّخَذُوا۟ مِن دُونِ ٱللَّهِ شُفَعَآءَ قُلْ أَوَلَوْ كَانُوا۟ لَا يَمْلِكُونَ شَيْـًٔا وَلَا يَعْقِلُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcii{قُل لِّلَّهِ ٱلشَّفَٰعَةُ جَمِيعًا لَّهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ ثُمَّ إِلَيْهِ تُرْجَعُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmciii{وَإِذَا ذُكِرَ ٱللَّهُ وَحْدَهُ ٱشْمَأَزَّتْ قُلُوبُ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ وَإِذَا ذُكِرَ ٱلَّذِينَ مِن دُونِهِۦٓ إِذَا هُمْ يَسْتَبْشِرُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmciv{قُلِ ٱللَّهُمَّ فَاطِرَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ عَٰلِمَ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ أَنتَ تَحْكُمُ بَيْنَ عِبَادِكَ فِى مَا كَانُوا۟ فِيهِ يَخْتَلِفُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcv{وَلَوْ أَنَّ لِلَّذِينَ ظَلَمُوا۟ مَا فِى ٱلْأَرْضِ جَمِيعًا وَمِثْلَهُۥ مَعَهُۥ لَٱفْتَدَوْا۟ بِهِۦ مِن سُوٓءِ ٱلْعَذَابِ يَوْمَ ٱلْقِيَٰمَةِ وَبَدَا لَهُم مِّنَ ٱللَّهِ مَا لَمْ يَكُونُوا۟ يَحْتَسِبُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcvi{وَبَدَا لَهُمْ سَيِّـَٔاتُ مَا كَسَبُوا۟ وَحَاقَ بِهِم مَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcvii{فَإِذَا مَسَّ ٱلْإِنسَٰنَ ضُرٌّ دَعَانَا ثُمَّ إِذَا خَوَّلْنَٰهُ نِعْمَةً مِّنَّا قَالَ إِنَّمَآ أُوتِيتُهُۥ عَلَىٰ عِلْمٍۭ بَلْ هِىَ فِتْنَةٌ وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَعْلَمُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcviii{قَدْ قَالَهَا ٱلَّذِينَ مِن قَبْلِهِمْ فَمَآ أَغْنَىٰ عَنْهُم مَّا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcix{فَأَصَابَهُمْ سَيِّـَٔاتُ مَا كَسَبُوا۟ وَٱلَّذِينَ ظَلَمُوا۟ مِنْ هَٰٓؤُلَآءِ سَيُصِيبُهُمْ سَيِّـَٔاتُ مَا كَسَبُوا۟ وَمَا هُم بِمُعْجِزِينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcx{أَوَلَمْ يَعْلَمُوٓا۟ أَنَّ ٱللَّهَ يَبْسُطُ ٱلرِّزْقَ لِمَن يَشَآءُ وَيَقْدِرُ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يُؤْمِنُونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcxi{قُلْ يَٰعِبَادِىَ ٱلَّذِينَ أَسْرَفُوا۟ عَلَىٰٓ أَنفُسِهِمْ لَا تَقْنَطُوا۟ مِن رَّحْمَةِ ٱللَّهِ إِنَّ ٱللَّهَ يَغْفِرُ ٱلذُّنُوبَ جَمِيعًا إِنَّهُۥ هُوَ ٱلْغَفُورُ ٱلرَّحِيمُ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcxii{وَأَنِيبُوٓا۟ إِلَىٰ رَبِّكُمْ وَأَسْلِمُوا۟ لَهُۥ مِن قَبْلِ أَن يَأْتِيَكُمُ ٱلْعَذَابُ ثُمَّ لَا تُنصَرُونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcxiii{وَٱتَّبِعُوٓا۟ أَحْسَنَ مَآ أُنزِلَ إِلَيْكُم مِّن رَّبِّكُم مِّن قَبْلِ أَن يَأْتِيَكُمُ ٱلْعَذَابُ بَغْتَةً وَأَنتُمْ لَا تَشْعُرُونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcxiv{أَن تَقُولَ نَفْسٌ يَٰحَسْرَتَىٰ عَلَىٰ مَا فَرَّطتُ فِى جَنۢبِ ٱللَّهِ وَإِن كُنتُ لَمِنَ ٱلسَّٰخِرِينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcxv{أَوْ تَقُولَ لَوْ أَنَّ ٱللَّهَ هَدَىٰنِى لَكُنتُ مِنَ ٱلْمُتَّقِينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcxvi{أَوْ تَقُولَ حِينَ تَرَى ٱلْعَذَابَ لَوْ أَنَّ لِى كَرَّةً فَأَكُونَ مِنَ ٱلْمُحْسِنِينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcxvii{بَلَىٰ قَدْ جَآءَتْكَ ءَايَٰتِى فَكَذَّبْتَ بِهَا وَٱسْتَكْبَرْتَ وَكُنتَ مِنَ ٱلْكَٰفِرِينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcxviii{وَيَوْمَ ٱلْقِيَٰمَةِ تَرَى ٱلَّذِينَ كَذَبُوا۟ عَلَى ٱللَّهِ وُجُوهُهُم مُّسْوَدَّةٌ أَلَيْسَ فِى جَهَنَّمَ مَثْوًى لِّلْمُتَكَبِّرِينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmcxix{وَيُنَجِّى ٱللَّهُ ٱلَّذِينَ ٱتَّقَوْا۟ بِمَفَازَتِهِمْ لَا يَمَسُّهُمُ ٱلسُّوٓءُ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmcxx{ٱللَّهُ خَٰلِقُ كُلِّ شَىْءٍ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ وَكِيلٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmcxxi{لَّهُۥ مَقَالِيدُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱلَّذِينَ كَفَرُوا۟ بِـَٔايَٰتِ ٱللَّهِ أُو۟لَٰٓئِكَ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmcxxii{قُلْ أَفَغَيْرَ ٱللَّهِ تَأْمُرُوٓنِّىٓ أَعْبُدُ أَيُّهَا ٱلْجَٰهِلُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcxxiii{وَلَقَدْ أُوحِىَ إِلَيْكَ وَإِلَى ٱلَّذِينَ مِن قَبْلِكَ لَئِنْ أَشْرَكْتَ لَيَحْبَطَنَّ عَمَلُكَ وَلَتَكُونَنَّ مِنَ ٱلْخَٰسِرِينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcxxiv{بَلِ ٱللَّهَ فَٱعْبُدْ وَكُن مِّنَ ٱلشَّٰكِرِينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcxxv{وَمَا قَدَرُوا۟ ٱللَّهَ حَقَّ قَدْرِهِۦ وَٱلْأَرْضُ جَمِيعًا قَبْضَتُهُۥ يَوْمَ ٱلْقِيَٰمَةِ وَٱلسَّمَٰوَٰتُ مَطْوِيَّٰتٌۢ بِيَمِينِهِۦ سُبْحَٰنَهُۥ وَتَعَٰلَىٰ عَمَّا يُشْرِكُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcxxvi{وَنُفِخَ فِى ٱلصُّورِ فَصَعِقَ مَن فِى ٱلسَّمَٰوَٰتِ وَمَن فِى ٱلْأَرْضِ إِلَّا مَن شَآءَ ٱللَّهُ ثُمَّ نُفِخَ فِيهِ أُخْرَىٰ فَإِذَا هُمْ قِيَامٌ يَنظُرُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmcxxvii{وَأَشْرَقَتِ ٱلْأَرْضُ بِنُورِ رَبِّهَا وَوُضِعَ ٱلْكِتَٰبُ وَجِا۟ىٓءَ بِٱلنَّبِيِّۦنَ وَٱلشُّهَدَآءِ وَقُضِىَ بَيْنَهُم بِٱلْحَقِّ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcxxviii{وَوُفِّيَتْ كُلُّ نَفْسٍ مَّا عَمِلَتْ وَهُوَ أَعْلَمُ بِمَا يَفْعَلُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcxxix{وَسِيقَ ٱلَّذِينَ كَفَرُوٓا۟ إِلَىٰ جَهَنَّمَ زُمَرًا حَتَّىٰٓ إِذَا جَآءُوهَا فُتِحَتْ أَبْوَٰبُهَا وَقَالَ لَهُمْ خَزَنَتُهَآ أَلَمْ يَأْتِكُمْ رُسُلٌ مِّنكُمْ يَتْلُونَ عَلَيْكُمْ ءَايَٰتِ رَبِّكُمْ وَيُنذِرُونَكُمْ لِقَآءَ يَوْمِكُمْ هَٰذَا قَالُوا۟ بَلَىٰ وَلَٰكِنْ حَقَّتْ كَلِمَةُ ٱلْعَذَابِ عَلَى ٱلْكَٰفِرِينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmcxxx{قِيلَ ٱدْخُلُوٓا۟ أَبْوَٰبَ جَهَنَّمَ خَٰلِدِينَ فِيهَا فَبِئْسَ مَثْوَى ٱلْمُتَكَبِّرِينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmcxxxi{وَسِيقَ ٱلَّذِينَ ٱتَّقَوْا۟ رَبَّهُمْ إِلَى ٱلْجَنَّةِ زُمَرًا حَتَّىٰٓ إِذَا جَآءُوهَا وَفُتِحَتْ أَبْوَٰبُهَا وَقَالَ لَهُمْ خَزَنَتُهَا سَلَٰمٌ عَلَيْكُمْ طِبْتُمْ فَٱدْخُلُوهَا خَٰلِدِينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmcxxxii{وَقَالُوا۟ ٱلْحَمْدُ لِلَّهِ ٱلَّذِى صَدَقَنَا وَعْدَهُۥ وَأَوْرَثَنَا ٱلْأَرْضَ نَتَبَوَّأُ مِنَ ٱلْجَنَّةِ حَيْثُ نَشَآءُ فَنِعْمَ أَجْرُ ٱلْعَٰمِلِينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmcxxxiii{وَتَرَى ٱلْمَلَٰٓئِكَةَ حَآفِّينَ مِنْ حَوْلِ ٱلْعَرْشِ يُسَبِّحُونَ بِحَمْدِ رَبِّهِمْ وَقُضِىَ بَيْنَهُم بِٱلْحَقِّ وَقِيلَ ٱلْحَمْدُ لِلَّهِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmcxxxiv{\basmalah حمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcxxxv{تَنزِيلُ ٱلْكِتَٰبِ مِنَ ٱللَّهِ ٱلْعَزِيزِ ٱلْعَلِيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcxxxvi{غَافِرِ ٱلذَّنۢبِ وَقَابِلِ ٱلتَّوْبِ شَدِيدِ ٱلْعِقَابِ ذِى ٱلطَّوْلِ لَآ إِلَٰهَ إِلَّا هُوَ إِلَيْهِ ٱلْمَصِيرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcxxxvii{مَا يُجَٰدِلُ فِىٓ ءَايَٰتِ ٱللَّهِ إِلَّا ٱلَّذِينَ كَفَرُوا۟ فَلَا يَغْرُرْكَ تَقَلُّبُهُمْ فِى ٱلْبِلَٰدِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcxxxviii{كَذَّبَتْ قَبْلَهُمْ قَوْمُ نُوحٍ وَٱلْأَحْزَابُ مِنۢ بَعْدِهِمْ وَهَمَّتْ كُلُّ أُمَّةٍۭ بِرَسُولِهِمْ لِيَأْخُذُوهُ وَجَٰدَلُوا۟ بِٱلْبَٰطِلِ لِيُدْحِضُوا۟ بِهِ ٱلْحَقَّ فَأَخَذْتُهُمْ فَكَيْفَ كَانَ عِقَابِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcxxxix{وَكَذَٰلِكَ حَقَّتْ كَلِمَتُ رَبِّكَ عَلَى ٱلَّذِينَ كَفَرُوٓا۟ أَنَّهُمْ أَصْحَٰبُ ٱلنَّارِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcxl{ٱلَّذِينَ يَحْمِلُونَ ٱلْعَرْشَ وَمَنْ حَوْلَهُۥ يُسَبِّحُونَ بِحَمْدِ رَبِّهِمْ وَيُؤْمِنُونَ بِهِۦ وَيَسْتَغْفِرُونَ لِلَّذِينَ ءَامَنُوا۟ رَبَّنَا وَسِعْتَ كُلَّ شَىْءٍ رَّحْمَةً وَعِلْمًا فَٱغْفِرْ لِلَّذِينَ تَابُوا۟ وَٱتَّبَعُوا۟ سَبِيلَكَ وَقِهِمْ عَذَابَ ٱلْجَحِيمِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcxli{رَبَّنَا وَأَدْخِلْهُمْ جَنَّٰتِ عَدْنٍ ٱلَّتِى وَعَدتَّهُمْ وَمَن صَلَحَ مِنْ ءَابَآئِهِمْ وَأَزْوَٰجِهِمْ وَذُرِّيَّٰتِهِمْ إِنَّكَ أَنتَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcxlii{وَقِهِمُ ٱلسَّيِّـَٔاتِ وَمَن تَقِ ٱلسَّيِّـَٔاتِ يَوْمَئِذٍ فَقَدْ رَحِمْتَهُۥ وَذَٰلِكَ هُوَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcxliii{إِنَّ ٱلَّذِينَ كَفَرُوا۟ يُنَادَوْنَ لَمَقْتُ ٱللَّهِ أَكْبَرُ مِن مَّقْتِكُمْ أَنفُسَكُمْ إِذْ تُدْعَوْنَ إِلَى ٱلْإِيمَٰنِ فَتَكْفُرُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcxliv{قَالُوا۟ رَبَّنَآ أَمَتَّنَا ٱثْنَتَيْنِ وَأَحْيَيْتَنَا ٱثْنَتَيْنِ فَٱعْتَرَفْنَا بِذُنُوبِنَا فَهَلْ إِلَىٰ خُرُوجٍ مِّن سَبِيلٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcxlv{ذَٰلِكُم بِأَنَّهُۥٓ إِذَا دُعِىَ ٱللَّهُ وَحْدَهُۥ كَفَرْتُمْ وَإِن يُشْرَكْ بِهِۦ تُؤْمِنُوا۟ فَٱلْحُكْمُ لِلَّهِ ٱلْعَلِىِّ ٱلْكَبِيرِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcxlvi{هُوَ ٱلَّذِى يُرِيكُمْ ءَايَٰتِهِۦ وَيُنَزِّلُ لَكُم مِّنَ ٱلسَّمَآءِ رِزْقًا وَمَا يَتَذَكَّرُ إِلَّا مَن يُنِيبُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcxlvii{فَٱدْعُوا۟ ٱللَّهَ مُخْلِصِينَ لَهُ ٱلدِّينَ وَلَوْ كَرِهَ ٱلْكَٰفِرُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcxlviii{رَفِيعُ ٱلدَّرَجَٰتِ ذُو ٱلْعَرْشِ يُلْقِى ٱلرُّوحَ مِنْ أَمْرِهِۦ عَلَىٰ مَن يَشَآءُ مِنْ عِبَادِهِۦ لِيُنذِرَ يَوْمَ ٱلتَّلَاقِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcxlix{يَوْمَ هُم بَٰرِزُونَ لَا يَخْفَىٰ عَلَى ٱللَّهِ مِنْهُمْ شَىْءٌ لِّمَنِ ٱلْمُلْكُ ٱلْيَوْمَ لِلَّهِ ٱلْوَٰحِدِ ٱلْقَهَّارِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcl{ٱلْيَوْمَ تُجْزَىٰ كُلُّ نَفْسٍۭ بِمَا كَسَبَتْ لَا ظُلْمَ ٱلْيَوْمَ إِنَّ ٱللَّهَ سَرِيعُ ٱلْحِسَابِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcli{وَأَنذِرْهُمْ يَوْمَ ٱلْءَازِفَةِ إِذِ ٱلْقُلُوبُ لَدَى ٱلْحَنَاجِرِ كَٰظِمِينَ مَا لِلظَّٰلِمِينَ مِنْ حَمِيمٍ وَلَا شَفِيعٍ يُطَاعُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmclii{يَعْلَمُ خَآئِنَةَ ٱلْأَعْيُنِ وَمَا تُخْفِى ٱلصُّدُورُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcliii{وَٱللَّهُ يَقْضِى بِٱلْحَقِّ وَٱلَّذِينَ يَدْعُونَ مِن دُونِهِۦ لَا يَقْضُونَ بِشَىْءٍ إِنَّ ٱللَّهَ هُوَ ٱلسَّمِيعُ ٱلْبَصِيرُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcliv{أَوَلَمْ يَسِيرُوا۟ فِى ٱلْأَرْضِ فَيَنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلَّذِينَ كَانُوا۟ مِن قَبْلِهِمْ كَانُوا۟ هُمْ أَشَدَّ مِنْهُمْ قُوَّةً وَءَاثَارًا فِى ٱلْأَرْضِ فَأَخَذَهُمُ ٱللَّهُ بِذُنُوبِهِمْ وَمَا كَانَ لَهُم مِّنَ ٱللَّهِ مِن وَاقٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmclv{ذَٰلِكَ بِأَنَّهُمْ كَانَت تَّأْتِيهِمْ رُسُلُهُم بِٱلْبَيِّنَٰتِ فَكَفَرُوا۟ فَأَخَذَهُمُ ٱللَّهُ إِنَّهُۥ قَوِىٌّ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmclvi{وَلَقَدْ أَرْسَلْنَا مُوسَىٰ بِـَٔايَٰتِنَا وَسُلْطَٰنٍ مُّبِينٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmclvii{إِلَىٰ فِرْعَوْنَ وَهَٰمَٰنَ وَقَٰرُونَ فَقَالُوا۟ سَٰحِرٌ كَذَّابٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmclviii{فَلَمَّا جَآءَهُم بِٱلْحَقِّ مِنْ عِندِنَا قَالُوا۟ ٱقْتُلُوٓا۟ أَبْنَآءَ ٱلَّذِينَ ءَامَنُوا۟ مَعَهُۥ وَٱسْتَحْيُوا۟ نِسَآءَهُمْ وَمَا كَيْدُ ٱلْكَٰفِرِينَ إِلَّا فِى ضَلَٰلٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmclix{وَقَالَ فِرْعَوْنُ ذَرُونِىٓ أَقْتُلْ مُوسَىٰ وَلْيَدْعُ رَبَّهُۥٓ إِنِّىٓ أَخَافُ أَن يُبَدِّلَ دِينَكُمْ أَوْ أَن يُظْهِرَ فِى ٱلْأَرْضِ ٱلْفَسَادَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmclx{وَقَالَ مُوسَىٰٓ إِنِّى عُذْتُ بِرَبِّى وَرَبِّكُم مِّن كُلِّ مُتَكَبِّرٍ لَّا يُؤْمِنُ بِيَوْمِ ٱلْحِسَابِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmclxi{وَقَالَ رَجُلٌ مُّؤْمِنٌ مِّنْ ءَالِ فِرْعَوْنَ يَكْتُمُ إِيمَٰنَهُۥٓ أَتَقْتُلُونَ رَجُلًا أَن يَقُولَ رَبِّىَ ٱللَّهُ وَقَدْ جَآءَكُم بِٱلْبَيِّنَٰتِ مِن رَّبِّكُمْ وَإِن يَكُ كَٰذِبًا فَعَلَيْهِ كَذِبُهُۥ وَإِن يَكُ صَادِقًا يُصِبْكُم بَعْضُ ٱلَّذِى يَعِدُكُمْ إِنَّ ٱللَّهَ لَا يَهْدِى مَنْ هُوَ مُسْرِفٌ كَذَّابٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmclxii{يَٰقَوْمِ لَكُمُ ٱلْمُلْكُ ٱلْيَوْمَ ظَٰهِرِينَ فِى ٱلْأَرْضِ فَمَن يَنصُرُنَا مِنۢ بَأْسِ ٱللَّهِ إِن جَآءَنَا قَالَ فِرْعَوْنُ مَآ أُرِيكُمْ إِلَّا مَآ أَرَىٰ وَمَآ أَهْدِيكُمْ إِلَّا سَبِيلَ ٱلرَّشَادِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmclxiii{وَقَالَ ٱلَّذِىٓ ءَامَنَ يَٰقَوْمِ إِنِّىٓ أَخَافُ عَلَيْكُم مِّثْلَ يَوْمِ ٱلْأَحْزَابِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmclxiv{مِثْلَ دَأْبِ قَوْمِ نُوحٍ وَعَادٍ وَثَمُودَ وَٱلَّذِينَ مِنۢ بَعْدِهِمْ وَمَا ٱللَّهُ يُرِيدُ ظُلْمًا لِّلْعِبَادِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmclxv{وَيَٰقَوْمِ إِنِّىٓ أَخَافُ عَلَيْكُمْ يَوْمَ ٱلتَّنَادِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmclxvi{يَوْمَ تُوَلُّونَ مُدْبِرِينَ مَا لَكُم مِّنَ ٱللَّهِ مِنْ عَاصِمٍ وَمَن يُضْلِلِ ٱللَّهُ فَمَا لَهُۥ مِنْ هَادٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmclxvii{وَلَقَدْ جَآءَكُمْ يُوسُفُ مِن قَبْلُ بِٱلْبَيِّنَٰتِ فَمَا زِلْتُمْ فِى شَكٍّ مِّمَّا جَآءَكُم بِهِۦ حَتَّىٰٓ إِذَا هَلَكَ قُلْتُمْ لَن يَبْعَثَ ٱللَّهُ مِنۢ بَعْدِهِۦ رَسُولًا كَذَٰلِكَ يُضِلُّ ٱللَّهُ مَنْ هُوَ مُسْرِفٌ مُّرْتَابٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmclxviii{ٱلَّذِينَ يُجَٰدِلُونَ فِىٓ ءَايَٰتِ ٱللَّهِ بِغَيْرِ سُلْطَٰنٍ أَتَىٰهُمْ كَبُرَ مَقْتًا عِندَ ٱللَّهِ وَعِندَ ٱلَّذِينَ ءَامَنُوا۟ كَذَٰلِكَ يَطْبَعُ ٱللَّهُ عَلَىٰ كُلِّ قَلْبِ مُتَكَبِّرٍ جَبَّارٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmclxix{وَقَالَ فِرْعَوْنُ يَٰهَٰمَٰنُ ٱبْنِ لِى صَرْحًا لَّعَلِّىٓ أَبْلُغُ ٱلْأَسْبَٰبَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmclxx{أَسْبَٰبَ ٱلسَّمَٰوَٰتِ فَأَطَّلِعَ إِلَىٰٓ إِلَٰهِ مُوسَىٰ وَإِنِّى لَأَظُنُّهُۥ كَٰذِبًا وَكَذَٰلِكَ زُيِّنَ لِفِرْعَوْنَ سُوٓءُ عَمَلِهِۦ وَصُدَّ عَنِ ٱلسَّبِيلِ وَمَا كَيْدُ فِرْعَوْنَ إِلَّا فِى تَبَابٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmclxxi{وَقَالَ ٱلَّذِىٓ ءَامَنَ يَٰقَوْمِ ٱتَّبِعُونِ أَهْدِكُمْ سَبِيلَ ٱلرَّشَادِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmclxxii{يَٰقَوْمِ إِنَّمَا هَٰذِهِ ٱلْحَيَوٰةُ ٱلدُّنْيَا مَتَٰعٌ وَإِنَّ ٱلْءَاخِرَةَ هِىَ دَارُ ٱلْقَرَارِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmclxxiii{مَنْ عَمِلَ سَيِّئَةً فَلَا يُجْزَىٰٓ إِلَّا مِثْلَهَا وَمَنْ عَمِلَ صَٰلِحًا مِّن ذَكَرٍ أَوْ أُنثَىٰ وَهُوَ مُؤْمِنٌ فَأُو۟لَٰٓئِكَ يَدْخُلُونَ ٱلْجَنَّةَ يُرْزَقُونَ فِيهَا بِغَيْرِ حِسَابٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmclxxiv{وَيَٰقَوْمِ مَا لِىٓ أَدْعُوكُمْ إِلَى ٱلنَّجَوٰةِ وَتَدْعُونَنِىٓ إِلَى ٱلنَّارِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmclxxv{تَدْعُونَنِى لِأَكْفُرَ بِٱللَّهِ وَأُشْرِكَ بِهِۦ مَا لَيْسَ لِى بِهِۦ عِلْمٌ وَأَنَا۠ أَدْعُوكُمْ إِلَى ٱلْعَزِيزِ ٱلْغَفَّٰرِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmclxxvi{لَا جَرَمَ أَنَّمَا تَدْعُونَنِىٓ إِلَيْهِ لَيْسَ لَهُۥ دَعْوَةٌ فِى ٱلدُّنْيَا وَلَا فِى ٱلْءَاخِرَةِ وَأَنَّ مَرَدَّنَآ إِلَى ٱللَّهِ وَأَنَّ ٱلْمُسْرِفِينَ هُمْ أَصْحَٰبُ ٱلنَّارِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmclxxvii{فَسَتَذْكُرُونَ مَآ أَقُولُ لَكُمْ وَأُفَوِّضُ أَمْرِىٓ إِلَى ٱللَّهِ إِنَّ ٱللَّهَ بَصِيرٌۢ بِٱلْعِبَادِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmclxxviii{فَوَقَىٰهُ ٱللَّهُ سَيِّـَٔاتِ مَا مَكَرُوا۟ وَحَاقَ بِـَٔالِ فِرْعَوْنَ سُوٓءُ ٱلْعَذَابِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmclxxix{ٱلنَّارُ يُعْرَضُونَ عَلَيْهَا غُدُوًّا وَعَشِيًّا وَيَوْمَ تَقُومُ ٱلسَّاعَةُ أَدْخِلُوٓا۟ ءَالَ فِرْعَوْنَ أَشَدَّ ٱلْعَذَابِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmclxxx{وَإِذْ يَتَحَآجُّونَ فِى ٱلنَّارِ فَيَقُولُ ٱلضُّعَفَٰٓؤُا۟ لِلَّذِينَ ٱسْتَكْبَرُوٓا۟ إِنَّا كُنَّا لَكُمْ تَبَعًا فَهَلْ أَنتُم مُّغْنُونَ عَنَّا نَصِيبًا مِّنَ ٱلنَّارِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmclxxxi{قَالَ ٱلَّذِينَ ٱسْتَكْبَرُوٓا۟ إِنَّا كُلٌّ فِيهَآ إِنَّ ٱللَّهَ قَدْ حَكَمَ بَيْنَ ٱلْعِبَادِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmclxxxii{وَقَالَ ٱلَّذِينَ فِى ٱلنَّارِ لِخَزَنَةِ جَهَنَّمَ ٱدْعُوا۟ رَبَّكُمْ يُخَفِّفْ عَنَّا يَوْمًا مِّنَ ٱلْعَذَابِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmclxxxiii{قَالُوٓا۟ أَوَلَمْ تَكُ تَأْتِيكُمْ رُسُلُكُم بِٱلْبَيِّنَٰتِ قَالُوا۟ بَلَىٰ قَالُوا۟ فَٱدْعُوا۟ وَمَا دُعَٰٓؤُا۟ ٱلْكَٰفِرِينَ إِلَّا فِى ضَلَٰلٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmclxxxiv{إِنَّا لَنَنصُرُ رُسُلَنَا وَٱلَّذِينَ ءَامَنُوا۟ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَيَوْمَ يَقُومُ ٱلْأَشْهَٰدُ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmclxxxv{يَوْمَ لَا يَنفَعُ ٱلظَّٰلِمِينَ مَعْذِرَتُهُمْ وَلَهُمُ ٱللَّعْنَةُ وَلَهُمْ سُوٓءُ ٱلدَّارِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmclxxxvi{وَلَقَدْ ءَاتَيْنَا مُوسَى ٱلْهُدَىٰ وَأَوْرَثْنَا بَنِىٓ إِسْرَٰٓءِيلَ ٱلْكِتَٰبَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmclxxxvii{هُدًى وَذِكْرَىٰ لِأُو۟لِى ٱلْأَلْبَٰبِ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmclxxxviii{فَٱصْبِرْ إِنَّ وَعْدَ ٱللَّهِ حَقٌّ وَٱسْتَغْفِرْ لِذَنۢبِكَ وَسَبِّحْ بِحَمْدِ رَبِّكَ بِٱلْعَشِىِّ وَٱلْإِبْكَٰرِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmclxxxix{إِنَّ ٱلَّذِينَ يُجَٰدِلُونَ فِىٓ ءَايَٰتِ ٱللَّهِ بِغَيْرِ سُلْطَٰنٍ أَتَىٰهُمْ إِن فِى صُدُورِهِمْ إِلَّا كِبْرٌ مَّا هُم بِبَٰلِغِيهِ فَٱسْتَعِذْ بِٱللَّهِ إِنَّهُۥ هُوَ ٱلسَّمِيعُ ٱلْبَصِيرُ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcxc{لَخَلْقُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ أَكْبَرُ مِنْ خَلْقِ ٱلنَّاسِ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcxci{وَمَا يَسْتَوِى ٱلْأَعْمَىٰ وَٱلْبَصِيرُ وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ وَلَا ٱلْمُسِىٓءُ قَلِيلًا مَّا تَتَذَكَّرُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcxcii{إِنَّ ٱلسَّاعَةَ لَءَاتِيَةٌ لَّا رَيْبَ فِيهَا وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يُؤْمِنُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcxciii{وَقَالَ رَبُّكُمُ ٱدْعُونِىٓ أَسْتَجِبْ لَكُمْ إِنَّ ٱلَّذِينَ يَسْتَكْبِرُونَ عَنْ عِبَادَتِى سَيَدْخُلُونَ جَهَنَّمَ دَاخِرِينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmcxciv{ٱللَّهُ ٱلَّذِى جَعَلَ لَكُمُ ٱلَّيْلَ لِتَسْكُنُوا۟ فِيهِ وَٱلنَّهَارَ مُبْصِرًا إِنَّ ٱللَّهَ لَذُو فَضْلٍ عَلَى ٱلنَّاسِ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَشْكُرُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmcxcv{ذَٰلِكُمُ ٱللَّهُ رَبُّكُمْ خَٰلِقُ كُلِّ شَىْءٍ لَّآ إِلَٰهَ إِلَّا هُوَ فَأَنَّىٰ تُؤْفَكُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmcxcvi{كَذَٰلِكَ يُؤْفَكُ ٱلَّذِينَ كَانُوا۟ بِـَٔايَٰتِ ٱللَّهِ يَجْحَدُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmcxcvii{ٱللَّهُ ٱلَّذِى جَعَلَ لَكُمُ ٱلْأَرْضَ قَرَارًا وَٱلسَّمَآءَ بِنَآءً وَصَوَّرَكُمْ فَأَحْسَنَ صُوَرَكُمْ وَرَزَقَكُم مِّنَ ٱلطَّيِّبَٰتِ ذَٰلِكُمُ ٱللَّهُ رَبُّكُمْ فَتَبَارَكَ ٱللَّهُ رَبُّ ٱلْعَٰلَمِينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcxcviii{هُوَ ٱلْحَىُّ لَآ إِلَٰهَ إِلَّا هُوَ فَٱدْعُوهُ مُخْلِصِينَ لَهُ ٱلدِّينَ ٱلْحَمْدُ لِلَّهِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcxcix{قُلْ إِنِّى نُهِيتُ أَنْ أَعْبُدَ ٱلَّذِينَ تَدْعُونَ مِن دُونِ ٱللَّهِ لَمَّا جَآءَنِىَ ٱلْبَيِّنَٰتُ مِن رَّبِّى وَأُمِرْتُ أَنْ أُسْلِمَ لِرَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcc{هُوَ ٱلَّذِى خَلَقَكُم مِّن تُرَابٍ ثُمَّ مِن نُّطْفَةٍ ثُمَّ مِنْ عَلَقَةٍ ثُمَّ يُخْرِجُكُمْ طِفْلًا ثُمَّ لِتَبْلُغُوٓا۟ أَشُدَّكُمْ ثُمَّ لِتَكُونُوا۟ شُيُوخًا وَمِنكُم مَّن يُتَوَفَّىٰ مِن قَبْلُ وَلِتَبْلُغُوٓا۟ أَجَلًا مُّسَمًّى وَلَعَلَّكُمْ تَعْقِلُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcci{هُوَ ٱلَّذِى يُحْىِۦ وَيُمِيتُ فَإِذَا قَضَىٰٓ أَمْرًا فَإِنَّمَا يَقُولُ لَهُۥ كُن فَيَكُونُ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmccii{أَلَمْ تَرَ إِلَى ٱلَّذِينَ يُجَٰدِلُونَ فِىٓ ءَايَٰتِ ٱللَّهِ أَنَّىٰ يُصْرَفُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcciii{ٱلَّذِينَ كَذَّبُوا۟ بِٱلْكِتَٰبِ وَبِمَآ أَرْسَلْنَا بِهِۦ رُسُلَنَا فَسَوْفَ يَعْلَمُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcciv{إِذِ ٱلْأَغْلَٰلُ فِىٓ أَعْنَٰقِهِمْ وَٱلسَّلَٰسِلُ يُسْحَبُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmccv{فِى ٱلْحَمِيمِ ثُمَّ فِى ٱلنَّارِ يُسْجَرُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmccvi{ثُمَّ قِيلَ لَهُمْ أَيْنَ مَا كُنتُمْ تُشْرِكُونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmccvii{مِن دُونِ ٱللَّهِ قَالُوا۟ ضَلُّوا۟ عَنَّا بَل لَّمْ نَكُن نَّدْعُوا۟ مِن قَبْلُ شَيْـًٔا كَذَٰلِكَ يُضِلُّ ٱللَّهُ ٱلْكَٰفِرِينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmccviii{ذَٰلِكُم بِمَا كُنتُمْ تَفْرَحُونَ فِى ٱلْأَرْضِ بِغَيْرِ ٱلْحَقِّ وَبِمَا كُنتُمْ تَمْرَحُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmccix{ٱدْخُلُوٓا۟ أَبْوَٰبَ جَهَنَّمَ خَٰلِدِينَ فِيهَا فَبِئْسَ مَثْوَى ٱلْمُتَكَبِّرِينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmccx{فَٱصْبِرْ إِنَّ وَعْدَ ٱللَّهِ حَقٌّ فَإِمَّا نُرِيَنَّكَ بَعْضَ ٱلَّذِى نَعِدُهُمْ أَوْ نَتَوَفَّيَنَّكَ فَإِلَيْنَا يُرْجَعُونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmccxi{وَلَقَدْ أَرْسَلْنَا رُسُلًا مِّن قَبْلِكَ مِنْهُم مَّن قَصَصْنَا عَلَيْكَ وَمِنْهُم مَّن لَّمْ نَقْصُصْ عَلَيْكَ وَمَا كَانَ لِرَسُولٍ أَن يَأْتِىَ بِـَٔايَةٍ إِلَّا بِإِذْنِ ٱللَّهِ فَإِذَا جَآءَ أَمْرُ ٱللَّهِ قُضِىَ بِٱلْحَقِّ وَخَسِرَ هُنَالِكَ ٱلْمُبْطِلُونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmccxii{ٱللَّهُ ٱلَّذِى جَعَلَ لَكُمُ ٱلْأَنْعَٰمَ لِتَرْكَبُوا۟ مِنْهَا وَمِنْهَا تَأْكُلُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmmccxiii{وَلَكُمْ فِيهَا مَنَٰفِعُ وَلِتَبْلُغُوا۟ عَلَيْهَا حَاجَةً فِى صُدُورِكُمْ وَعَلَيْهَا وَعَلَى ٱلْفُلْكِ تُحْمَلُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmccxiv{وَيُرِيكُمْ ءَايَٰتِهِۦ فَأَىَّ ءَايَٰتِ ٱللَّهِ تُنكِرُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmccxv{أَفَلَمْ يَسِيرُوا۟ فِى ٱلْأَرْضِ فَيَنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلَّذِينَ مِن قَبْلِهِمْ كَانُوٓا۟ أَكْثَرَ مِنْهُمْ وَأَشَدَّ قُوَّةً وَءَاثَارًا فِى ٱلْأَرْضِ فَمَآ أَغْنَىٰ عَنْهُم مَّا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmccxvi{فَلَمَّا جَآءَتْهُمْ رُسُلُهُم بِٱلْبَيِّنَٰتِ فَرِحُوا۟ بِمَا عِندَهُم مِّنَ ٱلْعِلْمِ وَحَاقَ بِهِم مَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmccxvii{فَلَمَّا رَأَوْا۟ بَأْسَنَا قَالُوٓا۟ ءَامَنَّا بِٱللَّهِ وَحْدَهُۥ وَكَفَرْنَا بِمَا كُنَّا بِهِۦ مُشْرِكِينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmccxviii{فَلَمْ يَكُ يَنفَعُهُمْ إِيمَٰنُهُمْ لَمَّا رَأَوْا۟ بَأْسَنَا سُنَّتَ ٱللَّهِ ٱلَّتِى قَدْ خَلَتْ فِى عِبَادِهِۦ وَخَسِرَ هُنَالِكَ ٱلْكَٰفِرُونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmccxix{\basmalah حمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmccxx{تَنزِيلٌ مِّنَ ٱلرَّحْمَٰنِ ٱلرَّحِيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmccxxi{كِتَٰبٌ فُصِّلَتْ ءَايَٰتُهُۥ قُرْءَانًا عَرَبِيًّا لِّقَوْمٍ يَعْلَمُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmccxxii{بَشِيرًا وَنَذِيرًا فَأَعْرَضَ أَكْثَرُهُمْ فَهُمْ لَا يَسْمَعُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmccxxiii{وَقَالُوا۟ قُلُوبُنَا فِىٓ أَكِنَّةٍ مِّمَّا تَدْعُونَآ إِلَيْهِ وَفِىٓ ءَاذَانِنَا وَقْرٌ وَمِنۢ بَيْنِنَا وَبَيْنِكَ حِجَابٌ فَٱعْمَلْ إِنَّنَا عَٰمِلُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmccxxiv{قُلْ إِنَّمَآ أَنَا۠ بَشَرٌ مِّثْلُكُمْ يُوحَىٰٓ إِلَىَّ أَنَّمَآ إِلَٰهُكُمْ إِلَٰهٌ وَٰحِدٌ فَٱسْتَقِيمُوٓا۟ إِلَيْهِ وَٱسْتَغْفِرُوهُ وَوَيْلٌ لِّلْمُشْرِكِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmccxxv{ٱلَّذِينَ لَا يُؤْتُونَ ٱلزَّكَوٰةَ وَهُم بِٱلْءَاخِرَةِ هُمْ كَٰفِرُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmccxxvi{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَهُمْ أَجْرٌ غَيْرُ مَمْنُونٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmccxxvii{قُلْ أَئِنَّكُمْ لَتَكْفُرُونَ بِٱلَّذِى خَلَقَ ٱلْأَرْضَ فِى يَوْمَيْنِ وَتَجْعَلُونَ لَهُۥٓ أَندَادًا ذَٰلِكَ رَبُّ ٱلْعَٰلَمِينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmccxxviii{وَجَعَلَ فِيهَا رَوَٰسِىَ مِن فَوْقِهَا وَبَٰرَكَ فِيهَا وَقَدَّرَ فِيهَآ أَقْوَٰتَهَا فِىٓ أَرْبَعَةِ أَيَّامٍ سَوَآءً لِّلسَّآئِلِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmccxxix{ثُمَّ ٱسْتَوَىٰٓ إِلَى ٱلسَّمَآءِ وَهِىَ دُخَانٌ فَقَالَ لَهَا وَلِلْأَرْضِ ٱئْتِيَا طَوْعًا أَوْ كَرْهًا قَالَتَآ أَتَيْنَا طَآئِعِينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmccxxx{فَقَضَىٰهُنَّ سَبْعَ سَمَٰوَاتٍ فِى يَوْمَيْنِ وَأَوْحَىٰ فِى كُلِّ سَمَآءٍ أَمْرَهَا وَزَيَّنَّا ٱلسَّمَآءَ ٱلدُّنْيَا بِمَصَٰبِيحَ وَحِفْظًا ذَٰلِكَ تَقْدِيرُ ٱلْعَزِيزِ ٱلْعَلِيمِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmccxxxi{فَإِنْ أَعْرَضُوا۟ فَقُلْ أَنذَرْتُكُمْ صَٰعِقَةً مِّثْلَ صَٰعِقَةِ عَادٍ وَثَمُودَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmccxxxii{إِذْ جَآءَتْهُمُ ٱلرُّسُلُ مِنۢ بَيْنِ أَيْدِيهِمْ وَمِنْ خَلْفِهِمْ أَلَّا تَعْبُدُوٓا۟ إِلَّا ٱللَّهَ قَالُوا۟ لَوْ شَآءَ رَبُّنَا لَأَنزَلَ مَلَٰٓئِكَةً فَإِنَّا بِمَآ أُرْسِلْتُم بِهِۦ كَٰفِرُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmccxxxiii{فَأَمَّا عَادٌ فَٱسْتَكْبَرُوا۟ فِى ٱلْأَرْضِ بِغَيْرِ ٱلْحَقِّ وَقَالُوا۟ مَنْ أَشَدُّ مِنَّا قُوَّةً أَوَلَمْ يَرَوْا۟ أَنَّ ٱللَّهَ ٱلَّذِى خَلَقَهُمْ هُوَ أَشَدُّ مِنْهُمْ قُوَّةً وَكَانُوا۟ بِـَٔايَٰتِنَا يَجْحَدُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmccxxxiv{فَأَرْسَلْنَا عَلَيْهِمْ رِيحًا صَرْصَرًا فِىٓ أَيَّامٍ نَّحِسَاتٍ لِّنُذِيقَهُمْ عَذَابَ ٱلْخِزْىِ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَلَعَذَابُ ٱلْءَاخِرَةِ أَخْزَىٰ وَهُمْ لَا يُنصَرُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmccxxxv{وَأَمَّا ثَمُودُ فَهَدَيْنَٰهُمْ فَٱسْتَحَبُّوا۟ ٱلْعَمَىٰ عَلَى ٱلْهُدَىٰ فَأَخَذَتْهُمْ صَٰعِقَةُ ٱلْعَذَابِ ٱلْهُونِ بِمَا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmccxxxvi{وَنَجَّيْنَا ٱلَّذِينَ ءَامَنُوا۟ وَكَانُوا۟ يَتَّقُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmccxxxvii{وَيَوْمَ يُحْشَرُ أَعْدَآءُ ٱللَّهِ إِلَى ٱلنَّارِ فَهُمْ يُوزَعُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmccxxxviii{حَتَّىٰٓ إِذَا مَا جَآءُوهَا شَهِدَ عَلَيْهِمْ سَمْعُهُمْ وَأَبْصَٰرُهُمْ وَجُلُودُهُم بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmccxxxix{وَقَالُوا۟ لِجُلُودِهِمْ لِمَ شَهِدتُّمْ عَلَيْنَا قَالُوٓا۟ أَنطَقَنَا ٱللَّهُ ٱلَّذِىٓ أَنطَقَ كُلَّ شَىْءٍ وَهُوَ خَلَقَكُمْ أَوَّلَ مَرَّةٍ وَإِلَيْهِ تُرْجَعُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmccxl{وَمَا كُنتُمْ تَسْتَتِرُونَ أَن يَشْهَدَ عَلَيْكُمْ سَمْعُكُمْ وَلَآ أَبْصَٰرُكُمْ وَلَا جُلُودُكُمْ وَلَٰكِن ظَنَنتُمْ أَنَّ ٱللَّهَ لَا يَعْلَمُ كَثِيرًا مِّمَّا تَعْمَلُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmccxli{وَذَٰلِكُمْ ظَنُّكُمُ ٱلَّذِى ظَنَنتُم بِرَبِّكُمْ أَرْدَىٰكُمْ فَأَصْبَحْتُم مِّنَ ٱلْخَٰسِرِينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmccxlii{فَإِن يَصْبِرُوا۟ فَٱلنَّارُ مَثْوًى لَّهُمْ وَإِن يَسْتَعْتِبُوا۟ فَمَا هُم مِّنَ ٱلْمُعْتَبِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmccxliii{وَقَيَّضْنَا لَهُمْ قُرَنَآءَ فَزَيَّنُوا۟ لَهُم مَّا بَيْنَ أَيْدِيهِمْ وَمَا خَلْفَهُمْ وَحَقَّ عَلَيْهِمُ ٱلْقَوْلُ فِىٓ أُمَمٍ قَدْ خَلَتْ مِن قَبْلِهِم مِّنَ ٱلْجِنِّ وَٱلْإِنسِ إِنَّهُمْ كَانُوا۟ خَٰسِرِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmccxliv{وَقَالَ ٱلَّذِينَ كَفَرُوا۟ لَا تَسْمَعُوا۟ لِهَٰذَا ٱلْقُرْءَانِ وَٱلْغَوْا۟ فِيهِ لَعَلَّكُمْ تَغْلِبُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmccxlv{فَلَنُذِيقَنَّ ٱلَّذِينَ كَفَرُوا۟ عَذَابًا شَدِيدًا وَلَنَجْزِيَنَّهُمْ أَسْوَأَ ٱلَّذِى كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmccxlvi{ذَٰلِكَ جَزَآءُ أَعْدَآءِ ٱللَّهِ ٱلنَّارُ لَهُمْ فِيهَا دَارُ ٱلْخُلْدِ جَزَآءًۢ بِمَا كَانُوا۟ بِـَٔايَٰتِنَا يَجْحَدُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmccxlvii{وَقَالَ ٱلَّذِينَ كَفَرُوا۟ رَبَّنَآ أَرِنَا ٱلَّذَيْنِ أَضَلَّانَا مِنَ ٱلْجِنِّ وَٱلْإِنسِ نَجْعَلْهُمَا تَحْتَ أَقْدَامِنَا لِيَكُونَا مِنَ ٱلْأَسْفَلِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmccxlviii{إِنَّ ٱلَّذِينَ قَالُوا۟ رَبُّنَا ٱللَّهُ ثُمَّ ٱسْتَقَٰمُوا۟ تَتَنَزَّلُ عَلَيْهِمُ ٱلْمَلَٰٓئِكَةُ أَلَّا تَخَافُوا۟ وَلَا تَحْزَنُوا۟ وَأَبْشِرُوا۟ بِٱلْجَنَّةِ ٱلَّتِى كُنتُمْ تُوعَدُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmccxlix{نَحْنُ أَوْلِيَآؤُكُمْ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَفِى ٱلْءَاخِرَةِ وَلَكُمْ فِيهَا مَا تَشْتَهِىٓ أَنفُسُكُمْ وَلَكُمْ فِيهَا مَا تَدَّعُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmccl{نُزُلًا مِّنْ غَفُورٍ رَّحِيمٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmccli{وَمَنْ أَحْسَنُ قَوْلًا مِّمَّن دَعَآ إِلَى ٱللَّهِ وَعَمِلَ صَٰلِحًا وَقَالَ إِنَّنِى مِنَ ٱلْمُسْلِمِينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcclii{وَلَا تَسْتَوِى ٱلْحَسَنَةُ وَلَا ٱلسَّيِّئَةُ ٱدْفَعْ بِٱلَّتِى هِىَ أَحْسَنُ فَإِذَا ٱلَّذِى بَيْنَكَ وَبَيْنَهُۥ عَدَٰوَةٌ كَأَنَّهُۥ وَلِىٌّ حَمِيمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmccliii{وَمَا يُلَقَّىٰهَآ إِلَّا ٱلَّذِينَ صَبَرُوا۟ وَمَا يُلَقَّىٰهَآ إِلَّا ذُو حَظٍّ عَظِيمٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmccliv{وَإِمَّا يَنزَغَنَّكَ مِنَ ٱلشَّيْطَٰنِ نَزْغٌ فَٱسْتَعِذْ بِٱللَّهِ إِنَّهُۥ هُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcclv{وَمِنْ ءَايَٰتِهِ ٱلَّيْلُ وَٱلنَّهَارُ وَٱلشَّمْسُ وَٱلْقَمَرُ لَا تَسْجُدُوا۟ لِلشَّمْسِ وَلَا لِلْقَمَرِ وَٱسْجُدُوا۟ لِلَّهِ ٱلَّذِى خَلَقَهُنَّ إِن كُنتُمْ إِيَّاهُ تَعْبُدُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcclvi{فَإِنِ ٱسْتَكْبَرُوا۟ فَٱلَّذِينَ عِندَ رَبِّكَ يُسَبِّحُونَ لَهُۥ بِٱلَّيْلِ وَٱلنَّهَارِ وَهُمْ لَا يَسْـَٔمُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcclvii{وَمِنْ ءَايَٰتِهِۦٓ أَنَّكَ تَرَى ٱلْأَرْضَ خَٰشِعَةً فَإِذَآ أَنزَلْنَا عَلَيْهَا ٱلْمَآءَ ٱهْتَزَّتْ وَرَبَتْ إِنَّ ٱلَّذِىٓ أَحْيَاهَا لَمُحْىِ ٱلْمَوْتَىٰٓ إِنَّهُۥ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcclviii{إِنَّ ٱلَّذِينَ يُلْحِدُونَ فِىٓ ءَايَٰتِنَا لَا يَخْفَوْنَ عَلَيْنَآ أَفَمَن يُلْقَىٰ فِى ٱلنَّارِ خَيْرٌ أَم مَّن يَأْتِىٓ ءَامِنًا يَوْمَ ٱلْقِيَٰمَةِ ٱعْمَلُوا۟ مَا شِئْتُمْ إِنَّهُۥ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcclix{إِنَّ ٱلَّذِينَ كَفَرُوا۟ بِٱلذِّكْرِ لَمَّا جَآءَهُمْ وَإِنَّهُۥ لَكِتَٰبٌ عَزِيزٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcclx{لَّا يَأْتِيهِ ٱلْبَٰطِلُ مِنۢ بَيْنِ يَدَيْهِ وَلَا مِنْ خَلْفِهِۦ تَنزِيلٌ مِّنْ حَكِيمٍ حَمِيدٍ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcclxi{مَّا يُقَالُ لَكَ إِلَّا مَا قَدْ قِيلَ لِلرُّسُلِ مِن قَبْلِكَ إِنَّ رَبَّكَ لَذُو مَغْفِرَةٍ وَذُو عِقَابٍ أَلِيمٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcclxii{وَلَوْ جَعَلْنَٰهُ قُرْءَانًا أَعْجَمِيًّا لَّقَالُوا۟ لَوْلَا فُصِّلَتْ ءَايَٰتُهُۥٓ ءَا۬عْجَمِىٌّ وَعَرَبِىٌّ قُلْ هُوَ لِلَّذِينَ ءَامَنُوا۟ هُدًى وَشِفَآءٌ وَٱلَّذِينَ لَا يُؤْمِنُونَ فِىٓ ءَاذَانِهِمْ وَقْرٌ وَهُوَ عَلَيْهِمْ عَمًى أُو۟لَٰٓئِكَ يُنَادَوْنَ مِن مَّكَانٍۭ بَعِيدٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcclxiii{وَلَقَدْ ءَاتَيْنَا مُوسَى ٱلْكِتَٰبَ فَٱخْتُلِفَ فِيهِ وَلَوْلَا كَلِمَةٌ سَبَقَتْ مِن رَّبِّكَ لَقُضِىَ بَيْنَهُمْ وَإِنَّهُمْ لَفِى شَكٍّ مِّنْهُ مُرِيبٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcclxiv{مَّنْ عَمِلَ صَٰلِحًا فَلِنَفْسِهِۦ وَمَنْ أَسَآءَ فَعَلَيْهَا وَمَا رَبُّكَ بِظَلَّٰمٍ لِّلْعَبِيدِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcclxv{إِلَيْهِ يُرَدُّ عِلْمُ ٱلسَّاعَةِ وَمَا تَخْرُجُ مِن ثَمَرَٰتٍ مِّنْ أَكْمَامِهَا وَمَا تَحْمِلُ مِنْ أُنثَىٰ وَلَا تَضَعُ إِلَّا بِعِلْمِهِۦ وَيَوْمَ يُنَادِيهِمْ أَيْنَ شُرَكَآءِى قَالُوٓا۟ ءَاذَنَّٰكَ مَا مِنَّا مِن شَهِيدٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcclxvi{وَضَلَّ عَنْهُم مَّا كَانُوا۟ يَدْعُونَ مِن قَبْلُ وَظَنُّوا۟ مَا لَهُم مِّن مَّحِيصٍ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcclxvii{لَّا يَسْـَٔمُ ٱلْإِنسَٰنُ مِن دُعَآءِ ٱلْخَيْرِ وَإِن مَّسَّهُ ٱلشَّرُّ فَيَـُٔوسٌ قَنُوطٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcclxviii{وَلَئِنْ أَذَقْنَٰهُ رَحْمَةً مِّنَّا مِنۢ بَعْدِ ضَرَّآءَ مَسَّتْهُ لَيَقُولَنَّ هَٰذَا لِى وَمَآ أَظُنُّ ٱلسَّاعَةَ قَآئِمَةً وَلَئِن رُّجِعْتُ إِلَىٰ رَبِّىٓ إِنَّ لِى عِندَهُۥ لَلْحُسْنَىٰ فَلَنُنَبِّئَنَّ ٱلَّذِينَ كَفَرُوا۟ بِمَا عَمِلُوا۟ وَلَنُذِيقَنَّهُم مِّنْ عَذَابٍ غَلِيظٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcclxix{وَإِذَآ أَنْعَمْنَا عَلَى ٱلْإِنسَٰنِ أَعْرَضَ وَنَـَٔا بِجَانِبِهِۦ وَإِذَا مَسَّهُ ٱلشَّرُّ فَذُو دُعَآءٍ عَرِيضٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcclxx{قُلْ أَرَءَيْتُمْ إِن كَانَ مِنْ عِندِ ٱللَّهِ ثُمَّ كَفَرْتُم بِهِۦ مَنْ أَضَلُّ مِمَّنْ هُوَ فِى شِقَاقٍۭ بَعِيدٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcclxxi{سَنُرِيهِمْ ءَايَٰتِنَا فِى ٱلْءَافَاقِ وَفِىٓ أَنفُسِهِمْ حَتَّىٰ يَتَبَيَّنَ لَهُمْ أَنَّهُ ٱلْحَقُّ أَوَلَمْ يَكْفِ بِرَبِّكَ أَنَّهُۥ عَلَىٰ كُلِّ شَىْءٍ شَهِيدٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcclxxii{أَلَآ إِنَّهُمْ فِى مِرْيَةٍ مِّن لِّقَآءِ رَبِّهِمْ أَلَآ إِنَّهُۥ بِكُلِّ شَىْءٍ مُّحِيطٌۢ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcclxxiii{\basmalah حمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcclxxiv{عٓسٓقٓ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcclxxv{كَذَٰلِكَ يُوحِىٓ إِلَيْكَ وَإِلَى ٱلَّذِينَ مِن قَبْلِكَ ٱللَّهُ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcclxxvi{لَهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَهُوَ ٱلْعَلِىُّ ٱلْعَظِيمُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcclxxvii{تَكَادُ ٱلسَّمَٰوَٰتُ يَتَفَطَّرْنَ مِن فَوْقِهِنَّ وَٱلْمَلَٰٓئِكَةُ يُسَبِّحُونَ بِحَمْدِ رَبِّهِمْ وَيَسْتَغْفِرُونَ لِمَن فِى ٱلْأَرْضِ أَلَآ إِنَّ ٱللَّهَ هُوَ ٱلْغَفُورُ ٱلرَّحِيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcclxxviii{وَٱلَّذِينَ ٱتَّخَذُوا۟ مِن دُونِهِۦٓ أَوْلِيَآءَ ٱللَّهُ حَفِيظٌ عَلَيْهِمْ وَمَآ أَنتَ عَلَيْهِم بِوَكِيلٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcclxxix{وَكَذَٰلِكَ أَوْحَيْنَآ إِلَيْكَ قُرْءَانًا عَرَبِيًّا لِّتُنذِرَ أُمَّ ٱلْقُرَىٰ وَمَنْ حَوْلَهَا وَتُنذِرَ يَوْمَ ٱلْجَمْعِ لَا رَيْبَ فِيهِ فَرِيقٌ فِى ٱلْجَنَّةِ وَفَرِيقٌ فِى ٱلسَّعِيرِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcclxxx{وَلَوْ شَآءَ ٱللَّهُ لَجَعَلَهُمْ أُمَّةً وَٰحِدَةً وَلَٰكِن يُدْخِلُ مَن يَشَآءُ فِى رَحْمَتِهِۦ وَٱلظَّٰلِمُونَ مَا لَهُم مِّن وَلِىٍّ وَلَا نَصِيرٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcclxxxi{أَمِ ٱتَّخَذُوا۟ مِن دُونِهِۦٓ أَوْلِيَآءَ فَٱللَّهُ هُوَ ٱلْوَلِىُّ وَهُوَ يُحْىِ ٱلْمَوْتَىٰ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcclxxxii{وَمَا ٱخْتَلَفْتُمْ فِيهِ مِن شَىْءٍ فَحُكْمُهُۥٓ إِلَى ٱللَّهِ ذَٰلِكُمُ ٱللَّهُ رَبِّى عَلَيْهِ تَوَكَّلْتُ وَإِلَيْهِ أُنِيبُ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcclxxxiii{فَاطِرُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ جَعَلَ لَكُم مِّنْ أَنفُسِكُمْ أَزْوَٰجًا وَمِنَ ٱلْأَنْعَٰمِ أَزْوَٰجًا يَذْرَؤُكُمْ فِيهِ لَيْسَ كَمِثْلِهِۦ شَىْءٌ وَهُوَ ٱلسَّمِيعُ ٱلْبَصِيرُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcclxxxiv{لَهُۥ مَقَالِيدُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ يَبْسُطُ ٱلرِّزْقَ لِمَن يَشَآءُ وَيَقْدِرُ إِنَّهُۥ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcclxxxv{شَرَعَ لَكُم مِّنَ ٱلدِّينِ مَا وَصَّىٰ بِهِۦ نُوحًا وَٱلَّذِىٓ أَوْحَيْنَآ إِلَيْكَ وَمَا وَصَّيْنَا بِهِۦٓ إِبْرَٰهِيمَ وَمُوسَىٰ وَعِيسَىٰٓ أَنْ أَقِيمُوا۟ ٱلدِّينَ وَلَا تَتَفَرَّقُوا۟ فِيهِ كَبُرَ عَلَى ٱلْمُشْرِكِينَ مَا تَدْعُوهُمْ إِلَيْهِ ٱللَّهُ يَجْتَبِىٓ إِلَيْهِ مَن يَشَآءُ وَيَهْدِىٓ إِلَيْهِ مَن يُنِيبُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcclxxxvi{وَمَا تَفَرَّقُوٓا۟ إِلَّا مِنۢ بَعْدِ مَا جَآءَهُمُ ٱلْعِلْمُ بَغْيًۢا بَيْنَهُمْ وَلَوْلَا كَلِمَةٌ سَبَقَتْ مِن رَّبِّكَ إِلَىٰٓ أَجَلٍ مُّسَمًّى لَّقُضِىَ بَيْنَهُمْ وَإِنَّ ٱلَّذِينَ أُورِثُوا۟ ٱلْكِتَٰبَ مِنۢ بَعْدِهِمْ لَفِى شَكٍّ مِّنْهُ مُرِيبٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcclxxxvii{فَلِذَٰلِكَ فَٱدْعُ وَٱسْتَقِمْ كَمَآ أُمِرْتَ وَلَا تَتَّبِعْ أَهْوَآءَهُمْ وَقُلْ ءَامَنتُ بِمَآ أَنزَلَ ٱللَّهُ مِن كِتَٰبٍ وَأُمِرْتُ لِأَعْدِلَ بَيْنَكُمُ ٱللَّهُ رَبُّنَا وَرَبُّكُمْ لَنَآ أَعْمَٰلُنَا وَلَكُمْ أَعْمَٰلُكُمْ لَا حُجَّةَ بَيْنَنَا وَبَيْنَكُمُ ٱللَّهُ يَجْمَعُ بَيْنَنَا وَإِلَيْهِ ٱلْمَصِيرُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcclxxxviii{وَٱلَّذِينَ يُحَآجُّونَ فِى ٱللَّهِ مِنۢ بَعْدِ مَا ٱسْتُجِيبَ لَهُۥ حُجَّتُهُمْ دَاحِضَةٌ عِندَ رَبِّهِمْ وَعَلَيْهِمْ غَضَبٌ وَلَهُمْ عَذَابٌ شَدِيدٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcclxxxix{ٱللَّهُ ٱلَّذِىٓ أَنزَلَ ٱلْكِتَٰبَ بِٱلْحَقِّ وَٱلْمِيزَانَ وَمَا يُدْرِيكَ لَعَلَّ ٱلسَّاعَةَ قَرِيبٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmccxc{يَسْتَعْجِلُ بِهَا ٱلَّذِينَ لَا يُؤْمِنُونَ بِهَا وَٱلَّذِينَ ءَامَنُوا۟ مُشْفِقُونَ مِنْهَا وَيَعْلَمُونَ أَنَّهَا ٱلْحَقُّ أَلَآ إِنَّ ٱلَّذِينَ يُمَارُونَ فِى ٱلسَّاعَةِ لَفِى ضَلَٰلٍۭ بَعِيدٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmccxci{ٱللَّهُ لَطِيفٌۢ بِعِبَادِهِۦ يَرْزُقُ مَن يَشَآءُ وَهُوَ ٱلْقَوِىُّ ٱلْعَزِيزُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmccxcii{مَن كَانَ يُرِيدُ حَرْثَ ٱلْءَاخِرَةِ نَزِدْ لَهُۥ فِى حَرْثِهِۦ وَمَن كَانَ يُرِيدُ حَرْثَ ٱلدُّنْيَا نُؤْتِهِۦ مِنْهَا وَمَا لَهُۥ فِى ٱلْءَاخِرَةِ مِن نَّصِيبٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmccxciii{أَمْ لَهُمْ شُرَكَٰٓؤُا۟ شَرَعُوا۟ لَهُم مِّنَ ٱلدِّينِ مَا لَمْ يَأْذَنۢ بِهِ ٱللَّهُ وَلَوْلَا كَلِمَةُ ٱلْفَصْلِ لَقُضِىَ بَيْنَهُمْ وَإِنَّ ٱلظَّٰلِمِينَ لَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmccxciv{تَرَى ٱلظَّٰلِمِينَ مُشْفِقِينَ مِمَّا كَسَبُوا۟ وَهُوَ وَاقِعٌۢ بِهِمْ وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ فِى رَوْضَاتِ ٱلْجَنَّاتِ لَهُم مَّا يَشَآءُونَ عِندَ رَبِّهِمْ ذَٰلِكَ هُوَ ٱلْفَضْلُ ٱلْكَبِيرُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmccxcv{ذَٰلِكَ ٱلَّذِى يُبَشِّرُ ٱللَّهُ عِبَادَهُ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ قُل لَّآ أَسْـَٔلُكُمْ عَلَيْهِ أَجْرًا إِلَّا ٱلْمَوَدَّةَ فِى ٱلْقُرْبَىٰ وَمَن يَقْتَرِفْ حَسَنَةً نَّزِدْ لَهُۥ فِيهَا حُسْنًا إِنَّ ٱللَّهَ غَفُورٌ شَكُورٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmccxcvi{أَمْ يَقُولُونَ ٱفْتَرَىٰ عَلَى ٱللَّهِ كَذِبًا فَإِن يَشَإِ ٱللَّهُ يَخْتِمْ عَلَىٰ قَلْبِكَ وَيَمْحُ ٱللَّهُ ٱلْبَٰطِلَ وَيُحِقُّ ٱلْحَقَّ بِكَلِمَٰتِهِۦٓ إِنَّهُۥ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmccxcvii{وَهُوَ ٱلَّذِى يَقْبَلُ ٱلتَّوْبَةَ عَنْ عِبَادِهِۦ وَيَعْفُوا۟ عَنِ ٱلسَّيِّـَٔاتِ وَيَعْلَمُ مَا تَفْعَلُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmccxcviii{وَيَسْتَجِيبُ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ وَيَزِيدُهُم مِّن فَضْلِهِۦ وَٱلْكَٰفِرُونَ لَهُمْ عَذَابٌ شَدِيدٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmccxcix{وَلَوْ بَسَطَ ٱللَّهُ ٱلرِّزْقَ لِعِبَادِهِۦ لَبَغَوْا۟ فِى ٱلْأَرْضِ وَلَٰكِن يُنَزِّلُ بِقَدَرٍ مَّا يَشَآءُ إِنَّهُۥ بِعِبَادِهِۦ خَبِيرٌۢ بَصِيرٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmccc{وَهُوَ ٱلَّذِى يُنَزِّلُ ٱلْغَيْثَ مِنۢ بَعْدِ مَا قَنَطُوا۟ وَيَنشُرُ رَحْمَتَهُۥ وَهُوَ ٱلْوَلِىُّ ٱلْحَمِيدُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmccci{وَمِنْ ءَايَٰتِهِۦ خَلْقُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَثَّ فِيهِمَا مِن دَآبَّةٍ وَهُوَ عَلَىٰ جَمْعِهِمْ إِذَا يَشَآءُ قَدِيرٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmcccii{وَمَآ أَصَٰبَكُم مِّن مُّصِيبَةٍ فَبِمَا كَسَبَتْ أَيْدِيكُمْ وَيَعْفُوا۟ عَن كَثِيرٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmccciii{وَمَآ أَنتُم بِمُعْجِزِينَ فِى ٱلْأَرْضِ وَمَا لَكُم مِّن دُونِ ٱللَّهِ مِن وَلِىٍّ وَلَا نَصِيرٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmccciv{وَمِنْ ءَايَٰتِهِ ٱلْجَوَارِ فِى ٱلْبَحْرِ كَٱلْأَعْلَٰمِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmcccv{إِن يَشَأْ يُسْكِنِ ٱلرِّيحَ فَيَظْلَلْنَ رَوَاكِدَ عَلَىٰ ظَهْرِهِۦٓ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّكُلِّ صَبَّارٍ شَكُورٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcccvi{أَوْ يُوبِقْهُنَّ بِمَا كَسَبُوا۟ وَيَعْفُ عَن كَثِيرٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmcccvii{وَيَعْلَمَ ٱلَّذِينَ يُجَٰدِلُونَ فِىٓ ءَايَٰتِنَا مَا لَهُم مِّن مَّحِيصٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmcccviii{فَمَآ أُوتِيتُم مِّن شَىْءٍ فَمَتَٰعُ ٱلْحَيَوٰةِ ٱلدُّنْيَا وَمَا عِندَ ٱللَّهِ خَيْرٌ وَأَبْقَىٰ لِلَّذِينَ ءَامَنُوا۟ وَعَلَىٰ رَبِّهِمْ يَتَوَكَّلُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcccix{وَٱلَّذِينَ يَجْتَنِبُونَ كَبَٰٓئِرَ ٱلْإِثْمِ وَٱلْفَوَٰحِشَ وَإِذَا مَا غَضِبُوا۟ هُمْ يَغْفِرُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcccx{وَٱلَّذِينَ ٱسْتَجَابُوا۟ لِرَبِّهِمْ وَأَقَامُوا۟ ٱلصَّلَوٰةَ وَأَمْرُهُمْ شُورَىٰ بَيْنَهُمْ وَمِمَّا رَزَقْنَٰهُمْ يُنفِقُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcccxi{وَٱلَّذِينَ إِذَآ أَصَابَهُمُ ٱلْبَغْىُ هُمْ يَنتَصِرُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcccxii{وَجَزَٰٓؤُا۟ سَيِّئَةٍ سَيِّئَةٌ مِّثْلُهَا فَمَنْ عَفَا وَأَصْلَحَ فَأَجْرُهُۥ عَلَى ٱللَّهِ إِنَّهُۥ لَا يُحِبُّ ٱلظَّٰلِمِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcccxiii{وَلَمَنِ ٱنتَصَرَ بَعْدَ ظُلْمِهِۦ فَأُو۟لَٰٓئِكَ مَا عَلَيْهِم مِّن سَبِيلٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcccxiv{إِنَّمَا ٱلسَّبِيلُ عَلَى ٱلَّذِينَ يَظْلِمُونَ ٱلنَّاسَ وَيَبْغُونَ فِى ٱلْأَرْضِ بِغَيْرِ ٱلْحَقِّ أُو۟لَٰٓئِكَ لَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcccxv{وَلَمَن صَبَرَ وَغَفَرَ إِنَّ ذَٰلِكَ لَمِنْ عَزْمِ ٱلْأُمُورِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcccxvi{وَمَن يُضْلِلِ ٱللَّهُ فَمَا لَهُۥ مِن وَلِىٍّ مِّنۢ بَعْدِهِۦ وَتَرَى ٱلظَّٰلِمِينَ لَمَّا رَأَوُا۟ ٱلْعَذَابَ يَقُولُونَ هَلْ إِلَىٰ مَرَدٍّ مِّن سَبِيلٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcccxvii{وَتَرَىٰهُمْ يُعْرَضُونَ عَلَيْهَا خَٰشِعِينَ مِنَ ٱلذُّلِّ يَنظُرُونَ مِن طَرْفٍ خَفِىٍّ وَقَالَ ٱلَّذِينَ ءَامَنُوٓا۟ إِنَّ ٱلْخَٰسِرِينَ ٱلَّذِينَ خَسِرُوٓا۟ أَنفُسَهُمْ وَأَهْلِيهِمْ يَوْمَ ٱلْقِيَٰمَةِ أَلَآ إِنَّ ٱلظَّٰلِمِينَ فِى عَذَابٍ مُّقِيمٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcccxviii{وَمَا كَانَ لَهُم مِّنْ أَوْلِيَآءَ يَنصُرُونَهُم مِّن دُونِ ٱللَّهِ وَمَن يُضْلِلِ ٱللَّهُ فَمَا لَهُۥ مِن سَبِيلٍ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcccxix{ٱسْتَجِيبُوا۟ لِرَبِّكُم مِّن قَبْلِ أَن يَأْتِىَ يَوْمٌ لَّا مَرَدَّ لَهُۥ مِنَ ٱللَّهِ مَا لَكُم مِّن مَّلْجَإٍ يَوْمَئِذٍ وَمَا لَكُم مِّن نَّكِيرٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcccxx{فَإِنْ أَعْرَضُوا۟ فَمَآ أَرْسَلْنَٰكَ عَلَيْهِمْ حَفِيظًا إِنْ عَلَيْكَ إِلَّا ٱلْبَلَٰغُ وَإِنَّآ إِذَآ أَذَقْنَا ٱلْإِنسَٰنَ مِنَّا رَحْمَةً فَرِحَ بِهَا وَإِن تُصِبْهُمْ سَيِّئَةٌۢ بِمَا قَدَّمَتْ أَيْدِيهِمْ فَإِنَّ ٱلْإِنسَٰنَ كَفُورٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcccxxi{لِّلَّهِ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ يَخْلُقُ مَا يَشَآءُ يَهَبُ لِمَن يَشَآءُ إِنَٰثًا وَيَهَبُ لِمَن يَشَآءُ ٱلذُّكُورَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcccxxii{أَوْ يُزَوِّجُهُمْ ذُكْرَانًا وَإِنَٰثًا وَيَجْعَلُ مَن يَشَآءُ عَقِيمًا إِنَّهُۥ عَلِيمٌ قَدِيرٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcccxxiii{وَمَا كَانَ لِبَشَرٍ أَن يُكَلِّمَهُ ٱللَّهُ إِلَّا وَحْيًا أَوْ مِن وَرَآئِ حِجَابٍ أَوْ يُرْسِلَ رَسُولًا فَيُوحِىَ بِإِذْنِهِۦ مَا يَشَآءُ إِنَّهُۥ عَلِىٌّ حَكِيمٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcccxxiv{وَكَذَٰلِكَ أَوْحَيْنَآ إِلَيْكَ رُوحًا مِّنْ أَمْرِنَا مَا كُنتَ تَدْرِى مَا ٱلْكِتَٰبُ وَلَا ٱلْإِيمَٰنُ وَلَٰكِن جَعَلْنَٰهُ نُورًا نَّهْدِى بِهِۦ مَن نَّشَآءُ مِنْ عِبَادِنَا وَإِنَّكَ لَتَهْدِىٓ إِلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcccxxv{صِرَٰطِ ٱللَّهِ ٱلَّذِى لَهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ أَلَآ إِلَى ٱللَّهِ تَصِيرُ ٱلْأُمُورُ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcccxxvi{\basmalah حمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcccxxvii{وَٱلْكِتَٰبِ ٱلْمُبِينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcccxxviii{إِنَّا جَعَلْنَٰهُ قُرْءَٰنًا عَرَبِيًّا لَّعَلَّكُمْ تَعْقِلُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcccxxix{وَإِنَّهُۥ فِىٓ أُمِّ ٱلْكِتَٰبِ لَدَيْنَا لَعَلِىٌّ حَكِيمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcccxxx{أَفَنَضْرِبُ عَنكُمُ ٱلذِّكْرَ صَفْحًا أَن كُنتُمْ قَوْمًا مُّسْرِفِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcccxxxi{وَكَمْ أَرْسَلْنَا مِن نَّبِىٍّ فِى ٱلْأَوَّلِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcccxxxii{وَمَا يَأْتِيهِم مِّن نَّبِىٍّ إِلَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcccxxxiii{فَأَهْلَكْنَآ أَشَدَّ مِنْهُم بَطْشًا وَمَضَىٰ مَثَلُ ٱلْأَوَّلِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcccxxxiv{وَلَئِن سَأَلْتَهُم مَّنْ خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ لَيَقُولُنَّ خَلَقَهُنَّ ٱلْعَزِيزُ ٱلْعَلِيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcccxxxv{ٱلَّذِى جَعَلَ لَكُمُ ٱلْأَرْضَ مَهْدًا وَجَعَلَ لَكُمْ فِيهَا سُبُلًا لَّعَلَّكُمْ تَهْتَدُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcccxxxvi{وَٱلَّذِى نَزَّلَ مِنَ ٱلسَّمَآءِ مَآءًۢ بِقَدَرٍ فَأَنشَرْنَا بِهِۦ بَلْدَةً مَّيْتًا كَذَٰلِكَ تُخْرَجُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcccxxxvii{وَٱلَّذِى خَلَقَ ٱلْأَزْوَٰجَ كُلَّهَا وَجَعَلَ لَكُم مِّنَ ٱلْفُلْكِ وَٱلْأَنْعَٰمِ مَا تَرْكَبُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcccxxxviii{لِتَسْتَوُۥا۟ عَلَىٰ ظُهُورِهِۦ ثُمَّ تَذْكُرُوا۟ نِعْمَةَ رَبِّكُمْ إِذَا ٱسْتَوَيْتُمْ عَلَيْهِ وَتَقُولُوا۟ سُبْحَٰنَ ٱلَّذِى سَخَّرَ لَنَا هَٰذَا وَمَا كُنَّا لَهُۥ مُقْرِنِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcccxxxix{وَإِنَّآ إِلَىٰ رَبِّنَا لَمُنقَلِبُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcccxl{وَجَعَلُوا۟ لَهُۥ مِنْ عِبَادِهِۦ جُزْءًا إِنَّ ٱلْإِنسَٰنَ لَكَفُورٌ مُّبِينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcccxli{أَمِ ٱتَّخَذَ مِمَّا يَخْلُقُ بَنَاتٍ وَأَصْفَىٰكُم بِٱلْبَنِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcccxlii{وَإِذَا بُشِّرَ أَحَدُهُم بِمَا ضَرَبَ لِلرَّحْمَٰنِ مَثَلًا ظَلَّ وَجْهُهُۥ مُسْوَدًّا وَهُوَ كَظِيمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcccxliii{أَوَمَن يُنَشَّؤُا۟ فِى ٱلْحِلْيَةِ وَهُوَ فِى ٱلْخِصَامِ غَيْرُ مُبِينٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcccxliv{وَجَعَلُوا۟ ٱلْمَلَٰٓئِكَةَ ٱلَّذِينَ هُمْ عِبَٰدُ ٱلرَّحْمَٰنِ إِنَٰثًا أَشَهِدُوا۟ خَلْقَهُمْ سَتُكْتَبُ شَهَٰدَتُهُمْ وَيُسْـَٔلُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcccxlv{وَقَالُوا۟ لَوْ شَآءَ ٱلرَّحْمَٰنُ مَا عَبَدْنَٰهُم مَّا لَهُم بِذَٰلِكَ مِنْ عِلْمٍ إِنْ هُمْ إِلَّا يَخْرُصُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcccxlvi{أَمْ ءَاتَيْنَٰهُمْ كِتَٰبًا مِّن قَبْلِهِۦ فَهُم بِهِۦ مُسْتَمْسِكُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcccxlvii{بَلْ قَالُوٓا۟ إِنَّا وَجَدْنَآ ءَابَآءَنَا عَلَىٰٓ أُمَّةٍ وَإِنَّا عَلَىٰٓ ءَاثَٰرِهِم مُّهْتَدُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcccxlviii{وَكَذَٰلِكَ مَآ أَرْسَلْنَا مِن قَبْلِكَ فِى قَرْيَةٍ مِّن نَّذِيرٍ إِلَّا قَالَ مُتْرَفُوهَآ إِنَّا وَجَدْنَآ ءَابَآءَنَا عَلَىٰٓ أُمَّةٍ وَإِنَّا عَلَىٰٓ ءَاثَٰرِهِم مُّقْتَدُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcccxlix{قَٰلَ أَوَلَوْ جِئْتُكُم بِأَهْدَىٰ مِمَّا وَجَدتُّمْ عَلَيْهِ ءَابَآءَكُمْ قَالُوٓا۟ إِنَّا بِمَآ أُرْسِلْتُم بِهِۦ كَٰفِرُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcccl{فَٱنتَقَمْنَا مِنْهُمْ فَٱنظُرْ كَيْفَ كَانَ عَٰقِبَةُ ٱلْمُكَذِّبِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcccli{وَإِذْ قَالَ إِبْرَٰهِيمُ لِأَبِيهِ وَقَوْمِهِۦٓ إِنَّنِى بَرَآءٌ مِّمَّا تَعْبُدُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmccclii{إِلَّا ٱلَّذِى فَطَرَنِى فَإِنَّهُۥ سَيَهْدِينِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmcccliii{وَجَعَلَهَا كَلِمَةًۢ بَاقِيَةً فِى عَقِبِهِۦ لَعَلَّهُمْ يَرْجِعُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmcccliv{بَلْ مَتَّعْتُ هَٰٓؤُلَآءِ وَءَابَآءَهُمْ حَتَّىٰ جَآءَهُمُ ٱلْحَقُّ وَرَسُولٌ مُّبِينٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmccclv{وَلَمَّا جَآءَهُمُ ٱلْحَقُّ قَالُوا۟ هَٰذَا سِحْرٌ وَإِنَّا بِهِۦ كَٰفِرُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmccclvi{وَقَالُوا۟ لَوْلَا نُزِّلَ هَٰذَا ٱلْقُرْءَانُ عَلَىٰ رَجُلٍ مِّنَ ٱلْقَرْيَتَيْنِ عَظِيمٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmccclvii{أَهُمْ يَقْسِمُونَ رَحْمَتَ رَبِّكَ نَحْنُ قَسَمْنَا بَيْنَهُم مَّعِيشَتَهُمْ فِى ٱلْحَيَوٰةِ ٱلدُّنْيَا وَرَفَعْنَا بَعْضَهُمْ فَوْقَ بَعْضٍ دَرَجَٰتٍ لِّيَتَّخِذَ بَعْضُهُم بَعْضًا سُخْرِيًّا وَرَحْمَتُ رَبِّكَ خَيْرٌ مِّمَّا يَجْمَعُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmccclviii{وَلَوْلَآ أَن يَكُونَ ٱلنَّاسُ أُمَّةً وَٰحِدَةً لَّجَعَلْنَا لِمَن يَكْفُرُ بِٱلرَّحْمَٰنِ لِبُيُوتِهِمْ سُقُفًا مِّن فِضَّةٍ وَمَعَارِجَ عَلَيْهَا يَظْهَرُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmccclix{وَلِبُيُوتِهِمْ أَبْوَٰبًا وَسُرُرًا عَلَيْهَا يَتَّكِـُٔونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmccclx{وَزُخْرُفًا وَإِن كُلُّ ذَٰلِكَ لَمَّا مَتَٰعُ ٱلْحَيَوٰةِ ٱلدُّنْيَا وَٱلْءَاخِرَةُ عِندَ رَبِّكَ لِلْمُتَّقِينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmccclxi{وَمَن يَعْشُ عَن ذِكْرِ ٱلرَّحْمَٰنِ نُقَيِّضْ لَهُۥ شَيْطَٰنًا فَهُوَ لَهُۥ قَرِينٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmccclxii{وَإِنَّهُمْ لَيَصُدُّونَهُمْ عَنِ ٱلسَّبِيلِ وَيَحْسَبُونَ أَنَّهُم مُّهْتَدُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmccclxiii{حَتَّىٰٓ إِذَا جَآءَنَا قَالَ يَٰلَيْتَ بَيْنِى وَبَيْنَكَ بُعْدَ ٱلْمَشْرِقَيْنِ فَبِئْسَ ٱلْقَرِينُ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmccclxiv{وَلَن يَنفَعَكُمُ ٱلْيَوْمَ إِذ ظَّلَمْتُمْ أَنَّكُمْ فِى ٱلْعَذَابِ مُشْتَرِكُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmccclxv{أَفَأَنتَ تُسْمِعُ ٱلصُّمَّ أَوْ تَهْدِى ٱلْعُمْىَ وَمَن كَانَ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmccclxvi{فَإِمَّا نَذْهَبَنَّ بِكَ فَإِنَّا مِنْهُم مُّنتَقِمُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmccclxvii{أَوْ نُرِيَنَّكَ ٱلَّذِى وَعَدْنَٰهُمْ فَإِنَّا عَلَيْهِم مُّقْتَدِرُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmccclxviii{فَٱسْتَمْسِكْ بِٱلَّذِىٓ أُوحِىَ إِلَيْكَ إِنَّكَ عَلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmccclxix{وَإِنَّهُۥ لَذِكْرٌ لَّكَ وَلِقَوْمِكَ وَسَوْفَ تُسْـَٔلُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmccclxx{وَسْـَٔلْ مَنْ أَرْسَلْنَا مِن قَبْلِكَ مِن رُّسُلِنَآ أَجَعَلْنَا مِن دُونِ ٱلرَّحْمَٰنِ ءَالِهَةً يُعْبَدُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmccclxxi{وَلَقَدْ أَرْسَلْنَا مُوسَىٰ بِـَٔايَٰتِنَآ إِلَىٰ فِرْعَوْنَ وَمَلَإِي۟هِۦ فَقَالَ إِنِّى رَسُولُ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmccclxxii{فَلَمَّا جَآءَهُم بِـَٔايَٰتِنَآ إِذَا هُم مِّنْهَا يَضْحَكُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmccclxxiii{وَمَا نُرِيهِم مِّنْ ءَايَةٍ إِلَّا هِىَ أَكْبَرُ مِنْ أُخْتِهَا وَأَخَذْنَٰهُم بِٱلْعَذَابِ لَعَلَّهُمْ يَرْجِعُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmccclxxiv{وَقَالُوا۟ يَٰٓأَيُّهَ ٱلسَّاحِرُ ٱدْعُ لَنَا رَبَّكَ بِمَا عَهِدَ عِندَكَ إِنَّنَا لَمُهْتَدُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmccclxxv{فَلَمَّا كَشَفْنَا عَنْهُمُ ٱلْعَذَابَ إِذَا هُمْ يَنكُثُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmccclxxvi{وَنَادَىٰ فِرْعَوْنُ فِى قَوْمِهِۦ قَالَ يَٰقَوْمِ أَلَيْسَ لِى مُلْكُ مِصْرَ وَهَٰذِهِ ٱلْأَنْهَٰرُ تَجْرِى مِن تَحْتِىٓ أَفَلَا تُبْصِرُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmccclxxvii{أَمْ أَنَا۠ خَيْرٌ مِّنْ هَٰذَا ٱلَّذِى هُوَ مَهِينٌ وَلَا يَكَادُ يُبِينُ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmccclxxviii{فَلَوْلَآ أُلْقِىَ عَلَيْهِ أَسْوِرَةٌ مِّن ذَهَبٍ أَوْ جَآءَ مَعَهُ ٱلْمَلَٰٓئِكَةُ مُقْتَرِنِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmccclxxix{فَٱسْتَخَفَّ قَوْمَهُۥ فَأَطَاعُوهُ إِنَّهُمْ كَانُوا۟ قَوْمًا فَٰسِقِينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmccclxxx{فَلَمَّآ ءَاسَفُونَا ٱنتَقَمْنَا مِنْهُمْ فَأَغْرَقْنَٰهُمْ أَجْمَعِينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmccclxxxi{فَجَعَلْنَٰهُمْ سَلَفًا وَمَثَلًا لِّلْءَاخِرِينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmccclxxxii{وَلَمَّا ضُرِبَ ٱبْنُ مَرْيَمَ مَثَلًا إِذَا قَوْمُكَ مِنْهُ يَصِدُّونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmccclxxxiii{وَقَالُوٓا۟ ءَأَٰلِهَتُنَا خَيْرٌ أَمْ هُوَ مَا ضَرَبُوهُ لَكَ إِلَّا جَدَلًۢا بَلْ هُمْ قَوْمٌ خَصِمُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmccclxxxiv{إِنْ هُوَ إِلَّا عَبْدٌ أَنْعَمْنَا عَلَيْهِ وَجَعَلْنَٰهُ مَثَلًا لِّبَنِىٓ إِسْرَٰٓءِيلَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmccclxxxv{وَلَوْ نَشَآءُ لَجَعَلْنَا مِنكُم مَّلَٰٓئِكَةً فِى ٱلْأَرْضِ يَخْلُفُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmccclxxxvi{وَإِنَّهُۥ لَعِلْمٌ لِّلسَّاعَةِ فَلَا تَمْتَرُنَّ بِهَا وَٱتَّبِعُونِ هَٰذَا صِرَٰطٌ مُّسْتَقِيمٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmccclxxxvii{وَلَا يَصُدَّنَّكُمُ ٱلشَّيْطَٰنُ إِنَّهُۥ لَكُمْ عَدُوٌّ مُّبِينٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmccclxxxviii{وَلَمَّا جَآءَ عِيسَىٰ بِٱلْبَيِّنَٰتِ قَالَ قَدْ جِئْتُكُم بِٱلْحِكْمَةِ وَلِأُبَيِّنَ لَكُم بَعْضَ ٱلَّذِى تَخْتَلِفُونَ فِيهِ فَٱتَّقُوا۟ ٱللَّهَ وَأَطِيعُونِ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmccclxxxix{إِنَّ ٱللَّهَ هُوَ رَبِّى وَرَبُّكُمْ فَٱعْبُدُوهُ هَٰذَا صِرَٰطٌ مُّسْتَقِيمٌ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcccxc{فَٱخْتَلَفَ ٱلْأَحْزَابُ مِنۢ بَيْنِهِمْ فَوَيْلٌ لِّلَّذِينَ ظَلَمُوا۟ مِنْ عَذَابِ يَوْمٍ أَلِيمٍ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcccxci{هَلْ يَنظُرُونَ إِلَّا ٱلسَّاعَةَ أَن تَأْتِيَهُم بَغْتَةً وَهُمْ لَا يَشْعُرُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcccxcii{ٱلْأَخِلَّآءُ يَوْمَئِذٍۭ بَعْضُهُمْ لِبَعْضٍ عَدُوٌّ إِلَّا ٱلْمُتَّقِينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcccxciii{يَٰعِبَادِ لَا خَوْفٌ عَلَيْكُمُ ٱلْيَوْمَ وَلَآ أَنتُمْ تَحْزَنُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmcccxciv{ٱلَّذِينَ ءَامَنُوا۟ بِـَٔايَٰتِنَا وَكَانُوا۟ مُسْلِمِينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcccxcv{ٱدْخُلُوا۟ ٱلْجَنَّةَ أَنتُمْ وَأَزْوَٰجُكُمْ تُحْبَرُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcccxcvi{يُطَافُ عَلَيْهِم بِصِحَافٍ مِّن ذَهَبٍ وَأَكْوَابٍ وَفِيهَا مَا تَشْتَهِيهِ ٱلْأَنفُسُ وَتَلَذُّ ٱلْأَعْيُنُ وَأَنتُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmcccxcvii{وَتِلْكَ ٱلْجَنَّةُ ٱلَّتِىٓ أُورِثْتُمُوهَا بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmcccxcviii{لَكُمْ فِيهَا فَٰكِهَةٌ كَثِيرَةٌ مِّنْهَا تَأْكُلُونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmcccxcix{إِنَّ ٱلْمُجْرِمِينَ فِى عَذَابِ جَهَنَّمَ خَٰلِدُونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmcd{لَا يُفَتَّرُ عَنْهُمْ وَهُمْ فِيهِ مُبْلِسُونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmcdi{وَمَا ظَلَمْنَٰهُمْ وَلَٰكِن كَانُوا۟ هُمُ ٱلظَّٰلِمِينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmcdii{وَنَادَوْا۟ يَٰمَٰلِكُ لِيَقْضِ عَلَيْنَا رَبُّكَ قَالَ إِنَّكُم مَّٰكِثُونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmcdiii{لَقَدْ جِئْنَٰكُم بِٱلْحَقِّ وَلَٰكِنَّ أَكْثَرَكُمْ لِلْحَقِّ كَٰرِهُونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmcdiv{أَمْ أَبْرَمُوٓا۟ أَمْرًا فَإِنَّا مُبْرِمُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmmcdv{أَمْ يَحْسَبُونَ أَنَّا لَا نَسْمَعُ سِرَّهُمْ وَنَجْوَىٰهُم بَلَىٰ وَرُسُلُنَا لَدَيْهِمْ يَكْتُبُونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmcdvi{قُلْ إِن كَانَ لِلرَّحْمَٰنِ وَلَدٌ فَأَنَا۠ أَوَّلُ ٱلْعَٰبِدِينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmcdvii{سُبْحَٰنَ رَبِّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ رَبِّ ٱلْعَرْشِ عَمَّا يَصِفُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmcdviii{فَذَرْهُمْ يَخُوضُوا۟ وَيَلْعَبُوا۟ حَتَّىٰ يُلَٰقُوا۟ يَوْمَهُمُ ٱلَّذِى يُوعَدُونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmcdix{وَهُوَ ٱلَّذِى فِى ٱلسَّمَآءِ إِلَٰهٌ وَفِى ٱلْأَرْضِ إِلَٰهٌ وَهُوَ ٱلْحَكِيمُ ٱلْعَلِيمُ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmcdx{وَتَبَارَكَ ٱلَّذِى لَهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَا وَعِندَهُۥ عِلْمُ ٱلسَّاعَةِ وَإِلَيْهِ تُرْجَعُونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmcdxi{وَلَا يَمْلِكُ ٱلَّذِينَ يَدْعُونَ مِن دُونِهِ ٱلشَّفَٰعَةَ إِلَّا مَن شَهِدَ بِٱلْحَقِّ وَهُمْ يَعْلَمُونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmmcdxii{وَلَئِن سَأَلْتَهُم مَّنْ خَلَقَهُمْ لَيَقُولُنَّ ٱللَّهُ فَأَنَّىٰ يُؤْفَكُونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmmcdxiii{وَقِيلِهِۦ يَٰرَبِّ إِنَّ هَٰٓؤُلَآءِ قَوْمٌ لَّا يُؤْمِنُونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmmcdxiv{فَٱصْفَحْ عَنْهُمْ وَقُلْ سَلَٰمٌ فَسَوْفَ يَعْلَمُونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmmcdxv{\basmalah حمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcdxvi{وَٱلْكِتَٰبِ ٱلْمُبِينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcdxvii{إِنَّآ أَنزَلْنَٰهُ فِى لَيْلَةٍ مُّبَٰرَكَةٍ إِنَّا كُنَّا مُنذِرِينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcdxviii{فِيهَا يُفْرَقُ كُلُّ أَمْرٍ حَكِيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcdxix{أَمْرًا مِّنْ عِندِنَآ إِنَّا كُنَّا مُرْسِلِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcdxx{رَحْمَةً مِّن رَّبِّكَ إِنَّهُۥ هُوَ ٱلسَّمِيعُ ٱلْعَلِيمُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcdxxi{رَبِّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَآ إِن كُنتُم مُّوقِنِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcdxxii{لَآ إِلَٰهَ إِلَّا هُوَ يُحْىِۦ وَيُمِيتُ رَبُّكُمْ وَرَبُّ ءَابَآئِكُمُ ٱلْأَوَّلِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcdxxiii{بَلْ هُمْ فِى شَكٍّ يَلْعَبُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcdxxiv{فَٱرْتَقِبْ يَوْمَ تَأْتِى ٱلسَّمَآءُ بِدُخَانٍ مُّبِينٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcdxxv{يَغْشَى ٱلنَّاسَ هَٰذَا عَذَابٌ أَلِيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcdxxvi{رَّبَّنَا ٱكْشِفْ عَنَّا ٱلْعَذَابَ إِنَّا مُؤْمِنُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcdxxvii{أَنَّىٰ لَهُمُ ٱلذِّكْرَىٰ وَقَدْ جَآءَهُمْ رَسُولٌ مُّبِينٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcdxxviii{ثُمَّ تَوَلَّوْا۟ عَنْهُ وَقَالُوا۟ مُعَلَّمٌ مَّجْنُونٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcdxxix{إِنَّا كَاشِفُوا۟ ٱلْعَذَابِ قَلِيلًا إِنَّكُمْ عَآئِدُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcdxxx{يَوْمَ نَبْطِشُ ٱلْبَطْشَةَ ٱلْكُبْرَىٰٓ إِنَّا مُنتَقِمُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcdxxxi{وَلَقَدْ فَتَنَّا قَبْلَهُمْ قَوْمَ فِرْعَوْنَ وَجَآءَهُمْ رَسُولٌ كَرِيمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcdxxxii{أَنْ أَدُّوٓا۟ إِلَىَّ عِبَادَ ٱللَّهِ إِنِّى لَكُمْ رَسُولٌ أَمِينٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcdxxxiii{وَأَن لَّا تَعْلُوا۟ عَلَى ٱللَّهِ إِنِّىٓ ءَاتِيكُم بِسُلْطَٰنٍ مُّبِينٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcdxxxiv{وَإِنِّى عُذْتُ بِرَبِّى وَرَبِّكُمْ أَن تَرْجُمُونِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcdxxxv{وَإِن لَّمْ تُؤْمِنُوا۟ لِى فَٱعْتَزِلُونِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcdxxxvi{فَدَعَا رَبَّهُۥٓ أَنَّ هَٰٓؤُلَآءِ قَوْمٌ مُّجْرِمُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcdxxxvii{فَأَسْرِ بِعِبَادِى لَيْلًا إِنَّكُم مُّتَّبَعُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcdxxxviii{وَٱتْرُكِ ٱلْبَحْرَ رَهْوًا إِنَّهُمْ جُندٌ مُّغْرَقُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcdxxxix{كَمْ تَرَكُوا۟ مِن جَنَّٰتٍ وَعُيُونٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcdxl{وَزُرُوعٍ وَمَقَامٍ كَرِيمٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmcdxli{وَنَعْمَةٍ كَانُوا۟ فِيهَا فَٰكِهِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmcdxlii{كَذَٰلِكَ وَأَوْرَثْنَٰهَا قَوْمًا ءَاخَرِينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmcdxliii{فَمَا بَكَتْ عَلَيْهِمُ ٱلسَّمَآءُ وَٱلْأَرْضُ وَمَا كَانُوا۟ مُنظَرِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmcdxliv{وَلَقَدْ نَجَّيْنَا بَنِىٓ إِسْرَٰٓءِيلَ مِنَ ٱلْعَذَابِ ٱلْمُهِينِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmcdxlv{مِن فِرْعَوْنَ إِنَّهُۥ كَانَ عَالِيًا مِّنَ ٱلْمُسْرِفِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmcdxlvi{وَلَقَدِ ٱخْتَرْنَٰهُمْ عَلَىٰ عِلْمٍ عَلَى ٱلْعَٰلَمِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmcdxlvii{وَءَاتَيْنَٰهُم مِّنَ ٱلْءَايَٰتِ مَا فِيهِ بَلَٰٓؤٌا۟ مُّبِينٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcdxlviii{إِنَّ هَٰٓؤُلَآءِ لَيَقُولُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmcdxlix{إِنْ هِىَ إِلَّا مَوْتَتُنَا ٱلْأُولَىٰ وَمَا نَحْنُ بِمُنشَرِينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmcdl{فَأْتُوا۟ بِـَٔابَآئِنَآ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcdli{أَهُمْ خَيْرٌ أَمْ قَوْمُ تُبَّعٍ وَٱلَّذِينَ مِن قَبْلِهِمْ أَهْلَكْنَٰهُمْ إِنَّهُمْ كَانُوا۟ مُجْرِمِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcdlii{وَمَا خَلَقْنَا ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَمَا بَيْنَهُمَا لَٰعِبِينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcdliii{مَا خَلَقْنَٰهُمَآ إِلَّا بِٱلْحَقِّ وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَعْلَمُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcdliv{إِنَّ يَوْمَ ٱلْفَصْلِ مِيقَٰتُهُمْ أَجْمَعِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcdlv{يَوْمَ لَا يُغْنِى مَوْلًى عَن مَّوْلًى شَيْـًٔا وَلَا هُمْ يُنصَرُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcdlvi{إِلَّا مَن رَّحِمَ ٱللَّهُ إِنَّهُۥ هُوَ ٱلْعَزِيزُ ٱلرَّحِيمُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcdlvii{إِنَّ شَجَرَتَ ٱلزَّقُّومِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcdlviii{طَعَامُ ٱلْأَثِيمِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcdlix{كَٱلْمُهْلِ يَغْلِى فِى ٱلْبُطُونِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcdlx{كَغَلْىِ ٱلْحَمِيمِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcdlxi{خُذُوهُ فَٱعْتِلُوهُ إِلَىٰ سَوَآءِ ٱلْجَحِيمِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcdlxii{ثُمَّ صُبُّوا۟ فَوْقَ رَأْسِهِۦ مِنْ عَذَابِ ٱلْحَمِيمِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcdlxiii{ذُقْ إِنَّكَ أَنتَ ٱلْعَزِيزُ ٱلْكَرِيمُ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcdlxiv{إِنَّ هَٰذَا مَا كُنتُم بِهِۦ تَمْتَرُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcdlxv{إِنَّ ٱلْمُتَّقِينَ فِى مَقَامٍ أَمِينٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcdlxvi{فِى جَنَّٰتٍ وَعُيُونٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcdlxvii{يَلْبَسُونَ مِن سُندُسٍ وَإِسْتَبْرَقٍ مُّتَقَٰبِلِينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcdlxviii{كَذَٰلِكَ وَزَوَّجْنَٰهُم بِحُورٍ عِينٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcdlxix{يَدْعُونَ فِيهَا بِكُلِّ فَٰكِهَةٍ ءَامِنِينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcdlxx{لَا يَذُوقُونَ فِيهَا ٱلْمَوْتَ إِلَّا ٱلْمَوْتَةَ ٱلْأُولَىٰ وَوَقَىٰهُمْ عَذَابَ ٱلْجَحِيمِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcdlxxi{فَضْلًا مِّن رَّبِّكَ ذَٰلِكَ هُوَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcdlxxii{فَإِنَّمَا يَسَّرْنَٰهُ بِلِسَانِكَ لَعَلَّهُمْ يَتَذَكَّرُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcdlxxiii{فَٱرْتَقِبْ إِنَّهُم مُّرْتَقِبُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcdlxxiv{\basmalah حمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcdlxxv{تَنزِيلُ ٱلْكِتَٰبِ مِنَ ٱللَّهِ ٱلْعَزِيزِ ٱلْحَكِيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcdlxxvi{إِنَّ فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ لَءَايَٰتٍ لِّلْمُؤْمِنِينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcdlxxvii{وَفِى خَلْقِكُمْ وَمَا يَبُثُّ مِن دَآبَّةٍ ءَايَٰتٌ لِّقَوْمٍ يُوقِنُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcdlxxviii{وَٱخْتِلَٰفِ ٱلَّيْلِ وَٱلنَّهَارِ وَمَآ أَنزَلَ ٱللَّهُ مِنَ ٱلسَّمَآءِ مِن رِّزْقٍ فَأَحْيَا بِهِ ٱلْأَرْضَ بَعْدَ مَوْتِهَا وَتَصْرِيفِ ٱلرِّيَٰحِ ءَايَٰتٌ لِّقَوْمٍ يَعْقِلُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcdlxxix{تِلْكَ ءَايَٰتُ ٱللَّهِ نَتْلُوهَا عَلَيْكَ بِٱلْحَقِّ فَبِأَىِّ حَدِيثٍۭ بَعْدَ ٱللَّهِ وَءَايَٰتِهِۦ يُؤْمِنُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcdlxxx{وَيْلٌ لِّكُلِّ أَفَّاكٍ أَثِيمٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxi{يَسْمَعُ ءَايَٰتِ ٱللَّهِ تُتْلَىٰ عَلَيْهِ ثُمَّ يُصِرُّ مُسْتَكْبِرًا كَأَن لَّمْ يَسْمَعْهَا فَبَشِّرْهُ بِعَذَابٍ أَلِيمٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxii{وَإِذَا عَلِمَ مِنْ ءَايَٰتِنَا شَيْـًٔا ٱتَّخَذَهَا هُزُوًا أُو۟لَٰٓئِكَ لَهُمْ عَذَابٌ مُّهِينٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxiii{مِّن وَرَآئِهِمْ جَهَنَّمُ وَلَا يُغْنِى عَنْهُم مَّا كَسَبُوا۟ شَيْـًٔا وَلَا مَا ٱتَّخَذُوا۟ مِن دُونِ ٱللَّهِ أَوْلِيَآءَ وَلَهُمْ عَذَابٌ عَظِيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxiv{هَٰذَا هُدًى وَٱلَّذِينَ كَفَرُوا۟ بِـَٔايَٰتِ رَبِّهِمْ لَهُمْ عَذَابٌ مِّن رِّجْزٍ أَلِيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxv{ٱللَّهُ ٱلَّذِى سَخَّرَ لَكُمُ ٱلْبَحْرَ لِتَجْرِىَ ٱلْفُلْكُ فِيهِ بِأَمْرِهِۦ وَلِتَبْتَغُوا۟ مِن فَضْلِهِۦ وَلَعَلَّكُمْ تَشْكُرُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxvi{وَسَخَّرَ لَكُم مَّا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ جَمِيعًا مِّنْهُ إِنَّ فِى ذَٰلِكَ لَءَايَٰتٍ لِّقَوْمٍ يَتَفَكَّرُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxvii{قُل لِّلَّذِينَ ءَامَنُوا۟ يَغْفِرُوا۟ لِلَّذِينَ لَا يَرْجُونَ أَيَّامَ ٱللَّهِ لِيَجْزِىَ قَوْمًۢا بِمَا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxviii{مَنْ عَمِلَ صَٰلِحًا فَلِنَفْسِهِۦ وَمَنْ أَسَآءَ فَعَلَيْهَا ثُمَّ إِلَىٰ رَبِّكُمْ تُرْجَعُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxix{وَلَقَدْ ءَاتَيْنَا بَنِىٓ إِسْرَٰٓءِيلَ ٱلْكِتَٰبَ وَٱلْحُكْمَ وَٱلنُّبُوَّةَ وَرَزَقْنَٰهُم مِّنَ ٱلطَّيِّبَٰتِ وَفَضَّلْنَٰهُمْ عَلَى ٱلْعَٰلَمِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcdxc{وَءَاتَيْنَٰهُم بَيِّنَٰتٍ مِّنَ ٱلْأَمْرِ فَمَا ٱخْتَلَفُوٓا۟ إِلَّا مِنۢ بَعْدِ مَا جَآءَهُمُ ٱلْعِلْمُ بَغْيًۢا بَيْنَهُمْ إِنَّ رَبَّكَ يَقْضِى بَيْنَهُمْ يَوْمَ ٱلْقِيَٰمَةِ فِيمَا كَانُوا۟ فِيهِ يَخْتَلِفُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcdxci{ثُمَّ جَعَلْنَٰكَ عَلَىٰ شَرِيعَةٍ مِّنَ ٱلْأَمْرِ فَٱتَّبِعْهَا وَلَا تَتَّبِعْ أَهْوَآءَ ٱلَّذِينَ لَا يَعْلَمُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcdxcii{إِنَّهُمْ لَن يُغْنُوا۟ عَنكَ مِنَ ٱللَّهِ شَيْـًٔا وَإِنَّ ٱلظَّٰلِمِينَ بَعْضُهُمْ أَوْلِيَآءُ بَعْضٍ وَٱللَّهُ وَلِىُّ ٱلْمُتَّقِينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcdxciii{هَٰذَا بَصَٰٓئِرُ لِلنَّاسِ وَهُدًى وَرَحْمَةٌ لِّقَوْمٍ يُوقِنُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcdxciv{أَمْ حَسِبَ ٱلَّذِينَ ٱجْتَرَحُوا۟ ٱلسَّيِّـَٔاتِ أَن نَّجْعَلَهُمْ كَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ سَوَآءً مَّحْيَاهُمْ وَمَمَاتُهُمْ سَآءَ مَا يَحْكُمُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcdxcv{وَخَلَقَ ٱللَّهُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ بِٱلْحَقِّ وَلِتُجْزَىٰ كُلُّ نَفْسٍۭ بِمَا كَسَبَتْ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcdxcvi{أَفَرَءَيْتَ مَنِ ٱتَّخَذَ إِلَٰهَهُۥ هَوَىٰهُ وَأَضَلَّهُ ٱللَّهُ عَلَىٰ عِلْمٍ وَخَتَمَ عَلَىٰ سَمْعِهِۦ وَقَلْبِهِۦ وَجَعَلَ عَلَىٰ بَصَرِهِۦ غِشَٰوَةً فَمَن يَهْدِيهِ مِنۢ بَعْدِ ٱللَّهِ أَفَلَا تَذَكَّرُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcdxcvii{وَقَالُوا۟ مَا هِىَ إِلَّا حَيَاتُنَا ٱلدُّنْيَا نَمُوتُ وَنَحْيَا وَمَا يُهْلِكُنَآ إِلَّا ٱلدَّهْرُ وَمَا لَهُم بِذَٰلِكَ مِنْ عِلْمٍ إِنْ هُمْ إِلَّا يَظُنُّونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcdxcviii{وَإِذَا تُتْلَىٰ عَلَيْهِمْ ءَايَٰتُنَا بَيِّنَٰتٍ مَّا كَانَ حُجَّتَهُمْ إِلَّآ أَن قَالُوا۟ ٱئْتُوا۟ بِـَٔابَآئِنَآ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcdxcix{قُلِ ٱللَّهُ يُحْيِيكُمْ ثُمَّ يُمِيتُكُمْ ثُمَّ يَجْمَعُكُمْ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ لَا رَيْبَ فِيهِ وَلَٰكِنَّ أَكْثَرَ ٱلنَّاسِ لَا يَعْلَمُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmd{وَلِلَّهِ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَيَوْمَ تَقُومُ ٱلسَّاعَةُ يَوْمَئِذٍ يَخْسَرُ ٱلْمُبْطِلُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdi{وَتَرَىٰ كُلَّ أُمَّةٍ جَاثِيَةً كُلُّ أُمَّةٍ تُدْعَىٰٓ إِلَىٰ كِتَٰبِهَا ٱلْيَوْمَ تُجْزَوْنَ مَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdii{هَٰذَا كِتَٰبُنَا يَنطِقُ عَلَيْكُم بِٱلْحَقِّ إِنَّا كُنَّا نَسْتَنسِخُ مَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdiii{فَأَمَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ فَيُدْخِلُهُمْ رَبُّهُمْ فِى رَحْمَتِهِۦ ذَٰلِكَ هُوَ ٱلْفَوْزُ ٱلْمُبِينُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdiv{وَأَمَّا ٱلَّذِينَ كَفَرُوٓا۟ أَفَلَمْ تَكُنْ ءَايَٰتِى تُتْلَىٰ عَلَيْكُمْ فَٱسْتَكْبَرْتُمْ وَكُنتُمْ قَوْمًا مُّجْرِمِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdv{وَإِذَا قِيلَ إِنَّ وَعْدَ ٱللَّهِ حَقٌّ وَٱلسَّاعَةُ لَا رَيْبَ فِيهَا قُلْتُم مَّا نَدْرِى مَا ٱلسَّاعَةُ إِن نَّظُنُّ إِلَّا ظَنًّا وَمَا نَحْنُ بِمُسْتَيْقِنِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdvi{وَبَدَا لَهُمْ سَيِّـَٔاتُ مَا عَمِلُوا۟ وَحَاقَ بِهِم مَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdvii{وَقِيلَ ٱلْيَوْمَ نَنسَىٰكُمْ كَمَا نَسِيتُمْ لِقَآءَ يَوْمِكُمْ هَٰذَا وَمَأْوَىٰكُمُ ٱلنَّارُ وَمَا لَكُم مِّن نَّٰصِرِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdviii{ذَٰلِكُم بِأَنَّكُمُ ٱتَّخَذْتُمْ ءَايَٰتِ ٱللَّهِ هُزُوًا وَغَرَّتْكُمُ ٱلْحَيَوٰةُ ٱلدُّنْيَا فَٱلْيَوْمَ لَا يُخْرَجُونَ مِنْهَا وَلَا هُمْ يُسْتَعْتَبُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdix{فَلِلَّهِ ٱلْحَمْدُ رَبِّ ٱلسَّمَٰوَٰتِ وَرَبِّ ٱلْأَرْضِ رَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdx{وَلَهُ ٱلْكِبْرِيَآءُ فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdxi{\basmalah حمٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdxii{تَنزِيلُ ٱلْكِتَٰبِ مِنَ ٱللَّهِ ٱلْعَزِيزِ ٱلْحَكِيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdxiii{مَا خَلَقْنَا ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَمَا بَيْنَهُمَآ إِلَّا بِٱلْحَقِّ وَأَجَلٍ مُّسَمًّى وَٱلَّذِينَ كَفَرُوا۟ عَمَّآ أُنذِرُوا۟ مُعْرِضُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdxiv{قُلْ أَرَءَيْتُم مَّا تَدْعُونَ مِن دُونِ ٱللَّهِ أَرُونِى مَاذَا خَلَقُوا۟ مِنَ ٱلْأَرْضِ أَمْ لَهُمْ شِرْكٌ فِى ٱلسَّمَٰوَٰتِ ٱئْتُونِى بِكِتَٰبٍ مِّن قَبْلِ هَٰذَآ أَوْ أَثَٰرَةٍ مِّنْ عِلْمٍ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdxv{وَمَنْ أَضَلُّ مِمَّن يَدْعُوا۟ مِن دُونِ ٱللَّهِ مَن لَّا يَسْتَجِيبُ لَهُۥٓ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ وَهُمْ عَن دُعَآئِهِمْ غَٰفِلُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdxvi{وَإِذَا حُشِرَ ٱلنَّاسُ كَانُوا۟ لَهُمْ أَعْدَآءً وَكَانُوا۟ بِعِبَادَتِهِمْ كَٰفِرِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdxvii{وَإِذَا تُتْلَىٰ عَلَيْهِمْ ءَايَٰتُنَا بَيِّنَٰتٍ قَالَ ٱلَّذِينَ كَفَرُوا۟ لِلْحَقِّ لَمَّا جَآءَهُمْ هَٰذَا سِحْرٌ مُّبِينٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdxviii{أَمْ يَقُولُونَ ٱفْتَرَىٰهُ قُلْ إِنِ ٱفْتَرَيْتُهُۥ فَلَا تَمْلِكُونَ لِى مِنَ ٱللَّهِ شَيْـًٔا هُوَ أَعْلَمُ بِمَا تُفِيضُونَ فِيهِ كَفَىٰ بِهِۦ شَهِيدًۢا بَيْنِى وَبَيْنَكُمْ وَهُوَ ٱلْغَفُورُ ٱلرَّحِيمُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdxix{قُلْ مَا كُنتُ بِدْعًا مِّنَ ٱلرُّسُلِ وَمَآ أَدْرِى مَا يُفْعَلُ بِى وَلَا بِكُمْ إِنْ أَتَّبِعُ إِلَّا مَا يُوحَىٰٓ إِلَىَّ وَمَآ أَنَا۠ إِلَّا نَذِيرٌ مُّبِينٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdxx{قُلْ أَرَءَيْتُمْ إِن كَانَ مِنْ عِندِ ٱللَّهِ وَكَفَرْتُم بِهِۦ وَشَهِدَ شَاهِدٌ مِّنۢ بَنِىٓ إِسْرَٰٓءِيلَ عَلَىٰ مِثْلِهِۦ فَـَٔامَنَ وَٱسْتَكْبَرْتُمْ إِنَّ ٱللَّهَ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdxxi{وَقَالَ ٱلَّذِينَ كَفَرُوا۟ لِلَّذِينَ ءَامَنُوا۟ لَوْ كَانَ خَيْرًا مَّا سَبَقُونَآ إِلَيْهِ وَإِذْ لَمْ يَهْتَدُوا۟ بِهِۦ فَسَيَقُولُونَ هَٰذَآ إِفْكٌ قَدِيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdxxii{وَمِن قَبْلِهِۦ كِتَٰبُ مُوسَىٰٓ إِمَامًا وَرَحْمَةً وَهَٰذَا كِتَٰبٌ مُّصَدِّقٌ لِّسَانًا عَرَبِيًّا لِّيُنذِرَ ٱلَّذِينَ ظَلَمُوا۟ وَبُشْرَىٰ لِلْمُحْسِنِينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdxxiii{إِنَّ ٱلَّذِينَ قَالُوا۟ رَبُّنَا ٱللَّهُ ثُمَّ ٱسْتَقَٰمُوا۟ فَلَا خَوْفٌ عَلَيْهِمْ وَلَا هُمْ يَحْزَنُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdxxiv{أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْجَنَّةِ خَٰلِدِينَ فِيهَا جَزَآءًۢ بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdxxv{وَوَصَّيْنَا ٱلْإِنسَٰنَ بِوَٰلِدَيْهِ إِحْسَٰنًا حَمَلَتْهُ أُمُّهُۥ كُرْهًا وَوَضَعَتْهُ كُرْهًا وَحَمْلُهُۥ وَفِصَٰلُهُۥ ثَلَٰثُونَ شَهْرًا حَتَّىٰٓ إِذَا بَلَغَ أَشُدَّهُۥ وَبَلَغَ أَرْبَعِينَ سَنَةً قَالَ رَبِّ أَوْزِعْنِىٓ أَنْ أَشْكُرَ نِعْمَتَكَ ٱلَّتِىٓ أَنْعَمْتَ عَلَىَّ وَعَلَىٰ وَٰلِدَىَّ وَأَنْ أَعْمَلَ صَٰلِحًا تَرْضَىٰهُ وَأَصْلِحْ لِى فِى ذُرِّيَّتِىٓ إِنِّى تُبْتُ إِلَيْكَ وَإِنِّى مِنَ ٱلْمُسْلِمِينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdxxvi{أُو۟لَٰٓئِكَ ٱلَّذِينَ نَتَقَبَّلُ عَنْهُمْ أَحْسَنَ مَا عَمِلُوا۟ وَنَتَجَاوَزُ عَن سَيِّـَٔاتِهِمْ فِىٓ أَصْحَٰبِ ٱلْجَنَّةِ وَعْدَ ٱلصِّدْقِ ٱلَّذِى كَانُوا۟ يُوعَدُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdxxvii{وَٱلَّذِى قَالَ لِوَٰلِدَيْهِ أُفٍّ لَّكُمَآ أَتَعِدَانِنِىٓ أَنْ أُخْرَجَ وَقَدْ خَلَتِ ٱلْقُرُونُ مِن قَبْلِى وَهُمَا يَسْتَغِيثَانِ ٱللَّهَ وَيْلَكَ ءَامِنْ إِنَّ وَعْدَ ٱللَّهِ حَقٌّ فَيَقُولُ مَا هَٰذَآ إِلَّآ أَسَٰطِيرُ ٱلْأَوَّلِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdxxviii{أُو۟لَٰٓئِكَ ٱلَّذِينَ حَقَّ عَلَيْهِمُ ٱلْقَوْلُ فِىٓ أُمَمٍ قَدْ خَلَتْ مِن قَبْلِهِم مِّنَ ٱلْجِنِّ وَٱلْإِنسِ إِنَّهُمْ كَانُوا۟ خَٰسِرِينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdxxix{وَلِكُلٍّ دَرَجَٰتٌ مِّمَّا عَمِلُوا۟ وَلِيُوَفِّيَهُمْ أَعْمَٰلَهُمْ وَهُمْ لَا يُظْلَمُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdxxx{وَيَوْمَ يُعْرَضُ ٱلَّذِينَ كَفَرُوا۟ عَلَى ٱلنَّارِ أَذْهَبْتُمْ طَيِّبَٰتِكُمْ فِى حَيَاتِكُمُ ٱلدُّنْيَا وَٱسْتَمْتَعْتُم بِهَا فَٱلْيَوْمَ تُجْزَوْنَ عَذَابَ ٱلْهُونِ بِمَا كُنتُمْ تَسْتَكْبِرُونَ فِى ٱلْأَرْضِ بِغَيْرِ ٱلْحَقِّ وَبِمَا كُنتُمْ تَفْسُقُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdxxxi{وَٱذْكُرْ أَخَا عَادٍ إِذْ أَنذَرَ قَوْمَهُۥ بِٱلْأَحْقَافِ وَقَدْ خَلَتِ ٱلنُّذُرُ مِنۢ بَيْنِ يَدَيْهِ وَمِنْ خَلْفِهِۦٓ أَلَّا تَعْبُدُوٓا۟ إِلَّا ٱللَّهَ إِنِّىٓ أَخَافُ عَلَيْكُمْ عَذَابَ يَوْمٍ عَظِيمٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdxxxii{قَالُوٓا۟ أَجِئْتَنَا لِتَأْفِكَنَا عَنْ ءَالِهَتِنَا فَأْتِنَا بِمَا تَعِدُنَآ إِن كُنتَ مِنَ ٱلصَّٰدِقِينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdxxxiii{قَالَ إِنَّمَا ٱلْعِلْمُ عِندَ ٱللَّهِ وَأُبَلِّغُكُم مَّآ أُرْسِلْتُ بِهِۦ وَلَٰكِنِّىٓ أَرَىٰكُمْ قَوْمًا تَجْهَلُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdxxxiv{فَلَمَّا رَأَوْهُ عَارِضًا مُّسْتَقْبِلَ أَوْدِيَتِهِمْ قَالُوا۟ هَٰذَا عَارِضٌ مُّمْطِرُنَا بَلْ هُوَ مَا ٱسْتَعْجَلْتُم بِهِۦ رِيحٌ فِيهَا عَذَابٌ أَلِيمٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdxxxv{تُدَمِّرُ كُلَّ شَىْءٍۭ بِأَمْرِ رَبِّهَا فَأَصْبَحُوا۟ لَا يُرَىٰٓ إِلَّا مَسَٰكِنُهُمْ كَذَٰلِكَ نَجْزِى ٱلْقَوْمَ ٱلْمُجْرِمِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdxxxvi{وَلَقَدْ مَكَّنَّٰهُمْ فِيمَآ إِن مَّكَّنَّٰكُمْ فِيهِ وَجَعَلْنَا لَهُمْ سَمْعًا وَأَبْصَٰرًا وَأَفْـِٔدَةً فَمَآ أَغْنَىٰ عَنْهُمْ سَمْعُهُمْ وَلَآ أَبْصَٰرُهُمْ وَلَآ أَفْـِٔدَتُهُم مِّن شَىْءٍ إِذْ كَانُوا۟ يَجْحَدُونَ بِـَٔايَٰتِ ٱللَّهِ وَحَاقَ بِهِم مَّا كَانُوا۟ بِهِۦ يَسْتَهْزِءُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdxxxvii{وَلَقَدْ أَهْلَكْنَا مَا حَوْلَكُم مِّنَ ٱلْقُرَىٰ وَصَرَّفْنَا ٱلْءَايَٰتِ لَعَلَّهُمْ يَرْجِعُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdxxxviii{فَلَوْلَا نَصَرَهُمُ ٱلَّذِينَ ٱتَّخَذُوا۟ مِن دُونِ ٱللَّهِ قُرْبَانًا ءَالِهَةًۢ بَلْ ضَلُّوا۟ عَنْهُمْ وَذَٰلِكَ إِفْكُهُمْ وَمَا كَانُوا۟ يَفْتَرُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdxxxix{وَإِذْ صَرَفْنَآ إِلَيْكَ نَفَرًا مِّنَ ٱلْجِنِّ يَسْتَمِعُونَ ٱلْقُرْءَانَ فَلَمَّا حَضَرُوهُ قَالُوٓا۟ أَنصِتُوا۟ فَلَمَّا قُضِىَ وَلَّوْا۟ إِلَىٰ قَوْمِهِم مُّنذِرِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdxl{قَالُوا۟ يَٰقَوْمَنَآ إِنَّا سَمِعْنَا كِتَٰبًا أُنزِلَ مِنۢ بَعْدِ مُوسَىٰ مُصَدِّقًا لِّمَا بَيْنَ يَدَيْهِ يَهْدِىٓ إِلَى ٱلْحَقِّ وَإِلَىٰ طَرِيقٍ مُّسْتَقِيمٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdxli{يَٰقَوْمَنَآ أَجِيبُوا۟ دَاعِىَ ٱللَّهِ وَءَامِنُوا۟ بِهِۦ يَغْفِرْ لَكُم مِّن ذُنُوبِكُمْ وَيُجِرْكُم مِّنْ عَذَابٍ أَلِيمٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdxlii{وَمَن لَّا يُجِبْ دَاعِىَ ٱللَّهِ فَلَيْسَ بِمُعْجِزٍ فِى ٱلْأَرْضِ وَلَيْسَ لَهُۥ مِن دُونِهِۦٓ أَوْلِيَآءُ أُو۟لَٰٓئِكَ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdxliii{أَوَلَمْ يَرَوْا۟ أَنَّ ٱللَّهَ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَلَمْ يَعْىَ بِخَلْقِهِنَّ بِقَٰدِرٍ عَلَىٰٓ أَن يُحْۦِىَ ٱلْمَوْتَىٰ بَلَىٰٓ إِنَّهُۥ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdxliv{وَيَوْمَ يُعْرَضُ ٱلَّذِينَ كَفَرُوا۟ عَلَى ٱلنَّارِ أَلَيْسَ هَٰذَا بِٱلْحَقِّ قَالُوا۟ بَلَىٰ وَرَبِّنَا قَالَ فَذُوقُوا۟ ٱلْعَذَابَ بِمَا كُنتُمْ تَكْفُرُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdxlv{فَٱصْبِرْ كَمَا صَبَرَ أُو۟لُوا۟ ٱلْعَزْمِ مِنَ ٱلرُّسُلِ وَلَا تَسْتَعْجِل لَّهُمْ كَأَنَّهُمْ يَوْمَ يَرَوْنَ مَا يُوعَدُونَ لَمْ يَلْبَثُوٓا۟ إِلَّا سَاعَةً مِّن نَّهَارٍۭ بَلَٰغٌ فَهَلْ يُهْلَكُ إِلَّا ٱلْقَوْمُ ٱلْفَٰسِقُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdxlvi{\basmalah ٱلَّذِينَ كَفَرُوا۟ وَصَدُّوا۟ عَن سَبِيلِ ٱللَّهِ أَضَلَّ أَعْمَٰلَهُمْ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdxlvii{وَٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ وَءَامَنُوا۟ بِمَا نُزِّلَ عَلَىٰ مُحَمَّدٍ وَهُوَ ٱلْحَقُّ مِن رَّبِّهِمْ كَفَّرَ عَنْهُمْ سَيِّـَٔاتِهِمْ وَأَصْلَحَ بَالَهُمْ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdxlviii{ذَٰلِكَ بِأَنَّ ٱلَّذِينَ كَفَرُوا۟ ٱتَّبَعُوا۟ ٱلْبَٰطِلَ وَأَنَّ ٱلَّذِينَ ءَامَنُوا۟ ٱتَّبَعُوا۟ ٱلْحَقَّ مِن رَّبِّهِمْ كَذَٰلِكَ يَضْرِبُ ٱللَّهُ لِلنَّاسِ أَمْثَٰلَهُمْ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdxlix{فَإِذَا لَقِيتُمُ ٱلَّذِينَ كَفَرُوا۟ فَضَرْبَ ٱلرِّقَابِ حَتَّىٰٓ إِذَآ أَثْخَنتُمُوهُمْ فَشُدُّوا۟ ٱلْوَثَاقَ فَإِمَّا مَنًّۢا بَعْدُ وَإِمَّا فِدَآءً حَتَّىٰ تَضَعَ ٱلْحَرْبُ أَوْزَارَهَا ذَٰلِكَ وَلَوْ يَشَآءُ ٱللَّهُ لَٱنتَصَرَ مِنْهُمْ وَلَٰكِن لِّيَبْلُوَا۟ بَعْضَكُم بِبَعْضٍ وَٱلَّذِينَ قُتِلُوا۟ فِى سَبِيلِ ٱللَّهِ فَلَن يُضِلَّ أَعْمَٰلَهُمْ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdl{سَيَهْدِيهِمْ وَيُصْلِحُ بَالَهُمْ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdli{وَيُدْخِلُهُمُ ٱلْجَنَّةَ عَرَّفَهَا لَهُمْ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdlii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِن تَنصُرُوا۟ ٱللَّهَ يَنصُرْكُمْ وَيُثَبِّتْ أَقْدَامَكُمْ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdliii{وَٱلَّذِينَ كَفَرُوا۟ فَتَعْسًا لَّهُمْ وَأَضَلَّ أَعْمَٰلَهُمْ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdliv{ذَٰلِكَ بِأَنَّهُمْ كَرِهُوا۟ مَآ أَنزَلَ ٱللَّهُ فَأَحْبَطَ أَعْمَٰلَهُمْ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdlv{أَفَلَمْ يَسِيرُوا۟ فِى ٱلْأَرْضِ فَيَنظُرُوا۟ كَيْفَ كَانَ عَٰقِبَةُ ٱلَّذِينَ مِن قَبْلِهِمْ دَمَّرَ ٱللَّهُ عَلَيْهِمْ وَلِلْكَٰفِرِينَ أَمْثَٰلُهَا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdlvi{ذَٰلِكَ بِأَنَّ ٱللَّهَ مَوْلَى ٱلَّذِينَ ءَامَنُوا۟ وَأَنَّ ٱلْكَٰفِرِينَ لَا مَوْلَىٰ لَهُمْ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdlvii{إِنَّ ٱللَّهَ يُدْخِلُ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ وَٱلَّذِينَ كَفَرُوا۟ يَتَمَتَّعُونَ وَيَأْكُلُونَ كَمَا تَأْكُلُ ٱلْأَنْعَٰمُ وَٱلنَّارُ مَثْوًى لَّهُمْ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdlviii{وَكَأَيِّن مِّن قَرْيَةٍ هِىَ أَشَدُّ قُوَّةً مِّن قَرْيَتِكَ ٱلَّتِىٓ أَخْرَجَتْكَ أَهْلَكْنَٰهُمْ فَلَا نَاصِرَ لَهُمْ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdlix{أَفَمَن كَانَ عَلَىٰ بَيِّنَةٍ مِّن رَّبِّهِۦ كَمَن زُيِّنَ لَهُۥ سُوٓءُ عَمَلِهِۦ وَٱتَّبَعُوٓا۟ أَهْوَآءَهُم\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdlx{مَّثَلُ ٱلْجَنَّةِ ٱلَّتِى وُعِدَ ٱلْمُتَّقُونَ فِيهَآ أَنْهَٰرٌ مِّن مَّآءٍ غَيْرِ ءَاسِنٍ وَأَنْهَٰرٌ مِّن لَّبَنٍ لَّمْ يَتَغَيَّرْ طَعْمُهُۥ وَأَنْهَٰرٌ مِّنْ خَمْرٍ لَّذَّةٍ لِّلشَّٰرِبِينَ وَأَنْهَٰرٌ مِّنْ عَسَلٍ مُّصَفًّى وَلَهُمْ فِيهَا مِن كُلِّ ٱلثَّمَرَٰتِ وَمَغْفِرَةٌ مِّن رَّبِّهِمْ كَمَنْ هُوَ خَٰلِدٌ فِى ٱلنَّارِ وَسُقُوا۟ مَآءً حَمِيمًا فَقَطَّعَ أَمْعَآءَهُمْ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdlxi{وَمِنْهُم مَّن يَسْتَمِعُ إِلَيْكَ حَتَّىٰٓ إِذَا خَرَجُوا۟ مِنْ عِندِكَ قَالُوا۟ لِلَّذِينَ أُوتُوا۟ ٱلْعِلْمَ مَاذَا قَالَ ءَانِفًا أُو۟لَٰٓئِكَ ٱلَّذِينَ طَبَعَ ٱللَّهُ عَلَىٰ قُلُوبِهِمْ وَٱتَّبَعُوٓا۟ أَهْوَآءَهُمْ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdlxii{وَٱلَّذِينَ ٱهْتَدَوْا۟ زَادَهُمْ هُدًى وَءَاتَىٰهُمْ تَقْوَىٰهُمْ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdlxiii{فَهَلْ يَنظُرُونَ إِلَّا ٱلسَّاعَةَ أَن تَأْتِيَهُم بَغْتَةً فَقَدْ جَآءَ أَشْرَاطُهَا فَأَنَّىٰ لَهُمْ إِذَا جَآءَتْهُمْ ذِكْرَىٰهُمْ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdlxiv{فَٱعْلَمْ أَنَّهُۥ لَآ إِلَٰهَ إِلَّا ٱللَّهُ وَٱسْتَغْفِرْ لِذَنۢبِكَ وَلِلْمُؤْمِنِينَ وَٱلْمُؤْمِنَٰتِ وَٱللَّهُ يَعْلَمُ مُتَقَلَّبَكُمْ وَمَثْوَىٰكُمْ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdlxv{وَيَقُولُ ٱلَّذِينَ ءَامَنُوا۟ لَوْلَا نُزِّلَتْ سُورَةٌ فَإِذَآ أُنزِلَتْ سُورَةٌ مُّحْكَمَةٌ وَذُكِرَ فِيهَا ٱلْقِتَالُ رَأَيْتَ ٱلَّذِينَ فِى قُلُوبِهِم مَّرَضٌ يَنظُرُونَ إِلَيْكَ نَظَرَ ٱلْمَغْشِىِّ عَلَيْهِ مِنَ ٱلْمَوْتِ فَأَوْلَىٰ لَهُمْ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdlxvi{طَاعَةٌ وَقَوْلٌ مَّعْرُوفٌ فَإِذَا عَزَمَ ٱلْأَمْرُ فَلَوْ صَدَقُوا۟ ٱللَّهَ لَكَانَ خَيْرًا لَّهُمْ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdlxvii{فَهَلْ عَسَيْتُمْ إِن تَوَلَّيْتُمْ أَن تُفْسِدُوا۟ فِى ٱلْأَرْضِ وَتُقَطِّعُوٓا۟ أَرْحَامَكُمْ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdlxviii{أُو۟لَٰٓئِكَ ٱلَّذِينَ لَعَنَهُمُ ٱللَّهُ فَأَصَمَّهُمْ وَأَعْمَىٰٓ أَبْصَٰرَهُمْ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdlxix{أَفَلَا يَتَدَبَّرُونَ ٱلْقُرْءَانَ أَمْ عَلَىٰ قُلُوبٍ أَقْفَالُهَآ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdlxx{إِنَّ ٱلَّذِينَ ٱرْتَدُّوا۟ عَلَىٰٓ أَدْبَٰرِهِم مِّنۢ بَعْدِ مَا تَبَيَّنَ لَهُمُ ٱلْهُدَى ٱلشَّيْطَٰنُ سَوَّلَ لَهُمْ وَأَمْلَىٰ لَهُمْ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdlxxi{ذَٰلِكَ بِأَنَّهُمْ قَالُوا۟ لِلَّذِينَ كَرِهُوا۟ مَا نَزَّلَ ٱللَّهُ سَنُطِيعُكُمْ فِى بَعْضِ ٱلْأَمْرِ وَٱللَّهُ يَعْلَمُ إِسْرَارَهُمْ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdlxxii{فَكَيْفَ إِذَا تَوَفَّتْهُمُ ٱلْمَلَٰٓئِكَةُ يَضْرِبُونَ وُجُوهَهُمْ وَأَدْبَٰرَهُمْ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdlxxiii{ذَٰلِكَ بِأَنَّهُمُ ٱتَّبَعُوا۟ مَآ أَسْخَطَ ٱللَّهَ وَكَرِهُوا۟ رِضْوَٰنَهُۥ فَأَحْبَطَ أَعْمَٰلَهُمْ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdlxxiv{أَمْ حَسِبَ ٱلَّذِينَ فِى قُلُوبِهِم مَّرَضٌ أَن لَّن يُخْرِجَ ٱللَّهُ أَضْغَٰنَهُمْ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdlxxv{وَلَوْ نَشَآءُ لَأَرَيْنَٰكَهُمْ فَلَعَرَفْتَهُم بِسِيمَٰهُمْ وَلَتَعْرِفَنَّهُمْ فِى لَحْنِ ٱلْقَوْلِ وَٱللَّهُ يَعْلَمُ أَعْمَٰلَكُمْ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdlxxvi{وَلَنَبْلُوَنَّكُمْ حَتَّىٰ نَعْلَمَ ٱلْمُجَٰهِدِينَ مِنكُمْ وَٱلصَّٰبِرِينَ وَنَبْلُوَا۟ أَخْبَارَكُمْ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdlxxvii{إِنَّ ٱلَّذِينَ كَفَرُوا۟ وَصَدُّوا۟ عَن سَبِيلِ ٱللَّهِ وَشَآقُّوا۟ ٱلرَّسُولَ مِنۢ بَعْدِ مَا تَبَيَّنَ لَهُمُ ٱلْهُدَىٰ لَن يَضُرُّوا۟ ٱللَّهَ شَيْـًٔا وَسَيُحْبِطُ أَعْمَٰلَهُمْ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdlxxviii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ أَطِيعُوا۟ ٱللَّهَ وَأَطِيعُوا۟ ٱلرَّسُولَ وَلَا تُبْطِلُوٓا۟ أَعْمَٰلَكُمْ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdlxxix{إِنَّ ٱلَّذِينَ كَفَرُوا۟ وَصَدُّوا۟ عَن سَبِيلِ ٱللَّهِ ثُمَّ مَاتُوا۟ وَهُمْ كُفَّارٌ فَلَن يَغْفِرَ ٱللَّهُ لَهُمْ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdlxxx{فَلَا تَهِنُوا۟ وَتَدْعُوٓا۟ إِلَى ٱلسَّلْمِ وَأَنتُمُ ٱلْأَعْلَوْنَ وَٱللَّهُ مَعَكُمْ وَلَن يَتِرَكُمْ أَعْمَٰلَكُمْ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdlxxxi{إِنَّمَا ٱلْحَيَوٰةُ ٱلدُّنْيَا لَعِبٌ وَلَهْوٌ وَإِن تُؤْمِنُوا۟ وَتَتَّقُوا۟ يُؤْتِكُمْ أُجُورَكُمْ وَلَا يَسْـَٔلْكُمْ أَمْوَٰلَكُمْ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdlxxxii{إِن يَسْـَٔلْكُمُوهَا فَيُحْفِكُمْ تَبْخَلُوا۟ وَيُخْرِجْ أَضْغَٰنَكُمْ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdlxxxiii{هَٰٓأَنتُمْ هَٰٓؤُلَآءِ تُدْعَوْنَ لِتُنفِقُوا۟ فِى سَبِيلِ ٱللَّهِ فَمِنكُم مَّن يَبْخَلُ وَمَن يَبْخَلْ فَإِنَّمَا يَبْخَلُ عَن نَّفْسِهِۦ وَٱللَّهُ ٱلْغَنِىُّ وَأَنتُمُ ٱلْفُقَرَآءُ وَإِن تَتَوَلَّوْا۟ يَسْتَبْدِلْ قَوْمًا غَيْرَكُمْ ثُمَّ لَا يَكُونُوٓا۟ أَمْثَٰلَكُم\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdlxxxiv{\basmalah إِنَّا فَتَحْنَا لَكَ فَتْحًا مُّبِينًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdlxxxv{لِّيَغْفِرَ لَكَ ٱللَّهُ مَا تَقَدَّمَ مِن ذَنۢبِكَ وَمَا تَأَخَّرَ وَيُتِمَّ نِعْمَتَهُۥ عَلَيْكَ وَيَهْدِيَكَ صِرَٰطًا مُّسْتَقِيمًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdlxxxvi{وَيَنصُرَكَ ٱللَّهُ نَصْرًا عَزِيزًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdlxxxvii{هُوَ ٱلَّذِىٓ أَنزَلَ ٱلسَّكِينَةَ فِى قُلُوبِ ٱلْمُؤْمِنِينَ لِيَزْدَادُوٓا۟ إِيمَٰنًا مَّعَ إِيمَٰنِهِمْ وَلِلَّهِ جُنُودُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَكَانَ ٱللَّهُ عَلِيمًا حَكِيمًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdlxxxviii{لِّيُدْخِلَ ٱلْمُؤْمِنِينَ وَٱلْمُؤْمِنَٰتِ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا وَيُكَفِّرَ عَنْهُمْ سَيِّـَٔاتِهِمْ وَكَانَ ذَٰلِكَ عِندَ ٱللَّهِ فَوْزًا عَظِيمًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdlxxxix{وَيُعَذِّبَ ٱلْمُنَٰفِقِينَ وَٱلْمُنَٰفِقَٰتِ وَٱلْمُشْرِكِينَ وَٱلْمُشْرِكَٰتِ ٱلظَّآنِّينَ بِٱللَّهِ ظَنَّ ٱلسَّوْءِ عَلَيْهِمْ دَآئِرَةُ ٱلسَّوْءِ وَغَضِبَ ٱللَّهُ عَلَيْهِمْ وَلَعَنَهُمْ وَأَعَدَّ لَهُمْ جَهَنَّمَ وَسَآءَتْ مَصِيرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdxc{وَلِلَّهِ جُنُودُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَكَانَ ٱللَّهُ عَزِيزًا حَكِيمًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdxci{إِنَّآ أَرْسَلْنَٰكَ شَٰهِدًا وَمُبَشِّرًا وَنَذِيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdxcii{لِّتُؤْمِنُوا۟ بِٱللَّهِ وَرَسُولِهِۦ وَتُعَزِّرُوهُ وَتُوَقِّرُوهُ وَتُسَبِّحُوهُ بُكْرَةً وَأَصِيلًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdxciii{إِنَّ ٱلَّذِينَ يُبَايِعُونَكَ إِنَّمَا يُبَايِعُونَ ٱللَّهَ يَدُ ٱللَّهِ فَوْقَ أَيْدِيهِمْ فَمَن نَّكَثَ فَإِنَّمَا يَنكُثُ عَلَىٰ نَفْسِهِۦ وَمَنْ أَوْفَىٰ بِمَا عَٰهَدَ عَلَيْهُ ٱللَّهَ فَسَيُؤْتِيهِ أَجْرًا عَظِيمًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdxciv{سَيَقُولُ لَكَ ٱلْمُخَلَّفُونَ مِنَ ٱلْأَعْرَابِ شَغَلَتْنَآ أَمْوَٰلُنَا وَأَهْلُونَا فَٱسْتَغْفِرْ لَنَا يَقُولُونَ بِأَلْسِنَتِهِم مَّا لَيْسَ فِى قُلُوبِهِمْ قُلْ فَمَن يَمْلِكُ لَكُم مِّنَ ٱللَّهِ شَيْـًٔا إِنْ أَرَادَ بِكُمْ ضَرًّا أَوْ أَرَادَ بِكُمْ نَفْعًۢا بَلْ كَانَ ٱللَّهُ بِمَا تَعْمَلُونَ خَبِيرًۢا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdxcv{بَلْ ظَنَنتُمْ أَن لَّن يَنقَلِبَ ٱلرَّسُولُ وَٱلْمُؤْمِنُونَ إِلَىٰٓ أَهْلِيهِمْ أَبَدًا وَزُيِّنَ ذَٰلِكَ فِى قُلُوبِكُمْ وَظَنَنتُمْ ظَنَّ ٱلسَّوْءِ وَكُنتُمْ قَوْمًۢا بُورًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdxcvi{وَمَن لَّمْ يُؤْمِنۢ بِٱللَّهِ وَرَسُولِهِۦ فَإِنَّآ أَعْتَدْنَا لِلْكَٰفِرِينَ سَعِيرًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdxcvii{وَلِلَّهِ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ يَغْفِرُ لِمَن يَشَآءُ وَيُعَذِّبُ مَن يَشَآءُ وَكَانَ ٱللَّهُ غَفُورًا رَّحِيمًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdxcviii{سَيَقُولُ ٱلْمُخَلَّفُونَ إِذَا ٱنطَلَقْتُمْ إِلَىٰ مَغَانِمَ لِتَأْخُذُوهَا ذَرُونَا نَتَّبِعْكُمْ يُرِيدُونَ أَن يُبَدِّلُوا۟ كَلَٰمَ ٱللَّهِ قُل لَّن تَتَّبِعُونَا كَذَٰلِكُمْ قَالَ ٱللَّهُ مِن قَبْلُ فَسَيَقُولُونَ بَلْ تَحْسُدُونَنَا بَلْ كَانُوا۟ لَا يَفْقَهُونَ إِلَّا قَلِيلًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdxcix{قُل لِّلْمُخَلَّفِينَ مِنَ ٱلْأَعْرَابِ سَتُدْعَوْنَ إِلَىٰ قَوْمٍ أُو۟لِى بَأْسٍ شَدِيدٍ تُقَٰتِلُونَهُمْ أَوْ يُسْلِمُونَ فَإِن تُطِيعُوا۟ يُؤْتِكُمُ ٱللَّهُ أَجْرًا حَسَنًا وَإِن تَتَوَلَّوْا۟ كَمَا تَوَلَّيْتُم مِّن قَبْلُ يُعَذِّبْكُمْ عَذَابًا أَلِيمًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdc{لَّيْسَ عَلَى ٱلْأَعْمَىٰ حَرَجٌ وَلَا عَلَى ٱلْأَعْرَجِ حَرَجٌ وَلَا عَلَى ٱلْمَرِيضِ حَرَجٌ وَمَن يُطِعِ ٱللَّهَ وَرَسُولَهُۥ يُدْخِلْهُ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ وَمَن يَتَوَلَّ يُعَذِّبْهُ عَذَابًا أَلِيمًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdci{لَّقَدْ رَضِىَ ٱللَّهُ عَنِ ٱلْمُؤْمِنِينَ إِذْ يُبَايِعُونَكَ تَحْتَ ٱلشَّجَرَةِ فَعَلِمَ مَا فِى قُلُوبِهِمْ فَأَنزَلَ ٱلسَّكِينَةَ عَلَيْهِمْ وَأَثَٰبَهُمْ فَتْحًا قَرِيبًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcii{وَمَغَانِمَ كَثِيرَةً يَأْخُذُونَهَا وَكَانَ ٱللَّهُ عَزِيزًا حَكِيمًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdciii{وَعَدَكُمُ ٱللَّهُ مَغَانِمَ كَثِيرَةً تَأْخُذُونَهَا فَعَجَّلَ لَكُمْ هَٰذِهِۦ وَكَفَّ أَيْدِىَ ٱلنَّاسِ عَنكُمْ وَلِتَكُونَ ءَايَةً لِّلْمُؤْمِنِينَ وَيَهْدِيَكُمْ صِرَٰطًا مُّسْتَقِيمًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdciv{وَأُخْرَىٰ لَمْ تَقْدِرُوا۟ عَلَيْهَا قَدْ أَحَاطَ ٱللَّهُ بِهَا وَكَانَ ٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcv{وَلَوْ قَٰتَلَكُمُ ٱلَّذِينَ كَفَرُوا۟ لَوَلَّوُا۟ ٱلْأَدْبَٰرَ ثُمَّ لَا يَجِدُونَ وَلِيًّا وَلَا نَصِيرًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcvi{سُنَّةَ ٱللَّهِ ٱلَّتِى قَدْ خَلَتْ مِن قَبْلُ وَلَن تَجِدَ لِسُنَّةِ ٱللَّهِ تَبْدِيلًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcvii{وَهُوَ ٱلَّذِى كَفَّ أَيْدِيَهُمْ عَنكُمْ وَأَيْدِيَكُمْ عَنْهُم بِبَطْنِ مَكَّةَ مِنۢ بَعْدِ أَنْ أَظْفَرَكُمْ عَلَيْهِمْ وَكَانَ ٱللَّهُ بِمَا تَعْمَلُونَ بَصِيرًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcviii{هُمُ ٱلَّذِينَ كَفَرُوا۟ وَصَدُّوكُمْ عَنِ ٱلْمَسْجِدِ ٱلْحَرَامِ وَٱلْهَدْىَ مَعْكُوفًا أَن يَبْلُغَ مَحِلَّهُۥ وَلَوْلَا رِجَالٌ مُّؤْمِنُونَ وَنِسَآءٌ مُّؤْمِنَٰتٌ لَّمْ تَعْلَمُوهُمْ أَن تَطَـُٔوهُمْ فَتُصِيبَكُم مِّنْهُم مَّعَرَّةٌۢ بِغَيْرِ عِلْمٍ لِّيُدْخِلَ ٱللَّهُ فِى رَحْمَتِهِۦ مَن يَشَآءُ لَوْ تَزَيَّلُوا۟ لَعَذَّبْنَا ٱلَّذِينَ كَفَرُوا۟ مِنْهُمْ عَذَابًا أَلِيمًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcix{إِذْ جَعَلَ ٱلَّذِينَ كَفَرُوا۟ فِى قُلُوبِهِمُ ٱلْحَمِيَّةَ حَمِيَّةَ ٱلْجَٰهِلِيَّةِ فَأَنزَلَ ٱللَّهُ سَكِينَتَهُۥ عَلَىٰ رَسُولِهِۦ وَعَلَى ٱلْمُؤْمِنِينَ وَأَلْزَمَهُمْ كَلِمَةَ ٱلتَّقْوَىٰ وَكَانُوٓا۟ أَحَقَّ بِهَا وَأَهْلَهَا وَكَانَ ٱللَّهُ بِكُلِّ شَىْءٍ عَلِيمًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdcx{لَّقَدْ صَدَقَ ٱللَّهُ رَسُولَهُ ٱلرُّءْيَا بِٱلْحَقِّ لَتَدْخُلُنَّ ٱلْمَسْجِدَ ٱلْحَرَامَ إِن شَآءَ ٱللَّهُ ءَامِنِينَ مُحَلِّقِينَ رُءُوسَكُمْ وَمُقَصِّرِينَ لَا تَخَافُونَ فَعَلِمَ مَا لَمْ تَعْلَمُوا۟ فَجَعَلَ مِن دُونِ ذَٰلِكَ فَتْحًا قَرِيبًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcxi{هُوَ ٱلَّذِىٓ أَرْسَلَ رَسُولَهُۥ بِٱلْهُدَىٰ وَدِينِ ٱلْحَقِّ لِيُظْهِرَهُۥ عَلَى ٱلدِّينِ كُلِّهِۦ وَكَفَىٰ بِٱللَّهِ شَهِيدًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcxii{مُّحَمَّدٌ رَّسُولُ ٱللَّهِ وَٱلَّذِينَ مَعَهُۥٓ أَشِدَّآءُ عَلَى ٱلْكُفَّارِ رُحَمَآءُ بَيْنَهُمْ تَرَىٰهُمْ رُكَّعًا سُجَّدًا يَبْتَغُونَ فَضْلًا مِّنَ ٱللَّهِ وَرِضْوَٰنًا سِيمَاهُمْ فِى وُجُوهِهِم مِّنْ أَثَرِ ٱلسُّجُودِ ذَٰلِكَ مَثَلُهُمْ فِى ٱلتَّوْرَىٰةِ وَمَثَلُهُمْ فِى ٱلْإِنجِيلِ كَزَرْعٍ أَخْرَجَ شَطْـَٔهُۥ فَـَٔازَرَهُۥ فَٱسْتَغْلَظَ فَٱسْتَوَىٰ عَلَىٰ سُوقِهِۦ يُعْجِبُ ٱلزُّرَّاعَ لِيَغِيظَ بِهِمُ ٱلْكُفَّارَ وَعَدَ ٱللَّهُ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ مِنْهُم مَّغْفِرَةً وَأَجْرًا عَظِيمًۢا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdcxiii{\basmalah يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تُقَدِّمُوا۟ بَيْنَ يَدَىِ ٱللَّهِ وَرَسُولِهِۦ وَٱتَّقُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ سَمِيعٌ عَلِيمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcxiv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَرْفَعُوٓا۟ أَصْوَٰتَكُمْ فَوْقَ صَوْتِ ٱلنَّبِىِّ وَلَا تَجْهَرُوا۟ لَهُۥ بِٱلْقَوْلِ كَجَهْرِ بَعْضِكُمْ لِبَعْضٍ أَن تَحْبَطَ أَعْمَٰلُكُمْ وَأَنتُمْ لَا تَشْعُرُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcxv{إِنَّ ٱلَّذِينَ يَغُضُّونَ أَصْوَٰتَهُمْ عِندَ رَسُولِ ٱللَّهِ أُو۟لَٰٓئِكَ ٱلَّذِينَ ٱمْتَحَنَ ٱللَّهُ قُلُوبَهُمْ لِلتَّقْوَىٰ لَهُم مَّغْفِرَةٌ وَأَجْرٌ عَظِيمٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcxvi{إِنَّ ٱلَّذِينَ يُنَادُونَكَ مِن وَرَآءِ ٱلْحُجُرَٰتِ أَكْثَرُهُمْ لَا يَعْقِلُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcxvii{وَلَوْ أَنَّهُمْ صَبَرُوا۟ حَتَّىٰ تَخْرُجَ إِلَيْهِمْ لَكَانَ خَيْرًا لَّهُمْ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdcxviii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِن جَآءَكُمْ فَاسِقٌۢ بِنَبَإٍ فَتَبَيَّنُوٓا۟ أَن تُصِيبُوا۟ قَوْمًۢا بِجَهَٰلَةٍ فَتُصْبِحُوا۟ عَلَىٰ مَا فَعَلْتُمْ نَٰدِمِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdcxix{وَٱعْلَمُوٓا۟ أَنَّ فِيكُمْ رَسُولَ ٱللَّهِ لَوْ يُطِيعُكُمْ فِى كَثِيرٍ مِّنَ ٱلْأَمْرِ لَعَنِتُّمْ وَلَٰكِنَّ ٱللَّهَ حَبَّبَ إِلَيْكُمُ ٱلْإِيمَٰنَ وَزَيَّنَهُۥ فِى قُلُوبِكُمْ وَكَرَّهَ إِلَيْكُمُ ٱلْكُفْرَ وَٱلْفُسُوقَ وَٱلْعِصْيَانَ أُو۟لَٰٓئِكَ هُمُ ٱلرَّٰشِدُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdcxx{فَضْلًا مِّنَ ٱللَّهِ وَنِعْمَةً وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdcxxi{وَإِن طَآئِفَتَانِ مِنَ ٱلْمُؤْمِنِينَ ٱقْتَتَلُوا۟ فَأَصْلِحُوا۟ بَيْنَهُمَا فَإِنۢ بَغَتْ إِحْدَىٰهُمَا عَلَى ٱلْأُخْرَىٰ فَقَٰتِلُوا۟ ٱلَّتِى تَبْغِى حَتَّىٰ تَفِىٓءَ إِلَىٰٓ أَمْرِ ٱللَّهِ فَإِن فَآءَتْ فَأَصْلِحُوا۟ بَيْنَهُمَا بِٱلْعَدْلِ وَأَقْسِطُوٓا۟ إِنَّ ٱللَّهَ يُحِبُّ ٱلْمُقْسِطِينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdcxxii{إِنَّمَا ٱلْمُؤْمِنُونَ إِخْوَةٌ فَأَصْلِحُوا۟ بَيْنَ أَخَوَيْكُمْ وَٱتَّقُوا۟ ٱللَّهَ لَعَلَّكُمْ تُرْحَمُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdcxxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا يَسْخَرْ قَوْمٌ مِّن قَوْمٍ عَسَىٰٓ أَن يَكُونُوا۟ خَيْرًا مِّنْهُمْ وَلَا نِسَآءٌ مِّن نِّسَآءٍ عَسَىٰٓ أَن يَكُنَّ خَيْرًا مِّنْهُنَّ وَلَا تَلْمِزُوٓا۟ أَنفُسَكُمْ وَلَا تَنَابَزُوا۟ بِٱلْأَلْقَٰبِ بِئْسَ ٱلِٱسْمُ ٱلْفُسُوقُ بَعْدَ ٱلْإِيمَٰنِ وَمَن لَّمْ يَتُبْ فَأُو۟لَٰٓئِكَ هُمُ ٱلظَّٰلِمُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdcxxiv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱجْتَنِبُوا۟ كَثِيرًا مِّنَ ٱلظَّنِّ إِنَّ بَعْضَ ٱلظَّنِّ إِثْمٌ وَلَا تَجَسَّسُوا۟ وَلَا يَغْتَب بَّعْضُكُم بَعْضًا أَيُحِبُّ أَحَدُكُمْ أَن يَأْكُلَ لَحْمَ أَخِيهِ مَيْتًا فَكَرِهْتُمُوهُ وَٱتَّقُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ تَوَّابٌ رَّحِيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdcxxv{يَٰٓأَيُّهَا ٱلنَّاسُ إِنَّا خَلَقْنَٰكُم مِّن ذَكَرٍ وَأُنثَىٰ وَجَعَلْنَٰكُمْ شُعُوبًا وَقَبَآئِلَ لِتَعَارَفُوٓا۟ إِنَّ أَكْرَمَكُمْ عِندَ ٱللَّهِ أَتْقَىٰكُمْ إِنَّ ٱللَّهَ عَلِيمٌ خَبِيرٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdcxxvi{قَالَتِ ٱلْأَعْرَابُ ءَامَنَّا قُل لَّمْ تُؤْمِنُوا۟ وَلَٰكِن قُولُوٓا۟ أَسْلَمْنَا وَلَمَّا يَدْخُلِ ٱلْإِيمَٰنُ فِى قُلُوبِكُمْ وَإِن تُطِيعُوا۟ ٱللَّهَ وَرَسُولَهُۥ لَا يَلِتْكُم مِّنْ أَعْمَٰلِكُمْ شَيْـًٔا إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdcxxvii{إِنَّمَا ٱلْمُؤْمِنُونَ ٱلَّذِينَ ءَامَنُوا۟ بِٱللَّهِ وَرَسُولِهِۦ ثُمَّ لَمْ يَرْتَابُوا۟ وَجَٰهَدُوا۟ بِأَمْوَٰلِهِمْ وَأَنفُسِهِمْ فِى سَبِيلِ ٱللَّهِ أُو۟لَٰٓئِكَ هُمُ ٱلصَّٰدِقُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdcxxviii{قُلْ أَتُعَلِّمُونَ ٱللَّهَ بِدِينِكُمْ وَٱللَّهُ يَعْلَمُ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَٱللَّهُ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcxxix{يَمُنُّونَ عَلَيْكَ أَنْ أَسْلَمُوا۟ قُل لَّا تَمُنُّوا۟ عَلَىَّ إِسْلَٰمَكُم بَلِ ٱللَّهُ يَمُنُّ عَلَيْكُمْ أَنْ هَدَىٰكُمْ لِلْإِيمَٰنِ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcxxx{إِنَّ ٱللَّهَ يَعْلَمُ غَيْبَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱللَّهُ بَصِيرٌۢ بِمَا تَعْمَلُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcxxxi{\basmalah قٓ وَٱلْقُرْءَانِ ٱلْمَجِيدِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcxxxii{بَلْ عَجِبُوٓا۟ أَن جَآءَهُم مُّنذِرٌ مِّنْهُمْ فَقَالَ ٱلْكَٰفِرُونَ هَٰذَا شَىْءٌ عَجِيبٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcxxxiii{أَءِذَا مِتْنَا وَكُنَّا تُرَابًا ذَٰلِكَ رَجْعٌۢ بَعِيدٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcxxxiv{قَدْ عَلِمْنَا مَا تَنقُصُ ٱلْأَرْضُ مِنْهُمْ وَعِندَنَا كِتَٰبٌ حَفِيظٌۢ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcxxxv{بَلْ كَذَّبُوا۟ بِٱلْحَقِّ لَمَّا جَآءَهُمْ فَهُمْ فِىٓ أَمْرٍ مَّرِيجٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdcxxxvi{أَفَلَمْ يَنظُرُوٓا۟ إِلَى ٱلسَّمَآءِ فَوْقَهُمْ كَيْفَ بَنَيْنَٰهَا وَزَيَّنَّٰهَا وَمَا لَهَا مِن فُرُوجٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdcxxxvii{وَٱلْأَرْضَ مَدَدْنَٰهَا وَأَلْقَيْنَا فِيهَا رَوَٰسِىَ وَأَنۢبَتْنَا فِيهَا مِن كُلِّ زَوْجٍۭ بَهِيجٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdcxxxviii{تَبْصِرَةً وَذِكْرَىٰ لِكُلِّ عَبْدٍ مُّنِيبٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdcxxxix{وَنَزَّلْنَا مِنَ ٱلسَّمَآءِ مَآءً مُّبَٰرَكًا فَأَنۢبَتْنَا بِهِۦ جَنَّٰتٍ وَحَبَّ ٱلْحَصِيدِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdcxl{وَٱلنَّخْلَ بَاسِقَٰتٍ لَّهَا طَلْعٌ نَّضِيدٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdcxli{رِّزْقًا لِّلْعِبَادِ وَأَحْيَيْنَا بِهِۦ بَلْدَةً مَّيْتًا كَذَٰلِكَ ٱلْخُرُوجُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdcxlii{كَذَّبَتْ قَبْلَهُمْ قَوْمُ نُوحٍ وَأَصْحَٰبُ ٱلرَّسِّ وَثَمُودُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdcxliii{وَعَادٌ وَفِرْعَوْنُ وَإِخْوَٰنُ لُوطٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdcxliv{وَأَصْحَٰبُ ٱلْأَيْكَةِ وَقَوْمُ تُبَّعٍ كُلٌّ كَذَّبَ ٱلرُّسُلَ فَحَقَّ وَعِيدِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdcxlv{أَفَعَيِينَا بِٱلْخَلْقِ ٱلْأَوَّلِ بَلْ هُمْ فِى لَبْسٍ مِّنْ خَلْقٍ جَدِيدٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdcxlvi{وَلَقَدْ خَلَقْنَا ٱلْإِنسَٰنَ وَنَعْلَمُ مَا تُوَسْوِسُ بِهِۦ نَفْسُهُۥ وَنَحْنُ أَقْرَبُ إِلَيْهِ مِنْ حَبْلِ ٱلْوَرِيدِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcxlvii{إِذْ يَتَلَقَّى ٱلْمُتَلَقِّيَانِ عَنِ ٱلْيَمِينِ وَعَنِ ٱلشِّمَالِ قَعِيدٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcxlviii{مَّا يَلْفِظُ مِن قَوْلٍ إِلَّا لَدَيْهِ رَقِيبٌ عَتِيدٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcxlix{وَجَآءَتْ سَكْرَةُ ٱلْمَوْتِ بِٱلْحَقِّ ذَٰلِكَ مَا كُنتَ مِنْهُ تَحِيدُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdcl{وَنُفِخَ فِى ٱلصُّورِ ذَٰلِكَ يَوْمُ ٱلْوَعِيدِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcli{وَجَآءَتْ كُلُّ نَفْسٍ مَّعَهَا سَآئِقٌ وَشَهِيدٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdclii{لَّقَدْ كُنتَ فِى غَفْلَةٍ مِّنْ هَٰذَا فَكَشَفْنَا عَنكَ غِطَآءَكَ فَبَصَرُكَ ٱلْيَوْمَ حَدِيدٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcliii{وَقَالَ قَرِينُهُۥ هَٰذَا مَا لَدَىَّ عَتِيدٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcliv{أَلْقِيَا فِى جَهَنَّمَ كُلَّ كَفَّارٍ عَنِيدٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdclv{مَّنَّاعٍ لِّلْخَيْرِ مُعْتَدٍ مُّرِيبٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdclvi{ٱلَّذِى جَعَلَ مَعَ ٱللَّهِ إِلَٰهًا ءَاخَرَ فَأَلْقِيَاهُ فِى ٱلْعَذَابِ ٱلشَّدِيدِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdclvii{قَالَ قَرِينُهُۥ رَبَّنَا مَآ أَطْغَيْتُهُۥ وَلَٰكِن كَانَ فِى ضَلَٰلٍۭ بَعِيدٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdclviii{قَالَ لَا تَخْتَصِمُوا۟ لَدَىَّ وَقَدْ قَدَّمْتُ إِلَيْكُم بِٱلْوَعِيدِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdclix{مَا يُبَدَّلُ ٱلْقَوْلُ لَدَىَّ وَمَآ أَنَا۠ بِظَلَّٰمٍ لِّلْعَبِيدِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdclx{يَوْمَ نَقُولُ لِجَهَنَّمَ هَلِ ٱمْتَلَأْتِ وَتَقُولُ هَلْ مِن مَّزِيدٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdclxi{وَأُزْلِفَتِ ٱلْجَنَّةُ لِلْمُتَّقِينَ غَيْرَ بَعِيدٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdclxii{هَٰذَا مَا تُوعَدُونَ لِكُلِّ أَوَّابٍ حَفِيظٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdclxiii{مَّنْ خَشِىَ ٱلرَّحْمَٰنَ بِٱلْغَيْبِ وَجَآءَ بِقَلْبٍ مُّنِيبٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdclxiv{ٱدْخُلُوهَا بِسَلَٰمٍ ذَٰلِكَ يَوْمُ ٱلْخُلُودِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdclxv{لَهُم مَّا يَشَآءُونَ فِيهَا وَلَدَيْنَا مَزِيدٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdclxvi{وَكَمْ أَهْلَكْنَا قَبْلَهُم مِّن قَرْنٍ هُمْ أَشَدُّ مِنْهُم بَطْشًا فَنَقَّبُوا۟ فِى ٱلْبِلَٰدِ هَلْ مِن مَّحِيصٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdclxvii{إِنَّ فِى ذَٰلِكَ لَذِكْرَىٰ لِمَن كَانَ لَهُۥ قَلْبٌ أَوْ أَلْقَى ٱلسَّمْعَ وَهُوَ شَهِيدٌ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdclxviii{وَلَقَدْ خَلَقْنَا ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ وَمَا بَيْنَهُمَا فِى سِتَّةِ أَيَّامٍ وَمَا مَسَّنَا مِن لُّغُوبٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdclxix{فَٱصْبِرْ عَلَىٰ مَا يَقُولُونَ وَسَبِّحْ بِحَمْدِ رَبِّكَ قَبْلَ طُلُوعِ ٱلشَّمْسِ وَقَبْلَ ٱلْغُرُوبِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdclxx{وَمِنَ ٱلَّيْلِ فَسَبِّحْهُ وَأَدْبَٰرَ ٱلسُّجُودِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdclxxi{وَٱسْتَمِعْ يَوْمَ يُنَادِ ٱلْمُنَادِ مِن مَّكَانٍ قَرِيبٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdclxxii{يَوْمَ يَسْمَعُونَ ٱلصَّيْحَةَ بِٱلْحَقِّ ذَٰلِكَ يَوْمُ ٱلْخُرُوجِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdclxxiii{إِنَّا نَحْنُ نُحْىِۦ وَنُمِيتُ وَإِلَيْنَا ٱلْمَصِيرُ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdclxxiv{يَوْمَ تَشَقَّقُ ٱلْأَرْضُ عَنْهُمْ سِرَاعًا ذَٰلِكَ حَشْرٌ عَلَيْنَا يَسِيرٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdclxxv{نَّحْنُ أَعْلَمُ بِمَا يَقُولُونَ وَمَآ أَنتَ عَلَيْهِم بِجَبَّارٍ فَذَكِّرْ بِٱلْقُرْءَانِ مَن يَخَافُ وَعِيدِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdclxxvi{\basmalah وَٱلذَّٰرِيَٰتِ ذَرْوًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdclxxvii{فَٱلْحَٰمِلَٰتِ وِقْرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdclxxviii{فَٱلْجَٰرِيَٰتِ يُسْرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdclxxix{فَٱلْمُقَسِّمَٰتِ أَمْرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdclxxx{إِنَّمَا تُوعَدُونَ لَصَادِقٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdclxxxi{وَإِنَّ ٱلدِّينَ لَوَٰقِعٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdclxxxii{وَٱلسَّمَآءِ ذَاتِ ٱلْحُبُكِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdclxxxiii{إِنَّكُمْ لَفِى قَوْلٍ مُّخْتَلِفٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdclxxxiv{يُؤْفَكُ عَنْهُ مَنْ أُفِكَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdclxxxv{قُتِلَ ٱلْخَرَّٰصُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdclxxxvi{ٱلَّذِينَ هُمْ فِى غَمْرَةٍ سَاهُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdclxxxvii{يَسْـَٔلُونَ أَيَّانَ يَوْمُ ٱلدِّينِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdclxxxviii{يَوْمَ هُمْ عَلَى ٱلنَّارِ يُفْتَنُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdclxxxix{ذُوقُوا۟ فِتْنَتَكُمْ هَٰذَا ٱلَّذِى كُنتُم بِهِۦ تَسْتَعْجِلُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdcxc{إِنَّ ٱلْمُتَّقِينَ فِى جَنَّٰتٍ وَعُيُونٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdcxci{ءَاخِذِينَ مَآ ءَاتَىٰهُمْ رَبُّهُمْ إِنَّهُمْ كَانُوا۟ قَبْلَ ذَٰلِكَ مُحْسِنِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcxcii{كَانُوا۟ قَلِيلًا مِّنَ ٱلَّيْلِ مَا يَهْجَعُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcxciii{وَبِٱلْأَسْحَارِ هُمْ يَسْتَغْفِرُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcxciv{وَفِىٓ أَمْوَٰلِهِمْ حَقٌّ لِّلسَّآئِلِ وَٱلْمَحْرُومِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdcxcv{وَفِى ٱلْأَرْضِ ءَايَٰتٌ لِّلْمُوقِنِينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcxcvi{وَفِىٓ أَنفُسِكُمْ أَفَلَا تُبْصِرُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcxcvii{وَفِى ٱلسَّمَآءِ رِزْقُكُمْ وَمَا تُوعَدُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcxcviii{فَوَرَبِّ ٱلسَّمَآءِ وَٱلْأَرْضِ إِنَّهُۥ لَحَقٌّ مِّثْلَ مَآ أَنَّكُمْ تَنطِقُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcxcix{هَلْ أَتَىٰكَ حَدِيثُ ضَيْفِ إِبْرَٰهِيمَ ٱلْمُكْرَمِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcc{إِذْ دَخَلُوا۟ عَلَيْهِ فَقَالُوا۟ سَلَٰمًا قَالَ سَلَٰمٌ قَوْمٌ مُّنكَرُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcci{فَرَاغَ إِلَىٰٓ أَهْلِهِۦ فَجَآءَ بِعِجْلٍ سَمِينٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdccii{فَقَرَّبَهُۥٓ إِلَيْهِمْ قَالَ أَلَا تَأْكُلُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcciii{فَأَوْجَسَ مِنْهُمْ خِيفَةً قَالُوا۟ لَا تَخَفْ وَبَشَّرُوهُ بِغُلَٰمٍ عَلِيمٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcciv{فَأَقْبَلَتِ ٱمْرَأَتُهُۥ فِى صَرَّةٍ فَصَكَّتْ وَجْهَهَا وَقَالَتْ عَجُوزٌ عَقِيمٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdccv{قَالُوا۟ كَذَٰلِكِ قَالَ رَبُّكِ إِنَّهُۥ هُوَ ٱلْحَكِيمُ ٱلْعَلِيمُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdccvi{قَالَ فَمَا خَطْبُكُمْ أَيُّهَا ٱلْمُرْسَلُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdccvii{قَالُوٓا۟ إِنَّآ أُرْسِلْنَآ إِلَىٰ قَوْمٍ مُّجْرِمِينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdccviii{لِنُرْسِلَ عَلَيْهِمْ حِجَارَةً مِّن طِينٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdccix{مُّسَوَّمَةً عِندَ رَبِّكَ لِلْمُسْرِفِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdccx{فَأَخْرَجْنَا مَن كَانَ فِيهَا مِنَ ٱلْمُؤْمِنِينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdccxi{فَمَا وَجَدْنَا فِيهَا غَيْرَ بَيْتٍ مِّنَ ٱلْمُسْلِمِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdccxii{وَتَرَكْنَا فِيهَآ ءَايَةً لِّلَّذِينَ يَخَافُونَ ٱلْعَذَابَ ٱلْأَلِيمَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdccxiii{وَفِى مُوسَىٰٓ إِذْ أَرْسَلْنَٰهُ إِلَىٰ فِرْعَوْنَ بِسُلْطَٰنٍ مُّبِينٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdccxiv{فَتَوَلَّىٰ بِرُكْنِهِۦ وَقَالَ سَٰحِرٌ أَوْ مَجْنُونٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdccxv{فَأَخَذْنَٰهُ وَجُنُودَهُۥ فَنَبَذْنَٰهُمْ فِى ٱلْيَمِّ وَهُوَ مُلِيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdccxvi{وَفِى عَادٍ إِذْ أَرْسَلْنَا عَلَيْهِمُ ٱلرِّيحَ ٱلْعَقِيمَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdccxvii{مَا تَذَرُ مِن شَىْءٍ أَتَتْ عَلَيْهِ إِلَّا جَعَلَتْهُ كَٱلرَّمِيمِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdccxviii{وَفِى ثَمُودَ إِذْ قِيلَ لَهُمْ تَمَتَّعُوا۟ حَتَّىٰ حِينٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdccxix{فَعَتَوْا۟ عَنْ أَمْرِ رَبِّهِمْ فَأَخَذَتْهُمُ ٱلصَّٰعِقَةُ وَهُمْ يَنظُرُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdccxx{فَمَا ٱسْتَطَٰعُوا۟ مِن قِيَامٍ وَمَا كَانُوا۟ مُنتَصِرِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdccxxi{وَقَوْمَ نُوحٍ مِّن قَبْلُ إِنَّهُمْ كَانُوا۟ قَوْمًا فَٰسِقِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdccxxii{وَٱلسَّمَآءَ بَنَيْنَٰهَا بِأَيْي۟دٍ وَإِنَّا لَمُوسِعُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdccxxiii{وَٱلْأَرْضَ فَرَشْنَٰهَا فَنِعْمَ ٱلْمَٰهِدُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdccxxiv{وَمِن كُلِّ شَىْءٍ خَلَقْنَا زَوْجَيْنِ لَعَلَّكُمْ تَذَكَّرُونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdccxxv{فَفِرُّوٓا۟ إِلَى ٱللَّهِ إِنِّى لَكُم مِّنْهُ نَذِيرٌ مُّبِينٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmdccxxvi{وَلَا تَجْعَلُوا۟ مَعَ ٱللَّهِ إِلَٰهًا ءَاخَرَ إِنِّى لَكُم مِّنْهُ نَذِيرٌ مُّبِينٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmdccxxvii{كَذَٰلِكَ مَآ أَتَى ٱلَّذِينَ مِن قَبْلِهِم مِّن رَّسُولٍ إِلَّا قَالُوا۟ سَاحِرٌ أَوْ مَجْنُونٌ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmdccxxviii{أَتَوَاصَوْا۟ بِهِۦ بَلْ هُمْ قَوْمٌ طَاغُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmdccxxix{فَتَوَلَّ عَنْهُمْ فَمَآ أَنتَ بِمَلُومٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmdccxxx{وَذَكِّرْ فَإِنَّ ٱلذِّكْرَىٰ تَنفَعُ ٱلْمُؤْمِنِينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmdccxxxi{وَمَا خَلَقْتُ ٱلْجِنَّ وَٱلْإِنسَ إِلَّا لِيَعْبُدُونِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmdccxxxii{مَآ أُرِيدُ مِنْهُم مِّن رِّزْقٍ وَمَآ أُرِيدُ أَن يُطْعِمُونِ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmdccxxxiii{إِنَّ ٱللَّهَ هُوَ ٱلرَّزَّاقُ ذُو ٱلْقُوَّةِ ٱلْمَتِينُ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmdccxxxiv{فَإِنَّ لِلَّذِينَ ظَلَمُوا۟ ذَنُوبًا مِّثْلَ ذَنُوبِ أَصْحَٰبِهِمْ فَلَا يَسْتَعْجِلُونِ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmdccxxxv{فَوَيْلٌ لِّلَّذِينَ كَفَرُوا۟ مِن يَوْمِهِمُ ٱلَّذِى يُوعَدُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmdccxxxvi{\basmalah وَٱلطُّورِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdccxxxvii{وَكِتَٰبٍ مَّسْطُورٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdccxxxviii{فِى رَقٍّ مَّنشُورٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdccxxxix{وَٱلْبَيْتِ ٱلْمَعْمُورِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdccxl{وَٱلسَّقْفِ ٱلْمَرْفُوعِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdccxli{وَٱلْبَحْرِ ٱلْمَسْجُورِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdccxlii{إِنَّ عَذَابَ رَبِّكَ لَوَٰقِعٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdccxliii{مَّا لَهُۥ مِن دَافِعٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdccxliv{يَوْمَ تَمُورُ ٱلسَّمَآءُ مَوْرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdccxlv{وَتَسِيرُ ٱلْجِبَالُ سَيْرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdccxlvi{فَوَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdccxlvii{ٱلَّذِينَ هُمْ فِى خَوْضٍ يَلْعَبُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdccxlviii{يَوْمَ يُدَعُّونَ إِلَىٰ نَارِ جَهَنَّمَ دَعًّا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdccxlix{هَٰذِهِ ٱلنَّارُ ٱلَّتِى كُنتُم بِهَا تُكَذِّبُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdccl{أَفَسِحْرٌ هَٰذَآ أَمْ أَنتُمْ لَا تُبْصِرُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdccli{ٱصْلَوْهَا فَٱصْبِرُوٓا۟ أَوْ لَا تَصْبِرُوا۟ سَوَآءٌ عَلَيْكُمْ إِنَّمَا تُجْزَوْنَ مَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcclii{إِنَّ ٱلْمُتَّقِينَ فِى جَنَّٰتٍ وَنَعِيمٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdccliii{فَٰكِهِينَ بِمَآ ءَاتَىٰهُمْ رَبُّهُمْ وَوَقَىٰهُمْ رَبُّهُمْ عَذَابَ ٱلْجَحِيمِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdccliv{كُلُوا۟ وَٱشْرَبُوا۟ هَنِيٓـًٔۢا بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdcclv{مُتَّكِـِٔينَ عَلَىٰ سُرُرٍ مَّصْفُوفَةٍ وَزَوَّجْنَٰهُم بِحُورٍ عِينٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcclvi{وَٱلَّذِينَ ءَامَنُوا۟ وَٱتَّبَعَتْهُمْ ذُرِّيَّتُهُم بِإِيمَٰنٍ أَلْحَقْنَا بِهِمْ ذُرِّيَّتَهُمْ وَمَآ أَلَتْنَٰهُم مِّنْ عَمَلِهِم مِّن شَىْءٍ كُلُّ ٱمْرِئٍۭ بِمَا كَسَبَ رَهِينٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcclvii{وَأَمْدَدْنَٰهُم بِفَٰكِهَةٍ وَلَحْمٍ مِّمَّا يَشْتَهُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcclviii{يَتَنَٰزَعُونَ فِيهَا كَأْسًا لَّا لَغْوٌ فِيهَا وَلَا تَأْثِيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcclix{وَيَطُوفُ عَلَيْهِمْ غِلْمَانٌ لَّهُمْ كَأَنَّهُمْ لُؤْلُؤٌ مَّكْنُونٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcclx{وَأَقْبَلَ بَعْضُهُمْ عَلَىٰ بَعْضٍ يَتَسَآءَلُونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcclxi{قَالُوٓا۟ إِنَّا كُنَّا قَبْلُ فِىٓ أَهْلِنَا مُشْفِقِينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdcclxii{فَمَنَّ ٱللَّهُ عَلَيْنَا وَوَقَىٰنَا عَذَابَ ٱلسَّمُومِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcclxiii{إِنَّا كُنَّا مِن قَبْلُ نَدْعُوهُ إِنَّهُۥ هُوَ ٱلْبَرُّ ٱلرَّحِيمُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcclxiv{فَذَكِّرْ فَمَآ أَنتَ بِنِعْمَتِ رَبِّكَ بِكَاهِنٍ وَلَا مَجْنُونٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdcclxv{أَمْ يَقُولُونَ شَاعِرٌ نَّتَرَبَّصُ بِهِۦ رَيْبَ ٱلْمَنُونِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdcclxvi{قُلْ تَرَبَّصُوا۟ فَإِنِّى مَعَكُم مِّنَ ٱلْمُتَرَبِّصِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdcclxvii{أَمْ تَأْمُرُهُمْ أَحْلَٰمُهُم بِهَٰذَآ أَمْ هُمْ قَوْمٌ طَاغُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdcclxviii{أَمْ يَقُولُونَ تَقَوَّلَهُۥ بَل لَّا يُؤْمِنُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdcclxix{فَلْيَأْتُوا۟ بِحَدِيثٍ مِّثْلِهِۦٓ إِن كَانُوا۟ صَٰدِقِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdcclxx{أَمْ خُلِقُوا۟ مِنْ غَيْرِ شَىْءٍ أَمْ هُمُ ٱلْخَٰلِقُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdcclxxi{أَمْ خَلَقُوا۟ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ بَل لَّا يُوقِنُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdcclxxii{أَمْ عِندَهُمْ خَزَآئِنُ رَبِّكَ أَمْ هُمُ ٱلْمُصَۣيْطِرُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdcclxxiii{أَمْ لَهُمْ سُلَّمٌ يَسْتَمِعُونَ فِيهِ فَلْيَأْتِ مُسْتَمِعُهُم بِسُلْطَٰنٍ مُّبِينٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdcclxxiv{أَمْ لَهُ ٱلْبَنَٰتُ وَلَكُمُ ٱلْبَنُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdcclxxv{أَمْ تَسْـَٔلُهُمْ أَجْرًا فَهُم مِّن مَّغْرَمٍ مُّثْقَلُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdcclxxvi{أَمْ عِندَهُمُ ٱلْغَيْبُ فَهُمْ يَكْتُبُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdcclxxvii{أَمْ يُرِيدُونَ كَيْدًا فَٱلَّذِينَ كَفَرُوا۟ هُمُ ٱلْمَكِيدُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdcclxxviii{أَمْ لَهُمْ إِلَٰهٌ غَيْرُ ٱللَّهِ سُبْحَٰنَ ٱللَّهِ عَمَّا يُشْرِكُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdcclxxix{وَإِن يَرَوْا۟ كِسْفًا مِّنَ ٱلسَّمَآءِ سَاقِطًا يَقُولُوا۟ سَحَابٌ مَّرْكُومٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdcclxxx{فَذَرْهُمْ حَتَّىٰ يُلَٰقُوا۟ يَوْمَهُمُ ٱلَّذِى فِيهِ يُصْعَقُونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxi{يَوْمَ لَا يُغْنِى عَنْهُمْ كَيْدُهُمْ شَيْـًٔا وَلَا هُمْ يُنصَرُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxii{وَإِنَّ لِلَّذِينَ ظَلَمُوا۟ عَذَابًا دُونَ ذَٰلِكَ وَلَٰكِنَّ أَكْثَرَهُمْ لَا يَعْلَمُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxiii{وَٱصْبِرْ لِحُكْمِ رَبِّكَ فَإِنَّكَ بِأَعْيُنِنَا وَسَبِّحْ بِحَمْدِ رَبِّكَ حِينَ تَقُومُ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxiv{وَمِنَ ٱلَّيْلِ فَسَبِّحْهُ وَإِدْبَٰرَ ٱلنُّجُومِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxv{\basmalah وَٱلنَّجْمِ إِذَا هَوَىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxvi{مَا ضَلَّ صَاحِبُكُمْ وَمَا غَوَىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxvii{وَمَا يَنطِقُ عَنِ ٱلْهَوَىٰٓ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxviii{إِنْ هُوَ إِلَّا وَحْىٌ يُوحَىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxix{عَلَّمَهُۥ شَدِيدُ ٱلْقُوَىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdccxc{ذُو مِرَّةٍ فَٱسْتَوَىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdccxci{وَهُوَ بِٱلْأُفُقِ ٱلْأَعْلَىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdccxcii{ثُمَّ دَنَا فَتَدَلَّىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdccxciii{فَكَانَ قَابَ قَوْسَيْنِ أَوْ أَدْنَىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdccxciv{فَأَوْحَىٰٓ إِلَىٰ عَبْدِهِۦ مَآ أَوْحَىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdccxcv{مَا كَذَبَ ٱلْفُؤَادُ مَا رَأَىٰٓ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdccxcvi{أَفَتُمَٰرُونَهُۥ عَلَىٰ مَا يَرَىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdccxcvii{وَلَقَدْ رَءَاهُ نَزْلَةً أُخْرَىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdccxcviii{عِندَ سِدْرَةِ ٱلْمُنتَهَىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdccxcix{عِندَهَا جَنَّةُ ٱلْمَأْوَىٰٓ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdccc{إِذْ يَغْشَى ٱلسِّدْرَةَ مَا يَغْشَىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdccci{مَا زَاغَ ٱلْبَصَرُ وَمَا طَغَىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcccii{لَقَدْ رَأَىٰ مِنْ ءَايَٰتِ رَبِّهِ ٱلْكُبْرَىٰٓ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdccciii{أَفَرَءَيْتُمُ ٱللَّٰتَ وَٱلْعُزَّىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdccciv{وَمَنَوٰةَ ٱلثَّالِثَةَ ٱلْأُخْرَىٰٓ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcccv{أَلَكُمُ ٱلذَّكَرُ وَلَهُ ٱلْأُنثَىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcccvi{تِلْكَ إِذًا قِسْمَةٌ ضِيزَىٰٓ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcccvii{إِنْ هِىَ إِلَّآ أَسْمَآءٌ سَمَّيْتُمُوهَآ أَنتُمْ وَءَابَآؤُكُم مَّآ أَنزَلَ ٱللَّهُ بِهَا مِن سُلْطَٰنٍ إِن يَتَّبِعُونَ إِلَّا ٱلظَّنَّ وَمَا تَهْوَى ٱلْأَنفُسُ وَلَقَدْ جَآءَهُم مِّن رَّبِّهِمُ ٱلْهُدَىٰٓ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcccviii{أَمْ لِلْإِنسَٰنِ مَا تَمَنَّىٰ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcccix{فَلِلَّهِ ٱلْءَاخِرَةُ وَٱلْأُولَىٰ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcccx{وَكَم مِّن مَّلَكٍ فِى ٱلسَّمَٰوَٰتِ لَا تُغْنِى شَفَٰعَتُهُمْ شَيْـًٔا إِلَّا مِنۢ بَعْدِ أَن يَأْذَنَ ٱللَّهُ لِمَن يَشَآءُ وَيَرْضَىٰٓ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxi{إِنَّ ٱلَّذِينَ لَا يُؤْمِنُونَ بِٱلْءَاخِرَةِ لَيُسَمُّونَ ٱلْمَلَٰٓئِكَةَ تَسْمِيَةَ ٱلْأُنثَىٰ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxii{وَمَا لَهُم بِهِۦ مِنْ عِلْمٍ إِن يَتَّبِعُونَ إِلَّا ٱلظَّنَّ وَإِنَّ ٱلظَّنَّ لَا يُغْنِى مِنَ ٱلْحَقِّ شَيْـًٔا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxiii{فَأَعْرِضْ عَن مَّن تَوَلَّىٰ عَن ذِكْرِنَا وَلَمْ يُرِدْ إِلَّا ٱلْحَيَوٰةَ ٱلدُّنْيَا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxiv{ذَٰلِكَ مَبْلَغُهُم مِّنَ ٱلْعِلْمِ إِنَّ رَبَّكَ هُوَ أَعْلَمُ بِمَن ضَلَّ عَن سَبِيلِهِۦ وَهُوَ أَعْلَمُ بِمَنِ ٱهْتَدَىٰ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxv{وَلِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ لِيَجْزِىَ ٱلَّذِينَ أَسَٰٓـُٔوا۟ بِمَا عَمِلُوا۟ وَيَجْزِىَ ٱلَّذِينَ أَحْسَنُوا۟ بِٱلْحُسْنَى\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdcccxvi{ٱلَّذِينَ يَجْتَنِبُونَ كَبَٰٓئِرَ ٱلْإِثْمِ وَٱلْفَوَٰحِشَ إِلَّا ٱللَّمَمَ إِنَّ رَبَّكَ وَٰسِعُ ٱلْمَغْفِرَةِ هُوَ أَعْلَمُ بِكُمْ إِذْ أَنشَأَكُم مِّنَ ٱلْأَرْضِ وَإِذْ أَنتُمْ أَجِنَّةٌ فِى بُطُونِ أُمَّهَٰتِكُمْ فَلَا تُزَكُّوٓا۟ أَنفُسَكُمْ هُوَ أَعْلَمُ بِمَنِ ٱتَّقَىٰٓ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxvii{أَفَرَءَيْتَ ٱلَّذِى تَوَلَّىٰ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxviii{وَأَعْطَىٰ قَلِيلًا وَأَكْدَىٰٓ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxix{أَعِندَهُۥ عِلْمُ ٱلْغَيْبِ فَهُوَ يَرَىٰٓ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxx{أَمْ لَمْ يُنَبَّأْ بِمَا فِى صُحُفِ مُوسَىٰ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxxi{وَإِبْرَٰهِيمَ ٱلَّذِى وَفَّىٰٓ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxxii{أَلَّا تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَىٰ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxxiii{وَأَن لَّيْسَ لِلْإِنسَٰنِ إِلَّا مَا سَعَىٰ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxxiv{وَأَنَّ سَعْيَهُۥ سَوْفَ يُرَىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxxv{ثُمَّ يُجْزَىٰهُ ٱلْجَزَآءَ ٱلْأَوْفَىٰ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdcccxxvi{وَأَنَّ إِلَىٰ رَبِّكَ ٱلْمُنتَهَىٰ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxxvii{وَأَنَّهُۥ هُوَ أَضْحَكَ وَأَبْكَىٰ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxxviii{وَأَنَّهُۥ هُوَ أَمَاتَ وَأَحْيَا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxxix{وَأَنَّهُۥ خَلَقَ ٱلزَّوْجَيْنِ ٱلذَّكَرَ وَٱلْأُنثَىٰ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxxx{مِن نُّطْفَةٍ إِذَا تُمْنَىٰ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxi{وَأَنَّ عَلَيْهِ ٱلنَّشْأَةَ ٱلْأُخْرَىٰ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxii{وَأَنَّهُۥ هُوَ أَغْنَىٰ وَأَقْنَىٰ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxiii{وَأَنَّهُۥ هُوَ رَبُّ ٱلشِّعْرَىٰ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxiv{وَأَنَّهُۥٓ أَهْلَكَ عَادًا ٱلْأُولَىٰ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxv{وَثَمُودَا۟ فَمَآ أَبْقَىٰ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxvi{وَقَوْمَ نُوحٍ مِّن قَبْلُ إِنَّهُمْ كَانُوا۟ هُمْ أَظْلَمَ وَأَطْغَىٰ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxvii{وَٱلْمُؤْتَفِكَةَ أَهْوَىٰ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxviii{فَغَشَّىٰهَا مَا غَشَّىٰ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxix{فَبِأَىِّ ءَالَآءِ رَبِّكَ تَتَمَارَىٰ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxl{هَٰذَا نَذِيرٌ مِّنَ ٱلنُّذُرِ ٱلْأُولَىٰٓ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxli{أَزِفَتِ ٱلْءَازِفَةُ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxlii{لَيْسَ لَهَا مِن دُونِ ٱللَّهِ كَاشِفَةٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxliii{أَفَمِنْ هَٰذَا ٱلْحَدِيثِ تَعْجَبُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxliv{وَتَضْحَكُونَ وَلَا تَبْكُونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxlv{وَأَنتُمْ سَٰمِدُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmdcccxlvi{فَٱسْجُدُوا۟ لِلَّهِ وَٱعْبُدُوا۟\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxlvii{\basmalah ٱقْتَرَبَتِ ٱلسَّاعَةُ وَٱنشَقَّ ٱلْقَمَرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcccxlviii{وَإِن يَرَوْا۟ ءَايَةً يُعْرِضُوا۟ وَيَقُولُوا۟ سِحْرٌ مُّسْتَمِرٌّ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxlix{وَكَذَّبُوا۟ وَٱتَّبَعُوٓا۟ أَهْوَآءَهُمْ وَكُلُّ أَمْرٍ مُّسْتَقِرٌّ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcccl{وَلَقَدْ جَآءَهُم مِّنَ ٱلْأَنۢبَآءِ مَا فِيهِ مُزْدَجَرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcccli{حِكْمَةٌۢ بَٰلِغَةٌ فَمَا تُغْنِ ٱلنُّذُرُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdccclii{فَتَوَلَّ عَنْهُمْ يَوْمَ يَدْعُ ٱلدَّاعِ إِلَىٰ شَىْءٍ نُّكُرٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdcccliii{خُشَّعًا أَبْصَٰرُهُمْ يَخْرُجُونَ مِنَ ٱلْأَجْدَاثِ كَأَنَّهُمْ جَرَادٌ مُّنتَشِرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdcccliv{مُّهْطِعِينَ إِلَى ٱلدَّاعِ يَقُولُ ٱلْكَٰفِرُونَ هَٰذَا يَوْمٌ عَسِرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdccclv{كَذَّبَتْ قَبْلَهُمْ قَوْمُ نُوحٍ فَكَذَّبُوا۟ عَبْدَنَا وَقَالُوا۟ مَجْنُونٌ وَٱزْدُجِرَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdccclvi{فَدَعَا رَبَّهُۥٓ أَنِّى مَغْلُوبٌ فَٱنتَصِرْ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdccclvii{فَفَتَحْنَآ أَبْوَٰبَ ٱلسَّمَآءِ بِمَآءٍ مُّنْهَمِرٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdccclviii{وَفَجَّرْنَا ٱلْأَرْضَ عُيُونًا فَٱلْتَقَى ٱلْمَآءُ عَلَىٰٓ أَمْرٍ قَدْ قُدِرَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdccclix{وَحَمَلْنَٰهُ عَلَىٰ ذَاتِ أَلْوَٰحٍ وَدُسُرٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdccclx{تَجْرِى بِأَعْيُنِنَا جَزَآءً لِّمَن كَانَ كُفِرَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdccclxi{وَلَقَد تَّرَكْنَٰهَآ ءَايَةً فَهَلْ مِن مُّدَّكِرٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdccclxii{فَكَيْفَ كَانَ عَذَابِى وَنُذُرِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdccclxiii{وَلَقَدْ يَسَّرْنَا ٱلْقُرْءَانَ لِلذِّكْرِ فَهَلْ مِن مُّدَّكِرٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdccclxiv{كَذَّبَتْ عَادٌ فَكَيْفَ كَانَ عَذَابِى وَنُذُرِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdccclxv{إِنَّآ أَرْسَلْنَا عَلَيْهِمْ رِيحًا صَرْصَرًا فِى يَوْمِ نَحْسٍ مُّسْتَمِرٍّ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdccclxvi{تَنزِعُ ٱلنَّاسَ كَأَنَّهُمْ أَعْجَازُ نَخْلٍ مُّنقَعِرٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdccclxvii{فَكَيْفَ كَانَ عَذَابِى وَنُذُرِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdccclxviii{وَلَقَدْ يَسَّرْنَا ٱلْقُرْءَانَ لِلذِّكْرِ فَهَلْ مِن مُّدَّكِرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdccclxix{كَذَّبَتْ ثَمُودُ بِٱلنُّذُرِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdccclxx{فَقَالُوٓا۟ أَبَشَرًا مِّنَّا وَٰحِدًا نَّتَّبِعُهُۥٓ إِنَّآ إِذًا لَّفِى ضَلَٰلٍ وَسُعُرٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdccclxxi{أَءُلْقِىَ ٱلذِّكْرُ عَلَيْهِ مِنۢ بَيْنِنَا بَلْ هُوَ كَذَّابٌ أَشِرٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdccclxxii{سَيَعْلَمُونَ غَدًا مَّنِ ٱلْكَذَّابُ ٱلْأَشِرُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdccclxxiii{إِنَّا مُرْسِلُوا۟ ٱلنَّاقَةِ فِتْنَةً لَّهُمْ فَٱرْتَقِبْهُمْ وَٱصْطَبِرْ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdccclxxiv{وَنَبِّئْهُمْ أَنَّ ٱلْمَآءَ قِسْمَةٌۢ بَيْنَهُمْ كُلُّ شِرْبٍ مُّحْتَضَرٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdccclxxv{فَنَادَوْا۟ صَاحِبَهُمْ فَتَعَاطَىٰ فَعَقَرَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdccclxxvi{فَكَيْفَ كَانَ عَذَابِى وَنُذُرِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdccclxxvii{إِنَّآ أَرْسَلْنَا عَلَيْهِمْ صَيْحَةً وَٰحِدَةً فَكَانُوا۟ كَهَشِيمِ ٱلْمُحْتَظِرِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdccclxxviii{وَلَقَدْ يَسَّرْنَا ٱلْقُرْءَانَ لِلذِّكْرِ فَهَلْ مِن مُّدَّكِرٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdccclxxix{كَذَّبَتْ قَوْمُ لُوطٍۭ بِٱلنُّذُرِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdccclxxx{إِنَّآ أَرْسَلْنَا عَلَيْهِمْ حَاصِبًا إِلَّآ ءَالَ لُوطٍ نَّجَّيْنَٰهُم بِسَحَرٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxi{نِّعْمَةً مِّنْ عِندِنَا كَذَٰلِكَ نَجْزِى مَن شَكَرَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxii{وَلَقَدْ أَنذَرَهُم بَطْشَتَنَا فَتَمَارَوْا۟ بِٱلنُّذُرِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxiii{وَلَقَدْ رَٰوَدُوهُ عَن ضَيْفِهِۦ فَطَمَسْنَآ أَعْيُنَهُمْ فَذُوقُوا۟ عَذَابِى وَنُذُرِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxiv{وَلَقَدْ صَبَّحَهُم بُكْرَةً عَذَابٌ مُّسْتَقِرٌّ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxv{فَذُوقُوا۟ عَذَابِى وَنُذُرِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxvi{وَلَقَدْ يَسَّرْنَا ٱلْقُرْءَانَ لِلذِّكْرِ فَهَلْ مِن مُّدَّكِرٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxvii{وَلَقَدْ جَآءَ ءَالَ فِرْعَوْنَ ٱلنُّذُرُ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxviii{كَذَّبُوا۟ بِـَٔايَٰتِنَا كُلِّهَا فَأَخَذْنَٰهُمْ أَخْذَ عَزِيزٍ مُّقْتَدِرٍ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxix{أَكُفَّارُكُمْ خَيْرٌ مِّنْ أُو۟لَٰٓئِكُمْ أَمْ لَكُم بَرَآءَةٌ فِى ٱلزُّبُرِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxc{أَمْ يَقُولُونَ نَحْنُ جَمِيعٌ مُّنتَصِرٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxci{سَيُهْزَمُ ٱلْجَمْعُ وَيُوَلُّونَ ٱلدُّبُرَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxcii{بَلِ ٱلسَّاعَةُ مَوْعِدُهُمْ وَٱلسَّاعَةُ أَدْهَىٰ وَأَمَرُّ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxciii{إِنَّ ٱلْمُجْرِمِينَ فِى ضَلَٰلٍ وَسُعُرٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxciv{يَوْمَ يُسْحَبُونَ فِى ٱلنَّارِ عَلَىٰ وُجُوهِهِمْ ذُوقُوا۟ مَسَّ سَقَرَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxcv{إِنَّا كُلَّ شَىْءٍ خَلَقْنَٰهُ بِقَدَرٍ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxcvi{وَمَآ أَمْرُنَآ إِلَّا وَٰحِدَةٌ كَلَمْحٍۭ بِٱلْبَصَرِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxcvii{وَلَقَدْ أَهْلَكْنَآ أَشْيَاعَكُمْ فَهَلْ مِن مُّدَّكِرٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmdcccxcviii{وَكُلُّ شَىْءٍ فَعَلُوهُ فِى ٱلزُّبُرِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxcix{وَكُلُّ صَغِيرٍ وَكَبِيرٍ مُّسْتَطَرٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcm{إِنَّ ٱلْمُتَّقِينَ فِى جَنَّٰتٍ وَنَهَرٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcmi{فِى مَقْعَدِ صِدْقٍ عِندَ مَلِيكٍ مُّقْتَدِرٍۭ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcmii{\basmalah ٱلرَّحْمَٰنُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcmiii{عَلَّمَ ٱلْقُرْءَانَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcmiv{خَلَقَ ٱلْإِنسَٰنَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcmv{عَلَّمَهُ ٱلْبَيَانَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcmvi{ٱلشَّمْسُ وَٱلْقَمَرُ بِحُسْبَانٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcmvii{وَٱلنَّجْمُ وَٱلشَّجَرُ يَسْجُدَانِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcmviii{وَٱلسَّمَآءَ رَفَعَهَا وَوَضَعَ ٱلْمِيزَانَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcmix{أَلَّا تَطْغَوْا۟ فِى ٱلْمِيزَانِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcmx{وَأَقِيمُوا۟ ٱلْوَزْنَ بِٱلْقِسْطِ وَلَا تُخْسِرُوا۟ ٱلْمِيزَانَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcmxi{وَٱلْأَرْضَ وَضَعَهَا لِلْأَنَامِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcmxii{فِيهَا فَٰكِهَةٌ وَٱلنَّخْلُ ذَاتُ ٱلْأَكْمَامِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcmxiii{وَٱلْحَبُّ ذُو ٱلْعَصْفِ وَٱلرَّيْحَانُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcmxiv{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcmxv{خَلَقَ ٱلْإِنسَٰنَ مِن صَلْصَٰلٍ كَٱلْفَخَّارِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcmxvi{وَخَلَقَ ٱلْجَآنَّ مِن مَّارِجٍ مِّن نَّارٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcmxvii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcmxviii{رَبُّ ٱلْمَشْرِقَيْنِ وَرَبُّ ٱلْمَغْرِبَيْنِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcmxix{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcmxx{مَرَجَ ٱلْبَحْرَيْنِ يَلْتَقِيَانِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcmxxi{بَيْنَهُمَا بَرْزَخٌ لَّا يَبْغِيَانِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcmxxii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcmxxiii{يَخْرُجُ مِنْهُمَا ٱللُّؤْلُؤُ وَٱلْمَرْجَانُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcmxxiv{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcmxxv{وَلَهُ ٱلْجَوَارِ ٱلْمُنشَـَٔاتُ فِى ٱلْبَحْرِ كَٱلْأَعْلَٰمِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcmxxvi{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcmxxvii{كُلُّ مَنْ عَلَيْهَا فَانٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmcmxxviii{وَيَبْقَىٰ وَجْهُ رَبِّكَ ذُو ٱلْجَلَٰلِ وَٱلْإِكْرَامِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmcmxxix{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmcmxxx{يَسْـَٔلُهُۥ مَن فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ كُلَّ يَوْمٍ هُوَ فِى شَأْنٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmcmxxxi{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmcmxxxii{سَنَفْرُغُ لَكُمْ أَيُّهَ ٱلثَّقَلَانِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmcmxxxiii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmcmxxxiv{يَٰمَعْشَرَ ٱلْجِنِّ وَٱلْإِنسِ إِنِ ٱسْتَطَعْتُمْ أَن تَنفُذُوا۟ مِنْ أَقْطَارِ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ فَٱنفُذُوا۟ لَا تَنفُذُونَ إِلَّا بِسُلْطَٰنٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcmxxxv{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmcmxxxvi{يُرْسَلُ عَلَيْكُمَا شُوَاظٌ مِّن نَّارٍ وَنُحَاسٌ فَلَا تَنتَصِرَانِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmcmxxxvii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcmxxxviii{فَإِذَا ٱنشَقَّتِ ٱلسَّمَآءُ فَكَانَتْ وَرْدَةً كَٱلدِّهَانِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcmxxxix{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcmxl{فَيَوْمَئِذٍ لَّا يُسْـَٔلُ عَن ذَنۢبِهِۦٓ إِنسٌ وَلَا جَآنٌّ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcmxli{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcmxlii{يُعْرَفُ ٱلْمُجْرِمُونَ بِسِيمَٰهُمْ فَيُؤْخَذُ بِٱلنَّوَٰصِى وَٱلْأَقْدَامِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcmxliii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcmxliv{هَٰذِهِۦ جَهَنَّمُ ٱلَّتِى يُكَذِّبُ بِهَا ٱلْمُجْرِمُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcmxlv{يَطُوفُونَ بَيْنَهَا وَبَيْنَ حَمِيمٍ ءَانٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcmxlvi{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcmxlvii{وَلِمَنْ خَافَ مَقَامَ رَبِّهِۦ جَنَّتَانِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcmxlviii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcmxlix{ذَوَاتَآ أَفْنَانٍ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcml{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcmli{فِيهِمَا عَيْنَانِ تَجْرِيَانِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcmlii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcmliii{فِيهِمَا مِن كُلِّ فَٰكِهَةٍ زَوْجَانِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcmliv{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcmlv{مُتَّكِـِٔينَ عَلَىٰ فُرُشٍۭ بَطَآئِنُهَا مِنْ إِسْتَبْرَقٍ وَجَنَى ٱلْجَنَّتَيْنِ دَانٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcmlvi{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcmlvii{فِيهِنَّ قَٰصِرَٰتُ ٱلطَّرْفِ لَمْ يَطْمِثْهُنَّ إِنسٌ قَبْلَهُمْ وَلَا جَآنٌّ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcmlviii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcmlix{كَأَنَّهُنَّ ٱلْيَاقُوتُ وَٱلْمَرْجَانُ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcmlx{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcmlxi{هَلْ جَزَآءُ ٱلْإِحْسَٰنِ إِلَّا ٱلْإِحْسَٰنُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmcmlxii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmcmlxiii{وَمِن دُونِهِمَا جَنَّتَانِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmcmlxiv{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmcmlxv{مُدْهَآمَّتَانِ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcmlxvi{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcmlxvii{فِيهِمَا عَيْنَانِ نَضَّاخَتَانِ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcmlxviii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcmlxix{فِيهِمَا فَٰكِهَةٌ وَنَخْلٌ وَرُمَّانٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmcmlxx{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcmlxxi{فِيهِنَّ خَيْرَٰتٌ حِسَانٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcmlxxii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmcmlxxiii{حُورٌ مَّقْصُورَٰتٌ فِى ٱلْخِيَامِ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmcmlxxiv{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmcmlxxv{لَمْ يَطْمِثْهُنَّ إِنسٌ قَبْلَهُمْ وَلَا جَآنٌّ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmcmlxxvi{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmcmlxxvii{مُتَّكِـِٔينَ عَلَىٰ رَفْرَفٍ خُضْرٍ وَعَبْقَرِىٍّ حِسَانٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmcmlxxviii{فَبِأَىِّ ءَالَآءِ رَبِّكُمَا تُكَذِّبَانِ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmcmlxxix{تَبَٰرَكَ ٱسْمُ رَبِّكَ ذِى ٱلْجَلَٰلِ وَٱلْإِكْرَامِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmcmlxxx{\basmalah إِذَا وَقَعَتِ ٱلْوَاقِعَةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxi{لَيْسَ لِوَقْعَتِهَا كَاذِبَةٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxii{خَافِضَةٌ رَّافِعَةٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxiii{إِذَا رُجَّتِ ٱلْأَرْضُ رَجًّا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxiv{وَبُسَّتِ ٱلْجِبَالُ بَسًّا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxv{فَكَانَتْ هَبَآءً مُّنۢبَثًّا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxvi{وَكُنتُمْ أَزْوَٰجًا ثَلَٰثَةً\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxvii{فَأَصْحَٰبُ ٱلْمَيْمَنَةِ مَآ أَصْحَٰبُ ٱلْمَيْمَنَةِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxviii{وَأَصْحَٰبُ ٱلْمَشْـَٔمَةِ مَآ أَصْحَٰبُ ٱلْمَشْـَٔمَةِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxix{وَٱلسَّٰبِقُونَ ٱلسَّٰبِقُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcmxc{أُو۟لَٰٓئِكَ ٱلْمُقَرَّبُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcmxci{فِى جَنَّٰتِ ٱلنَّعِيمِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcmxcii{ثُلَّةٌ مِّنَ ٱلْأَوَّلِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcmxciii{وَقَلِيلٌ مِّنَ ٱلْءَاخِرِينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcmxciv{عَلَىٰ سُرُرٍ مَّوْضُونَةٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcmxcv{مُّتَّكِـِٔينَ عَلَيْهَا مُتَقَٰبِلِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcmxcvi{يَطُوفُ عَلَيْهِمْ وِلْدَٰنٌ مُّخَلَّدُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcmxcvii{بِأَكْوَابٍ وَأَبَارِيقَ وَكَأْسٍ مِّن مَّعِينٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcmxcviii{لَّا يُصَدَّعُونَ عَنْهَا وَلَا يُنزِفُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcmxcix{وَفَٰكِهَةٍ مِّمَّا يَتَخَيَّرُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmm{وَلَحْمِ طَيْرٍ مِّمَّا يَشْتَهُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmi{وَحُورٌ عِينٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmii{كَأَمْثَٰلِ ٱللُّؤْلُؤِ ٱلْمَكْنُونِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmiii{جَزَآءًۢ بِمَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmiv{لَا يَسْمَعُونَ فِيهَا لَغْوًا وَلَا تَأْثِيمًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmv{إِلَّا قِيلًا سَلَٰمًا سَلَٰمًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmvi{وَأَصْحَٰبُ ٱلْيَمِينِ مَآ أَصْحَٰبُ ٱلْيَمِينِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmvii{فِى سِدْرٍ مَّخْضُودٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmviii{وَطَلْحٍ مَّنضُودٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmix{وَظِلٍّ مَّمْدُودٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmx{وَمَآءٍ مَّسْكُوبٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmxi{وَفَٰكِهَةٍ كَثِيرَةٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmxii{لَّا مَقْطُوعَةٍ وَلَا مَمْنُوعَةٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmxiii{وَفُرُشٍ مَّرْفُوعَةٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmxiv{إِنَّآ أَنشَأْنَٰهُنَّ إِنشَآءً\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmxv{فَجَعَلْنَٰهُنَّ أَبْكَارًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmxvi{عُرُبًا أَتْرَابًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmxvii{لِّأَصْحَٰبِ ٱلْيَمِينِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmxviii{ثُلَّةٌ مِّنَ ٱلْأَوَّلِينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmxix{وَثُلَّةٌ مِّنَ ٱلْءَاخِرِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmxx{وَأَصْحَٰبُ ٱلشِّمَالِ مَآ أَصْحَٰبُ ٱلشِّمَالِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmxxi{فِى سَمُومٍ وَحَمِيمٍ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmxxii{وَظِلٍّ مِّن يَحْمُومٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmxxiii{لَّا بَارِدٍ وَلَا كَرِيمٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmxxiv{إِنَّهُمْ كَانُوا۟ قَبْلَ ذَٰلِكَ مُتْرَفِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmxxv{وَكَانُوا۟ يُصِرُّونَ عَلَى ٱلْحِنثِ ٱلْعَظِيمِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmxxvi{وَكَانُوا۟ يَقُولُونَ أَئِذَا مِتْنَا وَكُنَّا تُرَابًا وَعِظَٰمًا أَءِنَّا لَمَبْعُوثُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmxxvii{أَوَءَابَآؤُنَا ٱلْأَوَّلُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmxxviii{قُلْ إِنَّ ٱلْأَوَّلِينَ وَٱلْءَاخِرِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmxxix{لَمَجْمُوعُونَ إِلَىٰ مِيقَٰتِ يَوْمٍ مَّعْلُومٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmxxx{ثُمَّ إِنَّكُمْ أَيُّهَا ٱلضَّآلُّونَ ٱلْمُكَذِّبُونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmxxxi{لَءَاكِلُونَ مِن شَجَرٍ مِّن زَقُّومٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmxxxii{فَمَالِـُٔونَ مِنْهَا ٱلْبُطُونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmmxxxiii{فَشَٰرِبُونَ عَلَيْهِ مِنَ ٱلْحَمِيمِ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmmxxxiv{فَشَٰرِبُونَ شُرْبَ ٱلْهِيمِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmmxxxv{هَٰذَا نُزُلُهُمْ يَوْمَ ٱلدِّينِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmmxxxvi{نَحْنُ خَلَقْنَٰكُمْ فَلَوْلَا تُصَدِّقُونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmmxxxvii{أَفَرَءَيْتُم مَّا تُمْنُونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmmxxxviii{ءَأَنتُمْ تَخْلُقُونَهُۥٓ أَمْ نَحْنُ ٱلْخَٰلِقُونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmmxxxix{نَحْنُ قَدَّرْنَا بَيْنَكُمُ ٱلْمَوْتَ وَمَا نَحْنُ بِمَسْبُوقِينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmmxl{عَلَىٰٓ أَن نُّبَدِّلَ أَمْثَٰلَكُمْ وَنُنشِئَكُمْ فِى مَا لَا تَعْلَمُونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmmxli{وَلَقَدْ عَلِمْتُمُ ٱلنَّشْأَةَ ٱلْأُولَىٰ فَلَوْلَا تَذَكَّرُونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmmxlii{أَفَرَءَيْتُم مَّا تَحْرُثُونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmmxliii{ءَأَنتُمْ تَزْرَعُونَهُۥٓ أَمْ نَحْنُ ٱلزَّٰرِعُونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmmxliv{لَوْ نَشَآءُ لَجَعَلْنَٰهُ حُطَٰمًا فَظَلْتُمْ تَفَكَّهُونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmmxlv{إِنَّا لَمُغْرَمُونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmmxlvi{بَلْ نَحْنُ مَحْرُومُونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmmxlvii{أَفَرَءَيْتُمُ ٱلْمَآءَ ٱلَّذِى تَشْرَبُونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmmxlviii{ءَأَنتُمْ أَنزَلْتُمُوهُ مِنَ ٱلْمُزْنِ أَمْ نَحْنُ ٱلْمُنزِلُونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmmxlix{لَوْ نَشَآءُ جَعَلْنَٰهُ أُجَاجًا فَلَوْلَا تَشْكُرُونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmml{أَفَرَءَيْتُمُ ٱلنَّارَ ٱلَّتِى تُورُونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmmli{ءَأَنتُمْ أَنشَأْتُمْ شَجَرَتَهَآ أَمْ نَحْنُ ٱلْمُنشِـُٔونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmmlii{نَحْنُ جَعَلْنَٰهَا تَذْكِرَةً وَمَتَٰعًا لِّلْمُقْوِينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmmliii{فَسَبِّحْ بِٱسْمِ رَبِّكَ ٱلْعَظِيمِ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmmliv{فَلَآ أُقْسِمُ بِمَوَٰقِعِ ٱلنُّجُومِ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmmlv{وَإِنَّهُۥ لَقَسَمٌ لَّوْ تَعْلَمُونَ عَظِيمٌ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmmlvi{إِنَّهُۥ لَقُرْءَانٌ كَرِيمٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmmlvii{فِى كِتَٰبٍ مَّكْنُونٍ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmmlviii{لَّا يَمَسُّهُۥٓ إِلَّا ٱلْمُطَهَّرُونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmmmlix{تَنزِيلٌ مِّن رَّبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmmlx{أَفَبِهَٰذَا ٱلْحَدِيثِ أَنتُم مُّدْهِنُونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmmlxi{وَتَجْعَلُونَ رِزْقَكُمْ أَنَّكُمْ تُكَذِّبُونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmmlxii{فَلَوْلَآ إِذَا بَلَغَتِ ٱلْحُلْقُومَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmmlxiii{وَأَنتُمْ حِينَئِذٍ تَنظُرُونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmmlxiv{وَنَحْنُ أَقْرَبُ إِلَيْهِ مِنكُمْ وَلَٰكِن لَّا تُبْصِرُونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmmlxv{فَلَوْلَآ إِن كُنتُمْ غَيْرَ مَدِينِينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmmmlxvi{تَرْجِعُونَهَآ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmmmlxvii{فَأَمَّآ إِن كَانَ مِنَ ٱلْمُقَرَّبِينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmmmlxviii{فَرَوْحٌ وَرَيْحَانٌ وَجَنَّتُ نَعِيمٍ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmmmlxix{وَأَمَّآ إِن كَانَ مِنْ أَصْحَٰبِ ٱلْيَمِينِ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmmmlxx{فَسَلَٰمٌ لَّكَ مِنْ أَصْحَٰبِ ٱلْيَمِينِ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmmmlxxi{وَأَمَّآ إِن كَانَ مِنَ ٱلْمُكَذِّبِينَ ٱلضَّآلِّينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmmmlxxii{فَنُزُلٌ مِّنْ حَمِيمٍ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmmmlxxiii{وَتَصْلِيَةُ جَحِيمٍ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmmmmlxxiv{إِنَّ هَٰذَا لَهُوَ حَقُّ ٱلْيَقِينِ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmmmmlxxv{فَسَبِّحْ بِٱسْمِ رَبِّكَ ٱلْعَظِيمِ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmmmmlxxvi{\basmalah سَبَّحَ لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmlxxvii{لَهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ يُحْىِۦ وَيُمِيتُ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmlxxviii{هُوَ ٱلْأَوَّلُ وَٱلْءَاخِرُ وَٱلظَّٰهِرُ وَٱلْبَاطِنُ وَهُوَ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmlxxix{هُوَ ٱلَّذِى خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ فِى سِتَّةِ أَيَّامٍ ثُمَّ ٱسْتَوَىٰ عَلَى ٱلْعَرْشِ يَعْلَمُ مَا يَلِجُ فِى ٱلْأَرْضِ وَمَا يَخْرُجُ مِنْهَا وَمَا يَنزِلُ مِنَ ٱلسَّمَآءِ وَمَا يَعْرُجُ فِيهَا وَهُوَ مَعَكُمْ أَيْنَ مَا كُنتُمْ وَٱللَّهُ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmlxxx{لَّهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَإِلَى ٱللَّهِ تُرْجَعُ ٱلْأُمُورُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmlxxxi{يُولِجُ ٱلَّيْلَ فِى ٱلنَّهَارِ وَيُولِجُ ٱلنَّهَارَ فِى ٱلَّيْلِ وَهُوَ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmlxxxii{ءَامِنُوا۟ بِٱللَّهِ وَرَسُولِهِۦ وَأَنفِقُوا۟ مِمَّا جَعَلَكُم مُّسْتَخْلَفِينَ فِيهِ فَٱلَّذِينَ ءَامَنُوا۟ مِنكُمْ وَأَنفَقُوا۟ لَهُمْ أَجْرٌ كَبِيرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmlxxxiii{وَمَا لَكُمْ لَا تُؤْمِنُونَ بِٱللَّهِ وَٱلرَّسُولُ يَدْعُوكُمْ لِتُؤْمِنُوا۟ بِرَبِّكُمْ وَقَدْ أَخَذَ مِيثَٰقَكُمْ إِن كُنتُم مُّؤْمِنِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmlxxxiv{هُوَ ٱلَّذِى يُنَزِّلُ عَلَىٰ عَبْدِهِۦٓ ءَايَٰتٍۭ بَيِّنَٰتٍ لِّيُخْرِجَكُم مِّنَ ٱلظُّلُمَٰتِ إِلَى ٱلنُّورِ وَإِنَّ ٱللَّهَ بِكُمْ لَرَءُوفٌ رَّحِيمٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmlxxxv{وَمَا لَكُمْ أَلَّا تُنفِقُوا۟ فِى سَبِيلِ ٱللَّهِ وَلِلَّهِ مِيرَٰثُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ لَا يَسْتَوِى مِنكُم مَّنْ أَنفَقَ مِن قَبْلِ ٱلْفَتْحِ وَقَٰتَلَ أُو۟لَٰٓئِكَ أَعْظَمُ دَرَجَةً مِّنَ ٱلَّذِينَ أَنفَقُوا۟ مِنۢ بَعْدُ وَقَٰتَلُوا۟ وَكُلًّا وَعَدَ ٱللَّهُ ٱلْحُسْنَىٰ وَٱللَّهُ بِمَا تَعْمَلُونَ خَبِيرٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmlxxxvi{مَّن ذَا ٱلَّذِى يُقْرِضُ ٱللَّهَ قَرْضًا حَسَنًا فَيُضَٰعِفَهُۥ لَهُۥ وَلَهُۥٓ أَجْرٌ كَرِيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmlxxxvii{يَوْمَ تَرَى ٱلْمُؤْمِنِينَ وَٱلْمُؤْمِنَٰتِ يَسْعَىٰ نُورُهُم بَيْنَ أَيْدِيهِمْ وَبِأَيْمَٰنِهِم بُشْرَىٰكُمُ ٱلْيَوْمَ جَنَّٰتٌ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا ذَٰلِكَ هُوَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmlxxxviii{يَوْمَ يَقُولُ ٱلْمُنَٰفِقُونَ وَٱلْمُنَٰفِقَٰتُ لِلَّذِينَ ءَامَنُوا۟ ٱنظُرُونَا نَقْتَبِسْ مِن نُّورِكُمْ قِيلَ ٱرْجِعُوا۟ وَرَآءَكُمْ فَٱلْتَمِسُوا۟ نُورًا فَضُرِبَ بَيْنَهُم بِسُورٍ لَّهُۥ بَابٌۢ بَاطِنُهُۥ فِيهِ ٱلرَّحْمَةُ وَظَٰهِرُهُۥ مِن قِبَلِهِ ٱلْعَذَابُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmlxxxix{يُنَادُونَهُمْ أَلَمْ نَكُن مَّعَكُمْ قَالُوا۟ بَلَىٰ وَلَٰكِنَّكُمْ فَتَنتُمْ أَنفُسَكُمْ وَتَرَبَّصْتُمْ وَٱرْتَبْتُمْ وَغَرَّتْكُمُ ٱلْأَمَانِىُّ حَتَّىٰ جَآءَ أَمْرُ ٱللَّهِ وَغَرَّكُم بِٱللَّهِ ٱلْغَرُورُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmxc{فَٱلْيَوْمَ لَا يُؤْخَذُ مِنكُمْ فِدْيَةٌ وَلَا مِنَ ٱلَّذِينَ كَفَرُوا۟ مَأْوَىٰكُمُ ٱلنَّارُ هِىَ مَوْلَىٰكُمْ وَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmxci{أَلَمْ يَأْنِ لِلَّذِينَ ءَامَنُوٓا۟ أَن تَخْشَعَ قُلُوبُهُمْ لِذِكْرِ ٱللَّهِ وَمَا نَزَلَ مِنَ ٱلْحَقِّ وَلَا يَكُونُوا۟ كَٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ مِن قَبْلُ فَطَالَ عَلَيْهِمُ ٱلْأَمَدُ فَقَسَتْ قُلُوبُهُمْ وَكَثِيرٌ مِّنْهُمْ فَٰسِقُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmxcii{ٱعْلَمُوٓا۟ أَنَّ ٱللَّهَ يُحْىِ ٱلْأَرْضَ بَعْدَ مَوْتِهَا قَدْ بَيَّنَّا لَكُمُ ٱلْءَايَٰتِ لَعَلَّكُمْ تَعْقِلُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmxciii{إِنَّ ٱلْمُصَّدِّقِينَ وَٱلْمُصَّدِّقَٰتِ وَأَقْرَضُوا۟ ٱللَّهَ قَرْضًا حَسَنًا يُضَٰعَفُ لَهُمْ وَلَهُمْ أَجْرٌ كَرِيمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmxciv{وَٱلَّذِينَ ءَامَنُوا۟ بِٱللَّهِ وَرُسُلِهِۦٓ أُو۟لَٰٓئِكَ هُمُ ٱلصِّدِّيقُونَ وَٱلشُّهَدَآءُ عِندَ رَبِّهِمْ لَهُمْ أَجْرُهُمْ وَنُورُهُمْ وَٱلَّذِينَ كَفَرُوا۟ وَكَذَّبُوا۟ بِـَٔايَٰتِنَآ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْجَحِيمِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmxcv{ٱعْلَمُوٓا۟ أَنَّمَا ٱلْحَيَوٰةُ ٱلدُّنْيَا لَعِبٌ وَلَهْوٌ وَزِينَةٌ وَتَفَاخُرٌۢ بَيْنَكُمْ وَتَكَاثُرٌ فِى ٱلْأَمْوَٰلِ وَٱلْأَوْلَٰدِ كَمَثَلِ غَيْثٍ أَعْجَبَ ٱلْكُفَّارَ نَبَاتُهُۥ ثُمَّ يَهِيجُ فَتَرَىٰهُ مُصْفَرًّا ثُمَّ يَكُونُ حُطَٰمًا وَفِى ٱلْءَاخِرَةِ عَذَابٌ شَدِيدٌ وَمَغْفِرَةٌ مِّنَ ٱللَّهِ وَرِضْوَٰنٌ وَمَا ٱلْحَيَوٰةُ ٱلدُّنْيَآ إِلَّا مَتَٰعُ ٱلْغُرُورِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmxcvi{سَابِقُوٓا۟ إِلَىٰ مَغْفِرَةٍ مِّن رَّبِّكُمْ وَجَنَّةٍ عَرْضُهَا كَعَرْضِ ٱلسَّمَآءِ وَٱلْأَرْضِ أُعِدَّتْ لِلَّذِينَ ءَامَنُوا۟ بِٱللَّهِ وَرُسُلِهِۦ ذَٰلِكَ فَضْلُ ٱللَّهِ يُؤْتِيهِ مَن يَشَآءُ وَٱللَّهُ ذُو ٱلْفَضْلِ ٱلْعَظِيمِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmxcvii{مَآ أَصَابَ مِن مُّصِيبَةٍ فِى ٱلْأَرْضِ وَلَا فِىٓ أَنفُسِكُمْ إِلَّا فِى كِتَٰبٍ مِّن قَبْلِ أَن نَّبْرَأَهَآ إِنَّ ذَٰلِكَ عَلَى ٱللَّهِ يَسِيرٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmxcviii{لِّكَيْلَا تَأْسَوْا۟ عَلَىٰ مَا فَاتَكُمْ وَلَا تَفْرَحُوا۟ بِمَآ ءَاتَىٰكُمْ وَٱللَّهُ لَا يُحِبُّ كُلَّ مُخْتَالٍ فَخُورٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmxcix{ٱلَّذِينَ يَبْخَلُونَ وَيَأْمُرُونَ ٱلنَّاسَ بِٱلْبُخْلِ وَمَن يَتَوَلَّ فَإِنَّ ٱللَّهَ هُوَ ٱلْغَنِىُّ ٱلْحَمِيدُ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmc{لَقَدْ أَرْسَلْنَا رُسُلَنَا بِٱلْبَيِّنَٰتِ وَأَنزَلْنَا مَعَهُمُ ٱلْكِتَٰبَ وَٱلْمِيزَانَ لِيَقُومَ ٱلنَّاسُ بِٱلْقِسْطِ وَأَنزَلْنَا ٱلْحَدِيدَ فِيهِ بَأْسٌ شَدِيدٌ وَمَنَٰفِعُ لِلنَّاسِ وَلِيَعْلَمَ ٱللَّهُ مَن يَنصُرُهُۥ وَرُسُلَهُۥ بِٱلْغَيْبِ إِنَّ ٱللَّهَ قَوِىٌّ عَزِيزٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmci{وَلَقَدْ أَرْسَلْنَا نُوحًا وَإِبْرَٰهِيمَ وَجَعَلْنَا فِى ذُرِّيَّتِهِمَا ٱلنُّبُوَّةَ وَٱلْكِتَٰبَ فَمِنْهُم مُّهْتَدٍ وَكَثِيرٌ مِّنْهُمْ فَٰسِقُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcii{ثُمَّ قَفَّيْنَا عَلَىٰٓ ءَاثَٰرِهِم بِرُسُلِنَا وَقَفَّيْنَا بِعِيسَى ٱبْنِ مَرْيَمَ وَءَاتَيْنَٰهُ ٱلْإِنجِيلَ وَجَعَلْنَا فِى قُلُوبِ ٱلَّذِينَ ٱتَّبَعُوهُ رَأْفَةً وَرَحْمَةً وَرَهْبَانِيَّةً ٱبْتَدَعُوهَا مَا كَتَبْنَٰهَا عَلَيْهِمْ إِلَّا ٱبْتِغَآءَ رِضْوَٰنِ ٱللَّهِ فَمَا رَعَوْهَا حَقَّ رِعَايَتِهَا فَـَٔاتَيْنَا ٱلَّذِينَ ءَامَنُوا۟ مِنْهُمْ أَجْرَهُمْ وَكَثِيرٌ مِّنْهُمْ فَٰسِقُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmciii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱتَّقُوا۟ ٱللَّهَ وَءَامِنُوا۟ بِرَسُولِهِۦ يُؤْتِكُمْ كِفْلَيْنِ مِن رَّحْمَتِهِۦ وَيَجْعَل لَّكُمْ نُورًا تَمْشُونَ بِهِۦ وَيَغْفِرْ لَكُمْ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmciv{لِّئَلَّا يَعْلَمَ أَهْلُ ٱلْكِتَٰبِ أَلَّا يَقْدِرُونَ عَلَىٰ شَىْءٍ مِّن فَضْلِ ٱللَّهِ وَأَنَّ ٱلْفَضْلَ بِيَدِ ٱللَّهِ يُؤْتِيهِ مَن يَشَآءُ وَٱللَّهُ ذُو ٱلْفَضْلِ ٱلْعَظِيمِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcv{\basmalah قَدْ سَمِعَ ٱللَّهُ قَوْلَ ٱلَّتِى تُجَٰدِلُكَ فِى زَوْجِهَا وَتَشْتَكِىٓ إِلَى ٱللَّهِ وَٱللَّهُ يَسْمَعُ تَحَاوُرَكُمَآ إِنَّ ٱللَّهَ سَمِيعٌۢ بَصِيرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcvi{ٱلَّذِينَ يُظَٰهِرُونَ مِنكُم مِّن نِّسَآئِهِم مَّا هُنَّ أُمَّهَٰتِهِمْ إِنْ أُمَّهَٰتُهُمْ إِلَّا ٱلَّٰٓـِٔى وَلَدْنَهُمْ وَإِنَّهُمْ لَيَقُولُونَ مُنكَرًا مِّنَ ٱلْقَوْلِ وَزُورًا وَإِنَّ ٱللَّهَ لَعَفُوٌّ غَفُورٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcvii{وَٱلَّذِينَ يُظَٰهِرُونَ مِن نِّسَآئِهِمْ ثُمَّ يَعُودُونَ لِمَا قَالُوا۟ فَتَحْرِيرُ رَقَبَةٍ مِّن قَبْلِ أَن يَتَمَآسَّا ذَٰلِكُمْ تُوعَظُونَ بِهِۦ وَٱللَّهُ بِمَا تَعْمَلُونَ خَبِيرٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcviii{فَمَن لَّمْ يَجِدْ فَصِيَامُ شَهْرَيْنِ مُتَتَابِعَيْنِ مِن قَبْلِ أَن يَتَمَآسَّا فَمَن لَّمْ يَسْتَطِعْ فَإِطْعَامُ سِتِّينَ مِسْكِينًا ذَٰلِكَ لِتُؤْمِنُوا۟ بِٱللَّهِ وَرَسُولِهِۦ وَتِلْكَ حُدُودُ ٱللَّهِ وَلِلْكَٰفِرِينَ عَذَابٌ أَلِيمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcix{إِنَّ ٱلَّذِينَ يُحَآدُّونَ ٱللَّهَ وَرَسُولَهُۥ كُبِتُوا۟ كَمَا كُبِتَ ٱلَّذِينَ مِن قَبْلِهِمْ وَقَدْ أَنزَلْنَآ ءَايَٰتٍۭ بَيِّنَٰتٍ وَلِلْكَٰفِرِينَ عَذَابٌ مُّهِينٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcx{يَوْمَ يَبْعَثُهُمُ ٱللَّهُ جَمِيعًا فَيُنَبِّئُهُم بِمَا عَمِلُوٓا۟ أَحْصَىٰهُ ٱللَّهُ وَنَسُوهُ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ شَهِيدٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcxi{أَلَمْ تَرَ أَنَّ ٱللَّهَ يَعْلَمُ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ مَا يَكُونُ مِن نَّجْوَىٰ ثَلَٰثَةٍ إِلَّا هُوَ رَابِعُهُمْ وَلَا خَمْسَةٍ إِلَّا هُوَ سَادِسُهُمْ وَلَآ أَدْنَىٰ مِن ذَٰلِكَ وَلَآ أَكْثَرَ إِلَّا هُوَ مَعَهُمْ أَيْنَ مَا كَانُوا۟ ثُمَّ يُنَبِّئُهُم بِمَا عَمِلُوا۟ يَوْمَ ٱلْقِيَٰمَةِ إِنَّ ٱللَّهَ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcxii{أَلَمْ تَرَ إِلَى ٱلَّذِينَ نُهُوا۟ عَنِ ٱلنَّجْوَىٰ ثُمَّ يَعُودُونَ لِمَا نُهُوا۟ عَنْهُ وَيَتَنَٰجَوْنَ بِٱلْإِثْمِ وَٱلْعُدْوَٰنِ وَمَعْصِيَتِ ٱلرَّسُولِ وَإِذَا جَآءُوكَ حَيَّوْكَ بِمَا لَمْ يُحَيِّكَ بِهِ ٱللَّهُ وَيَقُولُونَ فِىٓ أَنفُسِهِمْ لَوْلَا يُعَذِّبُنَا ٱللَّهُ بِمَا نَقُولُ حَسْبُهُمْ جَهَنَّمُ يَصْلَوْنَهَا فَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا تَنَٰجَيْتُمْ فَلَا تَتَنَٰجَوْا۟ بِٱلْإِثْمِ وَٱلْعُدْوَٰنِ وَمَعْصِيَتِ ٱلرَّسُولِ وَتَنَٰجَوْا۟ بِٱلْبِرِّ وَٱلتَّقْوَىٰ وَٱتَّقُوا۟ ٱللَّهَ ٱلَّذِىٓ إِلَيْهِ تُحْشَرُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcxiv{إِنَّمَا ٱلنَّجْوَىٰ مِنَ ٱلشَّيْطَٰنِ لِيَحْزُنَ ٱلَّذِينَ ءَامَنُوا۟ وَلَيْسَ بِضَآرِّهِمْ شَيْـًٔا إِلَّا بِإِذْنِ ٱللَّهِ وَعَلَى ٱللَّهِ فَلْيَتَوَكَّلِ ٱلْمُؤْمِنُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcxv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا قِيلَ لَكُمْ تَفَسَّحُوا۟ فِى ٱلْمَجَٰلِسِ فَٱفْسَحُوا۟ يَفْسَحِ ٱللَّهُ لَكُمْ وَإِذَا قِيلَ ٱنشُزُوا۟ فَٱنشُزُوا۟ يَرْفَعِ ٱللَّهُ ٱلَّذِينَ ءَامَنُوا۟ مِنكُمْ وَٱلَّذِينَ أُوتُوا۟ ٱلْعِلْمَ دَرَجَٰتٍ وَٱللَّهُ بِمَا تَعْمَلُونَ خَبِيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcxvi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا نَٰجَيْتُمُ ٱلرَّسُولَ فَقَدِّمُوا۟ بَيْنَ يَدَىْ نَجْوَىٰكُمْ صَدَقَةً ذَٰلِكَ خَيْرٌ لَّكُمْ وَأَطْهَرُ فَإِن لَّمْ تَجِدُوا۟ فَإِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcxvii{ءَأَشْفَقْتُمْ أَن تُقَدِّمُوا۟ بَيْنَ يَدَىْ نَجْوَىٰكُمْ صَدَقَٰتٍ فَإِذْ لَمْ تَفْعَلُوا۟ وَتَابَ ٱللَّهُ عَلَيْكُمْ فَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَءَاتُوا۟ ٱلزَّكَوٰةَ وَأَطِيعُوا۟ ٱللَّهَ وَرَسُولَهُۥ وَٱللَّهُ خَبِيرٌۢ بِمَا تَعْمَلُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcxviii{أَلَمْ تَرَ إِلَى ٱلَّذِينَ تَوَلَّوْا۟ قَوْمًا غَضِبَ ٱللَّهُ عَلَيْهِم مَّا هُم مِّنكُمْ وَلَا مِنْهُمْ وَيَحْلِفُونَ عَلَى ٱلْكَذِبِ وَهُمْ يَعْلَمُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcxix{أَعَدَّ ٱللَّهُ لَهُمْ عَذَابًا شَدِيدًا إِنَّهُمْ سَآءَ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcxx{ٱتَّخَذُوٓا۟ أَيْمَٰنَهُمْ جُنَّةً فَصَدُّوا۟ عَن سَبِيلِ ٱللَّهِ فَلَهُمْ عَذَابٌ مُّهِينٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcxxi{لَّن تُغْنِىَ عَنْهُمْ أَمْوَٰلُهُمْ وَلَآ أَوْلَٰدُهُم مِّنَ ٱللَّهِ شَيْـًٔا أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ هُمْ فِيهَا خَٰلِدُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcxxii{يَوْمَ يَبْعَثُهُمُ ٱللَّهُ جَمِيعًا فَيَحْلِفُونَ لَهُۥ كَمَا يَحْلِفُونَ لَكُمْ وَيَحْسَبُونَ أَنَّهُمْ عَلَىٰ شَىْءٍ أَلَآ إِنَّهُمْ هُمُ ٱلْكَٰذِبُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcxxiii{ٱسْتَحْوَذَ عَلَيْهِمُ ٱلشَّيْطَٰنُ فَأَنسَىٰهُمْ ذِكْرَ ٱللَّهِ أُو۟لَٰٓئِكَ حِزْبُ ٱلشَّيْطَٰنِ أَلَآ إِنَّ حِزْبَ ٱلشَّيْطَٰنِ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcxxiv{إِنَّ ٱلَّذِينَ يُحَآدُّونَ ٱللَّهَ وَرَسُولَهُۥٓ أُو۟لَٰٓئِكَ فِى ٱلْأَذَلِّينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcxxv{كَتَبَ ٱللَّهُ لَأَغْلِبَنَّ أَنَا۠ وَرُسُلِىٓ إِنَّ ٱللَّهَ قَوِىٌّ عَزِيزٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcxxvi{لَّا تَجِدُ قَوْمًا يُؤْمِنُونَ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ يُوَآدُّونَ مَنْ حَآدَّ ٱللَّهَ وَرَسُولَهُۥ وَلَوْ كَانُوٓا۟ ءَابَآءَهُمْ أَوْ أَبْنَآءَهُمْ أَوْ إِخْوَٰنَهُمْ أَوْ عَشِيرَتَهُمْ أُو۟لَٰٓئِكَ كَتَبَ فِى قُلُوبِهِمُ ٱلْإِيمَٰنَ وَأَيَّدَهُم بِرُوحٍ مِّنْهُ وَيُدْخِلُهُمْ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَا رَضِىَ ٱللَّهُ عَنْهُمْ وَرَضُوا۟ عَنْهُ أُو۟لَٰٓئِكَ حِزْبُ ٱللَّهِ أَلَآ إِنَّ حِزْبَ ٱللَّهِ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcxxvii{\basmalah سَبَّحَ لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcxxviii{هُوَ ٱلَّذِىٓ أَخْرَجَ ٱلَّذِينَ كَفَرُوا۟ مِنْ أَهْلِ ٱلْكِتَٰبِ مِن دِيَٰرِهِمْ لِأَوَّلِ ٱلْحَشْرِ مَا ظَنَنتُمْ أَن يَخْرُجُوا۟ وَظَنُّوٓا۟ أَنَّهُم مَّانِعَتُهُمْ حُصُونُهُم مِّنَ ٱللَّهِ فَأَتَىٰهُمُ ٱللَّهُ مِنْ حَيْثُ لَمْ يَحْتَسِبُوا۟ وَقَذَفَ فِى قُلُوبِهِمُ ٱلرُّعْبَ يُخْرِبُونَ بُيُوتَهُم بِأَيْدِيهِمْ وَأَيْدِى ٱلْمُؤْمِنِينَ فَٱعْتَبِرُوا۟ يَٰٓأُو۟لِى ٱلْأَبْصَٰرِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcxxix{وَلَوْلَآ أَن كَتَبَ ٱللَّهُ عَلَيْهِمُ ٱلْجَلَآءَ لَعَذَّبَهُمْ فِى ٱلدُّنْيَا وَلَهُمْ فِى ٱلْءَاخِرَةِ عَذَابُ ٱلنَّارِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcxxx{ذَٰلِكَ بِأَنَّهُمْ شَآقُّوا۟ ٱللَّهَ وَرَسُولَهُۥ وَمَن يُشَآقِّ ٱللَّهَ فَإِنَّ ٱللَّهَ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcxxxi{مَا قَطَعْتُم مِّن لِّينَةٍ أَوْ تَرَكْتُمُوهَا قَآئِمَةً عَلَىٰٓ أُصُولِهَا فَبِإِذْنِ ٱللَّهِ وَلِيُخْزِىَ ٱلْفَٰسِقِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcxxxii{وَمَآ أَفَآءَ ٱللَّهُ عَلَىٰ رَسُولِهِۦ مِنْهُمْ فَمَآ أَوْجَفْتُمْ عَلَيْهِ مِنْ خَيْلٍ وَلَا رِكَابٍ وَلَٰكِنَّ ٱللَّهَ يُسَلِّطُ رُسُلَهُۥ عَلَىٰ مَن يَشَآءُ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcxxxiii{مَّآ أَفَآءَ ٱللَّهُ عَلَىٰ رَسُولِهِۦ مِنْ أَهْلِ ٱلْقُرَىٰ فَلِلَّهِ وَلِلرَّسُولِ وَلِذِى ٱلْقُرْبَىٰ وَٱلْيَتَٰمَىٰ وَٱلْمَسَٰكِينِ وَٱبْنِ ٱلسَّبِيلِ كَىْ لَا يَكُونَ دُولَةًۢ بَيْنَ ٱلْأَغْنِيَآءِ مِنكُمْ وَمَآ ءَاتَىٰكُمُ ٱلرَّسُولُ فَخُذُوهُ وَمَا نَهَىٰكُمْ عَنْهُ فَٱنتَهُوا۟ وَٱتَّقُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ شَدِيدُ ٱلْعِقَابِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcxxxiv{لِلْفُقَرَآءِ ٱلْمُهَٰجِرِينَ ٱلَّذِينَ أُخْرِجُوا۟ مِن دِيَٰرِهِمْ وَأَمْوَٰلِهِمْ يَبْتَغُونَ فَضْلًا مِّنَ ٱللَّهِ وَرِضْوَٰنًا وَيَنصُرُونَ ٱللَّهَ وَرَسُولَهُۥٓ أُو۟لَٰٓئِكَ هُمُ ٱلصَّٰدِقُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcxxxv{وَٱلَّذِينَ تَبَوَّءُو ٱلدَّارَ وَٱلْإِيمَٰنَ مِن قَبْلِهِمْ يُحِبُّونَ مَنْ هَاجَرَ إِلَيْهِمْ وَلَا يَجِدُونَ فِى صُدُورِهِمْ حَاجَةً مِّمَّآ أُوتُوا۟ وَيُؤْثِرُونَ عَلَىٰٓ أَنفُسِهِمْ وَلَوْ كَانَ بِهِمْ خَصَاصَةٌ وَمَن يُوقَ شُحَّ نَفْسِهِۦ فَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcxxxvi{وَٱلَّذِينَ جَآءُو مِنۢ بَعْدِهِمْ يَقُولُونَ رَبَّنَا ٱغْفِرْ لَنَا وَلِإِخْوَٰنِنَا ٱلَّذِينَ سَبَقُونَا بِٱلْإِيمَٰنِ وَلَا تَجْعَلْ فِى قُلُوبِنَا غِلًّا لِّلَّذِينَ ءَامَنُوا۟ رَبَّنَآ إِنَّكَ رَءُوفٌ رَّحِيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcxxxvii{أَلَمْ تَرَ إِلَى ٱلَّذِينَ نَافَقُوا۟ يَقُولُونَ لِإِخْوَٰنِهِمُ ٱلَّذِينَ كَفَرُوا۟ مِنْ أَهْلِ ٱلْكِتَٰبِ لَئِنْ أُخْرِجْتُمْ لَنَخْرُجَنَّ مَعَكُمْ وَلَا نُطِيعُ فِيكُمْ أَحَدًا أَبَدًا وَإِن قُوتِلْتُمْ لَنَنصُرَنَّكُمْ وَٱللَّهُ يَشْهَدُ إِنَّهُمْ لَكَٰذِبُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcxxxviii{لَئِنْ أُخْرِجُوا۟ لَا يَخْرُجُونَ مَعَهُمْ وَلَئِن قُوتِلُوا۟ لَا يَنصُرُونَهُمْ وَلَئِن نَّصَرُوهُمْ لَيُوَلُّنَّ ٱلْأَدْبَٰرَ ثُمَّ لَا يُنصَرُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcxxxix{لَأَنتُمْ أَشَدُّ رَهْبَةً فِى صُدُورِهِم مِّنَ ٱللَّهِ ذَٰلِكَ بِأَنَّهُمْ قَوْمٌ لَّا يَفْقَهُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcxl{لَا يُقَٰتِلُونَكُمْ جَمِيعًا إِلَّا فِى قُرًى مُّحَصَّنَةٍ أَوْ مِن وَرَآءِ جُدُرٍۭ بَأْسُهُم بَيْنَهُمْ شَدِيدٌ تَحْسَبُهُمْ جَمِيعًا وَقُلُوبُهُمْ شَتَّىٰ ذَٰلِكَ بِأَنَّهُمْ قَوْمٌ لَّا يَعْقِلُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcxli{كَمَثَلِ ٱلَّذِينَ مِن قَبْلِهِمْ قَرِيبًا ذَاقُوا۟ وَبَالَ أَمْرِهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcxlii{كَمَثَلِ ٱلشَّيْطَٰنِ إِذْ قَالَ لِلْإِنسَٰنِ ٱكْفُرْ فَلَمَّا كَفَرَ قَالَ إِنِّى بَرِىٓءٌ مِّنكَ إِنِّىٓ أَخَافُ ٱللَّهَ رَبَّ ٱلْعَٰلَمِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcxliii{فَكَانَ عَٰقِبَتَهُمَآ أَنَّهُمَا فِى ٱلنَّارِ خَٰلِدَيْنِ فِيهَا وَذَٰلِكَ جَزَٰٓؤُا۟ ٱلظَّٰلِمِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcxliv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ ٱتَّقُوا۟ ٱللَّهَ وَلْتَنظُرْ نَفْسٌ مَّا قَدَّمَتْ لِغَدٍ وَٱتَّقُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ خَبِيرٌۢ بِمَا تَعْمَلُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcxlv{وَلَا تَكُونُوا۟ كَٱلَّذِينَ نَسُوا۟ ٱللَّهَ فَأَنسَىٰهُمْ أَنفُسَهُمْ أُو۟لَٰٓئِكَ هُمُ ٱلْفَٰسِقُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcxlvi{لَا يَسْتَوِىٓ أَصْحَٰبُ ٱلنَّارِ وَأَصْحَٰبُ ٱلْجَنَّةِ أَصْحَٰبُ ٱلْجَنَّةِ هُمُ ٱلْفَآئِزُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcxlvii{لَوْ أَنزَلْنَا هَٰذَا ٱلْقُرْءَانَ عَلَىٰ جَبَلٍ لَّرَأَيْتَهُۥ خَٰشِعًا مُّتَصَدِّعًا مِّنْ خَشْيَةِ ٱللَّهِ وَتِلْكَ ٱلْأَمْثَٰلُ نَضْرِبُهَا لِلنَّاسِ لَعَلَّهُمْ يَتَفَكَّرُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcxlviii{هُوَ ٱللَّهُ ٱلَّذِى لَآ إِلَٰهَ إِلَّا هُوَ عَٰلِمُ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ هُوَ ٱلرَّحْمَٰنُ ٱلرَّحِيمُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcxlix{هُوَ ٱللَّهُ ٱلَّذِى لَآ إِلَٰهَ إِلَّا هُوَ ٱلْمَلِكُ ٱلْقُدُّوسُ ٱلسَّلَٰمُ ٱلْمُؤْمِنُ ٱلْمُهَيْمِنُ ٱلْعَزِيزُ ٱلْجَبَّارُ ٱلْمُتَكَبِّرُ سُبْحَٰنَ ٱللَّهِ عَمَّا يُشْرِكُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcl{هُوَ ٱللَّهُ ٱلْخَٰلِقُ ٱلْبَارِئُ ٱلْمُصَوِّرُ لَهُ ٱلْأَسْمَآءُ ٱلْحُسْنَىٰ يُسَبِّحُ لَهُۥ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcli{\basmalah يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَتَّخِذُوا۟ عَدُوِّى وَعَدُوَّكُمْ أَوْلِيَآءَ تُلْقُونَ إِلَيْهِم بِٱلْمَوَدَّةِ وَقَدْ كَفَرُوا۟ بِمَا جَآءَكُم مِّنَ ٱلْحَقِّ يُخْرِجُونَ ٱلرَّسُولَ وَإِيَّاكُمْ أَن تُؤْمِنُوا۟ بِٱللَّهِ رَبِّكُمْ إِن كُنتُمْ خَرَجْتُمْ جِهَٰدًا فِى سَبِيلِى وَٱبْتِغَآءَ مَرْضَاتِى تُسِرُّونَ إِلَيْهِم بِٱلْمَوَدَّةِ وَأَنَا۠ أَعْلَمُ بِمَآ أَخْفَيْتُمْ وَمَآ أَعْلَنتُمْ وَمَن يَفْعَلْهُ مِنكُمْ فَقَدْ ضَلَّ سَوَآءَ ٱلسَّبِيلِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmclii{إِن يَثْقَفُوكُمْ يَكُونُوا۟ لَكُمْ أَعْدَآءً وَيَبْسُطُوٓا۟ إِلَيْكُمْ أَيْدِيَهُمْ وَأَلْسِنَتَهُم بِٱلسُّوٓءِ وَوَدُّوا۟ لَوْ تَكْفُرُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcliii{لَن تَنفَعَكُمْ أَرْحَامُكُمْ وَلَآ أَوْلَٰدُكُمْ يَوْمَ ٱلْقِيَٰمَةِ يَفْصِلُ بَيْنَكُمْ وَٱللَّهُ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcliv{قَدْ كَانَتْ لَكُمْ أُسْوَةٌ حَسَنَةٌ فِىٓ إِبْرَٰهِيمَ وَٱلَّذِينَ مَعَهُۥٓ إِذْ قَالُوا۟ لِقَوْمِهِمْ إِنَّا بُرَءَٰٓؤُا۟ مِنكُمْ وَمِمَّا تَعْبُدُونَ مِن دُونِ ٱللَّهِ كَفَرْنَا بِكُمْ وَبَدَا بَيْنَنَا وَبَيْنَكُمُ ٱلْعَدَٰوَةُ وَٱلْبَغْضَآءُ أَبَدًا حَتَّىٰ تُؤْمِنُوا۟ بِٱللَّهِ وَحْدَهُۥٓ إِلَّا قَوْلَ إِبْرَٰهِيمَ لِأَبِيهِ لَأَسْتَغْفِرَنَّ لَكَ وَمَآ أَمْلِكُ لَكَ مِنَ ٱللَّهِ مِن شَىْءٍ رَّبَّنَا عَلَيْكَ تَوَكَّلْنَا وَإِلَيْكَ أَنَبْنَا وَإِلَيْكَ ٱلْمَصِيرُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmclv{رَبَّنَا لَا تَجْعَلْنَا فِتْنَةً لِّلَّذِينَ كَفَرُوا۟ وَٱغْفِرْ لَنَا رَبَّنَآ إِنَّكَ أَنتَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmclvi{لَقَدْ كَانَ لَكُمْ فِيهِمْ أُسْوَةٌ حَسَنَةٌ لِّمَن كَانَ يَرْجُوا۟ ٱللَّهَ وَٱلْيَوْمَ ٱلْءَاخِرَ وَمَن يَتَوَلَّ فَإِنَّ ٱللَّهَ هُوَ ٱلْغَنِىُّ ٱلْحَمِيدُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmclvii{عَسَى ٱللَّهُ أَن يَجْعَلَ بَيْنَكُمْ وَبَيْنَ ٱلَّذِينَ عَادَيْتُم مِّنْهُم مَّوَدَّةً وَٱللَّهُ قَدِيرٌ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmclviii{لَّا يَنْهَىٰكُمُ ٱللَّهُ عَنِ ٱلَّذِينَ لَمْ يُقَٰتِلُوكُمْ فِى ٱلدِّينِ وَلَمْ يُخْرِجُوكُم مِّن دِيَٰرِكُمْ أَن تَبَرُّوهُمْ وَتُقْسِطُوٓا۟ إِلَيْهِمْ إِنَّ ٱللَّهَ يُحِبُّ ٱلْمُقْسِطِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmclix{إِنَّمَا يَنْهَىٰكُمُ ٱللَّهُ عَنِ ٱلَّذِينَ قَٰتَلُوكُمْ فِى ٱلدِّينِ وَأَخْرَجُوكُم مِّن دِيَٰرِكُمْ وَظَٰهَرُوا۟ عَلَىٰٓ إِخْرَاجِكُمْ أَن تَوَلَّوْهُمْ وَمَن يَتَوَلَّهُمْ فَأُو۟لَٰٓئِكَ هُمُ ٱلظَّٰلِمُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmclx{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا جَآءَكُمُ ٱلْمُؤْمِنَٰتُ مُهَٰجِرَٰتٍ فَٱمْتَحِنُوهُنَّ ٱللَّهُ أَعْلَمُ بِإِيمَٰنِهِنَّ فَإِنْ عَلِمْتُمُوهُنَّ مُؤْمِنَٰتٍ فَلَا تَرْجِعُوهُنَّ إِلَى ٱلْكُفَّارِ لَا هُنَّ حِلٌّ لَّهُمْ وَلَا هُمْ يَحِلُّونَ لَهُنَّ وَءَاتُوهُم مَّآ أَنفَقُوا۟ وَلَا جُنَاحَ عَلَيْكُمْ أَن تَنكِحُوهُنَّ إِذَآ ءَاتَيْتُمُوهُنَّ أُجُورَهُنَّ وَلَا تُمْسِكُوا۟ بِعِصَمِ ٱلْكَوَافِرِ وَسْـَٔلُوا۟ مَآ أَنفَقْتُمْ وَلْيَسْـَٔلُوا۟ مَآ أَنفَقُوا۟ ذَٰلِكُمْ حُكْمُ ٱللَّهِ يَحْكُمُ بَيْنَكُمْ وَٱللَّهُ عَلِيمٌ حَكِيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmclxi{وَإِن فَاتَكُمْ شَىْءٌ مِّنْ أَزْوَٰجِكُمْ إِلَى ٱلْكُفَّارِ فَعَاقَبْتُمْ فَـَٔاتُوا۟ ٱلَّذِينَ ذَهَبَتْ أَزْوَٰجُهُم مِّثْلَ مَآ أَنفَقُوا۟ وَٱتَّقُوا۟ ٱللَّهَ ٱلَّذِىٓ أَنتُم بِهِۦ مُؤْمِنُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmclxii{يَٰٓأَيُّهَا ٱلنَّبِىُّ إِذَا جَآءَكَ ٱلْمُؤْمِنَٰتُ يُبَايِعْنَكَ عَلَىٰٓ أَن لَّا يُشْرِكْنَ بِٱللَّهِ شَيْـًٔا وَلَا يَسْرِقْنَ وَلَا يَزْنِينَ وَلَا يَقْتُلْنَ أَوْلَٰدَهُنَّ وَلَا يَأْتِينَ بِبُهْتَٰنٍ يَفْتَرِينَهُۥ بَيْنَ أَيْدِيهِنَّ وَأَرْجُلِهِنَّ وَلَا يَعْصِينَكَ فِى مَعْرُوفٍ فَبَايِعْهُنَّ وَٱسْتَغْفِرْ لَهُنَّ ٱللَّهَ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmclxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تَتَوَلَّوْا۟ قَوْمًا غَضِبَ ٱللَّهُ عَلَيْهِمْ قَدْ يَئِسُوا۟ مِنَ ٱلْءَاخِرَةِ كَمَا يَئِسَ ٱلْكُفَّارُ مِنْ أَصْحَٰبِ ٱلْقُبُورِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmclxiv{\basmalah سَبَّحَ لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmclxv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لِمَ تَقُولُونَ مَا لَا تَفْعَلُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmclxvi{كَبُرَ مَقْتًا عِندَ ٱللَّهِ أَن تَقُولُوا۟ مَا لَا تَفْعَلُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmclxvii{إِنَّ ٱللَّهَ يُحِبُّ ٱلَّذِينَ يُقَٰتِلُونَ فِى سَبِيلِهِۦ صَفًّا كَأَنَّهُم بُنْيَٰنٌ مَّرْصُوصٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmclxviii{وَإِذْ قَالَ مُوسَىٰ لِقَوْمِهِۦ يَٰقَوْمِ لِمَ تُؤْذُونَنِى وَقَد تَّعْلَمُونَ أَنِّى رَسُولُ ٱللَّهِ إِلَيْكُمْ فَلَمَّا زَاغُوٓا۟ أَزَاغَ ٱللَّهُ قُلُوبَهُمْ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلْفَٰسِقِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmclxix{وَإِذْ قَالَ عِيسَى ٱبْنُ مَرْيَمَ يَٰبَنِىٓ إِسْرَٰٓءِيلَ إِنِّى رَسُولُ ٱللَّهِ إِلَيْكُم مُّصَدِّقًا لِّمَا بَيْنَ يَدَىَّ مِنَ ٱلتَّوْرَىٰةِ وَمُبَشِّرًۢا بِرَسُولٍ يَأْتِى مِنۢ بَعْدِى ٱسْمُهُۥٓ أَحْمَدُ فَلَمَّا جَآءَهُم بِٱلْبَيِّنَٰتِ قَالُوا۟ هَٰذَا سِحْرٌ مُّبِينٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmclxx{وَمَنْ أَظْلَمُ مِمَّنِ ٱفْتَرَىٰ عَلَى ٱللَّهِ ٱلْكَذِبَ وَهُوَ يُدْعَىٰٓ إِلَى ٱلْإِسْلَٰمِ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmclxxi{يُرِيدُونَ لِيُطْفِـُٔوا۟ نُورَ ٱللَّهِ بِأَفْوَٰهِهِمْ وَٱللَّهُ مُتِمُّ نُورِهِۦ وَلَوْ كَرِهَ ٱلْكَٰفِرُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmclxxii{هُوَ ٱلَّذِىٓ أَرْسَلَ رَسُولَهُۥ بِٱلْهُدَىٰ وَدِينِ ٱلْحَقِّ لِيُظْهِرَهُۥ عَلَى ٱلدِّينِ كُلِّهِۦ وَلَوْ كَرِهَ ٱلْمُشْرِكُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmclxxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ هَلْ أَدُلُّكُمْ عَلَىٰ تِجَٰرَةٍ تُنجِيكُم مِّنْ عَذَابٍ أَلِيمٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmclxxiv{تُؤْمِنُونَ بِٱللَّهِ وَرَسُولِهِۦ وَتُجَٰهِدُونَ فِى سَبِيلِ ٱللَّهِ بِأَمْوَٰلِكُمْ وَأَنفُسِكُمْ ذَٰلِكُمْ خَيْرٌ لَّكُمْ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmclxxv{يَغْفِرْ لَكُمْ ذُنُوبَكُمْ وَيُدْخِلْكُمْ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ وَمَسَٰكِنَ طَيِّبَةً فِى جَنَّٰتِ عَدْنٍ ذَٰلِكَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmclxxvi{وَأُخْرَىٰ تُحِبُّونَهَا نَصْرٌ مِّنَ ٱللَّهِ وَفَتْحٌ قَرِيبٌ وَبَشِّرِ ٱلْمُؤْمِنِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmclxxvii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ كُونُوٓا۟ أَنصَارَ ٱللَّهِ كَمَا قَالَ عِيسَى ٱبْنُ مَرْيَمَ لِلْحَوَارِيِّۦنَ مَنْ أَنصَارِىٓ إِلَى ٱللَّهِ قَالَ ٱلْحَوَارِيُّونَ نَحْنُ أَنصَارُ ٱللَّهِ فَـَٔامَنَت طَّآئِفَةٌ مِّنۢ بَنِىٓ إِسْرَٰٓءِيلَ وَكَفَرَت طَّآئِفَةٌ فَأَيَّدْنَا ٱلَّذِينَ ءَامَنُوا۟ عَلَىٰ عَدُوِّهِمْ فَأَصْبَحُوا۟ ظَٰهِرِينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmclxxviii{\basmalah يُسَبِّحُ لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ ٱلْمَلِكِ ٱلْقُدُّوسِ ٱلْعَزِيزِ ٱلْحَكِيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmclxxix{هُوَ ٱلَّذِى بَعَثَ فِى ٱلْأُمِّيِّۦنَ رَسُولًا مِّنْهُمْ يَتْلُوا۟ عَلَيْهِمْ ءَايَٰتِهِۦ وَيُزَكِّيهِمْ وَيُعَلِّمُهُمُ ٱلْكِتَٰبَ وَٱلْحِكْمَةَ وَإِن كَانُوا۟ مِن قَبْلُ لَفِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmclxxx{وَءَاخَرِينَ مِنْهُمْ لَمَّا يَلْحَقُوا۟ بِهِمْ وَهُوَ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmclxxxi{ذَٰلِكَ فَضْلُ ٱللَّهِ يُؤْتِيهِ مَن يَشَآءُ وَٱللَّهُ ذُو ٱلْفَضْلِ ٱلْعَظِيمِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmclxxxii{مَثَلُ ٱلَّذِينَ حُمِّلُوا۟ ٱلتَّوْرَىٰةَ ثُمَّ لَمْ يَحْمِلُوهَا كَمَثَلِ ٱلْحِمَارِ يَحْمِلُ أَسْفَارًۢا بِئْسَ مَثَلُ ٱلْقَوْمِ ٱلَّذِينَ كَذَّبُوا۟ بِـَٔايَٰتِ ٱللَّهِ وَٱللَّهُ لَا يَهْدِى ٱلْقَوْمَ ٱلظَّٰلِمِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmclxxxiii{قُلْ يَٰٓأَيُّهَا ٱلَّذِينَ هَادُوٓا۟ إِن زَعَمْتُمْ أَنَّكُمْ أَوْلِيَآءُ لِلَّهِ مِن دُونِ ٱلنَّاسِ فَتَمَنَّوُا۟ ٱلْمَوْتَ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmclxxxiv{وَلَا يَتَمَنَّوْنَهُۥٓ أَبَدًۢا بِمَا قَدَّمَتْ أَيْدِيهِمْ وَٱللَّهُ عَلِيمٌۢ بِٱلظَّٰلِمِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmclxxxv{قُلْ إِنَّ ٱلْمَوْتَ ٱلَّذِى تَفِرُّونَ مِنْهُ فَإِنَّهُۥ مُلَٰقِيكُمْ ثُمَّ تُرَدُّونَ إِلَىٰ عَٰلِمِ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ فَيُنَبِّئُكُم بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmclxxxvi{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِذَا نُودِىَ لِلصَّلَوٰةِ مِن يَوْمِ ٱلْجُمُعَةِ فَٱسْعَوْا۟ إِلَىٰ ذِكْرِ ٱللَّهِ وَذَرُوا۟ ٱلْبَيْعَ ذَٰلِكُمْ خَيْرٌ لَّكُمْ إِن كُنتُمْ تَعْلَمُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmclxxxvii{فَإِذَا قُضِيَتِ ٱلصَّلَوٰةُ فَٱنتَشِرُوا۟ فِى ٱلْأَرْضِ وَٱبْتَغُوا۟ مِن فَضْلِ ٱللَّهِ وَٱذْكُرُوا۟ ٱللَّهَ كَثِيرًا لَّعَلَّكُمْ تُفْلِحُونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmclxxxviii{وَإِذَا رَأَوْا۟ تِجَٰرَةً أَوْ لَهْوًا ٱنفَضُّوٓا۟ إِلَيْهَا وَتَرَكُوكَ قَآئِمًا قُلْ مَا عِندَ ٱللَّهِ خَيْرٌ مِّنَ ٱللَّهْوِ وَمِنَ ٱلتِّجَٰرَةِ وَٱللَّهُ خَيْرُ ٱلرَّٰزِقِينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmclxxxix{\basmalah إِذَا جَآءَكَ ٱلْمُنَٰفِقُونَ قَالُوا۟ نَشْهَدُ إِنَّكَ لَرَسُولُ ٱللَّهِ وَٱللَّهُ يَعْلَمُ إِنَّكَ لَرَسُولُهُۥ وَٱللَّهُ يَشْهَدُ إِنَّ ٱلْمُنَٰفِقِينَ لَكَٰذِبُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcxc{ٱتَّخَذُوٓا۟ أَيْمَٰنَهُمْ جُنَّةً فَصَدُّوا۟ عَن سَبِيلِ ٱللَّهِ إِنَّهُمْ سَآءَ مَا كَانُوا۟ يَعْمَلُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcxci{ذَٰلِكَ بِأَنَّهُمْ ءَامَنُوا۟ ثُمَّ كَفَرُوا۟ فَطُبِعَ عَلَىٰ قُلُوبِهِمْ فَهُمْ لَا يَفْقَهُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcxcii{وَإِذَا رَأَيْتَهُمْ تُعْجِبُكَ أَجْسَامُهُمْ وَإِن يَقُولُوا۟ تَسْمَعْ لِقَوْلِهِمْ كَأَنَّهُمْ خُشُبٌ مُّسَنَّدَةٌ يَحْسَبُونَ كُلَّ صَيْحَةٍ عَلَيْهِمْ هُمُ ٱلْعَدُوُّ فَٱحْذَرْهُمْ قَٰتَلَهُمُ ٱللَّهُ أَنَّىٰ يُؤْفَكُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcxciii{وَإِذَا قِيلَ لَهُمْ تَعَالَوْا۟ يَسْتَغْفِرْ لَكُمْ رَسُولُ ٱللَّهِ لَوَّوْا۟ رُءُوسَهُمْ وَرَأَيْتَهُمْ يَصُدُّونَ وَهُم مُّسْتَكْبِرُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcxciv{سَوَآءٌ عَلَيْهِمْ أَسْتَغْفَرْتَ لَهُمْ أَمْ لَمْ تَسْتَغْفِرْ لَهُمْ لَن يَغْفِرَ ٱللَّهُ لَهُمْ إِنَّ ٱللَّهَ لَا يَهْدِى ٱلْقَوْمَ ٱلْفَٰسِقِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcxcv{هُمُ ٱلَّذِينَ يَقُولُونَ لَا تُنفِقُوا۟ عَلَىٰ مَنْ عِندَ رَسُولِ ٱللَّهِ حَتَّىٰ يَنفَضُّوا۟ وَلِلَّهِ خَزَآئِنُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَلَٰكِنَّ ٱلْمُنَٰفِقِينَ لَا يَفْقَهُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcxcvi{يَقُولُونَ لَئِن رَّجَعْنَآ إِلَى ٱلْمَدِينَةِ لَيُخْرِجَنَّ ٱلْأَعَزُّ مِنْهَا ٱلْأَذَلَّ وَلِلَّهِ ٱلْعِزَّةُ وَلِرَسُولِهِۦ وَلِلْمُؤْمِنِينَ وَلَٰكِنَّ ٱلْمُنَٰفِقِينَ لَا يَعْلَمُونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcxcvii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ لَا تُلْهِكُمْ أَمْوَٰلُكُمْ وَلَآ أَوْلَٰدُكُمْ عَن ذِكْرِ ٱللَّهِ وَمَن يَفْعَلْ ذَٰلِكَ فَأُو۟لَٰٓئِكَ هُمُ ٱلْخَٰسِرُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcxcviii{وَأَنفِقُوا۟ مِن مَّا رَزَقْنَٰكُم مِّن قَبْلِ أَن يَأْتِىَ أَحَدَكُمُ ٱلْمَوْتُ فَيَقُولَ رَبِّ لَوْلَآ أَخَّرْتَنِىٓ إِلَىٰٓ أَجَلٍ قَرِيبٍ فَأَصَّدَّقَ وَأَكُن مِّنَ ٱلصَّٰلِحِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcxcix{وَلَن يُؤَخِّرَ ٱللَّهُ نَفْسًا إِذَا جَآءَ أَجَلُهَا وَٱللَّهُ خَبِيرٌۢ بِمَا تَعْمَلُونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcc{\basmalah يُسَبِّحُ لِلَّهِ مَا فِى ٱلسَّمَٰوَٰتِ وَمَا فِى ٱلْأَرْضِ لَهُ ٱلْمُلْكُ وَلَهُ ٱلْحَمْدُ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcci{هُوَ ٱلَّذِى خَلَقَكُمْ فَمِنكُمْ كَافِرٌ وَمِنكُم مُّؤْمِنٌ وَٱللَّهُ بِمَا تَعْمَلُونَ بَصِيرٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccii{خَلَقَ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضَ بِٱلْحَقِّ وَصَوَّرَكُمْ فَأَحْسَنَ صُوَرَكُمْ وَإِلَيْهِ ٱلْمَصِيرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcciii{يَعْلَمُ مَا فِى ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَيَعْلَمُ مَا تُسِرُّونَ وَمَا تُعْلِنُونَ وَٱللَّهُ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcciv{أَلَمْ يَأْتِكُمْ نَبَؤُا۟ ٱلَّذِينَ كَفَرُوا۟ مِن قَبْلُ فَذَاقُوا۟ وَبَالَ أَمْرِهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccv{ذَٰلِكَ بِأَنَّهُۥ كَانَت تَّأْتِيهِمْ رُسُلُهُم بِٱلْبَيِّنَٰتِ فَقَالُوٓا۟ أَبَشَرٌ يَهْدُونَنَا فَكَفَرُوا۟ وَتَوَلَّوا۟ وَّٱسْتَغْنَى ٱللَّهُ وَٱللَّهُ غَنِىٌّ حَمِيدٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccvi{زَعَمَ ٱلَّذِينَ كَفَرُوٓا۟ أَن لَّن يُبْعَثُوا۟ قُلْ بَلَىٰ وَرَبِّى لَتُبْعَثُنَّ ثُمَّ لَتُنَبَّؤُنَّ بِمَا عَمِلْتُمْ وَذَٰلِكَ عَلَى ٱللَّهِ يَسِيرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccvii{فَـَٔامِنُوا۟ بِٱللَّهِ وَرَسُولِهِۦ وَٱلنُّورِ ٱلَّذِىٓ أَنزَلْنَا وَٱللَّهُ بِمَا تَعْمَلُونَ خَبِيرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccviii{يَوْمَ يَجْمَعُكُمْ لِيَوْمِ ٱلْجَمْعِ ذَٰلِكَ يَوْمُ ٱلتَّغَابُنِ وَمَن يُؤْمِنۢ بِٱللَّهِ وَيَعْمَلْ صَٰلِحًا يُكَفِّرْ عَنْهُ سَيِّـَٔاتِهِۦ وَيُدْخِلْهُ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَآ أَبَدًا ذَٰلِكَ ٱلْفَوْزُ ٱلْعَظِيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccix{وَٱلَّذِينَ كَفَرُوا۟ وَكَذَّبُوا۟ بِـَٔايَٰتِنَآ أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلنَّارِ خَٰلِدِينَ فِيهَا وَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccx{مَآ أَصَابَ مِن مُّصِيبَةٍ إِلَّا بِإِذْنِ ٱللَّهِ وَمَن يُؤْمِنۢ بِٱللَّهِ يَهْدِ قَلْبَهُۥ وَٱللَّهُ بِكُلِّ شَىْءٍ عَلِيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccxi{وَأَطِيعُوا۟ ٱللَّهَ وَأَطِيعُوا۟ ٱلرَّسُولَ فَإِن تَوَلَّيْتُمْ فَإِنَّمَا عَلَىٰ رَسُولِنَا ٱلْبَلَٰغُ ٱلْمُبِينُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccxii{ٱللَّهُ لَآ إِلَٰهَ إِلَّا هُوَ وَعَلَى ٱللَّهِ فَلْيَتَوَكَّلِ ٱلْمُؤْمِنُونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmccxiii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوٓا۟ إِنَّ مِنْ أَزْوَٰجِكُمْ وَأَوْلَٰدِكُمْ عَدُوًّا لَّكُمْ فَٱحْذَرُوهُمْ وَإِن تَعْفُوا۟ وَتَصْفَحُوا۟ وَتَغْفِرُوا۟ فَإِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmccxiv{إِنَّمَآ أَمْوَٰلُكُمْ وَأَوْلَٰدُكُمْ فِتْنَةٌ وَٱللَّهُ عِندَهُۥٓ أَجْرٌ عَظِيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmccxv{فَٱتَّقُوا۟ ٱللَّهَ مَا ٱسْتَطَعْتُمْ وَٱسْمَعُوا۟ وَأَطِيعُوا۟ وَأَنفِقُوا۟ خَيْرًا لِّأَنفُسِكُمْ وَمَن يُوقَ شُحَّ نَفْسِهِۦ فَأُو۟لَٰٓئِكَ هُمُ ٱلْمُفْلِحُونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmccxvi{إِن تُقْرِضُوا۟ ٱللَّهَ قَرْضًا حَسَنًا يُضَٰعِفْهُ لَكُمْ وَيَغْفِرْ لَكُمْ وَٱللَّهُ شَكُورٌ حَلِيمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmccxvii{عَٰلِمُ ٱلْغَيْبِ وَٱلشَّهَٰدَةِ ٱلْعَزِيزُ ٱلْحَكِيمُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmccxviii{\basmalah يَٰٓأَيُّهَا ٱلنَّبِىُّ إِذَا طَلَّقْتُمُ ٱلنِّسَآءَ فَطَلِّقُوهُنَّ لِعِدَّتِهِنَّ وَأَحْصُوا۟ ٱلْعِدَّةَ وَٱتَّقُوا۟ ٱللَّهَ رَبَّكُمْ لَا تُخْرِجُوهُنَّ مِنۢ بُيُوتِهِنَّ وَلَا يَخْرُجْنَ إِلَّآ أَن يَأْتِينَ بِفَٰحِشَةٍ مُّبَيِّنَةٍ وَتِلْكَ حُدُودُ ٱللَّهِ وَمَن يَتَعَدَّ حُدُودَ ٱللَّهِ فَقَدْ ظَلَمَ نَفْسَهُۥ لَا تَدْرِى لَعَلَّ ٱللَّهَ يُحْدِثُ بَعْدَ ذَٰلِكَ أَمْرًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccxix{فَإِذَا بَلَغْنَ أَجَلَهُنَّ فَأَمْسِكُوهُنَّ بِمَعْرُوفٍ أَوْ فَارِقُوهُنَّ بِمَعْرُوفٍ وَأَشْهِدُوا۟ ذَوَىْ عَدْلٍ مِّنكُمْ وَأَقِيمُوا۟ ٱلشَّهَٰدَةَ لِلَّهِ ذَٰلِكُمْ يُوعَظُ بِهِۦ مَن كَانَ يُؤْمِنُ بِٱللَّهِ وَٱلْيَوْمِ ٱلْءَاخِرِ وَمَن يَتَّقِ ٱللَّهَ يَجْعَل لَّهُۥ مَخْرَجًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccxx{وَيَرْزُقْهُ مِنْ حَيْثُ لَا يَحْتَسِبُ وَمَن يَتَوَكَّلْ عَلَى ٱللَّهِ فَهُوَ حَسْبُهُۥٓ إِنَّ ٱللَّهَ بَٰلِغُ أَمْرِهِۦ قَدْ جَعَلَ ٱللَّهُ لِكُلِّ شَىْءٍ قَدْرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccxxi{وَٱلَّٰٓـِٔى يَئِسْنَ مِنَ ٱلْمَحِيضِ مِن نِّسَآئِكُمْ إِنِ ٱرْتَبْتُمْ فَعِدَّتُهُنَّ ثَلَٰثَةُ أَشْهُرٍ وَٱلَّٰٓـِٔى لَمْ يَحِضْنَ وَأُو۟لَٰتُ ٱلْأَحْمَالِ أَجَلُهُنَّ أَن يَضَعْنَ حَمْلَهُنَّ وَمَن يَتَّقِ ٱللَّهَ يَجْعَل لَّهُۥ مِنْ أَمْرِهِۦ يُسْرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccxxii{ذَٰلِكَ أَمْرُ ٱللَّهِ أَنزَلَهُۥٓ إِلَيْكُمْ وَمَن يَتَّقِ ٱللَّهَ يُكَفِّرْ عَنْهُ سَيِّـَٔاتِهِۦ وَيُعْظِمْ لَهُۥٓ أَجْرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccxxiii{أَسْكِنُوهُنَّ مِنْ حَيْثُ سَكَنتُم مِّن وُجْدِكُمْ وَلَا تُضَآرُّوهُنَّ لِتُضَيِّقُوا۟ عَلَيْهِنَّ وَإِن كُنَّ أُو۟لَٰتِ حَمْلٍ فَأَنفِقُوا۟ عَلَيْهِنَّ حَتَّىٰ يَضَعْنَ حَمْلَهُنَّ فَإِنْ أَرْضَعْنَ لَكُمْ فَـَٔاتُوهُنَّ أُجُورَهُنَّ وَأْتَمِرُوا۟ بَيْنَكُم بِمَعْرُوفٍ وَإِن تَعَاسَرْتُمْ فَسَتُرْضِعُ لَهُۥٓ أُخْرَىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccxxiv{لِيُنفِقْ ذُو سَعَةٍ مِّن سَعَتِهِۦ وَمَن قُدِرَ عَلَيْهِ رِزْقُهُۥ فَلْيُنفِقْ مِمَّآ ءَاتَىٰهُ ٱللَّهُ لَا يُكَلِّفُ ٱللَّهُ نَفْسًا إِلَّا مَآ ءَاتَىٰهَا سَيَجْعَلُ ٱللَّهُ بَعْدَ عُسْرٍ يُسْرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccxxv{وَكَأَيِّن مِّن قَرْيَةٍ عَتَتْ عَنْ أَمْرِ رَبِّهَا وَرُسُلِهِۦ فَحَاسَبْنَٰهَا حِسَابًا شَدِيدًا وَعَذَّبْنَٰهَا عَذَابًا نُّكْرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccxxvi{فَذَاقَتْ وَبَالَ أَمْرِهَا وَكَانَ عَٰقِبَةُ أَمْرِهَا خُسْرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccxxvii{أَعَدَّ ٱللَّهُ لَهُمْ عَذَابًا شَدِيدًا فَٱتَّقُوا۟ ٱللَّهَ يَٰٓأُو۟لِى ٱلْأَلْبَٰبِ ٱلَّذِينَ ءَامَنُوا۟ قَدْ أَنزَلَ ٱللَّهُ إِلَيْكُمْ ذِكْرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccxxviii{رَّسُولًا يَتْلُوا۟ عَلَيْكُمْ ءَايَٰتِ ٱللَّهِ مُبَيِّنَٰتٍ لِّيُخْرِجَ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ مِنَ ٱلظُّلُمَٰتِ إِلَى ٱلنُّورِ وَمَن يُؤْمِنۢ بِٱللَّهِ وَيَعْمَلْ صَٰلِحًا يُدْخِلْهُ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَآ أَبَدًا قَدْ أَحْسَنَ ٱللَّهُ لَهُۥ رِزْقًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccxxix{ٱللَّهُ ٱلَّذِى خَلَقَ سَبْعَ سَمَٰوَٰتٍ وَمِنَ ٱلْأَرْضِ مِثْلَهُنَّ يَتَنَزَّلُ ٱلْأَمْرُ بَيْنَهُنَّ لِتَعْلَمُوٓا۟ أَنَّ ٱللَّهَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ وَأَنَّ ٱللَّهَ قَدْ أَحَاطَ بِكُلِّ شَىْءٍ عِلْمًۢا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccxxx{\basmalah يَٰٓأَيُّهَا ٱلنَّبِىُّ لِمَ تُحَرِّمُ مَآ أَحَلَّ ٱللَّهُ لَكَ تَبْتَغِى مَرْضَاتَ أَزْوَٰجِكَ وَٱللَّهُ غَفُورٌ رَّحِيمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccxxxi{قَدْ فَرَضَ ٱللَّهُ لَكُمْ تَحِلَّةَ أَيْمَٰنِكُمْ وَٱللَّهُ مَوْلَىٰكُمْ وَهُوَ ٱلْعَلِيمُ ٱلْحَكِيمُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccxxxii{وَإِذْ أَسَرَّ ٱلنَّبِىُّ إِلَىٰ بَعْضِ أَزْوَٰجِهِۦ حَدِيثًا فَلَمَّا نَبَّأَتْ بِهِۦ وَأَظْهَرَهُ ٱللَّهُ عَلَيْهِ عَرَّفَ بَعْضَهُۥ وَأَعْرَضَ عَنۢ بَعْضٍ فَلَمَّا نَبَّأَهَا بِهِۦ قَالَتْ مَنْ أَنۢبَأَكَ هَٰذَا قَالَ نَبَّأَنِىَ ٱلْعَلِيمُ ٱلْخَبِيرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccxxxiii{إِن تَتُوبَآ إِلَى ٱللَّهِ فَقَدْ صَغَتْ قُلُوبُكُمَا وَإِن تَظَٰهَرَا عَلَيْهِ فَإِنَّ ٱللَّهَ هُوَ مَوْلَىٰهُ وَجِبْرِيلُ وَصَٰلِحُ ٱلْمُؤْمِنِينَ وَٱلْمَلَٰٓئِكَةُ بَعْدَ ذَٰلِكَ ظَهِيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccxxxiv{عَسَىٰ رَبُّهُۥٓ إِن طَلَّقَكُنَّ أَن يُبْدِلَهُۥٓ أَزْوَٰجًا خَيْرًا مِّنكُنَّ مُسْلِمَٰتٍ مُّؤْمِنَٰتٍ قَٰنِتَٰتٍ تَٰٓئِبَٰتٍ عَٰبِدَٰتٍ سَٰٓئِحَٰتٍ ثَيِّبَٰتٍ وَأَبْكَارًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccxxxv{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ قُوٓا۟ أَنفُسَكُمْ وَأَهْلِيكُمْ نَارًا وَقُودُهَا ٱلنَّاسُ وَٱلْحِجَارَةُ عَلَيْهَا مَلَٰٓئِكَةٌ غِلَاظٌ شِدَادٌ لَّا يَعْصُونَ ٱللَّهَ مَآ أَمَرَهُمْ وَيَفْعَلُونَ مَا يُؤْمَرُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccxxxvi{يَٰٓأَيُّهَا ٱلَّذِينَ كَفَرُوا۟ لَا تَعْتَذِرُوا۟ ٱلْيَوْمَ إِنَّمَا تُجْزَوْنَ مَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccxxxvii{يَٰٓأَيُّهَا ٱلَّذِينَ ءَامَنُوا۟ تُوبُوٓا۟ إِلَى ٱللَّهِ تَوْبَةً نَّصُوحًا عَسَىٰ رَبُّكُمْ أَن يُكَفِّرَ عَنكُمْ سَيِّـَٔاتِكُمْ وَيُدْخِلَكُمْ جَنَّٰتٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ يَوْمَ لَا يُخْزِى ٱللَّهُ ٱلنَّبِىَّ وَٱلَّذِينَ ءَامَنُوا۟ مَعَهُۥ نُورُهُمْ يَسْعَىٰ بَيْنَ أَيْدِيهِمْ وَبِأَيْمَٰنِهِمْ يَقُولُونَ رَبَّنَآ أَتْمِمْ لَنَا نُورَنَا وَٱغْفِرْ لَنَآ إِنَّكَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccxxxviii{يَٰٓأَيُّهَا ٱلنَّبِىُّ جَٰهِدِ ٱلْكُفَّارَ وَٱلْمُنَٰفِقِينَ وَٱغْلُظْ عَلَيْهِمْ وَمَأْوَىٰهُمْ جَهَنَّمُ وَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccxxxix{ضَرَبَ ٱللَّهُ مَثَلًا لِّلَّذِينَ كَفَرُوا۟ ٱمْرَأَتَ نُوحٍ وَٱمْرَأَتَ لُوطٍ كَانَتَا تَحْتَ عَبْدَيْنِ مِنْ عِبَادِنَا صَٰلِحَيْنِ فَخَانَتَاهُمَا فَلَمْ يُغْنِيَا عَنْهُمَا مِنَ ٱللَّهِ شَيْـًٔا وَقِيلَ ٱدْخُلَا ٱلنَّارَ مَعَ ٱلدَّٰخِلِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccxl{وَضَرَبَ ٱللَّهُ مَثَلًا لِّلَّذِينَ ءَامَنُوا۟ ٱمْرَأَتَ فِرْعَوْنَ إِذْ قَالَتْ رَبِّ ٱبْنِ لِى عِندَكَ بَيْتًا فِى ٱلْجَنَّةِ وَنَجِّنِى مِن فِرْعَوْنَ وَعَمَلِهِۦ وَنَجِّنِى مِنَ ٱلْقَوْمِ ٱلظَّٰلِمِينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccxli{وَمَرْيَمَ ٱبْنَتَ عِمْرَٰنَ ٱلَّتِىٓ أَحْصَنَتْ فَرْجَهَا فَنَفَخْنَا فِيهِ مِن رُّوحِنَا وَصَدَّقَتْ بِكَلِمَٰتِ رَبِّهَا وَكُتُبِهِۦ وَكَانَتْ مِنَ ٱلْقَٰنِتِينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccxlii{\basmalah تَبَٰرَكَ ٱلَّذِى بِيَدِهِ ٱلْمُلْكُ وَهُوَ عَلَىٰ كُلِّ شَىْءٍ قَدِيرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccxliii{ٱلَّذِى خَلَقَ ٱلْمَوْتَ وَٱلْحَيَوٰةَ لِيَبْلُوَكُمْ أَيُّكُمْ أَحْسَنُ عَمَلًا وَهُوَ ٱلْعَزِيزُ ٱلْغَفُورُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccxliv{ٱلَّذِى خَلَقَ سَبْعَ سَمَٰوَٰتٍ طِبَاقًا مَّا تَرَىٰ فِى خَلْقِ ٱلرَّحْمَٰنِ مِن تَفَٰوُتٍ فَٱرْجِعِ ٱلْبَصَرَ هَلْ تَرَىٰ مِن فُطُورٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccxlv{ثُمَّ ٱرْجِعِ ٱلْبَصَرَ كَرَّتَيْنِ يَنقَلِبْ إِلَيْكَ ٱلْبَصَرُ خَاسِئًا وَهُوَ حَسِيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccxlvi{وَلَقَدْ زَيَّنَّا ٱلسَّمَآءَ ٱلدُّنْيَا بِمَصَٰبِيحَ وَجَعَلْنَٰهَا رُجُومًا لِّلشَّيَٰطِينِ وَأَعْتَدْنَا لَهُمْ عَذَابَ ٱلسَّعِيرِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccxlvii{وَلِلَّذِينَ كَفَرُوا۟ بِرَبِّهِمْ عَذَابُ جَهَنَّمَ وَبِئْسَ ٱلْمَصِيرُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccxlviii{إِذَآ أُلْقُوا۟ فِيهَا سَمِعُوا۟ لَهَا شَهِيقًا وَهِىَ تَفُورُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccxlix{تَكَادُ تَمَيَّزُ مِنَ ٱلْغَيْظِ كُلَّمَآ أُلْقِىَ فِيهَا فَوْجٌ سَأَلَهُمْ خَزَنَتُهَآ أَلَمْ يَأْتِكُمْ نَذِيرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccl{قَالُوا۟ بَلَىٰ قَدْ جَآءَنَا نَذِيرٌ فَكَذَّبْنَا وَقُلْنَا مَا نَزَّلَ ٱللَّهُ مِن شَىْءٍ إِنْ أَنتُمْ إِلَّا فِى ضَلَٰلٍ كَبِيرٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccli{وَقَالُوا۟ لَوْ كُنَّا نَسْمَعُ أَوْ نَعْقِلُ مَا كُنَّا فِىٓ أَصْحَٰبِ ٱلسَّعِيرِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcclii{فَٱعْتَرَفُوا۟ بِذَنۢبِهِمْ فَسُحْقًا لِّأَصْحَٰبِ ٱلسَّعِيرِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccliii{إِنَّ ٱلَّذِينَ يَخْشَوْنَ رَبَّهُم بِٱلْغَيْبِ لَهُم مَّغْفِرَةٌ وَأَجْرٌ كَبِيرٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccliv{وَأَسِرُّوا۟ قَوْلَكُمْ أَوِ ٱجْهَرُوا۟ بِهِۦٓ إِنَّهُۥ عَلِيمٌۢ بِذَاتِ ٱلصُّدُورِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcclv{أَلَا يَعْلَمُ مَنْ خَلَقَ وَهُوَ ٱللَّطِيفُ ٱلْخَبِيرُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcclvi{هُوَ ٱلَّذِى جَعَلَ لَكُمُ ٱلْأَرْضَ ذَلُولًا فَٱمْشُوا۟ فِى مَنَاكِبِهَا وَكُلُوا۟ مِن رِّزْقِهِۦ وَإِلَيْهِ ٱلنُّشُورُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcclvii{ءَأَمِنتُم مَّن فِى ٱلسَّمَآءِ أَن يَخْسِفَ بِكُمُ ٱلْأَرْضَ فَإِذَا هِىَ تَمُورُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcclviii{أَمْ أَمِنتُم مَّن فِى ٱلسَّمَآءِ أَن يُرْسِلَ عَلَيْكُمْ حَاصِبًا فَسَتَعْلَمُونَ كَيْفَ نَذِيرِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcclix{وَلَقَدْ كَذَّبَ ٱلَّذِينَ مِن قَبْلِهِمْ فَكَيْفَ كَانَ نَكِيرِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcclx{أَوَلَمْ يَرَوْا۟ إِلَى ٱلطَّيْرِ فَوْقَهُمْ صَٰٓفَّٰتٍ وَيَقْبِضْنَ مَا يُمْسِكُهُنَّ إِلَّا ٱلرَّحْمَٰنُ إِنَّهُۥ بِكُلِّ شَىْءٍۭ بَصِيرٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcclxi{أَمَّنْ هَٰذَا ٱلَّذِى هُوَ جُندٌ لَّكُمْ يَنصُرُكُم مِّن دُونِ ٱلرَّحْمَٰنِ إِنِ ٱلْكَٰفِرُونَ إِلَّا فِى غُرُورٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcclxii{أَمَّنْ هَٰذَا ٱلَّذِى يَرْزُقُكُمْ إِنْ أَمْسَكَ رِزْقَهُۥ بَل لَّجُّوا۟ فِى عُتُوٍّ وَنُفُورٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcclxiii{أَفَمَن يَمْشِى مُكِبًّا عَلَىٰ وَجْهِهِۦٓ أَهْدَىٰٓ أَمَّن يَمْشِى سَوِيًّا عَلَىٰ صِرَٰطٍ مُّسْتَقِيمٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcclxiv{قُلْ هُوَ ٱلَّذِىٓ أَنشَأَكُمْ وَجَعَلَ لَكُمُ ٱلسَّمْعَ وَٱلْأَبْصَٰرَ وَٱلْأَفْـِٔدَةَ قَلِيلًا مَّا تَشْكُرُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcclxv{قُلْ هُوَ ٱلَّذِى ذَرَأَكُمْ فِى ٱلْأَرْضِ وَإِلَيْهِ تُحْشَرُونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcclxvi{وَيَقُولُونَ مَتَىٰ هَٰذَا ٱلْوَعْدُ إِن كُنتُمْ صَٰدِقِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcclxvii{قُلْ إِنَّمَا ٱلْعِلْمُ عِندَ ٱللَّهِ وَإِنَّمَآ أَنَا۠ نَذِيرٌ مُّبِينٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcclxviii{فَلَمَّا رَأَوْهُ زُلْفَةً سِيٓـَٔتْ وُجُوهُ ٱلَّذِينَ كَفَرُوا۟ وَقِيلَ هَٰذَا ٱلَّذِى كُنتُم بِهِۦ تَدَّعُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcclxix{قُلْ أَرَءَيْتُمْ إِنْ أَهْلَكَنِىَ ٱللَّهُ وَمَن مَّعِىَ أَوْ رَحِمَنَا فَمَن يُجِيرُ ٱلْكَٰفِرِينَ مِنْ عَذَابٍ أَلِيمٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcclxx{قُلْ هُوَ ٱلرَّحْمَٰنُ ءَامَنَّا بِهِۦ وَعَلَيْهِ تَوَكَّلْنَا فَسَتَعْلَمُونَ مَنْ هُوَ فِى ضَلَٰلٍ مُّبِينٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcclxxi{قُلْ أَرَءَيْتُمْ إِنْ أَصْبَحَ مَآؤُكُمْ غَوْرًا فَمَن يَأْتِيكُم بِمَآءٍ مَّعِينٍۭ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcclxxii{\basmalah نٓ وَٱلْقَلَمِ وَمَا يَسْطُرُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcclxxiii{مَآ أَنتَ بِنِعْمَةِ رَبِّكَ بِمَجْنُونٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcclxxiv{وَإِنَّ لَكَ لَأَجْرًا غَيْرَ مَمْنُونٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcclxxv{وَإِنَّكَ لَعَلَىٰ خُلُقٍ عَظِيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcclxxvi{فَسَتُبْصِرُ وَيُبْصِرُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcclxxvii{بِأَييِّكُمُ ٱلْمَفْتُونُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcclxxviii{إِنَّ رَبَّكَ هُوَ أَعْلَمُ بِمَن ضَلَّ عَن سَبِيلِهِۦ وَهُوَ أَعْلَمُ بِٱلْمُهْتَدِينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcclxxix{فَلَا تُطِعِ ٱلْمُكَذِّبِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcclxxx{وَدُّوا۟ لَوْ تُدْهِنُ فَيُدْهِنُونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxi{وَلَا تُطِعْ كُلَّ حَلَّافٍ مَّهِينٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxii{هَمَّازٍ مَّشَّآءٍۭ بِنَمِيمٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxiii{مَّنَّاعٍ لِّلْخَيْرِ مُعْتَدٍ أَثِيمٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxiv{عُتُلٍّۭ بَعْدَ ذَٰلِكَ زَنِيمٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxv{أَن كَانَ ذَا مَالٍ وَبَنِينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxvi{إِذَا تُتْلَىٰ عَلَيْهِ ءَايَٰتُنَا قَالَ أَسَٰطِيرُ ٱلْأَوَّلِينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxvii{سَنَسِمُهُۥ عَلَى ٱلْخُرْطُومِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxviii{إِنَّا بَلَوْنَٰهُمْ كَمَا بَلَوْنَآ أَصْحَٰبَ ٱلْجَنَّةِ إِذْ أَقْسَمُوا۟ لَيَصْرِمُنَّهَا مُصْبِحِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxix{وَلَا يَسْتَثْنُونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmccxc{فَطَافَ عَلَيْهَا طَآئِفٌ مِّن رَّبِّكَ وَهُمْ نَآئِمُونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmccxci{فَأَصْبَحَتْ كَٱلصَّرِيمِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmccxcii{فَتَنَادَوْا۟ مُصْبِحِينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmccxciii{أَنِ ٱغْدُوا۟ عَلَىٰ حَرْثِكُمْ إِن كُنتُمْ صَٰرِمِينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmccxciv{فَٱنطَلَقُوا۟ وَهُمْ يَتَخَٰفَتُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmccxcv{أَن لَّا يَدْخُلَنَّهَا ٱلْيَوْمَ عَلَيْكُم مِّسْكِينٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmccxcvi{وَغَدَوْا۟ عَلَىٰ حَرْدٍ قَٰدِرِينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmccxcvii{فَلَمَّا رَأَوْهَا قَالُوٓا۟ إِنَّا لَضَآلُّونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmccxcviii{بَلْ نَحْنُ مَحْرُومُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmccxcix{قَالَ أَوْسَطُهُمْ أَلَمْ أَقُل لَّكُمْ لَوْلَا تُسَبِّحُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmccc{قَالُوا۟ سُبْحَٰنَ رَبِّنَآ إِنَّا كُنَّا ظَٰلِمِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmccci{فَأَقْبَلَ بَعْضُهُمْ عَلَىٰ بَعْضٍ يَتَلَٰوَمُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcccii{قَالُوا۟ يَٰوَيْلَنَآ إِنَّا كُنَّا طَٰغِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmccciii{عَسَىٰ رَبُّنَآ أَن يُبْدِلَنَا خَيْرًا مِّنْهَآ إِنَّآ إِلَىٰ رَبِّنَا رَٰغِبُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmccciv{كَذَٰلِكَ ٱلْعَذَابُ وَلَعَذَابُ ٱلْءَاخِرَةِ أَكْبَرُ لَوْ كَانُوا۟ يَعْلَمُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmcccv{إِنَّ لِلْمُتَّقِينَ عِندَ رَبِّهِمْ جَنَّٰتِ ٱلنَّعِيمِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmcccvi{أَفَنَجْعَلُ ٱلْمُسْلِمِينَ كَٱلْمُجْرِمِينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmcccvii{مَا لَكُمْ كَيْفَ تَحْكُمُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmcccviii{أَمْ لَكُمْ كِتَٰبٌ فِيهِ تَدْرُسُونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmcccix{إِنَّ لَكُمْ فِيهِ لَمَا تَخَيَّرُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmcccx{أَمْ لَكُمْ أَيْمَٰنٌ عَلَيْنَا بَٰلِغَةٌ إِلَىٰ يَوْمِ ٱلْقِيَٰمَةِ إِنَّ لَكُمْ لَمَا تَحْكُمُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxi{سَلْهُمْ أَيُّهُم بِذَٰلِكَ زَعِيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxii{أَمْ لَهُمْ شُرَكَآءُ فَلْيَأْتُوا۟ بِشُرَكَآئِهِمْ إِن كَانُوا۟ صَٰدِقِينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmcccxiii{يَوْمَ يُكْشَفُ عَن سَاقٍ وَيُدْعَوْنَ إِلَى ٱلسُّجُودِ فَلَا يَسْتَطِيعُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxiv{خَٰشِعَةً أَبْصَٰرُهُمْ تَرْهَقُهُمْ ذِلَّةٌ وَقَدْ كَانُوا۟ يُدْعَوْنَ إِلَى ٱلسُّجُودِ وَهُمْ سَٰلِمُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxv{فَذَرْنِى وَمَن يُكَذِّبُ بِهَٰذَا ٱلْحَدِيثِ سَنَسْتَدْرِجُهُم مِّنْ حَيْثُ لَا يَعْلَمُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxvi{وَأُمْلِى لَهُمْ إِنَّ كَيْدِى مَتِينٌ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxvii{أَمْ تَسْـَٔلُهُمْ أَجْرًا فَهُم مِّن مَّغْرَمٍ مُّثْقَلُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxviii{أَمْ عِندَهُمُ ٱلْغَيْبُ فَهُمْ يَكْتُبُونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxix{فَٱصْبِرْ لِحُكْمِ رَبِّكَ وَلَا تَكُن كَصَاحِبِ ٱلْحُوتِ إِذْ نَادَىٰ وَهُوَ مَكْظُومٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxx{لَّوْلَآ أَن تَدَٰرَكَهُۥ نِعْمَةٌ مِّن رَّبِّهِۦ لَنُبِذَ بِٱلْعَرَآءِ وَهُوَ مَذْمُومٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxxi{فَٱجْتَبَٰهُ رَبُّهُۥ فَجَعَلَهُۥ مِنَ ٱلصَّٰلِحِينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxxii{وَإِن يَكَادُ ٱلَّذِينَ كَفَرُوا۟ لَيُزْلِقُونَكَ بِأَبْصَٰرِهِمْ لَمَّا سَمِعُوا۟ ٱلذِّكْرَ وَيَقُولُونَ إِنَّهُۥ لَمَجْنُونٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmcccxxiii{وَمَا هُوَ إِلَّا ذِكْرٌ لِّلْعَٰلَمِينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxxiv{\basmalah ٱلْحَآقَّةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcccxxv{مَا ٱلْحَآقَّةُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxxvi{وَمَآ أَدْرَىٰكَ مَا ٱلْحَآقَّةُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxxvii{كَذَّبَتْ ثَمُودُ وَعَادٌۢ بِٱلْقَارِعَةِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxxviii{فَأَمَّا ثَمُودُ فَأُهْلِكُوا۟ بِٱلطَّاغِيَةِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxxix{وَأَمَّا عَادٌ فَأُهْلِكُوا۟ بِرِيحٍ صَرْصَرٍ عَاتِيَةٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxxx{سَخَّرَهَا عَلَيْهِمْ سَبْعَ لَيَالٍ وَثَمَٰنِيَةَ أَيَّامٍ حُسُومًا فَتَرَى ٱلْقَوْمَ فِيهَا صَرْعَىٰ كَأَنَّهُمْ أَعْجَازُ نَخْلٍ خَاوِيَةٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxi{فَهَلْ تَرَىٰ لَهُم مِّنۢ بَاقِيَةٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxii{وَجَآءَ فِرْعَوْنُ وَمَن قَبْلَهُۥ وَٱلْمُؤْتَفِكَٰتُ بِٱلْخَاطِئَةِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxiii{فَعَصَوْا۟ رَسُولَ رَبِّهِمْ فَأَخَذَهُمْ أَخْذَةً رَّابِيَةً\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxiv{إِنَّا لَمَّا طَغَا ٱلْمَآءُ حَمَلْنَٰكُمْ فِى ٱلْجَارِيَةِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxv{لِنَجْعَلَهَا لَكُمْ تَذْكِرَةً وَتَعِيَهَآ أُذُنٌ وَٰعِيَةٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxvi{فَإِذَا نُفِخَ فِى ٱلصُّورِ نَفْخَةٌ وَٰحِدَةٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxvii{وَحُمِلَتِ ٱلْأَرْضُ وَٱلْجِبَالُ فَدُكَّتَا دَكَّةً وَٰحِدَةً\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxviii{فَيَوْمَئِذٍ وَقَعَتِ ٱلْوَاقِعَةُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxix{وَٱنشَقَّتِ ٱلسَّمَآءُ فَهِىَ يَوْمَئِذٍ وَاهِيَةٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxl{وَٱلْمَلَكُ عَلَىٰٓ أَرْجَآئِهَا وَيَحْمِلُ عَرْشَ رَبِّكَ فَوْقَهُمْ يَوْمَئِذٍ ثَمَٰنِيَةٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxli{يَوْمَئِذٍ تُعْرَضُونَ لَا تَخْفَىٰ مِنكُمْ خَافِيَةٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxlii{فَأَمَّا مَنْ أُوتِىَ كِتَٰبَهُۥ بِيَمِينِهِۦ فَيَقُولُ هَآؤُمُ ٱقْرَءُوا۟ كِتَٰبِيَهْ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxliii{إِنِّى ظَنَنتُ أَنِّى مُلَٰقٍ حِسَابِيَهْ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxliv{فَهُوَ فِى عِيشَةٍ رَّاضِيَةٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcccxlv{فِى جَنَّةٍ عَالِيَةٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxlvi{قُطُوفُهَا دَانِيَةٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxlvii{كُلُوا۟ وَٱشْرَبُوا۟ هَنِيٓـًٔۢا بِمَآ أَسْلَفْتُمْ فِى ٱلْأَيَّامِ ٱلْخَالِيَةِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxlviii{وَأَمَّا مَنْ أُوتِىَ كِتَٰبَهُۥ بِشِمَالِهِۦ فَيَقُولُ يَٰلَيْتَنِى لَمْ أُوتَ كِتَٰبِيَهْ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxlix{وَلَمْ أَدْرِ مَا حِسَابِيَهْ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcccl{يَٰلَيْتَهَا كَانَتِ ٱلْقَاضِيَةَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcccli{مَآ أَغْنَىٰ عَنِّى مَالِيَهْ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmccclii{هَلَكَ عَنِّى سُلْطَٰنِيَهْ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcccliii{خُذُوهُ فَغُلُّوهُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcccliv{ثُمَّ ٱلْجَحِيمَ صَلُّوهُ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmccclv{ثُمَّ فِى سِلْسِلَةٍ ذَرْعُهَا سَبْعُونَ ذِرَاعًا فَٱسْلُكُوهُ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmccclvi{إِنَّهُۥ كَانَ لَا يُؤْمِنُ بِٱللَّهِ ٱلْعَظِيمِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmccclvii{وَلَا يَحُضُّ عَلَىٰ طَعَامِ ٱلْمِسْكِينِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmccclviii{فَلَيْسَ لَهُ ٱلْيَوْمَ هَٰهُنَا حَمِيمٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmccclix{وَلَا طَعَامٌ إِلَّا مِنْ غِسْلِينٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmccclx{لَّا يَأْكُلُهُۥٓ إِلَّا ٱلْخَٰطِـُٔونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmccclxi{فَلَآ أُقْسِمُ بِمَا تُبْصِرُونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmccclxii{وَمَا لَا تُبْصِرُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmccclxiii{إِنَّهُۥ لَقَوْلُ رَسُولٍ كَرِيمٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmccclxiv{وَمَا هُوَ بِقَوْلِ شَاعِرٍ قَلِيلًا مَّا تُؤْمِنُونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmccclxv{وَلَا بِقَوْلِ كَاهِنٍ قَلِيلًا مَّا تَذَكَّرُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxvi{تَنزِيلٌ مِّن رَّبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmccclxvii{وَلَوْ تَقَوَّلَ عَلَيْنَا بَعْضَ ٱلْأَقَاوِيلِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmccclxviii{لَأَخَذْنَا مِنْهُ بِٱلْيَمِينِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmccclxix{ثُمَّ لَقَطَعْنَا مِنْهُ ٱلْوَتِينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmccclxx{فَمَا مِنكُم مِّنْ أَحَدٍ عَنْهُ حَٰجِزِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmccclxxi{وَإِنَّهُۥ لَتَذْكِرَةٌ لِّلْمُتَّقِينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmccclxxii{وَإِنَّا لَنَعْلَمُ أَنَّ مِنكُم مُّكَذِّبِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmccclxxiii{وَإِنَّهُۥ لَحَسْرَةٌ عَلَى ٱلْكَٰفِرِينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmccclxxiv{وَإِنَّهُۥ لَحَقُّ ٱلْيَقِينِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmccclxxv{فَسَبِّحْ بِٱسْمِ رَبِّكَ ٱلْعَظِيمِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxxvi{\basmalah سَأَلَ سَآئِلٌۢ بِعَذَابٍ وَاقِعٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccclxxvii{لِّلْكَٰفِرِينَ لَيْسَ لَهُۥ دَافِعٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxxviii{مِّنَ ٱللَّهِ ذِى ٱلْمَعَارِجِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccclxxix{تَعْرُجُ ٱلْمَلَٰٓئِكَةُ وَٱلرُّوحُ إِلَيْهِ فِى يَوْمٍ كَانَ مِقْدَارُهُۥ خَمْسِينَ أَلْفَ سَنَةٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccclxxx{فَٱصْبِرْ صَبْرًا جَمِيلًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxi{إِنَّهُمْ يَرَوْنَهُۥ بَعِيدًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxii{وَنَرَىٰهُ قَرِيبًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxiii{يَوْمَ تَكُونُ ٱلسَّمَآءُ كَٱلْمُهْلِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxiv{وَتَكُونُ ٱلْجِبَالُ كَٱلْعِهْنِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxv{وَلَا يَسْـَٔلُ حَمِيمٌ حَمِيمًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxvi{يُبَصَّرُونَهُمْ يَوَدُّ ٱلْمُجْرِمُ لَوْ يَفْتَدِى مِنْ عَذَابِ يَوْمِئِذٍۭ بِبَنِيهِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxvii{وَصَٰحِبَتِهِۦ وَأَخِيهِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxviii{وَفَصِيلَتِهِ ٱلَّتِى تُـْٔوِيهِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxix{وَمَن فِى ٱلْأَرْضِ جَمِيعًا ثُمَّ يُنجِيهِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxc{كَلَّآ إِنَّهَا لَظَىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxci{نَزَّاعَةً لِّلشَّوَىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxcii{تَدْعُوا۟ مَنْ أَدْبَرَ وَتَوَلَّىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxciii{وَجَمَعَ فَأَوْعَىٰٓ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxciv{إِنَّ ٱلْإِنسَٰنَ خُلِقَ هَلُوعًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxcv{إِذَا مَسَّهُ ٱلشَّرُّ جَزُوعًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxcvi{وَإِذَا مَسَّهُ ٱلْخَيْرُ مَنُوعًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcccxcvii{إِلَّا ٱلْمُصَلِّينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxcviii{ٱلَّذِينَ هُمْ عَلَىٰ صَلَاتِهِمْ دَآئِمُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxcix{وَٱلَّذِينَ فِىٓ أَمْوَٰلِهِمْ حَقٌّ مَّعْلُومٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcd{لِّلسَّآئِلِ وَٱلْمَحْرُومِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcdi{وَٱلَّذِينَ يُصَدِّقُونَ بِيَوْمِ ٱلدِّينِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcdii{وَٱلَّذِينَ هُم مِّنْ عَذَابِ رَبِّهِم مُّشْفِقُونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcdiii{إِنَّ عَذَابَ رَبِّهِمْ غَيْرُ مَأْمُونٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcdiv{وَٱلَّذِينَ هُمْ لِفُرُوجِهِمْ حَٰفِظُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcdv{إِلَّا عَلَىٰٓ أَزْوَٰجِهِمْ أَوْ مَا مَلَكَتْ أَيْمَٰنُهُمْ فَإِنَّهُمْ غَيْرُ مَلُومِينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcdvi{فَمَنِ ٱبْتَغَىٰ وَرَآءَ ذَٰلِكَ فَأُو۟لَٰٓئِكَ هُمُ ٱلْعَادُونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmcdvii{وَٱلَّذِينَ هُمْ لِأَمَٰنَٰتِهِمْ وَعَهْدِهِمْ رَٰعُونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmcdviii{وَٱلَّذِينَ هُم بِشَهَٰدَٰتِهِمْ قَآئِمُونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmcdix{وَٱلَّذِينَ هُمْ عَلَىٰ صَلَاتِهِمْ يُحَافِظُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmcdx{أُو۟لَٰٓئِكَ فِى جَنَّٰتٍ مُّكْرَمُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxi{فَمَالِ ٱلَّذِينَ كَفَرُوا۟ قِبَلَكَ مُهْطِعِينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxii{عَنِ ٱلْيَمِينِ وَعَنِ ٱلشِّمَالِ عِزِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxiii{أَيَطْمَعُ كُلُّ ٱمْرِئٍ مِّنْهُمْ أَن يُدْخَلَ جَنَّةَ نَعِيمٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxiv{كَلَّآ إِنَّا خَلَقْنَٰهُم مِّمَّا يَعْلَمُونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxv{فَلَآ أُقْسِمُ بِرَبِّ ٱلْمَشَٰرِقِ وَٱلْمَغَٰرِبِ إِنَّا لَقَٰدِرُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxvi{عَلَىٰٓ أَن نُّبَدِّلَ خَيْرًا مِّنْهُمْ وَمَا نَحْنُ بِمَسْبُوقِينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmcdxvii{فَذَرْهُمْ يَخُوضُوا۟ وَيَلْعَبُوا۟ حَتَّىٰ يُلَٰقُوا۟ يَوْمَهُمُ ٱلَّذِى يُوعَدُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxviii{يَوْمَ يَخْرُجُونَ مِنَ ٱلْأَجْدَاثِ سِرَاعًا كَأَنَّهُمْ إِلَىٰ نُصُبٍ يُوفِضُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxix{خَٰشِعَةً أَبْصَٰرُهُمْ تَرْهَقُهُمْ ذِلَّةٌ ذَٰلِكَ ٱلْيَوْمُ ٱلَّذِى كَانُوا۟ يُوعَدُونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxx{\basmalah إِنَّآ أَرْسَلْنَا نُوحًا إِلَىٰ قَوْمِهِۦٓ أَنْ أَنذِرْ قَوْمَكَ مِن قَبْلِ أَن يَأْتِيَهُمْ عَذَابٌ أَلِيمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdxxi{قَالَ يَٰقَوْمِ إِنِّى لَكُمْ نَذِيرٌ مُّبِينٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxxii{أَنِ ٱعْبُدُوا۟ ٱللَّهَ وَٱتَّقُوهُ وَأَطِيعُونِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxxiii{يَغْفِرْ لَكُم مِّن ذُنُوبِكُمْ وَيُؤَخِّرْكُمْ إِلَىٰٓ أَجَلٍ مُّسَمًّى إِنَّ أَجَلَ ٱللَّهِ إِذَا جَآءَ لَا يُؤَخَّرُ لَوْ كُنتُمْ تَعْلَمُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxxiv{قَالَ رَبِّ إِنِّى دَعَوْتُ قَوْمِى لَيْلًا وَنَهَارًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxxv{فَلَمْ يَزِدْهُمْ دُعَآءِىٓ إِلَّا فِرَارًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxxvi{وَإِنِّى كُلَّمَا دَعَوْتُهُمْ لِتَغْفِرَ لَهُمْ جَعَلُوٓا۟ أَصَٰبِعَهُمْ فِىٓ ءَاذَانِهِمْ وَٱسْتَغْشَوْا۟ ثِيَابَهُمْ وَأَصَرُّوا۟ وَٱسْتَكْبَرُوا۟ ٱسْتِكْبَارًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxxvii{ثُمَّ إِنِّى دَعَوْتُهُمْ جِهَارًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxxviii{ثُمَّ إِنِّىٓ أَعْلَنتُ لَهُمْ وَأَسْرَرْتُ لَهُمْ إِسْرَارًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxxix{فَقُلْتُ ٱسْتَغْفِرُوا۟ رَبَّكُمْ إِنَّهُۥ كَانَ غَفَّارًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxxx{يُرْسِلِ ٱلسَّمَآءَ عَلَيْكُم مِّدْرَارًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxi{وَيُمْدِدْكُم بِأَمْوَٰلٍ وَبَنِينَ وَيَجْعَل لَّكُمْ جَنَّٰتٍ وَيَجْعَل لَّكُمْ أَنْهَٰرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxii{مَّا لَكُمْ لَا تَرْجُونَ لِلَّهِ وَقَارًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxiii{وَقَدْ خَلَقَكُمْ أَطْوَارًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxiv{أَلَمْ تَرَوْا۟ كَيْفَ خَلَقَ ٱللَّهُ سَبْعَ سَمَٰوَٰتٍ طِبَاقًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxv{وَجَعَلَ ٱلْقَمَرَ فِيهِنَّ نُورًا وَجَعَلَ ٱلشَّمْسَ سِرَاجًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxvi{وَٱللَّهُ أَنۢبَتَكُم مِّنَ ٱلْأَرْضِ نَبَاتًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxvii{ثُمَّ يُعِيدُكُمْ فِيهَا وَيُخْرِجُكُمْ إِخْرَاجًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxviii{وَٱللَّهُ جَعَلَ لَكُمُ ٱلْأَرْضَ بِسَاطًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxix{لِّتَسْلُكُوا۟ مِنْهَا سُبُلًا فِجَاجًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxl{قَالَ نُوحٌ رَّبِّ إِنَّهُمْ عَصَوْنِى وَٱتَّبَعُوا۟ مَن لَّمْ يَزِدْهُ مَالُهُۥ وَوَلَدُهُۥٓ إِلَّا خَسَارًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcdxli{وَمَكَرُوا۟ مَكْرًا كُبَّارًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxlii{وَقَالُوا۟ لَا تَذَرُنَّ ءَالِهَتَكُمْ وَلَا تَذَرُنَّ وَدًّا وَلَا سُوَاعًا وَلَا يَغُوثَ وَيَعُوقَ وَنَسْرًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxliii{وَقَدْ أَضَلُّوا۟ كَثِيرًا وَلَا تَزِدِ ٱلظَّٰلِمِينَ إِلَّا ضَلَٰلًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxliv{مِّمَّا خَطِيٓـَٰٔتِهِمْ أُغْرِقُوا۟ فَأُدْخِلُوا۟ نَارًا فَلَمْ يَجِدُوا۟ لَهُم مِّن دُونِ ٱللَّهِ أَنصَارًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxlv{وَقَالَ نُوحٌ رَّبِّ لَا تَذَرْ عَلَى ٱلْأَرْضِ مِنَ ٱلْكَٰفِرِينَ دَيَّارًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxlvi{إِنَّكَ إِن تَذَرْهُمْ يُضِلُّوا۟ عِبَادَكَ وَلَا يَلِدُوٓا۟ إِلَّا فَاجِرًا كَفَّارًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxlvii{رَّبِّ ٱغْفِرْ لِى وَلِوَٰلِدَىَّ وَلِمَن دَخَلَ بَيْتِىَ مُؤْمِنًا وَلِلْمُؤْمِنِينَ وَٱلْمُؤْمِنَٰتِ وَلَا تَزِدِ ٱلظَّٰلِمِينَ إِلَّا تَبَارًۢا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxlviii{\basmalah قُلْ أُوحِىَ إِلَىَّ أَنَّهُ ٱسْتَمَعَ نَفَرٌ مِّنَ ٱلْجِنِّ فَقَالُوٓا۟ إِنَّا سَمِعْنَا قُرْءَانًا عَجَبًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdxlix{يَهْدِىٓ إِلَى ٱلرُّشْدِ فَـَٔامَنَّا بِهِۦ وَلَن نُّشْرِكَ بِرَبِّنَآ أَحَدًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdl{وَأَنَّهُۥ تَعَٰلَىٰ جَدُّ رَبِّنَا مَا ٱتَّخَذَ صَٰحِبَةً وَلَا وَلَدًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdli{وَأَنَّهُۥ كَانَ يَقُولُ سَفِيهُنَا عَلَى ٱللَّهِ شَطَطًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlii{وَأَنَّا ظَنَنَّآ أَن لَّن تَقُولَ ٱلْإِنسُ وَٱلْجِنُّ عَلَى ٱللَّهِ كَذِبًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcdliii{وَأَنَّهُۥ كَانَ رِجَالٌ مِّنَ ٱلْإِنسِ يَعُوذُونَ بِرِجَالٍ مِّنَ ٱلْجِنِّ فَزَادُوهُمْ رَهَقًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcdliv{وَأَنَّهُمْ ظَنُّوا۟ كَمَا ظَنَنتُمْ أَن لَّن يَبْعَثَ ٱللَّهُ أَحَدًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlv{وَأَنَّا لَمَسْنَا ٱلسَّمَآءَ فَوَجَدْنَٰهَا مُلِئَتْ حَرَسًا شَدِيدًا وَشُهُبًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlvi{وَأَنَّا كُنَّا نَقْعُدُ مِنْهَا مَقَٰعِدَ لِلسَّمْعِ فَمَن يَسْتَمِعِ ٱلْءَانَ يَجِدْ لَهُۥ شِهَابًا رَّصَدًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcdlvii{وَأَنَّا لَا نَدْرِىٓ أَشَرٌّ أُرِيدَ بِمَن فِى ٱلْأَرْضِ أَمْ أَرَادَ بِهِمْ رَبُّهُمْ رَشَدًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcdlviii{وَأَنَّا مِنَّا ٱلصَّٰلِحُونَ وَمِنَّا دُونَ ذَٰلِكَ كُنَّا طَرَآئِقَ قِدَدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcdlix{وَأَنَّا ظَنَنَّآ أَن لَّن نُّعْجِزَ ٱللَّهَ فِى ٱلْأَرْضِ وَلَن نُّعْجِزَهُۥ هَرَبًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlx{وَأَنَّا لَمَّا سَمِعْنَا ٱلْهُدَىٰٓ ءَامَنَّا بِهِۦ فَمَن يُؤْمِنۢ بِرَبِّهِۦ فَلَا يَخَافُ بَخْسًا وَلَا رَهَقًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxi{وَأَنَّا مِنَّا ٱلْمُسْلِمُونَ وَمِنَّا ٱلْقَٰسِطُونَ فَمَنْ أَسْلَمَ فَأُو۟لَٰٓئِكَ تَحَرَّوْا۟ رَشَدًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlxii{وَأَمَّا ٱلْقَٰسِطُونَ فَكَانُوا۟ لِجَهَنَّمَ حَطَبًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcdlxiii{وَأَلَّوِ ٱسْتَقَٰمُوا۟ عَلَى ٱلطَّرِيقَةِ لَأَسْقَيْنَٰهُم مَّآءً غَدَقًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcdlxiv{لِّنَفْتِنَهُمْ فِيهِ وَمَن يُعْرِضْ عَن ذِكْرِ رَبِّهِۦ يَسْلُكْهُ عَذَابًا صَعَدًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlxv{وَأَنَّ ٱلْمَسَٰجِدَ لِلَّهِ فَلَا تَدْعُوا۟ مَعَ ٱللَّهِ أَحَدًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlxvi{وَأَنَّهُۥ لَمَّا قَامَ عَبْدُ ٱللَّهِ يَدْعُوهُ كَادُوا۟ يَكُونُونَ عَلَيْهِ لِبَدًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcdlxvii{قُلْ إِنَّمَآ أَدْعُوا۟ رَبِّى وَلَآ أُشْرِكُ بِهِۦٓ أَحَدًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcdlxviii{قُلْ إِنِّى لَآ أَمْلِكُ لَكُمْ ضَرًّا وَلَا رَشَدًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcdlxix{قُلْ إِنِّى لَن يُجِيرَنِى مِنَ ٱللَّهِ أَحَدٌ وَلَنْ أَجِدَ مِن دُونِهِۦ مُلْتَحَدًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlxx{إِلَّا بَلَٰغًا مِّنَ ٱللَّهِ وَرِسَٰلَٰتِهِۦ وَمَن يَعْصِ ٱللَّهَ وَرَسُولَهُۥ فَإِنَّ لَهُۥ نَارَ جَهَنَّمَ خَٰلِدِينَ فِيهَآ أَبَدًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxi{حَتَّىٰٓ إِذَا رَأَوْا۟ مَا يُوعَدُونَ فَسَيَعْلَمُونَ مَنْ أَضْعَفُ نَاصِرًا وَأَقَلُّ عَدَدًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxii{قُلْ إِنْ أَدْرِىٓ أَقَرِيبٌ مَّا تُوعَدُونَ أَمْ يَجْعَلُ لَهُۥ رَبِّىٓ أَمَدًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxiii{عَٰلِمُ ٱلْغَيْبِ فَلَا يُظْهِرُ عَلَىٰ غَيْبِهِۦٓ أَحَدًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxiv{إِلَّا مَنِ ٱرْتَضَىٰ مِن رَّسُولٍ فَإِنَّهُۥ يَسْلُكُ مِنۢ بَيْنِ يَدَيْهِ وَمِنْ خَلْفِهِۦ رَصَدًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxv{لِّيَعْلَمَ أَن قَدْ أَبْلَغُوا۟ رِسَٰلَٰتِ رَبِّهِمْ وَأَحَاطَ بِمَا لَدَيْهِمْ وَأَحْصَىٰ كُلَّ شَىْءٍ عَدَدًۢا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxvi{\basmalah يَٰٓأَيُّهَا ٱلْمُزَّمِّلُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxvii{قُمِ ٱلَّيْلَ إِلَّا قَلِيلًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxviii{نِّصْفَهُۥٓ أَوِ ٱنقُصْ مِنْهُ قَلِيلًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxix{أَوْ زِدْ عَلَيْهِ وَرَتِّلِ ٱلْقُرْءَانَ تَرْتِيلًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxx{إِنَّا سَنُلْقِى عَلَيْكَ قَوْلًا ثَقِيلًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxi{إِنَّ نَاشِئَةَ ٱلَّيْلِ هِىَ أَشَدُّ وَطْـًٔا وَأَقْوَمُ قِيلًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxii{إِنَّ لَكَ فِى ٱلنَّهَارِ سَبْحًا طَوِيلًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxiii{وَٱذْكُرِ ٱسْمَ رَبِّكَ وَتَبَتَّلْ إِلَيْهِ تَبْتِيلًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxiv{رَّبُّ ٱلْمَشْرِقِ وَٱلْمَغْرِبِ لَآ إِلَٰهَ إِلَّا هُوَ فَٱتَّخِذْهُ وَكِيلًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxv{وَٱصْبِرْ عَلَىٰ مَا يَقُولُونَ وَٱهْجُرْهُمْ هَجْرًا جَمِيلًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxvi{وَذَرْنِى وَٱلْمُكَذِّبِينَ أُو۟لِى ٱلنَّعْمَةِ وَمَهِّلْهُمْ قَلِيلًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxvii{إِنَّ لَدَيْنَآ أَنكَالًا وَجَحِيمًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxviii{وَطَعَامًا ذَا غُصَّةٍ وَعَذَابًا أَلِيمًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxix{يَوْمَ تَرْجُفُ ٱلْأَرْضُ وَٱلْجِبَالُ وَكَانَتِ ٱلْجِبَالُ كَثِيبًا مَّهِيلًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxc{إِنَّآ أَرْسَلْنَآ إِلَيْكُمْ رَسُولًا شَٰهِدًا عَلَيْكُمْ كَمَآ أَرْسَلْنَآ إِلَىٰ فِرْعَوْنَ رَسُولًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxci{فَعَصَىٰ فِرْعَوْنُ ٱلرَّسُولَ فَأَخَذْنَٰهُ أَخْذًا وَبِيلًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxcii{فَكَيْفَ تَتَّقُونَ إِن كَفَرْتُمْ يَوْمًا يَجْعَلُ ٱلْوِلْدَٰنَ شِيبًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxciii{ٱلسَّمَآءُ مُنفَطِرٌۢ بِهِۦ كَانَ وَعْدُهُۥ مَفْعُولًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxciv{إِنَّ هَٰذِهِۦ تَذْكِرَةٌ فَمَن شَآءَ ٱتَّخَذَ إِلَىٰ رَبِّهِۦ سَبِيلًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxcv{إِنَّ رَبَّكَ يَعْلَمُ أَنَّكَ تَقُومُ أَدْنَىٰ مِن ثُلُثَىِ ٱلَّيْلِ وَنِصْفَهُۥ وَثُلُثَهُۥ وَطَآئِفَةٌ مِّنَ ٱلَّذِينَ مَعَكَ وَٱللَّهُ يُقَدِّرُ ٱلَّيْلَ وَٱلنَّهَارَ عَلِمَ أَن لَّن تُحْصُوهُ فَتَابَ عَلَيْكُمْ فَٱقْرَءُوا۟ مَا تَيَسَّرَ مِنَ ٱلْقُرْءَانِ عَلِمَ أَن سَيَكُونُ مِنكُم مَّرْضَىٰ وَءَاخَرُونَ يَضْرِبُونَ فِى ٱلْأَرْضِ يَبْتَغُونَ مِن فَضْلِ ٱللَّهِ وَءَاخَرُونَ يُقَٰتِلُونَ فِى سَبِيلِ ٱللَّهِ فَٱقْرَءُوا۟ مَا تَيَسَّرَ مِنْهُ وَأَقِيمُوا۟ ٱلصَّلَوٰةَ وَءَاتُوا۟ ٱلزَّكَوٰةَ وَأَقْرِضُوا۟ ٱللَّهَ قَرْضًا حَسَنًا وَمَا تُقَدِّمُوا۟ لِأَنفُسِكُم مِّنْ خَيْرٍ تَجِدُوهُ عِندَ ٱللَّهِ هُوَ خَيْرًا وَأَعْظَمَ أَجْرًا وَٱسْتَغْفِرُوا۟ ٱللَّهَ إِنَّ ٱللَّهَ غَفُورٌ رَّحِيمٌۢ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxcvi{\basmalah يَٰٓأَيُّهَا ٱلْمُدَّثِّرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdxcvii{قُمْ فَأَنذِرْ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxcviii{وَرَبَّكَ فَكَبِّرْ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxcix{وَثِيَابَكَ فَطَهِّرْ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmd{وَٱلرُّجْزَ فَٱهْجُرْ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdi{وَلَا تَمْنُن تَسْتَكْثِرُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdii{وَلِرَبِّكَ فَٱصْبِرْ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdiii{فَإِذَا نُقِرَ فِى ٱلنَّاقُورِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdiv{فَذَٰلِكَ يَوْمَئِذٍ يَوْمٌ عَسِيرٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdv{عَلَى ٱلْكَٰفِرِينَ غَيْرُ يَسِيرٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdvi{ذَرْنِى وَمَنْ خَلَقْتُ وَحِيدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdvii{وَجَعَلْتُ لَهُۥ مَالًا مَّمْدُودًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdviii{وَبَنِينَ شُهُودًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdix{وَمَهَّدتُّ لَهُۥ تَمْهِيدًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdx{ثُمَّ يَطْمَعُ أَنْ أَزِيدَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdxi{كَلَّآ إِنَّهُۥ كَانَ لِءَايَٰتِنَا عَنِيدًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdxii{سَأُرْهِقُهُۥ صَعُودًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdxiii{إِنَّهُۥ فَكَّرَ وَقَدَّرَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdxiv{فَقُتِلَ كَيْفَ قَدَّرَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdxv{ثُمَّ قُتِلَ كَيْفَ قَدَّرَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdxvi{ثُمَّ نَظَرَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdxvii{ثُمَّ عَبَسَ وَبَسَرَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdxviii{ثُمَّ أَدْبَرَ وَٱسْتَكْبَرَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdxix{فَقَالَ إِنْ هَٰذَآ إِلَّا سِحْرٌ يُؤْثَرُ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdxx{إِنْ هَٰذَآ إِلَّا قَوْلُ ٱلْبَشَرِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdxxi{سَأُصْلِيهِ سَقَرَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdxxii{وَمَآ أَدْرَىٰكَ مَا سَقَرُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdxxiii{لَا تُبْقِى وَلَا تَذَرُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdxxiv{لَوَّاحَةٌ لِّلْبَشَرِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdxxv{عَلَيْهَا تِسْعَةَ عَشَرَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdxxvi{وَمَا جَعَلْنَآ أَصْحَٰبَ ٱلنَّارِ إِلَّا مَلَٰٓئِكَةً وَمَا جَعَلْنَا عِدَّتَهُمْ إِلَّا فِتْنَةً لِّلَّذِينَ كَفَرُوا۟ لِيَسْتَيْقِنَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ وَيَزْدَادَ ٱلَّذِينَ ءَامَنُوٓا۟ إِيمَٰنًا وَلَا يَرْتَابَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ وَٱلْمُؤْمِنُونَ وَلِيَقُولَ ٱلَّذِينَ فِى قُلُوبِهِم مَّرَضٌ وَٱلْكَٰفِرُونَ مَاذَآ أَرَادَ ٱللَّهُ بِهَٰذَا مَثَلًا كَذَٰلِكَ يُضِلُّ ٱللَّهُ مَن يَشَآءُ وَيَهْدِى مَن يَشَآءُ وَمَا يَعْلَمُ جُنُودَ رَبِّكَ إِلَّا هُوَ وَمَا هِىَ إِلَّا ذِكْرَىٰ لِلْبَشَرِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdxxvii{كَلَّا وَٱلْقَمَرِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdxxviii{وَٱلَّيْلِ إِذْ أَدْبَرَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdxxix{وَٱلصُّبْحِ إِذَآ أَسْفَرَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdxxx{إِنَّهَا لَإِحْدَى ٱلْكُبَرِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdxxxi{نَذِيرًا لِّلْبَشَرِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdxxxii{لِمَن شَآءَ مِنكُمْ أَن يَتَقَدَّمَ أَوْ يَتَأَخَّرَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdxxxiii{كُلُّ نَفْسٍۭ بِمَا كَسَبَتْ رَهِينَةٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdxxxiv{إِلَّآ أَصْحَٰبَ ٱلْيَمِينِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdxxxv{فِى جَنَّٰتٍ يَتَسَآءَلُونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdxxxvi{عَنِ ٱلْمُجْرِمِينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdxxxvii{مَا سَلَكَكُمْ فِى سَقَرَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdxxxviii{قَالُوا۟ لَمْ نَكُ مِنَ ٱلْمُصَلِّينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmdxxxix{وَلَمْ نَكُ نُطْعِمُ ٱلْمِسْكِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmdxl{وَكُنَّا نَخُوضُ مَعَ ٱلْخَآئِضِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmdxli{وَكُنَّا نُكَذِّبُ بِيَوْمِ ٱلدِّينِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmdxlii{حَتَّىٰٓ أَتَىٰنَا ٱلْيَقِينُ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmdxliii{فَمَا تَنفَعُهُمْ شَفَٰعَةُ ٱلشَّٰفِعِينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmdxliv{فَمَا لَهُمْ عَنِ ٱلتَّذْكِرَةِ مُعْرِضِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmdxlv{كَأَنَّهُمْ حُمُرٌ مُّسْتَنفِرَةٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmdxlvi{فَرَّتْ مِن قَسْوَرَةٍۭ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmdxlvii{بَلْ يُرِيدُ كُلُّ ٱمْرِئٍ مِّنْهُمْ أَن يُؤْتَىٰ صُحُفًا مُّنَشَّرَةً\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmdxlviii{كَلَّا بَل لَّا يَخَافُونَ ٱلْءَاخِرَةَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmmdxlix{كَلَّآ إِنَّهُۥ تَذْكِرَةٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmmdl{فَمَن شَآءَ ذَكَرَهُۥ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmmdli{وَمَا يَذْكُرُونَ إِلَّآ أَن يَشَآءَ ٱللَّهُ هُوَ أَهْلُ ٱلتَّقْوَىٰ وَأَهْلُ ٱلْمَغْفِرَةِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmmdlii{\basmalah لَآ أُقْسِمُ بِيَوْمِ ٱلْقِيَٰمَةِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdliii{وَلَآ أُقْسِمُ بِٱلنَّفْسِ ٱللَّوَّامَةِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdliv{أَيَحْسَبُ ٱلْإِنسَٰنُ أَلَّن نَّجْمَعَ عِظَامَهُۥ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdlv{بَلَىٰ قَٰدِرِينَ عَلَىٰٓ أَن نُّسَوِّىَ بَنَانَهُۥ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdlvi{بَلْ يُرِيدُ ٱلْإِنسَٰنُ لِيَفْجُرَ أَمَامَهُۥ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdlvii{يَسْـَٔلُ أَيَّانَ يَوْمُ ٱلْقِيَٰمَةِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdlviii{فَإِذَا بَرِقَ ٱلْبَصَرُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdlix{وَخَسَفَ ٱلْقَمَرُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdlx{وَجُمِعَ ٱلشَّمْسُ وَٱلْقَمَرُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdlxi{يَقُولُ ٱلْإِنسَٰنُ يَوْمَئِذٍ أَيْنَ ٱلْمَفَرُّ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdlxii{كَلَّا لَا وَزَرَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdlxiii{إِلَىٰ رَبِّكَ يَوْمَئِذٍ ٱلْمُسْتَقَرُّ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdlxiv{يُنَبَّؤُا۟ ٱلْإِنسَٰنُ يَوْمَئِذٍۭ بِمَا قَدَّمَ وَأَخَّرَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdlxv{بَلِ ٱلْإِنسَٰنُ عَلَىٰ نَفْسِهِۦ بَصِيرَةٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdlxvi{وَلَوْ أَلْقَىٰ مَعَاذِيرَهُۥ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdlxvii{لَا تُحَرِّكْ بِهِۦ لِسَانَكَ لِتَعْجَلَ بِهِۦٓ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdlxviii{إِنَّ عَلَيْنَا جَمْعَهُۥ وَقُرْءَانَهُۥ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdlxix{فَإِذَا قَرَأْنَٰهُ فَٱتَّبِعْ قُرْءَانَهُۥ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdlxx{ثُمَّ إِنَّ عَلَيْنَا بَيَانَهُۥ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdlxxi{كَلَّا بَلْ تُحِبُّونَ ٱلْعَاجِلَةَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdlxxii{وَتَذَرُونَ ٱلْءَاخِرَةَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdlxxiii{وُجُوهٌ يَوْمَئِذٍ نَّاضِرَةٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdlxxiv{إِلَىٰ رَبِّهَا نَاظِرَةٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdlxxv{وَوُجُوهٌ يَوْمَئِذٍۭ بَاسِرَةٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdlxxvi{تَظُنُّ أَن يُفْعَلَ بِهَا فَاقِرَةٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdlxxvii{كَلَّآ إِذَا بَلَغَتِ ٱلتَّرَاقِىَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdlxxviii{وَقِيلَ مَنْ رَاقٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdlxxix{وَظَنَّ أَنَّهُ ٱلْفِرَاقُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdlxxx{وَٱلْتَفَّتِ ٱلسَّاقُ بِٱلسَّاقِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxi{إِلَىٰ رَبِّكَ يَوْمَئِذٍ ٱلْمَسَاقُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxii{فَلَا صَدَّقَ وَلَا صَلَّىٰ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxiii{وَلَٰكِن كَذَّبَ وَتَوَلَّىٰ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxiv{ثُمَّ ذَهَبَ إِلَىٰٓ أَهْلِهِۦ يَتَمَطَّىٰٓ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxv{أَوْلَىٰ لَكَ فَأَوْلَىٰ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxvi{ثُمَّ أَوْلَىٰ لَكَ فَأَوْلَىٰٓ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxvii{أَيَحْسَبُ ٱلْإِنسَٰنُ أَن يُتْرَكَ سُدًى\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxviii{أَلَمْ يَكُ نُطْفَةً مِّن مَّنِىٍّ يُمْنَىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxix{ثُمَّ كَانَ عَلَقَةً فَخَلَقَ فَسَوَّىٰ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdxc{فَجَعَلَ مِنْهُ ٱلزَّوْجَيْنِ ٱلذَّكَرَ وَٱلْأُنثَىٰٓ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdxci{أَلَيْسَ ذَٰلِكَ بِقَٰدِرٍ عَلَىٰٓ أَن يُحْۦِىَ ٱلْمَوْتَىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdxcii{\basmalah هَلْ أَتَىٰ عَلَى ٱلْإِنسَٰنِ حِينٌ مِّنَ ٱلدَّهْرِ لَمْ يَكُن شَيْـًٔا مَّذْكُورًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdxciii{إِنَّا خَلَقْنَا ٱلْإِنسَٰنَ مِن نُّطْفَةٍ أَمْشَاجٍ نَّبْتَلِيهِ فَجَعَلْنَٰهُ سَمِيعًۢا بَصِيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdxciv{إِنَّا هَدَيْنَٰهُ ٱلسَّبِيلَ إِمَّا شَاكِرًا وَإِمَّا كَفُورًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdxcv{إِنَّآ أَعْتَدْنَا لِلْكَٰفِرِينَ سَلَٰسِلَا۟ وَأَغْلَٰلًا وَسَعِيرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdxcvi{إِنَّ ٱلْأَبْرَارَ يَشْرَبُونَ مِن كَأْسٍ كَانَ مِزَاجُهَا كَافُورًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdxcvii{عَيْنًا يَشْرَبُ بِهَا عِبَادُ ٱللَّهِ يُفَجِّرُونَهَا تَفْجِيرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdxcviii{يُوفُونَ بِٱلنَّذْرِ وَيَخَافُونَ يَوْمًا كَانَ شَرُّهُۥ مُسْتَطِيرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdxcix{وَيُطْعِمُونَ ٱلطَّعَامَ عَلَىٰ حُبِّهِۦ مِسْكِينًا وَيَتِيمًا وَأَسِيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdc{إِنَّمَا نُطْعِمُكُمْ لِوَجْهِ ٱللَّهِ لَا نُرِيدُ مِنكُمْ جَزَآءً وَلَا شُكُورًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdci{إِنَّا نَخَافُ مِن رَّبِّنَا يَوْمًا عَبُوسًا قَمْطَرِيرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcii{فَوَقَىٰهُمُ ٱللَّهُ شَرَّ ذَٰلِكَ ٱلْيَوْمِ وَلَقَّىٰهُمْ نَضْرَةً وَسُرُورًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdciii{وَجَزَىٰهُم بِمَا صَبَرُوا۟ جَنَّةً وَحَرِيرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdciv{مُّتَّكِـِٔينَ فِيهَا عَلَى ٱلْأَرَآئِكِ لَا يَرَوْنَ فِيهَا شَمْسًا وَلَا زَمْهَرِيرًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcv{وَدَانِيَةً عَلَيْهِمْ ظِلَٰلُهَا وَذُلِّلَتْ قُطُوفُهَا تَذْلِيلًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcvi{وَيُطَافُ عَلَيْهِم بِـَٔانِيَةٍ مِّن فِضَّةٍ وَأَكْوَابٍ كَانَتْ قَوَارِيرَا۠\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcvii{قَوَارِيرَا۟ مِن فِضَّةٍ قَدَّرُوهَا تَقْدِيرًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcviii{وَيُسْقَوْنَ فِيهَا كَأْسًا كَانَ مِزَاجُهَا زَنجَبِيلًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcix{عَيْنًا فِيهَا تُسَمَّىٰ سَلْسَبِيلًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcx{وَيَطُوفُ عَلَيْهِمْ وِلْدَٰنٌ مُّخَلَّدُونَ إِذَا رَأَيْتَهُمْ حَسِبْتَهُمْ لُؤْلُؤًا مَّنثُورًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxi{وَإِذَا رَأَيْتَ ثَمَّ رَأَيْتَ نَعِيمًا وَمُلْكًا كَبِيرًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxii{عَٰلِيَهُمْ ثِيَابُ سُندُسٍ خُضْرٌ وَإِسْتَبْرَقٌ وَحُلُّوٓا۟ أَسَاوِرَ مِن فِضَّةٍ وَسَقَىٰهُمْ رَبُّهُمْ شَرَابًا طَهُورًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcxiii{إِنَّ هَٰذَا كَانَ لَكُمْ جَزَآءً وَكَانَ سَعْيُكُم مَّشْكُورًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxiv{إِنَّا نَحْنُ نَزَّلْنَا عَلَيْكَ ٱلْقُرْءَانَ تَنزِيلًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxv{فَٱصْبِرْ لِحُكْمِ رَبِّكَ وَلَا تُطِعْ مِنْهُمْ ءَاثِمًا أَوْ كَفُورًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxvi{وَٱذْكُرِ ٱسْمَ رَبِّكَ بُكْرَةً وَأَصِيلًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxvii{وَمِنَ ٱلَّيْلِ فَٱسْجُدْ لَهُۥ وَسَبِّحْهُ لَيْلًا طَوِيلًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxviii{إِنَّ هَٰٓؤُلَآءِ يُحِبُّونَ ٱلْعَاجِلَةَ وَيَذَرُونَ وَرَآءَهُمْ يَوْمًا ثَقِيلًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxix{نَّحْنُ خَلَقْنَٰهُمْ وَشَدَدْنَآ أَسْرَهُمْ وَإِذَا شِئْنَا بَدَّلْنَآ أَمْثَٰلَهُمْ تَبْدِيلًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxx{إِنَّ هَٰذِهِۦ تَذْكِرَةٌ فَمَن شَآءَ ٱتَّخَذَ إِلَىٰ رَبِّهِۦ سَبِيلًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxxi{وَمَا تَشَآءُونَ إِلَّآ أَن يَشَآءَ ٱللَّهُ إِنَّ ٱللَّهَ كَانَ عَلِيمًا حَكِيمًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxxii{يُدْخِلُ مَن يَشَآءُ فِى رَحْمَتِهِۦ وَٱلظَّٰلِمِينَ أَعَدَّ لَهُمْ عَذَابًا أَلِيمًۢا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdcxxiii{\basmalah وَٱلْمُرْسَلَٰتِ عُرْفًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcxxiv{فَٱلْعَٰصِفَٰتِ عَصْفًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxxv{وَٱلنَّٰشِرَٰتِ نَشْرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxxvi{فَٱلْفَٰرِقَٰتِ فَرْقًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxxvii{فَٱلْمُلْقِيَٰتِ ذِكْرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxxviii{عُذْرًا أَوْ نُذْرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxxix{إِنَّمَا تُوعَدُونَ لَوَٰقِعٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxxx{فَإِذَا ٱلنُّجُومُ طُمِسَتْ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxi{وَإِذَا ٱلسَّمَآءُ فُرِجَتْ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxii{وَإِذَا ٱلْجِبَالُ نُسِفَتْ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxiii{وَإِذَا ٱلرُّسُلُ أُقِّتَتْ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxiv{لِأَىِّ يَوْمٍ أُجِّلَتْ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxv{لِيَوْمِ ٱلْفَصْلِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxvi{وَمَآ أَدْرَىٰكَ مَا يَوْمُ ٱلْفَصْلِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxvii{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxviii{أَلَمْ نُهْلِكِ ٱلْأَوَّلِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxix{ثُمَّ نُتْبِعُهُمُ ٱلْءَاخِرِينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxl{كَذَٰلِكَ نَفْعَلُ بِٱلْمُجْرِمِينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxli{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxlii{أَلَمْ نَخْلُقكُّم مِّن مَّآءٍ مَّهِينٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxliii{فَجَعَلْنَٰهُ فِى قَرَارٍ مَّكِينٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcxliv{إِلَىٰ قَدَرٍ مَّعْلُومٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxlv{فَقَدَرْنَا فَنِعْمَ ٱلْقَٰدِرُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxlvi{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxlvii{أَلَمْ نَجْعَلِ ٱلْأَرْضَ كِفَاتًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxlviii{أَحْيَآءً وَأَمْوَٰتًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxlix{وَجَعَلْنَا فِيهَا رَوَٰسِىَ شَٰمِخَٰتٍ وَأَسْقَيْنَٰكُم مَّآءً فُرَاتًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcl{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcli{ٱنطَلِقُوٓا۟ إِلَىٰ مَا كُنتُم بِهِۦ تُكَذِّبُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdclii{ٱنطَلِقُوٓا۟ إِلَىٰ ظِلٍّ ذِى ثَلَٰثِ شُعَبٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcliii{لَّا ظَلِيلٍ وَلَا يُغْنِى مِنَ ٱللَّهَبِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdcliv{إِنَّهَا تَرْمِى بِشَرَرٍ كَٱلْقَصْرِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdclv{كَأَنَّهُۥ جِمَٰلَتٌ صُفْرٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdclvi{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdclvii{هَٰذَا يَوْمُ لَا يَنطِقُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdclviii{وَلَا يُؤْذَنُ لَهُمْ فَيَعْتَذِرُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdclix{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdclx{هَٰذَا يَوْمُ ٱلْفَصْلِ جَمَعْنَٰكُمْ وَٱلْأَوَّلِينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdclxi{فَإِن كَانَ لَكُمْ كَيْدٌ فَكِيدُونِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdclxii{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdclxiii{إِنَّ ٱلْمُتَّقِينَ فِى ظِلَٰلٍ وَعُيُونٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdclxiv{وَفَوَٰكِهَ مِمَّا يَشْتَهُونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdclxv{كُلُوا۟ وَٱشْرَبُوا۟ هَنِيٓـًٔۢا بِمَا كُنتُمْ تَعْمَلُونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmdclxvi{إِنَّا كَذَٰلِكَ نَجْزِى ٱلْمُحْسِنِينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmdclxvii{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmdclxviii{كُلُوا۟ وَتَمَتَّعُوا۟ قَلِيلًا إِنَّكُم مُّجْرِمُونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmdclxix{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmdclxx{وَإِذَا قِيلَ لَهُمُ ٱرْكَعُوا۟ لَا يَرْكَعُونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmdclxxi{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmdclxxii{فَبِأَىِّ حَدِيثٍۭ بَعْدَهُۥ يُؤْمِنُونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmdclxxiii{\basmalah عَمَّ يَتَسَآءَلُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdclxxiv{عَنِ ٱلنَّبَإِ ٱلْعَظِيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdclxxv{ٱلَّذِى هُمْ فِيهِ مُخْتَلِفُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdclxxvi{كَلَّا سَيَعْلَمُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdclxxvii{ثُمَّ كَلَّا سَيَعْلَمُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdclxxviii{أَلَمْ نَجْعَلِ ٱلْأَرْضَ مِهَٰدًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdclxxix{وَٱلْجِبَالَ أَوْتَادًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdclxxx{وَخَلَقْنَٰكُمْ أَزْوَٰجًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxi{وَجَعَلْنَا نَوْمَكُمْ سُبَاتًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxii{وَجَعَلْنَا ٱلَّيْلَ لِبَاسًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxiii{وَجَعَلْنَا ٱلنَّهَارَ مَعَاشًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxiv{وَبَنَيْنَا فَوْقَكُمْ سَبْعًا شِدَادًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxv{وَجَعَلْنَا سِرَاجًا وَهَّاجًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxvi{وَأَنزَلْنَا مِنَ ٱلْمُعْصِرَٰتِ مَآءً ثَجَّاجًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxvii{لِّنُخْرِجَ بِهِۦ حَبًّا وَنَبَاتًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxviii{وَجَنَّٰتٍ أَلْفَافًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxix{إِنَّ يَوْمَ ٱلْفَصْلِ كَانَ مِيقَٰتًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxc{يَوْمَ يُنفَخُ فِى ٱلصُّورِ فَتَأْتُونَ أَفْوَاجًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxci{وَفُتِحَتِ ٱلسَّمَآءُ فَكَانَتْ أَبْوَٰبًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxcii{وَسُيِّرَتِ ٱلْجِبَالُ فَكَانَتْ سَرَابًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxciii{إِنَّ جَهَنَّمَ كَانَتْ مِرْصَادًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcxciv{لِّلطَّٰغِينَ مَـَٔابًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxcv{لَّٰبِثِينَ فِيهَآ أَحْقَابًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxcvi{لَّا يَذُوقُونَ فِيهَا بَرْدًا وَلَا شَرَابًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxcvii{إِلَّا حَمِيمًا وَغَسَّاقًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxcviii{جَزَآءً وِفَاقًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxcix{إِنَّهُمْ كَانُوا۟ لَا يَرْجُونَ حِسَابًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcc{وَكَذَّبُوا۟ بِـَٔايَٰتِنَا كِذَّابًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcci{وَكُلَّ شَىْءٍ أَحْصَيْنَٰهُ كِتَٰبًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdccii{فَذُوقُوا۟ فَلَن نَّزِيدَكُمْ إِلَّا عَذَابًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcciii{إِنَّ لِلْمُتَّقِينَ مَفَازًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdcciv{حَدَآئِقَ وَأَعْنَٰبًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccv{وَكَوَاعِبَ أَتْرَابًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccvi{وَكَأْسًا دِهَاقًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccvii{لَّا يَسْمَعُونَ فِيهَا لَغْوًا وَلَا كِذَّٰبًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccviii{جَزَآءً مِّن رَّبِّكَ عَطَآءً حِسَابًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccix{رَّبِّ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَمَا بَيْنَهُمَا ٱلرَّحْمَٰنِ لَا يَمْلِكُونَ مِنْهُ خِطَابًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdccx{يَوْمَ يَقُومُ ٱلرُّوحُ وَٱلْمَلَٰٓئِكَةُ صَفًّا لَّا يَتَكَلَّمُونَ إِلَّا مَنْ أَذِنَ لَهُ ٱلرَّحْمَٰنُ وَقَالَ صَوَابًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxi{ذَٰلِكَ ٱلْيَوْمُ ٱلْحَقُّ فَمَن شَآءَ ٱتَّخَذَ إِلَىٰ رَبِّهِۦ مَـَٔابًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxii{إِنَّآ أَنذَرْنَٰكُمْ عَذَابًا قَرِيبًا يَوْمَ يَنظُرُ ٱلْمَرْءُ مَا قَدَّمَتْ يَدَاهُ وَيَقُولُ ٱلْكَافِرُ يَٰلَيْتَنِى كُنتُ تُرَٰبًۢا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxiii{\basmalah وَٱلنَّٰزِعَٰتِ غَرْقًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdccxiv{وَٱلنَّٰشِطَٰتِ نَشْطًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxv{وَٱلسَّٰبِحَٰتِ سَبْحًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxvi{فَٱلسَّٰبِقَٰتِ سَبْقًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxvii{فَٱلْمُدَبِّرَٰتِ أَمْرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxviii{يَوْمَ تَرْجُفُ ٱلرَّاجِفَةُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxix{تَتْبَعُهَا ٱلرَّادِفَةُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxx{قُلُوبٌ يَوْمَئِذٍ وَاجِفَةٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxxi{أَبْصَٰرُهَا خَٰشِعَةٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxxii{يَقُولُونَ أَءِنَّا لَمَرْدُودُونَ فِى ٱلْحَافِرَةِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxxiii{أَءِذَا كُنَّا عِظَٰمًا نَّخِرَةً\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdccxxiv{قَالُوا۟ تِلْكَ إِذًا كَرَّةٌ خَاسِرَةٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxxv{فَإِنَّمَا هِىَ زَجْرَةٌ وَٰحِدَةٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxxvi{فَإِذَا هُم بِٱلسَّاهِرَةِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxxvii{هَلْ أَتَىٰكَ حَدِيثُ مُوسَىٰٓ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxxviii{إِذْ نَادَىٰهُ رَبُّهُۥ بِٱلْوَادِ ٱلْمُقَدَّسِ طُوًى\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxxix{ٱذْهَبْ إِلَىٰ فِرْعَوْنَ إِنَّهُۥ طَغَىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxxx{فَقُلْ هَل لَّكَ إِلَىٰٓ أَن تَزَكَّىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxi{وَأَهْدِيَكَ إِلَىٰ رَبِّكَ فَتَخْشَىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxii{فَأَرَىٰهُ ٱلْءَايَةَ ٱلْكُبْرَىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxiii{فَكَذَّبَ وَعَصَىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxiv{ثُمَّ أَدْبَرَ يَسْعَىٰ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxv{فَحَشَرَ فَنَادَىٰ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxvi{فَقَالَ أَنَا۠ رَبُّكُمُ ٱلْأَعْلَىٰ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxvii{فَأَخَذَهُ ٱللَّهُ نَكَالَ ٱلْءَاخِرَةِ وَٱلْأُولَىٰٓ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxviii{إِنَّ فِى ذَٰلِكَ لَعِبْرَةً لِّمَن يَخْشَىٰٓ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxix{ءَأَنتُمْ أَشَدُّ خَلْقًا أَمِ ٱلسَّمَآءُ بَنَىٰهَا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxl{رَفَعَ سَمْكَهَا فَسَوَّىٰهَا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxli{وَأَغْطَشَ لَيْلَهَا وَأَخْرَجَ ضُحَىٰهَا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxlii{وَٱلْأَرْضَ بَعْدَ ذَٰلِكَ دَحَىٰهَآ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxliii{أَخْرَجَ مِنْهَا مَآءَهَا وَمَرْعَىٰهَا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdccxliv{وَٱلْجِبَالَ أَرْسَىٰهَا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxlv{مَتَٰعًا لَّكُمْ وَلِأَنْعَٰمِكُمْ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxlvi{فَإِذَا جَآءَتِ ٱلطَّآمَّةُ ٱلْكُبْرَىٰ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxlvii{يَوْمَ يَتَذَكَّرُ ٱلْإِنسَٰنُ مَا سَعَىٰ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxlviii{وَبُرِّزَتِ ٱلْجَحِيمُ لِمَن يَرَىٰ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxlix{فَأَمَّا مَن طَغَىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdccl{وَءَاثَرَ ٱلْحَيَوٰةَ ٱلدُّنْيَا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdccli{فَإِنَّ ٱلْجَحِيمَ هِىَ ٱلْمَأْوَىٰ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclii{وَأَمَّا مَنْ خَافَ مَقَامَ رَبِّهِۦ وَنَهَى ٱلنَّفْسَ عَنِ ٱلْهَوَىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdccliii{فَإِنَّ ٱلْجَنَّةَ هِىَ ٱلْمَأْوَىٰ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdccliv{يَسْـَٔلُونَكَ عَنِ ٱلسَّاعَةِ أَيَّانَ مُرْسَىٰهَا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclv{فِيمَ أَنتَ مِن ذِكْرَىٰهَآ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclvi{إِلَىٰ رَبِّكَ مُنتَهَىٰهَآ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclvii{إِنَّمَآ أَنتَ مُنذِرُ مَن يَخْشَىٰهَا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclviii{كَأَنَّهُمْ يَوْمَ يَرَوْنَهَا لَمْ يَلْبَثُوٓا۟ إِلَّا عَشِيَّةً أَوْ ضُحَىٰهَا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclix{\basmalah عَبَسَ وَتَوَلَّىٰٓ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcclx{أَن جَآءَهُ ٱلْأَعْمَىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclxi{وَمَا يُدْرِيكَ لَعَلَّهُۥ يَزَّكَّىٰٓ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclxii{أَوْ يَذَّكَّرُ فَتَنفَعَهُ ٱلذِّكْرَىٰٓ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclxiii{أَمَّا مَنِ ٱسْتَغْنَىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclxiv{فَأَنتَ لَهُۥ تَصَدَّىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclxv{وَمَا عَلَيْكَ أَلَّا يَزَّكَّىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcclxvi{وَأَمَّا مَن جَآءَكَ يَسْعَىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcclxvii{وَهُوَ يَخْشَىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclxviii{فَأَنتَ عَنْهُ تَلَهَّىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcclxix{كَلَّآ إِنَّهَا تَذْكِرَةٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcclxx{فَمَن شَآءَ ذَكَرَهُۥ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxi{فِى صُحُفٍ مُّكَرَّمَةٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxii{مَّرْفُوعَةٍ مُّطَهَّرَةٍۭ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxiii{بِأَيْدِى سَفَرَةٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxiv{كِرَامٍۭ بَرَرَةٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxv{قُتِلَ ٱلْإِنسَٰنُ مَآ أَكْفَرَهُۥ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxvi{مِنْ أَىِّ شَىْءٍ خَلَقَهُۥ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxvii{مِن نُّطْفَةٍ خَلَقَهُۥ فَقَدَّرَهُۥ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxviii{ثُمَّ ٱلسَّبِيلَ يَسَّرَهُۥ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxix{ثُمَّ أَمَاتَهُۥ فَأَقْبَرَهُۥ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxx{ثُمَّ إِذَا شَآءَ أَنشَرَهُۥ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxi{كَلَّا لَمَّا يَقْضِ مَآ أَمَرَهُۥ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxii{فَلْيَنظُرِ ٱلْإِنسَٰنُ إِلَىٰ طَعَامِهِۦٓ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxiii{أَنَّا صَبَبْنَا ٱلْمَآءَ صَبًّا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxiv{ثُمَّ شَقَقْنَا ٱلْأَرْضَ شَقًّا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxv{فَأَنۢبَتْنَا فِيهَا حَبًّا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxvi{وَعِنَبًا وَقَضْبًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxvii{وَزَيْتُونًا وَنَخْلًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxviii{وَحَدَآئِقَ غُلْبًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxix{وَفَٰكِهَةً وَأَبًّا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdccxc{مَّتَٰعًا لَّكُمْ وَلِأَنْعَٰمِكُمْ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxci{فَإِذَا جَآءَتِ ٱلصَّآخَّةُ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxcii{يَوْمَ يَفِرُّ ٱلْمَرْءُ مِنْ أَخِيهِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxciii{وَأُمِّهِۦ وَأَبِيهِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxciv{وَصَٰحِبَتِهِۦ وَبَنِيهِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxcv{لِكُلِّ ٱمْرِئٍ مِّنْهُمْ يَوْمَئِذٍ شَأْنٌ يُغْنِيهِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxcvi{وُجُوهٌ يَوْمَئِذٍ مُّسْفِرَةٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxcvii{ضَاحِكَةٌ مُّسْتَبْشِرَةٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxcviii{وَوُجُوهٌ يَوْمَئِذٍ عَلَيْهَا غَبَرَةٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxcix{تَرْهَقُهَا قَتَرَةٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdccc{أُو۟لَٰٓئِكَ هُمُ ٱلْكَفَرَةُ ٱلْفَجَرَةُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdccci{\basmalah إِذَا ٱلشَّمْسُ كُوِّرَتْ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcccii{وَإِذَا ٱلنُّجُومُ ٱنكَدَرَتْ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdccciii{وَإِذَا ٱلْجِبَالُ سُيِّرَتْ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccciv{وَإِذَا ٱلْعِشَارُ عُطِّلَتْ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccv{وَإِذَا ٱلْوُحُوشُ حُشِرَتْ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccvi{وَإِذَا ٱلْبِحَارُ سُجِّرَتْ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccvii{وَإِذَا ٱلنُّفُوسُ زُوِّجَتْ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccviii{وَإِذَا ٱلْمَوْءُۥدَةُ سُئِلَتْ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccix{بِأَىِّ ذَنۢبٍ قُتِلَتْ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccx{وَإِذَا ٱلصُّحُفُ نُشِرَتْ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxi{وَإِذَا ٱلسَّمَآءُ كُشِطَتْ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxii{وَإِذَا ٱلْجَحِيمُ سُعِّرَتْ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxiii{وَإِذَا ٱلْجَنَّةُ أُزْلِفَتْ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxiv{عَلِمَتْ نَفْسٌ مَّآ أَحْضَرَتْ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxv{فَلَآ أُقْسِمُ بِٱلْخُنَّسِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxvi{ٱلْجَوَارِ ٱلْكُنَّسِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxvii{وَٱلَّيْلِ إِذَا عَسْعَسَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxviii{وَٱلصُّبْحِ إِذَا تَنَفَّسَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxix{إِنَّهُۥ لَقَوْلُ رَسُولٍ كَرِيمٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxx{ذِى قُوَّةٍ عِندَ ذِى ٱلْعَرْشِ مَكِينٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxi{مُّطَاعٍ ثَمَّ أَمِينٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxii{وَمَا صَاحِبُكُم بِمَجْنُونٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxiii{وَلَقَدْ رَءَاهُ بِٱلْأُفُقِ ٱلْمُبِينِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxiv{وَمَا هُوَ عَلَى ٱلْغَيْبِ بِضَنِينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxv{وَمَا هُوَ بِقَوْلِ شَيْطَٰنٍ رَّجِيمٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxvi{فَأَيْنَ تَذْهَبُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxvii{إِنْ هُوَ إِلَّا ذِكْرٌ لِّلْعَٰلَمِينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxviii{لِمَن شَآءَ مِنكُمْ أَن يَسْتَقِيمَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxix{وَمَا تَشَآءُونَ إِلَّآ أَن يَشَآءَ ٱللَّهُ رَبُّ ٱلْعَٰلَمِينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxx{\basmalah إِذَا ٱلسَّمَآءُ ٱنفَطَرَتْ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxi{وَإِذَا ٱلْكَوَاكِبُ ٱنتَثَرَتْ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxii{وَإِذَا ٱلْبِحَارُ فُجِّرَتْ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxiii{وَإِذَا ٱلْقُبُورُ بُعْثِرَتْ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxiv{عَلِمَتْ نَفْسٌ مَّا قَدَّمَتْ وَأَخَّرَتْ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxv{يَٰٓأَيُّهَا ٱلْإِنسَٰنُ مَا غَرَّكَ بِرَبِّكَ ٱلْكَرِيمِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxvi{ٱلَّذِى خَلَقَكَ فَسَوَّىٰكَ فَعَدَلَكَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxvii{فِىٓ أَىِّ صُورَةٍ مَّا شَآءَ رَكَّبَكَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxviii{كَلَّا بَلْ تُكَذِّبُونَ بِٱلدِّينِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxix{وَإِنَّ عَلَيْكُمْ لَحَٰفِظِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxl{كِرَامًا كَٰتِبِينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxli{يَعْلَمُونَ مَا تَفْعَلُونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlii{إِنَّ ٱلْأَبْرَارَ لَفِى نَعِيمٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxliii{وَإِنَّ ٱلْفُجَّارَ لَفِى جَحِيمٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxliv{يَصْلَوْنَهَا يَوْمَ ٱلدِّينِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlv{وَمَا هُمْ عَنْهَا بِغَآئِبِينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlvi{وَمَآ أَدْرَىٰكَ مَا يَوْمُ ٱلدِّينِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlvii{ثُمَّ مَآ أَدْرَىٰكَ مَا يَوْمُ ٱلدِّينِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlviii{يَوْمَ لَا تَمْلِكُ نَفْسٌ لِّنَفْسٍ شَيْـًٔا وَٱلْأَمْرُ يَوْمَئِذٍ لِّلَّهِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlix{\basmalah وَيْلٌ لِّلْمُطَفِّفِينَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcccl{ٱلَّذِينَ إِذَا ٱكْتَالُوا۟ عَلَى ٱلنَّاسِ يَسْتَوْفُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccli{وَإِذَا كَالُوهُمْ أَو وَّزَنُوهُمْ يُخْسِرُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclii{أَلَا يَظُنُّ أُو۟لَٰٓئِكَ أَنَّهُم مَّبْعُوثُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccliii{لِيَوْمٍ عَظِيمٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccliv{يَوْمَ يَقُومُ ٱلنَّاسُ لِرَبِّ ٱلْعَٰلَمِينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclv{كَلَّآ إِنَّ كِتَٰبَ ٱلْفُجَّارِ لَفِى سِجِّينٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdccclvi{وَمَآ أَدْرَىٰكَ مَا سِجِّينٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdccclvii{كِتَٰبٌ مَّرْقُومٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdccclviii{وَيْلٌ يَوْمَئِذٍ لِّلْمُكَذِّبِينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdccclix{ٱلَّذِينَ يُكَذِّبُونَ بِيَوْمِ ٱلدِّينِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdccclx{وَمَا يُكَذِّبُ بِهِۦٓ إِلَّا كُلُّ مُعْتَدٍ أَثِيمٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxi{إِذَا تُتْلَىٰ عَلَيْهِ ءَايَٰتُنَا قَالَ أَسَٰطِيرُ ٱلْأَوَّلِينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxii{كَلَّا بَلْ رَانَ عَلَىٰ قُلُوبِهِم مَّا كَانُوا۟ يَكْسِبُونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxiii{كَلَّآ إِنَّهُمْ عَن رَّبِّهِمْ يَوْمَئِذٍ لَّمَحْجُوبُونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdccclxiv{ثُمَّ إِنَّهُمْ لَصَالُوا۟ ٱلْجَحِيمِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclxv{ثُمَّ يُقَالُ هَٰذَا ٱلَّذِى كُنتُم بِهِۦ تُكَذِّبُونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdccclxvi{كَلَّآ إِنَّ كِتَٰبَ ٱلْأَبْرَارِ لَفِى عِلِّيِّينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdccclxvii{وَمَآ أَدْرَىٰكَ مَا عِلِّيُّونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdccclxviii{كِتَٰبٌ مَّرْقُومٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdccclxix{يَشْهَدُهُ ٱلْمُقَرَّبُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdccclxx{إِنَّ ٱلْأَبْرَارَ لَفِى نَعِيمٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxi{عَلَى ٱلْأَرَآئِكِ يَنظُرُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxii{تَعْرِفُ فِى وُجُوهِهِمْ نَضْرَةَ ٱلنَّعِيمِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxiii{يُسْقَوْنَ مِن رَّحِيقٍ مَّخْتُومٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxiv{خِتَٰمُهُۥ مِسْكٌ وَفِى ذَٰلِكَ فَلْيَتَنَافَسِ ٱلْمُتَنَٰفِسُونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxv{وَمِزَاجُهُۥ مِن تَسْنِيمٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxvi{عَيْنًا يَشْرَبُ بِهَا ٱلْمُقَرَّبُونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxvii{إِنَّ ٱلَّذِينَ أَجْرَمُوا۟ كَانُوا۟ مِنَ ٱلَّذِينَ ءَامَنُوا۟ يَضْحَكُونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxviii{وَإِذَا مَرُّوا۟ بِهِمْ يَتَغَامَزُونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxix{وَإِذَا ٱنقَلَبُوٓا۟ إِلَىٰٓ أَهْلِهِمُ ٱنقَلَبُوا۟ فَكِهِينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxx{وَإِذَا رَأَوْهُمْ قَالُوٓا۟ إِنَّ هَٰٓؤُلَآءِ لَضَآلُّونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxi{وَمَآ أُرْسِلُوا۟ عَلَيْهِمْ حَٰفِظِينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxii{فَٱلْيَوْمَ ٱلَّذِينَ ءَامَنُوا۟ مِنَ ٱلْكُفَّارِ يَضْحَكُونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxiii{عَلَى ٱلْأَرَآئِكِ يَنظُرُونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxiv{هَلْ ثُوِّبَ ٱلْكُفَّارُ مَا كَانُوا۟ يَفْعَلُونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxv{\basmalah إِذَا ٱلسَّمَآءُ ٱنشَقَّتْ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxvi{وَأَذِنَتْ لِرَبِّهَا وَحُقَّتْ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxvii{وَإِذَا ٱلْأَرْضُ مُدَّتْ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxviii{وَأَلْقَتْ مَا فِيهَا وَتَخَلَّتْ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxix{وَأَذِنَتْ لِرَبِّهَا وَحُقَّتْ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxc{يَٰٓأَيُّهَا ٱلْإِنسَٰنُ إِنَّكَ كَادِحٌ إِلَىٰ رَبِّكَ كَدْحًا فَمُلَٰقِيهِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxci{فَأَمَّا مَنْ أُوتِىَ كِتَٰبَهُۥ بِيَمِينِهِۦ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcii{فَسَوْفَ يُحَاسَبُ حِسَابًا يَسِيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxciii{وَيَنقَلِبُ إِلَىٰٓ أَهْلِهِۦ مَسْرُورًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxciv{وَأَمَّا مَنْ أُوتِىَ كِتَٰبَهُۥ وَرَآءَ ظَهْرِهِۦ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcv{فَسَوْفَ يَدْعُوا۟ ثُبُورًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcvi{وَيَصْلَىٰ سَعِيرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcvii{إِنَّهُۥ كَانَ فِىٓ أَهْلِهِۦ مَسْرُورًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcviii{إِنَّهُۥ ظَنَّ أَن لَّن يَحُورَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcix{بَلَىٰٓ إِنَّ رَبَّهُۥ كَانَ بِهِۦ بَصِيرًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcm{فَلَآ أُقْسِمُ بِٱلشَّفَقِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmi{وَٱلَّيْلِ وَمَا وَسَقَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmii{وَٱلْقَمَرِ إِذَا ٱتَّسَقَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmiii{لَتَرْكَبُنَّ طَبَقًا عَن طَبَقٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmiv{فَمَا لَهُمْ لَا يُؤْمِنُونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcmv{وَإِذَا قُرِئَ عَلَيْهِمُ ٱلْقُرْءَانُ لَا يَسْجُدُونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcmvi{بَلِ ٱلَّذِينَ كَفَرُوا۟ يُكَذِّبُونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcmvii{وَٱللَّهُ أَعْلَمُ بِمَا يُوعُونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcmviii{فَبَشِّرْهُم بِعَذَابٍ أَلِيمٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcmix{إِلَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَهُمْ أَجْرٌ غَيْرُ مَمْنُونٍۭ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcmx{\basmalah وَٱلسَّمَآءِ ذَاتِ ٱلْبُرُوجِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmxi{وَٱلْيَوْمِ ٱلْمَوْعُودِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxii{وَشَاهِدٍ وَمَشْهُودٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxiii{قُتِلَ أَصْحَٰبُ ٱلْأُخْدُودِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxiv{ٱلنَّارِ ذَاتِ ٱلْوَقُودِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxv{إِذْ هُمْ عَلَيْهَا قُعُودٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxvi{وَهُمْ عَلَىٰ مَا يَفْعَلُونَ بِٱلْمُؤْمِنِينَ شُهُودٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxvii{وَمَا نَقَمُوا۟ مِنْهُمْ إِلَّآ أَن يُؤْمِنُوا۟ بِٱللَّهِ ٱلْعَزِيزِ ٱلْحَمِيدِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmxviii{ٱلَّذِى لَهُۥ مُلْكُ ٱلسَّمَٰوَٰتِ وَٱلْأَرْضِ وَٱللَّهُ عَلَىٰ كُلِّ شَىْءٍ شَهِيدٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmxix{إِنَّ ٱلَّذِينَ فَتَنُوا۟ ٱلْمُؤْمِنِينَ وَٱلْمُؤْمِنَٰتِ ثُمَّ لَمْ يَتُوبُوا۟ فَلَهُمْ عَذَابُ جَهَنَّمَ وَلَهُمْ عَذَابُ ٱلْحَرِيقِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmxx{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ لَهُمْ جَنَّٰتٌ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ ذَٰلِكَ ٱلْفَوْزُ ٱلْكَبِيرُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmxxi{إِنَّ بَطْشَ رَبِّكَ لَشَدِيدٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxxii{إِنَّهُۥ هُوَ يُبْدِئُ وَيُعِيدُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxxiii{وَهُوَ ٱلْغَفُورُ ٱلْوَدُودُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxxiv{ذُو ٱلْعَرْشِ ٱلْمَجِيدُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxxv{فَعَّالٌ لِّمَا يُرِيدُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxxvi{هَلْ أَتَىٰكَ حَدِيثُ ٱلْجُنُودِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxxvii{فِرْعَوْنَ وَثَمُودَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmxxviii{بَلِ ٱلَّذِينَ كَفَرُوا۟ فِى تَكْذِيبٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmxxix{وَٱللَّهُ مِن وَرَآئِهِم مُّحِيطٌۢ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcmxxx{بَلْ هُوَ قُرْءَانٌ مَّجِيدٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxi{فِى لَوْحٍ مَّحْفُوظٍۭ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxii{\basmalah وَٱلسَّمَآءِ وَٱلطَّارِقِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxiii{وَمَآ أَدْرَىٰكَ مَا ٱلطَّارِقُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxiv{ٱلنَّجْمُ ٱلثَّاقِبُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxv{إِن كُلُّ نَفْسٍ لَّمَّا عَلَيْهَا حَافِظٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxvi{فَلْيَنظُرِ ٱلْإِنسَٰنُ مِمَّ خُلِقَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxvii{خُلِقَ مِن مَّآءٍ دَافِقٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxviii{يَخْرُجُ مِنۢ بَيْنِ ٱلصُّلْبِ وَٱلتَّرَآئِبِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxix{إِنَّهُۥ عَلَىٰ رَجْعِهِۦ لَقَادِرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmxl{يَوْمَ تُبْلَى ٱلسَّرَآئِرُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmxli{فَمَا لَهُۥ مِن قُوَّةٍ وَلَا نَاصِرٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmxlii{وَٱلسَّمَآءِ ذَاتِ ٱلرَّجْعِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmxliii{وَٱلْأَرْضِ ذَاتِ ٱلصَّدْعِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxliv{إِنَّهُۥ لَقَوْلٌ فَصْلٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxlv{وَمَا هُوَ بِٱلْهَزْلِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxlvi{إِنَّهُمْ يَكِيدُونَ كَيْدًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxlvii{وَأَكِيدُ كَيْدًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxlviii{فَمَهِّلِ ٱلْكَٰفِرِينَ أَمْهِلْهُمْ رُوَيْدًۢا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxlix{\basmalah سَبِّحِ ٱسْمَ رَبِّكَ ٱلْأَعْلَى\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcml{ٱلَّذِى خَلَقَ فَسَوَّىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmli{وَٱلَّذِى قَدَّرَ فَهَدَىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlii{وَٱلَّذِىٓ أَخْرَجَ ٱلْمَرْعَىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmliii{فَجَعَلَهُۥ غُثَآءً أَحْوَىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmliv{سَنُقْرِئُكَ فَلَا تَنسَىٰٓ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlv{إِلَّا مَا شَآءَ ٱللَّهُ إِنَّهُۥ يَعْلَمُ ٱلْجَهْرَ وَمَا يَخْفَىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlvi{وَنُيَسِّرُكَ لِلْيُسْرَىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlvii{فَذَكِّرْ إِن نَّفَعَتِ ٱلذِّكْرَىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlviii{سَيَذَّكَّرُ مَن يَخْشَىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmlix{وَيَتَجَنَّبُهَا ٱلْأَشْقَى\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmlx{ٱلَّذِى يَصْلَى ٱلنَّارَ ٱلْكُبْرَىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmlxi{ثُمَّ لَا يَمُوتُ فِيهَا وَلَا يَحْيَىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlxii{قَدْ أَفْلَحَ مَن تَزَكَّىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmlxiii{وَذَكَرَ ٱسْمَ رَبِّهِۦ فَصَلَّىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmlxiv{بَلْ تُؤْثِرُونَ ٱلْحَيَوٰةَ ٱلدُّنْيَا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlxv{وَٱلْءَاخِرَةُ خَيْرٌ وَأَبْقَىٰٓ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlxvi{إِنَّ هَٰذَا لَفِى ٱلصُّحُفِ ٱلْأُولَىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlxvii{صُحُفِ إِبْرَٰهِيمَ وَمُوسَىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlxviii{\basmalah هَلْ أَتَىٰكَ حَدِيثُ ٱلْغَٰشِيَةِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmlxix{وُجُوهٌ يَوْمَئِذٍ خَٰشِعَةٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmlxx{عَامِلَةٌ نَّاصِبَةٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxi{تَصْلَىٰ نَارًا حَامِيَةً\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxii{تُسْقَىٰ مِنْ عَيْنٍ ءَانِيَةٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxiii{لَّيْسَ لَهُمْ طَعَامٌ إِلَّا مِن ضَرِيعٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxiv{لَّا يُسْمِنُ وَلَا يُغْنِى مِن جُوعٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxv{وُجُوهٌ يَوْمَئِذٍ نَّاعِمَةٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxvi{لِّسَعْيِهَا رَاضِيَةٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxvii{فِى جَنَّةٍ عَالِيَةٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxviii{لَّا تَسْمَعُ فِيهَا لَٰغِيَةً\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxix{فِيهَا عَيْنٌ جَارِيَةٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxx{فِيهَا سُرُرٌ مَّرْفُوعَةٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxi{وَأَكْوَابٌ مَّوْضُوعَةٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxii{وَنَمَارِقُ مَصْفُوفَةٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxiii{وَزَرَابِىُّ مَبْثُوثَةٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxiv{أَفَلَا يَنظُرُونَ إِلَى ٱلْإِبِلِ كَيْفَ خُلِقَتْ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxv{وَإِلَى ٱلسَّمَآءِ كَيْفَ رُفِعَتْ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxvi{وَإِلَى ٱلْجِبَالِ كَيْفَ نُصِبَتْ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxvii{وَإِلَى ٱلْأَرْضِ كَيْفَ سُطِحَتْ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxviii{فَذَكِّرْ إِنَّمَآ أَنتَ مُذَكِّرٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxix{لَّسْتَ عَلَيْهِم بِمُصَيْطِرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxc{إِلَّا مَن تَوَلَّىٰ وَكَفَرَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxci{فَيُعَذِّبُهُ ٱللَّهُ ٱلْعَذَابَ ٱلْأَكْبَرَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxcii{إِنَّ إِلَيْنَآ إِيَابَهُمْ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxciii{ثُمَّ إِنَّ عَلَيْنَا حِسَابَهُم\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxciv{\basmalah وَٱلْفَجْرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmxcv{وَلَيَالٍ عَشْرٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxcvi{وَٱلشَّفْعِ وَٱلْوَتْرِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxcvii{وَٱلَّيْلِ إِذَا يَسْرِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxcviii{هَلْ فِى ذَٰلِكَ قَسَمٌ لِّذِى حِجْرٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxcix{أَلَمْ تَرَ كَيْفَ فَعَلَ رَبُّكَ بِعَادٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmm{إِرَمَ ذَاتِ ٱلْعِمَادِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmi{ٱلَّتِى لَمْ يُخْلَقْ مِثْلُهَا فِى ٱلْبِلَٰدِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmii{وَثَمُودَ ٱلَّذِينَ جَابُوا۟ ٱلصَّخْرَ بِٱلْوَادِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmiii{وَفِرْعَوْنَ ذِى ٱلْأَوْتَادِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmiv{ٱلَّذِينَ طَغَوْا۟ فِى ٱلْبِلَٰدِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmv{فَأَكْثَرُوا۟ فِيهَا ٱلْفَسَادَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmvi{فَصَبَّ عَلَيْهِمْ رَبُّكَ سَوْطَ عَذَابٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmvii{إِنَّ رَبَّكَ لَبِٱلْمِرْصَادِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmviii{فَأَمَّا ٱلْإِنسَٰنُ إِذَا مَا ٱبْتَلَىٰهُ رَبُّهُۥ فَأَكْرَمَهُۥ وَنَعَّمَهُۥ فَيَقُولُ رَبِّىٓ أَكْرَمَنِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmix{وَأَمَّآ إِذَا مَا ٱبْتَلَىٰهُ فَقَدَرَ عَلَيْهِ رِزْقَهُۥ فَيَقُولُ رَبِّىٓ أَهَٰنَنِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmx{كَلَّا بَل لَّا تُكْرِمُونَ ٱلْيَتِيمَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmxi{وَلَا تَحَٰٓضُّونَ عَلَىٰ طَعَامِ ٱلْمِسْكِينِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmxii{وَتَأْكُلُونَ ٱلتُّرَاثَ أَكْلًا لَّمًّا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmxiii{وَتُحِبُّونَ ٱلْمَالَ حُبًّا جَمًّا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmmxiv{كَلَّآ إِذَا دُكَّتِ ٱلْأَرْضُ دَكًّا دَكًّا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmmxv{وَجَآءَ رَبُّكَ وَٱلْمَلَكُ صَفًّا صَفًّا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmmxvi{وَجِا۟ىٓءَ يَوْمَئِذٍۭ بِجَهَنَّمَ يَوْمَئِذٍ يَتَذَكَّرُ ٱلْإِنسَٰنُ وَأَنَّىٰ لَهُ ٱلذِّكْرَىٰ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmmxvii{يَقُولُ يَٰلَيْتَنِى قَدَّمْتُ لِحَيَاتِى\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmmxviii{فَيَوْمَئِذٍ لَّا يُعَذِّبُ عَذَابَهُۥٓ أَحَدٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmmxix{وَلَا يُوثِقُ وَثَاقَهُۥٓ أَحَدٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmmxx{يَٰٓأَيَّتُهَا ٱلنَّفْسُ ٱلْمُطْمَئِنَّةُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmmxxi{ٱرْجِعِىٓ إِلَىٰ رَبِّكِ رَاضِيَةً مَّرْضِيَّةً\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmmxxii{فَٱدْخُلِى فِى عِبَٰدِى\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmmxxiii{وَٱدْخُلِى جَنَّتِى\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmmxxiv{\basmalah لَآ أُقْسِمُ بِهَٰذَا ٱلْبَلَدِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmxxv{وَأَنتَ حِلٌّۢ بِهَٰذَا ٱلْبَلَدِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmxxvi{وَوَالِدٍ وَمَا وَلَدَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmxxvii{لَقَدْ خَلَقْنَا ٱلْإِنسَٰنَ فِى كَبَدٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmxxviii{أَيَحْسَبُ أَن لَّن يَقْدِرَ عَلَيْهِ أَحَدٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmxxix{يَقُولُ أَهْلَكْتُ مَالًا لُّبَدًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmxxx{أَيَحْسَبُ أَن لَّمْ يَرَهُۥٓ أَحَدٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmxxxi{أَلَمْ نَجْعَل لَّهُۥ عَيْنَيْنِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmxxxii{وَلِسَانًا وَشَفَتَيْنِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmxxxiii{وَهَدَيْنَٰهُ ٱلنَّجْدَيْنِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmxxxiv{فَلَا ٱقْتَحَمَ ٱلْعَقَبَةَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmxxxv{وَمَآ أَدْرَىٰكَ مَا ٱلْعَقَبَةُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmxxxvi{فَكُّ رَقَبَةٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmxxxvii{أَوْ إِطْعَٰمٌ فِى يَوْمٍ ذِى مَسْغَبَةٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmxxxviii{يَتِيمًا ذَا مَقْرَبَةٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmxxxix{أَوْ مِسْكِينًا ذَا مَتْرَبَةٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmxl{ثُمَّ كَانَ مِنَ ٱلَّذِينَ ءَامَنُوا۟ وَتَوَاصَوْا۟ بِٱلصَّبْرِ وَتَوَاصَوْا۟ بِٱلْمَرْحَمَةِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmxli{أُو۟لَٰٓئِكَ أَصْحَٰبُ ٱلْمَيْمَنَةِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmxlii{وَٱلَّذِينَ كَفَرُوا۟ بِـَٔايَٰتِنَا هُمْ أَصْحَٰبُ ٱلْمَشْـَٔمَةِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmxliii{عَلَيْهِمْ نَارٌ مُّؤْصَدَةٌۢ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmmxliv{\basmalah وَٱلشَّمْسِ وَضُحَىٰهَا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmxlv{وَٱلْقَمَرِ إِذَا تَلَىٰهَا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmxlvi{وَٱلنَّهَارِ إِذَا جَلَّىٰهَا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmxlvii{وَٱلَّيْلِ إِذَا يَغْشَىٰهَا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmxlviii{وَٱلسَّمَآءِ وَمَا بَنَىٰهَا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmxlix{وَٱلْأَرْضِ وَمَا طَحَىٰهَا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmml{وَنَفْسٍ وَمَا سَوَّىٰهَا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmli{فَأَلْهَمَهَا فُجُورَهَا وَتَقْوَىٰهَا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmlii{قَدْ أَفْلَحَ مَن زَكَّىٰهَا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmliii{وَقَدْ خَابَ مَن دَسَّىٰهَا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmliv{كَذَّبَتْ ثَمُودُ بِطَغْوَىٰهَآ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmlv{إِذِ ٱنۢبَعَثَ أَشْقَىٰهَا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmlvi{فَقَالَ لَهُمْ رَسُولُ ٱللَّهِ نَاقَةَ ٱللَّهِ وَسُقْيَٰهَا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmlvii{فَكَذَّبُوهُ فَعَقَرُوهَا فَدَمْدَمَ عَلَيْهِمْ رَبُّهُم بِذَنۢبِهِمْ فَسَوَّىٰهَا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmlviii{وَلَا يَخَافُ عُقْبَٰهَا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmlix{\basmalah وَٱلَّيْلِ إِذَا يَغْشَىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmlx{وَٱلنَّهَارِ إِذَا تَجَلَّىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmlxi{وَمَا خَلَقَ ٱلذَّكَرَ وَٱلْأُنثَىٰٓ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmlxii{إِنَّ سَعْيَكُمْ لَشَتَّىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmlxiii{فَأَمَّا مَنْ أَعْطَىٰ وَٱتَّقَىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmlxiv{وَصَدَّقَ بِٱلْحُسْنَىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmlxv{فَسَنُيَسِّرُهُۥ لِلْيُسْرَىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmlxvi{وَأَمَّا مَنۢ بَخِلَ وَٱسْتَغْنَىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmlxvii{وَكَذَّبَ بِٱلْحُسْنَىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmlxviii{فَسَنُيَسِّرُهُۥ لِلْعُسْرَىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmlxix{وَمَا يُغْنِى عَنْهُ مَالُهُۥٓ إِذَا تَرَدَّىٰٓ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmlxx{إِنَّ عَلَيْنَا لَلْهُدَىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmlxxi{وَإِنَّ لَنَا لَلْءَاخِرَةَ وَٱلْأُولَىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmlxxii{فَأَنذَرْتُكُمْ نَارًا تَلَظَّىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmlxxiii{لَا يَصْلَىٰهَآ إِلَّا ٱلْأَشْقَى\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmlxxiv{ٱلَّذِى كَذَّبَ وَتَوَلَّىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmlxxv{وَسَيُجَنَّبُهَا ٱلْأَتْقَى\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmlxxvi{ٱلَّذِى يُؤْتِى مَالَهُۥ يَتَزَكَّىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmlxxvii{وَمَا لِأَحَدٍ عِندَهُۥ مِن نِّعْمَةٍ تُجْزَىٰٓ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmlxxviii{إِلَّا ٱبْتِغَآءَ وَجْهِ رَبِّهِ ٱلْأَعْلَىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmmlxxix{وَلَسَوْفَ يَرْضَىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmmlxxx{\basmalah وَٱلضُّحَىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxi{وَٱلَّيْلِ إِذَا سَجَىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxii{مَا وَدَّعَكَ رَبُّكَ وَمَا قَلَىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxiii{وَلَلْءَاخِرَةُ خَيْرٌ لَّكَ مِنَ ٱلْأُولَىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxiv{وَلَسَوْفَ يُعْطِيكَ رَبُّكَ فَتَرْضَىٰٓ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxv{أَلَمْ يَجِدْكَ يَتِيمًا فَـَٔاوَىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxvi{وَوَجَدَكَ ضَآلًّا فَهَدَىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxvii{وَوَجَدَكَ عَآئِلًا فَأَغْنَىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxviii{فَأَمَّا ٱلْيَتِيمَ فَلَا تَقْهَرْ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxix{وَأَمَّا ٱلسَّآئِلَ فَلَا تَنْهَرْ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmxc{وَأَمَّا بِنِعْمَةِ رَبِّكَ فَحَدِّثْ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmxci{\basmalah أَلَمْ نَشْرَحْ لَكَ صَدْرَكَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmxcii{وَوَضَعْنَا عَنكَ وِزْرَكَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmxciii{ٱلَّذِىٓ أَنقَضَ ظَهْرَكَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmxciv{وَرَفَعْنَا لَكَ ذِكْرَكَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmxcv{فَإِنَّ مَعَ ٱلْعُسْرِ يُسْرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmxcvi{إِنَّ مَعَ ٱلْعُسْرِ يُسْرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmxcvii{فَإِذَا فَرَغْتَ فَٱنصَبْ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmxcviii{وَإِلَىٰ رَبِّكَ فَٱرْغَب\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmxcix{\basmalah وَٱلتِّينِ وَٱلزَّيْتُونِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmc{وَطُورِ سِينِينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmci{وَهَٰذَا ٱلْبَلَدِ ٱلْأَمِينِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcii{لَقَدْ خَلَقْنَا ٱلْإِنسَٰنَ فِىٓ أَحْسَنِ تَقْوِيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmciii{ثُمَّ رَدَدْنَٰهُ أَسْفَلَ سَٰفِلِينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmciv{إِلَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ فَلَهُمْ أَجْرٌ غَيْرُ مَمْنُونٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcv{فَمَا يُكَذِّبُكَ بَعْدُ بِٱلدِّينِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcvi{أَلَيْسَ ٱللَّهُ بِأَحْكَمِ ٱلْحَٰكِمِينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcvii{\basmalah ٱقْرَأْ بِٱسْمِ رَبِّكَ ٱلَّذِى خَلَقَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcviii{خَلَقَ ٱلْإِنسَٰنَ مِنْ عَلَقٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcix{ٱقْرَأْ وَرَبُّكَ ٱلْأَكْرَمُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcx{ٱلَّذِى عَلَّمَ بِٱلْقَلَمِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxi{عَلَّمَ ٱلْإِنسَٰنَ مَا لَمْ يَعْلَمْ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxii{كَلَّآ إِنَّ ٱلْإِنسَٰنَ لَيَطْغَىٰٓ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxiii{أَن رَّءَاهُ ٱسْتَغْنَىٰٓ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxiv{إِنَّ إِلَىٰ رَبِّكَ ٱلرُّجْعَىٰٓ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxv{أَرَءَيْتَ ٱلَّذِى يَنْهَىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmcxvi{عَبْدًا إِذَا صَلَّىٰٓ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmcxvii{أَرَءَيْتَ إِن كَانَ عَلَى ٱلْهُدَىٰٓ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmcxviii{أَوْ أَمَرَ بِٱلتَّقْوَىٰٓ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxix{أَرَءَيْتَ إِن كَذَّبَ وَتَوَلَّىٰٓ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxx{أَلَمْ يَعْلَم بِأَنَّ ٱللَّهَ يَرَىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxxi{كَلَّا لَئِن لَّمْ يَنتَهِ لَنَسْفَعًۢا بِٱلنَّاصِيَةِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxxii{نَاصِيَةٍ كَٰذِبَةٍ خَاطِئَةٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxxiii{فَلْيَدْعُ نَادِيَهُۥ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxxiv{سَنَدْعُ ٱلزَّبَانِيَةَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxxv{كَلَّا لَا تُطِعْهُ وَٱسْجُدْ وَٱقْتَرِب\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmcxxvi{\basmalah إِنَّآ أَنزَلْنَٰهُ فِى لَيْلَةِ ٱلْقَدْرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxxvii{وَمَآ أَدْرَىٰكَ مَا لَيْلَةُ ٱلْقَدْرِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxxviii{لَيْلَةُ ٱلْقَدْرِ خَيْرٌ مِّنْ أَلْفِ شَهْرٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxxix{تَنَزَّلُ ٱلْمَلَٰٓئِكَةُ وَٱلرُّوحُ فِيهَا بِإِذْنِ رَبِّهِم مِّن كُلِّ أَمْرٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxxx{سَلَٰمٌ هِىَ حَتَّىٰ مَطْلَعِ ٱلْفَجْرِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxi{\basmalah لَمْ يَكُنِ ٱلَّذِينَ كَفَرُوا۟ مِنْ أَهْلِ ٱلْكِتَٰبِ وَٱلْمُشْرِكِينَ مُنفَكِّينَ حَتَّىٰ تَأْتِيَهُمُ ٱلْبَيِّنَةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxii{رَسُولٌ مِّنَ ٱللَّهِ يَتْلُوا۟ صُحُفًا مُّطَهَّرَةً\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxiii{فِيهَا كُتُبٌ قَيِّمَةٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxiv{وَمَا تَفَرَّقَ ٱلَّذِينَ أُوتُوا۟ ٱلْكِتَٰبَ إِلَّا مِنۢ بَعْدِ مَا جَآءَتْهُمُ ٱلْبَيِّنَةُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxv{وَمَآ أُمِرُوٓا۟ إِلَّا لِيَعْبُدُوا۟ ٱللَّهَ مُخْلِصِينَ لَهُ ٱلدِّينَ حُنَفَآءَ وَيُقِيمُوا۟ ٱلصَّلَوٰةَ وَيُؤْتُوا۟ ٱلزَّكَوٰةَ وَذَٰلِكَ دِينُ ٱلْقَيِّمَةِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxvi{إِنَّ ٱلَّذِينَ كَفَرُوا۟ مِنْ أَهْلِ ٱلْكِتَٰبِ وَٱلْمُشْرِكِينَ فِى نَارِ جَهَنَّمَ خَٰلِدِينَ فِيهَآ أُو۟لَٰٓئِكَ هُمْ شَرُّ ٱلْبَرِيَّةِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxvii{إِنَّ ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ أُو۟لَٰٓئِكَ هُمْ خَيْرُ ٱلْبَرِيَّةِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxviii{جَزَآؤُهُمْ عِندَ رَبِّهِمْ جَنَّٰتُ عَدْنٍ تَجْرِى مِن تَحْتِهَا ٱلْأَنْهَٰرُ خَٰلِدِينَ فِيهَآ أَبَدًا رَّضِىَ ٱللَّهُ عَنْهُمْ وَرَضُوا۟ عَنْهُ ذَٰلِكَ لِمَنْ خَشِىَ رَبَّهُۥ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxix{\basmalah إِذَا زُلْزِلَتِ ٱلْأَرْضُ زِلْزَالَهَا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxl{وَأَخْرَجَتِ ٱلْأَرْضُ أَثْقَالَهَا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxli{وَقَالَ ٱلْإِنسَٰنُ مَا لَهَا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxlii{يَوْمَئِذٍ تُحَدِّثُ أَخْبَارَهَا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxliii{بِأَنَّ رَبَّكَ أَوْحَىٰ لَهَا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxliv{يَوْمَئِذٍ يَصْدُرُ ٱلنَّاسُ أَشْتَاتًا لِّيُرَوْا۟ أَعْمَٰلَهُمْ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxlv{فَمَن يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُۥ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxlvi{وَمَن يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُۥ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxlvii{\basmalah وَٱلْعَٰدِيَٰتِ ضَبْحًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxlviii{فَٱلْمُورِيَٰتِ قَدْحًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxlix{فَٱلْمُغِيرَٰتِ صُبْحًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcl{فَأَثَرْنَ بِهِۦ نَقْعًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcli{فَوَسَطْنَ بِهِۦ جَمْعًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclii{إِنَّ ٱلْإِنسَٰنَ لِرَبِّهِۦ لَكَنُودٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcliii{وَإِنَّهُۥ عَلَىٰ ذَٰلِكَ لَشَهِيدٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcliv{وَإِنَّهُۥ لِحُبِّ ٱلْخَيْرِ لَشَدِيدٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclv{أَفَلَا يَعْلَمُ إِذَا بُعْثِرَ مَا فِى ٱلْقُبُورِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmclvi{وَحُصِّلَ مَا فِى ٱلصُّدُورِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmclvii{إِنَّ رَبَّهُم بِهِمْ يَوْمَئِذٍ لَّخَبِيرٌۢ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmclviii{\basmalah ٱلْقَارِعَةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclix{مَا ٱلْقَارِعَةُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclx{وَمَآ أَدْرَىٰكَ مَا ٱلْقَارِعَةُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxi{يَوْمَ يَكُونُ ٱلنَّاسُ كَٱلْفَرَاشِ ٱلْمَبْثُوثِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmclxii{وَتَكُونُ ٱلْجِبَالُ كَٱلْعِهْنِ ٱلْمَنفُوشِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclxiii{فَأَمَّا مَن ثَقُلَتْ مَوَٰزِينُهُۥ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmclxiv{فَهُوَ فِى عِيشَةٍ رَّاضِيَةٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmclxv{وَأَمَّا مَنْ خَفَّتْ مَوَٰزِينُهُۥ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclxvi{فَأُمُّهُۥ هَاوِيَةٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmclxvii{وَمَآ أَدْرَىٰكَ مَا هِيَهْ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmclxviii{نَارٌ حَامِيَةٌۢ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmclxix{\basmalah أَلْهَىٰكُمُ ٱلتَّكَاثُرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclxx{حَتَّىٰ زُرْتُمُ ٱلْمَقَابِرَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclxxi{كَلَّا سَوْفَ تَعْلَمُونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxxii{ثُمَّ كَلَّا سَوْفَ تَعْلَمُونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmclxxiii{كَلَّا لَوْ تَعْلَمُونَ عِلْمَ ٱلْيَقِينِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclxxiv{لَتَرَوُنَّ ٱلْجَحِيمَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmclxxv{ثُمَّ لَتَرَوُنَّهَا عَيْنَ ٱلْيَقِينِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmclxxvi{ثُمَّ لَتُسْـَٔلُنَّ يَوْمَئِذٍ عَنِ ٱلنَّعِيمِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclxxvii{\basmalah وَٱلْعَصْرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclxxviii{إِنَّ ٱلْإِنسَٰنَ لَفِى خُسْرٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclxxix{إِلَّا ٱلَّذِينَ ءَامَنُوا۟ وَعَمِلُوا۟ ٱلصَّٰلِحَٰتِ وَتَوَاصَوْا۟ بِٱلْحَقِّ وَتَوَاصَوْا۟ بِٱلصَّبْرِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxxx{\basmalah وَيْلٌ لِّكُلِّ هُمَزَةٍ لُّمَزَةٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxi{ٱلَّذِى جَمَعَ مَالًا وَعَدَّدَهُۥ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxii{يَحْسَبُ أَنَّ مَالَهُۥٓ أَخْلَدَهُۥ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxiii{كَلَّا لَيُنۢبَذَنَّ فِى ٱلْحُطَمَةِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxiv{وَمَآ أَدْرَىٰكَ مَا ٱلْحُطَمَةُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxv{نَارُ ٱللَّهِ ٱلْمُوقَدَةُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxvi{ٱلَّتِى تَطَّلِعُ عَلَى ٱلْأَفْـِٔدَةِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxvii{إِنَّهَا عَلَيْهِم مُّؤْصَدَةٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxviii{فِى عَمَدٍ مُّمَدَّدَةٍۭ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxix{\basmalah أَلَمْ تَرَ كَيْفَ فَعَلَ رَبُّكَ بِأَصْحَٰبِ ٱلْفِيلِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxc{أَلَمْ يَجْعَلْ كَيْدَهُمْ فِى تَضْلِيلٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxci{وَأَرْسَلَ عَلَيْهِمْ طَيْرًا أَبَابِيلَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxcii{تَرْمِيهِم بِحِجَارَةٍ مِّن سِجِّيلٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxciii{فَجَعَلَهُمْ كَعَصْفٍ مَّأْكُولٍۭ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxciv{\basmalah لِإِيلَٰفِ قُرَيْشٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxcv{إِۦلَٰفِهِمْ رِحْلَةَ ٱلشِّتَآءِ وَٱلصَّيْفِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxcvi{فَلْيَعْبُدُوا۟ رَبَّ هَٰذَا ٱلْبَيْتِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxcvii{ٱلَّذِىٓ أَطْعَمَهُم مِّن جُوعٍ وَءَامَنَهُم مِّنْ خَوْفٍۭ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxcviii{\basmalah أَرَءَيْتَ ٱلَّذِى يُكَذِّبُ بِٱلدِّينِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxcix{فَذَٰلِكَ ٱلَّذِى يَدُعُّ ٱلْيَتِيمَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcc{وَلَا يَحُضُّ عَلَىٰ طَعَامِ ٱلْمِسْكِينِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcci{فَوَيْلٌ لِّلْمُصَلِّينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccii{ٱلَّذِينَ هُمْ عَن صَلَاتِهِمْ سَاهُونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcciii{ٱلَّذِينَ هُمْ يُرَآءُونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcciv{وَيَمْنَعُونَ ٱلْمَاعُونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmccv{\basmalah إِنَّآ أَعْطَيْنَٰكَ ٱلْكَوْثَرَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccvi{فَصَلِّ لِرَبِّكَ وَٱنْحَرْ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccvii{إِنَّ شَانِئَكَ هُوَ ٱلْأَبْتَرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccviii{\basmalah قُلْ يَٰٓأَيُّهَا ٱلْكَٰفِرُونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccix{لَآ أَعْبُدُ مَا تَعْبُدُونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccx{وَلَآ أَنتُمْ عَٰبِدُونَ مَآ أَعْبُدُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxi{وَلَآ أَنَا۠ عَابِدٌ مَّا عَبَدتُّمْ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxii{وَلَآ أَنتُمْ عَٰبِدُونَ مَآ أَعْبُدُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxiii{لَكُمْ دِينُكُمْ وَلِىَ دِينِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmccxiv{\basmalah إِذَا جَآءَ نَصْرُ ٱللَّهِ وَٱلْفَتْحُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxv{وَرَأَيْتَ ٱلنَّاسَ يَدْخُلُونَ فِى دِينِ ٱللَّهِ أَفْوَاجًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxvi{فَسَبِّحْ بِحَمْدِ رَبِّكَ وَٱسْتَغْفِرْهُ إِنَّهُۥ كَانَ تَوَّابًۢا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxvii{\basmalah تَبَّتْ يَدَآ أَبِى لَهَبٍ وَتَبَّ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxviii{مَآ أَغْنَىٰ عَنْهُ مَالُهُۥ وَمَا كَسَبَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxix{سَيَصْلَىٰ نَارًا ذَاتَ لَهَبٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxx{وَٱمْرَأَتُهُۥ حَمَّالَةَ ٱلْحَطَبِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxi{فِى جِيدِهَا حَبْلٌ مِّن مَّسَدٍۭ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxxii{\basmalah قُلْ هُوَ ٱللَّهُ أَحَدٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxxiii{ٱللَّهُ ٱلصَّمَدُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxxiv{لَمْ يَلِدْ وَلَمْ يُولَدْ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxxv{وَلَمْ يَكُن لَّهُۥ كُفُوًا أَحَدٌۢ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxvi{\basmalah قُلْ أَعُوذُ بِرَبِّ ٱلْفَلَقِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxxvii{مِن شَرِّ مَا خَلَقَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxxviii{وَمِن شَرِّ غَاسِقٍ إِذَا وَقَبَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxxix{وَمِن شَرِّ ٱلنَّفَّٰثَٰتِ فِى ٱلْعُقَدِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxx{وَمِن شَرِّ حَاسِدٍ إِذَا حَسَدَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxi{\basmalah قُلْ أَعُوذُ بِرَبِّ ٱلنَّاسِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxii{مَلِكِ ٱلنَّاسِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxiii{إِلَٰهِ ٱلنَّاسِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxiv{مِن شَرِّ ٱلْوَسْوَاسِ ٱلْخَنَّاسِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxv{ٱلَّذِى يُوَسْوِسُ فِى صُدُورِ ٱلنَّاسِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxvi{مِنَ ٱلْجِنَّةِ وَٱلنَّاسِ\qt@no{﴿٦﴾}}
