%% This is file `qurantext-en.translation.def',
%% 
%% Copyright © 2015-2021
%% Seiied-Mohammad-Javad Razavian <javadr@gmail.com>
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%% 
%% This work is “author-maintained” (as per LPPL maintenance status).
%% 
%% The Current Maintainer of this work is Seiied-Mohammad-Javad Razavian.
%% 
%% to one who has devoted his life to Quran
%%
\qt@newcmd\qurantrans@en@i{In the name of Allah, most benevolent, ever-merciful.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@ii{ALL PRAISE BE to Allah, Lord of all the worlds,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@iii{Most beneficent, ever-merciful,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@iv{King of the Day of Judgement.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@v{You alone we worship, and to You alone turn for help.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@vi{Guide us (O Lord) to the path that is straight,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@vii{The path of those You have blessed, Not of those who have earned Your anger, nor those who have gone astray.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@viii{\basmalahen ALIF LAM MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@ix{This is The Book free of doubt and involution, a guidance for those who preserve themselves from evil and follow the straight path,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@x{Who believe in the Unknown and fulfil their devotional obligations, and spend in charity of what We have given them;\qt@no{(3)}}
\qt@newcmd\qurantrans@en@xi{Who believe in what has been revealed to you and what was revealed to those before you, and are certain of the Hereafter.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@xii{They have found the guidance of their Lord and will be successful.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@xiii{As for those who deny, it is all the same if you warn them or not, they will not believe.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@xiv{God has sealed their hearts and ears, and veiled their eyes. For them is great deprivation.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@xv{And there are some who, though they say: ``We believe in God and the Last Day," (in reality) do not believe.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@xvi{They (try to) deceive God and those who believe, yet deceive none but themselves although they do not know.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@xvii{Sick are their hearts, and God adds to their malady. For them is suffering for they lie.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@xviii{When asked to desist from spreading corruption in the land they say: ``Why, we are reformers."\qt@no{(11)}}
\qt@newcmd\qurantrans@en@xix{Yet they are surely mischief-mongers, even though they do not know.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@xx{When asked to believe as others do, they say: ``Should we believe like fools?" And yet they are the fools, even though they do not know.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@xxi{When they meet the faithful they say: ``We believe;" but when alone with the devils (their fellows), they say: ``We are really with you; we were joking."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@xxii{But God will turn the joke against them and allow them to sink deeper into evil and wander perplexed in their wickedness.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@xxiii{They are indeed those who bartered away good guidance for error and gained nothing from the deal, nor found the right way.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@xxiv{They are like a man who kindles a fire, and when its glow has illumined the air God takes away their light leaving them in the dark where they will not be able to see.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@xxv{They are deaf, dumb and blind, and shall never return;\qt@no{(18)}}
\qt@newcmd\qurantrans@en@xxvi{Or like rain pouring from the sky which hides within it darkness, thunder and lightning. They thrust their fingers into their ears for safety against noise and death. But God surrounds those who believe not from all sides.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@xxvii{Verily the lightning could snatch away their eyes. When it flashes forth they walk in its flare. When darkness returns they stand still. And if the Lord wills so He could take away their hearing and sight; surely God is all-powerful.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@xxviii{So, O you people, adore your Lord who created you, as He did those before you, that you could take heed for yourselves and fear Him\qt@no{(21)}}
\qt@newcmd\qurantrans@en@xxix{Who made the earth a bed for you, the sky a canopy, and sends forth rain from the skies that fruits may grow -- your food and sustenance. So, do not make another the equal of God knowingly.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@xxx{If you are in doubt of what We have revealed to Our votary, then bring a Surah like this, and call any witness, apart from God, you like, if you are truthful.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@xxxi{But if you cannot, as indeed you cannot, then guard yourselves against the Fire whose fuel is men and rocks, which has been prepared for the infidels.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@xxxii{Announce to those who believe and have done good deeds, glad tidings of gardens under which rivers flow, and where, when they eat the fruits that grow, they will say: ``Indeed they are the same as we were given before," so like in semblance the food would be. And they shall have fair spouses there, and live there abidingly.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@xxxiii{God is not loath to advance the similitude of a gnat or a being more contemptible; and those who believe know whatever is from the Lord is true. But those who disbelieve say: ``What does God mean by this parable?" He causes some to err this way, and some He guides; yet He turns away none but those who transgress,\qt@no{(26)}}
\qt@newcmd\qurantrans@en@xxxiv{Who, having sealed it, break God's covenant, dividing what He ordained cohered; and those who spread discord in the land will suffer assuredly.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@xxxv{Then how can you disbelieve in God? He gave you life when you were dead. He will make you die again then bring you back to life: To Him then you will return.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@xxxvi{He made for you all that lies within the earth, then turning to the firmament He proportioned several skies: He has knowledge of everything.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@xxxvii{Remember, when your Lord said to the angels: ``I have to place a trustee on the earth," they said: ``Will You place one there who would create disorder and shed blood, while we intone Your litanies and sanctify Your name?" And God said: ``I know what you do not know."\qt@no{(30)}}
\qt@newcmd\qurantrans@en@xxxviii{Then He gave Adam knowledge of the nature and reality of all things and everything, and set them before the angels and said: ``Tell Me the names of these if you are truthful."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@xxxix{And they said: ``Glory to You (O Lord), knowledge we have none except what You have given us, for You are all-knowing and all-wise."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@xl{Then He said to Adam: ``Convey to them their names." And when he had told them, God said: ``Did I not tell you that I know the unknown of the heavens and the earth, and I know what you disclose and know what you hide?"\qt@no{(33)}}
\qt@newcmd\qurantrans@en@xli{Remember, when We asked the angels to bow in homage to Adam, they all bowed but Iblis, who disdained and turned insolent, and so became a disbeliever.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@xlii{And We said to Adam: ``Both you and your spouse live in the Garden, eat freely to your fill wherever you like, but approach not this tree or you will become transgressors.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@xliii{But Satan tempted them and had them banished from the (happy) state they were in. And We said: ``Go, one the antagonist of the other, and live on the earth for a time ordained, and fend for yourselves."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@xliv{Then his Lord sent commands to Adam and turned towards him: Indeed He is compassionate and kind.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@xlv{And We said to them: ``Go, all of you. When I send guidance, whoever follows it will neither have fear nor regret;\qt@no{(38)}}
\qt@newcmd\qurantrans@en@xlvi{But those who deny and reject Our signs will belong to Hell, and there abide unchanged."\qt@no{(39)}}
\qt@newcmd\qurantrans@en@xlvii{O children of Israel, remember the favours I bestowed on you. So keep your pledge to Me, and I will mine to you, and be fearful of Me,\qt@no{(40)}}
\qt@newcmd\qurantrans@en@xlviii{And believe in what I have sent down which verifies what is already with you; and do not be the first to deny it, nor part with it for little gain; and beware of Me.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@xlix{Do not confuse truth with falsehood, nor conceal the truth knowingly.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@l{Be firm in devotion; give zakat (the due share of your wealth for the welfare of others), and bow with those who bow (before God).\qt@no{(43)}}
\qt@newcmd\qurantrans@en@li{Will you enjoin good deeds on the others and forget your own selves? You also read the Scriptures, why do you then not understand?\qt@no{(44)}}
\qt@newcmd\qurantrans@en@lii{Find strength in fortitude and prayer, which is heavy and exacting but for those who are humble and meek,\qt@no{(45)}}
\qt@newcmd\qurantrans@en@liii{Who are conscious that they have to meet their Lord, and to Him they have to return.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@liv{Remember, O children of Israel, the favours I bestowed on you, and made you exalted among the nations of the world.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@lv{Take heed of the day when no man will be useful to man in the least, when no intercession matter nor ransom avail, nor help reach them.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@lvi{Remember, We saved you from the Pharaoh's people who wronged and oppressed you and slew your sons but spared your women: In this was a great favour from your Lord.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@lvii{Remember, We parted the sea and saved you, and drowned the men of Pharaoh before your very eyes.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@lviii{Yet, remember, as We communed with Moses for forty nights you took the calf in his absence (and worshipped it), and you did wrong.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@lix{Even so, We pardoned you that you may be grateful.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@lx{Remember, We gave Moses the Book and Discernment of falsehood and truth, that you may be guided.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@lxi{Remember, Moses said: ``My people, by taking this calf you have done yourselves harm, so now turn to your Creator in repentance, and kill your pride, which is better with your Lord." And (the Lord) softened towards you, for He is all-forgiving and merciful.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@lxii{Remember, when you said to Moses: ``We shall not believe in you until we see God face to face," lightning struck you as you looked.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@lxiii{Even then We revived you after you had become senseless that you might give thanks;\qt@no{(56)}}
\qt@newcmd\qurantrans@en@lxiv{And made the cloud spread shade over you, and sent for you manna and quails that you may eat of the good things We have made for you. No harm was done to Us, they only harmed themselves.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@lxv{And remember, We said to you: ``Enter this city, eat wherever you like, as much as you please, but pass through the gates in humility and say: 'May our sins be forgiven.' We shall forgive your trespasses and give those who do good abundance.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@lxvi{But the wicked changed and perverted the word We had spoken to a word distorted, and We sent from heaven retribution on the wicked, for they disobeyed.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@lxvii{And remember, when Moses asked for water for his people, We told him to strike the rock with his staff, and behold, twelve springs of gushing water gushed forth so that each of the tribes came to know its place of drinking. Eat and drink, (enjoy) God's gifts, and spread no discord in the land.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@lxviii{Remember, when you said: ``O Moses, we are tired of eating the same food (day after day), ask your Lord to give us fruits of the earth, herbs and cucumbers, grains and lentils and onions;" he said: ``Would you rather exchange what is good with what is bad? Go then to the city, you shall have what you ask." So they were disgraced and became indigent, earning the anger of God, for they disbelieved the word of God, and slayed the prophets unjustly, for they transgressed and rebelled.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@lxix{Surely the believers and the Jews, Nazareans and the Sabians, whoever believes in God and the Last Day, and whosoever does right, shall have his reward with his Lord and will neither have fear nor regret.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@lxx{Remember the day We made the covenant with you and exalted you on the Mount and said: ``Hold fast to what We have given you, and remember what is therein that you may take heed."\qt@no{(63)}}
\qt@newcmd\qurantrans@en@lxxi{But you went back (on your word), and but for the mercy and grace of God you were lost.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@lxxii{You know and have known already those among you who had broken the sanctity of the Sabbath, and to whom We had said: ``Become (like) apes despised,"\qt@no{(65)}}
\qt@newcmd\qurantrans@en@lxxiii{And whom We made an example for the people (of the day) and those after them, and warning for those who fear God.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@lxxiv{Remember, when Moses said to his people: ``God demands that you sacrifice a cow," they said: ``Are you making fun of us?" And he said: ``God forbid that I be of the ignorant."\qt@no{(67)}}
\qt@newcmd\qurantrans@en@lxxv{``Call on your Lord for us," they said, ``that He might inform us what kind she should be." ``Neither old nor young, says God, but of age in between," answered Moses. ``So do as you are bid."\qt@no{(68)}}
\qt@newcmd\qurantrans@en@lxxvi{``Call on your Lord," they said, ``to tell us the colour of the cow." ``God says," answered Moses, ``a fawn coloured cow, rich yellow, well pleasing to the eye."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@lxxvii{``Call on your Lord," they said, ``to name its variety, as cows be all alike to us. If God wills we shall be guided aright."\qt@no{(70)}}
\qt@newcmd\qurantrans@en@lxxviii{And Moses said: ``He says it's a cow unyoked, nor worn out by ploughing or watering the fields, one in good shape with no mark or blemish." ``Now have you brought us the truth," they said; and then, after wavering, they sacrificed the cow.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@lxxix{Remember when you killed a man and blamed each other for the deed, God brought to light what you concealed.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@lxxx{We had pronounced already: ``Slay (the murderer) for (taking a life)." Thus God preserves life from death and shows you His signs that you may understand.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@lxxxi{Yet, in spite of this, your hearts only hardened like rocks or even harder, but among rocks are those from which rivers flow; and there are also those which split open and water gushes forth; as well as those that roll down for fear of God. And God is not negligent of all that you do.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@lxxxii{How do you expect them to put their faith in you, when you know that some among them heard the word of God and, having understood, perverted it knowingly?\qt@no{(75)}}
\qt@newcmd\qurantrans@en@lxxxiii{For when they meet the faithful, they say: ``We believe;" but when among themselves, they say: ``Why do you tell them what the Lord has revealed to you? They will only dispute it in the presence of your Lord. Have you no sense indeed?"\qt@no{(76)}}
\qt@newcmd\qurantrans@en@lxxxiv{Do they not know that God is aware of what they hide and what they disclose?\qt@no{(77)}}
\qt@newcmd\qurantrans@en@lxxxv{Among them are heathens who know nothing of the Book but only what they wish to believe, and are only lost in fantasies.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@lxxxvi{But woe to them who fake the Scriptures and say: ``This is from God," so that they might earn some profit thereby; and woe to them for what they fake, and woe to them for what they earn from it!\qt@no{(79)}}
\qt@newcmd\qurantrans@en@lxxxvii{Yet they say: ``The Fire will not touch us for more than a few days." Say.. ``Have you so received a promise from God?" ``Then surely God will not withdraw His pledge. Or do you impute things to God of which you have no knowledge at all?"\qt@no{(80)}}
\qt@newcmd\qurantrans@en@lxxxviii{Why, they who have earned the wages of sin and are enclosed in error, are people of Hell, where they will abide for ever.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@lxxxix{But those who believe and do good deeds are people of Paradise, and shall live there forever.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@xc{Remember, when We made a covenant with the people of Israel and said: ``Worship no one but God, and be good to your parents and your kin, and to orphans and the needy, and speak of goodness to men; observe your devotional obligations, and give zakat (the due share of your wealth for the welfare of others)," you went back (on your word), except only a few, and paid no heed.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@xci{And remember, when We made a covenant with you whereby you agreed you will neither shed blood among you nor turn your people out of their homes, you promised, and are witness to it too.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@xcii{But you still kill one another, and you turn a section of your people from their homes, assisting one another against them with guilt and oppression. Yet when they are brought to you as captives you ransom them, although forbidden it was to drive them away. Do you, then, believe a part of the Book and reject a part? There is no other award for them who so act but disgrace in the world, and on the Day of Judgement the severest of punishment; for God is not heedless of all that you do.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@xciii{They are those who bought the life of the world at the cost of the life to come; and neither will their torment decrease nor help reach them.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@xciv{Remember We gave Moses the Book and sent after him many an apostle; and to Jesus, son of Mary, We gave clear evidence of the truth, reinforcing him with divine grace. Even so, when a messenger brought to you what did not suit your mood you turned haughty, and called some imposters and some others you slew.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@xcv{And they say: ``Our hearts are enfolded in covers." In fact God has cursed them for their unbelief; and only a little do they believe.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@xcvi{And when the Book was sent to them by God verifying what had been revealed to them already even though before it they used to pray for victory over the unbelievers and even though they recognised it when it came to them, they renounced it. The curse of God be on those who deny!\qt@no{(89)}}
\qt@newcmd\qurantrans@en@xcvii{They bartered their lives ill denying the revelation of God out of spite that God should bestow His grace among His votaries on whomsoever He will, and thus earned wrath upon wrath. The punishment for disbelievers is ignominious.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@xcviii{And when it is said to them: ``believe in what God has sent down," they say: ``We believe what was sent to us, and do not believe what has come thereafter," although it affirms the truth they possess already. Say: ``Why have you then been slaying God's apostles as of old, if you do believe?"\qt@no{(91)}}
\qt@newcmd\qurantrans@en@xcix{Although Moses had come to you with evidence of the truth, you chose the calf in his absence, and you transgressed.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@c{Remember when We took your pledge and exalted you on the Mount (saying:) ``Hold fast to what We have given you, firmly, and pay heed," you said: ``We have heard and will not obey." (The image of) the calf had sunk deep into their hearts on account of unbelief. Say: ``Vile is your belief if you are believers indeed!"\qt@no{(93)}}
\qt@newcmd\qurantrans@en@ci{Tell them: ``If you think you alone will abide with God to the exclusion of the rest of Mankind, in the mansions of the world to come, then wish for death if what you say is true."\qt@no{(94)}}
\qt@newcmd\qurantrans@en@cii{But they will surely not wish for death because of what they had done in the past; and God knows the sinners well.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@ciii{You will see they are covetous of life more than other men, even more than those who practise idolatry. Each one of them desires to live a thousand years, although longevity will never save them from punishment, for God sees all they do.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@civ{Say: ``Whosoever is the enemy of Gabriel who revealed the word of God to you by the dispensation of God, reaffirming what had been revealed before, and is a guidance and good news for those who believe, --\qt@no{(97)}}
\qt@newcmd\qurantrans@en@cv{Whosoever is the enemy of God and His angels and apostles, and of Gabriel and Michael, then God is the enemy of such unbelievers."\qt@no{(98)}}
\qt@newcmd\qurantrans@en@cvi{We have sent clear signs to you, such as none can deny except those who transgress the truth.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@cvii{And every time they made a pledge some of them pushed it aside, and many of them do not believe.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@cviii{When a messenger was sent to them by God affirming the Books they had already received, some of them put (His message) behind their backs as if they had no knowledge of it.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@cix{And they follow what devilish beings used to chant against the authority of Solomon, though Solomon never disbelieved and only the devils denied, who taught sorcery to men, which, they said, had been revealed to the angels of Babylon, Harut and Marut, who, however, never taught it without saying: ``We have been sent to deceive you, so do not renounce (your faith)." They learnt what led to discord between husband and wife. Yet they could not harm any one or without the dispensation of God. And they learnt what harmed them and brought no gain. They knew indeed whoever bought this had no place in the world to come, and that surely they had sold themselves for something that was vile. If only they had sense!\qt@no{(102)}}
\qt@newcmd\qurantrans@en@cx{Had they come to believe instead, and taken heed for themselves, they would surely have earned from God a far better reward. If only they had sense!\qt@no{(103)}}
\qt@newcmd\qurantrans@en@cxi{Say not (to the Prophet), O Believers: ``Have regard for us (ra'ina)," but ``look at us (unzurna)," and obey him in what he says. Painful is the nemesis for disbelievers.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@cxii{Those without faith among the people of the Book, and those who worship idols, do not wish that good should come to you from your Lord. But God chooses whom He likes for His grace; and the bounty of God is infinite.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@cxiii{When We cancel a message (sent to an earlier prophet) or throw it into oblivion, We replace it with one better or one similar. Do you not know that God has power over all things?\qt@no{(106)}}
\qt@newcmd\qurantrans@en@cxiv{Do you not know that God's is the kingdom of the heavens and the earth, and that there is none to save and protect you apart from God?\qt@no{(107)}}
\qt@newcmd\qurantrans@en@cxv{Do you too, O believers, wish to question your Apostle as Moses was in the past? But he who takes unbelief in exchange for belief only strays from the right path.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@cxvi{How many of the followers of the Books having once known the truth desire in their hearts, out of envy, to turn you into infidels again even after the truth has become clear to them! But you forbear and overlook till God fulfil His plan; and God has power over all things.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@cxvii{Fulfil your devotional obligations and pay the zakat. And what you send ahead of good you will find with God, for He sees all that you do ill.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@cxviii{And they say: ``None will go to Paradise but the Jews and the Christians;" but this is only wishful thinking. Say: ``Bring the proof if you are truthful."\qt@no{(111)}}
\qt@newcmd\qurantrans@en@cxix{Only he who surrenders to God with all his heart and also does good, will find his reward with his Lord, and will have no fear or regret.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@cxx{The Jews say: ``The Christians are not right," and the Christians say: ``The Jews are in the wrong;" yet both read the Scriptures; and this is what the unread had said too. God alone will judge between them in their differences on the Day of Reckoning.\qt@no{(113)}}
\qt@newcmd\qurantrans@en@cxxi{And who is more unjust than he who prohibits the name of God being used in His mosques, who hurries to despoil them even though he has no right to enter them except in reverence? For them is ignominy in the world and severe punishment in the life to come.\qt@no{(114)}}
\qt@newcmd\qurantrans@en@cxxii{To God belong the East and the West. Wherever you turn the glory of God is everywhere: All-pervading is He and all-knowing.\qt@no{(115)}}
\qt@newcmd\qurantrans@en@cxxiii{Yet they say that God has begotten a son. May He be praised! Indeed everything in the heavens and the earth belongs to Him, and all are obedient to God.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@cxxiv{Creator of the heavens and the earth from nothingness, He has only to say when He wills a thing: ``Be", and it is.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@cxxv{But those who are ignorant say: ``Why does God not speak or show us a sign?" The same question had been asked by men before them, who were like them in their hearts. But to those who are firm in their faith We have shown Our signs already.\qt@no{(118)}}
\qt@newcmd\qurantrans@en@cxxvi{And We have sent you with the truth to give glad tidings and to warn. You will not be questioned about those and who are inmates of Hell.\qt@no{(119)}}
\qt@newcmd\qurantrans@en@cxxvii{The Jews and Christians will never be pleased with you until you follow their way. Say: ``God's guidance alone is true guidance;" for if you give in to their wishes after having received the (Book of) knowledge from God, then none will you have as friend or helper to save you.\qt@no{(120)}}
\qt@newcmd\qurantrans@en@cxxviii{Those to whom We have sent down the Book, and who read it as it should be read, believe in it truly; but those who deny it will be losers.\qt@no{(121)}}
\qt@newcmd\qurantrans@en@cxxix{O children of Israel, remember the favours I bestowed on you, and made you exalted among the nations of the world.\qt@no{(122)}}
\qt@newcmd\qurantrans@en@cxxx{Fear the day when no man will stand up for man in the least, and no ransom avail nor intercession matter nor help reach.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@cxxxi{Remember, when his Lord tried Abraham by a number of commands which he fulfilled, God said to him: ``I will make you a leader among men." And when Abraham asked: ``From my progeny too?" the Lord said: ``My pledge does not include transgressors."\qt@no{(124)}}
\qt@newcmd\qurantrans@en@cxxxii{Remember, We made the House (of Ka'bah) a place of congregation and safe retreat, and said: ``Make the spot where Abraham stood the place of worship;" and enjoined upon Abraham and Ishmael to keep Our House immaculate for those who shall walk around it and stay in it for contemplation and prayer, and for bowing in adoration.\qt@no{(125)}}
\qt@newcmd\qurantrans@en@cxxxiii{And when Abraham said: ``O Lord, make this a city of peace, and give those of its citizens who believe in God and the Last Day fruits for food," He answered: ``To those will I also give a little who believe not, for a time, then drag them to Hell, a dreadful destination!"\qt@no{(126)}}
\qt@newcmd\qurantrans@en@cxxxiv{And when Abraham was raising the plinth of the House with Ishmael, (he prayed): ``Accept this from us, O Lord, for You hear and know everything;\qt@no{(127)}}
\qt@newcmd\qurantrans@en@cxxxv{And make us submit, O Lord, to Your will, and our progeny a people submissive to You. Teach us the way of worship and forgive our trespasses, for You are compassionate and merciful;\qt@no{(128)}}
\qt@newcmd\qurantrans@en@cxxxvi{And send to them, O Lord, an apostle from among them to impart Your messages to them, and teach them the Book and the wisdom, and correct them in every way; for indeed You are mighty and wise.\qt@no{(129)}}
\qt@newcmd\qurantrans@en@cxxxvii{Who will turn away from the creed of Abraham but one dull of soul? We made him the chosen one here in the world, and one of the best in the world to come,\qt@no{(130)}}
\qt@newcmd\qurantrans@en@cxxxviii{(For) when his Lord said to him: ``Obey," he replied: ``I submit to the Lord of all the worlds."\qt@no{(131)}}
\qt@newcmd\qurantrans@en@cxxxix{And Abraham left this legacy to his sons, and to Jacob, and said: ``O my sons, God has chosen this as the faith for you. Do not die but as those who have submitted (to God)."\qt@no{(132)}}
\qt@newcmd\qurantrans@en@cxl{Were you present at the hour of Jacob's death? ``What will you worship after me?" he asked his sons, and they answered: ``We shall worship your God and the God of your fathers, of Abraham and Ishmael and Isaac, the one and only God; and to Him we submit."\qt@no{(133)}}
\qt@newcmd\qurantrans@en@cxli{Those were the people, and they have passed away. Theirs the reward for what they did, as yours will be for what you do. You will not be questioned about their deeds.\qt@no{(134)}}
\qt@newcmd\qurantrans@en@cxlii{They say: ``Become Jews or become Christians, and find the right way." Say: ``No. We follow the way of Abraham the upright, who was not an idolater."\qt@no{(135)}}
\qt@newcmd\qurantrans@en@cxliii{Say: ``We believe in God and what has been sent down to us, and what had been revealed to Abraham and Ishmael and Isaac and Jacob and their progeny, and that which was given to Moses and Christ, and to all other prophets by the Lord. We make no distinction among them, and we submit to Him."\qt@no{(136)}}
\qt@newcmd\qurantrans@en@cxliv{If they come to believe as you did, they will find the right path. If they turn away then they will only oppose; but God will suffice you against them, for God hears all and knows everything.\qt@no{(137)}}
\qt@newcmd\qurantrans@en@cxlv{``We have taken the colouring of God; and whose shade is better than God's? Him alone we worship."\qt@no{(138)}}
\qt@newcmd\qurantrans@en@cxlvi{Say: ``Why do you dispute with us about God when He is equally your Lord and our Lord? To us belong our actions, to you yours; and we are true to Him."\qt@no{(139)}}
\qt@newcmd\qurantrans@en@cxlvii{Or do you claim that Abraham and Ishmael and Isaac and Jacob and their offspring were Jews or Christians? Say: ``Have you more knowledge than God?" Who is more wicked than he who conceals the testimony he received from God? God is not unaware of all you do.\qt@no{(140)}}
\qt@newcmd\qurantrans@en@cxlviii{They were the people, and they have passed away. Theirs the reward for what they did, as yours will be for what you do. You will not be questioned about their deeds.\qt@no{(141)}}
\qt@newcmd\qurantrans@en@cxlix{The foolish will now ask and say: ``What has made the faithful turn away from the Qiblah towards which they used to pray?" Say: ``To God belong the East and the West. He guides who so wills to the path that is straight."\qt@no{(142)}}
\qt@newcmd\qurantrans@en@cl{We have made you a temperate people that you act as witness over man, and the Prophet as witness over you. We decreed the Qiblah which you faced before that We may know who follow the Apostle and who turn away in haste. And this was a hard (test) except for those who were guided by God. But God will not suffer your faith to go waste, for God is to men full of mercy and grace.\qt@no{(143)}}
\qt@newcmd\qurantrans@en@cli{We have seen you turn your face to the heavens. We shall turn you to a Qiblah that will please you. So turn towards the Holy Mosque, and turn towards it wherever you be. And those who are recipients of the Book surely know that this is the truth from their Lord; and God is not negligent of all that you do.\qt@no{(144)}}
\qt@newcmd\qurantrans@en@clii{Even though you bring all the proof to the people of the Book they will not face the direction you turn to, nor you theirs, nor will they follow each other's direction. And if you follow their whims after all the knowledge that has reached you, then surely you will be among transgressors.\qt@no{(145)}}
\qt@newcmd\qurantrans@en@cliii{Those to whom We have sent down the Book know this even as they know their sons. Yet a section among them conceals the truth knowingly.\qt@no{(146)}}
\qt@newcmd\qurantrans@en@cliv{The truth is from your Lord, so be not among those who are sceptics.\qt@no{(147)}}
\qt@newcmd\qurantrans@en@clv{Each has a goal to which he turns. So strive towards piety and excel the others: God will bring you all together wheresoever you be. God has power over everything.\qt@no{(148)}}
\qt@newcmd\qurantrans@en@clvi{Wherever you come from turn towards the Holy Mosque: This in truth is from your Lord. God is not negligent of all you do.\qt@no{(149)}}
\qt@newcmd\qurantrans@en@clvii{Whichever place you come from turn towards the Holy Mosque, and wherever you are, turn your faces towards it so that people may have no cause for argument against you, except such among them as are wicked. But do not fear them, fear Me that I may accomplish My favours on you, and you may find the right way perchance.\qt@no{(150)}}
\qt@newcmd\qurantrans@en@clviii{Even as We sent a messenger from among you to convey Our messages to you and cleanse you, and teach you the Book and the wisdom, and what you did not know;\qt@no{(151)}}
\qt@newcmd\qurantrans@en@clix{So, therefore, remember Me, and I shall remember you; and give thanks and do not be ungrateful.\qt@no{(152)}}
\qt@newcmd\qurantrans@en@clx{O you who believe, seek courage in fortitude and prayer, for God is with those who are patient and persevere.\qt@no{(153)}}
\qt@newcmd\qurantrans@en@clxi{Do not say that those who are killed in the way of God, are dead, for indeed they are alive, even though you are not aware.\qt@no{(154)}}
\qt@newcmd\qurantrans@en@clxii{Be sure We shall try you with something of fear and hunger and loss of wealth and life and the fruits (of your labour); but give tidings of happiness to those who have patience,\qt@no{(155)}}
\qt@newcmd\qurantrans@en@clxiii{Who say when assailed by adversity: ``Surely we are for God, and to Him we shall return."\qt@no{(156)}}
\qt@newcmd\qurantrans@en@clxiv{On such men are the blessings of God and His mercy, for they are indeed on the right path.\qt@no{(157)}}
\qt@newcmd\qurantrans@en@clxv{Truly Safa and Marwa are the symbols of God. Whoever goes on pilgrimage to the House (of God), or on a holy visit, is not guilty of wrong if he walk around them; and he who does good of his own accord will find appreciation with God who knows everything.\qt@no{(158)}}
\qt@newcmd\qurantrans@en@clxvi{They who conceal Our signs and the guidance We have sent them and have made clear in the Book, are condemned of God and are condemned by those who are worthy of condemning.\qt@no{(159)}}
\qt@newcmd\qurantrans@en@clxvii{But those who repent and reform and proclaim (the truth), are forgiven, for I am forgiving and merciful.\qt@no{(160)}}
\qt@newcmd\qurantrans@en@clxviii{But those who deny, and die disbelieving, bear the condemnation of God and the angels and that of all men,\qt@no{(161)}}
\qt@newcmd\qurantrans@en@clxix{Under which they will live, and their suffering will neither decrease nor be respite for them.\qt@no{(162)}}
\qt@newcmd\qurantrans@en@clxx{Your God is one God; there is no god other than He, the compassionate, ever-merciful.\qt@no{(163)}}
\qt@newcmd\qurantrans@en@clxxi{Creation of the heavens and the earth, alternation of night and day, and sailing of ships across the ocean with what is useful to man, and the rain that God sends from the sky enlivening the earth that was dead, and the scattering of beasts of all kinds upon it, and the changing of the winds, and the clouds which remain obedient between earth and sky, are surely signs for the wise.\qt@no{(164)}}
\qt@newcmd\qurantrans@en@clxxii{And yet there are men who take others as compeers of God, and bestow on them love due to God; but the love of the faithful for God is more intense. If only the wicked could see now the agony that they will behold (on the Day of Resurrection), they will know that to God belongs the power entirely'. And the punishment of God is severe.\qt@no{(165)}}
\qt@newcmd\qurantrans@en@clxxiii{When those who were followed will disclaim those who followed them, and see the torment all ties between them shall be severed,\qt@no{(166)}}
\qt@newcmd\qurantrans@en@clxxiv{And the followers will say: ``Could we live but once again we would leave them as they have abandoned us now." God will show them thus their deeds, and fill them with remorse; but never shall they find release from the Fire.\qt@no{(167)}}
\qt@newcmd\qurantrans@en@clxxv{O men, eat only the things of the earth that are lawful and good. Do not walk in the footsteps of Satan, your acknowledged enemy.\qt@no{(168)}}
\qt@newcmd\qurantrans@en@clxxvi{He will ask you to indulge in evil, indecency, and to speak lies of God you cannot even conceive.\qt@no{(169)}}
\qt@newcmd\qurantrans@en@clxxvii{When it is said to them: ``Follow what God has revealed," they reply: ``No, we shall follow only what our fathers had practiced," -- even though their fathers had no wisdom or guidance!\qt@no{(170)}}
\qt@newcmd\qurantrans@en@clxxviii{The semblance of the infidels is that of a man who shouts to one that cannot hear more than a call and a cry. They are deaf, dumb and blind, and they fail to understand.\qt@no{(171)}}
\qt@newcmd\qurantrans@en@clxxix{O believers, eat what is good of the food We have given you, and be grateful to God, if indeed you are obedient to Him.\qt@no{(172)}}
\qt@newcmd\qurantrans@en@clxxx{Forbidden to you are carrion and blood, and the flesh of the swine, and that which has been consecrated (or killed) in the name of any other than God. If one is obliged by necessity to eat it without intending to transgress, or reverting to it, he is not guilty of sin; for God is forgiving and kind.\qt@no{(173)}}
\qt@newcmd\qurantrans@en@clxxxi{Those who conceal any part of the Scriptures that God has revealed, and thus make a little profit thereby, take nothing but fire as food; and God will not turn to them on the Day of Resurrection, nor nourish them for growth; and their doom will be painful.\qt@no{(174)}}
\qt@newcmd\qurantrans@en@clxxxii{They are those who bartered away good guidance for error, and pardon for punishment: How great is their striving for the Fire\qt@no{(175)}}
\qt@newcmd\qurantrans@en@clxxxiii{That is because God has revealed the Book containing the truth; but those who are at variance about it have gone astray in their contrariness.\qt@no{(176)}}
\qt@newcmd\qurantrans@en@clxxxiv{Piety does not lie in turning your face to East or West: Piety lies in believing in God, the Last Day and the angels, the Scriptures and the prophets, and disbursing your wealth out of love for God among your kin and the orphans, the wayfarers and mendicants, freeing the slaves, observing your devotional obligations, and in paying the zakat and fulfilling a pledge you have given, and being patient in hardship, adversity, and times of peril. These are the men who affirm the truth, and they are those who follow the straight path.\qt@no{(177)}}
\qt@newcmd\qurantrans@en@clxxxv{O believers, ordained for you is retribution for the murdered, (whether) a free man (is guilty) of (the murder of) a free man, or a slave of a slave, or a woman of a woman. But he who is pardoned some of it by his brother should be dealt with equity, and recompense (for blood) paid with a grace. This is a concession from your Lord and a kindness. He who transgresses in spite of it shall suffer painful punishment.\qt@no{(178)}}
\qt@newcmd\qurantrans@en@clxxxvi{In retribution there is life (and preservation). O men of sense, you may haply take heed for yourselves.\qt@no{(179)}}
\qt@newcmd\qurantrans@en@clxxxvii{It is ordained that when any one of you nears death, and he owns goods and chattels, he should bequeath them equitably to his parents and next of kin. This is binding on those who are upright and fear God.\qt@no{(180)}}
\qt@newcmd\qurantrans@en@clxxxviii{And any one who changes the will, having heard it, shall be guilty and accountable; for God hears all and knows everything.\qt@no{(181)}}
\qt@newcmd\qurantrans@en@clxxxix{He who suspects wrong or partiality on the part of the testator and brings about a settlement, does not incure any guilt, for God is verily forgiving and merciful.\qt@no{(182)}}
\qt@newcmd\qurantrans@en@cxc{O believers, fasting is enjoined on you as it was on those before you, so that you might become righteous.\qt@no{(183)}}
\qt@newcmd\qurantrans@en@cxci{Fast a (fixed) number of days, but if someone is ill or is travelling (he should complete) the number of days (he had missed); and those who find it hard to fast should expiate by feeding a poor person. For the good they do with a little hardship is better for men. And if you fast it is good for you, if you knew.\qt@no{(184)}}
\qt@newcmd\qurantrans@en@cxcii{Ramadan is the month in which the Qur'an was revealed as guidance to man and clear proof of the guidance, and criterion (of falsehood and truth). So when you see the new moon you should fast the whole month; but a person who is ill or travelling (and fails to do so) should fast on other days, as God wishes ease and not hardship for you, so that you complete the (fixed) number (of fasts), and give glory to God for the guidance, and be grateful.\qt@no{(185)}}
\qt@newcmd\qurantrans@en@cxciii{When My devotees enquire of you about Me, I am near, and answer the call of every supplicant when he calls. It behoves them to hearken to Me and believe in Me that they may follow the right path.\qt@no{(186)}}
\qt@newcmd\qurantrans@en@cxciv{You are allowed to sleep with your wives on the nights of the fast: They are your dress as you are theirs. God is aware you were cheating yourselves, so He turned to you and pardoned you. So now you may have intercourse with them, and seek what God has ordained for you. Eat and drink until the white thread of dawn appears clear from the dark line, then fast until the night falls; and abstain from your wives (when you have decided) to stay in the mosques for assiduous devotion. These are the bounds fixed by God, so keep well within them. So does God make His signs clear to men that they may take heed for themselves.\qt@no{(187)}}
\qt@newcmd\qurantrans@en@cxcv{And do not consume each other's wealth in vain, nor offer it to men in authority with intent of usurping unlawfully and knowingly a part of the wealth of others.\qt@no{(188)}}
\qt@newcmd\qurantrans@en@cxcvi{They ask you of the new moons. Say: ``These are periods set for men (to reckon) time, and for pilgrimage." Piety does not lie in entering the house through the back door, for the pious man is he who follows the straight path. Enter the house through the main gate, and obey God. You may haply find success.\qt@no{(189)}}
\qt@newcmd\qurantrans@en@cxcvii{Fight those in the way of God who fight you, but do not be aggressive: God does not like aggressors.\qt@no{(190)}}
\qt@newcmd\qurantrans@en@cxcviii{And fight those (who fight you) wheresoever you find them, and expel them from the place they had turned you out from. Oppression is worse than killing. Do not fight them by the Holy Mosque unless they fight you there. If they do, then slay them: Such is the requital for unbelievers.\qt@no{(191)}}
\qt@newcmd\qurantrans@en@cxcix{But if they desist, God is forgiving and kind.\qt@no{(192)}}
\qt@newcmd\qurantrans@en@cc{Fight them till sedition comes to end, and the law of God (prevails). If they desist, then cease to be hostile, except against those who oppress.\qt@no{(193)}}
\qt@newcmd\qurantrans@en@cci{(Fighting during) the holy month (if the sanctity) of the holy month (is violated) is (just) retribution. So if you are oppressed, oppress those who oppress you to the same degree, and fear God, and know that God is with those who are pious and follow the right path.\qt@no{(194)}}
\qt@newcmd\qurantrans@en@ccii{Spend in the way of God, and do not seek destruction at your own hands. So do good for God loves those who do good.\qt@no{(195)}}
\qt@newcmd\qurantrans@en@cciii{Perform the pilgrimage and holy visit ('Umra, to Makkah) in the service of God. But if you are prevented, send an offering which you can afford as sacrifice, and do not shave your heads until the offering has reached the place of sacrifice. But if you are sick or have ailment of the scalp (preventing the shaving of hair), then offer expiation by fasting or else giving alms or a sacrificial offering. When you have security, then those of you who wish to perform the holy visit along with the pilgrimage, should make a sacrifice according to their means. But he who has nothing, should fast for three days during the pilgrimage and seven on return, completing ten. This applies to him whose family does not live near the Holy Mosque. Have fear of God, and remember that God is severe in punishment.\qt@no{(196)}}
\qt@newcmd\qurantrans@en@cciv{Known are the months of pilgrimage. If one resolves to perform the pilgrimage in these months, let him not indulge in concupiscence, sin or quarrel. And the good you do shall be known to God. Provide for the journey, and the best of provisions is piety. O men of understanding, obey Me.\qt@no{(197)}}
\qt@newcmd\qurantrans@en@ccv{It is no sin to seek the favours of your Lord (by trading). When you start from 'Arafat in a concourse, remember God at the monument that is sacred (al-Mash'ar al-haram), and remember Him as He has shown you the way, for in the olden days you we're a people astray.\qt@no{(198)}}
\qt@newcmd\qurantrans@en@ccvi{Then move with the crowd impetuously, and pray God to forgive you your sins. God is surely forgiving and kind.\qt@no{(199)}}
\qt@newcmd\qurantrans@en@ccvii{When you have finished the rites and ceremonies, remember God as you do your fathers, in fact with a greater devotion. There are some who say: ``Give us, O Lord, in the world;" but they will forego their share in the life to come.\qt@no{(200)}}
\qt@newcmd\qurantrans@en@ccviii{But some there are who pray: ``Give us of good in the world, O Lord, and give us of good in the life to come, and suffer us not to suffer the torment of Hell."\qt@no{(201)}}
\qt@newcmd\qurantrans@en@ccix{They are those who will surely have their share of whatsoever they have earned; for God is swift at the reckoning.\qt@no{(202)}}
\qt@newcmd\qurantrans@en@ccx{Remember God during the stated days; but if a person comes away after two days, it will not be a sin; and if one tarries, he will not transgress, if he keep away from evil. Follow the law of God, and remember that you will have to gather before Him in the end.\qt@no{(203)}}
\qt@newcmd\qurantrans@en@ccxi{There is a man who talks well of the world to your pleasing, and makes God witness to what is in his heart, yet he is the most contentious;\qt@no{(204)}}
\qt@newcmd\qurantrans@en@ccxii{For when his back is turned he goes about spreading disorder in the land, destroying fields and flocks; but God does not love disorder.\qt@no{(205)}}
\qt@newcmd\qurantrans@en@ccxiii{Whenever he is told: ``Obey God," his arrogance leads him to more sin; and sufficient for him shall be Hell: How evil a place of wide expanse!\qt@no{(206)}}
\qt@newcmd\qurantrans@en@ccxiv{And there is a man who is willing to sell even his soul to win the favour of God; and God is compassionate to His creatures.\qt@no{(207)}}
\qt@newcmd\qurantrans@en@ccxv{O believers, come to full submission to God. Do not follow in the footsteps of Satan your acknowledged foe.\qt@no{(208)}}
\qt@newcmd\qurantrans@en@ccxvi{If you falter even after Our signs have reached you, then do not forget that God is all-powerful and all-wise.\qt@no{(209)}}
\qt@newcmd\qurantrans@en@ccxvii{Are they waiting for God to appear in the balconies of clouds with a host of angels, and the matter to be settled? But all things rest with God in the end.\qt@no{(210)}}
\qt@newcmd\qurantrans@en@ccxviii{Ask the children of Israel how many a clear sign We had given them. But if one changes the favour of God after having received it, then remember, God is severe in revenge.\qt@no{(211)}}
\qt@newcmd\qurantrans@en@ccxix{Enamoured are the unbelievers of the life of this world, and scoff at the faithful. But those who keep from evil and follow the straight path will have a higher place than they on the Day of Reckoning; for God gives in measure without number whomsoever He will.\qt@no{(212)}}
\qt@newcmd\qurantrans@en@ccxx{Men belonged to a single community, and God sent them messengers to give them happy tidings and warnings, and sent the Book with them containing the truth to judge between them in matters of dispute; but only those who received it differed after receiving clear proofs, on account of waywardness (and jealousies) among them. Then God by His dispensation showed those who believed the way to the truth about which they were differing; for God shows whom He please the path that is straight.\qt@no{(213)}}
\qt@newcmd\qurantrans@en@ccxxi{Do you think you will find your way to Paradise even though you have not known what the others before you have gone through? They had suffered affliction and loss, and were shaken and tossed about so that even the Apostle had to cry out with his followers: ``When will the help of God arrive?" Remember, the help of God is ever at hand.\qt@no{(214)}}
\qt@newcmd\qurantrans@en@ccxxii{They ask you of what they should give in charity. Tell them: ``What you can spare of your wealth as should benefit the parents, the relatives, the orphans, the needy, the wayfarers, for God is not unaware of the good deeds that you do."\qt@no{(215)}}
\qt@newcmd\qurantrans@en@ccxxiii{Enjoined on you is fighting, and this you abhor. You may dislike a thing yet it may be good for you; or a thing may haply please you but may be bad for you. Only God has knowledge, and you do not know.\qt@no{(216)}}
\qt@newcmd\qurantrans@en@ccxxiv{They ask you of war in the holy month. Tell them: ``To fight in that month is a great sin. But a greater sin in the eyes of God is to hinder people from the way of God, and not to believe in Him, and to bar access to the Holy Mosque and turn people out of its precincts; and oppression is worse than killing. They will always seek war against you till they turn you away from your faith, if they can. But those of you who turn back on their faith and die disbelieving will have wasted their deeds in this world and the next. They are inmates of Hell, and shall there abide for ever.\qt@no{(217)}}
\qt@newcmd\qurantrans@en@ccxxv{Surely those who believe, and those who leave their homes and fight in the way of God, may hope for His benevolence, for God is forgiving and kind.\qt@no{(218)}}
\qt@newcmd\qurantrans@en@ccxxvi{They ask you of (intoxicants,) wine and gambling. Tell them: ``There is great enervation though profit in them for men; but their enervation is greater than benefit. And they ask you what they should give. Tell them: ``The utmost you can spare." So does God reveal His signs: You may haply reflect\qt@no{(219)}}
\qt@newcmd\qurantrans@en@ccxxvii{On this world and the next. And they ask you about the orphans. Tell them: ``Improving their lot is much better; and if you take interest in their affairs, they are your brethren; and God is aware who are corrupt and who are honest; and if He had pleased He could surely have imposed on you hardship, for God is all-powerful and all-wise.\qt@no{(220)}}
\qt@newcmd\qurantrans@en@ccxxviii{Do not marry idolatrous women unless they join the faith. A maid servant who is a believer is better than an idolatress even though you may like her. And do not marry your daughters to idolaters until they accept the faith. A servant who is a believer is better than an idolater even though you may like him. They invite you to Hell, but God calls you to Paradise and pardon by His grace. And He makes His signs manifest that men may haply take heed.\qt@no{(221)}}
\qt@newcmd\qurantrans@en@ccxxix{They ask you about menstruation. Tell them: ``This is a period of stress. So keep away from women in this state till they are relieved of it. When they are free of it, you may go to them as God has enjoined. For God loves those who seek pardon, and those who are clean."\qt@no{(222)}}
\qt@newcmd\qurantrans@en@ccxxx{Women are like fields for you; so seed them as you intend, but plan the future in advance. And fear God, and remember, you have to face Him in the end. So convey glad tidings to those who believe.\qt@no{(223)}}
\qt@newcmd\qurantrans@en@ccxxxi{Do not implicate God in your oaths to avoid doing good and being pious and keeping peace among men, for God hears all and knows everything.\qt@no{(224)}}
\qt@newcmd\qurantrans@en@ccxxxii{God will not call you to account for that which is senseless in your oaths, but only for what is in your hearts; for God is forgiving and forbearing.\qt@no{(225)}}
\qt@newcmd\qurantrans@en@ccxxxiii{Those who swear to keep away from their wives (with intent of divorcing them) have four months of grace; then if they reconcile (during this period), surely God is forgiving and kind.\qt@no{(226)}}
\qt@newcmd\qurantrans@en@ccxxxiv{And if they are bent on divorce, God hears all and knows everything.\qt@no{(227)}}
\qt@newcmd\qurantrans@en@ccxxxv{Women who are divorced have to wait for three monthly periods, and if they believe in God and the Last Day they must not hide unlawfully what God has formed within their wombs. Their husbands would do well to take them back in that case, if they wish to be reconciled. Women also have recognised rights as men have, though men have an edge over them. But God is all-mighty and all-wise.\qt@no{(228)}}
\qt@newcmd\qurantrans@en@ccxxxvi{Divorce is (revokable) two times (after pronouncement), after which (there are two ways open for husbands), either (to) keep (the wives) honourably, or part with them in a decent way. You are not allowed to take away the least of what you have given your wives, unless both of you fear that you would not be able to keep within the limits set by God. If you fear you cannot maintain the bounds fixed by God, there will be no blame on either if the woman redeems herself. Do not exceed the limits of God, for those who exceed the bounds set by God are transgressors.\qt@no{(229)}}
\qt@newcmd\qurantrans@en@ccxxxvii{If a man divorces her again (a third time), she becomes unlawful for him (and he cannot remarry her) until she has married another man. Then if he divorces her there is no harm if the two unite again if they think they will keep within the bounds set by God and made clear for those who understand.\qt@no{(230)}}
\qt@newcmd\qurantrans@en@ccxxxviii{When you have divorced your wives, and they have reached the end of the period of waiting, then keep them honourably (by revoking the divorce), or let them go with honour, and do not detain them with the intent of harassing lest you should transgress. He who does so will wrong himself. Do not mock the decrees of God, and remember the favours God has bestowed on you, and revealed to you the Book and the Law to warn you of the consequences of doing wrong. Have fear of God, and remember, God is cognisant of everything.\qt@no{(231)}}
\qt@newcmd\qurantrans@en@ccxxxix{When you have divorced your wives and they have completed the fixed term (of waiting), do not stop them from marrying other men if it is agreed between them honourably. This warning is for those among you who believe in God and the Last Day. This is both proper and right for you, for God knows and you do not know.\qt@no{(232)}}
\qt@newcmd\qurantrans@en@ccxl{The mothers should suckle their babies for a period of two years for those (fathers) who wish that they should complete the suckling, in which case they should feed them and clothe them in a befitting way; but no soul should be compelled beyond capacity, neither the mother made to suffer for the child nor the father for his offspring. The same holds good for the heir of the father (if he dies). If they wish to wean the child by mutual consent there is no harm. And if you wish to engage a wet nurse you may do so if you pay her an agreed amount as is customary. But fear God, and remember that God sees all that you do.\qt@no{(233)}}
\qt@newcmd\qurantrans@en@ccxli{Wives of men who die among you should wait (after their husbands death) for four months and ten days; and when the term is over there is no sin if they do what they like with themselves honourably, for God is aware of all that you do.\qt@no{(234)}}
\qt@newcmd\qurantrans@en@ccxlii{There is no harm in proposing in secret to (any of) these women, or keeping the intention to yourself: God is aware that you will keep them in mind. Yet do not make a promise in secret, unless you speak in a manner that is proper; and do not resolve upon marriage till the fixed term of waiting is over. Remember that God knows what is in your hearts; so be fearful of Him, and remember that God is forgiving and forbearing.\qt@no{(235)}}
\qt@newcmd\qurantrans@en@ccxliii{There is no sin in divorcing your wives before the consummation of marriage or settling the dowry; but then provide adequately for them, the affluent according to their means, the poor in accordance with theirs as is befitting. This is surely the duty of those who do good.\qt@no{(236)}}
\qt@newcmd\qurantrans@en@ccxliv{And if you divorce them before the consummation of marriage, but after settling the dowry, then half the settled dowry must be paid, unless the woman forgoes it, or the person who holds the bond of marriage pays the full amount. And if the man pays the whole, it is nearer to piety. But do not forget to be good to each other, and remember that God sees all that you do.\qt@no{(237)}}
\qt@newcmd\qurantrans@en@ccxlv{Be wakeful of your service of prayer, and the midmost service; and honour God by standing before Him in devotion.\qt@no{(238)}}
\qt@newcmd\qurantrans@en@ccxlvi{If you fear (war or danger), pray while standing or on horseback; but when you have safety again remember God, for He taught you what you did not know.\qt@no{(239)}}
\qt@newcmd\qurantrans@en@ccxlvii{Those among you about to die leaving wives behind, should bequeath a year's maintenance and lodging for them, without expelling them from home. But if they leave (of their own accord), you will not be blamed for what they do with themselves in their own rights. God is all-mighty and all-wise.\qt@no{(240)}}
\qt@newcmd\qurantrans@en@ccxlviii{Making a fair provision for women who are divorced is the duty of those who are God-fearing and pious.\qt@no{(241)}}
\qt@newcmd\qurantrans@en@ccxlix{So does God pronounce His decrees that you may understand.\qt@no{(242)}}
\qt@newcmd\qurantrans@en@ccl{Have you never thought of men who went out of their homes as a measure of safety against death, and they were thousands, to whom God said: ``Die," then restored them to life? Indeed God bestows His blessings on men; only most men are not grateful.\qt@no{(243)}}
\qt@newcmd\qurantrans@en@ccli{Fight in the way of God, and remember that God hears all and knows everything.\qt@no{(244)}}
\qt@newcmd\qurantrans@en@cclii{Who will give a goodly loan to God which He might double many times? For God withholds and enlarges, and to Him you will return.\qt@no{(245)}}
\qt@newcmd\qurantrans@en@ccliii{Have you thought of the elders of Israel after Moses, and how they said to their apostle: ``Set up a king for us, then we shall fight in the way of God?" He replied: ``This too is possible that when commanded to fight you may not fight at all." They said: ``How is it we should not fight in the way of God when we have been driven from our homes and deprived of our Sons?" But when they were ordered to fight they turned away, except for a few; yet God knows the sinners.\qt@no{(246)}}
\qt@newcmd\qurantrans@en@ccliv{And when their prophet said to them: ``God has raised Saul king over you," they said: ``How can he be king over us when we have greater right to kingship than he, for he does not even possess abundant wealth?" ``God has chosen him in preference to you," said the prophet ``and given him much more wisdom and prowess; and God gives authority to whomsoever He will: God is infinite and all-wise."\qt@no{(247)}}
\qt@newcmd\qurantrans@en@cclv{Their prophet said to them: ``The sign of his kingship will be that you will come to have a heart full of peace and tranquility from your Lord and the legacy left by Moses' and Aaron's family supported by angels. This shall be a token for you if you really believe."\qt@no{(248)}}
\qt@newcmd\qurantrans@en@cclvi{When Saul led his armies, he said: ``God will test you by a stream. Whoever drinks its water will not be of me; but those who do not drink shall be on my side. The only exception will be those who scoop up a palmful of water with their hands." And but for a few they all drank of its water. When they had crossed it, and those who believed with him, they said: ``We have no strength to combat Goliath and his forces today. But those who believed they have to face their Lord, said: ``Many a time has a small band defeated a large horde by the will of God. God is with those who are patient (and persevere)."\qt@no{(249)}}
\qt@newcmd\qurantrans@en@cclvii{And when they were facing Goliath and his hordes they prayed: ``O Lord, give us endurance and steady our steps, and help us against the deniers of truth."\qt@no{(250)}}
\qt@newcmd\qurantrans@en@cclviii{By the will of God they defeated them, and David killed Goliath, and God gave him kingship and wisdom, and taught him whatsoever He pleased. If God did not make men deter one another this earth would indeed be depraved. But gracious is God to the people of the world.\qt@no{(251)}}
\qt@newcmd\qurantrans@en@cclix{These are the messages of God. We recite them to you in all truth, as indeed you are one of the apostles.\qt@no{(252)}}
\qt@newcmd\qurantrans@en@cclx{Of all these apostles We have favoured some over the others. God has addressed some of them, and the stations of some have been exalted over the others. And to Jesus, son of Mary, We gave tokens, and reinforced him with divine grace. If God had so willed those who came after them would never have contended when clear signs had come to them. But dissensions arose, some believed, some denied. And if God had willed they would never have fought among themselves. But God does whatsoever He please.\qt@no{(253)}}
\qt@newcmd\qurantrans@en@cclxi{O believers, expend of what We have given you before the day arrives on which there will be no barter, and no friendship or intercession matter, and those who are disbelievers will be sinners.\qt@no{(254)}}
\qt@newcmd\qurantrans@en@cclxii{God: There is no god but He, the living, eternal, self-subsisting, ever sustaining. Neither does somnolence affect Him nor sleep. To Him belongs all that is in the heavens and the earth: and who can intercede with Him except by His leave? Known to Him is all that is present before men and what is hidden (in time past and time future), and not even a little of His knowledge can they grasp except what He will. His seat extends over heavens and the earth, and He tires not protecting them: He alone is all high and supreme.\qt@no{(255)}}
\qt@newcmd\qurantrans@en@cclxiii{There is no compulsion in matter of faith. Distinct is the way of guidance now from error. He who turns away from the forces of evil and believes in God, will surely hold fast to a handle that is strong and unbreakable, for God hears all and knows everything.\qt@no{(256)}}
\qt@newcmd\qurantrans@en@cclxiv{God is the friend of those who believe, and leads them out of darkness into light; but the patrons of infidels are idols and devils who lead them from light into darkness. They are the residents of Hell, and will there for ever abide.\qt@no{(257)}}
\qt@newcmd\qurantrans@en@cclxv{Have you thought of the man who argued with Abraham about his Lord because God had given him a kingdom? When Abraham said: ``My Lord is the giver of life and death," he replied: ``I am the giver of life and death." And Abraham said: ``God makes the sun rise from the East; so you make it rise from the West," and dumbfounded was the infidel. God does not guide those who are unjust.\qt@no{(258)}}
\qt@newcmd\qurantrans@en@cclxvi{Or take the man who passed by a town which lay destroyed upside down. He said: ``How can God restore this city now that it is destroyed?" So God made him die for a hundred years, then brought him back to life, and inquired: ``How long did you stay in this state?" ``A day or less than a day," he replied. ``No," He said, ``you were dead a hundred years, yet look at your victuals, they have not decomposed; and look at your ass! We shall make you a warning for men. And regard the bones, how We raise them and clothe them with flesh." When this became clear to him, the man said: ``Indeed God has power over all things."\qt@no{(259)}}
\qt@newcmd\qurantrans@en@cclxvii{Remember, when Abraham said: ``O Lord, show me how you raise the dead," He said: ``What! Do you not believe?" ``I do," answered Abraham. ``I only ask for my heart's assurance." (The Lord) said: ``Trap four birds and tame them, then put each of them on a (separate) hill, and call them, and they will come flying to you. Know that God is all-powerful and all-wise."\qt@no{(260)}}
\qt@newcmd\qurantrans@en@cclxviii{The semblance of those who expend their wealth in the way of God is that of a grain of corn from which grow seven ears, each ear containing a hundred grains. Truly God increases for whomsoever He will, for God is infinite and all-wise.\qt@no{(261)}}
\qt@newcmd\qurantrans@en@cclxix{Those who spend in the way of God, and having spent do not boast or give pain (by word or deed), will get their reward from their Lord, and will neither have fear nor regret.\qt@no{(262)}}
\qt@newcmd\qurantrans@en@cclxx{Saying a word that is kind, and forgiving is better than charity that hurts. (Do not forget that) God is affluent and kind.\qt@no{(263)}}
\qt@newcmd\qurantrans@en@cclxxi{O believers, do not nullify your charity by giving to oblige and flaunting (your favours) like a man who spends of his wealth only to show off, but does not believe in God and the Last Day. His semblance is that of a rock covered with earth which is washed away by rain exposing the hard rock bare. So they gain nothing from their earnings. God does not guide a people who do not believe.\qt@no{(264)}}
\qt@newcmd\qurantrans@en@cclxxii{But the semblance of those who expend their wealth to please God with firm and resolute hearts, is like a garden on a height on which the rain falls and it yields its fruits twice as much; and even if the rain does not fall the dew will suffice. For God sees all that you do.\qt@no{(265)}}
\qt@newcmd\qurantrans@en@cclxxiii{Does any of you wish to have an orchard full of date-palm trees and vines, and streams of running water and fruits of all kinds, and then old age should overtake him while his children are small, and a scorching whirlwind should smite and burn it down? Thus God makes His signs clear to you that you may reflect.\qt@no{(266)}}
\qt@newcmd\qurantrans@en@cclxxiv{O believers, give in charity what is good of the things you have earned, and of what you produce from the earth; and do not choose to give what is bad as alms, that is, things you would not like to accept yourself except with some condescension. Remember that God is affluent and praiseworthy.\qt@no{(267)}}
\qt@newcmd\qurantrans@en@cclxxv{Satan threatens you with want, and orders you (to commit) shameful acts. But God promises His pardon and grace, for God is bounteous and all-knowing.\qt@no{(268)}}
\qt@newcmd\qurantrans@en@cclxxvi{He gives wisdom to whomsoever He please; and those who are bestowed wisdom get good in abundance. Yet none remembers this save men of wisdom.\qt@no{(269)}}
\qt@newcmd\qurantrans@en@cclxxvii{Whatsoever you give away in alms or vow as offering, is all known to God; but the wicked will have none to help them.\qt@no{(270)}}
\qt@newcmd\qurantrans@en@cclxxviii{If you give alms openly, it is well; but if you do it secretly and give to the poor, that is better. This will absolve you of some of your sins; and God is cognisant of all you do.\qt@no{(271)}}
\qt@newcmd\qurantrans@en@cclxxix{It is not for you to guide them: God guides whom He will. Whatever you spend you will do so for yourself, for you will do so to seek the way that leads to God; and what you spend in charity you will get back in full, and no wrong will be done to you.\qt@no{(272)}}
\qt@newcmd\qurantrans@en@cclxxx{(Give to) the needy who are engaged in the service of God who are not able to move about in the land, whom the ignorant consider to be affluent as they refrain from asking. You can know them from their faces for they do not ask of men importunately. God is surely cognisant of good things that you spend.\qt@no{(273)}}
\qt@newcmd\qurantrans@en@cclxxxi{Those who spend of their wealth in the way of God, day and night, in secret or openly, have their reward with their Lord, and have nothing to fear or regret.\qt@no{(274)}}
\qt@newcmd\qurantrans@en@cclxxxii{Those who live on usury will not rise (on Doomsday) but like a man possessed of the devil and demented. This because they say that trading is like usury. But trade has been sanctioned and usury forbidden by God. Those who are warned by their Lord and desist will keep (what they have taken of interest) already, and the matter will rest with God. But those who revert to it again are the residents of Hell where they will abide for ever.\qt@no{(275)}}
\qt@newcmd\qurantrans@en@cclxxxiii{God takes away (gain) from usury, but adds (profit) to charity; and God does not love the ungrateful and sinners.\qt@no{(276)}}
\qt@newcmd\qurantrans@en@cclxxxiv{Those who believe and do good deeds, and fulfil their devotional obligations and pay the zakat, have their reward with their Lord, and will have neither fear nor regret.\qt@no{(277)}}
\qt@newcmd\qurantrans@en@cclxxxv{O believers, fear God and forego the interest that is owing, if you really believe.\qt@no{(278)}}
\qt@newcmd\qurantrans@en@cclxxxvi{If you do not, beware of war on the part of God and His Apostle. But if you repent, you shall keep your principal. Oppress none and no one will oppress you.\qt@no{(279)}}
\qt@newcmd\qurantrans@en@cclxxxvii{If a debtor is in want, give him time until his circumstances improve; but if you forego (the debt) as charity, that will be to your good, if you really understand.\qt@no{(280)}}
\qt@newcmd\qurantrans@en@cclxxxviii{Have fear of the day when you go back to God. Then each will be paid back in full his reward, and no one will be wronged.\qt@no{(281)}}
\qt@newcmd\qurantrans@en@cclxxxix{O believers, when you negotiate a debt for a fixed term, draw up an agreement in writing, though better it would be to have a scribe write it faithfully down; and no scribe should refuse to write as God has taught him, and write what the borrower dictates, and have fear of God, his Lord, and not leave out a thing. If the borrower is deficient of mind or infirm, or unable to explain, let the guardian explain judiciously; and have two of your men to act as witnesses; but if two men are not available, then a man and two women you approve, so that in case one of them is confused the other may prompt her. When the witnesses are summoned they should not refuse (to come). But do not neglect to draw up a contract, big or small, with the time fixed for paying back the debt. This is more equitable in the eyes of God, and better as evidence and best for avoiding doubt. But if it is a deal about some merchandise requiring transaction face to face, there is no harm if no (contract is drawn up) in writing. Have witnesses to the deal, (and make sure) that the scribe or the witness is not harmed. If he is, it would surely be sinful on your part. And have fear of God, for God gives you knowledge, and God is aware of everything.\qt@no{(282)}}
\qt@newcmd\qurantrans@en@ccxc{If you are on a journey and cannot find a scribe, pledge your goods (against the Loan); and if one trusts the other, then let him who is trusted deliver the thing entrusted, and have fear of God, his Lord. Do not suppress any evidence, for he who conceals evidence is sinful of heart; and God is aware of all you do.\qt@no{(283)}}
\qt@newcmd\qurantrans@en@ccxci{To God belongs all that is in the heavens and the earth; and whether you reveal what is in your heart or conceal it, you will have to account for it to God who will pardon whom He please and punish whom He will, for God has the power over all things.\qt@no{(284)}}
\qt@newcmd\qurantrans@en@ccxcii{The Prophet believes in what has been revealed to him by his Lord, and so do the faithful. Each one believes in God and His angels, His Books and the prophets, and We make no distinction between the apostles. For they say: ``We hear and obey, and we seek Your forgiveness, O Lord, for to You we shall journey in the end."\qt@no{(285)}}
\qt@newcmd\qurantrans@en@ccxciii{God does not burden a soul beyond capacity. Each will enjoy what (good) he earns, as indeed each will suffer from (the wrong) he does. Punish us not, O Lord, if we fail to remember or lapse into error. Burden us not, O Lord, with a burden as You did those before us. Impose not upon us a burden, O Lord, we cannot carry. Overlook our trespasses and forgive us, and have mercy upon us; You are our Lord and Master, help us against the clan of unbelievers.\qt@no{(286)}}
\qt@newcmd\qurantrans@en@ccxciv{\basmalahen ALIF LAM MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@ccxcv{God: there is no god but He, the living, eternal, self-subsisting, ever sustaining.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@ccxcvi{He has verily revealed to you this Book, in truth and confirmation of the Books revealed before, as indeed He had revealed the Torah and the Gospel\qt@no{(3)}}
\qt@newcmd\qurantrans@en@ccxcvii{Before this as guidance for men, and has sent the criterion (of falsehood and truth). As for those who deny the signs of God, the punishment is severe; for God is all powerful and great His requital.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@ccxcviii{There is nothing in the earth and the heavens that is hidden from God.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@ccxcix{He shapes you in the womb of the mother as He wills. There is no god but He, the all-mighty and all-wise.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@ccc{He has sent down this Book which contains some verses that are categorical and basic to the Book, and others allegorical. But those who are twisted of mind look for verses metaphorical, seeking deviation and giving to them interpretations of their own; but none knows their meaning except God; and those who are steeped in knowledge affirm: ``We believe in them as all of them are from the Lord." But only those who have wisdom understand.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@ccci{``Let us not go astray, O Lord, having guided us already. Bestow on us Your blessings for You are the benevolent.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@cccii{You will gather mankind together, O Lord, on a day that is certain to come, and God does not fail in His promise.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@ccciii{As for those who deny, neither their wealth nor their children will help them in the least against God. They shall be but faggots for (the fire of) Hell,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@ccciv{Like the people of the Pharaoh, and those before them, who rejected Our signs, and were punished for their sins by God; and the punishment of God is severe.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@cccv{So tell the disbelievers: ``You will surely be subdued and driven to Hell: How bad a preparation!"\qt@no{(12)}}
\qt@newcmd\qurantrans@en@cccvi{There was a token for you in the two armies which clashed (in the battle of Badr), one fighting for God, the other of unbelievers who saw with their own eyes the faithful to be two times as many as they, for God reinforces with His help whomsoever He will. In this is a lesson for those who have eyes.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@cccvii{Enamoured are the people of the lust of (earthly) pleasures, of women and of children and hoarded heaps of gold and silver, well-bred horses, and tilled land and cattle, all (vain) goods and chattels of the life of this world, while the best of abodes is with God.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@cccviii{Say: ``Shall I tell you of (things) even better? With the Lord are gardens with running streams of water for those who keep from evil and follow the straight path, where they will live unchanged with the purest of companions and blessings of God." And under God's eyes are devotees\qt@no{(15)}}
\qt@newcmd\qurantrans@en@cccix{who say: ``O Lord, we believe; forgive our trespasses and save us the torment of Hell."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@cccx{They are the patient, the sincere and devout, full of charity, who pray for forgiveness in the hours of dawn.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@cccxi{God is witness there is no god but He, and so are the angels and men full of learning. He is the upholder of justice. There is no god but He, the mighty and all-wise.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@cccxii{The true way with God is peace; and the people of the Book did not differ until knowledge (of this revelation) had come to them, out of mutual opposition. But those who deny the signs of God (should remember) He is swift in the reckoning.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@cccxiii{Even then if they argue, tell them: ``I have bowed in submission to God, and so have my followers." And tell the people of the Book and the Arabs: ``Do you submit?" If they do, they will find the right path; if they turn away, your duty is to deliver the message. And God keeps an eye on His votaries.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@cccxiv{To those who deny the signs of God, and slay the apostles unjustly, and slay the upholders of justice, give news of painful punishment.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@cccxv{Their good deeds will be wasted in this world and in the next, and none will they have to help them.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@cccxvi{Have you not seen the people who have received a part of Revelation who are called to the Book of God that it may judge (in their disputes) between them? But some, being averse turn away,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@cccxvii{For they say: ``The Fire will not touch us for more than a few days." They have been deceived by the lies they have themselves fabricated, and stray from their faith.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@cccxviii{How shall it be when We gather them together on a day that is certain to come, when each will receive his reward without (favour or) wrong?\qt@no{(25)}}
\qt@newcmd\qurantrans@en@cccxix{Say: ``O Lord of all dominions, You give whom it pleases You the kingdom, and You take away the power from whosoever You will; You exalt whom You please and debase whom You will. All goodness is Yours (entirely). Indeed You have the power over all things.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@cccxx{You make the night succeed the day, the day succeed the night, raise the living from the dead, the dead from the living, and give whomsoever You please, and in measure without number."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@cccxxi{Those who believe should not take unbelievers as their friends in preference to those who believe -- and whoever does so should have no (expectations) of God -- unless to safeguard yourselves against them. But God commands you to beware of Him, for to God you will journey in the end.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@cccxxii{Say: ``Whether you conceal or reveal whatsoever is in your hearts it is all known to God, as is known to Him all that is in the heavens and the earth; and God has the power over all things."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@cccxxiii{On the day when every man will find whatever of good he has earned and of evil, and is confronted with it, he shall wish that a distance appeared between him and that day -- (that it were far away). God bids you beware of Him, though compassionate is God to His votaries.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@cccxxiv{Say: ``If you love God then follow me that God may love you and forgive your faults; for God is forgiving and kind."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@cccxxv{Say: ``Obey God and His Messenger;" and if they refuse (then remember) God does not love disbelievers.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@cccxxvi{God had chosen Adam and Noah and the families of Abraham and 'Imran in preference to others.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@cccxxvii{They were descendants of one another; and God hears all and knows everything.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@cccxxviii{Remember, when the wife of 'Imran prayed: ``O Lord, I offer what I carry in my womb in dedication to Your service, accept it, for You hear all and know everything."\qt@no{(35)}}
\qt@newcmd\qurantrans@en@cccxxix{And when she had given birth to the child, she said: ``O Lord, I have delivered but a girl." -- But God knew better what she had delivered: A boy could not be as that girl was. ``I have named her Mary," (she said), ``and I give her into Your keeping. Preserve her and her children from Satan the ostracized."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@cccxxx{Her Lord accepted her graciously, and she grew up with excellence, and was given into the care of Zachariah. Whenever Zachariah came to see her in the chamber, he found her provided with food, and he asked: ``Where has this come from, O Mary?" And she said: ``From God who gives food in abundance to whomsoever He will."\qt@no{(37)}}
\qt@newcmd\qurantrans@en@cccxxxi{Then prayed Zachariah to his Lord: ``O Lord, bestow on me offspring, virtuous and good, for You answer all prayers."\qt@no{(38)}}
\qt@newcmd\qurantrans@en@cccxxxii{Then the angels said to him as he stood in the chamber at prayer: ``God sends you good tidings of John who will confirm a thing from God and be noble, continent, and a prophet, and one of those who are upright and do good."\qt@no{(39)}}
\qt@newcmd\qurantrans@en@cccxxxiii{``How can I have a son, O Lord," he said, ``for I am old and my wife is barren?" ``Thus," came the answer, ``God does as He wills."\qt@no{(40)}}
\qt@newcmd\qurantrans@en@cccxxxiv{And Zachariah said: ``Give me a token, O Lord." ``The token will be," was the reply, ``that you will speak to no man for three days except by signs; and remember your Lord much, and pray at evening and sunrise."\qt@no{(41)}}
\qt@newcmd\qurantrans@en@cccxxxv{The angels said: ``O Mary, indeed God has favoured you and made you immaculate, and chosen you from all the women of the world.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@cccxxxvi{So adore your Lord, O Mary, and pay homage and bow with those who bow in prayer."\qt@no{(43)}}
\qt@newcmd\qurantrans@en@cccxxxvii{This is news of the Unknown that We send you, for you were not there when they cast lots with quills (to determine) who should take care of Mary, nor when they disputed it.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@cccxxxviii{When the angels said: ``O Mary, God gives you news of a thing from Him, for rejoicing, (news of one) whose name will be Messiah, Jesus, son of Mary, illustrious in this world and the next, and one among the honoured,\qt@no{(45)}}
\qt@newcmd\qurantrans@en@cccxxxix{Who will speak to the people when in the cradle and when in the prime of life, and will be among the upright and doers of good."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@cccxl{She said: ``How can I have a son, O Lord, when no man has touched me?" He said: ``That is how God creates what He wills. When He decrees a thing, He says 'Be', and it is.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@cccxli{He will teach him the Law and the judgement, and the Torah and the Gospel,\qt@no{(48)}}
\qt@newcmd\qurantrans@en@cccxlii{And he will be Apostle to the children of Israel, (saying:) 'I have come to you with a prodigy from your Lord that I will fashion the state of destiny out of mire for you, and breathe (a new spirit) into it, and (you) will rise by the will of God. I will heal the blind and the leper, and infuse life into the dead, by the leave of God. I will tell you what you devour and what you hoard in your homes. In this will be a portent for you if you do believe.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@cccxliii{I (have come to) confirm the truth of the Torah which was sent down before me, and make certain things lawful which have been forbidden until now; and I come to you with a sign from your Lord; so be fearful of God and follow me.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@cccxliv{Surely God is my Lord, and your Lord, so worship Him; and this is the right path.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@cccxlv{When Jesus perceived their unbelief he asked: ``Who will help me in the way of God?" ``We," the disciples answered, ``shall be the helpers of God. We believe in God; and you be our witness that we submit and obey.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@cccxlvi{``O Lord, we believe in Your revelations and follow this Apostle. Enroll us among the witnesses."\qt@no{(53)}}
\qt@newcmd\qurantrans@en@cccxlvii{But they (the unbelievers) contrived a plot, and God did the like; and God's plan is the best.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@cccxlviii{When God said: ``O Jesus, I will take you to Myself and exalt you, and rid you of the infidels, and hold those who follow you above those who disbelieve till the Day of Resurrection. You have then to come back to Me when I will judge between you in what you were at variance."\qt@no{(55)}}
\qt@newcmd\qurantrans@en@cccxlix{Those who are infidels will surely receive severe punishment both in this world and the next; and none will they have to help (or save) them.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@cccl{But those who believe and do good deeds shall be given their recompense in full; but God does not love the unjust.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@cccli{These verses that We read to you are signs and reminder full of wisdom.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@ccclii{For God the likeness of Jesus is as that of Adam whom He fashioned out of dust and said ``Be" and he was.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@cccliii{This is the truth from your Lord, so do not be in doubt.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@cccliv{Tell those who dispute this with you even after the knowledge that has reached you: ``Come, let us gather our sons and your sons, our women and your women, ourselves and yourselves, and pray and solicit God to condemn those who lie."\qt@no{(61)}}
\qt@newcmd\qurantrans@en@ccclv{And this verily is the true account. There is no god but God, and God is all-mighty and all-wise.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@ccclvi{If they turn away (remember) God knows the mischief-mongers.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@ccclvii{Tell them: ``O people of the Book, let us come to an agreement on that which is common between us, that we worship no one but God, and make none His compeer, and that none of us take any others for lord apart from God." If they turn away you tell them: ``Bear witness that we submit to Him."\qt@no{(64)}}
\qt@newcmd\qurantrans@en@ccclviii{O people of the Book, why dispute about Abraham? The Torah and the Gospel were sent down after him: Do you not understand?\qt@no{(65)}}
\qt@newcmd\qurantrans@en@ccclix{Remember you are those who disputed the things you knew; so wherefore dispute about things you do not know? And God has the knowledge, while you do not know.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@ccclx{Neither was Abraham a Jew nor a Christian, but upright and obedient, and not an idolater.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@ccclxi{Of all men the nearest to Abraham are those who follow him, and then this Prophet and the faithful; and God is the protector of all believers.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@ccclxii{Some among the people of the Book wish to lead you astray, yet they lead none astray but themselves, though they do not realise.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@ccclxiii{O people of the Book, why do you disbelieve the signs of God having witnessed them yourselves?\qt@no{(70)}}
\qt@newcmd\qurantrans@en@ccclxiv{O people of the Book, why do you mix the false with the true, and hide the truth knowingly?\qt@no{(71)}}
\qt@newcmd\qurantrans@en@ccclxv{A section of the people of the Book say: ``Believe in the morning what has been revealed to the faithful, and deny in the evening; they might perhaps turn back;\qt@no{(72)}}
\qt@newcmd\qurantrans@en@ccclxvi{``And do not believe those who do not belong to your faith." Say: ``True guidance is the guidance of God -- that any may be given the like of what has been given you." Will they argue with you before your Lord? Say: ``God's is the bounty. He gives whomsoever He please, for He is infinite and all-wise."\qt@no{(73)}}
\qt@newcmd\qurantrans@en@ccclxvii{He may choose whom He likes for His favours, for great is His bounty.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@ccclxviii{There are some among the people of the Book who return a whole treasure entrusted to them; yet some there are who do not give back a dinar until you demand and insist, because they say: ``It is not a sin for us to (usurp) the rights of the Arabs." Yet they lie against God, and they know it.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@ccclxix{But certainly whoever keeps his promise and follows the right path (will be blessed), for God loves those who shun evil and follow the right course.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@ccclxx{Those who trade on the promises of God, and who purchase a little gain from their oaths, will have no share in the life to come. God will not address or even regard them on the Day of Resurrection, nor perfect them, and their suffering will be painful.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@ccclxxi{Among them is a section which distorts in reading the Scripture in a way that though it sounds like the Scripture, in fact it is not; yet they say it is from God, when they know it is not; and they lie about God, and knowingly.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@ccclxxii{It is not for a mortal to whom God reveals the Book and the judgement and the prophethood to say to the people: ``Be my votaries instead of God's," but (to say): ``Become learned in divine law, by virtue of teaching and studying the Book."\qt@no{(79)}}
\qt@newcmd\qurantrans@en@ccclxxiii{He will surely not bid you make the angels and the prophets your lords. Would he order you disbelief after you have submitted (and accepted the law of God)?\qt@no{(80)}}
\qt@newcmd\qurantrans@en@ccclxxiv{Remember when God covenanted the prophets (and said): ``If after I have given you the Law and the judgement there comes an apostle to you who confirms the truth already with you, you will surely believe him and help him;" and asked: ``Do you accept and agree to the terms of My covenant?" They said: ``We accept." ``Then you be witness," said God, ``and I shall be witness with you.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@ccclxxv{Then any one who turns away will be a transgressor."\qt@no{(82)}}
\qt@newcmd\qurantrans@en@ccclxxvi{Do they seek another way than God's? But whosoever is in the heavens and the earth is submissive to God and obedient (to Him), by choice or constraint, and will be returned to Him.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@ccclxxvii{Say: ``We believe in God, and in what has been revealed to us, and in what had been sent down to Abraham and Ishmael and Isaac and Jacob and their offspring, and what had been revealed to Moses and to Jesus and to all other prophets by their Lord. We make no distinction between them, and we submit to Him and obey."\qt@no{(84)}}
\qt@newcmd\qurantrans@en@ccclxxviii{And whoever seeks a way other than submission to God, it will not be accepted from him, and he will be a loser in the world to come.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@ccclxxix{How can God show the way to those who, having come to faith, turned away, even though they had borne witness that the Messenger was true, and the clear signs had reached them? God does not show the unrighteous the way.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@ccclxxx{For such the requital is the curse of God and the angels and of men.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@ccclxxxi{They shall live under it, and none of their agony decrease nor be respite for them.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@ccclxxxii{But those who repent and reform, God is surely forgiving and merciful.\qt@no{(89)}}
\qt@newcmd\qurantrans@en@ccclxxxiii{Those who deny, having once come to faith, and persist in denial, will not have their repentance accepted, for they have gone astray.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@ccclxxxiv{From those who deny and die disbelieving will never be accepted an earthful of gold if proferred by them as ransom. For them is grievous punishment, and none will help them.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@ccclxxxv{You will never come to piety unless you spend of things you love; and whatever you spend is known to God.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@ccclxxxvi{To the children of Israel was lawful all food except what Israel forbade himself before the Torah was revealed. Say: ``Bring the Torah and recite it, if what you say is true."\qt@no{(93)}}
\qt@newcmd\qurantrans@en@ccclxxxvii{And anyone who fabricates lies about God even after this, is wicked indeed.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@ccclxxxviii{Say: ``God has veritably spoken the truth. So now follow the way of Abraham the upright, who was not of idolaters."\qt@no{(95)}}
\qt@newcmd\qurantrans@en@ccclxxxix{The first House of God to be set up for men was at Bakkah the blessed, a guidance for the people of the world.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@cccxc{It contains clear signs, and the spot where Abraham had stood. And anyone who enters it will find security. And whosoever can afford should visit the House on a pilgrimage as duty to God. Whosoever denies, should remember that God is independent of the peoples of the world.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@cccxci{Say: ``O people of the Book, why do you reject the word of God when God is a witness to all that you do?"\qt@no{(98)}}
\qt@newcmd\qurantrans@en@cccxcii{Then say: ``O people of the Book, why do you turn the believers away from the path of God, looking for obliquities in the way when you are witness to it? And God is aware of all that you do."\qt@no{(99)}}
\qt@newcmd\qurantrans@en@cccxciii{O believers, if you follow what some of the people of the Book say, it will turn you into unbelievers even after you have come to belief.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@cccxciv{And how can you disbelieve? To you are being recited the messages of God, and His prophet is among you. And whosoever holds fast to God shall verily be guided to the path that is straight.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@cccxcv{O believers, fear God as He should be feared, and do not die but submitting (to Him).\qt@no{(102)}}
\qt@newcmd\qurantrans@en@cccxcvi{Hold on firmly together to the rope of God, and be not divided among yourselves, and remember the favours God bestowed on you when you were one another's foe and He reconciled your hearts, and you turned into brethren through His grace. You had stood on the edge of a pit of fire and He saved you from it, thus revealing to you His clear signs that you may find the right way perchance.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@cccxcvii{So let there be a body among you who may call to the good, enjoin what is esteemed and forbid what is odious. They are those who will be successful.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@cccxcviii{So be not like those who became disunited and differed among themselves after clear proofs had come to them. For them is great suffering.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@cccxcix{On the Day when some faces would be bright, and some others will be black (with despair), those with black faces (will be told): ``Having come to the faith you denied it; now taste therefore the penalty for you disbelieved."\qt@no{(106)}}
\qt@newcmd\qurantrans@en@cd{And those with bright faces shall be under God's grace and enjoy it for ever.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@cdi{These are the commandments of God We recite to you verily; God does not wish injustice to the creatures of the world.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@cdii{For to God belongs all that is in the heavens and the earth, and to God do all things return.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@cdiii{Of all the communities raised among men you are the best, enjoining the good, forbidding the wrong, and believing in God. If the people of the Book had come to believe it was best for them; but only some believe, and transgressors are many.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@cdiv{They will do you no harm but annoyance; and if they fight you they will only turn their backs, then no help will reach them.\qt@no{(111)}}
\qt@newcmd\qurantrans@en@cdv{Degraded they shall live wheresoever they be unless they make an alliance with God and alliance with men, for they have incurred the anger of God, and misery overhangs them. That is because they denied the signs of God and killed the prophets unjustly, and rebelled, and went beyond the limit.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@cdvi{Yet all of them are not alike. Among the people of the Book is a section upright, who recite the scriptures in the hours of the night and bow in adoration and pray,\qt@no{(113)}}
\qt@newcmd\qurantrans@en@cdvii{And believe in God and the Last Day, and enjoin what is good and forbid what is wrong, and who hasten to give in charity: they are among the upright and the doers of good.\qt@no{(114)}}
\qt@newcmd\qurantrans@en@cdviii{And the good they do will not go unaccepted; for God is aware of those who keep away from evil.\qt@no{(115)}}
\qt@newcmd\qurantrans@en@cdix{As for those who disbelieve, neither wealth nor children will avail them in the least against God. They are the residents of Hell where they will live for ever.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@cdx{What they spend in the life of this world is like a frosty wind which smites and destroys the crops of a people who had wronged themselves. God did not wrong them, they wronged themselves.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@cdxi{O believers, do not make others except your own people your confidants. They will spare no effort to ruin you: They surely desire your annihilation. Hate is on their tongues, and what they hide in their hearts is worse. We have shown you the signs if you have sense.\qt@no{(118)}}
\qt@newcmd\qurantrans@en@cdxii{Just think! You hold them as your friends but they do not, even though you believe in all the Scriptures. When they meet you they say: ``We believe;" but when they are alone they bite their fingers in rage. Say: ``Die of your rage. God is aware of the secrets of the hearts."\qt@no{(119)}}
\qt@newcmd\qurantrans@en@cdxiii{If good comes your way, they are vexed; but if evil befalls you they are pleased and rejoice; yet if you are patient and guard yourselves against evil, their cunning will not harm you in the least, for whatsoever they do is well within the reach of God.\qt@no{(120)}}
\qt@newcmd\qurantrans@en@cdxiv{Remember when you set forth in the morning from your house assigning the faithful positions for the battle, God heard everything and knew all.\qt@no{(121)}}
\qt@newcmd\qurantrans@en@cdxv{When two of your bands were about to lose heart God befriended them; and in Him should the faithful place their trust.\qt@no{(122)}}
\qt@newcmd\qurantrans@en@cdxvi{For God had helped you during the Battle of Badr at a time when you were helpless. So act in compliance with the laws of God; you may well be grateful.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@cdxvii{Remember when you said to the faithful: ``Is it not sufficient that your Lord should send for your help three thousand angels from the heavens?\qt@no{(124)}}
\qt@newcmd\qurantrans@en@cdxviii{Indeed if you are patient and take heed for yourselves, and the (enemy) come rushing at you suddenly your Lord will send even five thousand angels on chargers sweeping down."\qt@no{(125)}}
\qt@newcmd\qurantrans@en@cdxix{And God did not do so but as good tidings for you, and to reassure your hearts for victory comes from God alone, the all-mighty and all-wise --\qt@no{(126)}}
\qt@newcmd\qurantrans@en@cdxx{In order that He may cut off a part of unbelievers or overthrow them, and they turn back in frustration.\qt@no{(127)}}
\qt@newcmd\qurantrans@en@cdxxi{You have no say in the matter if He pardon them or punish them, for they are unjust.\qt@no{(128)}}
\qt@newcmd\qurantrans@en@cdxxii{To God belongs all that is in the heavens and the earth: He may pardon whom He please and punish whom He will. Yet God is forgiving and kind.\qt@no{(129)}}
\qt@newcmd\qurantrans@en@cdxxiii{O you who believe, do not practice usury, charging doubled and redoubled (interest); but have fear of God: you may well attain your goal.\qt@no{(130)}}
\qt@newcmd\qurantrans@en@cdxxiv{Keep away from the Fire prepared for the infidels;\qt@no{(131)}}
\qt@newcmd\qurantrans@en@cdxxv{Obey God and the Prophet, that you may be treated with mercy.\qt@no{(132)}}
\qt@newcmd\qurantrans@en@cdxxvi{And hasten for the pardon of your Lord, and for Paradise extending over the heavens and the earth, laid out for those who take heed for themselves and fear God,\qt@no{(133)}}
\qt@newcmd\qurantrans@en@cdxxvii{Who expend both in joy and tribulation, who suppress their anger and pardon their fellowmen; and God loves those who are upright and do good,\qt@no{(134)}}
\qt@newcmd\qurantrans@en@cdxxviii{And those who, if they commit a shameful act or some wrong against themselves, remember God and seek forgiveness for their sins: For who can forgive except God? They should not be perverse about their doings, knowingly.\qt@no{(135)}}
\qt@newcmd\qurantrans@en@cdxxix{Their recompense is pardon by their Lord, and gardens with streams of running water where they will abide for ever. How fair is the recompense of those who act!\qt@no{(136)}}
\qt@newcmd\qurantrans@en@cdxxx{There have been many dispensations before you; so travel in the land and see what befell those who denied the truth.\qt@no{(137)}}
\qt@newcmd\qurantrans@en@cdxxxi{This is a clear declaration for mankind, and a guidance and a warning for those who preserve themselves from evil.\qt@no{(138)}}
\qt@newcmd\qurantrans@en@cdxxxii{So do not lose heart or be grieved, for you will surely prevail if you are believers.\qt@no{(139)}}
\qt@newcmd\qurantrans@en@cdxxxiii{If you have been wounded they too have suffered a wound. We cause this alternation of night and day in the affairs of men so that God may know those who believe, taking some as witness (of truth) from your ranks, for God does not like those who are unjust.\qt@no{(140)}}
\qt@newcmd\qurantrans@en@cdxxxiv{This is so that God may try the faithful and destroy the unbelievers.\qt@no{(141)}}
\qt@newcmd\qurantrans@en@cdxxxv{Do you think you will go to Paradise while God does not know who among you strive and persist?\qt@no{(142)}}
\qt@newcmd\qurantrans@en@cdxxxvi{You had wished to know death before you faced it (in battle); so now you have seen it before your own eyes.\qt@no{(143)}}
\qt@newcmd\qurantrans@en@cdxxxvii{Muhammad is only a messenger; and many a messenger has gone before him. So what if he dies or is killed! Will you turn back and go away in haste? But he who turns back and goes away in haste will do no harm to God. But God will reward those who give thanks (and are grateful).\qt@no{(144)}}
\qt@newcmd\qurantrans@en@cdxxxviii{No one can die before his appointed term except in accordance with the law of God. And to him who desires a reward in this world, We shall give it; and to him who desires a reward in the life to come, We shall do that. We shall certainly reward those who are grateful.\qt@no{(145)}}
\qt@newcmd\qurantrans@en@cdxxxix{Many a seeker after God has fought in the way of God by the side of many an apostle, undaunted (by disaster), and did not disgrace themselves; -- verily God loves those who are steadfast.\qt@no{(146)}}
\qt@newcmd\qurantrans@en@cdxl{Nor did they say aught but: ``O our Lord, forgive us our sins and excesses in our acts, and steady our steps, and help us against unbelieving people."\qt@no{(147)}}
\qt@newcmd\qurantrans@en@cdxli{So God rewarded them in this world, and a better reward awaits them in the next; for God loves those who do good.\qt@no{(148)}}
\qt@newcmd\qurantrans@en@cdxlii{O believers, if you listen to the infidels they will make you turn your backs, and you will be the losers.\qt@no{(149)}}
\qt@newcmd\qurantrans@en@cdxliii{But God is your protector, and He is the best of helpers.\qt@no{(150)}}
\qt@newcmd\qurantrans@en@cdxliv{We shall strike terror into the hearts of unbelievers for ascribing compeers to God for which He has sent down no sanction. Hell is their residence, the evil abode of the unjust.\qt@no{(151)}}
\qt@newcmd\qurantrans@en@cdxlv{The promise made to you by God was verified when you destroyed (the foe) by His leave, until you were unmanned and disputed the order, and thus disobeyed (the Apostle) even after He had brought you in sight of (victory) you longed for. Some of you desired this world, and some of you the next. Then He put you to flight before (them) in order to try you. But (now) He has forgiven you, for surely God is kind to the faithful.\qt@no{(152)}}
\qt@newcmd\qurantrans@en@cdxlvi{Remember, as you were rushing up (the hill) without turning back to look, though the Prophet was calling you from the rear, He requited you with anguish for an anguish that you do not fret for missed opportunity and what befell you, for God is aware of all that you do,\qt@no{(153)}}
\qt@newcmd\qurantrans@en@cdxlvii{Then after affliction He Sent you a drowsiness as comes after security, overwhelming some among you, and making some anxious for themselves, and made them think thoughts of pagan ignorance; and they said: ``Have we a say in any affair?" Say: ``All affairs rest with God." They hide in their hearts what they do not disclose to you. They say: ``If we had a say in the affair we would not have been killed in this place." Tell them: ``Even had you stayed at home, those of you who were ordained to fight would have gone to their place of (eternal) rest. God had to try them to bring out what they concealed in their breasts, and to bring out the secrets of their hearts, for God knows your innermost thoughts.\qt@no{(154)}}
\qt@newcmd\qurantrans@en@cdxlviii{All those among you who turned their backs on the day the two armies clashed (at 'Uhud) were surely induced by Satan to fail in their duty because of their sinful deeds. But God has already forgiven them, for God is forgiving and kind.\qt@no{(155)}}
\qt@newcmd\qurantrans@en@cdxlix{O you who believe, do not be like those who deny, and say of their brethren (who died) travelling in the land or fighting: ``Had they stayed with us here they would not have died or been killed." This happened so that God may fill their hearts with grief. God is the giver of life and death and sees all that you do.\qt@no{(156)}}
\qt@newcmd\qurantrans@en@cdl{If you are killed in the cause of God or you die, the forgiveness and mercy of God are better than all that you amass.\qt@no{(157)}}
\qt@newcmd\qurantrans@en@cdli{And if you die or are killed, even so it is to God that you will return.\qt@no{(158)}}
\qt@newcmd\qurantrans@en@cdlii{It was through God's mercy that you dealt with them gently; for had you been stern and hard of heart they would surely have broken away from you. So pardon them and pray that forgiveness be theirs, and seek their counsel in all affairs, And when you have come to a decision place your trust in God alone, for He loves those who place their trust in Him.\qt@no{(159)}}
\qt@newcmd\qurantrans@en@cdliii{If God is there to help you none will overcome you; and if He forsake you, who will help you other than Him? So only in God should the faithful place their trust.\qt@no{(160)}}
\qt@newcmd\qurantrans@en@cdliv{It is not for a prophet to be false; and whoever is false will indeed bring his falsehood with him on the Day of Reckoning when each will receive his reward without favour or wrong.\qt@no{(161)}}
\qt@newcmd\qurantrans@en@cdlv{Is a man who has followed the pleasure of God the same as he who has incurred His wrath, whose abode is surely Hell, a dreadful place?\qt@no{(162)}}
\qt@newcmd\qurantrans@en@cdlvi{There are different ranks with God, And God sees everything you do.\qt@no{(163)}}
\qt@newcmd\qurantrans@en@cdlvii{God has favoured the faithful by sending an apostle to them from among themselves, who recites to them His messages, and reforms and teaches them the Law and the judgement, for they were clearly in error before.\qt@no{(164)}}
\qt@newcmd\qurantrans@en@cdlviii{How is it that when misfortune befell you, you said: ``Where has this come from?" -- even though you had inflicted disaster twice as great on (the enemy). Say: ``This has come from your own selves." Surely God has power over all things.\qt@no{(165)}}
\qt@newcmd\qurantrans@en@cdlix{What you suffered on the day the two armies had met was by God's dispensation, so that He may distinguish the faithful,\qt@no{(166)}}
\qt@newcmd\qurantrans@en@cdlx{And may distinguish the hypocrites who were told: ``Fight in the way of God, or defend yourselves," and who had replied: ``If we knew of the fight we would have followed you." They were nearer unbelief than faith on that day, and they said with their tongues what was not in their hearts; but God is aware of what they hide.\qt@no{(167)}}
\qt@newcmd\qurantrans@en@cdlxi{To those who sit at home and say of their brothers: ``They would never have been killed had they listened to us, say: ``Drive away death from your midst if what you say is true."\qt@no{(168)}}
\qt@newcmd\qurantrans@en@cdlxii{Never think that those who are killed in the way of God are dead. They are alive, getting succour from their Lord,\qt@no{(169)}}
\qt@newcmd\qurantrans@en@cdlxiii{Rejoicing at what God has given them of His grace, and happy for those who are trying to overtake them but have not joined them yet, and who will have no fear or regret.\qt@no{(170)}}
\qt@newcmd\qurantrans@en@cdlxiv{They rejoice at the kindness and mercy of God; and God does not suffer the wages of the faithful to go waste.\qt@no{(171)}}
\qt@newcmd\qurantrans@en@cdlxv{Those who obeyed the call of God and His Messenger, even after they were wounded, and took heed for themselves, shall indeed have an ample reward,\qt@no{(172)}}
\qt@newcmd\qurantrans@en@cdlxvi{Those who were told: ``They have gathered an army, beware," and their faith increased and they said: ``God is sufficient for us, and the best of protectors,"\qt@no{(173)}}
\qt@newcmd\qurantrans@en@cdlxvii{And returned with God's favour and grace without harm, for they attended the pleasure of God; and great is the benevolence of God.\qt@no{(174)}}
\qt@newcmd\qurantrans@en@cdlxviii{It is no one but Satan who frightens you with his allies. But do not fear him, fear Me, if indeed you are believers.\qt@no{(175)}}
\qt@newcmd\qurantrans@en@cdlxix{And do not be grieved by those who rush into disbelief. They do no harm to God; and God will not give them any share in the life to come, and their torment shall be great.\qt@no{(176)}}
\qt@newcmd\qurantrans@en@cdlxx{Those who barter unbelief for faith, will not harm God in the least, and the punishment for them will be painful.\qt@no{(177)}}
\qt@newcmd\qurantrans@en@cdlxxi{The unbelievers must not think that the respite We give them augurs well. We do so that they sink deeper into sin, and suffer an ignominious doom.\qt@no{(178)}}
\qt@newcmd\qurantrans@en@cdlxxii{God will not leave the believers in the state they are in till He has sifted the evil from the good; nor will God reveal the secrets of the Unknown. He chooses (for this) from His apostles whom He will. So believe in God and the prophets, for if you believe and fear the displeasure of God your reward will be great.\qt@no{(179)}}
\qt@newcmd\qurantrans@en@cdlxxiii{Let not those who are niggardly of things that God has given them of His largesse think that this is good for them. In fact, it is worse; for what they grudged will be hung around their necks on the Day of Resurrection. To God belong the heavens and the earth, and God is aware of all you do.\qt@no{(180)}}
\qt@newcmd\qurantrans@en@cdlxxiv{God has indeed heard the words of those who said: ``God is a pauper whereas we are rich." We shall make a note of their words, and the murders of the prophets they committed unjustly, and say to them: ``Now taste the agony of burning."\qt@no{(181)}}
\qt@newcmd\qurantrans@en@cdlxxv{This is (requital) for the deeds you had committed, for God is not unjust to any of His creatures.\qt@no{(182)}}
\qt@newcmd\qurantrans@en@cdlxxvi{To those who say: ``God has ordained that we should not believe an apostle who does not bring burnt offerings," say: ``Many an apostle had come to you before me with manifest proofs, even with what you mention; then why did you kill them if you were men of truth?"\qt@no{(183)}}
\qt@newcmd\qurantrans@en@cdlxxvii{If they call you a liar (remember) so had other apostles been called before you, who had come with clear signs and Scriptures and the Book enlightening.\qt@no{(184)}}
\qt@newcmd\qurantrans@en@cdlxxviii{Every soul will know the taste of death. You will get your recompense in full on the Day of Resurrection; and he who is spared the Fire and finds his way to Paradise will meet his desire. As for the life of this world, it is nothing but a merchandise of vanity.\qt@no{(185)}}
\qt@newcmd\qurantrans@en@cdlxxix{You will, nonetheless, be tried with your wealth and life, and will hear many untoward things from the followers of former Books and the infidels. But if you endure with patience and follow the straight path, it will surely (accord) with God's fixed resolve about human affairs.\qt@no{(186)}}
\qt@newcmd\qurantrans@en@cdlxxx{And remember when God took a promise from the people of the Book to make its (truth) known to mankind, and not keep back any part of it, they set aside (the pledge), and sold it away for a little gain but how wretched the bargain that they made!\qt@no{(187)}}
\qt@newcmd\qurantrans@en@cdlxxxi{Think not that those who exult at what they have done, and who love to be praised for what they have not done, shall escape the punishment, for grievous indeed will be their doom.\qt@no{(188)}}
\qt@newcmd\qurantrans@en@cdlxxxii{For God's is the kingdom of the heavens and the earth, and God's is the power over all things.\qt@no{(189)}}
\qt@newcmd\qurantrans@en@cdlxxxiii{In the creation of the heavens and the earth, the alternation of night and day, are signs for the wise.\qt@no{(190)}}
\qt@newcmd\qurantrans@en@cdlxxxiv{Those who honour God in meditation, standing or sitting or lying on their sides, who reflect and contemplate on the creation of the heavens and the earth, (and say) ``Not in vain have You made them. All praise be to You, O Lord, preserve us from the torment of Hell.\qt@no{(191)}}
\qt@newcmd\qurantrans@en@cdlxxxv{Whoever, O Lord, should be cast into Hell shall be verily disgraced; and the sinners shall have none to help (or save) them.\qt@no{(192)}}
\qt@newcmd\qurantrans@en@cdlxxxvi{We have heard, O our Lord, the crier call inviting us to faith (and announcing): 'Believe in your Lord.' O our Lord, to faith we have come, so forgive our trespasses, deliver us from sin, and grant us (the glory of) death with the just.\qt@no{(193)}}
\qt@newcmd\qurantrans@en@cdlxxxvii{Give us what You promised, O Lord, through Your prophets; and put us not to shame on the Day of Reckoning, for never do You go back on Your promise."\qt@no{(194)}}
\qt@newcmd\qurantrans@en@cdlxxxviii{The Lord heard their prayer and answered: ``I suffer not the good deeds of any to go waste, be he a man or a woman: The one of you is of the other. And those who were deprived of their homes or banished in My cause, and who fought and were killed, I shall blot out their sins and admit them indeed into gardens with rippling streams." -- A recompense from God, and the best of rewards is with God.\qt@no{(195)}}
\qt@newcmd\qurantrans@en@cdlxxxix{Be not deceived by the comings and goings of unbelievers in the land.\qt@no{(196)}}
\qt@newcmd\qurantrans@en@cdxc{Their commerce is but short-lived, and then their abode shall be Hell: And what an evil abode!\qt@no{(197)}}
\qt@newcmd\qurantrans@en@cdxci{But those who are pious and obedient to their Lord, will have gardens with streams of running water where they will abide as guests of God; and what is with God is best for the pious.\qt@no{(198)}}
\qt@newcmd\qurantrans@en@cdxcii{Certainly among the people of the Book are some who believe in God and in what has been revealed to you and had been revealed to them; and they bow in humility before God, and do not trade for paltry gain the signs of God. Their reward is verily with their Lord; and swift is the reckoning of God!\qt@no{(199)}}
\qt@newcmd\qurantrans@en@cdxciii{So you who believe, have endurance in suffering, be patient and persevere, strengthen each other and be firm, and be pious and fear God that you may find success.\qt@no{(200)}}
\qt@newcmd\qurantrans@en@cdxciv{\basmalahen O MEN, FEAR your Lord who created you from a single cell, and from it created its mate, and from the two of them dispersed men and women (male and female) in multitudes. So fear God in whose name you ask of one another (the bond of) relationships. God surely keeps watch over you.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@cdxcv{Give to the orphans their possessions, and do not replace things of your own which are bad with things which are good among theirs, and do not intermix their goods with your own and make use of them, for this is a grievous crime.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@cdxcvi{If you fear you cannot be equitable to orphan girls (in your charge, or misuse their persons), then marry women who are lawful for you, two, three, or four; but if you fear you cannot treat so many with equity, marry only one, or a maid or captive. This is better than being iniquitous.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@cdxcvii{Give to women their dowers willingly, but if they forego part of it themselves, then use it to your advantage.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@cdxcviii{Do not entrust (their) property God has given you to maintain (On trust), to those who are immature; but feed them and clothe them from it, and speak to them with kindness.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@cdxcix{And test (and try) the orphans until they are of marriageable age. If you find they have acquired sound judgement, then hand over their property to them; but devour not their wealth, nor use it up hastily out of fear that soon they will grow up (and demand it). And (the guardian) who is rich should abstain from spending much (of their wealth); and he who is poor should use only as much as is fair. And when you give back their possessions have this witnessed, (and remember) that God is sufficient to take all account.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@d{Men have a share in what the parents and relatives leave behind at death; and women have a share in what the parents and relatives leave behind. Be it large or small a legal share is fixed.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@di{And when the relatives and orphans and the needy collect at the time of the division (of property) provide for them too, and talk kindly to them.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@dii{Let people fear the day when they leave small children behind them unprovided, and how concerned they would be for them. So fear God and say the right things to them.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@diii{Those who devour the possessions of the orphans unjustly devour only fire, and will surely burn in Hell.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@div{As for the children, God decrees that the share of the male is equivalent to that of two females. If they consist of women only, and of them more than two, they will get two-thirds of the inheritance; but in case there is one, she will inherit one half. The parents will each inherit a sixth of the estate if it happens the deceased has left a child; but if he has left no children, and his parents are his heirs, then the mother will inherit one-third; but if he has left brothers, the mother will inherit one-sixth after payment of legacies and debts. Of parents and children you do not know who are more useful to you. These are the decrees of God who knows all and is wise.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@dv{Your share in the property the wives leave behind is half if they die without an issue, but in case they have left children, then your share is one-fourth after the payment of legacies and debts; and your wife shall inherit one-fourth of what you leave at death if you die childless, if not, she will get one-eighth of what you leave behind after payment of legacies and debts. If a man or a woman should die without leaving either children or parents behind but have brother and sister, they shall each inherit one-sixth. In case there are more, they will share one-third of the estate after payment of legacies and debts without prejudice to others. This is the decree of God who knows all and is kind.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@dvi{These are the limits set by God, and those who follow the commandments of God and the Prophet, will indeed be admitted to gardens with streams of water running by, where they will for ever abide; and this will be success supreme.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@dvii{Those who disobey God and the Prophet and exceed the bounds of law, will be taken to Hell and abide there for ever and shall suffer despicable punishment.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@dviii{If any of your women is guilty of unnatural offence, bring four of your witnesses to give evidence; if they testify against them, retain them in the houses until death overtakes them or God provides some other way for them.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@dix{If two (men) among you are guilty of such acts then punish both of them. But if they repent and reform, let them be, for God accepts repentance and is merciful.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@dx{God does accept repentance, but only of those who are guilty of an evil out of ignorance yet quickly repent, and God turns to them again, for God is all-knowing and all-wise.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@dxi{But (He does not accept) the repentance of those who continue indulging in evil until death draws near and they say: ``We now repent;" nor of those who die disbelieving. For them We have a grievous retribution in wait.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@dxii{O believers, you are not allowed to take perforce the women (of dead relatives) into your heritage, or tyrannise over them in order to deprive them of what you have given them, unless they are guilty of open adultery. Live with them with tolerance and justice even if you do not care for them. For it may well be you may not like a thing, yet God may have endued it with much goodness.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@dxiii{If you want to take another wife in place of the one you are married to, then even if you have given her a talent of gold, do not take back a thing. Would you take it away by slandering and using unjust means?\qt@no{(20)}}
\qt@newcmd\qurantrans@en@dxiv{How could you do that having slept with one another, and when they had taken a solemn pledge from you?\qt@no{(21)}}
\qt@newcmd\qurantrans@en@dxv{And do not wed the women your fathers had wed. What happened in the past is now past: It was lewd and abhorrent, and only the way of evil.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@dxvi{Unlawful are your mothers and daughters and your sisters to you, and the sisters of your fathers and your mothers, and the daughters of your brothers and sisters, and foster mothers, foster sisters, and the mothers of your wives, and the daughters of the wives you have slept with who are under your charge; but in case you have not slept with them there is no offence (if you marry their daughters); and the wives of your own begotten sons; and marrying two sisters is unlawful. What happened in the past (is now past): God is forgiving and kind.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@dxvii{Also forbidden are married women unless they are captives (of war). Such is the decree of God. Lawful for you are women besides these if you seek them with your wealth for wedlock and not for debauchery. Then give those of these women you have enjoyed, the agreed dower. It will not be sinful if you agree to something (else) by mutual consent after having settled the dowry. God is certainly all-knowing and all-wise.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@dxviii{If one of you cannot afford to marry a believing gentlewoman (let him marry) a maid who is a believer. God is aware of your faith: The one of you is of the other; so marry them with the consent of their people, and give them an appropriate dowry. They are women (seeking) wedlock, and not lechery, nor secretly looking for paramours. But if they are married and guilty of adultery, inflict on them half the punishment (enjoined) for gentlewomen. This is for those who are afraid of doing wrong. In case they can wait, it is better for them. God is forgiving and kind.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@dxix{God wishes to make it clear to you and guide you through the example of earlier people, and to forgive you, for God is all-knowing and all-wise.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@dxx{God likes to turn to you, but those who are lost in the pleasures of the flesh wish to turn you astray, far away.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@dxxi{God would like to lighten your burden, for man was created weak.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@dxxii{O believers, you should not usurp unjustly the wealth of each other, but trade by mutual consent; and do not destroy yourselves. God is merciful to you.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@dxxiii{If someone does so through oppression or injustice, We shall cast him into Hell: This is how (the Law of) God works inevitably.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@dxxiv{If you keep away from the deadly sins that have been forbidden, We shall efface your faults, and lead you to a place of honour.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@dxxv{Do not covet what God has favoured some with more than He has some others. Men have a share in what they earn, and women have theirs in what they earn. Ask God for His favours. Surely God has knowledge of everything.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@dxxvi{For each We have appointed heirs to what parents and relatives leave behind. And to those you have given your pledge in marriage give their share, for God is witness to everything.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@dxxvii{Men are the support of women as God gives some more means than others, and because they spend of their wealth (to provide for them). So women who are virtuous are obedient to God and guard the hidden as God has guarded it. As for women you feel are averse, talk to them suasively; then leave them alone in bed (without molesting them) and go to bed with them (when they are willing). If they open out to you, do not seek an excuse for blaming them. Surely God is sublime and great.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@dxxviii{If you fear a breach between them, appoint one arbiter from the people of the man and one from the people of the woman. If they wish to have a settlement then God will reconcile them, for God is all-knowing and cognisant.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@dxxix{Pay homage to God, and make none His compeer, and be good to your parents and relatives, the orphans and the needy and the neighbours who are your relatives, and the neighbours who are strangers, and the friend by your side, the traveller and your servants and subordinates. God does not surely love those who are arrogant and boastful,\qt@no{(36)}}
\qt@newcmd\qurantrans@en@dxxx{Who are miserly and bid others to be so, and hide what God has given them in His largesse. We have prepared for unbelievers a shameful punishment.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@dxxxi{Those who spend of their wealth to show off and do not believe in God and the Last Day, take Satan as companion, and how evil a companion (have they)!\qt@no{(38)}}
\qt@newcmd\qurantrans@en@dxxxii{Would something have befallen them if they had believed in God and the Last Day, and spent of what has been given them by God? God is fully aware of all they do.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@dxxxiii{God does not wrong any one, not even the equal of an atom; and if men do good He multiplies it by two, and adds a great reward of His own.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@dxxxiv{How shall it be when We call witnesses from each and every people and call you as witness over them?\qt@no{(41)}}
\qt@newcmd\qurantrans@en@dxxxv{On that day those who disbelieved and disobeyed the Prophet, shall wish they were levelled with the dust, and shall not be able to conceal a thing from God.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@dxxxvi{O you who believe, do not perform your service of prayer when you are intoxicated until you are sure of what you are saying, nor when in a state of seminal pollution, until you have taken a bath, except when you are travelling. But in case you are ill or are travelling, or you have relieved yourself of nature's call, or cohabited with a woman, and cannot find water, then take wholesome dust and pass it over your face and hands: God is benign and forgiving.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@dxxxvii{Have you not seen the people who were given a share of the Book, but who purchased only error, and wish that you also go astray?\qt@no{(44)}}
\qt@newcmd\qurantrans@en@dxxxviii{But God knows your enemies well: and sufficient is God to protect you, and sufficient is God for all help.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@dxxxix{Some among the Jews distort the words out of context and say (in place of the right words): ``We have heard and do not obey;" and, ``hear without hearing," and ``listen to us," twisting their tongues and reviling the faith. But if they had said: ``We have heard and obey," and, ``hear and regard us," it would have been better for them and more appropriate. But God has disgraced them for their lack of belief; and so only a few of them believe.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@dxl{O people of the Book, believe in what We have revealed, which confirms what is already with you before We disfigure your visages and turn your faces about and curse you, as We did with those who had broken the Sabbath; and what God decrees comes to pass.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@dxli{God does not forgive that compeers be ascribed to Him, though He may forgive aught else if He please. And he who ascribes compeers to God is guilty of the gravest sin.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@dxlii{Have you not seen the people who call themselves pure? Yet God purifies whom He pleases, and none shall be wronged even the breadth of a thread.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@dxliii{See how they fabricate lies about God, which is a clear sin.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@dxliv{Have you not seen those who were given a portion of the Book, who believe in false deities and evil powers, and say of unbelievers: ``These are better guided than those who believe."\qt@no{(51)}}
\qt@newcmd\qurantrans@en@dxlv{They are the ones who were cursed by God; and those who are cursed by God will have none to protect them.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@dxlvi{Have they a share in the kingdom? (If they had,) they would never have given an iota to the people.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@dxlvii{Are they so envious of others for what God has given them of His bounty? So We had given the Book and the Law to Abraham's family, and given them great dominion.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@dxlviii{Then some of them believed in it, and some turned away from it; yet sufficient is Hell, the flaming Fire!\qt@no{(55)}}
\qt@newcmd\qurantrans@en@dxlix{And those who disbelieve Our revelations shall be cast into Hell; and when their skin is burnt up and singed, We shall give them a new coat that they may go on tasting the agony of punishment, for God is all-mighty and all-wise.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@dl{But those who believe and do good deeds We shall admit into gardens with streams of running water, where they will abide for ever, with fairest of companions and coolest of shades.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@dli{God enjoins that you render to the owners what is held in trust with you, and that when you judge among the people do so equitably. Noble are the counsels of God, and God hears all and sees everything.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@dlii{O you who believe, obey God and the Prophet and those in authority among you; and if you are at variance over something, refer it to God and the Messenger, if you believe in God and the Last Day. This is good for you and the best of settlement.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@dliii{Have you never seen those who aver they believe in what has been revealed to you and had been to others before you, yet desire to turn for judgement to evil powers, even though they have been commanded to disbelieve in them? Satan only wishes to lead them astray, far away.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@dliv{When they are told: ``Come to that which God has revealed, and to the Prophet," you should see the hypocrites, how they hesitate and turn their faces away.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@dlv{How shall it be when they suffer misfortunes for their own misdeeds? Then they will come to you swearing by God and saying: ``We wish for nothing but good and amity."\qt@no{(62)}}
\qt@newcmd\qurantrans@en@dlvi{The secrets of the hearts of these people are well known to God. So leave them alone, and counsel them and speak to them eloquent words that would touch their very souls.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@dlvii{We have sent no apostle but that he should be obeyed by the will of God. If they had come to you after wronging themselves and asked forgiveness of God, and you had also asked forgiveness for them, they would surely have found God forgiving and merciful.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@dlviii{Indeed, by your Lord, they will not believe till they make you adjudge in their disputes and find no constraint in their minds about your decisions and accept them with full acquiescence.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@dlix{If We had commanded them to lay down their lives and to go forth from their homes, only a few would have obeyed; though had they followed what they had been commanded it would surely have been good for them and the strengthening of their faith.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@dlx{And We would have bestowed on them a great reward of Our own,\qt@no{(67)}}
\qt@newcmd\qurantrans@en@dlxi{And led them to the path that is straight.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@dlxii{Those who obey God and the Prophet are with those who are blessed by God, the prophets, the sincere and the trustful, the martyrs and the upright; and how excellent a company are they!\qt@no{(69)}}
\qt@newcmd\qurantrans@en@dlxiii{This is a favour from God; and sufficient is God, the all-knowing.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@dlxiv{O believers, take precautions, and advance in detachments, or go all together in a body.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@dlxv{Someone among you will surely lag behind, and if calamity should befall you, will say: ``God was gracious to me that I was not among them."\qt@no{(72)}}
\qt@newcmd\qurantrans@en@dlxvi{But if success comes to you from God he will say, as though no love existed between you and him: ``I wish I were with them, for I would have certainly met with great success."\qt@no{(73)}}
\qt@newcmd\qurantrans@en@dlxvii{Those who barter the life of this world for the next should fight in the way of God. And We shall bestow on him who fights in the way of God, whether he is killed or is victorious, a glorious reward.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@dlxviii{What has come upon you that you fight not in the cause of God and for the oppressed, men, women and children, who pray: ``Get us out of this city, O Lord, whose people are oppressors; so send us a friend by Your will, and send us a helper."\qt@no{(75)}}
\qt@newcmd\qurantrans@en@dlxix{Those who believe fight in the way of God; and those who do not, only fight for the powers of evil; so you should fight the allies of Satan. Surely the stratagem of Satan is ineffective.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@dlxx{Have you not seen the people who were told: ``Hold back your hands (from attacking), observe your devotional obligations and pay the zakat?" But when they were commanded to fight, behold, a section among them were filled with fear of men as though it were the fear of God and even more, and said: ``O Lord, why did you make war compulsory for us? Why did you not allow us to live a little more?" Say to them: ``How short-lived is the commerce of this world; but that of the next is best for those who fear God; and you will not be wronged the breadth of a thread."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@dlxxi{Death will overtake you wheresoever you be, even in the mightiest of towers. Yet if some good comes their way they say: ``It is from God;" and if it is evil that befalls them, they say: ``It is indeed from you." Say to them: ``Every thing is from God." O, what has come upon the people that even this they fail to understand!\qt@no{(78)}}
\qt@newcmd\qurantrans@en@dlxxii{What comes to you of good is verily from God; and what comes to you of ill is from your own self (your actions). We have sent you as apostle to all mankind; and God is sufficient as witness.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@dlxxiii{He who obeys the Apostle obeys God; and if some turn away (remember) We have not sent you as warden over them.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@dlxxiv{They say: ``We obey;" but when they leave your company, a section of them discuss at night other things than you had said; but God takes note of what they discuss. So turn aside from them and trust in God; and God is sufficient as protector.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@dlxxv{Do they not ponder over the Qur'an? Had it been the word of any other but God they would surely have found a good deal of variation in it.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@dlxxvi{And when any tidings of peace or war come to them they spread the news around. Had they gone to the Prophet or those in authority among them, then those who check and scrutinize would have known it, And but for the favour of God and His mercy you would certainly have followed Satan, except a few.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@dlxxvii{So fight on in the way of God (irrespective of the others). You cannot compel any one except your own self; but urge the believers to fight. It may well be that God will keep back the might of the infidels, for God's might is greater, and severe His punishment.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@dlxxviii{He who intercedes in a good cause will surely have a share in the recompense; and he who abets an evil act will share the burden thereof; for God (equates and) is watchful of all things.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@dlxxix{When you are greeted with a greeting, then greet with one fairer, or repeat the same greeting. For God takes account of all things.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@dlxxx{God: There is no god but He. He will gather you together on the Day of Resurrection which is certain to come; and whose word is truer than God's?\qt@no{(87)}}
\qt@newcmd\qurantrans@en@dlxxxi{How is it that you are divided in two factions about the hypocrites? God has routed them for what they were doing. Do you wish to guide him to the path whom God has allowed to go astray? As for him whom God allows to go astray you will not find a way.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@dlxxxii{They wish you to become disbelievers as they are, so that you should become like them. Therefore hold them not as friends until they go out of their homes in the way of God. If they do not, seize them wherever they are and do away with them. Do not make them your friends or allies,\qt@no{(89)}}
\qt@newcmd\qurantrans@en@dlxxxiii{Except those who take refuge with a people allied to you, or those who, weary of fighting you or their people, come over to you. If God had so willed He would surely have given them power over you, and they would have fought you. If they keep aloof and do not fight, and offer peace, God has left you no reason to fight them.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@dlxxxiv{You will also find persons who, while wishing to live in peace with you as well as with their own people, turn to civil war the moment they are called to it. If they do not keep away from you, nor offer you peace nor restrain their hands, seize them and kill them wherever they are. We have given you a clear sanction against them.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@dlxxxv{It is not for a believer to take a believer's life except by mistake; and he who kills a believer by mistake should free a slave who is a believer, and pay blood-money to the victim's family unless they forego it as an act of charity. If he belonged to a community hostile to you but was himself a believer, then a slave who is a believer should be freed. In case he belonged to a people with whom you have a treaty, then give blood-money to his family and free a believing slave. But he who has no means (to do so) should fast for a period of two months continuously to have his sins forgiven by God, and God is all-knowing and all-wise.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@dlxxxvi{Any one who kills a believer intentionally will be cast into Hell to abide there for ever, and suffer God's anger and damnation. For him a greater punishment awaits.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@dlxxxvii{O believers, when you go out on a journey in the way of God, be discreet and do not say to anyone who greets you in peace: ``You are not a believer." You desire the gain of earthly life, but there are prizes in plenty with God. You were also like him (an unbeliever) in the past, but God has been gracious to you. So be careful and discreet, for God is aware of what you do.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@dlxxxviii{The faithful who sit idle, other than those who are disabled, are not equal to those who fight in the way of God with their wealth and lives. God has exalted those in rank who fight for the faith with their wealth and souls over those who sit idle. Though God's promise of good is for all, He has granted His favour of the highest reward to those who struggle in preference to those who sit at home.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@dlxxxix{For them are higher ranks with God, and forgiveness and grace; and God is forgiving and kind.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@dxc{As for those whose souls are taken by the angels (at death) while in a state of unbelief, they will be asked by the angels: ``What (state) were you in?" They will answer: ``We were oppressed in the land." And the angels will say: ``Was not God's earth large enough for you to migrate?" Their abode will be Hell, and what an evil destination!\qt@no{(97)}}
\qt@newcmd\qurantrans@en@dxci{But those who are helpless, men, women and children, who can neither contrive a plan nor do they know the way,\qt@no{(98)}}
\qt@newcmd\qurantrans@en@dxcii{May well hope for the mercy of God; and God is full of mercy and grace.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@dxciii{Whosoever leaves his country in duty to God will find many places of refuge, and abundance on the earth. And he who leaves his home and becomes an emigre in the way of God and His Messenger, and death overtake him, is sure to receive his reward from God; for God is forgiving and kind.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@dxciv{When you travel in the land there is no sin if you curtail your service of prayer if you fear the unbelievers may harass you, for indeed your open enemies are the infidels.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@dxcv{When you are among them, and have to lead the service of prayer, let one group stand up with you, but let them keep their arms. After they have paid their homage they should go to the rear, and let the group which has not done so yet offer their service of prayer with you, remaining cautious and armed, The infidels wish to find you neglectful of your arms and provisions, to attack you unawares. It will not be a sin if you put aside your arms when you are troubled by rain, or you are ill; but take full precautions. God has reserved for infidels a despicable punishment\qt@no{(102)}}
\qt@newcmd\qurantrans@en@dxcvi{If you are late in performing your service of prayer honour God by remembering Him, standing or sitting or lying on your sides. And when you have security perform your act of prayer befittingly; and praying at fixed hours is prescribed for the faithful.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@dxcvii{And do not be chary of pursuing them. If you suffer, they shall also suffer like you. But while you have hope (of success) from God, they have none. Surely God is all-knowing and all-wise.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@dxcviii{We have sent down to you the Book containing the truth, in whose light you should judge among the people as God has shown you, and do not be a contender for deceivers.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@dxcix{And seek God's forgiveness, for God is surely forgiving and kind.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@dc{Do not argue for those who harbour deceit in their hearts, for God does not love the treacherous and the iniquitous.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@dci{They try to hide from (men), but they cannot hide from God who is with them at night when they discuss such matters as He does not approve; but what they do is well within the compass of God.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@dcii{Well, you are those who pleaded for them in the life of this world; but who will plead for them on the Day of Resurrection or be their security?\qt@no{(109)}}
\qt@newcmd\qurantrans@en@dciii{He who does evil or acts against his own interests (by disbelieving), then prays for God's forgiveness, will find God compassionate and merciful.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@dciv{He who earns the wages of sin does so for himself; and God is aware of everything and is wise.\qt@no{(111)}}
\qt@newcmd\qurantrans@en@dcv{He who commits a mistake or iniquity and ascribes it to one who is innocent, is guilty of calumny and brazen sin.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@dcvi{But for the mercy of God and His grace you would certainly have been misled by a section of them; yet they could not mislead you but themselves alone, and could do you no harm, for God has revealed to you the Book and the Law, and taught you what you did not know. Great have been the blessings of God on you.\qt@no{(113)}}
\qt@newcmd\qurantrans@en@dcvii{Their confidential counsels are seldom for the good, save of those who talk of charity or goodness or peace among men. Whosoever does so for the pleasure of God, We shall give him an ample reward.\qt@no{(114)}}
\qt@newcmd\qurantrans@en@dcviii{And he who opposes the Prophet even after the way has become clear to him, and follows a path other than the way of believers, We shall lead him to what he has chosen for himself, and shall take him to Hell: How evil a journey's end.\qt@no{(115)}}
\qt@newcmd\qurantrans@en@dcix{God does not forgive that compeers be ascribed to Him, and absolves all else whatsoever He will. And he who associates compeers with God has indeed wandered far astray.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@dcx{In His place they invoke only females (the pagan deities); and instead of Him they invoke Satan the obstinate rebel\qt@no{(117)}}
\qt@newcmd\qurantrans@en@dcxi{Who was condemned by God and who said: ``I shall take from Thy creatures my determinate share,\qt@no{(118)}}
\qt@newcmd\qurantrans@en@dcxii{And mislead them and tempt them, and order them to slit the ears of animals; and order them to alter God's creation." He who holds Satan as friend in place of God will assuredly be damned to perdition.\qt@no{(119)}}
\qt@newcmd\qurantrans@en@dcxiii{Whatever the promises he makes, whatever the desires he enkindles, and whatever the hopes Satan rouses in them, are no more than delusion.\qt@no{(120)}}
\qt@newcmd\qurantrans@en@dcxiv{For such the abode is only Hell from which they will find no escape.\qt@no{(121)}}
\qt@newcmd\qurantrans@en@dcxv{But those who believe and do good deeds We shall admit into gardens with streams of running water where they will abide for ever. True is the promise of God; and whose word could be truer than God's?\qt@no{(122)}}
\qt@newcmd\qurantrans@en@dcxvi{It is neither dependent on your wishes, nor the wishes of the people of the Book, (but) whosoever does ill will be punished for it, and will find no protector or friend apart from God;\qt@no{(123)}}
\qt@newcmd\qurantrans@en@dcxvii{But he who performs good deeds, whether man or a woman, and is a believer, will surely enter Paradise, and none shall be deprived even of an iota of his reward.\qt@no{(124)}}
\qt@newcmd\qurantrans@en@dcxviii{Whose way is better than that of the man who has submitted to God, and does good, and who follows the creed of Abraham the upright? And God chose Abraham as friend.\qt@no{(125)}}
\qt@newcmd\qurantrans@en@dcxix{And all that is in the heavens and the earth belongs to God; and everything is well within the compass of God.\qt@no{(126)}}
\qt@newcmd\qurantrans@en@dcxx{And they ask you for judgement about women. Tell them: ``God has given you instructions about them. You also read them in the Book concerning orphaned women (in your charge) to whom you deny their ordained rights and yet wish to take them in marriage, as well as in respect of helpless children, that you should be just in the matter of orphans." The good you do is known to God.\qt@no{(127)}}
\qt@newcmd\qurantrans@en@dcxxi{If a woman fears aversion from her husband, or ill treatment, there is no harm if they make a peaceful settlement; and peace is an excellent thing. But men keep self-interest uppermost. Yet if you do good and fear God, God is cognisant of all that you do.\qt@no{(128)}}
\qt@newcmd\qurantrans@en@dcxxii{Howsoever you may try you will never be able to treat your wives equally. But do not incline (to one) exclusively and leave (the other) suspended (as it were). Yet if you do the right thing and are just, God is verily forgiving and kind.\qt@no{(129)}}
\qt@newcmd\qurantrans@en@dcxxiii{If both (decide to) separate, God in His largesse will provide for them; for God is infinite and all wise.\qt@no{(130)}}
\qt@newcmd\qurantrans@en@dcxxiv{All that is in the heavens and the earth belongs to God. We had commanded those who received the Book before you, and have commanded you too, to obey the laws of God. Even if you deny, surely all that is in the heavens and the earth belongs to God; and God is self-sufficient and praise-worthy.\qt@no{(131)}}
\qt@newcmd\qurantrans@en@dcxxv{For all that is in the heavens and the earth belongs to God; and God is sufficient as guardian.\qt@no{(132)}}
\qt@newcmd\qurantrans@en@dcxxvi{He could take you away if He will, O men, and replace you with others: God has the power to do so.\qt@no{(133)}}
\qt@newcmd\qurantrans@en@dcxxvii{Whosoever desires a reward of this world (should remember) that with God are rewards of this world and the next; and God hears all and sees everything.\qt@no{(134)}}
\qt@newcmd\qurantrans@en@dcxxviii{O you who believe, be custodians of justice (and) witnesses for God, even though against yourselves or your parents or your relatives. Whether a man be rich or poor, God is his greater well-wisher than you. So follow not the behests of lust lest you swerve from justice; and if you prevaricate or avoid (giving evidence), God is cognisant of all that you do.\qt@no{(135)}}
\qt@newcmd\qurantrans@en@dcxxix{O believers, believe in God and His Messenger and the Book He has revealed to His Apostle, and the Books revealed before. But he who believes not in God and His angels and the Books and the prophets and the Last Day, has wandered far away.\qt@no{(136)}}
\qt@newcmd\qurantrans@en@dcxxx{Those who accept the faith, then disbelieve, then return to it, and deny once again and increase in disbelief, will not be forgiven by God or be guided by Him.\qt@no{(137)}}
\qt@newcmd\qurantrans@en@dcxxxi{Give tidings to the hypocrites that painful is their doom.\qt@no{(138)}}
\qt@newcmd\qurantrans@en@dcxxxii{Do those who take unbelievers as their friends in preference to the faithful seek power from them? But all power belongs to God.\qt@no{(139)}}
\qt@newcmd\qurantrans@en@dcxxxiii{You have been commanded in the Book that whensoever you hear God's messages denied or derided, do not sit in that company until they begin talking of other things, or you will be no different from them. Indeed God will put the hypocrites and infidels together in Hell.\qt@no{(140)}}
\qt@newcmd\qurantrans@en@dcxxxiv{Those who wait to see what befalls you, say in ease success comes to you from God: ``Were we not with you?" But if fortune favours the infidels, they say: ``Did we not overpower you, and yet protected you against the believers?" But God will judge between you on the Day of Resurrection; and God will never give the unbelievers a way over the faithful.\qt@no{(141)}}
\qt@newcmd\qurantrans@en@dcxxxv{The hypocrites try to deceive God, but He (leads them to) deceive themselves. When they stand up for performing the service of prayer they do so indolently, only for show, and remember God but little,\qt@no{(142)}}
\qt@newcmd\qurantrans@en@dcxxxvi{Wavering between the two, neither with these nor with those. For them who are not given the guidance by God, you will never find a way.\qt@no{(143)}}
\qt@newcmd\qurantrans@en@dcxxxvii{O believers, do not hold unbelievers as friends in preference to the faithful. Do you want to proffer a clear proof of your own guilt before God?\qt@no{(144)}}
\qt@newcmd\qurantrans@en@dcxxxviii{The hypocrites will be in the lowest depths of Hell, and you will find none to help them.\qt@no{(145)}}
\qt@newcmd\qurantrans@en@dcxxxix{But those who repent and amend, and hold firmly to God, and are sincere and wholly obedient to God, are surely with the faithful; and God will bestow on the faithful a great reward.\qt@no{(146)}}
\qt@newcmd\qurantrans@en@dcxl{Why should God punish you if you acknowledge the truth and believe? God is responsive to gratitude and is cognisant.\qt@no{(147)}}
\qt@newcmd\qurantrans@en@dcxli{God does not like ill (of others) spoken about, except by him who has been wronged. For God hears all and knows everything.\qt@no{(148)}}
\qt@newcmd\qurantrans@en@dcxlii{Whether you do some good openly or in secret, or forgive an ill done to you, (know) that God is forgiving and all-powerful.\qt@no{(149)}}
\qt@newcmd\qurantrans@en@dcxliii{Those who believe not in God and His apostles, and desire to differentiate between God and His messengers, and say: ``We believe in some and not in the others," and wish to find a way (between affirmation and denial),\qt@no{(150)}}
\qt@newcmd\qurantrans@en@dcxliv{Are verily the real unbelievers. And We have reserved for unbelievers an ignominious punishment.\qt@no{(151)}}
\qt@newcmd\qurantrans@en@dcxlv{But those who believe in God and His apostles and make no distinction among any of them, will be given by Him their recompense; for God is forgiving and kind.\qt@no{(152)}}
\qt@newcmd\qurantrans@en@dcxlvi{The people of the Book demand of you to bring for them a book from heaven. But of Moses they had asked a bigger thing, and demanded: ``Show us God face to face." They were struck by lightning then as punishment for their wickedness. Even then they made the calf, when clear signs had reached them. Still We forgave them and gave Moses clear authority.\qt@no{(153)}}
\qt@newcmd\qurantrans@en@dcxlvii{We exalted them on the Mount, and they gave a solemn pledge, and We said to them: ``Enter the gates submissively," and told them: ``Do not break the Sabbath," and took a solemn pledge from them.\qt@no{(154)}}
\qt@newcmd\qurantrans@en@dcxlviii{So (they were punished) for breaking the covenant and disbelieving the signs of God, and for killing the prophets unjustly, and saying: ``Our hearts are enfolded in covers," (though) in fact God had sealed them because of their unbelief; so they do not believe except a few;\qt@no{(155)}}
\qt@newcmd\qurantrans@en@dcxlix{And because they denied and spoke dreadful calumnies of Mary;\qt@no{(156)}}
\qt@newcmd\qurantrans@en@dcl{And for saying: ``We killed the Christ, Jesus, son of Mary, who was an apostle of God;" but they neither killed nor crucified him, though it so appeared to them. Those who disagree in the matter are only lost in doubt. They have no knowledge about it other than conjecture, for surely they did not kill him,\qt@no{(157)}}
\qt@newcmd\qurantrans@en@dcli{But God raised him up (in position) and closer to Himself; and God is all-mighty and all-wise.\qt@no{(158)}}
\qt@newcmd\qurantrans@en@dclii{There is not one among the people of the Book who will not believe in it before his death; and he will be a witness over them on the Day of Resurrection.\qt@no{(159)}}
\qt@newcmd\qurantrans@en@dcliii{Because of the wickedness of some among the Jews, and because they obstructed people from the way of God, We forbade them many things which were lawful for them;\qt@no{(160)}}
\qt@newcmd\qurantrans@en@dcliv{And because they practised usury although it had been forbidden them; and for using others' wealth unjustly. For those who are unbelievers among them We have reserved a painful punishment.\qt@no{(161)}}
\qt@newcmd\qurantrans@en@dclv{But to the learned among them, and the believers who affirm what has been revealed to you and was revealed to those before you, and to those who fulfil their devotional obligations, who pay the zakat and believe in God and the Last Day, We shall give a great reward.\qt@no{(162)}}
\qt@newcmd\qurantrans@en@dclvi{We have sent revelations to you as We sent revelations to Noah and the prophets (who came) after him; and We sent revelations to Abraham and Ishmael and Isaac and Jacob, and their offspring, and to Jesus and Job, and to Jonah and Aaron and Solomon, and to David We gave the Book of Psalms,\qt@no{(163)}}
\qt@newcmd\qurantrans@en@dclvii{And to many an apostle We have mentioned before, and to many other apostles We have not mentioned to you; and to Moses God spoke directly.\qt@no{(164)}}
\qt@newcmd\qurantrans@en@dclviii{All these apostles of good news and admonition were sent so that after the apostles men may have no argument against God. God is all-powerful and all-wise.\qt@no{(165)}}
\qt@newcmd\qurantrans@en@dclix{God is Himself witness to what has been revealed to you, and revealed with His knowledge, and the angels are witness; and God is sufficient as witness.\qt@no{(166)}}
\qt@newcmd\qurantrans@en@dclx{Those who denied and turned away from the path of God, have wandered far astray.\qt@no{(167)}}
\qt@newcmd\qurantrans@en@dclxi{Those who deny and transgress will not be forgiven by God, nor be shown the way\qt@no{(168)}}
\qt@newcmd\qurantrans@en@dclxii{Except to Hell, where they will abide for ever; and this is how (the law of God) works inevitably.\qt@no{(169)}}
\qt@newcmd\qurantrans@en@dclxiii{O men, the Apostle has now come to you, bringing the truth from your Lord; so believe for your own good; but if you deny (then remember) that all that is in the heavens and the earth belongs to God; and God is all-knowing and all-wise.\qt@no{(170)}}
\qt@newcmd\qurantrans@en@dclxiv{O people of the Book, do not be fanatical in your faith, and say nothing but the truth about God. The Messiah who is Jesus, son of Mary, was only an apostle of God, and a command of His which He sent to Mary, as a mercy from Him. So believe in God and His apostles, and do not call Him 'Trinity'. Abstain from this for your own good; for God is only one God, and far from His glory is it to beget a son. All that is in the heavens and the earth belongs to Him; and sufficient is God for all help.\qt@no{(171)}}
\qt@newcmd\qurantrans@en@dclxv{The Christ will never disdain to be a votary of God, nor will the angels close to Him. And those who disdain to serve Him and are proud (should remember) that they will all go back to Him in the end.\qt@no{(172)}}
\qt@newcmd\qurantrans@en@dclxvi{Then those who believed and earned good deeds will be given their recompense in full, and even more out of grace. But those who disdain and who boast will receive a painful punishment. They will find none except God to help them or save them.\qt@no{(173)}}
\qt@newcmd\qurantrans@en@dclxvii{O men, you have received infallible proof from your Lord, and We have sent down a beacon light to you.\qt@no{(174)}}
\qt@newcmd\qurantrans@en@dclxviii{So those who believe in God and hold fast to Him shall indeed be received into His mercy and His grace, and be guided to Him the straight path.\qt@no{(175)}}
\qt@newcmd\qurantrans@en@dclxix{They ask you for judgement about 'Kalalah' (a man who dies childless). Say: ``God has given a decision in the matter of inheritance." If a man dies and leaves no child behind but have a sister, she will get a half of what he owned, as he would have done the whole of what she possessed if she had died a childless person. In ease he has two sisters then they will get two-thirds of the heritage. But if he has both brothers and sisters, the male will inherit a share equal to that of two females. God makes this manifest to you lest you wander astray, for God has knowledge of everything.\qt@no{(176)}}
\qt@newcmd\qurantrans@en@dclxx{\basmalahen O YOU WHO believe, fulfil your obligations. Made lawful (as food) for you are animals except those mentioned (here); but unlawful during Pilgrimage is game. God ordains whatsoever He wills.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@dclxxi{O you who believe, do not violate the (sanctity of) offerings to God, nor the rites of the holy month, nor sacrificial cattle with garlands (that are brought to the Ka'bah), nor of the people who flock to the Holy House seeking the bounties of their Lord, and His pleasure. Hunt when you have laid aside the robe of the pilgrim. And do not let your hatred of a people who had barred you from the Holy Mosque lead you to aggression. But help one another in goodness and piety, and do not assist in crime and rebellion, and fear God. Surely God is severe in punishment.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@dclxxii{Forbidden you is carrion and blood, and the flesh of the swine, and whatsoever has been killed in the name of some other than God, and whatever has been strangled, or killed by a blow or a fall, or by goring, or that which has been mauled by wild beasts unless slaughtered while still alive; and that which has been slaughtered at altars is forbidden, and also dividing the meat by casting lots with arrows. All this is sinful. Today the unbelievers have lost every hope of (despoiling) your creed; so do not fear them, fear Me. Today I have perfected your system of belief and bestowed My favours upon you in full, and have chosen submission (al-Islam) as the creed for you. If one of you is driven by hunger (to eat the forbidden) without the evil intent of sinning, then God is forgiving and kind.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@dclxxiii{They ask you what is lawful for them. Say: ``All things are lawful for you that are clean, and what the trained hunting animals take for you as you have trained then, in the light of God's teachings, but read over them the name of God, and fear (straying from the path of) God, for God is swift in the reckoning."\qt@no{(4)}}
\qt@newcmd\qurantrans@en@dclxxiv{On this day all things that are clean have been made lawful for you; and made lawful for you is the food of the people of the Book, as your food is made lawful for them. And lawful are the chaste Muslim women, and the women of the people of the Book who are chaste, (for marriage) and not fornication or liaison, if you give them their dowries. Useless shall be rendered the acts of those who turn back on their faith, and they will be among the losers in the life to come.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@dclxxv{O believers, when you stand up for the service of prayer wash your faces and hands up to elbows, and also wipe your heads, and wash your feet up to the ankles. If you are in a state of seminal pollution, then bathe and purify yourself well. But in case you are ill or are travelling, or you have satisfied the call of nature, or have slept with a woman, and you cannot find water, then take wholesome dust and pass it over your face and your hands, for God does not wish to impose any hardship on you. He wishes to purify you, and grace you with His favours in full so that you may be grateful.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@dclxxvi{Remember the favours He bestowed on you, and the covenant He cemented with you, when you said: ``We have heard and obey." Have fear of God, for He knows the secrets of your heart.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@dclxxvii{O you who believe, stand up as witnesses for God in all fairness, and do not let the hatred of a people deviate you from justice. Be just: This is closest to piety; and beware of God. Surely God is aware of all you do.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@dclxxviii{God has made a promise of forgiveness and the highest reward to those who believe and perform good deeds.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@dclxxix{But those who disbelieve and deny Our revelations are the people of Hell.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@dclxxx{O believers, remember the favours God bestowed on you when a people raised their hands against you and He restrained their hands. So fear God; and the faithful should place their trust in God.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@dclxxxi{God covenanted the people of Israel and raised twelve leaders among them, and said: ``I shall verily be with you. If you fulfil your devotional obligations, pay the zakat and believe in My apostles and support them, and give a goodly loan to God, I shall certainly absolve you of your evil, and admit you to gardens with streams of running water. But whosoever among you denies after this, will have wandered away from the right path."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@dclxxxii{When they dishonoured their pledge We condemned them, and hardened their hearts. So they distort the words of the Scripture out of context, and have forgotten some of what they were warned against. You will always hear of treachery on their part except that of a few. But forbear and forgive them, for God loves those who do good.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@dclxxxiii{We had taken the pledge of those also who call themselves Christians. But they too forgot to take advantage of the warning they were given. So We have caused enmity and hatred among them to last till the Day of Resurrection, when God will inform them of what they were doing.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@dclxxxiv{O people of the Book, Our Apostle has come to you, announcing many things of the Scriptures that you have suppressed, passing over some others. To you has come light and a clear Book from God\qt@no{(15)}}
\qt@newcmd\qurantrans@en@dclxxxv{Through which God will lead those who follow His pleasure to the path of peace, and guide them out of darkness into light by His will, and to the path that is straight.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@dclxxxvi{Verily they are unbelievers who say: ``The Messiah, son of Mary, is God." You ask them: ``Who could prevail against God if He had chosen to destroy the Messiah, son of Mary, and his mother, and the rest of mankind?" For God's is the kingdom of the heavens and the earth and whatsoever lies between them. He creates what He please, for God has the power over all things.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@dclxxxvii{Say the Jews and the Christians: ``We are sons of God and beloved of Him." Say: ``Why does He punish you then for your sins? No: You are only mortals, of His creation." He can punish whom He please and pardon whom He will, for God's is the kingdom of the heavens and the earth and all that lies between them, and everything will go back to Him.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@dclxxxviii{O you people of the Book, Our Apostle has come to you when apostles had ceased to come long ago, lest you said: ``There did not come to us any messenger of good news or of warnings." So now there has reached you a bearer of good tidings and of warnings; for God has the power over all things.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@dclxxxix{Remember when Moses said to his people: ``O my people, remember the favours that God bestowed on you when He appointed apostles from among you, and made you kings and gave you what had never been given to any one in the world.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@dcxc{Enter then, my people, the Holy Land that God has ordained for you, and do not turn back, or you will suffer."\qt@no{(21)}}
\qt@newcmd\qurantrans@en@dcxci{They said: ``O Moses, in that land live a people who are formidable; we shall never go there until they leave. We shall enter when they go away."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@dcxcii{Then two of the men who feared (God), and to whom God was gracious, said to them: ``Charge and rush the gate. If you enter, you will surely be victorious. And place your trust in God if you truly believe."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@dcxciii{They said: ``O Moses, we shall never, never enter so long as they are there. Go you and your Lord to fight them; we stay here."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@dcxciv{Said (Moses): ``O Lord, I have control over none but myself and my brother; so distinguish between us and these, the wicked people."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@dcxcv{(And God) said: ``Then verily this land is forbidden them for forty years, and they shall wander perplexed over the earth. So do not grieve for these, the wicked people."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@dcxcvi{Narrate to them exactly the tale of the two sons of Adam. When each of them offered a sacrifice (to God), that of one was accepted, and that of the other was not. Said (the one): ``I will murder you," and the other replied: ``God only accepts from those who are upright and preserve themselves from evil.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@dcxcvii{If you raise your hand to kill me, I will raise not mine to kill you, for I fear God, the Lord of all the worlds;\qt@no{(28)}}
\qt@newcmd\qurantrans@en@dcxcviii{I would rather you suffered the punishment for sinning against me, and for your own sin, and became an inmate of Hell. And that is the requital for the unjust."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@dcxcix{Then the other was induced by his passion to murder his brother, and he killed him, and became one of the damned.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@dcc{Then God sent a raven which scratched the ground in order to show him how to hide the nakedness of his brother. ``Alas, the woe," said he, ``that I could not be even like the raven and hide the nakedness of my brother," and was filled with remorse.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@dcci{That is why We decreed for the children of Israel that whosoever kills a human being, except (as punishment) for murder or for spreading corruption in the land, it shall be like killing all humanity; and whosoever saves a life, saves the entire human race. Our apostles brought clear proofs to them; but even after that most of them committed excesses in the land.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@dccii{The punishment for those who wage war against God and His Prophet, and perpetrate disorders in the land, is to kill or hang them, or have a hand on one side and a foot on the other cut off, or banish them from the land. Such is their disgrace in the world, and in the Hereafter their doom shall be dreadful.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@dcciii{But those who repent before they are subdued should know that God is forgiving and kind.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@dcciv{O you who believe, follow the path shown to you by God, and seek the way of proximity to Him, and struggle in His way: you may have success.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@dccv{As for unbelievers, if they possess the riches of the whole earth, and two times more, and offer it as ransom for release from the torments of the Day of Resurrection, it will not be accepted from them, and their punishment will surely be painful.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@dccvi{They would like to escape from the Fire, but will never succeed, and their suffering will be constant\qt@no{(37)}}
\qt@newcmd\qurantrans@en@dccvii{As for the thief, whether man or woman, cut his hand as punishment from God for what he had done; and God is all mighty and all wise.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@dccviii{But those who repent after a crime and reform, shall be forgiven by God, for God is forgiving and kind.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@dccix{Do you not know that God's is the kingdom of the heavens and the earth? He punishes whom He will, and pardons whom He please, for God has the power over all things.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@dccx{Be not grieved, O Apostle, by those who hasten to outrace others in denial, and say with their tongues: ``We believe," but do not believe in their hearts. And those of the Jews who listen to tell lies, and spy on behalf of others who do not come to you, and who distort the words (of the Torah) out of context, and say: ``If you are given (what we say is true) accept it; but if you are not given it, beware." You cannot intercede with God for him whom God would not show the way. These are the people whose hearts God does not wish to purify. For them is ignominy in this world and punishment untold in the next --\qt@no{(41)}}
\qt@newcmd\qurantrans@en@dccxi{Eavesdropping for telling lies, earning through unlawful means! So, if they come to you, judge between them or decline. And if you decline, they can do you no harm; but if you judge, you should do so with justice, for God loves those who are just.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@dccxii{But why should they make you a judge when the Torah is with them which contains the Law of God? Even then they turn away. They are those who will never believe.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@dccxiii{We sent down the Torah which contains guidance and light, in accordance with which the prophets who were obedient (to God) gave instructions to the Jews, as did the rabbis and priests, for they were the custodians and witnesses of God's writ. So, therefore, do not fear men, fear Me, and barter not My messages away for a paltry gain. Those who do not judge by God's revelations are infidels indeed.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@dccxiv{And there (in the Torah) We had ordained for them a life for a life, and an eye for an eye, and a nose for a nose, and an ear for an ear, and a tooth for a tooth, and for wounds retribution, though he who forgoes it out of charity, atones for his sins. And those who do not judge by God's revelations are unjust.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@dccxv{Later, in the train (of the prophets), We sent Jesus, son of Mary, confirming the Torah which had been (Sent down) before him, and gave him the Gospel containing guidance and light, which corroborated the earlier Torah, a guidance and warning for those who preserve themselves from evil and follow the straight path.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@dccxvi{Let the people of the Gospel judge by what has been revealed in it by God. And those who do not judge in accordance with what God has revealed are transgressors.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@dccxvii{And to you We have revealed the Book containing the truth, confirming the earlier revelations, and preserving them (from change and corruption). So judge between them by what has been revealed by God, and do not follow their whims, side-stepping the truth that has reached you. To each of you We have given a law and a way and a pattern of life. If God had pleased He could surely have made you one people (professing one faith). But He wished to try and test you by that which He gave you. So try to excel in good deeds. To Him will you all return in the end, when He will tell you of what you were at variance.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@dccxviii{Judge between them in the light of what has been revealed by God, and do not follow their whims, and beware of them lest they lead you away from the guidance sent down to you by God. If they turn away, then know that God is sure to punish them for some of their sins; and many of them are transgressors.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@dccxix{Do they seek a judgement of the days of pagan ignorance? But who could be a better judge than God for those who are firm in their faith?\qt@no{(50)}}
\qt@newcmd\qurantrans@en@dccxx{O believers, do not hold Jews and Christians as your allies. They are allies of one another; and anyone who makes them his friends is surely one of them; and God does not guide the unjust.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@dccxxi{You will notice that those whose hearts are afflicted with sickness (of doubt) only hasten to join them and say: ``We fear lest misfortune should surround us." It may well be that God may soon send (you) success, or other command of His. Then will they be repentant of what they had concealed in their hearts.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@dccxxii{Then the believers will say: ``Are these the people who had sworn by God on solemn oath and said: ``We are surely with you?" Wasted have been all their deeds, and losers they remain.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@dccxxiii{O believers, any one of you who turns back on his faith (should remember) that God could verily bring (in your place) another people whom He would love as they would love Him, gentle with believers, unbending with infidels, who would strive in the way of God, unafraid of blame by any slanderer. Such is the favour of God which He bestows on whomsoever He will. God is infinite and all-knowing.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@dccxxiv{Your only friends are God and His Messenger, and those who believe and are steadfast in devotion, who pay the zakat and bow in homage (before God).\qt@no{(55)}}
\qt@newcmd\qurantrans@en@dccxxv{And those who take God and His Prophet and the faithful as their friends are indeed men of God, who will surely be victorious.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@dccxxvi{O believers, do not make friends with those who mock and make a sport of your faith, who were given the Book before you, and with unbelievers; and fear God if you truly believe;\qt@no{(57)}}
\qt@newcmd\qurantrans@en@dccxxvii{(Nor make friends with) those who, when you call (the faithful) to prayer, make mock of it and jest, because they do not understand.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@dccxxviii{Say to them: ``O people of the Book, what reason have you for disliking us other than that we believe in God and what has been sent down to us, and was sent down before, and because most of you are disobedient?"\qt@no{(59)}}
\qt@newcmd\qurantrans@en@dccxxix{Say: ``Shall I inform you who will receive the worst chastisement from God? They who were condemned by God, and on whom fell His wrath, and those who were turned to apes and swine, and those who worship the powers of evil. They are in the worse gradation, and farthest away from the right path."\qt@no{(60)}}
\qt@newcmd\qurantrans@en@dccxxx{When they come to you they say: ``We believe;" but unbelieving they came and unbelieving go; and God is aware of what they conceal in their hearts.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@dccxxxi{You will see among them many who rush into sin and wickedness, and devour unlawful gain. How evil are the things they do!\qt@no{(62)}}
\qt@newcmd\qurantrans@en@dccxxxii{Why do not their rabbis and priests prohibit them from talking of sinful things and from devouring unlawful gain? Evil are the acts they commit!\qt@no{(63)}}
\qt@newcmd\qurantrans@en@dccxxxiii{The Jews say: ``Bound are the hands of God." Tied be their own hands, and damned may they be for saying what they say! In fact, both His hands are open wide: He spends of His bounty in any way He please. But what your Lord has revealed to you will only increase their rebellion and unbelief. So We have caused enmity and hatred among them (which will last) till the Day of Resurrection. As often as they ignite the fires of war they are extinguished by God. Yet they rush around to spread corruption in the land; but God does not love those who are corrupt.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@dccxxxiv{If the people of the Book had believed and feared, We would surely have absolved them of their sins, and admitted them to gardens of delight.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@dccxxxv{And if they had followed the teachings of the Torah and the Gospel, and what has been sent down to them by their Lord, they would surely have enjoyed (blessings) from the heavens above and the earth below their feet.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@dccxxxvi{Some among them are moderate, but evil is what most of them do! O Prophet, announce what has reached you from your Lord, for if you do not, you will not have delivered His message. God will preserve you from (the mischief of) men; for God does not guide those who do not believe.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@dccxxxvii{Say to them: ``O people of the Book, you have no ground (for argument) until you follow the Torah and the Gospel and what has been revealed to you by your Lord." But what has been revealed to you by your Lord will surely increase rebellion and unbelief in many; so do not grieve for those who do not believe.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@dccxxxviii{All those who believe, and the Jews and the Sabians and the Christians, in fact any one who believes in God and the Last Day, and performs good deeds, will have nothing to fear or regret.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@dccxxxix{We had taken a solemn pledge from the children of Israel, and sent messengers to them; but whenever an apostle came to them bringing what did not suit their mood, they called one imposter, another they slew,\qt@no{(70)}}
\qt@newcmd\qurantrans@en@dccxl{And imagined that no trials would befall them; and they turned deaf and blind (to the truth). But God still turned to them; yet many of them turned blind and deaf again; but God sees everything they do.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@dccxli{They are surely infidels who say: ``God is the Christ, son of Mary." But the Christ had only said: ``O children of Israel, worship God who is my Lord and your Lord." Whosoever associates a compeer with God, will have Paradise denied to him by God, and his abode shall be Hell; and the sinners will have none to help them.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@dccxlii{Disbelievers are they surely who say: ``God is the third of the trinity;" but there is no god other than God the one. And if they do not desist from saying what they say, then indeed those among them who persist in disbelief will suffer painful punishment.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@dccxliii{Why do they not turn to God and ask His forgiveness? God is forgiving and kind.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@dccxliv{The Christ, son of Mary, was but an apostle, and many apostles had (come and) gone before him; and his mother was a woman of truth. They both ate the (same) food (as men). Behold, how We show men clear signs, and behold, how they wander astray!\qt@no{(75)}}
\qt@newcmd\qurantrans@en@dccxlv{Tell them: ``Leaving God aside, will you worship something that has no power over your loss or gain?" But God is all-hearing and all-knowing.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@dccxlvi{Tell them: ``O people of the Book, do not overstep the bounds of truth in your beliefs, and follow not the wishes of a people who had erred before, and led many others astray, and wandered away from the right path."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@dccxlvii{Cursed were disbelievers among the children of Israel by David and Jesus, son of Mary, because they rebelled and transgressed the bounds.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@dccxlviii{They did not restrain one another from the wicked things they used to do; and vile were the things that they were doing!\qt@no{(79)}}
\qt@newcmd\qurantrans@en@dccxlix{You can see among them many allying themselves with the infidels. Vile it was what they sent ahead of them, so that God's indignation came upon them; and torment will they suffer an eternity.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@dccl{If they had believed in God and the Prophet and what had been revealed to him, they would never have held them as allies; and many among them are transgressors.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@dccli{You will find the Jews and idolaters most excessive in hatred of those who believe; and the closest in love to the faithful are the people who say: ``We are the followers of Christ," because there are priests and monks among them, and they are not arrogant.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@dcclii{For when they listen to what has been revealed to this Apostle, you can see their eyes brim over with tears at the truth which they recognise, and say: ``O Lord, we believe; put us down among those who bear witness (to the truth).\qt@no{(83)}}
\qt@newcmd\qurantrans@en@dccliii{And why should we not believe in God and what has come down to us of the truth? And we hope to be admitted by our Lord among those who are upright and do good?"\qt@no{(84)}}
\qt@newcmd\qurantrans@en@dccliv{God will reward them for saying so with gardens where streams flow by, where they will live for ever. This is the recompense of those who do good.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@dcclv{But those who disbelieve and deny Our revelations are residents of Hell.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@dcclvi{O believers, do not forbid the good things God has made lawful for you; and do not transgress. God does not love transgressors.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@dcclvii{Eat what is lawful and good of the provisions God has bestowed on you, and fear God in whom you believe.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@dcclviii{God does not punish you but for what you swear in earnest. The expiation (for breaking an oath) is feeding ten persons who are poor, with food that you give your own families, or clothing them, or freeing a slave. But he who cannot do so should fast for three days. This is the expiation for an oath when you have sworn it. So abide by your oaths. Thus God makes His commandments clear to you: You may perhaps be grateful.\qt@no{(89)}}
\qt@newcmd\qurantrans@en@dcclix{O believers, this wine and gambling, these idols, and these arrows you use for divination, are all acts of Satan; so keep away from them. You may haply prosper.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@dcclx{Satan only wishes to create among you enmity and hatred through wine and gambling, and to divert you from the remembrance of God and prayer. Will you therefore not desist?\qt@no{(91)}}
\qt@newcmd\qurantrans@en@dcclxi{Obey God and the Prophet, and beware. If you turn away, remember, that the duty of Our Apostle is to give you a clear warning.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@dcclxii{Those who believe and perform good deeds will not be held guilty for what they have eaten (in the past) if they fear God and believe, and do good things and are conscious (of God) and believe, and still fear and do good, for God loves those who do good.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@dcclxiii{O you who believe, God will surely try you with the game that you take with your hands or your lances, in order to know who fear Him unseen. Whosoever transgress after this will suffer grievous punishment.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@dcclxiv{O you who believe, do not kill game when you are on pilgrimage. And anyone among you who does so on purpose should offer livestock of equivalent value, determined by two honourable persons among you, (as atonement), to be brought to the Ka'bah as an offering; or else expiate by giving food to the poor, or its equivalent in fasting, so that he may realise the gravity of his deed. God has forgiven what has happened in the past; but any one who does so again will be punished by God. And God is severe in requital.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@dcclxv{Lawful is all game of the water for you, and eating of it as food, so that you and the travellers may benefit by it. But unlawful is game of the jungle when you are on pilgrimage. Fear God before whom you have to gather in the end.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@dcclxvi{God has made the Ka'bah, the Sacred House, a means of support for mankind, as also the holy month, the sacrificial offerings, and consecrated cattle, so that you may understand that known to God is all that is in the heavens and the earth, and God has knowledge of everything.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@dcclxvii{Know that the punishment of God is severe, but that God is also forgiving and kind.\qt@no{(98)}}
\qt@newcmd\qurantrans@en@dcclxviii{It is for the Prophet to convey the message: God knows what you reveal and what you hide.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@dcclxix{Tell them: ``The unclean and the pure are not equal, even though the abundance of the unclean may be pleasing to you." So fear God, O men of wisdom; you may haply find success.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@dcclxx{O believers, do not ask about things which, if made known to you, may vex you. But if you ask about them when the Qur'an is being revealed they will be unfolded to you. God has overlooked (your failings) in this (respect), for God is forgiving and forbearing.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@dcclxxi{Such things were asked by a people before you, but they disbelieved them afterwards.\qt@no{(102)}}
\qt@newcmd\qurantrans@en@dcclxxii{God has not sanctioned Baheerah or Sa'ibah, Waseelah or Ham. The unbelievers fabricate lies of God, for many of them are devoid of sense.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@dcclxxiii{When you say to them: ``Come to what God has revealed, and the Prophet," they say: ``Sufficient to us is the faith that our fathers had followed," even though their fathers had no knowledge or guidance.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@dcclxxiv{O you who believe, on you rests (the responsibility) for your own selves. If you follow the right path those who have gone astray will not be able to do you harm. To God have all of you to return, when He will tell you what you were doing.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@dcclxxv{O you who believe, let two honest men among you be witness when you dictate your last will and testament as (the hour of) death draws near; and if death approaches while you are on a journey, two men other than yours. Detain them after the service of prayer, and if you doubt their word make them swear by God that: ``We shall not take a bribe even though it be offered by a near relative, nor hide the testimony of God, for then we shall surely be sinful."\qt@no{(106)}}
\qt@newcmd\qurantrans@en@dcclxxvi{If it transpires they have concealed the truth, two of those who are immediately concerned should take their place and swear by God: ``Our testimony is truer than theirs. We have stated no more (than the truth), or else we shall be unjust"\qt@no{(107)}}
\qt@newcmd\qurantrans@en@dcclxxvii{It is thus likely that men will bear witness rightly, or else fear that their oaths may be disproved by oaths given after them. So fear God, and do not forget that God does not guide the iniquitous.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@dcclxxviii{The day God will gather the apostles and ask: ``What answer was made to you?" They will say: ``We know not. You alone know the secrets unknown."\qt@no{(109)}}
\qt@newcmd\qurantrans@en@dcclxxix{And when God will say: ``O Jesus, son of Mary, remember the favours I bestowed on you and your mother, and reinforced you with divine grace that you spoke to men when in the cradle, and when in the prime of life; when I taught you the law and the judgement and the Torah and the Gospel; when you formed the state of your people's destiny out of mire and you breathed (a new spirit) into it, and they rose by My leave; when you healed the blind by My leave, and the leper; when you put life into the dead by My will; and when I held back the children of Israel from you when you brought to them My signs, and the disbelievers among them said: ``Surely these are nothing but pure magic."\qt@no{(110)}}
\qt@newcmd\qurantrans@en@dcclxxx{And when I inspired the disciples (through Jesus) to believe in Me and My apostle, they said: ``We believe, and You bear witness that we submit"\qt@no{(111)}}
\qt@newcmd\qurantrans@en@dcclxxxi{When the disciples said: ``O Jesus, son of Mary, could your Lord send down for us a table laid with food?" he said: ``Fear God, if indeed you believe."\qt@no{(112)}}
\qt@newcmd\qurantrans@en@dcclxxxii{They said: ``We should like to eat of it to reassure our hearts and to know that it's the truth you have told us, and that we should be witness to it."\qt@no{(113)}}
\qt@newcmd\qurantrans@en@dcclxxxiii{Said Jesus, son of Mary. ``O God, our Lord, send down a table well laid out with food from the skies so that this day may be a day of feast for the earlier among us and the later, and a token from You. Give us our (daily) bread, for You are the best of all givers of food."\qt@no{(114)}}
\qt@newcmd\qurantrans@en@dcclxxxiv{And said God: ``I shall send it down to you; but if any of you disbelieve after this, I shall inflict such punishment on him as I never shall inflict on any other creature."\qt@no{(115)}}
\qt@newcmd\qurantrans@en@dcclxxxv{And when God will ask: ``O Jesus, son of Mary, did you say to mankind: 'Worship me and my mother as two deities apart from God?' (Jesus) will answer: ``Halleluja. Could I say what I knew I had no right (to say)? Had I said it You would surely have known, for You know what is in my heart though I know not what You have. You alone know the secrets unknown.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@dcclxxxvi{I said nought to them but what You commanded me: Worship God, my Lord and your Lord. And so long as I dwelt with them I was witness over their actions. And after my life had been done, You were their keeper; and You are a witness over all things.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@dcclxxxvii{If You punish them, indeed they are Your creatures; if You pardon them, indeed You are mighty and wise."\qt@no{(118)}}
\qt@newcmd\qurantrans@en@dcclxxxviii{God will say: 'This is the day when the truthful shall profit by their truthfulness. For them will be gardens with streams running by, where they will for ever abide." God will accept them, and they will be gratified in (obeying) Him. This will surely be happiness supreme.\qt@no{(119)}}
\qt@newcmd\qurantrans@en@dcclxxxix{To God belongs all that is in the heavens and the earth, and His the power over everything.\qt@no{(120)}}
\qt@newcmd\qurantrans@en@dccxc{\basmalahen ALL PRAISE BE to God who created the heavens and the earth, and ordained darkness and light. Yet the unbelievers make the others equal of their Lord.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@dccxci{It is He who created you from clay then determined a term (of life) for you, and a term (is fixed) with Him. Even then you doubt.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@dccxcii{He is God in the heavens and the earth. He knows what you hide and bring out into the open, and knows what you earn (of good and evil).\qt@no{(3)}}
\qt@newcmd\qurantrans@en@dccxciii{Yet no sign of their Lord comes to them but they turn away from it.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@dccxciv{So they disbelieved the truth when it came to them; but they will soon come to know the reality of what they had ridiculed.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@dccxcv{Do they not see how many generations We laid low before them, whom We had firmly established in the land as We have not established you, and showered abundant rain on them, and made rivers lap at their feet, yet whom We destroyed for their sins, and raised new generations after them?\qt@no{(6)}}
\qt@newcmd\qurantrans@en@dccxcvi{Even if We had sent you a transcript on paper which they could feel with their hands, the unbelievers would have said: ``This is nothing but clear sorcery."\qt@no{(7)}}
\qt@newcmd\qurantrans@en@dccxcvii{They say: ``How is it no angel was sent down to him?" Had We sent an angel down the matter would have come to end, and they would have had no respite.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@dccxcviii{Even if We had sent down an angel as messenger he would have appeared in the garb of a man and filled them with confusion, like the one they are filled with.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@dccxcix{Surely the apostles have been mocked before you; but what they had mocked rebounded on the mockers themselves.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@dccc{Say: ``Travel in the land and see what happened to those who disbelieved."\qt@no{(11)}}
\qt@newcmd\qurantrans@en@dccci{And ask: ``To whom belongs what is in the heavens and the earth?" Say: ``To God." He has prescribed grace for Himself. He will gather you on the Day of Resurrection which is certain to come. Only they who are lost of soul will not come to believe.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@dcccii{Whatsoever dwells in the night and day belongs to Him. He is all-hearing and all-knowing.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@dccciii{Say: ``Should I find some other protector besides God the Creator of the heavens and the earth, who nourishes all and is nourished by none? Say: ``I am commanded to be the first to submit to Him, and not be an idolater."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@dccciv{Say: ``If I disobey my Lord, I fear the punishment of a grievous Day."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@dcccv{Whosoever is spared that Day will surely have mercy shown to him, and this will be a clear triumph.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@dcccvi{If God sends you harm, there is no one but He who can take it away; and if He bring you good, surely He has power over everything.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@dcccvii{It is He who prevails over His creatures, and He is all-wise and aware.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@dcccviii{Ask: ``Of all things what is most vital as evidence?" Say: ``God (who) is witness between you and me that this Qur'an has been revealed to me that I may warn you on its strength, and those whom it reaches. Do you really bear witness there are other gods with God?" Tell them: ``I bear no such Witness." Say: ``Verily He is the only God, and I am clear of what you associate (with Him)."\qt@no{(19)}}
\qt@newcmd\qurantrans@en@dcccix{Those to whom We have given the Book know it distinctly as they know their sons; but those who are lost of soul do not believe.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@dcccx{And who is more wicked than he who invents lies about God or denies His revelations? Surely the wicked will not succeed.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@dcccxi{The day We shall gather all of them together and say to those who ascribe (partners to God): ``Where are the compeers who you claimed (were equal to God)?"\qt@no{(22)}}
\qt@newcmd\qurantrans@en@dcccxii{Then their excuse will be but to say: ``By God our Lord, we were not idolaters."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@dcccxiii{You will see how they will lie against themselves, and all their slanderings will be vain.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@dcccxiv{There are some among them who listen to you; but We have put a covering on their hearts so that they fail to understand it, and a deafness appears in their ears. Even if they saw all the signs they would not believe in them; and even when they come to you to dispute with you, the unbelievers say: ``This is nothing but fables of antiquity."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@dcccxv{And they forbid others from (believing in) it, and themselves keep away from it. But they ruin none but themselves, and do not understand.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@dcccxvi{If you should see them when they are stood before the Fire, they will say: ``Ah would that we were sent back (to the world)! We shall not deny the signs of our Lord, and be among those who believe."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@dcccxvii{But no. What they were hiding has now become clear to them. If they were sent back they would surely return to what had been forbidden them, for surely they are liars.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@dcccxviii{They say: ``There is no other life but that of this world, and we will not be raised (from the dead)."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@dcccxix{If you see them when they are put before their Lord, He will say to them: ``Is not this the truth?" They will answer: ``Indeed, by our Lord." He will say: ``Then taste the agony of punishment for what you had denied."\qt@no{(30)}}
\qt@newcmd\qurantrans@en@dcccxx{They are surely lost who call the meeting with God a lie. When the Hour comes upon them unawares, they will say: ``Alas, we neglected it!" and carry their burdens on their backs: How evil the burden they will carry!\qt@no{(31)}}
\qt@newcmd\qurantrans@en@dcccxxi{As for the life of this world, it is nothing but a frolic and frivolity. The final abode is the best for those who are pious and fear God. Do you not comprehend?\qt@no{(32)}}
\qt@newcmd\qurantrans@en@dcccxxii{We know what they say distresses you. It is not you in fact they accuse of lies, but the wicked deny the revelations of God!\qt@no{(33)}}
\qt@newcmd\qurantrans@en@dcccxxiii{Many an apostle has been accused of lies before you. Yet they bore with fortitude the falsehoods and the hurt until our help arrived. There is no changing the word of God: The news of (past) apostles has come to you already.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@dcccxxiv{If their aversion still weighs upon you, seek out a tunnel (going deep) into the earth, or a ladder reaching out to the skies, and bring them a sign: (Even then they will not believe). If God had willed He would have brought them all to the right path. So be not like the pagans.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@dcccxxv{Only they will respond who can hear. As for the dead, raised they will be by God, then to Him they will be returned.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@dcccxxvi{They say: ``How is it no miracle was sent down to him from his Lord?" Say: ``God certainly has power to send down a miracle; but most men cannot understand."\qt@no{(37)}}
\qt@newcmd\qurantrans@en@dcccxxvii{There is not a thing that moves on the earth, no bird that flies on its wings, but has a community of its own like yours. There is nothing that We have left out from recording. Then they will all be gathered before their Lord.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@dcccxxviii{Those who deny Our revelations are deaf, dumb, and lost in the dark. God sends whosoever He wills astray, and leads whom He will to the straight path.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@dcccxxix{Say: ``Have you thought if the punishment of God or the Hour (of Doom) came upon you, would you call to any other than God? Answer, if you are men of truth."\qt@no{(40)}}
\qt@newcmd\qurantrans@en@dcccxxx{No: You will call to Him alone; and He will, if He please, remove (the distress) for which you had called Him; and forget those you associate as compeers (with Him)\qt@no{(41)}}
\qt@newcmd\qurantrans@en@dcccxxxi{We have indeed sent (apostles) to many a people before you, and inflicted upon them hardships and afflictions so that they might submit.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@dcccxxxii{Then why did they not submit when Our punishment came upon them? But their hearts were hardened, and Satan made things they were doing look attractive to them.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@dcccxxxiii{When they had become oblivious of what they were warned, We opened wide the gates of everything to them; yet as they rejoiced at what they were given, We caught them unawares, and they were filled with despair.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@dcccxxxiv{Thus were the wicked people rooted out of existence to the last. All praise be to God, the Lord of all the worlds.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@dcccxxxv{Say: ``Imagine if God takes away your hearing and sight, and sets a seal on your hearts, what deity other than God will restore them to you?" See how We inflect Our signs: Even then they turn aside.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@dcccxxxvi{Say: ``Imagine if the punishment of God were to come unawares, or openly, who will perish but the evil-doers?"\qt@no{(47)}}
\qt@newcmd\qurantrans@en@dcccxxxvii{We do not send apostles but to give good tidings and to warn. Then those who believe or reform will have neither fear nor regret.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@dcccxxxviii{But those who deny Our messages will be seized by nemesis for being disobedient.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@dcccxxxix{Tell them: ``I do not say that I possess the treasures of God, or have knowledge of the Unknown, or that I am an angel. I only follow what is sent down to me." And say: ``How can a blind man and a man who can see, be alike? Will you not reflect?"\qt@no{(50)}}
\qt@newcmd\qurantrans@en@dcccxl{Warn those who fear, through this (Qur'an), that they will be gathered before their Lord, and they will have none to protect or intercede for them apart from Him. They may haply take heed for themselves.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@dcccxli{Do not turn away those who supplicate their Lord morning and evening, seeking His magnificence. You are not accountable for them in the least, nor they for you at all. If you drive them away you will only be unjust.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@dcccxlii{Thus do We try men through one another so that they may ask: ``Are these the ones of all of us who have been favoured by God?" Does God not know who are the grateful?\qt@no{(53)}}
\qt@newcmd\qurantrans@en@dcccxliii{When those who believe in Our revelations come to you, say to them: ``Peace on you." Your Lord has prescribed grace for Himself, so that in case one of you commits evil out of ignorance, then feels repentant and reforms, He may be forgiving and kind.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@dcccxliv{Thus distinctly do We explain Our signs that the way of sinners may become distinct.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@dcccxlv{Tell them: ``I am forbidden to worship those you invoke apart from God." And say: ``I will not follow your wishes. If I do, I shall be lost and not be one of those who follow the right path."\qt@no{(56)}}
\qt@newcmd\qurantrans@en@dcccxlvi{Tell them: ``A clear proof has come to me from my Lord, and Him you deny. But what you wish to be hastened is not within my power. The judgement is only God's. He unfolds the Truth, and is the best of judges."\qt@no{(57)}}
\qt@newcmd\qurantrans@en@dcccxlvii{Say: ``If what you wish to be hastened were in my power, all matters between you and me would have been settled; God is cognisant of those who are unjust."\qt@no{(58)}}
\qt@newcmd\qurantrans@en@dcccxlviii{He has the keys of the Unknown. No one but He has knowledge; He knows what is on the land and in the sea. Not a leaf falls without His knowledge, nor a grain in the darkest (recess) of the earth, nor any thing green or seared that is not recorded in the open book (of nature).\qt@no{(59)}}
\qt@newcmd\qurantrans@en@dcccxlix{It is He indeed who sends you to death at night, and knows what you do in the day, then makes you rise with it again in order that the fixed term of life be fulfilled. Then to Him you will be returned when He will tell you what you did.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@dcccl{He has power over His creatures, and appoints guardians to watch over them. When death comes to one of you, Our messengers take away his soul, and do not falter.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@dcccli{Then they are taken to God, their real lord and master. His indeed is the judgement; and He is swift at reckoning.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@dccclii{Ask: ``Who is it who comes to your rescue in the darkness of the desert and the sea, and whom you supplicate humbly and unseen: 'If You deliver us from this, we shall indeed he grateful?'\qt@no{(63)}}
\qt@newcmd\qurantrans@en@dcccliii{Say: ``God delivers you from this and every calamity. Even then you ascribe compeers (to Him)!"\qt@no{(64)}}
\qt@newcmd\qurantrans@en@dcccliv{Say: ``He has power to send you retribution from the skies above, or the earth beneath your feet, or confound you with divisions among you, and give one the taste of the vengeance of the other." See, how distinctly We explain Our signs that they may understand.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@dccclv{This (Book) has been called by your people a falsehood though it is the truth. Say: ``I am not a warden over you."\qt@no{(66)}}
\qt@newcmd\qurantrans@en@dccclvi{A time is fixed for every prophecy; you will come to know in time.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@dccclvii{When you see them argue about Our messages, withdraw from their company until they begin to talk of other things. In case the Devil makes you forget, leave the company of these unjust people the moment you remember this.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@dccclviii{As for the heedful and devout, they are not accountable for them, but should give advice: They may haply come to fear God.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@dccclix{Leave those alone who have made a sport and frolic of their faith, and have been seduced by the life of this world. Remind them hereby lest a man is doomed for what he has done. He will have none to help him, or intercede for him, other than God; and even if he offer all the ransoms they will not be accepted from him. They are those who will be destroyed by their own acts. There will be scalding water to drink for them and painful punishment, for they had disbelieved.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@dccclx{Say: 'Should we call in place of God one who can neither help nor do us harm, and turn back after having been guided by God, like a man beguiled by the devils who wanders perplexed in the wilderness while his friends call him back to the right path, saying: 'Come to us, this way?' Say: ``God's guidance is (true) guidance, and we have been commanded to submit to the Lord of all the worlds.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@dccclxi{Observe (your) devotional obligations and fear (God), for it is He before whom you will be gathered (in the end)."\qt@no{(72)}}
\qt@newcmd\qurantrans@en@dccclxii{It is He who created the heavens and the earth with a definite purpose. The day He will say ``Be, `` it will be. His word is the truth, His alone the power on the Day when the blast of the trumpet will be sounded. He knows the hidden and the visible. He is all-prudent and all-knowing.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@dccclxiii{Remember when Abraham said to Azar, his father: ``Why do you take idols for God? I certainly find you and your people in error."\qt@no{(74)}}
\qt@newcmd\qurantrans@en@dccclxiv{Thus We showed to Abraham the visible and invisible world of the heavens and the earth, that he could be among those who believe.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@dccclxv{When the night came with her covering of darkness he saw a star, and (Azar, his father) said: ``This is my Lord." But when the star set, (Abraham) said: ``I love not those that wane."\qt@no{(76)}}
\qt@newcmd\qurantrans@en@dccclxvi{When (Azar) saw the moon rise all aglow, he said: ``This is my Lord." But even as the moon set, (Abraham) said: ``If my Lord had not shown me the way I would surely have gone astray."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@dccclxvii{When (Azar) saw the sun rise all resplendent, he said: ``My Lord is surely this, and the greatest of them all." But the sun also set, and (Abraham) said: ``O my people, I am through with those you associate (with God).\qt@no{(78)}}
\qt@newcmd\qurantrans@en@dccclxviii{I have truly turned my face towards Him who created the heavens and the earth: I have chosen one way and am not an idolater."\qt@no{(79)}}
\qt@newcmd\qurantrans@en@dccclxix{His people argued, and he said: ``Do you argue with me about God? He has guided me already, and I fear not what you associate with Him, unless my Lord wills, for held within the knowledge of my Lord is everything. Will you not reflect?\qt@no{(80)}}
\qt@newcmd\qurantrans@en@dccclxx{And why should I fear those you associate with Him when you fear not associating others with God for which He has sent down no sanction? Tell me, whose way is the way of peace, if you have the knowledge?\qt@no{(81)}}
\qt@newcmd\qurantrans@en@dccclxxi{They alone have peace who believe and do not intermix belief with denial, and are guided on the right path."\qt@no{(82)}}
\qt@newcmd\qurantrans@en@dccclxxii{This is the argument We gave to Abraham against his people. We exalt whosoever We please in rank by degrees. Your Lord is wise and all-knowing.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@dccclxxiii{And We gave him Isaac and Jacob and guided them, as We had guided Noah before them, and of his descendants, David and Solomon and Job and Joseph and Moses and Aaron. Thus We reward those who are upright and do good.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@dccclxxiv{Zachariah and John We guided, and guided Jesus and Elias who were all among the upright.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@dccclxxv{We gave guidance to Ishmael, Elisha and Jonah and Lot; And We favoured them over the other people of the world,\qt@no{(86)}}
\qt@newcmd\qurantrans@en@dccclxxvi{As We did some of their fathers and progeny and brethren, and chose them, and showed them the right path.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@dccclxxvii{This is God's guidance: He gives among His creatures whom He will. If they had associated others with Him, surely vain would have been all they did.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@dccclxxviii{Those were the people to whom We gave the Book and the Law and the Prophethood. But if they reject these things We shall entrust them to a people who will not deny.\qt@no{(89)}}
\qt@newcmd\qurantrans@en@dccclxxix{Those were the people who were guided by God; so follow their way. Say: ``I ask no recompense of you for this. It is but a reminder for all the people of the world."\qt@no{(90)}}
\qt@newcmd\qurantrans@en@dccclxxx{But they failed to make a just estimation of God when they said: ``He did not reveal to any man any thing." Ask them: ``Who then revealed the Book that Moses brought, -- a guidance and light for men, -- which you treat as sheafs of paper, which you display, yet conceal a great deal, though through it you were taught things you did not know before, nor even your fathers knew?" Say: ``God," and leave them to the sport of engaging in vain discourse.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@dccclxxxi{And this (Qur'an) is another Book that We have revealed, blessed, affirming the earlier (revelations), so that you may warn the people of (Makkah) the town of towns, and those who live around it. Those who believe in the life to come shall believe in it and be watchful of their moral obligations.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@dccclxxxii{Who is more vile than he who slanders God of falsehood, or says: ``Revelation came to me," when no such revelation came to him; or one who claims: ``I can reveal the like of what has been sent down by God?" If you could see the evil creatures in the agony of death with the angels thrusting forward their hands (saying): ``Yield up your souls: This day you will suffer ignominious punishment for uttering lies about God and rejecting His signs with arrogance."\qt@no{(93)}}
\qt@newcmd\qurantrans@en@dccclxxxiii{``You have come before Us all alone," (God will say), ``as when you were created first, leaving behind all that We had bestowed on you. We do not see your intercessors with you who, you imagined, had partnership with you. Shattered lie your ties with them now, and gone are the claims you made."\qt@no{(94)}}
\qt@newcmd\qurantrans@en@dccclxxxiv{Indeed it is God who splits up the seed and the kernel, and brings forth the living from the dead, the dead from the living. This is God: So whither do you stray?\qt@no{(95)}}
\qt@newcmd\qurantrans@en@dccclxxxv{He ushers in the dawn, and made the night for rest, the sun and moon a computation. Such is the measure appointed by Him, the omnipotent and all-wise.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@dccclxxxvi{It is He who made the stars by which you reckon your way through the darkness of the desert and the sea. Distinct have We made Our signs for those who recognise.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@dccclxxxvii{It is He who produced you from a single cell, and appointed a place of sojourning, (the womb of the mother), and a place of depositing, (the grave). How clear have We made Our signs for those who understand.\qt@no{(98)}}
\qt@newcmd\qurantrans@en@dccclxxxviii{It is He who sends down water from the skies, and brings out of it everything that grows, the green foliage, the grain lying close, the date palm trees with clusters of dates, and the gardens of grapes, and of olives and pomegranates, so similar yet so unlike. Look at the fruits, how they appear on the trees, and they ripen. In all these are signs for those who believe.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@dccclxxxix{Yet they ascribe to jinns a partnership with God, although He created them; and they ascribe to Him sons and daughters, without possessing any knowledge. All praise be to Him. He is much too exalted for things they associate (with Him).\qt@no{(100)}}
\qt@newcmd\qurantrans@en@dcccxc{Creator of the heavens and the earth from nothingness, how could He have a son when He has no mate? He created all things, and has knowledge of all things.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@dcccxci{This is God, your Lord; there is no god but He, the creator of all things. So pay homage to Him, for He takes care of everything.\qt@no{(102)}}
\qt@newcmd\qurantrans@en@dcccxcii{No eyes can penetrate Him, but He penetrates all eyes, and He knows all the mysteries, for He is all-knowing.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@dcccxciii{To you have come signs from your Lord, (and the light of understanding). So any one who sees (and understands) does so for himself, and any one who turns blind shall suffer the consequences alone. (Say:) ``I am not a guardian over you (to make you understand)."\qt@no{(104)}}
\qt@newcmd\qurantrans@en@dcccxciv{Thus in varied ways We explain Our signs so that they may say: ``You have been instructed," and that We might make it clear to those who understand.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@dcccxcv{So follow what is sent down to you by your Lord, for homage is due to no one but God, and turn away from idolaters.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@dcccxcvi{Had He willed they would not have been idolaters. We have not appointed you their guardian, nor are you their pleader.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@dcccxcvii{Do not revile those who invoke others apart from God, lest they begin to revile God out of malice and ignorance. We have made attractive their deeds to every people. They have to go back to their Lord, when He will tell them what they used to do.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@dcccxcviii{They solemnly swear by God: ``If a sign comes to us we shall certainly believe in it." Tell them: ``The signs are with God." Yet for all you know they will not believe if the signs came to them.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@dcccxcix{We shall turn their hearts and their eyes, for they did not believe them at the very first, and leave them to wander perplexed in bewilderment.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@cm{Even if We send down the angels to them, and the dead should speak to them, and We gather all things before their eyes, they will not believe, unless God should will, for most of them are ignorant.\qt@no{(111)}}
\qt@newcmd\qurantrans@en@cmi{That is how We have made for each apostle opponents, the satans among men and jinns, who inspire one another with deceitful talk. But if your Lord had willed they would not have done so. Pay no attention to them and to what they fabricate.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@cmii{Let those who do not believe in the life to come, listen to it and be pleased with it, and let them gain what they may gain.\qt@no{(113)}}
\qt@newcmd\qurantrans@en@cmiii{(Say): ``Then should I seek (the source of) law elsewhere than God, when it is He who has revealed this Book to you, which distinctly explains (everything)?" Those to whom We have given the Book know it has been sent by your Lord in truth. So be not a sceptic.\qt@no{(114)}}
\qt@newcmd\qurantrans@en@cmiv{Perfected are the laws of your Lord in truth and justice, and there is no changing His laws. He is all-hearing and all-knowing.\qt@no{(115)}}
\qt@newcmd\qurantrans@en@cmv{If you follow the majority of people on the earth, they will lead you astray from the path of God, for they follow only conjecture and surmise.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@cmvi{Your Lord surely knows those who have strayed from his path, and knows those who are rightly guided.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@cmvii{Eat only that over which the name of God has been pronounced, if you truly believe in His commands.\qt@no{(118)}}
\qt@newcmd\qurantrans@en@cmviii{And why should you not eat of that over which the name of God has been pronounced, when He has made it distinctly clear what is forbidden, unless you are constrained to do so. Surely many (men) mislead others into following their vain desires through lack of knowledge. Your Lord certainly knows the transgressors.\qt@no{(119)}}
\qt@newcmd\qurantrans@en@cmix{Discard both the visible and invisible sin. For those who sin will be punished for what they have done.\qt@no{(120)}}
\qt@newcmd\qurantrans@en@cmx{Do not eat of that over which God's name has not been pronounced, for that would amount to exceeding the limits of law. Certainly the devils inspire their proteges to dispute with you: If you obey them, you will surely become an idolater.\qt@no{(121)}}
\qt@newcmd\qurantrans@en@cmxi{Can he who was lifeless, to whom We gave life, and gave him a light in whose glow he walks among men, be like him who is used to darkness from which he can never emerge? Thus have been their doings made attractive to unbelievers.\qt@no{(122)}}
\qt@newcmd\qurantrans@en@cmxii{And thus have We placed in every city the greatest of the sinners to contrive and deceive; yet they contrive against no one but themselves even though they do not know.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@cmxiii{Every time a sign comes to them they say: ``We shall never believe till what God's apostles had been given comes to us." God knows best where to direct His messages. A degradation will befall the sinners and chastisement from God for deceiving.\qt@no{(124)}}
\qt@newcmd\qurantrans@en@cmxiv{Thus God guides whomsoever He please by opening wide his breast to surrender; and Straitens the breasts of those He allows to go astray, (who feel suffocated) as if they were ascending the skies. Thus will God punish those who do not believe.\qt@no{(125)}}
\qt@newcmd\qurantrans@en@cmxv{This is the straight path of your Lord. Distinct have We made Our signs for those who reflect.\qt@no{(126)}}
\qt@newcmd\qurantrans@en@cmxvi{For them is an abode of peace with their Lord. He will be their defender as reward for what they did.\qt@no{(127)}}
\qt@newcmd\qurantrans@en@cmxvii{On the day He will gather them together, (He will say:) ``O you assembly of jinns, you made great use of men." But their proteges among men will say: ``O our Lord, we lived a life of mutual gain, but have now reached the term You ordained for us." ``Your abode is Hell," He will say, ``where you will dwell for ever, unless God please otherwise." Verily your Lord is wise and all-knowing.\qt@no{(128)}}
\qt@newcmd\qurantrans@en@cmxviii{Thus do We place some sinners over others as requital for their deeds.\qt@no{(129)}}
\qt@newcmd\qurantrans@en@cmxix{O you assembly of jinns and men, did not apostles come to you from among you, communicating My signs to you, bringing warnings of this your day (of Doom)?" They will answer: ``We bear witness to our sins." They were surely deluded by the life of the world, and bore witness against themselves because they were unbelievers.\qt@no{(130)}}
\qt@newcmd\qurantrans@en@cmxx{And this (so that it may be clear) that your Lord does not destroy towns and cities arbitrarily while the citizens remain unaware.\qt@no{(131)}}
\qt@newcmd\qurantrans@en@cmxxi{Every one has his place according to his deeds, for your Lord is not negligent of what you do.\qt@no{(132)}}
\qt@newcmd\qurantrans@en@cmxxii{Your Lord is all-sufficient and full of benevolence. He can take you away if He please, and make whom He will succeed you, as He had raised you from the progeny of others.\qt@no{(133)}}
\qt@newcmd\qurantrans@en@cmxxiii{The promise that was made to you is bound to be fulfilled. It is not in your power to defeat it.\qt@no{(134)}}
\qt@newcmd\qurantrans@en@cmxxiv{Tell them: ``O my people, go on acting on your part, I am acting on mine. You will soon know whose is the guerdon of life to come." The wicked will not succeed.\qt@no{(135)}}
\qt@newcmd\qurantrans@en@cmxxv{They allocate a share from God's own created fields and cattle to God, and they say: ``This is God's" -- or so they think -- ``and that, of the compeers of God," so that what belongs to the compeers does not reach God, but that which is God's may reach the compeers (set up by them). How bad is the judgement that they make!\qt@no{(136)}}
\qt@newcmd\qurantrans@en@cmxxvi{In the same way have their companions shown many unbelievers the killing of their children as desirable in order to ruin them and falsify their faith. If God had so willed they would never have done so. Leave them to their falsehoods.\qt@no{(137)}}
\qt@newcmd\qurantrans@en@cmxxvii{They also say: ``These cattle and these crops are consecrated. None may eat of them other than those we permit," -- so they assert. ``And the use of these cattle is forbidden for carrying burden." They do not pronounce the name of God on certain animals, inventing lies against Him. He will punish them for what they fabricate.\qt@no{(138)}}
\qt@newcmd\qurantrans@en@cmxxviii{And they say: ``Whatever is in the wombs of these cattle is only meant for men and forbidden our women; but in case it should be still-born both could eat it." God will punish them for what they assert. He is all-wise and all-knowing.\qt@no{(139)}}
\qt@newcmd\qurantrans@en@cmxxix{They will surely perish who kill their offspring in ignorance foolhardily, and forbid the food that God has given them by fabricating lies against God. Misguided are they surely, and will never come to guidance.\qt@no{(140)}}
\qt@newcmd\qurantrans@en@cmxxx{It is He who grew the gardens, trellised and bowered, and palm trees and land sown with corn and many other seeds, and olives and pomegranates, alike and yet unlike. So eat of their fruit when they are in fruit, and give on the day of harvesting His due, and do not be extravagant, for God does not love those who are prodigal.\qt@no{(141)}}
\qt@newcmd\qurantrans@en@cmxxxi{He has created beasts of burden and cattle for slaughter. So eat of what God has given you for food, and do not walk in the footsteps of Satan who is surely your declared enemy.\qt@no{(142)}}
\qt@newcmd\qurantrans@en@cmxxxii{There are eight pairs, two of the species of sheep and two of goats. Ask them which has He forbidden, the two males or the two females, or what the females carry in their wombs? Produce the sanction if you are truthful.\qt@no{(143)}}
\qt@newcmd\qurantrans@en@cmxxxiii{And there are two of camels and two of oxen. Ask them: ``Which has He forbidden, the two males or the two females, or what the females carry in their wombs?" Were you present at the time God issued this command?" Who then could be more wicked than he who fabricates a lie and ascribes it to God to mislead men, without any knowledge? God does not guide the miscreants.\qt@no{(144)}}
\qt@newcmd\qurantrans@en@cmxxxiv{You tell them: ``In all the commands revealed to me I find nothing which men have been forbidden to eat except carrion and running blood and flesh of the swine for it is unclean, or meat consecrated in the name of some other than God, which is profane. But if one is constrained to eat of these without craving or reverting to it, then surely your Lord is forgiving and kind."\qt@no{(145)}}
\qt@newcmd\qurantrans@en@cmxxxv{We made unlawful for the Jews all animals with claws or nails, and the fat of the oxen and sheep, except that on their backs or their intestines, or which remains attached to their bones. This was the punishment for their insubordination; and what We say is true.\qt@no{(146)}}
\qt@newcmd\qurantrans@en@cmxxxvi{If they call you a liar, tell them infinite is the mercy of your Lord; but His vengeance will not be turned back from the sinners.\qt@no{(147)}}
\qt@newcmd\qurantrans@en@cmxxxvii{But the idolaters say: ``If God had so willed we would not have associated (others with Him), nor would have our fathers, nor would we have forbidden any thing." So had others denied before them, and had to taste Our punishment in the end. Ask them: ``Have you any knowledge? Then display it. You follow nothing but conjecture, and are nothing but liars."\qt@no{(148)}}
\qt@newcmd\qurantrans@en@cmxxxviii{Say: ``To God belongs the consummate argument. Had He willed He would surely have guided all of you aright."\qt@no{(149)}}
\qt@newcmd\qurantrans@en@cmxxxix{Tell them: ``Bring your witnesses to testify that God has forbidden this (and this)." Then even if they testify, you should not testify with them; and do not follow the wishes of those who deny Our signs and believe not in the Hereafter, and make others the equal of their Lord.\qt@no{(150)}}
\qt@newcmd\qurantrans@en@cmxl{Tell them: ``Come, I will read out what your Lord has made binding on you: That you make none the equal of God, and be good to your parents, and do not abandon your children out of poverty, for We give you food and We shall provide for them; and avoid what is shameful, whether open or hidden, and do not take a life which God has forbidden, unless for some just cause. These things has God enjoined on you. Haply you may understand.\qt@no{(151)}}
\qt@newcmd\qurantrans@en@cmxli{Do not spend the belongings of the orphans but for their betterment, until they come of age; and give in full measure, and weigh justly on the balance. God does not burden a soul beyond capacity. When you say a thing, let it be just, even though the matter relate to a relative of yours, and fulfil a promise made to God. These are the things that He has enjoined that you may take heed.\qt@no{(152)}}
\qt@newcmd\qurantrans@en@cmxlii{(He has further commanded:) 'This is My straight path, so walk along it, and do not follow other ways, lest you should turn away from the right one.' All this has He commanded. You may perhaps take heed for yourselves."\qt@no{(153)}}
\qt@newcmd\qurantrans@en@cmxliii{To that end We gave the Book to Moses, a perfect law, distinctly explaining all things, and a guidance and grace, so that they should believe in the meeting with their Lord.\qt@no{(154)}}
\qt@newcmd\qurantrans@en@cmxliv{Blessed is this Book We have revealed; so follow it and preserve yourself from evil that you may qualify for grace,\qt@no{(155)}}
\qt@newcmd\qurantrans@en@cmxlv{Lest you say: ``The Book that was sent before was meant only for two groups; we were not aware of their teachings;"\qt@no{(156)}}
\qt@newcmd\qurantrans@en@cmxlvi{Or that: ``Had the Book been sent down to us we would surely have been guided better than they." So you have now received from your Lord a clear proof and a guidance and grace. Then who is more wicked than he who denies the signs of God and turns away from them? We shall punish those severely who turn away: A requital indeed for having turned aside.\qt@no{(157)}}
\qt@newcmd\qurantrans@en@cmxlvii{What are the people waiting for? For the angels to come down, or your Lord to appear, or some signs from your Lord? The day when certain signs appear from your Lord, the embracing of faith shall not be of any avail to one who did not come to belief at first, or who did not perform good deeds by virtue of his faith. Tell them: ``Wait on, we are waiting too (for the good and evil to become distinct)."\qt@no{(158)}}
\qt@newcmd\qurantrans@en@cmxlviii{As for those who have created schisms in their order, and formed different sects, you have no concern with them. Their affair is with God. He will tell them the truth of what they were doing.\qt@no{(159)}}
\qt@newcmd\qurantrans@en@cmxlix{He who does a good deed will receive ten times its worth; and he who does evil will be requited to an equal degree; and no one will be wronged.\qt@no{(160)}}
\qt@newcmd\qurantrans@en@cml{Tell them: ``My Lord has directed me to a path that is straight, a supreme law, the creed of Abraham the upright who was not an idolater."\qt@no{(161)}}
\qt@newcmd\qurantrans@en@cmli{Tell them: ``My service and sacrifice, my life and my death, are all of them for God, the creator and Lord of all the worlds.\qt@no{(162)}}
\qt@newcmd\qurantrans@en@cmlii{No equal has He, I am commanded (to declare), and that I am the first to submit."\qt@no{(163)}}
\qt@newcmd\qurantrans@en@cmliii{Say: ``Shall I search for another lord apart from God when He is the only Lord of all and everything?" Each soul earns (what it earns) for itself, and no man shall bear another's burden. You have to go back to your Lord in the end when He will tell you about the things you disputed.\qt@no{(164)}}
\qt@newcmd\qurantrans@en@cmliv{It is He who made you trustees on the earth, and exalted some in rank over others in order to try you by what He has given you. Indeed your Lord's retribution is swift, yet He is forgiving and kind.\qt@no{(165)}}
\qt@newcmd\qurantrans@en@cmlv{\basmalahen Alif Lam Mim Sad.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@cmlvi{This Book has been sent down to you; so do not hesitate to warn (the unbelievers) through it, and remind the faithful.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@cmlvii{Follow what has been revealed to you by your Lord, and do not follow any other lord apart from Him. Yet little do you care to remember.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@cmlviii{Many a habitation have We laid low before: Our retribution came upon them in the night or in the midst of siesta at noon.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@cmlix{And when Our punishment overtook them they had nothing to say except crying out: ``We have indeed been sinners."\qt@no{(5)}}
\qt@newcmd\qurantrans@en@cmlx{(On the Day of Reckoning) We shall question the people to whom We had sent Our apostles, (if they followed their teachings), and will question the apostles.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@cmlxi{We shall recount (their deeds) to them with knowledge, for We were never absent (and saw all they did).\qt@no{(7)}}
\qt@newcmd\qurantrans@en@cmlxii{And the weighing will be just on that Day. Then those whose (deeds) are heavier in the balance will find fulfilment,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@cmlxiii{And those whose (deeds) are lighter in the scale shall perish for violating Our signs.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@cmlxiv{We settled you on the earth, and provided means of livelihood for you in it; but little are the thanks you give.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@cmlxv{Verily We created you and gave you form and shape, and ordered the angels to bow before Adam in homage; and they all bowed but Iblis who was not among those who bowed.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@cmlxvi{``What prevented you" (said God), ``from bowing (before Adam) at My bidding?" ``I am better than him," said he. ``You created me from fire, and him from clay."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@cmlxvii{So God said: ``Descend. You have no right to be insolent here. Go, and away; you are one of the damned."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@cmlxviii{``Grant me respite," said he, ``till the raising of the dead."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@cmlxix{And God said: ``You have the respite."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@cmlxx{``Since You led me into error," said Iblis, ``I shall lie in wait for them along Your straight path.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@cmlxxi{And I shall come upon them from the front and behind, right and left; and You will not find among them many who would give thanks."\qt@no{(17)}}
\qt@newcmd\qurantrans@en@cmlxxii{``Begone," said (God), ``contemptible and rejected! As for those who follow you, I shall fill up Hell with all of you.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@cmlxxiii{And you, O Adam, and your spouse, live in the Garden and eat your fill wheresoever you like, but do not approach this tree, or you will become iniquitous."\qt@no{(19)}}
\qt@newcmd\qurantrans@en@cmlxxiv{But Satan suggested (evil) to them, in order to reveal their hidden parts of which they were not aware (till then), and said: ``Your Lord has forbidden you (to go near) this tree that you may not become angels or immortal."\qt@no{(20)}}
\qt@newcmd\qurantrans@en@cmlxxv{Then he said to them on oath: ``I am your sincere friend;"\qt@no{(21)}}
\qt@newcmd\qurantrans@en@cmlxxvi{And led them (to the tree) by deceit. When they tasted (the fruit) of the tree their disgrace became exposed to them; and they patched the leaves of the Garden to hide it. And the Lord said to them: ``Did I not forbid you this tree? And I told you that Satan was your open enemy.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@cmlxxvii{They said: ``O our Lord, we have wronged ourselves. If You do not forgive us and have mercy upon us, we shall certainly be lost."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@cmlxxviii{``Go," said God, ``one the antagonist of the other, and live on the earth for a time ordained, and fend for yourselves.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@cmlxxix{You will live there, and there will you die," He said, ``and be raised from there (On the Day of Doom)."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@cmlxxx{O sons of Adam, We have revealed to you a dress that would both hide your nakedness and be an adornment, but the raiment of piety is best. This is one of the tokens of God: You may haply reflect.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@cmlxxxi{O sons of Adam, let not Satan beguile you as he did your parents out of Eden, and made them disrobe to expose their disgrace to them. For he and his host can see you from where you cannot see them. We have made the devils the friends of those who do not believe,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@cmlxxxii{Who say when they commit shameful acts: ``Our ancestors used to do so, and God has enjoined us to do the same." Say to them: ``God never enjoins a conduct that is shameful. You impute such lies to God as you do not know."\qt@no{(28)}}
\qt@newcmd\qurantrans@en@cmlxxxiii{Tell them: ``My Lord has enjoined piety, devotion in all acts of worship, and calling upon Him with exclusive obedience. For you will be reverted back to what you were (when) created first."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@cmlxxxiv{A Section (among them) were guided, a section were bound to go astray, (for) instead of God they took the devils as their friends; yet they think they are on the right path.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@cmlxxxv{O sons of Adam, attire yourselves at every time of worship; eat and drink, but do not be wasteful, for God does not like the prodigals.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@cmlxxxvi{Ask them: ``Who forbids you attire that God has given to His creatures, and the good things that He has provided?" Tell them: ``They are (meant) for believers in the world, and will be theirs on the Day of Judgement." That is how We explain Our signs to those who know.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@cmlxxxvii{Tell them: ``My Lord has forbidden repugnant acts, whether open or disguised, sin and unjust oppression, associating others with God, of which He has sent down no authority, and saying things of God of which you have no knowledge."\qt@no{(33)}}
\qt@newcmd\qurantrans@en@cmlxxxviii{A term is fixed for every people; and when their appointed time is come there will neither be a moment's delay nor haste.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@cmlxxxix{O sons of Adam, when apostles come to you from among you, who convey My messages, then those who take heed and amend will have neither fear nor regret.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@cmxc{But those who deny Our signs and disdain them, shall belong to Hell, where they will abide for ever.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@cmxci{Who could be more wicked than he who imputes lies to God or denies His revelations? Such as these will receive what is declared in the Book, and when Our angels come to draw out their souls and ask: ``Where are they you worshipped other than God?" They will answer: ``They have left us and fled;" and bear witness against themselves for being infidels.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@cmxcii{``Enter then the Fire," will God say, ``with the past generations of jinns and men." On entering each batch will condemn the other; and when all of them shall have entered one after the other, the last to come will say of those who had come before them: ``O our Lord, they are the ones who led us astray; so give them double chastisement in the Fire." He will answer: ``For all it will be double; but this you do not know."\qt@no{(38)}}
\qt@newcmd\qurantrans@en@cmxciii{Then the former will say to the latter: ``You have no privilege over us. So taste the punishment for what you had done."\qt@no{(39)}}
\qt@newcmd\qurantrans@en@cmxciv{Verily for those who deny Our signs and turn away in haughtiness from them, the gates of heaven shall not be opened, nor will they enter Paradise, not till the camel passes through the needle's eye. That is how We requite the transgressors:\qt@no{(40)}}
\qt@newcmd\qurantrans@en@cmxcv{For them is a flooring of Hell and a covering (of fire). That is how We requite the iniquitous.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@cmxcvi{As for those who believe and do good, We never burden a soul beyond capacity. They are men of Paradise where they will abide for ever.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@cmxcvii{Whatever the rancour they may have in their hearts We shall (cleanse and) remove. Streams of running water shall ripple at their feet, and they will say: ``We are grateful to God for guiding us here. Never would we have been guided if God had not shown us the way. The apostles of our Lord had indeed brought the truth." And the cry shall resound: ``This is Paradise you have inherited as meed for your deeds."\qt@no{(43)}}
\qt@newcmd\qurantrans@en@cmxcviii{And the inmates of Paradise will call to the residents of Hell: ``We have found that the promise made to us by our Lord was true. Have you also found the promise of your Lord to be true?" They will answer: ``Yes (it is so)." Then a crier will call from among them: ``The curse of God be on the vile,\qt@no{(44)}}
\qt@newcmd\qurantrans@en@cmxcix{``Who obstruct those who follow the path of God and try to make it oblique, who do not believe in the life to come."\qt@no{(45)}}
\qt@newcmd\qurantrans@en@m{There will be a veil between them, and on the wall will be the men (of al-A'raf) who will recognise everyone by their distinguishing marks, and will call to the inmates of Paradise: ``Peace on you," without having entered it themselves though hoping to do so.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mi{When their eyes fall on the inmates of Hell they will say: ``O Lord, do not place us in the crowd of the vile."\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mii{Recognising them by their marks the men of al-A'raf will call (to the inmates of Hell): ``Of what use was your amassing (of wealth) of which you were proud?"\qt@no{(48)}}
\qt@newcmd\qurantrans@en@miii{(Then pointing to the inmates of Paradise, they will say): ``Are they not those of whom you had sworn and said: 'God will not have mercy on them?' (And yet they have been told,) 'Enter Paradise where you will have no fear or regret.'"\qt@no{(49)}}
\qt@newcmd\qurantrans@en@miv{Those in Hell will call to the inmates of Paradise: ``Pour a little water over us, or give us a little of what God has given you." They will answer: ``God has verily forbidden these to those who denied the truth.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mv{``Who made a sport and frolic of their faith and were lured by the life of the world." As they had forgotten the meeting of this Day so shall We neglect them today for having rejected Our signs.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mvi{Indeed We had brought to them a Book distinct, replete with knowledge, and guidance and grace for men who believe.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mvii{Are they waiting for the exposition of what it speaks of? The day that (Reality) is unravelled, the people who had lost sight of it will say: ``The apostles of our Lord had indeed brought the truth. Do we have any one to intercede for us? If only we could go back to the world, we would act otherwise." Indeed they have caused themselves harm, and the lies they concocted did not help.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mviii{Surely your Lord is God who created the heavens and the earth in six spans of time, then assumed all power. He covers up the day with night which comes chasing it fast; and the sun and moon and the stars are subject to His command. It is His to create and enjoin. Blessed be God, the Lord of all the worlds.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mix{Pray to your Lord in humility and unseen. He does not love the iniquitous.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mx{And do not corrupt the land after it has been reformed; and pray to Him in awe and expectation. The blessing of God is at hand for those who do good.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mxi{Indeed it is He who sends the winds as harbingers of auspicious news announcing His beneficence, bringing heavy clouds which We drive towards a region lying dead, and send down rain, and raise all kinds of fruits. So shall We raise the dead that you may think and reflect.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mxii{The soil that is good produces (rich) crops by the will of its Lord, and that which is had yields only what is poor. So do We explain Our signs in different ways to people who give thanks.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mxiii{We sent Noah to his people, and he said: ``O people worship God; you have no other god but He; for I fear the retribution of the great Day may fall on you."\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mxiv{The elders of his people replied: ``We see clearly that you have gone astray."\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mxv{``I have not gone astray, O my people," he said, ``but have been sent by my Lord, the creator of all the worlds.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mxvi{I bring to you the messages of my Lord, and give you sincere advice, for I know from God what you do not know.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mxvii{Do you wonder that a warning has come to you from your Lord through a man who is one of you, and warns you to take heed for yourselves and fear God? You might be treated with mercy."\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mxviii{But they called him a liar, and We saved him and those with him in the Ark, and drowned the others who rejected Our signs, for they were a people purblind.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mxix{And We sent Hud, their brother, to the people of 'Ad. He said: ``O you people, worship God, for you have no other god but He. Will you not take heed for yourselves?"\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mxx{The chiefs of his people who were infidels replied: ``We find you full of folly, and a liar to boot."\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mxxi{``I am not a fool, O people," he answered, ``but have been sent by the Lord of all the worlds.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mxxii{I bring to you the messages of my Lord. I am your sincere friend.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mxxiii{Do you wonder that a warning has come to you from your Lord through a man who is one of you and warns you? Remember, He made you leaders after the people of Noah, and gave you a greater increase in your stature. So think of the favours of God; you may haply be blessed."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mxxiv{They answered: ``Have you come to say to us that we should worship only one God, abandoning those our ancestors had worshipped? If so, bring on us what you threaten us with, if what you say is true."\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mxxv{He replied: ``You have already been beset with punishment and the wrath of God. Why dispute with me about names invented by you and your ancestors for which no sanction was sent down? So wait (for what is to come), I am waiting with you."\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mxxvi{Then We saved him and those on his side by Our grace, and destroyed to the very last those who rejected Our signs and denied the truth.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mxxvii{We sent to Thamud their brother Saleh. ``O you people," said he, ``worship God, for you have no other god but He. Clear proof has come to you already from your Lord, and this she-camel of God is the token for you. Leave her free to graze upon God's earth, and do not molest her lest a grievous punishment should befall you.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mxxviii{Remember, how you were made leaders after the people of 'Ad, and were settled on the land so that you could construct on the plains palaces, and carve dwellings out of mountains. So think of the favours of God, and do not act with corruption in the land."\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mxxix{The chiefs among the people who were arrogant towards the weaker ones among them who believed, asked: ``Do you really know that Saleh has been sent by his Lord?" They said: ``Indeed we believe in the message he has brought."\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mxxx{Those who were arrogant answered: ``We do not believe in what you believe."\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mxxxi{Then they hamstrung the she-camel and rebelled against the command of their Lord, and said: ``Bring, O Saleh, on us the affliction you promise, if you are one of the sent ones."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mxxxii{Then they were seized by an earthquake, and lay overturned on the ground in their homes in the morning.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mxxxiii{Saleh turned away from them and said: ``O my people, I conveyed to you the message of my Lord and warned you; but you do not like those who wish you well."\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mxxxiv{And We sent Lot, who said to his people: ``Why do you commit this lecherous act which none in the world has committed before?\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mxxxv{In preference to women you satisfy your lust with men. Indeed you are a people who are guilty of excess."\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mxxxvi{His people made no answer, and only said: ``Drive them out of the city. They profess to be pure."\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mxxxvii{But We saved him and his family, except for his wife who was one of those who stayed behind.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mxxxviii{And We rained down on them a shower (of Stones). So witness the end of sinners!\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mxxxix{Remember, We sent to Midian their brother Shu'aib. ``O you people," he said, ``worship God, for you have no other god but He. Clear proof has come to you from your Lord; so give in full measure and full weight; do not keep back from people what is theirs, and do not corrupt the land after it has been reformed. This is best for you if you believe.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mxl{Do not lie in ambush to intimidate and divert from the path of God those who believe in Him, nor seek obliquity in it. Remember the day when you were few and He increased your numbers. So consider the fate of those who were evil.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mxli{If some of you believe what has been sent through me, and some of you do not, have patience until God decide between us, for He is the best of all judges."\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mxlii{The arrogant leaders of the people replied: ``We shall drive you away from our land, O Shu'aib, and those who are with you, unless you come back to your faith." But he remarked: ``Even if we are disgusted with it?\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mxliii{We shall only be guilty of blaspheming God if we accept your way after the people of Noah, and gave you a greater increase in your stature. So think of the favours of God; you may haply be blessed."\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mxliv{The chiefs among his people who did not believe said (to them): ``If you follow Shu'aib and his way you will surely be ruined."\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mxlv{Then they were seized by an earthquake, and lay overturned on the ground in their homes in the morning.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mxlvi{They who called Shu'aib a liar (disappeared) as though they had never existed; and those who called Shu'aib a liar were the ones who were ruined!\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mxlvii{So Shu'aib turned away from them and said: ``O people, I conveyed to you the message of my Lord, and warned you. (But you paid no heed). How can I grieve for a people who do not believe?"\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mxlviii{There is not a region to which We sent a prophet and did not inflict upon its people adversity and hardship so that they may submit.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mxlix{But when We changed hardship to ease, and they rose and prospered, (they forgot Our favours) and said: ``Our ancestors had also known suffering and joy." So We caught them unawares.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@ml{But if the people of these regions had believed and feared God, We would surely have showered on them blessings of the heavens and the earth; but they only denied, and We punished them for their deeds.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mli{Are the people of the region so secure that they lie asleep unaware as Our punishment overtakes them?\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mlii{Or, are the people of the towns so unafraid that (even when) Our retribution comes upon them in the hours of the morning they remain engrossed in sport and play?\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mliii{Can they remain secure against the plan of God? Only they feel secure against the plan of God who are certain of being ruined.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mliv{Do not the people who inherited the earth from the (earlier) inhabitants perceive that We could afflict them too for their sins if We pleased, and put seals on their hearts that they may not hear (the voice of truth)?\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mlv{These were the (earlier) habitations whose accounts We have given to you. Their apostles came with clear proofs, but they did not believe what they once denied. That is how God seals the hearts of those who do not believe.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mlvi{We did not find many of them faithful to their promises, and found many of them disobedient.\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mlvii{So We sent Moses with miracles after (these apostles) to the Pharaoh and his nobles, but they behaved with them high-handedly. See then the end of the authors of evil.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mlviii{Moses said: ``O Pharaoh, I have been sent by the Lord of all the worlds;\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mlix{``I am duty bound to speak nothing of God but the truth I have brought from your Lord a clear sign; so let the people of Israel depart with me."\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mlx{He said: ``If you have brought a sign then display it, if what you say is true."\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mlxi{At this Moses threw down his staff, and lo, it became a live serpent.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mlxii{And he drew forth his hand, and behold, it looked white to those who beheld it.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mlxiii{The nobles of Pharaoh said: ``He surely is a clever magician.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mlxiv{``He wishes to drive you away from the land. So what do you advise?"\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mlxv{They said: ``Put him and his brother off (awhile) and send out heralds to the cities\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mlxvi{``To bring all the wise magicians to you."\qt@no{(112)}}
\qt@newcmd\qurantrans@en@mlxvii{The magicians came to the Pharaoh and said: ``Is there reward for us if we succeed?"\qt@no{(113)}}
\qt@newcmd\qurantrans@en@mlxviii{``Yes," said he, ``you will be among the honoured."\qt@no{(114)}}
\qt@newcmd\qurantrans@en@mlxix{So they said: ``O Moses, you may cast your spell first, or we shall cast ours."\qt@no{(115)}}
\qt@newcmd\qurantrans@en@mlxx{``You cast it first," answered Moses. When they cast their spell, they bewitched the eyes of the people and petrified them by conjuring up a great charm.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@mlxxi{We said to Moses: ``Throw down your staff;" and it swallowed up their conjurations in no time.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@mlxxii{Thus the truth was upheld, and the falsehood that they practised was exposed.\qt@no{(118)}}
\qt@newcmd\qurantrans@en@mlxxiii{Thus there and then they were vanquished and overthrown, humiliated.\qt@no{(119)}}
\qt@newcmd\qurantrans@en@mlxxiv{The sorcerers fell to the ground in homage,\qt@no{(120)}}
\qt@newcmd\qurantrans@en@mlxxv{And said: ``We have come to believe in the Lord of all the worlds,\qt@no{(121)}}
\qt@newcmd\qurantrans@en@mlxxvi{``The Lord of Moses and Aaron."\qt@no{(122)}}
\qt@newcmd\qurantrans@en@mlxxvii{But Pharaoh said: ``You have come to accept belief in Him without my permission! This surely is a plot you have hatched to expel the people from the land. You will soon come to know.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@mlxxviii{``I will have your hands and feet on alternate sides cut off, and have you all crucified."\qt@no{(124)}}
\qt@newcmd\qurantrans@en@mlxxix{They answered: ``We have (in any case) to go back to our Lord.\qt@no{(125)}}
\qt@newcmd\qurantrans@en@mlxxx{``The only reason you have to hate us is that we believed in the signs of our Lord as they came to us. O our Lord, give us sufficient endurance that we may die submitting (to You)."\qt@no{(126)}}
\qt@newcmd\qurantrans@en@mlxxxi{And the leaders of Pharaoh's people said to him: ``Would you allow Moses and his people to create disorder in the land and discard you and your gods?" He replied: ``We shall now slay their sons and spare their women, and subdue them."\qt@no{(127)}}
\qt@newcmd\qurantrans@en@mlxxxii{Said Moses to his people: ``Invoke the help of God and be firm. The earth belongs to God: He can make whom He wills among His creatures inherit it. The future is theirs who take heed for themselves."\qt@no{(128)}}
\qt@newcmd\qurantrans@en@mlxxxiii{They said: ``We were oppressed before you came, and have been since you have come to us." He answered: ``It may well be that soon God may destroy your enemy and make you inherit the land, and then see how you behave."\qt@no{(129)}}
\qt@newcmd\qurantrans@en@mlxxxiv{We afflicted the people of Pharaoh with famine and dearth of everything that they might take heed.\qt@no{(130)}}
\qt@newcmd\qurantrans@en@mlxxxv{Yet when good came their way they said: ``It is our due;" but when misfortune befell them they put the omen down to Moses and those who were with him. But surely the omen was with God, yet most of them did not understand.\qt@no{(131)}}
\qt@newcmd\qurantrans@en@mlxxxvi{They said: ``Whatsoever the sign you have brought to deceive us, we shall not believe in you."\qt@no{(132)}}
\qt@newcmd\qurantrans@en@mlxxxvii{So We let loose on them floods and locusts, and vermin, frogs and blood -- how many different signs. But they still remained arrogant, for they were a people full of sin.\qt@no{(133)}}
\qt@newcmd\qurantrans@en@mlxxxviii{Yet when punishment overtook them, they said: ``O Moses, invoke your Lord for us as you have been enjoined. If the torment is removed, we shall certainly believe in you and let the people of Israel go with you."\qt@no{(134)}}
\qt@newcmd\qurantrans@en@mlxxxix{But no sooner was the punishment withdrawn for a time to enable them to make good their promise than they broke it.\qt@no{(135)}}
\qt@newcmd\qurantrans@en@mxc{So We took vengeance on them, and drowned them in the sea for rejecting Our signs and not heeding them.\qt@no{(136)}}
\qt@newcmd\qurantrans@en@mxci{We then made the people who were weak (and oppressed) successors of the land to the East and the West which We had blessed. Thus the fair promise of your Lord to the children of Israel was fulfilled, for they were patient in adversity; and whatsoever the Pharaoh and his people had fashioned, and the structures they had raised, were destroyed.\qt@no{(137)}}
\qt@newcmd\qurantrans@en@mxcii{When We brought the children of Israel across the sea, and they came to a people who were devoted to their idols, they said: ``O Moses, make us also a god like theirs." ``You are ignorant," he replied.\qt@no{(138)}}
\qt@newcmd\qurantrans@en@mxciii{``These people and their ways will surely be destroyed, for false is what they practise.\qt@no{(139)}}
\qt@newcmd\qurantrans@en@mxciv{``Do you want me to seek for you," he said, ``a god other than God, when He has exalted you over all the nations of the world?\qt@no{(140)}}
\qt@newcmd\qurantrans@en@mxcv{``Remember (the day) when He saved you from the people of Pharaoh who oppressed and afflicted you, and slew your sons and spared your women. In this was a great trial from your Lord."\qt@no{(141)}}
\qt@newcmd\qurantrans@en@mxcvi{We made an appointment of thirty nights with Moses (On Mount Sinai) to which We added ten more; so the term set by the Lord was completed in forty nights. Moses said to Aaron, his brother: ``Deputise for me among my people. Dispose rightly, and do not follow the way of the authors of evil."\qt@no{(142)}}
\qt@newcmd\qurantrans@en@mxcvii{When Moses arrived at the appointed time and his Lord spoke to him, he said: ``O Lord, reveal Yourself to me that I may behold You." ``You cannot behold Me," He said. ``But look at the mountain: If it remains firm in its place you may then behold Me." But when his Lord appeared on the mountain in His effulgence, it crumbled to a heap of dust, and Moses fell unconscious. When he came to, he said: ``All glory to You. I turn to You in repentance, and I am the first to believe."\qt@no{(143)}}
\qt@newcmd\qurantrans@en@mxcviii{Said (the Lord): ``O Moses, I raised you above all men by sending My messages and speaking to you; so receive what I give you, and be grateful."\qt@no{(144)}}
\qt@newcmd\qurantrans@en@mxcix{And We wrote down on tablets admonitions and clear explanations of all things for Moses, and ordered him: ``Hold fast to them, and command your people to observe the best in them. I will show you the abode of the wicked.\qt@no{(145)}}
\qt@newcmd\qurantrans@en@mc{I will turn those away from My signs who behave unjustly with arrogance in the land so that even though they see all the signs they will not believe in them; and if they see the path of rectitude, will not take it to be a way; and if they see the way of error take it to be the (right) path. This is so for they have called Our messages lies, and have been heedless of them."\qt@no{(146)}}
\qt@newcmd\qurantrans@en@mci{Vain are the acts of those who deny Our signs and the meeting in the Hereafter. Can they ever be rewarded for anything but what they did?\qt@no{(147)}}
\qt@newcmd\qurantrans@en@mcii{In the absence of Moses his people prepared the image of a calf from their ornaments, which gave out the mooing of a cow. Yet they did not see it could neither speak to them nor guide them to the right path. Even then they took it (for a deity) and did wrong.\qt@no{(148)}}
\qt@newcmd\qurantrans@en@mciii{Then they were filled with remorse and saw that they had erred and said: ``If our Lord does not forgive us we will surely be lost."\qt@no{(149)}}
\qt@newcmd\qurantrans@en@mciv{When Moses returned to his people, indignant and grieved, he said: ``How wickedly you behaved in my absence. Why must you hasten the decree of your Lord?" And he cast aside the tablets, and pulled his brother by the hair. ``O son of my mother," said (Aaron), ``these people took advantage of my weakness and almost killed me. Do not let my enemies rejoice at my plight, and do not put me down among transgressors."\qt@no{(150)}}
\qt@newcmd\qurantrans@en@mcv{(Moses) said: ``O Lord, forgive me and my brother, and admit us to Your grace, for You are the most compassionate of all."\qt@no{(151)}}
\qt@newcmd\qurantrans@en@mcvi{Surely those who have taken the calf (as a god) will suffer the anger of their Lord, and disgrace in the world. That is how We requite those who fabricate lies.\qt@no{(152)}}
\qt@newcmd\qurantrans@en@mcvii{Yet those who do wrong, then repent and believe, are forgiven, for your Lord is forgiving and kind.\qt@no{(153)}}
\qt@newcmd\qurantrans@en@mcviii{When his anger subsided Moses picked up the tablets. Inscribed on them was guidance and grace for those who fear their Lord.\qt@no{(154)}}
\qt@newcmd\qurantrans@en@mcix{Moses chose seventy of his people for the appointment (on Mount Sinai). When they arrived they were seized by a tremor. (Moses) said: ``O Lord, if You had so pleased You could have annihilated them and me before this. Will You destroy us for something the foolish among us have done? This is but a trial from You whereby You will lead whom You will astray and guide whom You please. You are our saviour, so forgive us and have mercy on us, for You are the best of forgivers.\qt@no{(155)}}
\qt@newcmd\qurantrans@en@mcx{Enjoin for us good in the world, and good in the world to come. We turn to You alone." And the Lord said: ``I punish only those whom I will, but My mercy enfolds everything. I shall enjoin it for those who take heed for themselves, who pay the zakat and believe in My signs,\qt@no{(156)}}
\qt@newcmd\qurantrans@en@mcxi{Who follow the messenger, the gentile Prophet, described in the Torah and the Gospel, who bids things noble and forbids things vile, makes lawful what is clean, and prohibits what is foul, who relieves them of their burdens, and the yoke that lies upon them. Those who believe and honour and help him, and follow the light sent with him, are those who will attain their goal."\qt@no{(157)}}
\qt@newcmd\qurantrans@en@mcxii{Say: ``O men, I am verily the apostle of God to you all. His whose kingdom extends over the heavens and the earth. There is no god but He, the giver of life and death. So believe in God and the messenger, the gentile Prophet, sent by Him, who believes in God and His messages. Obey him; you may haply be guided aright."\qt@no{(158)}}
\qt@newcmd\qurantrans@en@mcxiii{Among the people of Moses is a section that shows the way to the truth, and deals justly in accordance with it.\qt@no{(159)}}
\qt@newcmd\qurantrans@en@mcxiv{We divided them into twelve (different) tribes. When his people asked for water, We said to Moses: ``Strike the rock with your staff;" and behold, twelve springs of water gushed forth, so that each of the tribes had a place of its own to drink; and We made the clouds spread shade over them and sent for them manna and quails (and said): ``Eat of the good things We have provided for you." But (by disobeying) they did not harm Us, they harmed themselves.\qt@no{(160)}}
\qt@newcmd\qurantrans@en@mcxv{And when it was said to them: ``Live in this land and eat of its produce wheresoever you like, and ask for remission of your sins, but pass through the gates with submission (and not pride), We shall forgive your trespasses, and give to those who are righteous abundance,"\qt@no{(161)}}
\qt@newcmd\qurantrans@en@mcxvi{The wicked among them changed and perverted the word We had spoken to a word unpronounced; so We sent from heaven retribution on them for all their wickedness.\qt@no{(162)}}
\qt@newcmd\qurantrans@en@mcxvii{Enquire of them about the town situated by the sea where, when they did not keep the Sabbath, the fish came up to the surface of the water for them; but on days other than the Sabbath the fish did not come. We tried them in this way, for they were disobedient.\qt@no{(163)}}
\qt@newcmd\qurantrans@en@mcxviii{When a Section of them said: ``Why do you admonish a people whom God is about to destroy or to punish severely?" They replied: ``To clear ourselves of blame before your Lord, and that they may fear God.\qt@no{(164)}}
\qt@newcmd\qurantrans@en@mcxix{But when they forgot to remember the warning, We saved those who prohibited evil, but inflicted on the wicked a dreadful punishment -- requital for their disobedience.\qt@no{(165)}}
\qt@newcmd\qurantrans@en@mcxx{When they persisted in doing what they had been forbidden, We said to them: ``Become (like) apes despised."\qt@no{(166)}}
\qt@newcmd\qurantrans@en@mcxxi{And your Lord declared He would send men against them who would inflict dreadful suffering on them till the Day of Doom, for your Lord is swift in retribution, though He is certainly forgiving and kind.\qt@no{(167)}}
\qt@newcmd\qurantrans@en@mcxxii{We dispersed them in groups over the earth, some righteous, some otherwise; and We tried them with good things and bad, that they may haply turn back.\qt@no{(168)}}
\qt@newcmd\qurantrans@en@mcxxiii{Then after them a new generation inherited the Book. They took to the things of this base world, and said: ``We shall (surely) be forgiven this." Yet they will accept similar things if they came their way again. Had they not been covenanted in the Book to say nothing in the name of God but the truth? And they have read this in it. The abode of the life to come is better for those who fear God. Can they not comprehend?\qt@no{(169)}}
\qt@newcmd\qurantrans@en@mcxxiv{As for those who adhere to the Book and are firm in devotion, We shall certainly not let the wages of those who are upright to go waste.\qt@no{(170)}}
\qt@newcmd\qurantrans@en@mcxxv{The day We shook the mountain above them like an awning, and they feared it would fall over them, (We said): ``Hold fast to what We have given you, and bear in mind what is (said) therein so that you may take heed."\qt@no{(171)}}
\qt@newcmd\qurantrans@en@mcxxvi{When your Lord brings forth from their loins the offspring of the children of Adam, He makes them witnesses over themselves, (and asks): ``Am I not your Lord?" 'Indeed,' they reply. 'We bear witness,' -- lest you should say on the Day of Resurrection: ``We were not aware of this;"\qt@no{(172)}}
\qt@newcmd\qurantrans@en@mcxxvii{Or, lest they should say: ``It were our fathers who had ascribed compeers to God; we are only their offspring. Will You destroy us for the deeds of those who dealt in vanities?"\qt@no{(173)}}
\qt@newcmd\qurantrans@en@mcxxviii{That is how We explain Our signs distinctly so that they may come back (to the right path).\qt@no{(174)}}
\qt@newcmd\qurantrans@en@mcxxix{Relate to them the plight of the man whom We gave Our signs, but he passed them by, so that Satan came after him, and he went astray.\qt@no{(175)}}
\qt@newcmd\qurantrans@en@mcxxx{We wished to exalt him, but he loved baseness and followed his lust. His likeness is that of a dog who hangs out his tongue if you drive him away, and still hangs it out if you leave him alone. Such is the case of the people who deny Our signs. Narrate this history to them; they may haply reflect.\qt@no{(176)}}
\qt@newcmd\qurantrans@en@mcxxxi{Evil is the case of those who deny Our signs and wrong themselves.\qt@no{(177)}}
\qt@newcmd\qurantrans@en@mcxxxii{He alone is guided whom God shows the way; and whom He leads astray is surely lost.\qt@no{(178)}}
\qt@newcmd\qurantrans@en@mcxxxiii{Many of the jinns and human beings have We destined for Hell, who possess hearts but do not feel, have eyes but do not see, have ears but do not hear, like cattle, even worse than them. They are people unconcerned.\qt@no{(179)}}
\qt@newcmd\qurantrans@en@mcxxxiv{All the names of God are beautiful, so call Him by them; and leave those alone who act profanely towards His names: They will be retributed for their deeds.\qt@no{(180)}}
\qt@newcmd\qurantrans@en@mcxxxv{Yet there are among those We have created people who lead (others) to the truth, and act justly in its light\qt@no{(181)}}
\qt@newcmd\qurantrans@en@mcxxxvi{We shall punish those who deny Our revelations slowly in a way that they will not know.\qt@no{(182)}}
\qt@newcmd\qurantrans@en@mcxxxvii{I will just give them respite. My plan is certainly invincible.\qt@no{(183)}}
\qt@newcmd\qurantrans@en@mcxxxviii{Have they not bethought themselves their companion is not mad? He is only a plain admonisher.\qt@no{(184)}}
\qt@newcmd\qurantrans@en@mcxxxix{Have they not contemplated the kingdom of the heavens and the earth and everything created by God, (to educe) that perhaps their own term is drawing to a close? In what lore after this would they then believe?\qt@no{(185)}}
\qt@newcmd\qurantrans@en@mcxl{Whosoever God allows to go astray has none to show him the way, for He leaves them to wander perplexed in their wickedness.\qt@no{(186)}}
\qt@newcmd\qurantrans@en@mcxli{They ask you about the Hour: ``When is its determined time?" Say: ``Only my Lord has the knowledge. No one can reveal it except He. Oppressive will it be for the heavens and the earth. When it comes, it will come unawares." They ask you about it as if you were in the know. You tell them: ``Only God has the knowledge." But most people do not know.\qt@no{(187)}}
\qt@newcmd\qurantrans@en@mcxlii{Tell them: ``I am not master of my own gain or loss but as God may please. If I had the knowledge of the Unknown I would have enjoyed abundance of the good, and no evil would have touched me. I am only a bearer of warnings and bringer of happy news for those who believe."\qt@no{(188)}}
\qt@newcmd\qurantrans@en@mcxliii{It is He who created you from a single cell, and from it created its mate, that you may live as companions. When the man covered the woman she conceived a light burden and carried it about. And when she was heavy (with child) they prayed together to their Lord: ``If You bestow a healthy son on us we shall truly be grateful."\qt@no{(189)}}
\qt@newcmd\qurantrans@en@mcxliv{But when they were given a healthy son, they started ascribing to other powers a share in what God had bestowed on them. But God is above what they ascribe to Him.\qt@no{(190)}}
\qt@newcmd\qurantrans@en@mcxlv{Do they associate those with Him who cannot create a thing, and are themselves created,\qt@no{(191)}}
\qt@newcmd\qurantrans@en@mcxlvi{Who can neither help them, nor help themselves?\qt@no{(192)}}
\qt@newcmd\qurantrans@en@mcxlvii{If you call them to guidance they will not follow you. It is all the same if you call them or hold your tongue.\qt@no{(193)}}
\qt@newcmd\qurantrans@en@mcxlviii{Those whom you invoke besides God are created beings like you. So call on them and let them answer your call, if what you say is true.\qt@no{(194)}}
\qt@newcmd\qurantrans@en@mcxlix{Do they have feet to walk on, or hands to hold with, or eyes to see and ears to hear with? Say to them: ``Call your compeers, and work out a plot against me, and do not give me time.\qt@no{(195)}}
\qt@newcmd\qurantrans@en@mcl{My saviour is God who has revealed this Book; and He protects those who are upright;\qt@no{(196)}}
\qt@newcmd\qurantrans@en@mcli{While those you beseech apart from Him cannot help you or even help themselves.\qt@no{(197)}}
\qt@newcmd\qurantrans@en@mclii{When you call upon them for guidance, they do not hear. When you think they are looking at you, (in fact) they cannot see."\qt@no{(198)}}
\qt@newcmd\qurantrans@en@mcliii{Cultivate tolerance, enjoin justice, and avoid the fools.\qt@no{(199)}}
\qt@newcmd\qurantrans@en@mcliv{If you are instigated by the Devil to evil seek refuge in God, for God hears all and knows everything.\qt@no{(200)}}
\qt@newcmd\qurantrans@en@mclv{Verily those who fear God think of Him when assailed by the instigations of Satan, and lo! they begin to understand,\qt@no{(201)}}
\qt@newcmd\qurantrans@en@mclvi{Even though their (devilish) brothers would like them to continue in error, and would not desist.\qt@no{(202)}}
\qt@newcmd\qurantrans@en@mclvii{And when you do not bring a (Qur'anic) verse to them, they say: ``Why don't you make one up?" Say: ``I follow only what my Lord reveals to me." These (revelations) are an evident proof from your Lord, and a guidance and grace for those who believe.\qt@no{(203)}}
\qt@newcmd\qurantrans@en@mclviii{When the Qur'an is recited listen to it in silence. You may perhaps be blessed.\qt@no{(204)}}
\qt@newcmd\qurantrans@en@mclix{Meditate on your Lord inwardly with humility and trepidation, reciting His Book softly, morning and evening, and be not negligent.\qt@no{(205)}}
\qt@newcmd\qurantrans@en@mclx{Verily those who are in the presence of your Lord are never too proud to worship and celebrate His praises, and bow in homage to Him'.\qt@no{(206)}}
\qt@newcmd\qurantrans@en@mclxi{\basmalahen THEY ASK YOU of (benefits accruing as) spoils of war. Tell them: ``The benefits belong to God and His Messenger." So fulfil your duty to God and keep peace among yourselves. Obey God and the Prophet, If you really believe.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mclxii{Only they are true believers whose hearts fill up with awe when the name of God is mentioned; and their faith is further strengthened when His messages are read out to them; and those who place their trust in their Lord,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mclxiii{Who are firm in devotion, and spend of what We have given them,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mclxiv{Are true believers. There are for them (high) ranks with their Lord, and pardon and noble provision.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mclxv{As your Lord sent you from your home (to fight) for the true cause, a section of the faithful were averse,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mclxvi{Who argued with you about the matter even after it had become quite clear, as if they were being pushed into (the arms of) death as they waited.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mclxvii{Though God promised that one of two columns (would fall to you), you desired the one that was not armed. But God wished to confirm the truth by His words, and wipe the unbelievers out to the last,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mclxviii{So that Truth may be affirmed and falsehood negated, even though the sinners be averse.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mclxix{Remember when you prayed to your Lord for help, He heard you and said: ``I shall send a thousand angels following behind you for your aid."\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mclxx{He gave you the good news only to reassure your hearts, for victory comes from God alone, and certainly God is all-mighty and all-wise.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mclxxi{A blanketing sleep came over you as a (measure of) security from Him, and He sent down rain from the skies to cleanse you, and to remove the plague of Satan, and to strengthen your hearts and steady your steps.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mclxxii{And the Lord said to the angels: ``I am with you; go and strengthen the faithful. I shall fill the hearts of infidels with terror. So smite them on their necks and every joint, (and incapacitate them),"\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mclxxiii{For they had opposed God and His Apostle; but whosoever opposes God and his Apostle (should know) that God is severe in retribution.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mclxxiv{For you is this (punishment) to taste, for the infidels the torment of Hell.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mclxxv{O believers, when you meet unbelievers on the field of battle, do not turn your backs to them.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mclxxvi{For any one who turns his back on that day, except to manoeuvre or rally to his side, will bring the wrath of God on himself, and have Hell as abode; and what an evil destination!\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mclxxvii{It was not you who killed them, but God did so. You did not throw what you threw, (sand into the eyes of the enemy at Badr), but God, to bring out the best in the faithful by doing them a favour of His own. God is all-hearing and all-knowing.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mclxxviii{That was that, but remember God will make the plots of the unbelievers contemptible.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mclxxix{You had asked for a judgement, so the judgement has come to you (In the form of victory for the faithful). So, if you desist it will be better for you. If you come back to it, We shall do the same, and your forces, however large, will not be of the least avail, for God is with those who believe.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mclxxx{O believers, obey God and His Messenger, and do not turn away from him when you hear (him speak);\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mclxxxi{And do not be like those who say: ``We have heard," but do not hear.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mclxxxii{The worst of creatures in the eyes of God are those who are deaf and dumb and devoid of sense.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mclxxxiii{If God had seen any good in them He would surely have made them hear. Now even if He makes them hear they will turn away (in obduracy).\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mclxxxiv{O believers, respond to the call of God and His Prophet when he calls you to what will give you life (and preservation). Remember that God intervenes between man and his heart, and that you will be gathered before Him.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mclxxxv{Beware of sedition, which does not affect the oppressors alone among you, and know that the punishment of God is severe.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mclxxxvi{Remember, when you were few and powerless in the land, afraid of despoliation at the hands of men. But then God sheltered and helped you to strength, and provided for you good things that you may perhaps be grateful.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mclxxxvii{O you who believe, do not be faithless to God and His Apostle, nor violate your trusts knowingly.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mclxxxviii{Know that your worldly possessions and your children are just a temptation, and that God has greater rewards with Him.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mclxxxix{O believers, if you follow the path shown by God, He will give you a standard (of right and wrong), and overlook your sins, and forgive you. God is abounding in benevolence.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mcxc{Remember, when the infidels contrived to make you a prisoner or to murder or expel you, they plotted, but God also planned; and God's plan is the best.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mcxci{When Our messages were read out to them, they said: ``We have heard. We could certainly compose (writings) like them if we choose. They are but only tales of long ago."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mcxcii{They had also said: ``If this be the truth from you, O God, then rain down on us stones from the skies, or inflict a grievous punishment upon us."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mcxciii{But God would not choose to punish them while you are in their midst, nor afflict them when they are seeking forgiveness.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mcxciv{But what is there so special they have that God should not punish them when they obstruct people from the Holy Mosque, though they are not its (appointed) guardians? Its guardians could be only those who are pious and devout. But most of them do not know.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mcxcv{Their worship in the House of God has been no more than whistling and clapping. So they have to taste the punishment for disbelief.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mcxcvi{Those who disbelieve spend their possessions on turning men away from God. They will go on spending and rue it in the end, and will be subdued. But those who remain disbelievers shall be gathered into Hell\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mcxcvii{That God may separate the bad from the good, and link the wicked together and cast them into Hell. These are verily the people who will lose.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mcxcviii{You tell the unbelievers in case they desist whatever has happened will be forgiven them. If they persist, they should remember the fate of those who have gone before them.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mcxcix{So, fight them till all opposition ends, and obedience is wholly God's. If they desist then verily God sees all they do.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mcc{But if they are obstinate, know that God is your helper and protector: How excellent a helper, and how excellent a protector is He!\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mcci{Know that one-fifth of what you acquire as booty (of war) is for God and His Apostle, and for relatives and orphans, the poor and wayfarers, if you truly believe in God and what We revealed to Our votary on the day of victory over the infidels when the two armies clashed (at Badr). For God has the power to do any thing.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mccii{(That day) when you were at one end of the valley, (the unbelievers) at the other, and the caravan below you (on the lowland by the coast), you would surely have declined to fight if (the Makkans) had offered you battle. (But the battle did take place) that God may end the matter which had been accomplished, so that he who had to die may perish after a clear demonstration, and he who had to live may survive in the light of positive proof, for God hears all and knows everything.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mcciii{God showed (the Makkans) to be few in your dream, for if He had shown them to be many you would surely have lost courage and disagreed about the (wisdom) of the battle. But God spared you this, for He surely knows what is in the hearts of men.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mcciv{When you faced them He made (the enemy) seem few to you in numbers, and made you appear fewer in their eyes, (it was) so that God could accomplish what had been decreed; for all things rest with God.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mccv{O believers, when you meet an army, stand firm, and think of God a great deal that you may be blessed with success.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mccvi{Obey God and His Apostle, and do not disagree among yourselves or you will be unmanned and lose courage. Persevere, for God is with those who endure.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mccvii{Do not be like those who went out of their homes full of their own importance, ostentatiously, trying to hinder others from the way of God. But God encompasses all they do.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mccviii{Satan made their deeds look alluring to them, and said: ``None will prevail over you this day, for I shall be near at hand." Yet when the two armies appeared face to face, he turned back and fled, saying: ``I am not with you, for I can see what you cannot perceive. I fear God, for His punishment is severe."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mccix{The hypocrites, and those who had doubts in their hearts, said: ``Their faith has misled them." But whoever places his trust in God will find God mighty and wise.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mccx{If you could only see the infidels as the angels draw away their souls and strike their faces and their backs, (saying): ``Taste the torment of burning\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mccxi{For what you have brought upon yourselves." God is surely not unjust to His creatures, (they are unjust to themselves).\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mccxii{Their case is like that of Pharaoh's people, and of those before them, who denied the revelations of God, and were punished for their sins by God, and God is all powerful and Severe His punishment.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mccxiii{God does not withdraw a favour bestowed upon a people unless they change themselves, for God hears all and knows everything.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mccxiv{This was the case with the people of Pharaoh and those before them, who rejected the signs of their Lord and were destroyed for their sins, and We drowned the people of Pharaoh as they were oppressors.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mccxv{Verily the worst of creatures in the sight of God are those who deny (the truth), and will not believe.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mccxvi{As for those with whom you have made a treaty and who abrogate it every time, and do not fear God,\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mccxvii{If you meet them in battle, inflict on them such a defeat as would be a lesson for those who come after them, and that they may be warned.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mccxviii{If you apprehend treachery from a people (with whom you have a treaty), retaliate by breaking off (relations) with them, for God does not like those who are treacherous.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mccxix{The infidels should not think that they can bypass (the law of God). Surely they cannot get away.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mccxx{Prepare against them whatever arms and cavalry you can muster, that you may strike terror in (the hearts of) the enemies of God and your own, and others besides them not known to you, but known to God. Whatever you spend in the way of God will be paid back to you in full, and no wrong will be done to you.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mccxxi{But if they are inclined to peace, make peace with them, and have trust in God, for He hears all and knows everything.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mccxxii{If they try to cheat you, God is surely sufficient for you. It is He who has strengthened you with His help and with believers\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mccxxiii{Whose hearts He cemented with love. You could never have united their hearts even if you had spent whatever (wealth) is in the earth; but God united them with love, for He is all-mighty and all-wise.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mccxxiv{God is sufficient for you, O Prophet, and the faithful who follow you.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mccxxv{O Prophet, urge the faithful to fight. If there are twenty among you with determination they will vanquish two hundred; and if there are a hundred then they will vanquish a thousand unbelievers, for they are people devoid of understanding.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mccxxvi{God has lightened your burden as He knows you are weak: So, if there are a hundred men of firm determination among you, they will vanquish two hundred; and if there are a thousand of you they will vanquish two thousand by the will of God, for God is with those who are determined.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mccxxvii{No apostle should take captives until he has battled and subdued the country. You desire the vanities of this world, but God wills (for you the reward) of the world to come; and God is all-mighty and all-wise.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mccxxviii{Had this not been decreed by God in advance, you would have suffered a grievous punishment for what you took (as booty).\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mccxxix{But now use such of the spoils as are lawful and good, and fear God, for God is forgiving and kind.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mccxxx{O Prophet, tell the captives you have taken: ``If God finds some good in your hearts, He will reward you with something better than was taken away from you, and forgive your sins, for God is forgiving and kind."\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mccxxxi{If they try to deceive you, remember they have deceived God before. So He gave you mastery over them, for God is all-knowing and all-wise.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mccxxxii{Those who accepted the faith and set out of their homes, and fought in the way of God wealth and soul, and those who gave them shelter and helped them, are friends of one another. You are not responsible for protecting those who embraced the faith but did not leave their homes, until they do so. In ease they ask for your help in the name of faith, you are duty bound to help them, except against a people with whom you have a treaty; for God sees all that you do.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mccxxxiii{Those who are infidels aid one another. Unless you do the same there will be discord in the land and anarchy.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mccxxxiv{Those who accepted the faith and abandoned their homes, and struggled in the cause of God, and those who gave them shelter and helped them, are veritably true believers. For them is forgiveness and noble sustenance.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mccxxxv{Those who accepted the faith and left their homes and fought by your side, are your brothers; yet those who are related by blood are closer to one another according to the decree of God. Verily God knows everything.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mccxxxvi{\basmalahen IMMUNITY is granted those idolaters by God and his Apostle with whom you have a treaty.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mccxxxvii{(They can) move about for four months freely in the land, but should know they cannot escape (the law of) God, and that God can put the unbelievers to shame.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mccxxxviii{A general proclamation is (made) this day of the Greater Pilgrimage on the part of God and His Apostle, that God is not bound (by any contract) to idolaters, nor is His Apostle. It is, therefore, better for you to repent. If you do not, remember that you cannot elude (the grip of) God. So announce to those who deny the truth the news of painful punishment,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mccxxxix{Except those idolaters with whom you have a treaty, who have not failed you in the least, nor helped anyone against you. Fulfil your obligations to them during the term (of the treaty). God loves those who take heed for themselves.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mccxl{But when these months, prohibited (for fighting), are over, slay the idolaters wheresoever you find them, and take them captive or besiege them, and lie in wait for them at every likely place. But if they repent and fulfil their devotional obligations and pay the zakat, then let them go their way, for God is forgiving and kind.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mccxli{If an idolater seeks protection, then give him asylum that he may hear the word of God. Then escort him to a place of safety, for they are people who do not know.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mccxlii{How could there be a treaty between idolaters and God and His Apostle, except those you covenanted by the Sacred Mosque? Therefore as long as they are honest with you be correct with them, for God loves those who are godly.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mccxliii{How (can they be trusted)? If they prevail against you they will neither observe pacts nor good faith with you. They flatter you with their tongues, but their hearts are averse to you, for most of them are iniquitous.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mccxliv{They barter away the words of God for a petty price, and obstruct (others) from His path. How evil indeed are the things they do!\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mccxlv{They have no regard for kinship or treaties with believers, for they are transgressors.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mccxlvi{But if they repent and are firm in devotion and pay the zakat, then they are your brothers in faith. We explain Our commands distinctly for those who understand.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mccxlvii{If they break their pledge after giving their word and revile your faith, fight these specimens of faithlessness, for surely their oaths have no sanctity: They may haply desist.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mccxlviii{Will you not fight those who broke their pledge and plotted to banish the Apostle, and who were the first to attack you? Are you afraid of them? If you are believers you should fear God more.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mccxlix{Fight them so that God may punish them at your hands, and put them to shame, and help you against them, and heal the wounds of the hearts of believers,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mccl{And remove the anger from their breasts; for God turns to whosoever desires. God is all-knowing and all-wise.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mccli{Do you think you will get away before God knows who among you fought and did not take anyone but God, His Apostle and the faithful, as their friends? God is cognisant of all that you do.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mcclii{The idolaters have no right to visit the mosques of God while bearing testimony to their disbelief. Meaningless will be their acts, and in Hell they will bide for ever,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mccliii{Only those who believe in God and the Last Day, who fulfil their devotional obligations, pay the zakat, and fear no one but God, can visit the mosques of God. They may hope to be among the guided.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mccliv{Do you think that giving a drink of water to the pilgrims and going on a visit to the Sacred Mosque, is the same as believing in God and the Last Day, and striving in the cause of God? In the eyes of God it is not the same; and God does not show the unrighteous the way.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mcclv{Those who accepted the faith and left their homes and fought in the way of God, wealth and soul, have a greater reward with God, and will be successful.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mcclvi{Their Lord announces to them news of His mercy, acceptance, and gardens of lasting bliss\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mcclvii{Which they will enjoy for ever. Indeed God has greater rewards with Him.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mcclviii{O you who believe, do not hold your fathers and brothers as friends if they hold disbelief more dear than faith; and those of you who do so are iniquitous.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mcclix{You tell them: ``If your fathers and sons, your brothers and wives and families and wealth, or the business you fear may fail, and the mansions that you love, are dearer to you than God, His Apostle, and struggling in His cause, then wait until God's command arrives, for God does not show transgressors the way."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mcclx{Indeed God has helped you on many occasions, even during the battle of Hunain, when you were elated with joy at your numbers which did not prove of the least avail, so that the earth and its vast expanse became too narrow for you, and you turned back and retreated.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mcclxi{Then God sent down a sense of tranquility on His Apostle and the faithful; and sent down troops invisible to punish the infidels. This is the recompense of those who do not believe.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mcclxii{Yet God may turn (even) after this to whomsoever He please, for God is compassionate and kind.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mcclxiii{O believers, the idolaters are unclean. So they should not approach the Holy Mosque after this year. In case you fear indigence (from the stoppage of business with them), then God will enrich you of His bounty if He will, for God is all-knowing and all-wise.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mcclxiv{Fight those people of the Book who do not believe in God and the Last Day, who do not prohibit what God and His Apostle have forbidden, nor accept divine law, until all of them pay protective tax in submission.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mcclxv{The Jews say: ``Ezra is the son of God;" the Christians say: ``Christ is the son of God." That is what they say with their tongues following assertions made by unbelievers before them. May they be damned by God: How perverse are they!\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mcclxvi{They consider their rabbis and monks and the Christ, son of Mary, to be gods apart from God, even though they had been enjoined to worship only one God, for there is no god but He. Too holy is He for what they ascribe to Him!\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mcclxvii{They wish to extinguish the light of God by uttering blasphemies; but God will not have it so, for He wills to perfect His light, however the unbelievers be averse.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mcclxviii{It is He who sent His Messenger with guidance and the true faith in order to make it superior to other systems of belief, even though the idolaters may not like it.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mcclxix{O believers, many rabbis and priests devour the possessions of others wrongfully, and keep men away from the path of God. To those who accumulate gold and silver, and do not spend in the way of God, announce the news of painful punishment.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mcclxx{On the day We shall heat up (their gold) on the fire of Hell and brand their foreheads, sides and backs (and say to them): ``It is this you stored up for yourselves; so now taste of what you had stored!"\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mcclxxi{The number of months with God is twelve in accordance with God's law since the day He created the heavens and the earth. Of these four are holy. This is the straight reckoning. So do not exceed yourselves during them; but fight the idolaters to the end as they fight you in like manner; and remember, God is with those Who preserve themselves from evil and do the right.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mcclxxii{Intercalating a month is adding to unbelief. The unbelievers are misguided by this, for they take the same month to be sacred one year and sacrilegious the next, thus making the number of months sanctified by God accord with theirs in order to make what God has forbidden, lawful. Attractive seem to them their evil deeds; but God does not show the unbelievers the way.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mcclxxiii{What has happened to you, O believers, that when you are asked to set out in the cause of God your feet begin to drag? Do you find the life of the world so pleasing that you forget the life to come? Yet the profit of the life of this world is but meagre as compared to the life to come.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mcclxxiv{Unless you go out (to strive), God will inflict grievous punishment on you, and bring other people in your place, and you will not be able to harm Him in the least, for God has the power over all things.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mcclxxv{If you do not help (the Prophet, remember) God had helped him when the infidels had forced him to leave (and he was) one of two. When both of them were in the cave, he said to his companion: ``Do not grieve, for God is with us." Then God sent divine peace on him, and invisible armies for his help, and made the unbelievers' purpose abject. Most exalted is God's word, for God is all-mighty and all-wise.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mcclxxvi{O believers, go out in the cause of God, (whether) light or heavy, and strive in the service of God, wealth and soul. This is better for you if you understand.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mcclxxvii{(O Prophet), had the gain been close at hand, and easy the journey, they would surely have followed you; but hard was the journey and long the going. Even then they swear by God (and say): ``If we had the strength we would surely have gone out with you." They are only ruining themselves, for God is aware they lie.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mcclxxviii{May God forgive you. Why did you allow them (to stay behind) without ascertaining who spoke the truth and who were liars?\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mcclxxix{Those who believe in God and the Last Day, do not ask your leave to be excused from fighting wealth and soul (in the cause of God), for God knows the pious and devout.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mcclxxx{Only they ask (for leave) who do not believe in God and the Last Day, whose hearts are full of doubt; and doubting they waver (between gain and loss).\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mcclxxxi{If they had intended to go out (to fight) they would surely have made preparations. But God did not like their setting forth, and they were held back and told: ``Stay at home with those who stay behind."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mcclxxxii{Had they gone out with you, they would only have been a hindrance and let loose confusion among you to create discord; for there are some in your midst who spy for them. But God knows who are the wicked.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mcclxxxiii{They had tried to create disorder before and intrigued against you, but truth came out in the end and God's will prevailed, even though they did not like it.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mcclxxxiv{And (many a one) there is among them who says: ``Allow me (to stay back at home), and put me not on trial." Surely they have put themselves on trial already, and Hell will enclose the unbelievers from all sides.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mcclxxxv{If good comes your way they are vexed, but if calamity befalls you, they say: ``We had taken precautions in advance;" and pleased, turn away.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mcclxxxvi{Tell them: ``Nothing can befall us except what God decrees. Our protector is He, and in God should the faithful place their trust."\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mcclxxxvii{Say: ``Are you waiting for anything else but one of two good things for us, (victory or martyrdom)? Yet what we are waiting for you is the punishment of God, direct or through us. So keep waiting; we are waiting with you."\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mcclxxxviii{Tell them: ``You may spend (in the way of God), whether willingly or with reluctance, it will not be accepted from you, for you are reprobates."\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mcclxxxix{Nothing prevents the acceptance of what they spend except that they do not believe in God and His Apostle, and come to worship but languidly and spend only grudgingly.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mccxc{Do not marvel at their wealth and children. God intends to punish them through these in the world; and their souls will depart in a state of disbelief.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mccxci{They swear by God they are with you, though in fact they are not. They are only a frightened lot.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mccxcii{If they find a place of shelter or a cave or hole to hide, they will turn to it.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mccxciii{There are some among them who blame you (of partiality) in distributing the offerings made in the name of God. In case they receive some of these they are pleased, if not, they are incensed.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mccxciv{They should rather have been pleased with what God and His Prophet had given them, and said: ``God is sufficient for us; He will give us of His largesse as will His Apostle. We supplicate no one but God."\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mccxcv{Charities are meant for the indigent and needy, and those who collect and distribute them, and those whom you wish to win over, and for redeeming slaves (and captives) and those who are burdened with debt, and in the cause of God, and the wayfarers: So does God ordain. God is all-knowing and all-wise.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mccxcvi{There are some among them who talk ill of the Prophet by saying: ``He listens to everyone." Tell them: ``He listens for your good, and trusts in God and trusts the faithful, and he is a blessing for those who believe. For those who offend the Apostle of God there is painful punishment."\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mccxcvii{They swear by God to please you; but if they are believers it would have been worthier to have pleased God and His Apostle.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mccxcviii{Have they not realised that anyone who opposes God and His Prophet, will abide in Hell for ever? And that is the worst disgrace.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mccxcix{The hypocrites fear lest a Surah is revealed concerning them, exposing what is in their hearts. Say to them: ``Mock as much as you like; God will surely expose what you dread."\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mccc{But if you ask them, they will say: ``We were only gossiping and jesting." You ask them: ``Were you jesting with God, His revelations and His messengers?"\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mccci{Do not make excuses: You turned unbelievers after having come to faith. If We pardon a section of you (for being frivolous), We shall punish the other for being guilty (of deliberate sin).\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mcccii{The hypocrites (are the same) whether men or women, the one of them being of the other. They encourage what is bad and dissuade from the good, and tighten their purses (when it comes to spending in the way of God). Of God they are oblivious; so He is oblivious of them. The hypocrites are indeed transgressors.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mccciii{God has reserved for hypocrites, whether men or women, and for unbelievers, the fire of Hell, where they will abide for ever. This is sufficient for them: They have God's condemnation and lasting torment,\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mccciv{Like those before you who were greater in strength, had more wealth and children than you, who enjoyed their lot in this world, as you have enjoyed your share like them. You indulge in idle talk, as they had indulged in vain discourse. Yet nothing of what they did remains in this world or will in the next, and they are the losers.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mcccv{Has not the account of those before them come to them, -- of the people of Noah and 'Ad and Thamud, of Abraham and Midian, and all the habitations that were destroyed? Their apostles had come to them with clear proofs; and God did not surely wrong them, they wronged themselves.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mcccvi{Those who believe, men and women, befriend one another, and enjoin what is right and prohibit what is wrong. They observe their devotional obligations, pay the zakat, and obey God and His Apostle. God will be merciful to them, for God is all-mighty and all-wise.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mcccvii{God has promised men and women who believe gardens with streams of running water where they will abide for ever, and beautiful mansions in the Garden of Eden, and the blessings of God above all. That will be happiness supreme.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mcccviii{Strive, O Prophet, against the unbelievers and the hypocrites, and deal with them firmly. Their final abode is Hell: And what a wretched destination!\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mcccix{They swear by God: ``We never said this." But they surely said words disbelieving the truth, and they turned unbelievers after having come to faith, and designed what they could not accomplish. They did it only out of vengeance for God and His Apostle had enriched them by their grace. So, if they repent it is better for them. If they turn away then God would afflict them with painful punishment in this world and the next; and none will they have on the face of the earth to protect or help them.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mcccx{Some of them made a covenant with God: ``If You give us in Your bounty we shall give alms and be upright."\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mcccxi{But when He gave them of His bounty they became greedy, and then turned away.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mcccxii{As a consequence of breaking their promise made to God, and telling lies, he filled their hearts with hypocrisy which will last till the day they come before Him.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mcccxiii{Have they not realised that God knows their secrets and their confidential talk, and that God has the knowledge of unknown things?\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mcccxiv{They who defame those of the believers who give alms willingly, and deride those who have nothing besides what they earn by their labour (to give in charity), will be derided by God, and will suffer painful punishment.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mcccxv{Whether you plead forgiveness for them or not, God will not forgive them, even though you plead seventy times, for they disbelieved in God and His Apostle; and God does not show transgressors the way.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mcccxvi{Those who were left behind rejoiced that they stayed at home against the wishes of God's Apostle, being averse to fighting in the way of God with their wealth and lives, and said: ``Do not go in this heat." Tell them: ``The heat of Hell is far more intense." If only they had cared to instruct themselves!\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mcccxvii{So let them laugh a little, for weep they will, more as retribution for what they have done.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mcccxviii{If you come back to them by (the grace of) God, and they seek your permission to go (to fight), you should tell them: ``You will never go out nor fight the enemy with me any more. You preferred to stay back on the first occasion, so stay at home with those who stay behind."\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mcccxix{Do not invoke blessings on any of them who die, nor stand to pray at their graves, for they disbelieved in God and His Prophet, and died transgressors.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mcccxx{And let not their wealth and children astonish you. God wishes to punish them through these in the world, and their souls will depart in a state of disbelief.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mcccxxi{Whenever a Surah is revealed (which says): ``Believe in God and fight along with His Prophet," the well-to-do among them ask for leave to stay at home, and say: ``Leave us with those who are left behind."\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mcccxxii{They prefer to be with women who (are allowed to) stay at home during war, and their hearts are sealed; so they fail to understand.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mcccxxiii{But the Prophet and those who have embraced the faith with him, and have fought wealth and soul (in the way of God), are blessed and will be successful.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mcccxxiv{God has provision for them of gardens with Streams of running water, where they will abide for ever. This will be the supreme triumph.\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mcccxxv{Some Arabs of the desert came with ready excuses, asking for leave to stay behind. But those who had lied to God and His Prophet stayed at home doing nothing. So the punishment for those who disbelieve among them will be painful.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mcccxxvi{No blame will attach to the old and the sick, or those without means to spend on good acts, if they stay behind provided they are sincere to God and His Apostle; There is no way to blame those who are doers of good, for God is forgiving and kind.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mcccxxvii{Nor will they be blamed who came to you for transport, to whom you said: ``I cannot find any means of conveyance for you," and they went away in tears, grieving that they lacked the means to spend (on carriage).\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mcccxxviii{Blame will lie on those who are rich yet ask your leave to stay behind. They prefer to stay with women who stay at home, and God seals their hearts; so they do not understand.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mcccxxix{When you come back they will offer excuses to you. Tell them: ``Make no excuses; we do not believe you. God has informed us about you; and God and His Apostle shall watch your conduct. Then you will be brought to Him who knows what is hidden and what is manifest. He will tell you of what you did."\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mcccxxx{They will beg you in the name of God, on your return, to forgive them; but you keep away from them: They are scum; their abode is Hell: Requital for what they had done.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mcccxxxi{They will plead on oath that you accept them. Even if you accept them, remember God does not accept people who are disobedient.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mcccxxxii{The village Arabs are more obstinate in disbelief and hypocrisy, and impervious to ordinances revealed to His Apostle by God; yet God is aware of everything and is wise.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mcccxxxiii{Some of these rustics take whatever they spend in the way of God as a penalty, and wait for an adverse turn in your fortune. For them will be the adverse change, as God hears all and knows everything.\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mcccxxxiv{Yet some Arabs of the desert believe in God and the Last Day, and consider what they spend to be a means of bringing them nearer to God and the blessings of the Prophet. This is certainly a means of achieving nearness (to God), and God will admit them to His mercy, for God is forgiving and kind.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mcccxxxv{Those among the migrants (from Makkah) and helpers (in Madina) who were the first to believe, and those who followed them in goodness, have been accepted by God and they follow His way. For them He has gardens with streams of running water where they will abide for ever; and that is happiness supreme.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mcccxxxvi{Some of the Arabs of the desert around you are hypocrites, and some of the people of Madina are stubborn in hypocrisy. You are not aware of them; We know them, and will punish them twice, and they will be sent to a harrowing doom.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mcccxxxvii{But there are others who admit their sins of mixing good deeds with evil. It may be that God will accept their repentance, for God is forgiving and kind.\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mcccxxxviii{Accept the offerings they make from their wealth in order to cleanse and purify them for progress, and invoke blessings upon them. Your blessings will surely bring them peace, for God hears all and knows everything.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mcccxxxix{Do they not know that God accepts the repentance of His creatures and receives what they offer in charity, and that He is forgiving and kind?\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mcccxl{Say to them: ``Act. God will see your conduct, and so will His Apostle and the faithful; for you will in the end go back to Him, who knows the unknown and the known, who will tell you of what you were doing."\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mcccxli{There are still some others whose affairs await the dispensation of God. He may punish or pardon them, for God is all-knowing and all-wise.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mcccxlii{There are those who built a mosque on opposition and disbelief, and to cause rifts among the faithful, and to serve as an outpost for those who have warred against God and His Apostle before this. Yet they will surely swear: ``We had only meant well." But God is witness that they are liars.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mcccxliii{Never set foot in that place. Only a mosque whose foundations have been laid from the very first on godliness is worthy of your visiting it. There you will find men who wish to be purified; and God loves those who are pure.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mcccxliv{Is the man who lays the foundations of his sanctum on his allegiance to God and the wish to seek His favour, better, or he who lays the foundations of his building on the edge of a bank eroded by water, which will collapse with him into the fire of Hell? But God does not guide the people who are wilfully unjust.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mcccxlv{The edifice they have built will always fill their minds with perturbation (which will not cease) till their hearts are rent to pieces, for God is all-knowing and all-wise.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mcccxlvi{God has verily bought the souls and possessions of the faithful in exchange for a promise of Paradise. They fight in the cause of God, and kill and are killed. This is a promise incumbent on Him, as in the Torah, so the Gospel and the Qur'an. And who is more true to his promise than God? So rejoice at the bargain you have made with Him; for this will be triumph supreme.\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mcccxlvii{To those who repent and pay homage, give praise and are devout, who kneel in prayer and bow in supplication, who enjoin good deeds and prohibit the bad, and keep to the limits set by God, announce the news of rejoicing to the faithful.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@mcccxlviii{It is not worthy of the Prophet and those who believe to seek forgiveness for those who are idolaters, even though they may be their relatives, after they have come to know that they are destined for Hell.\qt@no{(113)}}
\qt@newcmd\qurantrans@en@mcccxlix{As for Abraham's prayer for his father, he was fulfilling a promise he had made to him. Yet when it became evident to him that (his father) was an enemy of God, he broke away from him, though Abraham was soft hearted and kind.\qt@no{(114)}}
\qt@newcmd\qurantrans@en@mcccl{God never leads men astray after guiding them, until He makes quite clear to them what they should avoid, for God indeed knows each and everything.\qt@no{(115)}}
\qt@newcmd\qurantrans@en@mcccli{Verily God's is the kingdom of the heavens and the earth. He alone is the giver of life and death; and none do you have besides God as friend and helper.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@mccclii{God was kind to the Prophet, the emigrants, and the helpers of the faithful who followed him in the hour of distress. When a section of them were about to lose courage He turned to them in His mercy, for He is compassionate and kind.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@mcccliii{He has relented towards the three also (who had refused to go to the battle of the Ditch) whose case was left undecided, and even the earth with all its expanse had become narrow for them, and their lives were confined, and they came to realise there was no refuge for them except in God. So He softened towards them that they may repent; for God surely accepts repentance and is merciful.\qt@no{(118)}}
\qt@newcmd\qurantrans@en@mcccliv{O believers, do not stray from the path of God, and be with those who are truthful.\qt@no{(119)}}
\qt@newcmd\qurantrans@en@mccclv{It was not worthy of the people of Madina, and the Arabs of the desert around them, to abandon the Prophet of God, and to care more for themselves than for him; for there is no hardship or thirst or hunger that they know in the service of God, and no place they walk on where walking provokes the unbelievers, and no harm they receive from the enemy, but is put down as a good deed in their favour. Surely God does not let the recompense of those who do good to go waste.\qt@no{(120)}}
\qt@newcmd\qurantrans@en@mccclvi{There is not a sum, large or small, that they spend, not a piece of land that they traverse (in the service of God) which is not put down in their favour, so that God could reward them for what they had done.\qt@no{(121)}}
\qt@newcmd\qurantrans@en@mccclvii{It is not possible for all believers to go out (to fight). So a part of each section (of the population) should go (to fight) in order that the others may acquire understanding of law and divinity, and warn their companions on return so that they may take heed for themselves.\qt@no{(122)}}
\qt@newcmd\qurantrans@en@mccclviii{O believers, fight the unbelievers around you, and let them realise that you are firm: Remember, God is with those who are pious and obedient to Him.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@mccclix{When a Surah is revealed some of them remark: ``Whose faith among you has it increased?" It does increase the faith of those who believe, and they rejoice.\qt@no{(124)}}
\qt@newcmd\qurantrans@en@mccclx{But it adds disbelief to disbelief for those whose hearts are filled with doubt, and they die disbelieving.\qt@no{(125)}}
\qt@newcmd\qurantrans@en@mccclxi{Do they not know that they are tried every year once or twice? Even then they do not repent and take heed.\qt@no{(126)}}
\qt@newcmd\qurantrans@en@mccclxii{Whenever a Surah is revealed they look at each other (so as to ask): ``Is anyone looking at Us?" and then turn away. Indeed God has turned their hearts away (from the truth), for they cannot discern the law of heaven.\qt@no{(127)}}
\qt@newcmd\qurantrans@en@mccclxiii{To you has come an Apostle from among you. Any sorrow that befalls you weighs upon him; He is eager for your happiness, full of concern for the faithful, compassionate and kind.\qt@no{(128)}}
\qt@newcmd\qurantrans@en@mccclxiv{So, if they turn away, say to them: ``God is sufficient for me. There is no God but He; I depend on Him alone, the Lord of the glorious Throne."\qt@no{(129)}}
\qt@newcmd\qurantrans@en@mccclxv{\basmalahen ALIF LAM RA. These are the verses of the authoritative Book.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mccclxvi{Are the people astonished that a man who is one of them was commanded by Us to warn them and to bring glad tidings to those who believe that they have a true precedence with their Lord? (Yet) the unbelievers say: ``He is a clear sorcerer."\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mccclxvii{Your Lord is God who created the heavens and the earth in six spans, then assumed His power, dispensing all affairs. None can intercede with Him except by His leave. He is God, your Lord, so worship Him. Will you not be warned?\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mccclxviii{To Him will you all return: God's promise is true. It is He who originates creation, then will revert it, so that He may reward those who believe and do good things in all justice. But those who deny the truth will receive boiling water to drink and grievous punishment, for they disbelieved.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mccclxix{It is He who gave the sun its radiance, the moon its lustre, and appointed its stations so that you may compute years and numbers. God did not create them but with deliberation. He distinctly explains His signs for those who can understand.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mccclxx{In the alternation of night and day, and all that He has created in the heavens and the earth, are certainly signs for people who fear God.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mccclxxi{As for those who do not hope to meet Us (after death), and are content with the life of this world, who are oblivious of Our signs,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mccclxxii{Will have Hell as their abode for what they have earned.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mccclxxiii{But those who believe and act for a beneficial end will be guided by their Lord for their good faith. At their feet shall flow streams of running water in gardens of delight.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mccclxxiv{Their invocation will be: ``All glory to you, O God," and ``Peace" will be their salutation, and the end of their prayer (will be): ``All praise be to God, the Lord of all the worlds."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mccclxxv{If God were to hasten the evil, as men try to hasten the good, their term would come to end. So We leave those who do not expect to meet Us to wander perplexed in transgression.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mccclxxvi{When man is afflicted with adversity he calls to Us, whether lying on his side, or sitting or standing. But when We take away his troubles, he moves away, as though he had never called to Us in affliction. In the same way, attractive have been made their deeds to the prodigals.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mccclxxvii{How many generations did We lay low before you when they became wilfully unjust. Their apostles had brought clear proofs to them, yet they never believed. So We punished the sinful people.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mccclxxviii{Then We appointed you leaders in the land after them to see how you behaved.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mccclxxix{When Our clear messages are recited to them, those who do not hope to meet Us, say: ``Bring a different Qur'an, or make amendments to this one." Say: ``It is not for me to change it of my will. I follow (only) what is revealed to me. If I disobey my Lord, I fear the punishment of an awful Day."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mccclxxx{Say: ``Had God pleased I would never have recited it to you, nor would He have given you comprehension of it. (Remember that I am one of you) and have lived a whole life with you before (its revelation). Even then you do not understand."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mccclxxxi{Who is more unjust than he who imputes lies to God or denies His revelations? The sinners will surely not be reprieved.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mccclxxxii{They worship those besides God who cannot do them harm or bring them gain, and say: ``These are our intercessors with God." Say: ``Do you want to inform God of things in the heavens and the earth He does not know?" Glorious is He, and too exalted for what they associate with Him!\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mccclxxxiii{Men were once a community of one faith; but they differed (and followed different ways). Had it not been for the word proclaimed by your Lord before, their differences would have been resolved.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mccclxxxiv{They say: ``How is it that no sign was sent by his Lord (to His Prophet)?" Tell them: ``Unknown things are only known to God. So watch and wait (for the sign); I am waiting and expecting with you."\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mccclxxxv{When We let them taste Our mercy after affliction, they contrive against Our signs. Say: ``God is swifter at contriving," for Our angels record everything you plan.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mccclxxxvi{It is He who enables you to travel over land and sea. When you sail in ships in a favourable breeze, you rejoice. But when a gale begins to blow and the waves dash against them from every side they realise that they have been caught in it, (and) they call on God in all faith: ``If You save us from this we shall ever be grateful."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mccclxxxvii{But when He rescues them, they commit excesses in the land unjustly again. Your rebellion, O people, shall recoil back on your own selves. The joys of the world (are only ephemeral): You have to come back to Us in the end. We shall then inform you what you were doing.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mccclxxxviii{The life of the world is like the rain that waters the crops of the earth which are used as food by men and cattle. But when the earth is embellished and adorned with gold, and its tillers begin to feel that (the crops) are under control, Our command descends suddenly at night or in the day, and We mow them down as though there was nothing there yesterday. This is how We distinctly explain Our signs to those who think.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mccclxxxix{God invites you to mansions of peace, and guides whosoever He will to the path that is straight\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mcccxc{For those who do good there is goodness and more, and no blot or disgrace will cover their faces. They are people of Paradise, where they will abide for ever.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mcccxci{But those who earn evil shall be punished to an equal degree as their evil, and they will be covered with shame, and will have none to protect them against God: Their faces shall be blackened as though with patches of the night. They are the people of Hell, where they will abide for ever,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mcccxcii{The day We shall gather them all together We shall say to the idolaters: ``Take your stand with the compeers you worshipped as the equals of God." We shall then create a rift between them, and the compeers will say: ``You did not worship us;\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mcccxciii{For God is sufficient as witness between us and you we were not aware of your worship."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mcccxciv{Then each will see what he had done in the past; and they will turn to God, their true Lord, and all the lies they had fabricated will be of no avail to them.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mcccxcv{Ask them: ``Who gives you food and sustenance from the skies and the earth? Or, who is the lord of ear and eye? And who brings forth the living from the dead, the dead from the living? And who directs all affairs?" They will say: ``God." So tell them: ``Why do you not fear Him?"\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mcccxcvi{Such then is God, your true Lord; and when truth is gone what is left but error? So why do you turn away?\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mcccxcvii{Thus the word of your Lord about those who disobey comes true, that they do not believe.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mcccxcviii{Ask them: ``Is there among the partners (you ascribe to God) one who first originates then reverts it? Say: ``It is God alone who first creates and then reverts it. So where do you stray?"\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mcccxcix{Ask: ``Is there one among those you associate with God who can show the way to the truth?" Say: ``It is God who shows the way to truth." Then who is more worthy of being followed -- He who guides to the truth, or he who cannot find the path until shown the way? What has happened to you that you judge in such a wise?\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mcd{Many of them follow nothing but illusion; yet illusion cannot replace the reality. God verily knows what they do.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mcdi{This Qur'an is not such (a writ) as could be composed by anyone but God. It confirms what has been revealed before, and is an exposition of (Heaven's) law. Without any doubt it's from the Lord of all the worlds.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mcdii{Do they say (of the Prophet) that: ``He has composed it?" Say to them: ``Bring a Surah like this, and call anyone apart from God you can (to help you), if what you say is true."\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mcdiii{In fact, they deny what is beyond the reach of their knowledge, whose explanation has not reached them yet. So had those who have gone before them denied; but look at the fate of the unjust\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mcdiv{Some of them will believe in it, some will not. Your Lord knows the transgressors well.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mcdv{If they (still) call you a liar, tell them: ``For me my actions, for you yours. You are not answerable for my deeds, nor I for what you do."\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mcdvi{Some of them listen to you: But can you make the deaf hear who do not understand a thing?\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mcdvii{Some of them look toward you: But can you show the blind the way even when they cannot see?\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mcdviii{Surely God does not wrong anyone; they wrong themselves.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mcdix{The day He will gather them together it will appear to them that they had lived (in the world) but an hour of a day to make each other's acquaintance. Verily those who deny the meeting with God will be lost, and not find the way.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mcdx{Whether We show you some of the promise (of punishment in wait) for them, or take you to Ourself, their returning is to Us in the end; and God is a witness to all they do.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mcdxi{For every people there is an apostle; and when their apostle is come the matter is decided between them equitably, and no one is wronged.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mcdxii{They say: ``When is this promise going to come, if what you say is true?"\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mcdxiii{Say: ``I have no power over my own gain or loss other than what God may please." Every people have a certain term. When their time is come they can neither delay it an hour nor advance it a moment forward.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mcdxiv{Say: ``Have you ever thought if His punishment befalls you at night or in the day, what would the sinners do to despatch it?\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mcdxv{Will you believe it when it comes to pass? Indeed, you will believe it then. How impatient you were to hasten it!\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mcdxvi{Then will the sinners be told: ``Now taste everlasting torment. Should you be rewarded for anything else but what you did?"\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mcdxvii{Yet they want to be informed if it is true. Say: ``By my Lord, it is the truth. You cannot invalidate it."\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mcdxviii{Even if every soul that has sinned possessed whatever is on the earth, it would surely offer it to ransom itself, and feel repentant on seeing the punishment. Yet the sentence would be passed with justice, and not one will be wronged.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mcdxix{For all that is in the heavens and the earth belongs to God. Remember, the promise of God is true. But most of them do not know.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mcdxx{He is the giver of life and death, and to Him you will return.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mcdxxi{O men, a warning has come to you from your Lord, a remedy for the (doubts) of the heart, and a guidance and grace for those who believe.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mcdxxii{Say: ``It is the blessing and mercy of God; so rejoice in it. It is better than all that you amass."\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mcdxxiii{Say: ``Have you thought of what God has sent you for food, of which you have labelled some as lawful and some forbidden?" And ask: ``Has God commanded this, or you are imputing lies to God?"\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mcdxxiv{What do those who invent lies of God think about the Day of Reckoning? (Will they escape the judgement?) In fact God is gracious to men; but most of them are not grateful.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mcdxxv{There is no state you are in, whether reading from the Qur'an, or doing something else, but We are watching you as you are engaged in it. There is not the weight of an atom on the earth and in the heavens that is hidden from your Lord, nor is there anything smaller or greater than this but is recorded in the perspicuous Book.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mcdxxvi{Remember, there is neither fear nor regret for the friends of God.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mcdxxvii{Those who believe and obey God,\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mcdxxviii{For them is good news in the life of the world and in the life to come. There is no changing the words of God. That will be the great triumph.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mcdxxix{You should not be grieved by what they say. All glory is wholly for God: He is the one who hears and knows everything.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mcdxxx{Remember, whosoever is in the heavens and the earth belongs to God. Those who call on others they associate with God, follow nothing but conjecture, and only guess.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mcdxxxi{It is He who made the night for you to rest, and made the day enlightening. Indeed there are signs in this for those who listen.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mcdxxxii{They say: ``God has begotten a son." Immaculate is He and self-sufficient." Whatsoever is in the heavens and the earth belongs to Him. You have no proof for this (assertion): Why do you say things of God you do not know?\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mcdxxxiii{Say: ``Those who fabricate lies about God will never succeed."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mcdxxxiv{Let them profit by the world (while they may): In the end they will come back to Us. Then We shall make them taste severe punishment for having denied (the truth).\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mcdxxxv{Recount to them the story of Noah when he said to his people: ``O people, if you find my staying with you and warning through God's signs, unbearable to you, know that I have reposed my trust in God. So plan your move, and call your associates, and make certain of your plan; then do whatever you intend against me, allowing me no respite.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mcdxxxvi{If you turn away from me (remember) I do not ask any recompense from you. My reward is with God; I have been commanded to be one of those who submit to Him."\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mcdxxxvii{Even then they denied him; so We saved him and those with him, in the ark, and established them in the land, and drowned those who denied Our signs. So think of the fate of those who were warned (and took no heed).\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mcdxxxviii{Afterwards We sent many messengers who brought clear proofs to their peoples. But they were not prepared to believe what they had once denied. That is how We seal the hearts of the iniquitous.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mcdxxxix{Then after them We sent Moses and Aaron with Our signs to the Pharaoh and his nobles; but they behaved arrogantly, for they were a people full of guilt.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mcdxl{Thus, when the truth had come to them from Us, they said: ``Surely this is nothing but pure magic."\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mcdxli{``You say this of the truth," said Moses, ``after it has come to you. Is this magic? But sorcerers do not ever prosper."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mcdxlii{``Have you come," said they, ``to turn us back from what we found our ancestors doing, so that the two of you may attain supremacy in the land? We shall not believe in what you say.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mcdxliii{``Bring the cleverest magicians to me," said the Pharaoh.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mcdxliv{So when the magicians arrived, Moses said to them: ``Cast whatever (spell) you have to cast."\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mcdxlv{When they had cast (their spell) Moses said: ``What you have cast is only a charm which God will surely nullify. God does not verily render the deeds of evil-doers righteous.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mcdxlvi{God vindicates the truth by His commands, however the sinners may dislike it."\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mcdxlvii{But none of them put faith in Moses except some youths among his people who were nonetheless afraid lest the Pharaoh and his nobles should persecute them; for the Pharaoh was mighty in the land, and guilty of excesses.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mcdxlviii{Moses said: ``O my people, if you do believe in God place your trust in Him if you are obedient."\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mcdxlix{They answered: ``We have placed our trust in God. O Lord, do not make us a target of oppression for these tyrannical people,\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mcdl{And deliver us by Your grace from a people who do not believe."\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mcdli{We commanded Moses and his brother: ``Build homes for your people in Egypt, and make your houses places of worship, perform your acts of prayer and give happy tidings to those who believe."\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mcdlii{And Moses said: ``O Lord, have You bestowed on the Pharaoh and his nobles pomp and plenty in the life of this world that they might mislead people from Your path? Destroy their possessions, O Lord, and harden their hearts that they may not believe until they face the painful punishment."\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mcdliii{Said (the Lord): ``Your prayer is answered. Therefore persist and do not follow the path of those who are ignorant."\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mcdliv{And We brought the people of Israel across the sea, but the Pharaoh and his army pursued them wickedly and maliciously till he was on the point of drowning, and he said: ``I believe that there is no god but He in whom the people of Israel believe, and I submit to Him."\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mcdlv{``Yes, now" (was the answer), ``though before this you were disobedient and rebellious.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mcdlvi{We shall preserve your body today that you may be a lesson for those who come after you; as many a man is heedless of Our signs."\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mcdlvii{We gave the people of Israel a settled abode, and bestowed good things on them to eat and use. So they did not differ until they came to have knowledge. Your Lord will assuredly settle their differences on the Day of Resurrection.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mcdlviii{If you are in doubt of what We have sent down to you, then ask those who have been reading the Book (for a long time) before you. The truth has indeed come to you from your Lord, so do not be one of those who doubt,\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mcdlix{And do not be one of those who deny the signs of God, or you will be among the losers.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mcdlx{Verily those against whom the word of your Lord is pronounced will never believe,\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mcdlxi{Even though all the signs came to them, not till they face the grievous punishment.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mcdlxii{Why has there been no habitation that believed and profited by their faith, except the people of Jonah? When they came to believe, We removed from them the affliction of shame in the world, and made them prosperous for a time.\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mcdlxiii{If your Lord had willed, all the people on the earth would have come to believe, one and all.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mcdlxiv{Are you going to compel the people to believe except by God's dispensation? He puts doubt in (the minds of) those who do not think.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mcdlxv{Say: ``Observe all there is in the heavens and the earth." But signs or warnings will be of no avail to those who do not believe.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mcdlxvi{Can they expect anything but what the people before them had known? Say: ``Then wait. I am waiting with you."\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mcdlxvii{Thus do We deliver our apostles and those who believe. As a matter of duty We save the believers.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mcdlxviii{Say: ``O men, if you have doubt about my faith, then (know) I do not worship those you worship apart from God, but I worship God who makes you die; and I am commanded to be a believer,\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mcdlxix{And to set my face toward the way, as one upright, and not be one of those who associate others with God.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mcdlxx{And not to invoke any other than God, who can neither help nor hurt me; for if I do, I would surely be unjust.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mcdlxxi{Should God bring you harm there is none but He who could deliver you from it, and if He wish you good there is none who could take away His blessings: He showers them on those of His creatures as He please, and He is forgiving and kind."\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mcdlxxii{Say: ``O men, the truth has come to you from your Lord, so he who follows the right path does so for himself, and he who goes astray errs against himself, and I am not a guardian over you.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mcdlxxiii{Follow what is revealed to you, and persist until God pronounce His judgement; for He is the best of all judges."\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mcdlxxiv{\basmalahen ALIF LAM RA. This is a Book whose verses are indeclinable and distinct, which comes from One who is most wise and all-knowing,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mcdlxxv{(Proclaiming) that you should worship none but God. Verily I bring to you from Him a message of warning and rejoicing,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mcdlxxvi{And that you should seek His forgiveness and turn towards Him. He will bestow the best things of life on you for a time ordained, and favour those with blessings who are worthy of grace. But if you turn away, I fear the punishment of a terrible Day for you.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mcdlxxvii{To God have you to go back, and He has power over everything.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mcdlxxviii{Look, how they double up their breasts in order to hide from Him. But when they cover themselves up with their garments, He knows what they hide and what they expose. Indeed, He knows the secrets of the hearts.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mcdlxxix{There is not a creature that moves on the earth whose nourishment is not provided by God, whose place of sojourning and depositing is not known to Him. All things conform to a manifest law.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mcdlxxx{It is He who created the heavens and the earth In six spans, and has control over the waters (of life) so that he may bring out the best that everyone of you could do. Yet if you said to them: ``You shall certainly be raised from the dead," the unbelievers will say: ``This will be nothing but sorcery."\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mcdlxxxi{If We defer their punishment for a certain time, they will say: ``What is keeping it back?" And yet, the day it comes, they will not be able to avert it; and what they used to laugh at will encompass them.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mcdlxxxii{If We allow man to enjoy Our favours, and then take them away from him, he becomes despondent and ungrateful.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mcdlxxxiii{If We let him taste Our favours after adversity, he says: ``Misfortune has left me," and begins to brag and exult,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mcdlxxxiv{Except those who endure with patience and do the right, who will have pardon and a great reward.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mcdlxxxv{You may haply omit some of what has been revealed to you, and may be disheartened because they say: ``Why was no treasure sent down to him, or an angel accompanied him?" Yet you have been sent to warn alone, for God takes care of everything.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mcdlxxxvi{Do they say (of the Prophet): ``He has forged (the Qur'an)?" Say: ``Then bring ten Surahs like it, and call anyone except God to help you, if what you say is true."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mcdlxxxvii{If they do not answer you, then know it has been revealed with the knowledge of God, and that there is no god but He. (And say:) ``Will you now submit?"\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mcdlxxxviii{To those who desire the life of this world and its many allures, We shall pay them in full for their acts herein and will not withold any thing.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mcdlxxxix{Yet these are the people for whom there is nothing but Fire in the world to come. Fruitless will be what they have fashioned, and whatever they have done will perish.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mcdxc{Will he who has a clear proof from his Lord, which acts as evidence from Him, before which the Book of Moses was a way-giver and a grace, (not believe in it)? Whoever among the partisans does not believe in it shall have Hell as the promised award. So have no doubt about it, for surely it's the truth from your Lord, though most men may not believe.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mcdxci{Who is more wicked than he who invents lies about God? Such men shall be arraigned before their Lord, and the witnesses will testify: ``These are those who imputed lies to God." Beware! The scourge of God will fall on the unjust,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mcdxcii{Who obstruct others from the way of God and seek obliquity in it, and do not believe in the life to come.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mcdxciii{They shall not weaken (the power of) God on earth, nor find any other protector but God. Their punishment will be doubled, for they could neither hear nor see.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mcdxciv{They are verily those who exceeded themselves, and the (gods) they invented abandoned them.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mcdxcv{Undoubtedly they will be losers in the life to come.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mcdxcvi{But those who believe and do things good, and are humble before their Lord, are men of Paradise where they will abide for ever.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mcdxcvii{The semblance of these two groups is that of a man who is deaf and blind, and the other who can hear and see. Can they be equal? Why do you not reflect?\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mcdxcviii{We sent Noah to his people (and he said): ``I give you a clear warning.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mcdxcix{Do not worship anyone but God; for I fear the punishment of a dreadful day for you."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@md{The leaders of the people who were unbelievers, replied: ``We see that you are but a man like us, and see that none among us follows you but the meanest and immature of judgement, and do not see any excellence in you above us. In fact, we think you are a liar."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mdi{He said: ``O my people, think. If I have a clear proof from my Lord, and He has bestowed on me His grace, though unknown to you, can we force it upon you when you are averse?\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mdii{I do not demand for it any wealth from you, O my people. My reward is with God. And I will not drive those away who believe. They have also to meet their Lord. But I see you are an ignorant people.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mdiii{O my people, who will save me from God if I drive them away? Do you not understand?\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mdiv{I say not that I have the treasures of God, or that I possess the knowledge of the unknown. I do not claim to be an angel, nor can I say that God will not bestow any good on those you disdain, for God is cognisant of what is in their hearts. If I say this, I will surely be unjust."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mdv{They said: ``O Noah, you have argued with us, and disputed at length; so bring that (retribution) you promise, if you speak the truth."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mdvi{He replied: ``Only God will bring it on you if He please, and you cannot prevail against Him.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mdvii{Even if I wish to advise you aright, my counsel will not profit you if God intend that you go astray, for He is your Lord and to Him you will return."\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mdviii{Do they say you have fabricated it? Tell them: ``If I have fabricated it, then mine is the guilt; but I am clear of what you are guilty."\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mdix{And Noah was informed through revelation: ``Apart from those who have come to believe already not one of your people is going to believe. So grieve not for what they are doing.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mdx{Build an ark under Our eye and as We instruct. Do not plead for those who have been wicked, for they shall certainly be drowned."\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mdxi{So he built the ark; and when groups of his people passed by him, they scoffed at him. He said to them: ``Though you laugh at us (now), we shall laugh at you, as you are laughing at us.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mdxii{You will soon come to know who suffers the punishment that would put him to shame, and who suffers lasting torment."\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mdxiii{When Our command was issued and the waters gushed forth from the source, We said: ``Take into (the ark) a pair of every species, and members of your family other than those against whom the sentence has been passed already, and those who come to believe." But only a few believed in him.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mdxiv{And (Noah) said: ``Embark. In the name of God be its course and mooring. My Lord is surely forgiving and kind."\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mdxv{It sailed on waves like mountains (high), and Noah called to his son who was separated from him: ``Embark with us, O my son, and be not one of those who do not believe."\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mdxvi{``I shall go up a mountain," he said, ``which will keep me from the water." ``There is no getting away," said Noah, ``from the decree of God today, except for those on whom be His mercy." And a wave came between them, and he was among those who were drowned.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mdxvii{Then it was said: ``O earth, swallow back your water; and, O sky, desist." And the water subsided, and the decree was accomplished. The ark came to rest on Judi (Mount Ararat), and it was said: ``Away with the cursed people!"\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mdxviii{Noah called on his Lord and said: ``O Lord, my son is surely a member of my family, and verily Your promise is true, as You are the most just of all judges."\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mdxix{``O Noah", He answered, ``truly he is not of your family. He is surely the outcome of an unrighteous act. So ask Me not of what you do not know. I warn you not to be one of the ignorant."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mdxx{``Preserve me, O Lord," said (Noah), ``from asking You that of which I have no knowledge. If You do not forgive me and have mercy on me I shall be among those who perish."\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mdxxi{(And the Lord) said: ``O Noah, disembark with peace and safety from Us and blessings on you and the people with you. As for some (of them), We shall bestow advantages for a time, then send a grievous punishment on them."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mdxxii{This is news of the Unknown We reveal to you, which neither you nor your people knew before. So endure with patience. The future is for those who keep away from evil and follow the straight path.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mdxxiii{We sent to the people of 'Ad their brother Hud, who said: ``O my people, worship God; you have no other god but He. (As for the idols,) you are only inventing lies.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mdxxiv{O my people, I ask no recompense of you for it: My reward is with Him who created me. Will you not, therefore, understand?\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mdxxv{O my people, beg your Lord to forgive you, and turn to Him in repentance. He will send down rain in torrents for you from the shies, and give you added strength. So do not turn away from Him as sinners."\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mdxxvi{They said: ``O Hud, you have come to us with no proofs. We shall not abandon our gods because you say so, nor believe in you.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mdxxvii{All we can say is that some of our gods have smitten you with evil." He replied:" I call God to witness, and you be witness too, that I am clear of what you associate (in your affairs)\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mdxxviii{Apart from Him. Contrive against me as much as you like, and give me no respite.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mdxxix{I place my trust in God who is my Lord and your Lord. There is no creature that moves on the earth who is not held by the forelock firmly by Him. Verily the way of my Lord is straight.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mdxxx{If you turn away, then (remember) I have delivered to you the message I was sent with. My Lord will put other people in your place, and you will not be able to prevail against Him. Indeed my Lord keeps a watch over all things."\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mdxxxi{So, when Our command was issued We rescued Hud by Our grace, and those who believed, with him, and saved them from a dreadful doom.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mdxxxii{These were the people of 'Ad who denied the word of their Lord and rebelled against His apostles, and followed the bidding of every perverse tyrant.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mdxxxiii{So they were accursed in the world, and they will be damned on the Day of Doom. Beware! The 'Ad turned away from their Lord.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mdxxxiv{Be warned! Accursed are the people of 'Ad who were Hud's. To Thamud We Sent their brother Saleh. ``O my people," he said, ``worship God; you have no other god but He. It is He who raised you from the earth and settled you upon it. So beg your Lord to forgive you, and turn to Him in repentance. Surely my Lord is near and answers."\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mdxxxv{They said: ``O Saleh, we had placed our hopes in you, but you forbid us from worshipping that which our fathers worshipped, and we are suspicious of what you are calling us to."\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mdxxxvi{He said: ``O my people, have you considered that if my Lord has clearly shown me the way, and I have His blessings too, who will save me then from God if I disobey? You will only add to my ruin.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mdxxxvii{O my people, this she-camel of God is a token for you. So leave her alone to graze on God's earth, and do not molest her, otherwise the swiftest punishment would befall you."\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mdxxxviii{But they hamstrung her. Then (Saleh) said: ``You have but three days to enjoy life in your homes. Infallible is this promise.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mdxxxix{So, when Our command (of punishment) came We delivered Saleh by Our grace, and those who believed, with him, from the disgrace of that day. Verily your Lord is mighty and powerful.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mdxl{The sinners were seized by a blast from heaven, and lay overturned in their homes in the morning,\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mdxli{As though they had never lived there at all. Beware! The people of Thamud turned away from their Lord. Beware! Accursed are the people of Thamud.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mdxlii{Our angels came to Abraham with good news, and said: ``Peace on you. ``Peace on you too," said Abraham, and hastened to bring a roasted calf.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mdxliii{When they did not stretch their hands towards it he became suspicious and afraid of them. They said: ``Do not be afraid. We have been sent to the people of Lot."\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mdxliv{His wife who stood near, laughed as We gave her the good news of Isaac, and after Isaac of Jacob.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mdxlv{She said: ``Woe betide me! Will I give birth when I am old and this my husband be aged? This is indeed surprising!"\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mdxlvi{``Why are you surprised at the command of God? God's mercy and blessings be upon you, O members of this household," they said. ``Verily He is worthy of praise and glory."\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mdxlvii{When Abraham's fear was dispelled, and the good news had come to him, he pleaded for the people of Lot with Us.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mdxlviii{Abraham was kind, compassionate, and penitent.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mdxlix{``Desist from pleading, O Abraham," (they said). ``Your Lord's command has verily been issued, and a punishment that cannot be averted is bound to fall on them."\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mdl{So when Our angels came to Lot, he grieved for them, and felt powerless to help them, and said: ``This is a day of sorrow.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mdli{His people came excited to him. They were addicted to sin already. Said (Lot): ``O my people, these daughters of mine are cleaner (and lawful) for you. Have fear of God, and do not shame me before my guests. Is there no man of discernment among you?"\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mdlii{They said: ``You know we have no need for your daughters, and know well what we want."\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mdliii{``I wish I had the power to resist you," said (Lot), ``or powerful support."\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mdliv{(The angels) said: ``O Lot, we have verily been sent by your Lord. They will never be able to harm you. So, leave late at night with your family, and none of you should turn back to look; but your wife will suffer (the fate) they are going to suffer. Their hour of doom is in the morning: Is not the morning nigh?"\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mdlv{So when the decreed moment arrived, We turned the habitations upside down, and rained upon them stones of hardened lava in quick succession,\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mdlvi{Impressed with (the signs) of your Lord. And such (punishment) is not far for the (other) transgressers.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mdlvii{We sent to Midian their brother Shu'aib. He said: ``O my people, worship God; you have no other god but He. So do not give in short measure nor underweigh. I see you are prosperous, but I fear the doom of an overwhelming Day for you.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mdlviii{So, O my people, weigh and measure with justness, and do not withhold things due to men, and do not spread corruption in the land, despoiling it.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mdlix{That which is left to you by God is better, if you are true believers; yet I am not a warden over you."\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mdlx{They said: ``O Shu'aib, does your piety teach that we should abandon what our fathers worshipped, or desist from doing what we like with our goods? How gracious a man of discernment you are indeed!"\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mdlxi{He said: ``O my people, think. I have a clear sign from my Lord, who has also given me a goodly provision, and I do not wish for myself what I forbid you: I only wish to reform you as best I can. My success is from God alone. In Him I have placed my trust, and to Him I turn.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mdlxii{``O my people (I fear) lest your opposition to me should bring you the like of what befell the people of Noah or Hud or Saleh; and the people of Lot are not distant from you.\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mdlxiii{``Beg your Lord to forgive you, and turn to Him. Indeed my Lord is compassionate and loving."\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mdlxiv{They said: ``O Shu'aib, much of what you say is meaningless to us, and then (for sure) you are powerless among us. But for your clan we would have stoned you to death. You have no power over us.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mdlxv{He said: ``My clan seems mightier to you than God whom you neglect and push behind your backs. Surely what you do is within the power of my Lord.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mdlxvi{Do on your part what you can, O people, I will do what I will. You will come to know who suffers the punishment that would put him to shame, and who is the liar. So watch; I am watching with you."\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mdlxvii{And when Our word came to pass, We rescued Shu'aib and those who believed, with him, by Our grace, but those who were wicked were seized by a punishment from heaven, and lay overturned in their homes in the morning.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mdlxviii{As though they had not dwelt there at all. Beware! Condemmed were the people of Midian as those of Thamud had been before them!\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mdlxix{We sent Moses with Our signs and full authority\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mdlxx{To the Pharaoh and his nobles, but they followed the bidding of Pharaoh, though the bidding of Pharaoh was unrightful.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mdlxxi{He shall be at the head of his people on the Day of Resurrection, and drive them into Hell like cattle driven to water -- what an evil watering-place to reach!\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mdlxxii{Damned will they be in this world, and on the Day of Doom how evil the gift that they will receive!\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mdlxxiii{These are a few accounts of settlements that We narrate to you. Some still survive, and some have been mowed down.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mdlxxiv{We did not wrong them; they wronged themselves. When your Lord's chastisement descended upon them, their gods, on whom they called apart from God, were not of the least avail, and all they did was only to add to their destruction.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mdlxxv{Such is the punishment of your Lord when He seizes human settlements in the acts of wickedness. Surely His hold is grievous and terrible.\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mdlxxvi{In this surely is a sign for him who fears the torment of the Hereafter, the day when mankind will be assembled together, which will be a day when all things would become evident.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mdlxxvii{We are deferring it only for a time ordained.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mdlxxviii{The day it comes no soul will dare say a word but by His leave; and some will be wretched, some will be blessed.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mdlxxix{And those who are doomed, will be in Hell: For them will be sighing and sobbing,\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mdlxxx{Where they will dwell so long as heaven and earth endure, unless your Lord will otherwise. Verily your Lord does as He wills.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mdlxxxi{Those who are blessed will be in Paradise, where they will dwell so long as heaven and earth survive, unless your Lord wills otherwise: This will be a gift uninterrupted.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mdlxxxii{So, you should not entertain any doubt about those whom they worship: They only worship what their fathers had worshipped before them. We shall verily give them their meed without diminution.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mdlxxxiii{Verily We gave to Moses the Book, but there was disagreement about it. Had the decree of your Lord (delaying it) not been issued the matter would have been settled between them. They are still suspicious of it and in doubt.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mdlxxxiv{Surely your Lord will reward everyone in accordance with his deeds. He is certainly aware of all they do.\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mdlxxxv{So, you and those who turned to God with you, should walk along the straight path as you have been commanded, and do not transgress, for He verily sees whatsoever you do.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@mdlxxxvi{Do not lean towards the wicked, or you will be caught in the flames of Hell, and have none to befriend you other than God, nor will you be given help.\qt@no{(113)}}
\qt@newcmd\qurantrans@en@mdlxxxvii{Stand up for the service of prayer at the two ends of day and the first watch of night. Remember that good deeds nullify the bad. This is a reminder for those who are observant.\qt@no{(114)}}
\qt@newcmd\qurantrans@en@mdlxxxviii{Be steadfast, for verily God does not let the reward of those who are upright and do good to go waste.\qt@no{(115)}}
\qt@newcmd\qurantrans@en@mdlxxxix{If only there had been men endued with virtue in the ages before you, who could preserve men from doing evil in the world, other than the few We saved from among them. Those who were wicked followed that which made them dissolute, and became sinners.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@mdxc{Your Lord would not surely destroy unjustly human habitations so long as the people are righteous.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@mdxci{But if your Lord had pleased He could have made all human beings into one community of belief. But they would still have differed from one another,\qt@no{(118)}}
\qt@newcmd\qurantrans@en@mdxcii{Except those on whom your Lord had mercy for which He has created them. But fulfilled shall be the word of your Lord. ``I will fill up Hell with jinns and men."\qt@no{(119)}}
\qt@newcmd\qurantrans@en@mdxciii{The histories of apostles that We relate to you are (meant) to strengthen your heart. Through them has the truth come to you, and guidance, and reminder to those who believe.\qt@no{(120)}}
\qt@newcmd\qurantrans@en@mdxciv{Say to the infidels. ``Act as best you can, we are acting too;\qt@no{(121)}}
\qt@newcmd\qurantrans@en@mdxcv{And wait (for what is to come), we are also waiting (to see)."\qt@no{(122)}}
\qt@newcmd\qurantrans@en@mdxcvi{To God belong the secrets of the heavens and the earth, and all things will go back to Him. So worship Him and put your trust in Him; your Lord is not heedless of what you do.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@mdxcvii{\basmalahen ALIF LAM RA. These are the verses of the immaculate Book.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mdxcviii{We have sent it down as a clear discourse that you may understand.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mdxcix{Through the revelation of this Qur'an We narrate the best of histories of which you were unaware before.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mdc{When Joseph told his father: ``O my father, I saw eleven stars and the sun and the moon bowing before me in homage,"\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mdci{He said: ``O son, do not narrate your dream to your brothers, or they will plot against you. Surely Satan is man's acknowledged foe.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mdcii{Your Lord will choose you and teach you to interpret events, and confer His favours on you and the house of Jacob, as He had done in the case of two ancestors of yours, Abraham and Isaac, before you. Indeed your Lord is all-knowing and all-wise."\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mdciii{In the story of Joseph and his brothers are lessons for those who inquire.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mdciv{``Surely Joseph and his brother are dearer to our father than we," (said his half brothers) ``even though we are a well-knit band. Our father is surely in the wrong.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mdcv{Let us kill Joseph or cast him in some distant land so that we may get our father's exclusive affection; then play innocent."\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mdcvi{One of them said: ``If you must do so, then do not kill Joseph, but throw him into an unused well. Some passing caravan may rescue him."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mdcvii{(Then going to their father) they said: ``O father, why don't you trust us with Joseph? We are in fact his well-wishers.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mdcviii{Let him go out with us tomorrow that he may enjoy and play. We shall take care of him."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mdcix{He said: ``I am afraid of sending him with you lest a wolf should devour him when you are unmindful."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mdcx{They replied: ``If a wolf should devour him when we are there, a well-knit band, we shall certainly be treacherous."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mdcxi{So, when they took him out they planned to throw him into an unused well. We revealed to Joseph: ``You will tell them (one day) of this deed when they will not apprehend it."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mdcxii{At nightfall they came to their father weeping,\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mdcxiii{And said: ``We went racing with one another and left Joseph to guard our things when a wolf devoured him. But you will not believe us even though we tell the truth."\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mdcxiv{They showed him the shirt with false blood on it. (Their father) said: ``It is not so; you have made up the story. Yet endurance is best. I seek the help of God alone for what you impute."\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mdcxv{A caravan happened to pass, and sent the water-carrier to bring water from the well. He let down his bucket (and pulled Joseph up with it). ``What luck," said the man; ``here is a boy;" and they hid him as an item of merchandise; but what they did was known to God.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mdcxvi{And they sold him as worthless for a few paltry dirham.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mdcxvii{The Egyptian who bought him instructed his wife: ``House him honourably. He may be of use to us. We may even adopt him as a son." So, We firmly established Joseph in the land, and taught him the interpretation of dreams. God dominated in his affairs, though most men do not know.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mdcxviii{When he reached the prime of life We gave him wisdom and knowledge. Thus We reward those who are good.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mdcxix{But she in whose house he resided wished to seduce him and, closing the doors, said: ``Come into me. ``God forbid!" he said; ``he is my master who has approved my stay. Surely those who act wrongly do not prosper."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mdcxx{But the woman desired him, and he would have desired her but for the indication he received from his Lord. This was so that We may avert both evil and lechery from him, for he was one of Our chosen devotees.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mdcxxi{Both of them raced to the door, and she (grabbed and) rent his shirt from behind. They met her lord outside the door. ``There is no other penalty for a man," said she, ``who wanted to outrage your wife but imprisonment or grievous punishment."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mdcxxii{(Joseph) said: ``It was she who wanted to seduce me." And a witness from her family testified: ``If the shirt is torn from the front then the woman is speaking the truth, and he is a liar.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mdcxxiii{But if the shirt is torn from behind then she is a liar, and he speaks the truth."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mdcxxiv{When the husband saw the shirt torn at the back, he said: ``Surely this is a woman's ruse, and the wiles of women are great.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mdcxxv{Ignore this affair, O Joseph; and you, O woman, ask forgiveness for your sin, for you were surely errant."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mdcxxvi{In the city the women gossiped: ``The minister's wife longs after her page. He has captured her heart. We think she is in clear error."\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mdcxxvii{When she heard their slanderings, she sent for them and prepared a banquet, and gave each of them a knife (for paring fruit), and called (to Joseph): ``Come out before them." When they saw him, the women were so wonderstruck they cut their hands, and exclaimed: ``O Lord preserve us! He is no mortal but an honourable angel."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mdcxxviii{She said: ``This is the one you blamed me for. I did desire his person, but he preserved himself from sin. Yet in case he does not do my bidding he will be put into prison and disgraced."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mdcxxix{(Joseph) prayed: ``O Lord, dearer is prison than what they invite me to. Unless You turn their guiles away from me I shall succumb to their charms and thus become a pagan."\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mdcxxx{His Lord heard his prayer, and averted the women's wiles from him. He verily hears and knows everything.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mdcxxxi{And yet in spite of having seen these clear proofs they found it proper to incarcerate him for a time.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mdcxxxii{Two other youths were imprisoned along with him. Said one of them: ``I dreamt that I was pressing grapes;" and the other: ``I dreamt that I was carrying bread on my head, and the birds were pecking at it. You tell us the meaning of this. You seem to be a righteous man."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mdcxxxiii{(Joseph) answered: ``I will give you its interpretation before the food you are served arrives. This knowledge is one of the things my Lord has taught me. I have given up the religion of those who do not believe in God and deny the life to come.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mdcxxxiv{I follow the faith of my fathers, of Abraham and Isaac and Jacob. We cannot associate anyone with God. This is among God's favours to us and to all mankind; but most men are not grateful.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mdcxxxv{(Tell me) O fellow-prisoners, are a number of gods better, or one God omnipotent?\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mdcxxxvi{(What) you worship besides Him are nothing but names that you and your fathers have assigned, for which no sanction has been sent down by God. Authority belongs to God alone. He commands that you worship none but Him. This is the right way; but most men are ignorant.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mdcxxxvii{O fellow-prisoners, one of you will serve wine to your master, the other will be crucified and the birds will peck at his brain. Determined is the matter of your inquiry."\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mdcxxxviii{And (Joseph) asked the man he knew would be released: ``Remember me to your lord;" but Satan made him forget to mention this to his lord, and Joseph remained in prison for a number of years.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mdcxxxix{(One day) the king said (to his courtiers): ``I saw seven fat cows in a dream being devoured by seven lean ones, and seven ears of corn that were green and seven others that were seared. O courtiers, tell me the significance of my dream, if you know how to interpret them."\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mdcxl{``They were only confused dreams," they said; ``we do not know how to interpret them."\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mdcxli{Then the servant, who of the two had been released, remembering (Joseph), said: ``I will give you its interpretation; let me go for it."\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mdcxlii{(And coming to the prison) he said: ``O Joseph the truthful, tell us (the meaning of) seven fat cows being devoured by seven lean ones, and seven green ears of corn and seven seared, that I may go back to the people and tell them."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mdcxliii{He said: ``Sow as usual for seven years, and after reaping leave the corn in the ears, except the little you need for food.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mdcxliv{Then there will come seven years of hardship which will consume the grain you had laid up against them, except a little you may have stored away.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mdcxlv{This will be followed by a year of rain, and people shall press (the grapes)."\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mdcxlvi{The king said: ``Bring him to me. So when the messenger came to Joseph, he said: ``Go back to your lord and ask him: 'How fare the women who had cut their hands?' My Lord is cognisant of their guile."\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mdcxlvii{The king asked the women: ``What was the affair of seducing Joseph?" ``God preserve us," they said; ``we know no evil against him." The wife of the minister said: ``The truth has now come out. It was I who desired to seduce him, but he is indeed a man of virtue." --\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mdcxlviii{(At this Joseph remarked:) ``From this (the Minister) should know that I did not betray him in his absence, and that God does not surely let the wiles of those who betray ever succeed.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mdcxlix{But I do not wish to absolve myself, for the soul is prone to evil, unless my Lord have mercy. Indeed my Lord is forgiving and kind." --\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mdcl{When the king heard this he said: ``Bring him to me. I shall take him in my special service." When he had talked to him, he said: ``Today you are established in a rank of trust with us."\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mdcli{``Appoint me over the granaries of the land," (he said); ``I shall be a knowledgeable keeper."\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mdclii{Thus We gave Joseph authority in the land so that he lived wherever he liked. We bestow Our favours on whomsoever We please, and do not allow the reward of those who are good to go waste.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mdcliii{And certainly the recompense of the life to come is better for those who believe and follow the right path.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mdcliv{The brothers of Joseph came (to Egypt) and visited him. He recognised them, though they did not recognise him.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mdclv{When he had supplied their provisions, he said to them: ``Bring your (half) brother with you. Have you not seen that I have given full measure, and that I am the best of hosts?\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mdclvi{But if you do not bring him with you, then I shall have no grain for you, nor should you come back to me."\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mdclvii{They said: ``We shall request his father, and will certainly do that."\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mdclviii{Then he ordered his servants: ``Put their money back in their packs: They may find it on reaching home, and perhaps come again."\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mdclix{When they returned to their father, they said: ``O father, a further measure has been denied us. So send our brother with us that he may bring more grain. We shall take care of him."\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mdclx{He replied: ``Should I trust you with him as I did his brother? But God is the best of guardians, and most merciful of all."\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mdclxi{When they unpacked their goods they said: ``O father, what more can we ask? Look, even our money has been returned. We shall go and bring a camel-load more of grain for our family, and take good care of our brother. That will be an easy measure."\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mdclxii{He said: ``I will never send him with you until you swear by God that you will bring him back to me, unless all of you are overtaken (by misfortune)." When they had given their promise, he said: ``God is witness to our conversation."\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mdclxiii{(As they were leaving) their father said to them: ``O my sons, do not seek one approach but employ different ways (of attaining your object). If anything should befall you from God I shall not be able to avert it, for all authority belongs to God. I have placed my trust in Him, and the trusting should rely on Him alone."\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mdclxiv{When they entered as their father had advised them, nothing could avail them against (the will of) God, yet it confirmed a premonition Jacob had, for verily he had knowledge as We had taught him, though most men do not know.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mdclxv{When they came to Joseph he made his brother his guest, and said: ``I am your brother. So do not grieve for what they had done."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mdclxvi{When he had given them their provisions he put his goblet in his brother's saddle-bag. Then a crier announced: ``O men of the caravan, you are thieves."\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mdclxvii{They turned to them and asked: ``What is it you have lost?"\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mdclxviii{``We cannot find the master's goblet. Whoever comes up with it will be given a camel-load of grain; I vouch for it."\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mdclxix{They said: ``We swear by God. You know we did not come to commit any crime in the land, nor are we thieves."\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mdclxx{``What should be the punishment," they were asked, ``in case you are liars?"\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mdclxxi{``The punishment for that (should be)," they said, ``that he in whose luggage it is found should be held as punishment. This is how we repay the wrong-doers."\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mdclxxii{So he searched their saddle-bags before his brother's, then produced the cup from his brother's bag. That is how We planned an excuse for Joseph, for under the law of the king he could not detain his brother unless God so willed. We raise the status of whom We please. Over every man of knowledge there is one more knowing.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mdclxxiii{Said the brothers: ``If he has stolen (no wonder), his brother had stolen before." But Joseph kept this secret and did not disclose it to them, and said (to himself): ``You are worse in the degree of evil, for God knows better of what you allege."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mdclxxiv{They said: ``O Minister, he has an aged father, so keep one of us in his place. We see you are a virtuous man."\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mdclxxv{``May God forgive us," he said, ``if we hold any one but him with whom we found our property, or else we would be unjust."\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mdclxxvi{When they despaired of (persuading) him, they went aside to confer. The oldest of them said: ``You know that your father has pledged you in the name of God, and you have been guilty of iniquity in the case of Joseph before. I will not leave this place unless my father permits or God decides for me, for He is the best of all judges.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mdclxxvii{So, go to your father and tell him: 'O father, your son has committed a theft. We bear witness to only what we know; we could not prevent the unknown.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mdclxxviii{Enquire from the people of that city, or ask the men of the caravan with whom we have come. We are verily speaking the truth.'"\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mdclxxix{``No," said (the father). ``You have made up the story; but patience is best; God may bring them back to me. He is all-knowing and all-wise."\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mdclxxx{He turned away from them and cried: ``Alas for Joseph!" And his eyes turned white with grief which he bore in silence.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mdclxxxi{``By God," said they, ``you will never stop thinking of Joseph till you are consumed or perish."\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mdclxxxii{He replied: ``I cry my plaint and grief to God, and know from God what you do not know.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mdclxxxiii{O sons, go in search of Joseph and his brother, and do not despair of the mercy of God. Only they despair of God's mercy who do not believe."\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mdclxxxiv{When they returned to him, they said (to Joseph): ``O Minister, calamity has befallen us and our people. We have brought but a meagre sum, but give us full measure as alms bestowed. God surely rewards those who give alms."\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mdclxxxv{, He said: ``Do you know what you did to Joseph and his brother in your ignorance?"\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mdclxxxvi{They said: ``Surely you are not Joseph!" ``I am Joseph," he said, ``and this is my brother. God has been gracious to us; for God does not verily deprive those who fear Him and are patient of the recompense of those who are good."\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mdclxxxvii{They said: ``By God, God has favoured you above us, for we have indeed been sinners."\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mdclxxxviii{``There is no blame on you today," he said, ``May God forgive you. He is the most merciful of all.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mdclxxxix{Take my shirt and put it on my father's face; his eyesight will be restored; and bring your entire family to me."\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mdcxc{The caravan departed (from Egypt) and Jacob said (at home): ``Say not that I am in my dotage, but I get the smell of Joseph."\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mdcxci{They said: ``By God, you are still persisting in your old delusion."\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mdcxcii{Then, as the harbinger of happy news arrived and put the garment over his face his eyesight was restored. He said: ``Did I not tell you? I know from God what you do not know."\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mdcxciii{Said (the sons): ``O our father, pray for us that our sins be forgiven, for we are really sinners."\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mdcxciv{``I will ask my Lord to forgive you," he replied, ``for He is forgiving and kind."\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mdcxcv{When they went back to Joseph he gave his father and mother a place of honour, and said: ``Enter Egypt in peace by the will of God."\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mdcxcvi{He seated his parents by his side on the throne; and they fell down before him in homage. ``O my father," said Joseph, ``this is the meaning of my earlier dream. My Lord has made it come true. He was gracious in getting me out of the prison, and bringing you out of the desert to me after the discord created by Satan between me and my brothers, for my Lord is gracious to whomsoever He please. He is indeed all-knowing and all-wise.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mdcxcvii{O my Lord, you have given me dominion and taught me the interpretation of dreams; O Creator of the heavens and the earth, You alone are my saviour in this world and the world to come; let me die submitting to You, and place me among the upright."\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mdcxcviii{This is news of the unknown We reveal to you, for you were not present when Joseph's brothers agreed on their course of action, and devised their plot.\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mdcxcix{Many men will not believe howsoever you wish,\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mdcc{Even though you ask no recompense (for it). It is only a warning for all mankind.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mdcci{How many a sign there is in the heavens and the earth which most men pass by and ignore,\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mdccii{Not only do they not believe in God, but also associate others with Him.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mdcciii{Do they really believe that an all-embracing punishment of God will not come upon them, or the Day of Doom overtake them suddenly while they remain unaware?\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mdcciv{Say: ``My way, and that of my followers, is to call you to God with full perception. All glory to God, I am not an idolater."\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mdccv{All the apostles We had sent before you were men of those regions, to whom We sent Our revelations. Have they not travelled on the earth and seen what befell the people before them? Surely the abode of the Hereafter is better for those who fear straying from the right path. Do you not understand?\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mdccvi{When the apostles despaired and thought they were made false promises, Our help arrived, and We delivered whom We pleased; but never will Our punishment be averted from the sinners.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mdccvii{Verily in their accounts is a lesson for men of wisdom. This is not a fictitious tale, but a verification of earlier Books, and a clear exposition of everything, and a guidance and grace for those who believe.\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mdccviii{\basmalahen ALIF LAM MIM RA. These are the verses of the Scripture. Whatsoever is sent down to you from your Lord is the truth; but most men do not believe.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mdccix{It is God who raised the skies without support, as you can see, then assumed His throne, and enthralled the sun and the moon (so that) each runs to a predetermined course. He disposes all affairs, distinctly explaining every sign that you may be certain of the meeting with your Lord.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mdccx{It is He who stretched the earth and placed upon it stabilisers and rivers; and made two of a pair of every fruit; (and) He covers up the day with the night. In these are signs for those who reflect.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mdccxi{On the earth are tracts adjoining one another, and vineyards, fields of corn and date-palm trees, some forked, some with single trunks, yet all irrigated by the self-same water, though We make some more excellent than the others in fruit. There are surely signs in them for those who understand.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mdccxii{If you are surprised, then astonishing is the speech (of those who say:) ``Having turned to dust shall we be raised as a new creation?" They are the ones who deny their Lord, and they will have collars around their necks. They are the inmates of Hell, where they will abide for ever.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mdccxiii{They want you to hasten the evil before the good, even when there have been examples of retribution before them. Though certainly your Lord forgives human beings for their iniquities, your Lord is severe of retribution.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mdccxiv{The unbelievers say: ``Why no miracle was sent down to him by his Lord?" But you are only a bearer of warnings, and a guide for every nation.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mdccxv{God is cognisant of what every female carries in her womb, or what the wombs want or exceed (of their disburdening time). With Him all things are in determined measure.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mdccxvi{He is the knower of the known and the unknown, the mighty and most high.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mdccxvii{He who keeps his secret among you is the same to Him as he who speaks out publicly, and he who hides himself in the night and walks freely in the day.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mdccxviii{His angels keep watch over him in succession (night and day), in front and behind, by God's command. Verily God does not change the state of a people till they change themselves. When God intends misfortune for a people no one can avert it, and no saviour will they have apart from Him.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mdccxix{It is He who makes the lightning flash for fear and hope, and raises massive clouds.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mdccxx{The thunder sings His praises, and the angels too, for awe of Him. He sends thunder-bolts and strikes whosoever He will with them: Even then it is God they contend about! But mighty is He in (His) power.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mdccxxi{To call on Him is true (supplication). For those they invoke other than Him do not answer them at all, except like a man who stretches his hands towards the water that it reach his mouth, but it will never reach it. Not more than error are the prayers of infidels.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mdccxxii{Whosoever is in the heavens and on earth bows to God in submission with a will or perforce, as do their shadows in the morning and evening.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mdccxxiii{Ask them: ``Who is the Lord of the heavens and the earth?" (They will) say: ``God." Say: ``Then why do you take protectors besides Him who have no power over their own gain or loss?" Say: ``Can a blind man and one who can see be equal? Or, darkness and light be the same? Or, have those they have appointed equal of God created, as He has created, so that the (two) creations look alike to them?" Say: ``God is the creator of everything. He is One, the omnipotent."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mdccxxiv{He sends down water from the skies, which flows in channels according to their capacity, with the scum borne on the surface of the torrent, as rises the scum when metals are heated on the fire for making ornaments and household utensils. This is how God determines truth and falsehood. The scum disappears like the foam on the bank, and that which is useful to man remains on the earth. That is how God sets forth precepts of wisdom.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mdccxxv{For those who obey their Lord is excellence. For those who fail to obey, the reckoning will be hard, even if they possess and give as ransom all that there is on the earth, and as much more; and Hell will be their abode: How wretched is its wide expanse!\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mdccxxvi{Can a man who knows what has been revealed to you from your Lord is the truth, and one who cannot see, be the same? They alone take warning who are wise,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mdccxxvii{Who fulfil their covenant with God and do not break their agreement,\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mdccxxviii{Who keep together what God has ordained held together, and fear their Lord and dread the hardship of the Reckoning,\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mdccxxix{Who persevere in seeking the way of their Lord, who fulfil their devotional obligations, and spend of what We have given them, secretly or openly, who repel evil with good: For them is the recompense of Paradise:\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mdccxxx{Perpetual gardens which they will enter with those of their fathers, spouses and children who were virtuous and at peace, with angels coming in through every door\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mdccxxxi{Saying: ``(Welcome,) peace on you, for you persevered." How excellent the recompense of Paradise!\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mdccxxxii{As for those who break God's covenant after validating it, and sever relations which God ordained cohered, and spread corruption in the land, there is condemnation for them and an evil abode.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mdccxxxiii{God increases or decreases the fortunes of whosoever He will, and they rejoice in the life of this world. Yet the life of this world is nothing but a merchandise as compared to the life of the next.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mdccxxxiv{The unbelievers say: ``How is it that no miracle was sent down to him by his Lord?" Say: ``God leads whosoever He wills astray, and guides whoever turns to Him in repentance.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mdccxxxv{Those who believe and find peace in their hearts from the contemplation of God: Surely there is peace of heart in the contemplation of God!"\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mdccxxxvi{Those who believe and do the right, have happiness, and an excellent resting place.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mdccxxxvii{That is how We have sent you to a people before whom many a people have come and gone, so that you may announce to them whatever We have revealed to you. But they do not believe in Ar-Rahman. Tell them: ``He is my Lord. There is no other god but He. In Him have I placed my trust, and to Him is my reversion."\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mdccxxxviii{Had there been a Qur'an which could have made the mountains move, or the earth to cleave asunder, or the dead to speak, yet all authority belongs to God. Have the believers not learnt that if God had so willed He could have guided all mankind? As for unbelievers, they will be visited by misfortune endlessly for what they have done; or it would sit in their homes till the promised threat of God comes to pass. Surely God does not go back on His promise.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mdccxxxix{Many an apostle have they mocked before you; but I allowed the unbelievers respite, then I seized them. How severe was My punishment then!\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mdccxl{Who is it who stands (watch) over every soul for what it does? Yet they ascribe compeers to God. Say: ``Then name them. Or are you announcing to God what He does not know on the earth? Or is it only empty talk? In fact, the unbelievers' plots are made to look attractive to them, so that they are held back from the right path. Whosoever God allows to go astray has none to show him the way.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mdccxli{For them is punishment in this world; and the punishment of the world to come is far more severe. They will have no one to save them from God.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mdccxlii{The likeness of Paradise promised the pious and devout is (of a garden) with streams of rippling water, everlasting fruits and shade. This is the recompense of those who keep away from evil; but the recompense of those who deny the truth is Hell.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mdccxliii{Those to whom We have given the Scriptures rejoice in what We have sent down to you; but some of their factions reject some of it. Tell them: ``I am commanded to worship only God, and not to associate compeers with Him. To Him I call you, and to Him is the destination."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mdccxliv{That is how We have sent down this (Qur'an) as a code of clear judgement. But if you follow their caprices, now that you have been given knowledge, you will have no friend or protector against God.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mdccxlv{We sent many apostles before you, and bestowed on them wives and children, but it was not for any apostle to come up with a miracle unless by the leave of God. For every age there is a law.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mdccxlvi{God abrogates or confirms whatsoever He will, for He has with Him the Book of Books.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mdccxlvii{Whether We allow you to see (the punishment) We have promised them, or end your life before (its execution), it is certainly for you to convey the message; the reckoning is for Us to do.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mdccxlviii{Do they not see Us advancing from all sides into their land and reducing its frontiers? It is for God to judge; and there is none to reverse His judgement. He is swift at reckoning.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mdccxlix{Surely those who had gone before them had also plotted; but God's is all the planning, for He has knowledge of what each does. The unbelievers will soon learn for whom is the guerdon of Paradise.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mdccl{Yet those who are disbelievers say: ``You are not the apostle sent (by God)." Tell them: ``God is sufficient as witness between me and you, and he who has knowledge of the Book."\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mdccli{\basmalahen ALIF LAM RA. A Book We have sent down to you that you may lead men out of darkness into light, by their Lord's command, to the path of the mighty, the worthy of praise.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mdcclii{God, to whom belongs all there is in the heavens and the earth. Woe to the unbelievers for the terrible punishment (that awaits).\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mdccliii{Those who hold the life of this world dearer than that of the next, who obstruct the path of God and seek obliquity in it, have wandered far into error.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mdccliv{We never sent a messenger who did not speak the tongue of his people, that he may explain to them distinctly. God leads whosoever He wills astray, and shows whoever He wills the way: He is all-mighty and all-wise.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mdcclv{Remember when We sent Moses with Our signs (We said): ``Bring your people out of darkness into light, and remind them of the visitations of God. Indeed there are signs in this for every steadfast, thankful soul"\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mdcclvi{So Moses said to his people: ``Remember the favours of God when He saved you from the people of Pharaoh who afflicted you with oppression, slaying your sons but keeping alive your women, which was a great trial from your Lord."\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mdcclvii{Remember, your Lord proclaimed: ``I shall give you more if you are grateful; but if you are thankless then surely My punishment is very great."\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mdcclviii{And Moses said: ``What if you and all the people of the world deny, God is unconcerned and worthy of praise."\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mdcclix{Has not the news of those before you, the people of Noah and 'Ad and Thamud, and those who came after them, come to you? None knows (about) them except God. Their apostles came to them with clear proofs, but they tried to silence them and said: ``We do not believe in what you have been sent with, and we are in doubt of what you call us to, about which we are in disquiet.'\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mdcclx{Said their apostles: ``Can there be doubt about God, the originator of the heavens and the earth? He calls you to forgive some of your sins, and give you respite for a time ordained." They said: ``You are only men like us, and yet you wish to turn us away from what our fathers worshipped. Bring to us then a clear proof."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mdcclxi{Their apostles said to them: ``Indeed we are men like you, but God bestows His favours on whomsoever He wills among His creatures. It is not in our power to bring a miracle for you without the leave of God. The believers should only place their trust in God.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mdcclxii{And why should we not repose our trust in God when He has shown us our paths of duty to Him? We shall bear with fortitude the hardships you inflict upon us. The trusting place their trust in God."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mdcclxiii{The unbelievers said to their apostles: ``We shall drive you out of our land, or else you come back to our fold." Their Lord then communicated to them: ``We shall annihilate these wicked people,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mdcclxiv{And establish you in their place. This is for him who fears My station, and dreads My commination."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mdcclxv{Then (the apostles) asked of God's assistance, and every arrogant tyrant was frustrated:\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mdcclxvi{Before him is Hell, and he will get putrid liquid to drink.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mdcclxvii{He will sip it, yet will not be able to gulp it down. Death will crowd in upon him from every side, but die he will not. A terrible torment trails him.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mdcclxviii{Like ashes are the deeds of those who deny their Lord, which the wind blows away on a windy day. They shall have no power over what they earned. This is the farthest limit of going astray.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mdcclxix{Do you not see that God has created the heavens and the earth with ultimate reason? If He so wills He could take you away from the earth and raise a new creation (in your place).\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mdcclxx{This is well within the power of God.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mdcclxxi{When they will all appear before God together, the weak will say to those who were arrogant: ``We were your followers, so can you now save us a little from God's punishment?" They will say: ``If we had been guided by God we would surely have shown you the way. To lament or endure is all the same to us now. No getting away is there for us."\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mdcclxxii{When the reckoning is over Satan will say: ``The promise that was made to you by God was indeed a true promise; but I went back on the promise I had made, for I had no power over you except to call you; and you responded to my call. So blame me not, but blame yourselves. Neither can I help you nor can you give me help. I disavow your having associated me earlier (with God). The punishment for those who are wicked is painful indeed."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mdcclxxiii{Those who believed and did the right, will be admitted to gardens with rivers flowing by, where they will abide by the leave of their Lord, with 'Peace' as their salutation.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mdcclxxiv{Do you not see how God compares a noble act to a healthy tree whose roots are firm and branches in the sky, which yields\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mdcclxxv{By the leave of its Lord its fruit in all seasons, God presents words of wisdom to men that they might reflect.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mdcclxxvi{An evil act is like a rotten tree torn out of the earth with no (base or) firmness.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mdcclxxvii{With immutuble words God makes the faithful dauntless in the life of the world and the life to come, but leads the unjust into error, for God does as He pleases.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mdcclxxviii{Have you not looked at those who repaid God's favours with ingratitude; who pulled their people down to ruin,\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mdcclxxix{Hell, where they will roast in the fire? And what an evil repository!\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mdcclxxx{They have appointed equals of God to mislead people from His path. Tell them: ``Enjoy yourselves (so long as you may). In the end you have to go to Hell."\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mdcclxxxi{Tell those of My creatures who believe: ``Observe your devotional obligations and give of what We have given you in charity, secretly or openly, before the Day arrives when there will be no buying or selling or befriending."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mdcclxxxii{It is God who created the heavens and the earth, and sent down rain from the sky producing fruits for your food thereby, and made you master of the ships that ply in the oceans by His command, subjected the rivers to your control,\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mdcclxxxiii{And subjugated the sun and moon for you so that they perform their tasks diligently; and subdued the night and day for your service.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mdcclxxxiv{He gave you whatsoever you asked. If you try to count the favours of God you will not be able to calculate. Man is most unjust indeed, full of ingratitude.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mdcclxxxv{Remember when Abraham prayed: ``O Lord, make this a city of peace, and preserve me and my progeny from worshipping idols:\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mdcclxxxvi{Many a man have they led astray, O Lord. So he who follows me is truly of me; but as for him who disobeys me, surely You are forgiving and kind.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mdcclxxxvii{I have settled some of my children, O Lord, in a barren valley near Your sacred House, so that, O our Lord, they may be constant in devotion. So put in the hearts of men some kindness for them, and provide fruits for them: They may haply be grateful.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mdcclxxxviii{O Lord, You have knowledge of what we hide and what we reveal, for nothing on the earth or in the skies is hidden from God.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mdcclxxxix{All praise be to God who bestowed on me Ishmael and Isaac in old age. Verily my Lord listens to prayer.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mdccxc{Grant, O Lord, that I and my offspring may remain constant in devotion. Grant, O Lord, my supplication.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mdccxci{O Lord, forgive me, my parents and the faithful on the Day the reckoning is done."\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mdccxcii{Think not God is oblivious of the deeds of the wicked. He has only allowed them respite till the Day on which all eyes would stare aghast,\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mdccxciii{(And) they would hasten forward, heads lifted upwards, gazes fixed, and emptied out their hearts.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mdccxciv{Warn the people of that Day when the punishment would be inflicted upon them. Then will the wicked say: ``O our Lord, give us respite a while more. We shall heed Your call and follow the apostles." (But they will be told,): ``Are you not those who used to swear: 'There is no reverse for us?'\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mdccxcv{Yet you dwelt in the dwellings of those who had exceeded themselves, and it was evident to you how We had dealt with them; and We held out examples before you."\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mdccxcvi{Still they are plotting their plots, but evident are their plots to God, even though they are so adroit as to make the mountains move.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mdccxcvii{Think not that God would go back on His promise (made) to the apostles. Indeed God is mighty, the Lord of retribution.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mdccxcviii{The day when the earth will he replaced by some other than the earth, as will be the skies, and every one will appear before God the one and omnipotent,\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mdccxcix{You will see the wicked on that day bound together in chains.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mdccc{Of molten pitch shall be their garments, their faces covered with flames,\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mdccci{That God may reward each soul for its deeds. Indeed God is swift at reckoning!\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mdcccii{This is a message for mankind that they may take a warning from it, and may know that He is the one and only God, and that men of wisdom may reflect.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mdccciii{\basmalahen ALIF LAM RA. These are the verses of the Book and the perspicuous oration.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mdccciv{The unbelievers would haply like to wish that they had submitted (and become Muslim).\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mdcccv{Leave them to feast and revel, beguiled by hope; they will come to know soon.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mdcccvi{Not one habitation have We destroyed but at the time determined for it.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mdcccvii{No people can hasten or delay the term already fixed for them.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mdcccviii{And yet they say: ``You, to whom this Exposition has been sent are surely possessed of the Devil.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mdcccix{If you are a man of truth, why can't you bring the angels to us?"\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mdcccx{But then We never send the angels down save with the purpose (of enforcing their doom), after which they will not be given more respite.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mdcccxi{We have sent down this Exposition, and We will guard it.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mdcccxii{We had also sent apostles to people of earlier persuasions.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mdcccxiii{But never once an apostle came to them at whom they did not scoff.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mdcccxiv{We place in the hearts of sinners (disbelief).\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mdcccxv{So, they will not believe in it: The example of former people is there.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mdcccxvi{Even if We open a door in the heavens and they ascend through it in broad daylight,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mdcccxvii{They will say all the same: ``Our eyes were dazed (and clouded over). We were a people ensorcelled."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mdcccxviii{We have placed the signs of the Zodiac in the sky, and decked it out for those who can see;\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mdcccxix{And We have preserved it from every accursed devil,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mdcccxx{Except the ones who listen on the sly, yet they are chased away by a shooting flame.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mdcccxxi{We stretched the earth and placed upon it firm stabilisers, and made all things grow upon it balanced evenly.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mdcccxxii{We have provided on it sustenance for you, and for those you cannot provide.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mdcccxxiii{Of all things there are We have the stores, and send them down in determined measure.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mdcccxxiv{We send rain-impregnated winds, and water from the sky which you drink, but you are not the keepers of its store.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mdcccxxv{It is We who give life and We who give death, and We are the One who will abide.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mdcccxxvi{We surely know those of you who go forward and those of you who lag behind.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mdcccxxvii{Your Lord will surely gather them together: Certainly He is all-wise and all-knowing.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mdcccxxviii{Man We fashioned from fermented clay dried tingling hard,\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mdcccxxix{As We fashioned jinns before from intense radiated heat.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mdcccxxx{But when your Lord said to the angels: ``I am verily going to create a human being from fermented clay dried tingling hard;\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mdcccxxxi{And when I have fashioned him and breathed into him of My spirit, bow before him in homage;"\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mdcccxxxii{The angels bowed in homage in a body\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mdcccxxxiii{Except Iblis. He refused to bow with the adorers.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mdcccxxxiv{``How is it, O Iblis," said (the Lord), ``you did not join those who bowed in homage?"\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mdcccxxxv{``How could I bow," said he, ``before a mortal whom You created from fermented clay dried tingling hard?"\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mdcccxxxvi{``Go hence, execrable," (said the Lord), ``from this place,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mdcccxxxvii{Condemned till the day of Doom!"\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mdcccxxxviii{``O my Lord," said he, ``give me respite till the day the dead are raised."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mdcccxxxix{``You are among the reprieved," (said the Lord),\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mdcccxl{``Till the predetermined time."\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mdcccxli{``O my Lord," he said, ``since You have led me into error I'll beguile them with the pleasures of the world and lead them astray,\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mdcccxlii{Except the chosen ones among Your creatures."\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mdcccxliii{(To which God) said: ``This way is right by Me.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mdcccxliv{No power shall you have over (all) My creatures except those who fall into error and follow you,\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mdcccxlv{For whom the ordained place is surely Hell,\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mdcccxlvi{Which has several gates, and each gate is marked for every section of them."\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mdcccxlvii{Verily those who keep away from evil and follow the straight path shall be in the midst of gardens and springs of water.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mdcccxlviii{``Enter in peace and tranquility," (they will be told).\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mdcccxlix{We shall cast out any grudge they may have in their hearts. (There) they will sit on couches face to face like brothers together.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mdcccl{No weariness will come upon them, nor will they be sent away from there.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mdcccli{Announce to My creatures that I am indeed forgiving and kind,\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mdccclii{But My punishment is surely a painful one.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mdcccliii{Inform them about the matter of Abraham's guests.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mdcccliv{When they came to him and said: ``Peace," he answered: ``Truly we are afraid of you."\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mdccclv{``Have no fear," they said. ``We bring you news of a son full of wisdom."\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mdccclvi{``You bring me the good news now," he said, ``when old age has come upon me. What good news are you giving me then?"\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mdccclvii{``We have given you the happy tidings of a truth," they replied. ``So do not be one of those who despair."\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mdccclviii{``Who would despair of the mercy of his Lord," he answered, ``but those who go astray."\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mdccclix{And asked them: ``What matter, O angels, brings you here?"\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mdccclx{``We have been sent," they said, ``to (punish) a sinful people,\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mdccclxi{``Except the family of Lot whom we shall save\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mdccclxii{``Other than his wife who, it is decreed, will remain with those who will stay behind."\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mdccclxiii{When the messengers came to the family of Lot,\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mdccclxiv{He said: ``You are people I do not know."\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mdccclxv{``We have come to you with news," they said, ``of what your people doubt;\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mdccclxvi{``Yet we bring to you the truth, and we are truthful.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mdccclxvii{``So leave with your family late in the night, yourself remaining in the rear, and let none turn back to look, and go where you will be commanded."\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mdccclxviii{We issued this command to him, for they were going to be destroyed in the morning.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mdccclxix{Then came the people of the city, exulting at the news.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mdccclxx{Said Lot: ``These are my guests; do not put me to shame,\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mdccclxxi{``And do not disgrace me. Have some fear of God."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mdccclxxii{``Did we not restrain you," they said, ``from (entertaining) creatures from the outside world?"\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mdccclxxiii{``Here are my daughters," said Lot, ``if you are so active."\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mdccclxxiv{Verily by your life they were utterly confused in their (lustful) drunkenness.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mdccclxxv{So they were seized by the mighty blast at break of day;\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mdccclxxvi{And We turned the city upside down, and rained on them stones of hardened lava.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mdccclxxvii{Herein are really signs for those who discern.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mdccclxxviii{This (city) lies on a road that still survives.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mdccclxxix{Indeed there is a portent in this for those who believe.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mdccclxxx{The dwellers of the Wood (near Midian) were also wicked.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mdccclxxxi{So We punished them too. They are both situated by the highway, clearly visible.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mdccclxxxii{The people of Al-Hijr denied Our apostles;\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mdccclxxxiii{And though We had given them Our signs they turned away from them.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mdccclxxxiv{They used to hew dwellings in the mountains to live in security.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mdccclxxxv{But they were seized by the mighty blast towards the morning;\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mdccclxxxvi{And all that they had done (for security) availed them nothing.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mdccclxxxvii{We have not created but with reason the heavens and the earth and all that lies within them. The Hour (of the great change) is certain to come. So turn away (from them) with a grace.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mdccclxxxviii{Surely your Lord is the Creator and knows (everything).\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mdccclxxxix{We have indeed given you the seven oft-repeated (examples), and the majestic Qur'an.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mdcccxc{So covet not things We have bestowed on a portion of them to enjoy, and do not grieve for them, and protect those who believe;\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mdcccxci{And say: ``I am a distinct warner,"\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mdcccxcii{Like (those) We had sent to those schismatics who slandered their Books\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mdcccxciii{And severed their Scripture into fragments.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mdcccxciv{By your Lord We shall question them one and all\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mdcccxcv{About their deeds.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mdcccxcvi{So declare to them what We have enjoined, and turn away from idolaters.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mdcccxcvii{We are surely sufficient to deal with those who scoff at you,\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mdcccxcviii{Who place other gods besides God. They will come to know soon.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mdcccxcix{We are well aware that you are disheartened by what they say.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mcm{But you should glorify your Lord with praises, and be among those who bow in submission;\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mcmi{And go on worshipping your Lord till the certainty (of death) comes upon you.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mcmii{\basmalahen THE DECREE of GOD will surely come; so do not try to hasten it: Too glorious and high is He for what they associate with Him.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mcmiii{He sends the angels with revelation by His command, to any of His creatures as He please, (saying): ``Warn that there is no god but I, so fear Me."\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mcmiv{He created the heavens and the earth with reason. Too glorious and high is He for what they associate with Him.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mcmv{Man He created from a drop of semen; and still he becomes an open contender.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mcmvi{He created the cattle from whom you get warm clothing and (other) advantages, and some you eat.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mcmvii{There is life and cheer for you as you drive them home in the evening, and lead them out in the morning to graze.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mcmviii{They carry your burdens to lands so distant you could not have reached without much hardship. Indeed your Lord is compassionate and kind.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mcmix{He created horses, mules and donkeys for riding and for splendour. He created other things too which you do not know.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mcmx{To God leads the right path, though some deviate. If He willed He could guide you all to the right way.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mcmxi{It is He who sends down water from the sky of which you drink, and which nourishes the plants you feed your cattle,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mcmxii{With which He makes crops grow, and olives, dates and grapes and fruits of every kind for you. In this is a sign for those who think.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mcmxiii{He harnessed the day and night for you, as also the sun, the moon and the stars, by His command. In this are signs for men who understand.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mcmxiv{And other things of different shades has He produced on the earth for you. In this are signs for those who reflect.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mcmxv{It is He who has subdued the sea that you may eat fresh meat from it, and obtain ornaments to wear. You see the ships plough through it that you may seek of His bounties and, perhaps, be grateful.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mcmxvi{He placed stablisers in the earth so that while it revolves you live undisturbed, and rivers and tracks so that you may find your way;\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mcmxvii{As well as many other signs, as by the stars (you) find direction.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mcmxviii{So, could one who creates be like one who cannot? Will you not then contemplate?\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mcmxix{If you count the favours of God you will not be able to calculate. Assuredly God is forgiving and kind.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mcmxx{God knows what you hide and disclose.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mcmxxi{, As for those they call besides God, they cannot create a thing, and have themselves been created.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mcmxxii{Dead, without life they are, and do not know when they will be raised.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mcmxxiii{Your God is one God. But the hearts of those who believe not in the life to come are filled with denial, and they are puffed up with pride.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mcmxxiv{Surely God knows what they hide and what they disclose. He certainly does not love the proud.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mcmxxv{For when they are asked: ``What has your Lord sent down?" they say: ``Tales of long ago."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mcmxxvi{On the Day of Resurrection they will carry their own burden and some of the load of those they have led astray without any knowledge. Oh, how evil a burden they will carry!\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mcmxxvii{Those who have gone before them had also conspired; then God uprooted their structure from its foundation; the roof fell over them from above, and punishment came upon them from somewhere they did not suspect.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mcmxxviii{On the Day of Resurrection He will disgrace them and ask: ``Where are My compeers for whom you contended?" Those endowed with knowledge will say: ``Shame and evil surely are for unbelievers today."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mcmxxix{They whose souls are drawn out by the angels while they are sinning, shall offer submission: ``We did no evil." But God knows well what you did.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mcmxxx{So enter the gates of Hell, and dwell there for ever. How dreadful a dwelling for the haughty!\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mcmxxxi{When those who took heed for themselves would be asked: ``What did your Lord send down?" They will answer: ``The best." For those who do good there is good in the world, but certainly the abode of the next is better. How excellent the home of the virtuous!\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mcmxxxii{They will enter perennial gardens with streams of water and all they wish. Thus will the pious and devout be rewarded.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mcmxxxiii{When the angels receive the souls of those who are blameless they will say: ``Peace on you. Enter Paradise as recompense for what you did."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mcmxxxiv{What! Do the (unbelievers) expect that the angels should descend, or the sentence of your Lord come to pass? So had the people done before them; yet God did not wrong them, they wronged themselves.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mcmxxxv{The evil they perpetrated overtook them, and what they mocked has turned upon them.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mcmxxxvi{The idolaters say: ``If God had willed we would not have worshipped anything apart from Him, nor would our fathers have done, nor would we have forbidden any thing without His (leave)." So had the people done before them. Therefore it is binding on the prophets to convey the message in clearest terms.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mcmxxxvii{To every community We have sent an apostle. (saying:) ``Worship God, and keep away from all other deities." Thus some of them were guided by God, and ruin was justified on some. Travel over the earth and see what befell those who accused (the apostles) of lies.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mcmxxxviii{Even if you are eager to guide them, God does not surely guide those who have gone astray: They will have no one to help them.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mcmxxxix{They swear emphatically in the name of God that God will not raise the dead. On the contrary, it is a promise incumbent on Him, though most men do not understand,\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mcmxl{For (they fear) He might make what they differed about plain to them, and that the infidels may realise that they were liars.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mcmxli{Yet when We will a thing We have only to say: ``Be", and it is.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mcmxlii{Those who left their homes in the cause of God after having been oppressed, will be given by Us a better place in the world, and if they knew, the guerdon of the next would be greater\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mcmxliii{(For) those who persevere and place their trust in their Lord.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mcmxliv{We sent before you none (as apostles) but men, to whom We sent revelations. In case you are unaware, enquire of those who are keepers of the Oracles of God.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mcmxlv{We had Sent them with miracles and Books; and We have sent to you this Reminder so that you may explain distinctly to men what was sent down to them: They may haply reflect.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mcmxlvi{Have the plotters of mischief become unafraid that God will not split the earth to swallow them, or that punishment will not fall upon them from somewhere they do not (even) suspect?\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mcmxlvii{Or that He will not seize them as they move about, and they will not be able to elude (His grasp);\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mcmxlviii{Or He may seize them by diminishing their portion. Yet your Lord is compassionate and kind.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mcmxlix{Do they not see the shadows of all things God has created incline to the right and the left, bowing in obeisance to God?\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mcml{All things that move on the earth and in the heavens, and the angels, bow in homage to God, and do not behave with pride.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mcmli{They have fear of God for His power over them, and act as commanded.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mcmlii{God says: ``Do not take to two gods, for there is only one God. So fear Me."\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mcmliii{Whatsoever is in the heavens and the earth belongs to Him, and His the judgement for ever. So will you fear any other than God?\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mcmliv{Whatsoever the blessings you enjoy are surely from God, and when in trouble you turn to Him in supplication.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mcmlv{Yet when He has delivered you from affliction, some of you ascribe companions to your Lord\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mcmlvi{So as to deny what We have bestowed on them. Well, enjoy yourselves, you will come to know soon.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mcmlvii{They set aside a portion of the food We have given them for those they do not know. By God, you will surely have to answer for all you contrive!\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mcmlviii{They attribute daughters to God, the glorious, but for themselves whatsoever they please.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mcmlix{Yet when news of the birth of a daughter reaches one of them, his face is darkened, and he is overwhelmed with silent grief,\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mcmlx{And hides from people for shame at the news, (at a loss) whether he should keep her with shame, or bury her in the ground. How bad is the judgement that they make!\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mcmlxi{The semblance of those who believe not in the life to come is that of the meanest; but the semblance of God is the most sublime, for He is all-mighty and all-wise.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mcmlxii{If God were to punish men for their inequity He would not leave a single moving thing on earth. Yet He gives them latitude for a time ordained. When that time is come, there will not be a moment's delay nor a moment's haste.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mcmlxiii{Yet they attribute to God what they find detestable; and their tongues assert the lie that for them is only good. On the contrary, there is Fire for them, and they will be thrown into it.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mcmlxiv{By God, We sent apostles to many a people before you, but Satan made their acts seem attractive to them, and he is their friend this day, and a painful torment awaits them.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mcmlxv{We have sent down this Book to you that you may explain to them what it is that they are differing about, and as guidance and a grace for those who believe.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mcmlxvi{God sends down water from the skies and quickens the dead earth to a new birth. Here is a sign for those who listen.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mcmlxvii{And surely in cattle there is a lesson for you: We give you a drink from the extract of food in their bellies and blood-purest milk so delicious to drink;\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mcmlxviii{And in fruits of the date-palm and the vine, from which you obtain inebriating drinks and excellent food. In this indeed are signs for those who understand.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mcmlxix{Your Lord predisposed the bees to make their hives in mountains, trees and trellices,\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mcmlxx{And suck from all fruits and flit about the unrestricted paths of their Lord. A drink of various hues comes out of their bellies which contains medicine for men. In this is a sign for those who reflect.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mcmlxxi{It is God who creates you, then makes you die; and some reach the age of dotage when they forget what they had known before. God is indeed all-knowing and all-powerful.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mcmlxxii{God has favoured some of you over others in the means of subsistence. But those who have been favoured with more do not give of their means to their dependents so that they may become equal with them. Do they then deny God's beneficence?\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mcmlxxiii{God has provided mates for you of your own kind, and has bestowed on you sons and daughters from your mates, and has given you good things for food. Will they even then believe in the false and deny God's grace?\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mcmlxxiv{Yet they worship those apart from God who cannot provide for them any sustenance from the heavens or the earth, nor will they have power to do so.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mcmlxxv{So do not invent similitudes for God. Indeed God knows, and you do not know.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mcmlxxvi{God presents the example of a man who is a hired servant with no power over anything, and another on whom We have bestowed a handsome fortune, who spends from it in private and in public: Can they be equal? Praised be God! But most men do not understand.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mcmlxxvii{God presents another example of two men, one dumb and unable to do a thing and is a burden on his master. Wherever he is sent he returns without any good (result). Could he be equal to one who enjoins what is just, and follows the right path?\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mcmlxxviii{To God belong the secrets of the heavens and the earth, and the Hour of Doom is a matter of the winking of an eye, even less, for God has certainly power over all things.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mcmlxxix{God produced you from your mothers' wombs knowing nothing, but gave you ears and eyes and hearts so that you may be grateful.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mcmlxxx{Do you not see the birds held high between the heavens and the earth? Nothing holds them (aloft) but God. There are verily signs in this for those who believe.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mcmlxxxi{God has given you homes to live in, and tents (made) from the hides of cattle convenient for days of travelling and halting; and from their wool and fur and hair you make domestic articles and goods that last a certain time.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mcmlxxxii{God has given you of things created, shade, and places of shelter in the mountains, and clothes for protection against the heat, and coats (of mail) for defence during war. He thus bestows His favours on you so that you may be grateful to Him.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mcmlxxxiii{If they still turn away, your duty is to warn them in clear terms.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mcmlxxxiv{They do know the favours of God, and yet they deny them, for most of them are not grateful.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mcmlxxxv{The day We shall call a witness from every people, the unbelievers will not be allowed to make excuses.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mcmlxxxvi{And when the wicked shall face the torment it will not be decreased, nor will they be reprieved.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mcmlxxxvii{When the idolaters see their partners they will call out: ``O our Lord, these are the partners we invoked instead of You;" but they will retort: ``You are liars."\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mcmlxxxviii{They will offer submission to God that Day, and the lies they fabricated will not be of the least avail.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mcmlxxxix{For those who deny the truth and obstruct (others) from the way of God, We shall add torment to torment as they were perpetrating corruption.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mcmxc{Remind them of the Day when We shall call from every people a witness against them, and make you a witness over them, for We have revealed to you the Book as an exposition of everything, and as guidance and grace and happy tidings for those who submit.\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mcmxci{Verily God has enjoined justice, the doing of good, and the giving of gifts to your relatives; and forbidden indecency, impropriety and oppression. He warns you so that you may remember.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mcmxcii{Fulfil your covenant with God, having made the covenant, and do not break your oaths once you have sworn them, as you have made God a witness over you. Indeed God knows what you do.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mcmxciii{And do not be like her who untwists her yarn having spun it into durable thread. Do not use your oaths deceitfully because one party has ascendency over you. God surely tries you in this way: He will make it clear to you on the Day of Resurrection what you were differing about.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mcmxciv{If God had pleased He would surely have made you a single community of belief; but He leads whosoever He wills astray, and guides whosoever He please. But you will surely be questioned about what you used to do.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mcmxcv{So do not make your oaths a means of deceiving one another, lest your foot should slip after having found its hold, and you taste of evil for having hindered (others) from the way of God, and suffer a grievous punishment.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mcmxcvi{And do not trade God's covenant for a paltry price. Remember, what is with God is better for you, if only you knew!\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mcmxcvii{For what you possess will pass, but what is with God will abide. We shall certainly award those who persevere a recompense in keeping with their deeds.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mcmxcviii{We shall invest whosoever works for good, whether man or woman, with a pleasant life, and reward them in accordance with the best of what they have done.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mcmxcix{So, when you recite the Qur'an seek refuge in God from Satan the execrable.\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mm{He does not have power over those who believe and place their trust in their Lord.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mmi{His power is only over those who take him as their patron, and those who ascribe equals (to God).\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mmii{When We replace a message with another -- and God knows best what He reveals -- they say: ``You have made it up;" yet most of them do not know.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mmiii{You say: ``It has been sent by divine grace from your Lord with truth to strengthen those who believe, and as guidance and good news for those who have submitted (to God)."\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mmiv{Yet We know what they say: ``It is only a man who instructs him." The speech of the man they imply is obscure while this is clear Arabic.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mmv{Those who do not believe in the words of God are verily not guided by God. For them is severe punishment.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mmvi{They alone invent lies who do not believe in the words of God, and they are liars.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mmvii{Whosoever denies having once believed -- unless he is forced to do so while his heart enjoys the peace of faith -- and opens his mind to disbelief will suffer the wrath of God. Their punishment will be great,\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mmviii{For they loved the life of this world more than the life to come; and God does not guide those who do not believe.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mmix{They are the ones whose hearts and ears and eyes have been sealed by God; and these are the heedless.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mmx{They will surely be losers in the life to come,\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mmxi{But (to) those who were victimised and left their homes and then fought and endured patiently, your Lord will surely be forgiving and kind.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mmxii{On the day when every soul will come pleading for itself, and every soul will be recompensed for what it had done, no one will be wronged.\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mmxiii{God presents the example of a town which enjoyed peace and security, its provisions coming from everywhere in abundance, but it denied the favours of God; so God acquainted it with intimate hunger and fear (as punishment) for what they had done.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@mmxiv{An apostle came to them who was one of them, but they called him a liar. Then they were seized by torment for they were sinners.\qt@no{(113)}}
\qt@newcmd\qurantrans@en@mmxv{Eat the good and lawful of things that God has given you, and be grateful for the bounty of God, if you really worship Him.\qt@no{(114)}}
\qt@newcmd\qurantrans@en@mmxvi{He has forbidden carrion and blood and the flesh of the swine, and what has been killed in the name of any other but God; but if one is driven by necessity (to eat it) without craving or reverting to it, then God is forgiving and kind.\qt@no{(115)}}
\qt@newcmd\qurantrans@en@mmxvii{Do not utter the lies your tongues make up: ``This is lawful, and this is forbidden," in order to impute lies to God; for they who impute lies to God will not find fulfilment.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@mmxviii{For them there is some enjoyment, but the punishment is painful.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@mmxix{We have already told you what We have forbidden the Jews. We did not wrong them, they wronged themselves.\qt@no{(118)}}
\qt@newcmd\qurantrans@en@mmxx{To those who do wrong out of ignorance, then repent and correct themselves, your Lord is indeed forgiving and kind.\qt@no{(119)}}
\qt@newcmd\qurantrans@en@mmxxi{Abraham was certainly a model of faith, obedient to God and upright, and not one of idolaters,\qt@no{(120)}}
\qt@newcmd\qurantrans@en@mmxxii{Grateful to Him for His favours; so He chose him and guided him to the path that is straight,\qt@no{(121)}}
\qt@newcmd\qurantrans@en@mmxxiii{And gave him what is good in the world, and in the Hereafter he will be among the righteous and the good.\qt@no{(122)}}
\qt@newcmd\qurantrans@en@mmxxiv{So We commanded you to follow the way of Abraham the upright who was not of idolaters.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@mmxxv{As for the Sabbath, it was imposed on those who had differed about it; and your Lord will tell them on the Day of Resurrection what it was they had differed about.\qt@no{(124)}}
\qt@newcmd\qurantrans@en@mmxxvi{Call them to the path of your Lord with wisdom and words of good advice; and reason with them in the best way possible. Your Lord surely knows who strays from His path, and He knows those who are guided the right way.\qt@no{(125)}}
\qt@newcmd\qurantrans@en@mmxxvii{If you have to retaliate, do so to the extent you have been injured; but if you forbear it is best for those who bear with fortitude.\qt@no{(126)}}
\qt@newcmd\qurantrans@en@mmxxviii{Endure with patience, for your endurance is not without the help of God. Do not grieve for them, and do not be distressed by their plots.\qt@no{(127)}}
\qt@newcmd\qurantrans@en@mmxxix{God is verily with those who are pious and devout, and those who are doers of good.\qt@no{(128)}}
\qt@newcmd\qurantrans@en@mmxxx{\basmalahen GLORY TO HIM who took His votary to a wide and open land from the Sacred Mosque (at Makkah) to the distant Mosque whose precincts We have blessed, that We may show him some of Our signs. Verily He is all-hearing and all-seeing.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmxxxi{We gave Moses the Book, and made it a guidance for the children of Israel that they should not take another protector apart from Me.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmxxxii{O you, the offspring of those We bore (in the ark) with Noah, he was indeed a grateful votary.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmxxxiii{We announced to the children of Israel in the Book: ``You will surely create disorder twice in the land, and become exceedingly arrogant."\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmxxxiv{So, when the time of the first prediction came, We sent against you Our creatures full of martial might, who ransacked your cities; and the prediction was fulfilled.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmxxxv{Then We gave you a chance against them, and strengthened you with wealth and children, and increased your numbers (and said):\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmxxxvi{``If you do good, you will do so for your own good; if you do ill, you will do it for your own loss." So, when the time of the second prediction comes, (We shall rouse another people) to shame you, and enter the Temple as they had done the first time, and to destroy what they conquered utterly.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmxxxvii{Your Lord may haply be merciful to you. But if you repeat it, We shall do the same. We have constituted Hell as prison for unbelievers.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmxxxviii{Verily this Qur'an directs you to the path that is straight, and gives happy tidings to those who believe and do the right: For them is a great reward.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmxxxix{As for those who do not believe in the Hereafter, We have prepared a painful punishment.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmxl{Man prays for evil as he prays for good, for man is hasty.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmxli{We have created night and day as two signs, then We efface the sign of the night, and make the sign of the day resplendent that you may seek the bounty of your Lord, and know the computation of years and numbers. We have expounded most distinctly everything.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmxlii{Round each man's neck We have hung his ledger of deeds, and on the Day of Resurrection will present it as a book spread out (and say):\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmxliii{``Read your ledger; this day you are sufficient to take your own account.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmxliv{``He who finds the right path does so for himself; and he who goes astray does so to his own loss; and no one who carries a burden bears another's load. We never punish till We have sent a messenger.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmxlv{``And when We destroy a human habitation We send Our command to (warn) its people living a life of ease; and when they disobey, the sentence against them is justified, and We destroy them utterly.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmxlvi{``How many generations have We laid low after Noah, for your Lord knows and notices well enough the sins of His creatures.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmxlvii{``Whosoever desires what hastes away, We hasten to give him (in this life) as much as We please to whosoever We will; but afterwards there is Hell for him in which he will burn, disgraced and ostracised.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmxlviii{``But he who desires the Hereafter, and strives for it with a will, and is a believer, will be favoured for his endeavour.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmxlix{``We bestow from the gifts of your Lord on these and on those, for the gifts of your Lord are not restricted.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mml{``See, how We favour one over the other; and in life to come are higher ranks and favours greater still.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmli{``Do not set up another god with God, or you will remain disgraced and destitute.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmlii{``So your Lord has decreed: Do not worship anyone but Him, and be good to your parents. If one or both of them grow old in your presence, do not say fie to them, nor reprove them, but say gentle words to them\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmliii{``And look after them with kindness and love, and say: ``O Lord, have mercy on them as they nourished me when I was small."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmliv{Your Lord knows what is in your heart. If you are righteous, then He is indeed forgiving to those who turn (to Him) in repentance.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmlv{So give to your relatives what is their due, and to those who are needy, and the wayfarers; and do not dissipate (your wealth) extravagantly.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmlvi{Those who dissipate (their wealth) are the brethren of the devils, and the Devil was ungrateful to his Lord.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmlvii{If you neglect (your parents) while seeking the bounty of your Lord, of which you are hopeful, speak to them softly.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmlviii{Do not be niggardly, nor extravagant that you may later feel reprehensive and constrained.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmlix{Certainly your Lord provides with open hands whosoever He will, but according to capacity, for He knows and watches His creatures.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmlx{Do not abandon your children out of fear of poverty. We will provide for them and for you. Killing them is certainly a great wrong.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmlxi{And do not go near fornication, as it is immoral and an evil way.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmlxii{And do not take a life, which God has forbidden, except in a just cause. We have given the right (of redress) to the heir of the person who is killed, but he should not exceed the limits (of justice) by slaying (the killer), for he will be judged (by the same law).\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmlxiii{And do not touch the property of the orphans except for bettering it, until they come of age; and fulfil the promise made: You will surely be questioned about the promise.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmlxiv{Give full measure when you are measuring, and weigh on a balanced scale. This is better, and excellent its consequence.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmlxv{Do not follow that of which you have no knowledge. Verily the ear, the eye, the heart, each will be questioned.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmlxvi{And do not strut about the land with insolence: Surely you cannot cleave the earth, nor attain the height of mountains in stature.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmlxvii{All these are evil and odious to your Lord.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmlxviii{This is some of the wisdom your Lord has revealed to you. So do not take another god apart from God, or you will be cast into Hell, reproved, ostracised.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmlxix{Has God chosen to give you sons, and taken for Himself daughters from among the angels? You utter grievous things indeed!\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmlxx{We have explained (the truth) in various ways in this Qur'an, that they may be warned; but it only increased their refractoriness.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmlxxi{Say: ``Had there been other gods with Him, as they assert, they would surely have sought a way (of opposition) against the Lord of the Throne."\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmlxxii{Too glorious and high is He, too exalted for what they say!\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmlxxiii{The seven skies, the earth, and all that lies within them, sing hallelujas to Him. There is nothing that does not chant His praises, but you do not understand their hymns of praise. He is verily clement and forgiving.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmlxxiv{When you recite the Qur'an, We place a hidden veil between you and those who do not believe in the Hereafter;\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmlxxv{And We put covers over their hearts and deafness in their ears that they should not understand it. So when you invoke your Lord alone in the Qur'an they turn their backs and walk away.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmlxxvi{We know well with what (intent) they hear you, for when they confer privately the wicked say: ``You follow but a man deluded."\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmlxxvii{See, what comparisons they coin for you, and go astray, and thus cannot find the way.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmlxxviii{Yet they say: ``When we are turned to bones and bits, shall we be raised as a new creation?"\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmlxxix{Tell them: ``(Even if) you turn to stones or steel,\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmlxxx{Or some other created thing which may seem to you most difficult (to create)!" They will then say: ``Who will revert us back?" Say: ``He who originated you in the first place." They will shake their heads at you and say: ``When will that be?" Say: ``In the near future, perhaps,\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmlxxxi{``On the day when He will call you, and you will answer with His praises and imagine you did not tarry but a while."\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmlxxxii{Tell My creatures only to speak words that are good. Verily Satan sows dissensions: Satan is indeed the acknowledged enemy of mankind.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmlxxxiii{Your Lord knows you better: He may have mercy on you if He please, or punish you if He will. Yet We have not sent you as warden over them.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmlxxxiv{Your Lord knows whoever is in the heavens and the earth. We exalted some of the prophets over the others; and to David We gave the Book of Psalms.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmlxxxv{Say: ``Call those whom you imagine to be gods besides Him; yet they have no power to relieve you of any distress or to avert it."\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmlxxxvi{Those they invoke themselves seek the way to their Lord, (striving) which one of them shall be nearest (to Him); and hope for His grace, and dread His punishment. Indeed, the punishment of your Lord is to be feared!\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmlxxxvii{There is not a habitation We shall not destroy before the Day of Resurrection, or not inflict severe punishment upon it. This is in accordance with the law (of God).\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmlxxxviii{Nothing could stop Us from sending signs except that the earlier people had rejected them as lies. We sent to Thamud the she-camel as a token to make it clear to them, but they treated her cruelly; and We send signs only to deter.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmlxxxix{When We said to you: ``Verily your Lord circumscribes mankind," and showed you the vision and the accursed tree of the Qur'an, it was as a bone of contention for men. Thus do We (instil) fear in them; but they only transgress the more.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmxc{When We asked the angels to bow before Adam, they all bowed but Iblis, who said: ``Can I bow before him whom You created from clay?"\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmxci{(And) said: ``Look! This is what you have honoured above me! If You defer (my term) till the Day of Resurrection, I will bring his progeny into complete subjugation, barring a few."\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmxcii{(And God) said: ``Away! Whosoever of them follows you will surely have Hell with you as requital -- an ample recompense.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmxciii{Mislead any of them you may with your voice, attack them with your cavalry and soldiers on foot, share their wealth and children with them, and make promises to them." -- But the promises of Satan are nothing but deceit.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmxciv{``You will surely have no power over My devotees: Your Lord is sufficient as their protector."\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmxcv{It is your Lord who drives your ships across the seas that you may seek of His bounty. He is verily kind to you.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmxcvi{When a calamity befalls you on the sea, all those you invoke fail you except Him. But when He brings you safely to the shore, you turn away, for man is most ungrateful.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmxcvii{Have you then become so sure that He will not cleave the earth and sink you in it by the shore, or send a gale against you, when you will not find any protector.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmxcviii{Or you feel so secure that He will not send you back (to sea) again or send a gravel-hurtling storm against you, and drown you for your ingratitude? Then you will not find any avenger against Us.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmxcix{Indeed We have honoured the children of Adam, and carried them over land and sea, provided them with good things for their sustenance, and exalted them over many of Our creatures.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmc{The day We shall summon all men with their leaders, whosoever is given his record in his right hand will be able to read his account, and none will be wronged the breadth of a thread.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmci{But whoso has been blind in this world shall be blind in the world to come, even farther astray from the path.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmcii{They had almost led you away from what has been revealed to you, that you may invent things about Us besides those revealed, when they would have taken you as friend.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmciii{If We had not kept you constant you had almost leaned towards them.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmciv{In that case We would have made you taste a double anguish of life and a double anguish of death, and then you would not have been able to find a helper against Us for yourself.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmcv{They had nearly expelled you from the land and driven you away from it. But then, they too would have stayed but a little after you.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmcvi{This has been Our way with the apostles whom We sent before you. You will not find any variation in Our line of action.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmcvii{Observe the service of prayer from the sun's declining from the meridian to the darkening of the night, and the recitation at dawn. Indeed the Recitation at dawn is palpably evident.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmcviii{Say a supererogatory prayer at the hour of the first watch: Your Lord may raise you to a most exalted station.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmcix{And pray: ``O my Lord, let my entry be with honour, and let my exit be with honour, and grant me power from You which would help (sustain) me."\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmcx{And say: ``Truth has come and falsehood nullified." Verily falsehood is perishable.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmcxi{What We have sent down of the Qur'an is a healing and a grace for the faithful, and adds only loss for the sinners.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmcxii{When We are gracious to man he turns away and moves aside; yet when evil befalls him he begins to despair.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmcxiii{Say: ``Each one acts according to his disposition, but your Lord knows well who follow the right path."\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmcxiv{They ask you about revelation. Say, revelation is by the command of your Lord, and that you have been given but little knowledge.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmcxv{If We pleased We could take away what We have revealed to you. Then you will not find any one to plead for it with Us,\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmcxvi{Unless your Lord have mercy. His blessings on you are great indeed.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmcxvii{Say: ``Surely if men and jinns get together to produce the like of this (Qur'an), they will not be able to produce the like of it, however they might assist one another.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmcxviii{We have given examples of every kind to men in this Qur'an in various ways, and even then most men disdain everything but unbelief,\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmcxix{And say: ``We will not believe you until you make a spring of water gush forth from the earth for us;\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmcxx{Or, until you acquire an orchard of date-palm trees and grapes, and produce rivers flowing through it;\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmcxxi{Or, let chunks of sky fall over us, as you assert (you will); or, bring God and the angels as a surety;\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmcxxii{Or, you come to possess a house of gold; or ascend to the skies, though we shall not believe in your having ascended till you bring down a book for us which we could read." Say: ``Glory to my Lord. I am only man and a messenger."\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmcxxiii{Nothing prevented men from believing when guidance came to them, other than (what) they said: ``Has God sent (only) a man as messenger?"\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mmcxxiv{Say: ``If angels had peopled the earth and walked about in peace and quiet, We would surely have sent to them an angel as messenger.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mmcxxv{Tell them: ``God is sufficient witness between me and you, for He knows His creatures well, and is well-informed."\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mmcxxvi{He is guided whom God guides. As for him He allows to go astray, you will not find a protector other than Him. We shall raise them on the Day of Resurrection in their own image, blind and dumb and deaf: Their habitation will be Hell. Every time (its fire) subsides We will intensify its flame.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mmcxxvii{This will be their retribution for having denied Our signs and said: ``Once we are turned to bones and bits, can we be raised as a new creation?"\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mmcxxviii{Do they not perceive that God, who created the heavens and the earth, has the power to create the like of them? There is no doubt that. He has fixed a term for them. Even then the wicked disdain everything but unbelief.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mmcxxix{Say: ``Even if you owned the stores of the mercy of my Lord, you would have held them back for fear of spending them, for man is niggardly."\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mmcxxx{We gave Moses nine clear signs; so ask the children of Israel. When (Moses) came to them the Pharaoh said: ``I think, O Moses, you have been deluded."\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mmcxxxi{He replied: ``You know that none but the Lord of the heavens and the earth has sent these (signs) as cogent proof. I truly think, O Pharaoh, your days are done."\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mmcxxxii{Then he sought to turn them out of the land, but We drowned him and all his followers.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mmcxxxiii{After this We told the children of Israel: ``Dwell in the land. When the promise of reckoning comes, We shall bring you together from a motley crowd.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mmcxxxiv{We have sent it down with truth, and with truth has (the Qur'an) come down. And We have sent you only to give good news and to warn.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mmcxxxv{We have divided the Qur'an into parts that you may recite it to men slowly, with deliberation. That is why We sent it down by degrees.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mmcxxxvi{Say: ``Believe in it or do not believe: Those who were given knowledge before it bow in adoration when it is read out to them,\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mmcxxxvii{And say: ``Glory be to our Lord. The promise of our Lord has indeed been fulfilled."\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mmcxxxviii{And weeping they kneel down, and this increases their humility.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mmcxxxix{Say: ``Call Him Allah or call Him Ar-Rahman; whatever the name you call Him by, all His names are beautiful." Do not say your prayers too loudly or in too low a voice, but follow a middle coarse.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mmcxl{And say: ``All praise be to God who has neither begotten a son nor has a partner in His kingdom; nor has He need of any one to protect Him from ignominy. So extol Him by extolling His majesty."\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mmcxli{\basmalahen ALL PRAISE BE to God who has revealed to His votary the Book which is free of all obliquity,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmcxlii{Immutable, so that it may warn of a severe punishment from Him; and give happy tidings to those who believe and do the right that there is a better reward (of Paradise) for them,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmcxliii{Where they will abide for ever;\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmcxliv{And that it may warn those who say: ``God has begotten a son."\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmcxlv{They have no knowledge of this, as their fathers did not have. How terrible are the words they utter! They speak nothing but lies.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmcxlvi{Will you kill yourself for grief of them if they do not believe in this presentation?\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmcxlvii{We have made whatever exists on the earth its adornment to test and try them (and) know who acts better;\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmcxlviii{For We shall certainly turn it to barren dust.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmcxlix{Do you think the men of the cave and Ar-Raqim were so strange among Our signs?\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmcl{When those young men took shelter in the cave, and prayed: ``O Lord, grant us Your favour and dispose our affair aright,"\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmcli{We sealed off their ears in the cave for a number of years,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmclii{Then roused them to ascertain which of the two groups could account for the period they had stayed.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmcliii{We narrate their story to you in all truth. They were a few young men who believed in their Lord; so We gave them greater guidance.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmcliv{And strengthened their hearts when they stood up and said: ``Our Lord is the Lord of the heavens and the earth. We shall invoke no god beside Him, for we shall have uttered a blasphemy then.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmclv{As for these our people here, they have taken to other gods apart from Him. Then why do they not bring a clear authority for them? Who is more wicked than he who fabricates a lie against God?"\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmclvi{(And they said to each other:) ``Now that you have withdrawn from them and what they worship beside God, it is better to take refuge in the cave. Your Lord may bestow of His mercy on you, and facilitate your affair."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmclvii{You may well have seen when the sun came up it moved away to the right of the cave, and when it went down it turned away to the left, and they stayed in its open space. This was among the signs of God. Whoever is guided by God follows the right path; and whosoever goes astray will not find a guide to show him the way.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmclviii{You may have thought that they were awake, yet they were asleep. We made them turn right and left, while their dog lay with his forelegs stretched across the threshold. If you had looked at them you would have surely turned away and fled with horror at the sight.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmclix{Even so We roused them that they may question one another. One of them asked: ``How long have you stayed here?" They said: ``A day or less than a day." ``Your Lord knows best," they said, ``how long you have stayed. So send one of you to the town with this money of yours to look for wholesome food and bring it for you; but he should be careful not to let your presence known.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmclx{If they come to know of you they will stone you to death, or force you to go back to their creed; then you will never succeed."\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmclxi{Thus did We inform the people about them that they may know the promise of God is true, and there is no doubt that the Hour will come. As they were arguing among themselves as to what should be done with them, (some) said: ``Erect a monument over them. Their Lord is best cognisant of them." Those who prevailed, said: ``We shall build a place of worship over their (sepulchre)."\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmclxii{Some will say: ``They were three, and their dog was the fourth;" and some will also say: ``They were five and their dog was the sixth," -- guessing in the dark. And some will even say: ``They were seven, and their dog the eighth." Say: ``My Lord alone knows best their number; none but only a few know of them." So do not argue about it with them but lightly, and do not enquire about them from any one of them.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmclxiii{Do not say of any thing: ``I will do it tomorrow,"\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmclxiv{Without (adding), ``if God may please;" and think of your Lord in ease you forget, and say: ``Perhaps my Lord will show me a nearer way to rectitude."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmclxv{(It is said) they stayed in the cave three hundred years and nine.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmclxvi{You say: ``God only knows how long they stayed. He alone knows the secrets of the heavens and the earth. How distinctly He sees and hears! They have no other guardian but Him, and He does not share His authority with any one."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmclxvii{Recite what has been revealed to you of the Book of your Lord. There is no one who can change the word of God; and you will not find refuge except in Him.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmclxviii{Persevere with those who call on their Lord morning and evening, seeking His magnificence. Do not turn your eyes away from them, seeking the splendours of this world, and do not follow him whose heart We have made oblivious to Our remembrance, who follows his own lust and exceeds the bound.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmclxix{Say: ``The truth is from your Lord: So believe if you like, or do not believe if you will." We have prepared for the sinners a fire which will envelope them in its tent. If they ask for water they will be helped to liquid like molten brass that would scald their mouths. How evil the drink, and evil the resting-place!\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmclxx{But surely We do not let the reward of those who believe and do the right to go waste.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmclxxi{There will be gardens of Eden for them, with rivers flowing by, where they will be decked in bracelets of gold, with silken robes of green and of brocades to wear, reclining on couches. How excellent the guerdon, and excellent the resting-place!\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmclxxii{Tell them the parable of two men. We gave one two gardens of grapes surrounded by date-palm trees, with corn fields in between.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmclxxiii{Each of the gardens yielded its fruit and did not withhold the least; and We made a stream flow in between them.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmclxxiv{So he became rich. Arguing one day with his friend he said: ``I have more wealth than you and more powerful kinsmen."\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmclxxv{And he walked into his garden, and, (forgetting) his limit, said: ``I cannot imagine that this will ever be ruined,\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmclxxvi{Nor can I think that the Hour (of Doom) will come, And even if I am brought back to my Lord, I will surely find a better place there than this."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmclxxvii{Disputing with him, his companion said: ``Do you disbelieve in Him who created you from dust, then a drop of semen, then formed you into a man?\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmclxxviii{And He is God, my Lord, and I do not associate any one with my Lord.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmclxxix{When you entered your garden, why did you not say: 'As God may please;' for no one has power except given by God? Though you see me poorer in wealth and children than you,\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmclxxx{Yet, my Lord may haply give me a garden better than yours, and He may send a thunder-bolt, from the skies and in the morning it will be a barren plain;\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmclxxxi{Or else of a morning its water may sink underground, and you will not find a trace of it."\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmclxxxii{And his vines were overtaken (with disaster), and he began to wring his hands (at the loss) of what he had spent on them, for the vines had fallen upon their trellises; and he said: ``Would to God that I had not associated any one with my Lord."\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmclxxxiii{He had no body to help him other than God, nor was he able to save himself.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmclxxxiv{The jurisdiction in this province belongs to God. His is the best reward, and His the best requital.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmclxxxv{Present to them the example of the life of this world so like the water We send down from the skies that mingles with the earth to nourish its vegetation, which then on the morrow turns to stubble and is blown away by the wind. God has power over everything.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmclxxxvi{Wealth and children are only the gloss of this world, but good deeds that abide are better with your Lord for recompense, and better for expectation.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmclxxxvii{The day We shall move the mountains, and you see the earth an open plain, We shall gather them together, leaving none behind.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmclxxxviii{They will be arraigned before their Lord row on row, (and He will say): ``Well, you have come to Us as We had first created you, even though you imagined We had fixed no time for this meeting."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmclxxxix{The ledger (of their deeds) would be placed before them. Then you will see the sinners terrified at its contents, and say: ``Alas, what a written revelation this, which has not left unaccounted the smallest or the greatest thing!" They will find in it whatsoever they had done. Your Lord does not wrong any one.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmcxc{When We said to the angels: ``Bow before Adam in adoration," they all bowed but Iblis. He was one of the jinni and rebelled against his Lord's command. And yet you take him and his offspring as your friends instead of Me, even though they are your enemies. How sad a substitute for the evil-doers!\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmcxci{I did not call them to witness the creation of the heavens and the earth, nor their own creation. I would not take as helpers those who lead (men) astray.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmcxcii{The day He will say: ``Call those you had called My compeers," they will call them, but will get no response, and We shall place a gulf between them.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmcxciii{The sinners will see the Fire and know that they will be thrown into it and will not find a way of escape from it.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmcxciv{We have explained in various ways all things to men in this Qur'an; but of all things man is most contentious.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmcxcv{There is nothing to prevent men from believing when the guidance has come to them, and asking for their Lord's forgiveness, unless they want the example of earlier people visited upon them, or the punishment to appear right before their eyes.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmcxcvi{We never send apostles but to convey happy tidings, and to warn. But those who disbelieve contend with false arguments to nullify the truth. They make a mockery of My revelations and of what they had been warned.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmcxcvii{Who is more unjust than he who, on being reminded of his Lord's revelations, turns away from them, and forgets the evil deeds he had committed in the past. Verily We have placed a covering on their hearts so that they do not understand, and a deafness in their ears so that however you may call them to guidance they will never be guided aright.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmcxcviii{But your Lord is forgiving, full of benevolence. If He had pleased to punish them for their doings He would have punished them immediately. But a term is fixed for them from which they will find no escape.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmcxcix{As for these habitations, We destroyed them only when they transgressed; even so We had fixed a time for their annihilation.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmcc{When Moses said to his servant (Joshua): ``I will not give up till I reach the confluence of two oceans, or I will journey on and on."\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmcci{When they reached the confluence they forgot the fish (they had brought as food) which swiftly made its way into the sea.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmccii{When they had gone past (the confluence), Moses said to his servant: ``Give me my breakfast. I am exhausted from this journey."\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmcciii{He said: ``You see, I forgot the fish on the rock where we had stopped. Only Satan made me forget to mention this; but the wonder is the fish escaped to the sea."\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmcciv{Moses said: ``But that is exactly what we were seeking." So they retraced their steps.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmccv{Then they found one of Our votaries, whom We had blessed and given knowledge from Us.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmccvi{Moses said to him: ``May I attend upon you that you may instruct me in the knowledge you have been taught of the right way?"\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmccvii{He said: ``You will not be able to bear with me.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmccviii{``How can you bear that which is beyond your comprehension?"\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmccix{``You will find me patient if God wills," said Moses; ``and I will not disobey you in any thing."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmccx{``If you must follow me," he said, ``do not ask me any thing until I speak of it to you myself."\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmccxi{So they set out till they (came to the quay) and went on board a ship in which he made a hole, (and Moses said:) ``You have made a hole in the boat to drown its passengers? You have done a strange thing!"\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmccxii{``Did I not tell you," he replied, ``that you will not be able to bear with me?"\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmccxiii{(Moses) said: ``Do not hold me for having forgotten, and do not reprove me and make my task difficult."\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmccxiv{The two went on till they came to a boy, whom he killed. Moses exclaimed: ``You have killed an innocent soul who had taken no life. You have done a most abominable thing!"\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmccxv{He said: ``Did I not tell you you will not be able to bear with me?"\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmccxvi{Moses said: ``If I ask you any thing again then do not keep me with you. You have my apology."\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmccxvii{The two went on till they came upon some villagers, and asked the people for food, but they refused to entertain them. There they found a wall that was crumbling, which he repaired. Moses remarked: ``You could have demanded wages for it if you liked."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmccxviii{``This is the parting of our ``ways," he said. ``But I will now explain the things you could not bear:\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmccxix{That boat belonged to poor people who used to toil on the sea. I damaged it because there was a king after them who used to seize every ship by force.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmccxx{As for the boy, his parents were believers, but we feared that he would harass them with defiance and disbelief.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmccxxi{We hoped their Lord would give them a substitute better than him in virtue and goodness.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmccxxii{As for that wall, it belonged to two orphan boys of the city, and their treasure was buried under it. Their father was an upright man. So your Lord willed that on reaching the age of maturity they should dig out their treasure as a favour from their Lord. So, I did not do that of my own accord. This is the explanation of things you could not bear with patience."\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmccxxiii{They ask you about Dhu'l-Qarnain.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmccxxiv{Say: ``I will cite before you his commemoration." We gave him authority in the land and means of accomplishing every end.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmccxxv{So he followed a certain road\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmccxxvi{Till he reached the point of the setting sun, and saw it set behind a muddy lake, and near it found a people. We said: ``O Dhu'l-Qarnain, you may either punish them or treat them with kindness."\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmccxxvii{He said: ``I shall punish whosoever is wicked. He will then be sent back to his Lord who will inflict on him a terrible punishment.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmccxxviii{But he who believes and does the right will have an excellent reward, and we shall make things easy for him."\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmccxxix{He then followed (another) road\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmccxxx{Till he reached the point of the rising sun, and saw it rise over a people for whom We had provided no shelter against it.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmccxxxi{It was so, for We were fully informed about him.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmccxxxii{He then followed (another) road\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmccxxxiii{Till he reached a place between two mountains, and found this side of it a people who understood but little of what was spoken.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmccxxxiv{They said: 'O Dhu'l-Qarnain, Gog and Magog are oppressing the land. May we pay you some tribute so that you could build a rampart between us and them?"\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mmccxxxv{He said: ``The ability my Lord has given me is better. So help me with your manual labour; I will build a wall between you and them.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mmccxxxvi{Bring me ingots of iron," (which they did) until the space between two mountain sides was filled up. ``Blow your bellows," he said; (and they blew) until it was red hot. ``Bring me molten brass," he said, ``that I may pour over it."\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mmccxxxvii{Thus (Gog and Magog) could neither climb over it nor dig a hole through (the rampart).\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mmccxxxviii{``This is the benevolence of my Lord," he said; ``but when the promise of my Lord comes to pass, He will reduce it to a mound of dust; and the promise of my Lord is true."\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mmccxxxix{We shall leave them on that day surging like waves pressing one against the other, and the trumpet blast will be sounded, when We shall gather them all together.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mmccxl{Then We shall bring Hell right before the infidels\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mmccxli{Whose eyes were veiled against My warning, and they could not hear.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mmccxlii{Do the unbelievers think they can make My own creatures their protectors against Me? We have prepared Hell for the hospitality of infidels.\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mmccxliii{Say: ``Shall I tell you whose labour will be wasted?\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mmccxliv{Theirs whose effort is misspent in pursuit of the pleasures of the world, even though they think they are doing good things."\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mmccxlv{They are those who reject the signs of their Lord, and the meeting with Him. So their good deeds will be fruitless, and on the Day of Judgement We shall not appoint any weighing for them.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mmccxlvi{Their requital will be Hell, because they disbelieved and mocked My signs and messengers.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mmccxlvii{But surely those who believe and do the right will have gardens of Paradise as gift,\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mmccxlviii{Where they will abide for ever, never wanting a change.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mmccxlix{Say: ``If the ocean turned to ink for writing down the colloquy of my Lord, the ocean itself would be exhausted ere the words (and wonders) of my Lord come to end, even if we brought another like it for replenishment."\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mmccl{Say: ``I am only a man like you, but it has been communicated to me that your Lord is one and single God, and that whosoever hopes to meet his Lord should do what is right, and not associate any one in the worship of his Lord."\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mmccli{\basmalahen KAF HA YA 'AIN SAD.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmcclii{Commemorate the beneficence of your Lord on Zachariah, His devotee,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmccliii{When he called to his Lord inwardly,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmccliv{And said: ``O my Lord, my bones decay, my head is white and hoary, yet in calling You, O Lord, I have never been deprived.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmcclv{But I fear my relatives after me; and my wife is barren. So grant me a successor as a favour from You\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmcclvi{Who will be heir to me, and heir to the house of Jacob; and make him obedient to You, O Lord."\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmcclvii{``O Zachariah," (it was) said, ``We give you good news of a son by name of John.' To none have We attributed the name before."\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmcclviii{``How can I have a son, O Lord" he said, ``when my wife is barren and I am old and decrepit?"\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmcclix{(The angel) answered: ``Thus will it be. Your Lord said: 'This is easy for Me; for when I brought you into being you were nothing.'\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmcclx{He said: ``O Lord, give me a token." ``Though sound," He answered, ``you will not talk to any one for three nights running."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmcclxi{So he came from the chamber to his people, and suggested to them (by signs) to sing the praises of the Lord morning and evening.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmcclxii{(We said:) ``O John, hold fast to the Book;" and We gave him wisdom right from boyhood,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmcclxiii{And compassion from Us, and goodness. So he was devout,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmcclxiv{And kind to his parents, neither arrogant nor disobedient.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmcclxv{So peace on him the day he was born, the day he will die, and the day that he will be raised from the dead.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmcclxvi{Commemorate Mary in the Book. When she withdrew from her family to a place in the East\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmcclxvii{And took cover from them, We sent a spirit of Ours to her who appeared before her in the concrete form of a man.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmcclxviii{``I seek refuge in the Merciful from you, if you fear Him," she said.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmcclxix{He replied: ``I am only a messenger from your Lord (sent) to bestow a good son on you."\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmcclxx{``How can I have a son," she said, ``when no man has touched me, nor am I sinful?"\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmcclxxi{He said: ``Thus will it be. Your Lord said: 'It is easy for Me,' and that: 'We shall make him a sign for men and a blessing from Us.' This is a thing already decreed."\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmcclxxii{When she conceived him she went away to a distant place.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmcclxxiii{The birth pangs led her to the trunk of a date-palm tree. ``Would that I had died before this," she said, ``and become a thing forgotten, unremembered."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmcclxxiv{Then (a voice) called to her from below: ``Grieve not; your Lord has made a rivulet gush forth right below you.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmcclxxv{Shake the trunk of the date-palm tree, and it will drop ripe dates for you.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmcclxxvi{Eat and drink, and be at peace. If you see any man, tell him: 'I have verily vowed a fast to Ar-Rahman and cannot speak to any one this day.'\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmcclxxvii{Then she brought the child to her people. They exclaimed: ``O Mary, you have done a most astonishing thing!\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmcclxxviii{O sister of Aaron, your father was not a wicked person, nor your mother sinful!"\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmcclxxix{But she pointed towards him. ``How can we talk to one," they said, ``who is only an infant in the cradle?"\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmcclxxx{``I am a servant of God," he answered. ``He has given me a Book and made me a prophet,\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmcclxxxi{And blessed me wherever I may be, and enjoined on me worship and zakat for as long as I live,\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmcclxxxii{And be dutiful to my mother. He has not made me haughty or rebellious.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmcclxxxiii{There was peace on me the day I was born, and will be the day I die, and on the day I will be raised from the dead."\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmcclxxxiv{This was Jesus, son of Mary: A true account they contend about.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmcclxxxv{It does not behove God to have a son. Too immaculate is He! When He decrees a thing He has only to say: ``Be", and it is.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmcclxxxvi{(Jesus only said:) ``Surely God is my Lord and your Lord, so worship Him. This is the straight path."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmcclxxxvii{Yet the sectarians differed among themselves. Alas for the unbelievers when they see the Terrible Day!\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmcclxxxviii{How keenly would they hear and see when they come before Us then, even though today the evil-doers are lost in palpable error.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmcclxxxix{Warn them of that day of pining when all matters will have been settled, though they would still be unaware and unbelieving (of the truth).\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmccxc{Verily We shall inherit the earth and whosoever is on it, and to Us they will return.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmccxci{Commemorate Abraham in the Book: He was upright, a prophet.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmccxcii{Remember, when he said to his father: ``O my father, why do you worship that which can neither hear nor see nor even profit you the least?\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmccxciii{O my father, to me has come such knowledge as never came to you. So follow me that I may show you the right path.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmccxciv{Why do you worship Satan, O father? Verily Satan was disobedient to Ar-Rahman.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmccxcv{O my father, I fear lest a punishment from Ar-Rahman should befall you, and you should become a friend of the Devil."\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmccxcvi{He said: ``Are you averse to my gods, O Abraham? If you do not desist, I shall have you stoned to death. So go away for a while from me."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmccxcvii{He answered: ``Peace be on you. I will seek forgiveness of my Lord for you. He has been gracious to me.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmccxcviii{I will leave you and those you invoke apart from God, and pray to my Lord. Haply in praying to my Lord I will not be deprived."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmccxcix{Thus, when he left them and the (idols) they worshipped, We bestowed on him Isaac and Jacob, and made each of them a prophet,\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmccc{And bestowed on them some of Our blessings, and gave them high renown.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmccci{Commemorate Moses in the Book. He was a chosen one, both an apostle and a prophet.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmcccii{We called him from the right side of the Mount, and brought him close for communion;\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmccciii{And bestowed on him his brother Aaron, a prophet, through Our benevolence.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmccciv{Commemorate Ishmael in the Book. He was true of his promise, and a messenger, a prophet.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmcccv{He enjoined on his household worship and zakat, and he was obedient to his Lord.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmcccvi{Commemorate Enoch in the Book. He was a truthful person and a prophet,\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmcccvii{And We raised him to an exalted station.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmcccviii{These are (some of) those who were favoured by God among the prophets of the progeny of Adam, and of those We bore in the ark with Noah, and the offspring of Abraham and Israel, and of those We guided and We chose, for they bowed weeping in adoration when the revelations of Ar-Rahman were recited to them.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmcccix{But they are succeeded by a generation who neglect their devotional obligations and follow only earthly pleasures; but they will reach the wrong road and meet destruction,\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmcccx{Except those who repent and come to believe and do the right. These will enter Paradise and will not be wronged the least\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmcccxi{In the gardens of Eden promised by Ar-Rahman to His creatures in the unknown (future). Verily His promise will come to pass.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmcccxii{They will hear no vain talk there, but only salutations of peace, and they will have their sustenance morning and evening."\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmcccxiii{This is the Paradise those of Our creatures will inherit who take heed and fear the displeasure of God.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmcccxiv{``We do not come down," (will the angels say) ``but only by your Lord's command." To Him belongs whatever lies before us and behind us, and the space in between. Your Lord does not ever forget:\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmcccxv{Lord of the heavens and the earth and all that lies between them. Therefore worship Him, and be constant in His worship. Do you know any namesake of His?\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmcccxvi{Yet man says: ``When I am dead, will I come to life again?"\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmcccxvii{Does man not remember that before We created him he was nothing?\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmcccxviii{By your Lord, We shall gather them and the devils together, then bring them crawling on their knees around Hell.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmcccxix{We shall pull out of every section those who were most perversely rebellious against Ar-Rahman.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmcccxx{We know best who deserve to be burnt in (the Fire).\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmcccxxi{There is not one among you who will not reach it. Your Lord has made this incumbent on Himself.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmcccxxii{We shall deliver those who took heed for themselves, and leave the evil-doers kneeling there.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmcccxxiii{When Our lucid revelations are read out to them, the infidels say to those who believe: ``Which of the two groups is better in standing, and whose company is more excellent?"\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmcccxxiv{How many generations that had far more wealth and ostentation have We laid low before them!\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmcccxxv{Say: ``Ar-Rahman extends the life of those who are astray until they come to realise what had been promised them was either (physical) affliction or (the terror) of Resurrection. Then will they know who is worse in position, and who is weak in supporters.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmcccxxvi{God gives greater guidance to those who are guided; and good deeds that endure are better with your Lord for reward, and better for consequence.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmcccxxvii{Have you seen him who denies Our revelations, and says: ``I will certainly be given wealth and children."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmcccxxviii{Has he peeped into the Unknown, or obtained a promise from Ar-Rahman?\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmcccxxix{Never so. We shall certainly write down what he says, and prolong the extent of his punishment.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmcccxxx{All that he claims will revert to Us, and he will come before Us all alone.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmcccxxxi{They have taken other gods apart from God that they might be a strength to them.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmcccxxxii{Never. They will deny their devotion and become their adversaries.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmcccxxxiii{Do you not see that We have set the devils against the infidels to rouse and instigate them?\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmcccxxxiv{So, do not be hasty with them. We are counting their number (of days).\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmcccxxxv{The day We shall usher the righteous before Ar-Rahman like envoys into the presence of a king,\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmcccxxxvi{And drive the wicked into Hell like cattle driven to water,\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmcccxxxvii{None will have power to intercede for them except one who obtains a promise from Ar-Rahman.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmcccxxxviii{They say: ``God has begotten a son."\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmcccxxxix{You have uttered a grievous thing\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmcccxl{Which would cleave the skies asunder, rend the earth, and split the mountains,\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmcccxli{For they have attributed a son to Ar-Rahman,\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmcccxlii{When it does not behove the Merciful to have a son.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmcccxliii{There is no one in the heavens and the earth but comes before Ar-Rahman in all obedience.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmcccxliv{He has counted them and calculated their number.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mmcccxlv{Every one of them will come before Him all alone on the Day of Resurrection.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mmcccxlvi{Surely Ar-Rahman will show love for those who believe and do the right.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mmcccxlvii{So We have made this (Qur'an) easy in your tongue that you may give good news to those who take heed, and warn the people who are contentious.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mmcccxlviii{How many generations have We laid low before them. Do you see any sign of them, or hear the least whisper of them?\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mmcccxlix{\basmalahen TA HA.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmcccl{We have not sent down the Qur'an to you that you should be burdened,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmcccli{But as admonition for him who fears --\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmccclii{A revelation from Him who created the earth and the high ascending skies,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmcccliii{The ever-merciful, established on the throne (of authority).\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmcccliv{Whatever is in the heavens and the earth and in between them, belongs to Him, as whatever lies under the earth.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmccclv{Whether you say a thing aloud or inaudibly, He has knowledge of the secret and the hidden.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmccclvi{God: There is no god but He. To Him belong the attributes most beautiful.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmccclvii{Has the story of Moses come to you?\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmccclviii{When he saw a fire he said to his family: ``You wait here. I have seen a fire. I may haply be able to bring an ember from it, or find direction by the fire."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmccclix{When he approached it, a voice called out:\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmccclx{``O Moses, I am verily your Lord, so take off your shoes, for you are in the holy plain of Towa.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmccclxi{I have chosen you, so listen to what is revealed to you.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmccclxii{I am God, and there is no god but I, so serve Me, and observe acts of prayer to remember Me.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmccclxiii{Verily the Hour (of the great change) is about to come. I keep it secret that every soul may be rewarded for its endeavour.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmccclxiv{So do not let those who do not believe in it and follow their vain desires, turn you away from it.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmccclxv{What is that in your right band, O Moses?"\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmccclxvi{``It's my staff," he answered; ``I lean on it, and fell leaves for my goats with it, and I have other uses for it."\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmccclxvii{``Throw it down, O Moses," said (the Voice).\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmccclxviii{So he threw it down, and lo, it became a running serpent.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmccclxix{``Catch it," said He, ``and have no fear; We shall revert it to its former state.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmccclxx{And face what is to come with patience, your hand will not be tarnished with blame: Another sign\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmccclxxi{That We may go on showing you Our greater signs.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmccclxxii{Go to the Pharaoh as he has become exceedingly rebellious."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmccclxxiii{Moses said: ``O my Lord, enlarge my breast,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmccclxxiv{And make my mission easy.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmccclxxv{Remove the defect of my tongue\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmccclxxvi{That they may understand my speech,\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmccclxxvii{And give me as assistant from my family\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmccclxxviii{Aaron my brother\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmccclxxix{To strengthen me\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmccclxxx{And share my task,\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmccclxxxi{That we may sing Your praises much,\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmccclxxxii{And remember you a great deal.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmccclxxxiii{Surely You know us well."\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmccclxxxiv{He answered: ``Granted is your prayer, O Moses.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmccclxxxv{We have bestowed Our favour on you before this\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmccclxxxvi{When We told your mother what We relate:\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmccclxxxvii{'Put him in a wooden box and cast it in the river. The river will cast it on the bank. An enemy of Ours, and his, will retrieve it.' We bestowed Our love on you that you may be reared under Our eyes.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmccclxxxviii{Then your sister followed you, and said (to the people who had retrieved the child): 'Should I guide you to a person who can nurse him?' We thus brought you back to your mother that her heart may be cheered, and she may not grieve. (Remember) when you killed a man We saved you from anguish; and tested and steeled you (in other ways). Afterwards you sojourned for several years with the people of Midian; then you came up to the measure,\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmccclxxxix{And I chose you for Myself.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmcccxc{Go with My signs, you and your brother, and do not be lax in remembering Me.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmcccxci{Then go to the Pharaoh as he has become exceedingly rebellious.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmcccxcii{Speak to him gently. He may possibly take heed or may come to have fear."\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmcccxciii{They said: ``O our Lord, we are really frightened lest he behave insolently with us or become violent."\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmcccxciv{(The Lord) said: ``Be not afraid. I am verily with you, and I hear and see.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmcccxcv{So go to him and say: 'The two of us have indeed been sent by your Lord. So let the children of Israel come with us, and do not oppress them. We have come to you with a token from your Lord. Peace on him who follows the way of guidance.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmcccxcvi{It has been revealed to us that punishment will befall him who denies and turns away.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmcccxcvii{He asked: ``Who then is that Lord of yours, O Moses?"\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmcccxcviii{(Moses) said: ``Our Lord is He who gave everything its natural form and directed it."\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmcccxcix{(The Pharaoh) said: ``And what about the former generations?"\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmcd{(Moses) replied: ``Knowledge of that is with my Lord (recorded) in the Book. My Lord neither errs nor forgets."\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmcdi{It is He who made the earth a bed for you, and traced for you paths upon it, and sends down water from the sky, and brings out through it every kind of vegetation\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmcdii{To eat and feed your cattle. Surely there are signs in these for those who are wise.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmcdiii{We created you from the earth and will revert you back to it; and raise you up from it a second time.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmcdiv{So We showed him all Our signs, but he denied them and refused,\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmcdv{And said: ``Have you come to us, O Moses, to drive us out of our land with your witchery?\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmcdvi{We shall certainly meet you with like magic. So make an appointment when we and you could meet on common ground, which neither we nor you should fail to keep."\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmcdvii{Said (Moses): ``Let your meeting be on the day of the Feast, and let people assemble in broad daylight."\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmcdviii{After this the Pharaoh withdrew and settled his stratagem, then came back.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmcdix{Moses said to them: ``Woe betide you. Do not fabricate a lie against God, or He will destroy you with some affliction. For he who fabricates lies is doomed to failure."\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmcdx{So they discussed their strategy among themselves and conferred privately,\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmcdxi{(And) said: ``These two are surely magicians. They want to deprive you of your land with their magic, and eradicate your distinct way (of life).\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmcdxii{So prepare your strategy and come forward. He alone shall win today who is superior."\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmcdxiii{They said: ``Either you cast (your spell), O Moses, or we shall cast it first."\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmcdxiv{Moses said: ``No. You cast it first" Then it seemed to Moses that by their magic their cords and rods were flying;\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmcdxv{And Moses felt afraid within himself.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmcdxvi{We said to him: ``Fear not. You will certainly be victorious.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmcdxvii{Throw down what is in your right hand: It will swallow up what they have conjured. For what they have fashioned is only a trick of the sorcerer; and a sorcerer does not succeed wherever he may come."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmcdxviii{The magicians, (seeing the miracle), fell down in prostration, saying: ``We believe in the Lord of Moses and Aaron."\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmcdxix{(The Pharaoh) said: ``You have come to believe without my dispensation. Surely he is your chief who taught you magic. I will have your hands and feet cut off on alternate sides and crucify you on the trunks of date-palm trees. You will come to know whose punishment is harder and protracted."\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmcdxx{They replied: ``We cannot choose you in the face of the clear testimony we have received, and over Him who created us. So do what you are determined to do. All that you would do will only be confined to our life on earth.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmcdxxi{We have certainly come to believe in our Lord that He may forgive our trespasses and the magic you have forced us to perform, for God is nobler and abiding."\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmcdxxii{Surely for him who comes before his Lord a sinner shall be Hell, where he will neither die nor live.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmcdxxiii{But whoever comes before Him a believer having done good deeds, will be raised to higher stations --\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmcdxxiv{Gardens of Eden with rippling streams, where he will live for ever. This is the recompense of those who achieve integrity.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmcdxxv{We commanded Moses: ``Journey by night with Our creatures, and strike a dry path for them through the sea. Do not fear being overtaken, nor have dread of any thing."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmcdxxvi{Then the Pharaoh followed them with his army, but the sea overpowered and engulfed them.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmcdxxvii{The Pharaoh had led his people astray, and did not rightly guide them.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmcdxxviii{O children of Israel, We delivered you from your enemy, and made a covenant with you on the right side of the Mount, and sent down for you manna and quails,\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmcdxxix{(And said): ``Eat of the good things We have given you for food, and do not exceed the bounds (of law) in this, or My wrath will surely fall upon you; and he who incurs My wrath will fall into the abyss.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmcdxxx{Yet I am gracious to him who repents and believes, and does the right, and follows the straight path.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmcdxxxi{What made you hurry away, O Moses, from your people?"\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmcdxxxii{He said: ``They are right behind me. I have hastened to You, O Lord, so that You may be pleased."\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmcdxxxiii{He said: ``We have put your people on trial in your absence; and Sameri has led them astray."\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmcdxxxiv{So Moses returned to his people full of anger and regret. ``O my people," he said, ``did not your Lord make you a better promise? Did the time of covenant seem too long to you? Or did you wish the wrath of your Lord to fall upon you that you broke the promise you had made to me?"\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmcdxxxv{They said: ``We did not break our promise to you of our own will, but we were made to carry the loads of ornaments belonging to the people, which we threw (into the fire), and so did Sameri.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmcdxxxvi{Then he produced the image of a calf which mooed like a cow. And they said: 'This is your god and the god of Moses (whom) he has neglected."\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmcdxxxvii{Did they not see that it did not give them any answer, nor had it power to do them harm or bring them gain?\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmcdxxxviii{Aaron had indeed told them earlier: ``O my people, you are being only misled with this. Surely your Lord is Ar-Rahman. So follow me and obey my command."\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmcdxxxix{They said ``So long as Moses does not come back we are not going to give it up, and we will remain devoted to it."\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmcdxl{But (Moses) said: ``O Aaron, when you saw that they had gone astray, what hindered you\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmcdxli{From coming after me? Did you not disobey my command?" (And Moses pulled him by the hair).\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmcdxlii{``O son of my mother," (Aaron cried), do not pull me by my beard or my hair! I was really afraid you may say that I had created a rift among the children of Israel, and did not pay heed to your command."\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mmcdxliii{Moses asked: ``O Sameri, what was the matter?"\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mmcdxliv{He said: ``I saw what they did not see. I picked up a handful of dust from the messenger's tracks and threw it in, for the idea seemed attractive to me."\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mmcdxlv{(Moses) said: ``Go hence! All your life you are (cursed) to say: 'Do not touch me; and a threat hangs over you which you will not be able to escape. Look at your god to whom you are so attached: We shall verily burn it, and disperse its ashes into the sea.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mmcdxlvi{Your god is only God. There is no other god but He. His knowledge extends over everything."\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mmcdxlvii{Thus do We narrate some account to you of what has gone before, and We have truly given you a Reminder of Our own.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mmcdxlviii{Whoever turns away from it will surely carry a burden on the Day of Judgement,\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mmcdxlix{And will live for ever under it. How evil the burden they will carry on the Day of Doom!\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mmcdl{The day the trumpet blast is sounded We shall raise the sinners blind,\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mmcdli{Whispering to one another: ``You have tarried but ten days."\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mmcdlii{We know well what they will say when the most upright among them will say: ``You did not tarry more than a day."\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mmcdliii{They will ask you about the mountains. Tell them: ``My Lord will uproot them from the base,\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mmcdliv{And turn them into a level plain,\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mmcdlv{Over which you will see no curves or elevations.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mmcdlvi{That day they will follow the summoner from whom there will be no receding; and their voices will be hushed before Ar-Rahman, and you will not hear a sound but faint shuffling.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mmcdlvii{On that day no intercession will matter other than his whom Ar-Rahman grants permission and accepts.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mmcdlviii{He knows what is before them and hidden from them, but they cannot grasp it with their knowledge.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mmcdlix{All heads will be bowed before the Living, the Eternal; and whosoever bears a load of iniquity will be full of despair.\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mmcdlx{But he who has done good things and believes, will have no fear of either being wronged or deprived.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@mmcdlxi{That is why We have sent it down as an eloquent Qur'an, and explained in different ways the intimidations through it that they may haply take heed, or perhaps it may lead them to contemplate.\qt@no{(113)}}
\qt@newcmd\qurantrans@en@mmcdlxii{Exalted then be God, the real King; and do not try to anticipate the Qur'an before the completion of its revelation, but pray: ``O Lord, give me greater knowledge."\qt@no{(114)}}
\qt@newcmd\qurantrans@en@mmcdlxiii{We had commanded Adam before, but he disregarded it: We found him lacking in resolution.\qt@no{(115)}}
\qt@newcmd\qurantrans@en@mmcdlxiv{When We said to the angels: ''Bow before Adam,'' they all bowed but Iblis, who refused.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@mmcdlxv{So We said; ``O Adam, he is truly your enemy and your wife's. Do not let him have you turned out of Paradise and come to grief.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@mmcdlxvi{Verily you will have no hunger or nakedness there,\qt@no{(118)}}
\qt@newcmd\qurantrans@en@mmcdlxvii{Nor thirst nor exposure to the sun."\qt@no{(119)}}
\qt@newcmd\qurantrans@en@mmcdlxviii{But then Satan tempted him by saying: ``O Adam, should I show you the tree of immortality, and a kingdom that will never know any wane?"\qt@no{(120)}}
\qt@newcmd\qurantrans@en@mmcdlxix{And both ate of (its fruit), and their hidden parts were exposed to one another, and they patched the leaves of the garden (to hide them). Adam disobeyed his Lord, and went astray.\qt@no{(121)}}
\qt@newcmd\qurantrans@en@mmcdlxx{Then his Lord chose him and relented towards him, and showed him the way;\qt@no{(122)}}
\qt@newcmd\qurantrans@en@mmcdlxxi{(And) said: ``Go down hence together, one the enemy of the other. Then will guidance come to you from Me; and whoever follows My direction will neither be disgraced nor be miserable.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@mmcdlxxii{But he who fails to heed My warning will have his means restricted; and on the Day of Resurrection We shall raise him blind."\qt@no{(124)}}
\qt@newcmd\qurantrans@en@mmcdlxxiii{He will ask: ``O Lord, why have you raised me blind when I was able to see?"\qt@no{(125)}}
\qt@newcmd\qurantrans@en@mmcdlxxiv{(God) will say: ``Because Our signs came to you, but you disregarded them. So shall We disregard you this day."\qt@no{(126)}}
\qt@newcmd\qurantrans@en@mmcdlxxv{And that is how We requite him who is extravagant and does not believe the signs of his Lord; and surely the punishment of the Hereafter is far more severe and persistent.\qt@no{(127)}}
\qt@newcmd\qurantrans@en@mmcdlxxvi{Did they not learn from the many generations that We destroyed before them, whose habitations they now frequent? Verily there are signs in this for men of understanding.\qt@no{(128)}}
\qt@newcmd\qurantrans@en@mmcdlxxvii{If the decree (of respite) had not been pronounced by your Lord, (the inevitable judgement would have ensued); but a term is fixed (for everything).\qt@no{(129)}}
\qt@newcmd\qurantrans@en@mmcdlxxviii{So you bear with patience what they say, and sing the praises of your Lord before the rising and setting of the sun, and honour Him in the watches of the night, and then at the two ends of day, that you may find acceptance.\qt@no{(130)}}
\qt@newcmd\qurantrans@en@mmcdlxxix{Do not covet what We have granted myriads of people of the pomp and glitter of this world to tempt them. The means your Lord has given you are better far and more enduring.\qt@no{(131)}}
\qt@newcmd\qurantrans@en@mmcdlxxx{Enjoin on your people service to God, and be yourself constant in it. We do not ask you to provide: It is We who provide for you. The reward is for piety and fear of God.\qt@no{(132)}}
\qt@newcmd\qurantrans@en@mmcdlxxxi{Yet they say: ``Why does he not bring a sign from his Lord?" Have not clear proofs come to them in what is contained in the earlier Books?\qt@no{(133)}}
\qt@newcmd\qurantrans@en@mmcdlxxxii{If We had destroyed them by some calamity sooner than this, they would have surely said: ``O Lord, if You had sent to us a messenger we would have followed Your command before being humbled and disgraced."\qt@no{(134)}}
\qt@newcmd\qurantrans@en@mmcdlxxxiii{Say: ``Each one awaits the consequence; so you wait. You will come to know soon who are the men of the straight path and who have come to guidance.\qt@no{(135)}}
\qt@newcmd\qurantrans@en@mmcdlxxxiv{\basmalahen NEAR HAS COME the reckoning for men, but they turn away in remissness.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmcdlxxxv{Never does a new reminder come to them from their Lord but they listen to it with dalliance.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmcdlxxxvi{Their minds are lost in frivolous pastimes; and the evil-doers discuss secretly: ``Is he not but only a man like you? Then why are you taken in by magic seeingly?"\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmcdlxxxvii{He said: ``My Lord knows whatever is spoken in the heavens and the earth. He hears all and knows everything."\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmcdlxxxviii{Yet they say: ``These are only confused dreams," or rather: ``He has invented them;" or: ``He is only a poet. Let him therefore bring a miracle to us as the earlier (apostles) were sent with."\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmcdlxxxix{Not one habitation that We destroyed before them had believed. So how can they believe?\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmcdxc{Never did We send a message before you but through a man, whom We inspired. If you do not know, then ask the keepers of the oracles of God.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmcdxci{We did not make their bodies immune to hunger, nor were they immortal.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmcdxcii{Then We made Our promise good to them and delivered whomsoever We pleased, and destroyed the transgressors.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmcdxciii{We have sent down to you a Book which has a reminder for you. Do you not understand?\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmcdxciv{How many habitations that were sinful have We demolished utterly, and raised other people after them.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmcdxcv{Whensoever they sensed Our punishment they fled from them.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmcdxcvi{``Do not flee; go back to your halls of pleasure and your habitations, so that you may be interrogated."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmcdxcvii{``Woe, alas," they said, ``we were really sinful."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmcdxcviii{And this remained their lament till We mowed them down and made them extinct.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmcdxcix{We have not created the heavens and the earth, and all that lies between them, out of fun.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmd{If We had pleased to make a plaything We could have made it Ourself, if We had cared to do so.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmdi{In fact We strike the truth against the false, which shatters it, and it disappears. Woe to you for what you attribute (to Him)!\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmdii{Whosoever is in the heavens and the earth belongs to Him; and those who are near Him do not disdain to worship Him or weary (of His service),\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmdiii{Nor cease to endeavour praising Him night and day.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmdiv{Or have they taken gods from the earth who can raise the dead?\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmdv{Had there been gods apart from God, both (the heavens and the earth) would have been despoiled. Much too glorious is God, the Lord of the mighty throne, for things they assert!\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmdvi{He cannot be questioned about what He does, but they will be questioned.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmdvii{Have they taken gods besides God? Say: ``Then bring your proof. Here is the Book of those who are with me, and the Book of those who have gone before me." But most men do not know the truth and turn away.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmdviii{We have not sent an apostle before you without instructing him that there is no god but I, so worship Me.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmdix{And yet they say: ``Ar-Rahman has begotten a son." Too exalted is He! In fact, those (they call His sons) were His honoured votaries.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmdx{They did not precede Him in their speech, and acted on His command.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmdxi{He knows what was there before them and what came after them; and they did not intercede for any one but whom He willed, and they were filled with awe of Him.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmdxii{If any one of them said: ``I am God besides Him," We should award him Hell; for this is how We requite the evil-doers.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmdxiii{Do not these unbelievers see that the heavens and the earth were an integrated mass, then We split them and made every living thing from water? Will they not believe even then?\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmdxiv{We placed stabilisers in the earth so that as it revolved with them you lived undisturbed; and We provided passageways between them so that men may find their way;\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmdxv{And We made the sky a well-protected roof. Still they turn away from His signs!\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmdxvi{It is He who created night and day, the sun and the moon, revolving on its orbit.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmdxvii{We have given no man everlastingness before you. So then if you die, will they live ever after?\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmdxviii{Every soul will know the taste of death. We tempt you with evil and with good as a trial; and to Us you will return.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmdxix{But when the unbelievers see you they make fun of you (and say): ``Is this the one who mentions your gods (deridingly)?" Yet in Ar-Rahman they disbelieve!\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmdxx{Man is made of inordinate haste. We will show you Our signs, then you will not desire to hasten (the punishment).\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmdxxi{Yet they say: ``When will the promised threat come to pass, if you speak the truth?"\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmdxxii{If only the unbelievers could apprehend the moment when they would neither be able to ward off the fire from their faces and their backs, nor help reach them!\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmdxxiii{It will come upon them unawares confounding them, and they will not be able to keep it back, nor will they be given respite.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmdxxiv{Many apostles have been scoffed before you; but they who scoffed were themselves caught by what they had ridiculed.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmdxxv{Say: ``Who guards you from Ar-Rahman by night and by day?" Yet from a mention of their Lord they turn away.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmdxxvi{Or do they have lords of their own besides Us who can defend them? But they are not able to help themselves, nor can they find protection against Us.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmdxxvii{We allowed them and their fathers time to enjoy till the very end of their lives. Do they not see Us advancing into the land, reducing its frontiers? Would they still prevail?\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmdxxviii{Say: ``I am warning you by God's command." But the deaf do not hear the call when they are warned.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmdxxix{Even if a whiff of the Lord's chastisement were to touch them they would surely say: ``Ah woe, alas, we were surely sinful."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmdxxx{We shall fix the scales of justice on the Day of Resurrection, so that none will be wronged in the least; and even if it were equal to a mustard seed in weight We shall take it (into account). We are sufficient for computation.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmdxxxi{We gave Moses and Aaron the Criterion, and a light and reminder for those who take heed for themselves,\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmdxxxii{Who are fearful of their Lord inwardly and dread the Hour.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmdxxxiii{And this is a blessed reminder that We have sent down. Will you then deny it?\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmdxxxiv{We had earlier given Abraham true direction, for We knew him well.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmdxxxv{When he said to his father and his people: ``What are these idols to which you cling so passionately?"\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmdxxxvi{They replied: ``We found our fathers worshipping them."\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmdxxxvii{He said: ``You and your fathers were in clear error."\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmdxxxviii{They said: ``Are you speaking in earnest, or only jesting?"\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmdxxxix{He said: ``In fact it was your Lord, the Lord of the heavens and the earth, who created them; and I bear witness to this.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmdxl{I swear by God I will do something to your idols when you have turned your backs and gone."\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmdxli{So he smashed them up to pieces with the exception of the biggest, so that they may turn to it.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmdxlii{They asked (on return): ``Who has done this to our gods? He is surely a mischief-monger."\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmdxliii{They said: ``We heard a youth talk about them. He is called Abraham."\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmdxliv{``Bring him before the people," they said, ``that they may bear witness."\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmdxlv{``Did you do this to our gods, O Abraham?" they enquired.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmdxlvi{``No," he said. ``It was done by that chief of theirs. Ask him in case they can speak."\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmdxlvii{Then they thought and observed: ``Surely you are yourselves unjust."\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmdxlviii{Then crestfallen (they confessed): ``Truly, as you know, they cannot speak."\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmdxlix{(So Abraham) said: ``Then why do you worship something apart from God that cannot profit you or do you harm?\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmdl{Fie on you and those you worship besides God! Will you not understand?"\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmdli{They said: ``Burn him, and save your gods, if you are men of action."\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmdlii{``Turn cold, O fire," We said, ``and give safety to Abraham."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmdliii{They wished to entrap him, but We made them greater losers.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmdliv{So We delivered him and Lot, and brought them to the land We had blessed for all the people.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmdlv{And We bestowed on him Isaac, and Jacob as an additional gift, and made them righteous.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmdlvi{And We made them leaders to guide (the people) by Our command; and We inspired them to perform good deeds and observe their moral obligations and pay the zakat; and they obeyed Us.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmdlvii{To Lot We gave wisdom and knowledge, and saved him from a people who acted villainously and were certainly wicked and disobedient.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmdlviii{Thus We admitted him to Our grace. He is surely one of the righteous.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmdlix{Remember Noah when he called to Us before this. We heard him and saved him and those with him from great distress;\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmdlx{And We helped him against the people who rejected Our signs as lies. They were a wicked people indeed, so We drowned them one and all.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmdlxi{(Remember) David and Solomon, when they pronounced judgement about the field which was eaten up at night by sheep belonging to certain people. We were witness to their judgement.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmdlxii{We made Solomon understand the case, and bestowed on each wisdom and knowledge, We subdued the al-jibal (mountains) with David to sing Our praises, and at-tair (birds). It is We who did it.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmdlxiii{And We taught him the art of making coats of mail to shield you from each other's violence. Will you not be grateful even then?\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmdlxiv{We made tempestuous winds obedient to Solomon which blew swiftly to sail at his bidding (with his ships) to the land We had blessed. We are cognisant of everything.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmdlxv{And many of the devils (We also made obedient to him) who dived for him, and did many other things; and We kept watch over them.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmdlxvi{(Remember) Job when he called to his Lord: ``I am afflicted with distress, and You are the most compassionate of all."\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmdlxvii{So We heard his cry and relieved him of the misery he was in. We restored his family to him, and along with them gave him others similar to them as a grace from Us and reminder for those who are obedient.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmdlxviii{(Remember) Ishmael, Edris and Dhu'l-Kifl. They were men of fortitude,\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmdlxix{And they were admitted to Our grace. Verily they were among the doers of good.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmdlxx{And (remember) Dhu'n-Noon (Jonah of the fish), when he went away in anger and imagined We will not test him (with distress). Then he called out from the darkness: ``There is no god other than You. All glory to You; surely I was a sinner.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmdlxxi{We heard his cry, and saved him from the anguish. That is how We deliver those who believe.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmdlxxii{(Remember) Zachariah when he called to his Lord: ``Do not leave me alone (and childless), for you are the best of givers."\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmdlxxiii{So We heard him and gave him John, and cured his wife (of barrenness). These were men who vied in good deeds with one another, and prayed to Us with love and awe, and were meek before Us.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmdlxxiv{(Remember) her who preserved her chastity, into whom We breathed a new life from Us, and made her and her son a token for mankind.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmdlxxv{Verily this your order is one order, and I am your Lord; so worship Me.\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmdlxxvi{But they split up the order among themselves; (yet) all of them have to come back to Me.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmdlxxvii{So he who does the right and is a believer, will not have his labour denied, for We are congnisant of it.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mmdlxxviii{It is imperative that a habitation We have destroyed will not desist (from unbelief)\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mmdlxxix{Until when the way is opened up for Gog and Magog and they press from every elevated place,\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mmdlxxx{And the certain promise (of Doom) comes near. Then the eyes of unbelievers will be fixed in horror, (and they will cry:) ``Ah, woe betide, we were indeed heedless of this, and were oppressors and unjust."\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mmdlxxxi{Verily you and those you worship other than God will be faggots for Hell; and come to it you will.\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mmdlxxxii{Had they really been gods they would not have entered it: They will all abide in it for ever.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mmdlxxxiii{There will only be groaning for them, and they will not hear any thing.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mmdlxxxiv{But those for whom a good reward had been fore-ordained by Us, will be far removed from it,\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mmdlxxxv{And will not hear its hissing, and will live for ever in the midst of what their hearts desire.\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mmdlxxxvi{They will have safety from the mighty terror, and angels will receive them, (saying:) ``This is your day which had been promised you."\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mmdlxxxvii{The day We shall roll up the heavens like a written scroll, We shall revert it (to nothing) as it was before We first created it. This is a promise incumbent on Us; We will certainly fulfil it.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mmdlxxxviii{We had prescribed in the Book of Psalms after the reminder and admonition, that those of Our creatures who are good will in the end rule the earth.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mmdlxxxix{Verily there is a message in this for people who are devout.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mmdxc{We have sent you as a benevolence to the creatures of the world.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mmdxci{Say: ``This is what has been revealed to me: 'Your God is one and only God.' So will you bow in homage to Him?"\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mmdxcii{If they turn away, tell them: ``I have warned you all alike. I do not know if what has been promised you is near or far away.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mmdxciii{He knows surely what you say aloud, and what you hide within your breasts.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mmdxciv{I do not know if this be a trial for you, or a little advantage for a while."\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mmdxcv{``Judge in truth (between us), O Lord," he said. ``Our Lord is merciful, whose help we seek against what you attribute."\qt@no{(112)}}
\qt@newcmd\qurantrans@en@mmdxcvi{\basmalahen O YOU PEOPLE, fear your Lord. The great upheaval of the Hour will indeed be terrible.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmdxcvii{The day you see it every suckling female will forget her suckling, and every pregnant female will discharge her burden. You will see men drunk, yet it will not be intoxication. The torment of God will be severe.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmdxcviii{And yet there are men who contend about God without understanding, and follow every wayward devil\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmdxcix{Who, it is inscribed, will beguile whoever follows him, and lead him to the torment of Hell.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmdc{If you have any doubt, O men, about being raised to life again, (remember) that We created you from dust, then a drop of semen, then an embryo, then a chewed up lump of flesh shaped and shapeless, that We may reveal (the various steps) to you. We keep what We please in the womb for a certain time, then you come out as a child, then reach the prime of age. Some of you die, some reach the age of dotage when they forget what they knew, having known it once. You see the earth all withered, then We send down rain upon it, and it bestirs itself, swells, and brings forth every kind of beauteous verdure.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmdci{That is so for God is the undeniable Reality. It is He who brings the dead to life, for He has power over everything.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmdcii{The Hour will come without a doubt, and God will raise those who are dead.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmdciii{Yet there are some who contend about God without any knowledge or guidance or enlightening Book,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmdciv{Turning their backs that they may lead away from the path of God. For such there is disgrace in the world, and on the Day of Judgement We shall make them taste the torment of burning.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmdcv{That is on account of what you had done in the past; yet God is not unjust to His creatures.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmdcvi{There are some men who worship God only from the margin. If there is some profit they are content; but if calamity befalls them they turn about, thus losing both this world and the next. This is indeed a palpable loss.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmdcvii{Leaving God they pray to those who cannot harm or profit them. That is the limit of going astray.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmdcviii{They pray to him whose bane is more imminent than his boon: How bad the protector and how bad the associate!\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmdcix{God will admit those who believe and do the right to gardens full of rippling streams. Verily God does as He pleases.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmdcx{He who thinks that God will not help him in this world and the next should stretch a rope to the sky then cut it off and see if his mind is relieved (of doubts) by this stratagem.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmdcxi{That is why We have sent down these clear revelations, for God gives guidance whomsoever He please.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmdcxii{God will judge between those who believe and the Jews, the Sabians, Christians and the Magians and the idolaters, on the Day of Judgement. Verily God is witness to everything.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmdcxiii{Do you see how all things in heavens and the earth, the sun, the moon, the stars, the mountains, trees and beasts, and men in abundance, pay homage to God? Yet there are many who deserve the punishment. And whosoever God disgraces will have none to raise him up in honour. God does verily as He will.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmdcxiv{These two (believers and unbelievers) are disputants, who contend about their Lord. But they who disbelieve will be fitted out with garments of flames. Boiling water will be poured down over their heads\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmdcxv{Which will dissolve everything within their bellies, and their skins.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmdcxvi{There are iron maces for them.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmdcxvii{As often as they try to escape from its anguish they would be put back into (the fire), and taste the torment of burning.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmdcxviii{God will surely admit those who believe and do the right to gardens with rivers running by, where they will be decked in bracelets of gold and of pearls; and of silk will be their garments.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmdcxix{They will be guided with gentle words, and guided to the commended path.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmdcxx{As for those who disbelieve, and obstruct the way of God and the holy Mosque which We have set down for all men, the native and the visitor alike. Whoever puts obstructions in this mischievously will taste of painful punishment.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmdcxxi{When We chose the site of the House for Abraham (We said:) ``Associate no one with Me, and clean My House for those who will circumambulate it, stand (in reverence), and bow in homage.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmdcxxii{Announce the Pilgrimage to the people. They will come to you on foot and riding along distant roads on lean and slender beasts,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmdcxxiii{In order to reach the place of advantage for them, and to pronounce the name of God on appointed days over cattle He has given them for food; then eat of the meat and feed the needy and the poor.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmdcxxiv{Let them then attend to their persons and complete the rites of pilgrimage, fulfil their vows and circuit round the ancient House.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmdcxxv{Apart from this, whoever respects the sacred ordinances of God, will find a better reward for him with his Lord. You are allowed to eat all cattle except those already mentioned to you. Avoid the repugnance of idols, and false and frivolous talk.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmdcxxvi{Turn uprightly to God without ascribing compeers to Him; for he who associates any one with God is like a thing that falls from the sky and is either snatched away by birds or carried far away by the wind.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmdcxxvii{All this, and honouring the offerings to God, comes from purity of heart.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmdcxxviii{, There are advantages for you in these (cattle) up to a time, then their place is the ancient House for sacrifice.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmdcxxix{For every community We have ordained certain rites that they may commemorate the name of God by reading it over the cattle We have given them for sacrifice. Your God is one God, so be obedient to Him. Give good tidings to those who bow in obedience to God,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmdcxxx{Whose hearts are filled with awe when the name of God is mentioned before them, who endure with fortitude what befalls them, and fulfil their moral obligations, and expend of what We have given them.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmdcxxxi{We have made the camels signs of God for you. There is good for you in this. So pronounce the name of God over them as they stand with their forefeet in a line. When they have fallen (slaughtered) on their sides, eat of (their meat) and feed those who are content with little, and those who supplicate. That is why We have brought them under your subjugation so that you may be grateful.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmdcxxxii{It is not their meat or blood that reaches God: It is the fealty of your heart that reaches him. That is why He has subjugated them to you that you may glorify God for having shown you the way. So give glad tidings to those who are doers of good.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmdcxxxiii{God will certainly defend the believers. Surely God does not like the traitors who deny the truth.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmdcxxxiv{Permission is granted those (to take up arms) who fight because they were oppressed. God is certainly able to give help to those\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmdcxxxv{Who were driven away from their homes for no other reason than they said: ``Our Lord is God." And if God had not restrained some men through some others, monastries, churches, synagogues and mosques, where the name of God is honoured most, would have been razed. God will surely help those who help Him, -- verily God is all-powerful and all-mighty, --\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmdcxxxvi{Those who would be firm in devotion, give zakat, and enjoin what is good and forbid what is wrong, if We gave them authority in the land. But the resultance of things rests with God.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmdcxxxvii{If they accuse you of falsehood, (remember that) the people of Noah, 'Ad and Thamud had accused (their apostles) before,\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmdcxxxviii{And the people of Abraham and Lot,\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmdcxxxix{And the people of Midian too. Moses was also accused of lies. So I allowed the infidels respite and then seized them. How was My reprobation then!\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmdcxl{How many a habitation given to wickedness have We destroyed, whose roofs tumbled down, which fell into ruins. How many a well and fortress reinforced lie abandoned!\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmdcxli{Have they not travelled in the land that they could have the heart to understand, and ears to hear? It is not the eyes alone that do not see, oblivious are the hearts within their breasts.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmdcxlii{That is how they ask you to hasten the punishment; but God does not go back on His promise. Verily a day with your Lord is equal by your reckoning to a thousand years.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmdcxliii{To how many habitations did We give respite, though given to wickedness, and then seized them. To Me they had to come back in the end.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmdcxliv{Tell them: ``O men, it's my duty to warn you clearly."\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmdcxlv{For those who believe and do the right is forgiveness and gracious provision.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmdcxlvi{But those who try to defeat Our signs are people of Hell.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmdcxlvii{We have sent no messenger or apostle before you with whose recitations Satan did not tamper. Yet God abrogates what Satan interpolates; then He confirms His revelations, for God is all-knowing and all-wise.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmdcxlviii{This is in order to make the interpolations of Satan a test for those whose hearts are diseased and hardened: Surely the sinners have gone far in dissent.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmdcxlix{At the same time those who have been given knowledge may know that this is the truth from your Lord, and come to believe in it, and their hearts become submissive to Him. Verily God guides those who believe, to the even path.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmdcl{The infidels will remain in doubt about it till the Hour overtakes them unawares, or the punishment of the barren day destructive should come upon them.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmdcli{The order will be God's on that Day; He will judge between them. Then those who had come to believe and done the right will be in gardens of delight.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmdclii{But those who did not believe and called Our revelations lies, will be given disgraceful punishment.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmdcliii{Those who left their homes in the way of God, and then were killed or died, will surely be given a better provision by God, for God is surely the best of providers.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmdcliv{God will surely lead them to a place with which they will be gratified. Verily God is all-knowing and forbearing.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmdclv{Whosoever retaliates to the extent of injury suffered by him, and is wronged again, will certainly be helped by God. Verily God is forgiving and kind.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmdclvi{That is so for God turns night into day and day into night, for God is all-hearing and all-seeing;\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmdclvii{That is so for God is the undeniable truth, and what they invoke apart from Him is false; yet God is all-high and supreme.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmdclviii{Do you not see how God sends down water from the sky and in the morning the earth turns green? Truly God is benign and well-informed.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmdclix{Whatsoever is in the heavens and the earth belongs to Him. Surely God is all-sufficing, worthy of praise.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmdclx{Do you not see God has harnessed all that is in the earth, to your service? And the boats ply in the ocean by His command. He holds the sky in position lest it should fall upon the earth save by His dispensation. Verily God is compassionate and kind to men.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmdclxi{It is He who gives you life, then makes you die; then He will bring you back to life again. Man is surely most ungrateful.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmdclxii{We have determined for each community a way of worship which they follow. So they should not contend with you in this matter; and you should go on calling them to your Lord. You are surely on the right path.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmdclxiii{If they argue with you, tell them: ``God knows well what you are doing.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmdclxiv{God will judge between you on the Day of Judgement in what you are at variance."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmdclxv{Do you not know that God knows whatever is in the heavens and the earth? This is surely in accordance with the law. This is certainly how (the law of) God works inevitably.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmdclxvi{Yet they worship in place of God that for which no authority has been sent to them, and of which they have no knowledge. The wicked will have none to help them.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmdclxvii{When Our clear messages are read out to them you can see denial on the faces of unbelievers. They can hardly restrain themselves from attacking those who recite Our revelations. Tell them: ``Should I give you news of something worse than this?" -- Hell, which God has promised the infidels. How evil a destination!\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmdclxviii{O men, give ear to this parable: Those you worship other than God can never create as much as a fly, even if they get together to do so; and if the fly were to rob them of a thing they would not be able to snatch it away from it. How weak the seeker and how weak the sought!\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmdclxix{They do not esteem God with the right estimation. God is surely all-powerful and all-mighty.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmdclxx{God chooses messengers from the angels and human beings. Verily God is all-hearing and all-seeing.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmdclxxi{He knows what is before them and what lies behind them, and all things go back to God.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmdclxxii{O you who believe, bow in adoration, Worship your Lord and do what is good that you may find success.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmdclxxiii{Strive in the way of God with a service worthy of Him. He has chosen you and laid no hardship on you in the way of faith, the faith of your forbear Abraham. He named you Muslim earlier, and in this (Qur'an), in order that the Prophet be witness over you, and you be witness over mankind. So be firm in devotion, pay the zakat, and hold on firmly to God. He is your friend: How excellent a friend is He, how excellent a helper!\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmdclxxiv{\basmalahen THE TRUE BELIEVERS will be successful,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmdclxxv{Who are humble in their service,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmdclxxvi{Who shun all frivolities,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmdclxxvii{Who strive for betterment;\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmdclxxviii{Who guard their sex\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmdclxxix{Except from their wives and women slaves of old are free of blame,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmdclxxx{But those who covet more than this will be transgressors;\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmdclxxxi{And those who fulfil their trusts and keep their promises;\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmdclxxxii{And those who are watchful of their acts of prayer.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmdclxxxiii{These are the real gainers,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmdclxxxiv{Who will inherit Paradise, and live in it for ever.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmdclxxxv{We created man from the finest extract of clay,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmdclxxxvi{Then We placed him as a sperm in a firmly established lodging;\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmdclxxxvii{Then We fashioned the sperm into an embryo, then fashioned the embryo into a shapeless lump of flesh; then from the lump of flesh We fashioned bones, then clothed the bones with flesh. Thus We formed him into a new creation. So blessed be God the best of Creators.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmdclxxxviii{And then you will certainly die,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmdclxxxix{Then will be raised up on the Day of Resurrection.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmdcxc{We made several highways one over the other above you. We are not neglectful of creation.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmdcxci{We send down water from the sky in determined measure, and store it up in the earth; and We have power to drain it away.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmdcxcii{We grow orchards of dates and grapes from it for you, Which yield fruits in abundance that you eat.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmdcxciii{The tree that grows on Mount Sinai yields oil and seasoning for those who eat.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmdcxciv{There are lessons for you in the cattle from whose bellies We give you milk to drink, and there are other advantages that you derive from them, and some of them you eat;\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmdcxcv{And you are carried on them and on boats.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmdcxcvi{We sent Noah to his people. He said: ``O my people, worship God, for you have no other god but He. Will you not take heed for yourselves?"\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmdcxcvii{The chiefs of his people, who did not believe, said: ``He is only a man like you. He wishes to acquire ascendancy over you. If God had willed He would have sent down angels. We never heard this from our elders.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmdcxcviii{He is only a man possessed; so wait and watch him for a time."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmdcxcix{``O my Lord," prayed (Noah), ``help me against them, for they accuse me of lies."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmdcc{So We asked him to build the ark under Our eyes and guidance, (and said): ``When Our command is issued and the source of water boils over, put a pair of every species in it, and your family except those for whom Our sentence has been passed already; and do not speak to Me for those who are wicked: They will be drowned.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmdcci{When you and those with you have boarded the ark, say: 'All praise be to God who has delivered us from the people who were sinful.'\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmdccii{And say: 'O Lord, disembark me in a welcome place; You are the best of deliverers.'\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmdcciii{There were surely signs in this; We will surely put you to the test.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmdcciv{After them We raised a new generation.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmdccv{Then We sent to them an apostle from among them (who said): ``Worship God, for you have no other god but He. Will you not take heed and fear God?"\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmdccvi{The chiefs of the people who did not believe and denied the life to come, though We had given them good things of this life to enjoy, (said): ``He is only a mortal like you. He eats as you do, and drinks as you drink.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmdccvii{So if you follow a man like yourself you will certainly be doomed.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmdccviii{Does he give you a promise that when you are dead and turned to dust and bones, you will be raised to life again?\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmdccix{How far-fetched what you are promised;\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmdccx{There is only the life of this world: We die and we live: there is no rising from the dead for us.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmdccxi{He is just a man who invents a lie about God; we cannot believe in him."\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmdccxii{(The apostle prayed): ``O Lord, deliver me, for they accuse me of lies."\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmdccxiii{Answered (the Lord): ``They shall wake up repenting soon."\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmdccxiv{So they were rightly seized by a mighty blast; and We turned them into mouldy rubbish: A good riddance of the wicked people!\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmdccxv{Then after them We raised other generations.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmdccxvi{No nation can live beyond its allotted time, or lag behind.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmdccxvii{Then We sent Our apostles one after the other. Every time an apostle came to a people they denied him. So We made one follow the other (to its doom), and turned them into bygone tales. Cursed be the people who do not believe!\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmdccxviii{Then We sent Moses and his brother Aaron with Our miracles and clear proofs\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmdccxix{To Pharaoh and his nobles who behaved with arrogance, for they were a conceited lot,\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmdccxx{And said: ``Should we believe in two men like yourselves, whose people are our subjects?"\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmdccxxi{Then they accused them of lies, and joined the company of those who were destroyed.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmdccxxii{And We gave the Book to Moses so that they may be guided.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmdccxxiii{And We made the son of Mary and his mother a sign, and gave them shelter on an elevated ground, sequestered, watered by a spring.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmdccxxiv{O you apostles, eat things that are clean, and do things that are good. We are surely cognisant of what you do.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmdccxxv{Verily this your order is one order, and I am your Lord, so fear Me.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmdccxxvi{But then they divided up their order into different creeds, each section rejoicing in what it had come to have.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmdccxxvii{So leave them to their ignorance for a time.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmdccxxviii{Do they think that by increasing their wealth and children\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmdccxxix{We are hastening to reward them for good deeds? No. They do not comprehend.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmdccxxx{Surely those who live in awe of their Lord,\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmdccxxxi{Who believe in their Lord's revelations,\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmdccxxxii{Who do not associate any one with their Lord,\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmdccxxxiii{Who give whatsoever they give (in His way), and their hearts tremble with fear that they have to go back to their Lord,\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmdccxxxiv{Are the ones who hasten to goodness and outpace the others.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmdccxxxv{We do not burden a soul beyond capacity, for We have a record that tells the truth. No wrong will be done to any one.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmdccxxxvi{Yet their hearts are oblivious of this; and besides, they are busy with other things,\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmdccxxxvii{So that when We seize the affluent among them with affliction, they will begin to implore for help.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmdccxxxviii{``Do not supplicate for help today; you will not be rescued by Us;\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmdccxxxix{For when My revelations were read out to you, you turned back on your heels and fled\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmdccxl{Insolently, treating them like tales told at night."\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmdccxli{Why did they not think over the message? Or has something come to them which had not come to their fathers?\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmdccxlii{Or did they not recognise their apostle, and rejected him?\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmdccxliii{Or do they say that he is possessed? In fact, he has brought the truth to them, but most of them abhor the truth.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmdccxliv{Had truth been subject to their whims the heavens and the earth and all those within them would have been depraved. In fact We had sent them their reminder, but they turned away from good advice.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmdccxlv{Or do you ask of them any tribute? In that case the tribute of your Lord is better, for He is the best of providers.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmdccxlvi{You are surely calling them to the right path.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmdccxlvii{But those who believe not in the Hereafter turn away from the straight path.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmdccxlviii{If We took compassion on them and removed the affliction they are in, they would only wander lost in confusion.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmdccxlix{We had seized them with the punishment, but they did not bow before their Lord nor turned to Him in humility,\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmdccl{So that when at last We open up the gate of severe punishment on them they will be overwhelmed with despair.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmdccli{It is He who gave you hearing, sight, and hearts, but only few of you give thanks.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmdcclii{It is He who multiplied you on the earth, and it will be before Him that you will be gathered.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmdccliii{It is He who gives you life and death, and His the alternation of night and day. Even then you do not understand,\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmdccliv{And talk as did the people of old.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmdcclv{They say: ``When we are dead and turned to dust and bones, shall we be raised to life again?\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmdcclvi{We and our fathers were promised this before; it is nothing but ancient lore!"\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmdcclvii{Say: ``To whom does the earth and whosoever is upon it then belong, if you know?"\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmdcclviii{They will say: ``To God." Say: ``Then why do you not bethink yourselves?"\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmdcclix{Say: ``Then who is the Lord of the seven skies? And who is the Lord of the mighty Throne?"\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmdcclx{They will say: ``God." Say: ``Then why do you not obey and fear Him?"\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmdcclxi{Say: ``Whose is the sovereignty over all things, who protects, and against whom there is no protection? (Answer) if you have knowledge."\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmdcclxii{They will say: ``God's." Say: ``Then why are you so deluded?"\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmdcclxiii{In fact We have sent the truth to them, but they are liars.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmdcclxiv{God has not begotten a son, nor is there any god besides Him. Had this been so, each god would have taken away what he had created with him, and some would have risen over the others. God is much too glorious for what they attribute (to Him)!\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmdcclxv{The knower of the absent and the present, too exalted is He for what they associate (with Him)!\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmdcclxvi{Say: ``O Lord, if I am made to see what has been promised them,\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmdcclxvii{Then do not, O Lord, put me among the sinners."\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mmdcclxviii{We have certainly the power to make you see what We have promised them.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mmdcclxix{Dispel evil with what is good. We know well what they attribute (to Us).\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mmdcclxx{Say: ``My Lord, I seek refuge in You from the evil promptings of the devils.\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mmdcclxxi{I seek refuge in You lest they come to me."\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mmdcclxxii{(But the unbelievers will persist) until when death comes to one of them he will say: ``O Lord, send me back again\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mmdcclxxiii{That I may do some good I did not do (in the world)." Not so. These are only words he utters. Behind them lies the intervening barrier (stretching) to the day of their resurrection.\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mmdcclxxiv{When the trumpet blast is sounded no ties of lineage will hold among them, nor will they ask after one another.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mmdcclxxv{Only those whose scales are heavier in the balance will find happiness.\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mmdcclxxvi{But those whose scales are lighter will perish and abide in Hell for ever.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mmdcclxxvii{Their faces will be scorched by flames, and they will grin and scowl within it.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mmdcclxxviii{``Were not My messages read out to you? But you denied them."\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mmdcclxxix{They will say: ``O Lord, our misery overwhelmed us, so we remained a people astray.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mmdcclxxx{Get us out of this, O Lord. If we transgress we will surely be sinful."\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mmdcclxxxi{He will say: ``Remain condemned in it, and do not speak to Me.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mmdcclxxxii{There was a section among My creatures that said: 'O Lord, we believe. Forgive us and have mercy upon us, for You are the best of the merciful.'\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mmdcclxxxiii{But you ridiculed them. So much so that out of (spite) for them you forgot to remember Me and laughed at them.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mmdcclxxxiv{I have rewarded them this day for they were constant, and they have come to attainment."\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mmdcclxxxv{They will be asked: ``How long did you live on the earth in terms of years?"\qt@no{(112)}}
\qt@newcmd\qurantrans@en@mmdcclxxxvi{They will say: ``A day or less than a day. Ask the enumerators of numbers."\qt@no{(113)}}
\qt@newcmd\qurantrans@en@mmdcclxxxvii{He will say: ``You stayed there only a moment, if you knew.\qt@no{(114)}}
\qt@newcmd\qurantrans@en@mmdcclxxxviii{Do you think We created you for nothing, and that you will not return to Us?"\qt@no{(115)}}
\qt@newcmd\qurantrans@en@mmdcclxxxix{Exalted then be God, the King, the Real. There is no god but He, the Lord of the glorious throne.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@mmdccxc{Whoever worships another god apart from God, for which he holds no proof, will have to account for it before his Lord. Verily the unbelievers will not prosper.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@mmdccxci{Say: ``My Lord, forgive and have mercy. You are the best of the merciful."\qt@no{(118)}}
\qt@newcmd\qurantrans@en@mmdccxcii{\basmalahen WE HAVE REVEALED this Surah and made it obligatory as We have sent down clear injunctions in it that you may be warned.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmdccxciii{The adulteress and adulterer should be flogged a hundred lashes each, and no pity for them should deter you from the law of God, if you believe in God and the Last Day; and the punishment should be witnessed by a body of believers.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmdccxciv{The adulterer can marry no one but an adulteress or his partner (in the act), and the adulteress cannot marry any but an adulterer or her partner (in the act). This is forbidden the believers,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmdccxcv{Those who defame chaste women and do not bring four witnesses should be punished with eighty lashes, and their testimony should not be accepted afterwards, for they are profligates,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmdccxcvi{Except those who repent after this and reform; and God is surely forgiving and kind.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmdccxcvii{Those who accuse their wives and do not have any witnesses except themselves, should swear four times in the name of God, the testimony of each such person being that he is speaking the truth,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmdccxcviii{And (swear) a fifth time that if he tell a lie the curse of God be on him.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmdccxcix{The woman's punishment can be averted if she swears four times by God as testimony that her husband is a liar,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmdccc{Her fifth oath being that the curse of God be on her if her husband should be speaking the truth.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmdccci{(This would not have been possible) if the grace and benevolence of God were not upon you; but God is compassionate and wise.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmdcccii{Those who spread lies were a clique among you. Do not think that it was bad for you: In fact it has been good for you. Each of them will pay for the sin he has committed, and he who had greater share (of guilt) will suffer grievous punishment.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmdccciii{Why did the faithful men and women not think well of their people when they heard this, and said: ``This is a clear lie?"\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmdccciv{Why did they not bring four witnesses (in support of their charge)? And since they did not bring the four witnesses they are themselves liars in the sight of God.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmdcccv{Were it not for the grace of God and His mercy upon you in this world and the next, you would have suffered a great affliction for the false accusation.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmdcccvi{When you talked about it and said what you did not know, and took it lightly -- though in the sight of God it was serious --\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmdcccvii{Why did you not say when you heard it: ``It is not for us to speak of it? God preserve us, it is a great calumny!"\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmdcccviii{God counsels you not to do a thing like this, if you are believers.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmdcccix{God explains His commands to you clearly, for God is all-knowing and all-wise.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmdcccx{There is painful punishment in this world and the next for those who like that immorality should spread among the believers, for God knows and you do not know.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmdcccxi{But for the grace of God and His mercy (much harm would have been done); yet God is compassionate and kind.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmdcccxii{O you who believe, do not follow in the footsteps of Satan, for he who follows in the footsteps of Satan will be induced by him to what is shameful and forbidden. But for the grace of God and His mercy upon you none of you would have escaped undefiled; but God makes whosoever He will grow in goodness, for God is all-hearing and all-knowing.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmdcccxiii{Let not those who are men of plenty and means among you swear that they will not give to their relatives and the poor and those who leave their homes in the service of God. They should forgive and overlook (their failings). Would you not like God to forgive you? And God is forgiving and kind.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmdcccxiv{Verily those who blaspheme unsuspecting chaste believing women will be cursed in this world and the next; and for them there will be severe punishment.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmdcccxv{The day their tongues and hands and feet bear witness to what they had done,\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmdcccxvi{God will pay them on that day their just due in full, and they will come to know that God is the tangible Reality.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmdcccxvii{Bad women deserve bad men, and bad men are for bad women; but good women are for good men, and good men for good women, for they are innocent of what people say. There is forgiveness for them and a gracious provision.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmdcccxviii{O you who believe, do not enter other houses except yours without first asking permission and saluting the inmates. This is better for you: You may haply take heed.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmdcccxix{If you find that no one is in, then do not enter unless you have received permission. If you are asked to go away, turn back. That is proper for you. God is aware of what you do.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmdcccxx{There is no harm in going into uninhabited houses where there is some convenience for you, as God has knowledge of what you hide and what you disclose.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmdcccxxi{Tell the believing men to lower their eyes and guard their private parts. There is for them goodness in this. God is aware of what they do.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmdcccxxii{Tell the believing women to lower their eyes, guard their private parts, and not display their charms except what is apparent outwardly, and cover their bosoms with their veils and not to show their finery except to their husbands or their fathers or fathers-in-law, their sons or step-sons, brothers, or their brothers' and sisters' sons, or their women attendants or captives, or male attendants who do not have any need (for women), or boys not yet aware of sex. They should not walk stamping their feet lest they make known what they hide of their Ornaments. O believers, turn to God, every one of you, so that you may be successful.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmdcccxxiii{Marry off those who are single among you, and those of your male and female servants who are righteous. If they are poor, God will enrich them of His grace, for God is bounteous and all-knowing.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmdcccxxiv{Those who cannot afford to marry should abstain from what is unlawful until God enriches them by His grace. And free those slaves you possess who wish to buy their freedom after a written undertaking, if you know they have some goodness, and give them out of the riches God has given you. Do not force your maids to prostitution if they wish to lead married lives, in order to get the benefits of this world. But if someone forces them, surely God (will forgive them) after their forced helplessness, for He is forgiving and kind.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmdcccxxv{We have sent down clear instructions to you, and illustrations from (the accounts) of those who have gone before you, and a warning for those who take heed for themselves.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmdcccxxvi{God is the light of the heavens and the earth. The semblance of His light is that of a niche in which is a lamp, the flame within a glass, the glass a glittering star as it were, lit with the oil of a blessed tree, the olive, neither of the East nor of the West, whose oil appears to light up even though fire touches it not, -- light upon light. God guides to His light whom He will. So does God advance precepts of wisdom for men, for God has knowledge of everything.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmdcccxxvii{(The light is lit) in houses of worship which God has allowed to be raised, and His name remembered in them. His praises are sung there morning and evening,\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmdcccxxviii{By men not distracted from the remembrance of God either by trade and commerce or buying and selling, who stand by their devotional obligations and pay the zakat, who fear the day when hearts and eyes would flutter with trepidation\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmdcccxxix{That God may reward them for the best of their deeds, and bestow more on them of His bounty, for God gives whom He please without measure.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmdcccxxx{As for those who disbelieve, their deeds are like a mirage in the desert which the thirsty takes for water till he reaches it to find that there was nothing, and finds God with him who settles his account, for God is swift at the reckoning.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmdcccxxxi{Or like darkness in a wide, wide sea, waves surging upon waves, with clouds overhanging, darkness on darkness. If you stretch your hand, you could hardly see it. For him whom God does not give any light, there is no light.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmdcccxxxii{Have you not seen that all those who are in the heavens and the earth, and the birds on the wing, sing the praises of God. Each one knows its obligations and its duties, and God knows whatever they do.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmdcccxxxiii{For God's is the kingdom of the heavens and the earth, and the returning is to God.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmdcccxxxiv{Have you not seen that God drives the clouds, then joins them together and puts them fold on fold. Then you see the rain fall through them; and He sends down hail from the sky where there are mountains of it, and strikes those with it whom He will, and wards it off from whomsoever He please. His lightning could snatch away their eyes.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmdcccxxxv{It is God who alternates night and day. There is surely a lesson in this for men of sight.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmdcccxxxvi{God created every moving thing from water: One crawls on its belly, one walks on two legs, another moves on four. God creates whatsoever He will. Indeed God has power over everything.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmdcccxxxvii{We have surely sent down clear signs. It is God who guides whom He will to the path that is straight.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmdcccxxxviii{They say they believe in God and the Prophet, and have come to believe, yet a section of them turns back even after this; and these are not believers.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmdcccxxxix{When they are called to God and His Prophet, that he may judge between them, a section of them turns away.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmdcccxl{Had right been on their side they would have come to him submissively.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmdcccxli{Is there a malady in their hearts, or they are deluded, or afraid that God and His Prophet would be unjust in dealing with them? Not so; they are themselves unjust.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmdcccxlii{The answer of the believers when they are called to God and His Apostle that he may judge between them, is: ``We hear and obey." And they are the ones who will prosper.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmdcccxliii{Whoever obeys God and His Prophet, fears God and does his duty to Him, will surely find success.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmdcccxliv{They swear solemnly by God: ``If you command us we shall go forth." Say: ``Do not swear. What is wanted is obedience, as should be. God is certainly aware of what you do."\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmdcccxlv{Say: ``Obey God and obey the Apostle. If you turn away, then for him is his duty to fulfil, and for you the burden that you carry; yet if you obey him you will be rightly guided. The duty of the Messenger is to convey the message clearly.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmdcccxlvi{God has promised to make those of you who believe and do the right, leaders in the land, as He had made those before them, and will establish their faith which He has chosen for them and change their fear into security. They will worship Me and not associate any one with Me. But those who disbelieve after this will be reprobates.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmdcccxlvii{So observe your devotional obligations, pay the zakat, and obey the Apostle so that you may be shown mercy.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmdcccxlviii{Do not think that unbelievers will subvert (the authority of God) on earth. Their abode is Hell; and what an evil destination!\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmdcccxlix{O you who believe, let your dependants and those who have not yet reached the age of puberty, ask permission (to enter your presence) on three occasions: Before the early morning prayer; when you disrobe for the mid-day siesta; and after prayer at night. These are the three occasions of dishabille for you. There is no harm if you or they visit one another at other times (without permission). God thus explains things to you clearly, for God is all-knowing and all-wise.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmdcccl{When your children have reached the age of puberty, they should similarly ask your leave (for entering) as others did before them. God thus clearly explains His commands to you, for God is all-knowing and all-wise.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmdcccli{As for your women past the age of bearing children, who have no hope of marriage, there is no harm if they take off their outer garments, but in such a way that they do not display their charms; yet if they avoid this it would be better for them. God is all-hearing and all-knowing.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmdccclii{There is no harm if the blind, the lame, the sick, or you yourselves, eat in your own houses or the houses of your fathers, mothers, or your brothers' houses, or those of your sisters, or your fathers' brothers' or sisters', or your mothers' brothers' or sisters', or in the houses whose care is entrusted to you, or the houses of your friends.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmdcccliii{There is no harm in your eating together or separately. But when you enter the houses, salute the inmates with a greeting in the name of God, invoking blessings and good health. That is how God explains things to you clearly so that you may understand. They alone are true believers who believe in God and His Apostle, and when they are with him on a matter of common concern, do not depart without obtaining his leave. Surely those who ask leave of you are the ones who believe in God and His Apostle. Therefore when they ask leave of you for personal business give leave to those you please, and seek God's forgiveness for them. Surely God is forgiving and kind.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmdcccliv{Do not consider your being summoned by the Apostle to be like your summoning one another. God knows those of you who go away surreptitiously. So let those who act in contravention of his command take heed lest a trial should befall them or a grievous punishment come upon them.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmdccclv{Does not everything in the heavens and the earth belong to God? He surely knows what state you are in; and on the day they go back to Him. He will tell them what they used to do, for God has knowledge of everything.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmdccclvi{\basmalahen BLESSED IS HE who revealed the Criterion (of right and wrong) to His votary that it may be a warning for the world, --\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmdccclvii{He to whom belongs the kingdom of the heavens and the earth, who has neither begotten a son nor has He a partner in His kingdom, (who) created everything and determined its exact measure.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmdccclviii{Yet they choose apart from Him gods who have not created any thing and have themselves been created, who possess no power over their loss or gain, or their death or life or being raised to life again.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmdccclix{Yet the unbelievers say: ``This is nothing but a lie he has concocted in which others have aided him." They have come down to mischief and lies.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmdccclx{And they say: ``These are fables of antiquity he has invented, which are dictated to him morning and evening."\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmdccclxi{Say: ``He who knows the secrets of the heavens and the earth has revealed it to me; and He is surely forgiving and kind."\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmdccclxii{But they say: ``What sort of prophet is this who eats food and walks the market places? Why was no angel sent to him to act as admonisher with him?\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmdccclxiii{Or a treasure should have been given to him, or he should have had an orchard from which he could eat." And these wicked people say: ``You only follow a man ensorcelled."\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmdccclxiv{Just see what comparisons they bring up for you! They are lost and cannot find the way.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmdccclxv{Blessed be He who, if He pleased, could give you better than that, -- gardens with rivers flowing by; and make palaces for you.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmdccclxvi{Yet they reject the Hour as untrue. We have prepared a Fire for those who deny the Resurrection.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmdccclxvii{When (Hell) appears to them from a distance they will hear it raging and roaring.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmdccclxviii{And when they are cast within a narrow space of it chained together, they would plead for death.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmdccclxix{``Do not ask for one death but many deaths on this day."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmdccclxx{Ask them: ``Is this better or a garden for everlasting abode which has been promised the pious and devout? It would be their guerdon and their destination.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmdccclxxi{There will they have whatever they wish, and there abide for ever." This is a promise incumbent on your Lord which will certainly be fulfilled.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmdccclxxii{The day He will gather them together along with those they worshipped other than God, He will ask them: ``Did you lure these creatures of Mine away, or did they themselves go astray?"\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmdccclxxiii{They will answer: ``Glory to You. It was not worthy of us to seek any protector other than You. But You allowed them and their fathers a life of ease until they turned oblivious of the Reminder. They were a people impenitent.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmdccclxxiv{(The idolaters will be told): ``Your gods have refuted your assertion. You can neither avert (your doom) nor receive any help. We shall make the wicked among you taste of severe punishment."\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmdccclxxv{We never sent before you apostles who did not eat food and walk the market places. We make some of you the means of trying the others. So will you persevere? Your Lord is always watching.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmdccclxxvi{Those who do not hope to meet Us say: ``Why are no angels sent down to us, or why do we not see our Lord?" They are full of self-conceit and behave with intense arrogance.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmdccclxxvii{The day they see the angels there will be no happy tidings for the sinners; and they will say: ``There is an insurmountable barrier!"\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmdccclxxviii{We shall turn to their deeds and scatter them like particles of dust.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmdccclxxix{The inmates of Paradise will have a better abode that day, and a better resting place.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmdccclxxx{The day the heavens splits asunder with a dazzling white cloud gathering and the angels descend in a continuous stream,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmdccclxxxi{The real sovereignty will belong to Ar-Rahman. How grievous will be the day for the infidels!\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmdccclxxxii{The sinner will then bite his hand and say: ``Would that I had taken the road with the Prophet.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmdccclxxxiii{Woe alas, ah would I had not taken so-and-so as friend!\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmdccclxxxiv{He led me astray from the Warning after it had come to me. Satan always betrays man.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmdccclxxxv{The prophet will say: ``O my Lord, my people had fettered the Qur'an."\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmdccclxxxvi{Thus do We keep opponents among the sinners for every apostle; yet your Lord is sufficient as a guide and helper.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmdccclxxxvii{The unbelievers say: ``Why was the whole Qur'an not sent down all at once to him?" It was sent thus that We may keep your heart resolute. So We enunciated it by steps and distinctly.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmdccclxxxviii{There is not an example they advance to which We do not give you a right answer and a better explanation.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmdccclxxxix{Those who will be pushed faces forward into Hell will be in a worse position, farther away from the path.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmdcccxc{We gave Moses the Book, and made his brother Aaron his minister,\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmdcccxci{Then We told them: ``Go to the people who have rejected Our signs." Then We annihilated them completely.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmdcccxcii{We had drowned the people of Noah when they had accused the apostles of lies, and turned them into an example for men. We have prepared a painful punishment for the wicked.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmdcccxciii{(As for) 'Ad, Thamud and the people of ar-Rass, and many generations in between them,\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmdcccxciv{We administered warnings to each of them, and then destroyed them completely.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmdcccxcv{They must have surely passed by the town on which We had rained the terrible rain of ruin. How could they not have seen it? Still they do not dread the Resurrection.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmdcccxcvi{When they see you they take you only in jest: ``Is this the one whom God has sent as messenger?\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmdcccxcvii{He would have surely turned us away from our gods if we had not adhered to them." They will know soon who is farther away from the path when they see the punishment!\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmdcccxcviii{Have you considered him who takes his own lust for his god? Can you stand a surety for him?\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmdcccxcix{Or do you think that most of them hear or understand? They are no better than cattle; in fact they are farther astray from the path.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmcm{Have you not seen how your Lord lengthens out the shadow? He could have kept it motionless if He liked. Yet We make the sun its pilot to show the way.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmcmi{Then We draw it back to Us, withdrawing it little by little.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmcmii{It is He who made the night a covering for you; and made sleep for rest, the day for rising.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmcmiii{It is He who sends the winds with auspicious news in advance of His benevolence; and We send pure water down from the sky\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmcmiv{To quicken a region that was dead, and to give it as drink to animals We have created and to men in plenty.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmcmv{And We distribute it among them in various ways that they may ponder and reflect; yet most men disdain everything but denial and thanklessness.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmcmvi{Had We pleased We could have raised a warner in every town.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmcmvii{So do not listen to unbelievers, and strive against them with greater effort.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmcmviii{It is He who made two bodies of water flow side by side, one fresh (and) sweet, the other brine (and) bitter, and has placed an interstice, a barrier between them.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmcmix{It is He who created man from water, then gave him consanguinity and affinity. Your Lord is omnipotent.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmcmx{And yet they worship besides God what cannot bring them gain or do them harm. The unbeliever has always been an auxiliary against his Lord.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmcmxi{Yet We have not sent you but to give good tidings and to warn.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmcmxii{Tell them: ``I do not ask any recompense of you for this other than (urging) whoever likes may take the way to his Lord."\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmcmxiii{Have trust in God the Living, who will never die, and sing His hallelujas; for He is well aware of the sins of His creatures.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmcmxiv{He created the heavens and the earth and all that lies between them in six spans then assumed His authority. He is the benevolent: Ask those who are well-informed.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmcmxv{When you say to them: ``Bow before Ar-Rahman," they say: ``What is Ar-Rahman? Should we adore whoever you ask us to?" And their aversion increases further.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmcmxvi{Blessed is He who placed in the heavens constellations of stars, and placed a burning lamp in it and the luminous moon.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmcmxvii{It is He who made the night and day an alternation for him who cares to reflect and be grateful.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmcmxviii{Devotees of Ar-Rahman are those who walk with humility on the earth, and when they are addressed by the ignorant, say: 'Peace;"\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmcmxix{And those who spend their nights bowed and standing before their Lord;\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmcmxx{Who say: ``O our Lord, avert from us the torment of Hell: Its punishment is surely continuous.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmcmxxi{It is indeed an evil halt and an evil abode;"\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmcmxxii{Who are neither prodigal nor miserly in their spending but follow a middle path;\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmcmxxiii{Who do not invoke any god apart from God, who do not take a life which God has forbidden except for a cause that is just, and do not fornicate -- and any one who does so will be punished for the crime,\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmcmxxiv{Whose punishment will be doubled on the Day of Judgement, and he will live for ever in disgrace,\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmcmxxv{Except those who repent and come to believe and do the right, for whom God will turn evil into goodness, for God is forgiving and kind.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmcmxxvi{Whosoever repents and does the right, will have turned back to God by way of repentance;\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmcmxxvii{And those who do not give false evidence, and if they come across unbecoming talk ignore it and pass by in a sedate way;\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmcmxxviii{Who, when reminded of their Lord's revelations, do not fall for them like the deaf and blind;\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmcmxxix{And those who say: ``O Lord, give us comfort in our spouses and children, and make us paragons of those who follow the straight path."\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmcmxxx{They will be rewarded for their perseverance with lofty mansions in empyrean where they will be received with greetings of peace and salutations,\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmcmxxxi{And abide there for ever: What an excellent destination and abode!\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmcmxxxii{Say: ``My Lord is not concerned on your account if you do not pray to Him. You have surely done with denying; soon will come the inevitable judgement.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmcmxxxiii{\basmalahen TA SIN MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmcmxxxiv{These are the verses of the perspicuous Book.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmcmxxxv{You may perhaps wear out your heart because they do not come to belief.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmcmxxxvi{We could send down from the heavens a sign to them if We pleased, before which their heads would remain bowed.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmcmxxxvii{Never does a new reminder come to them from Ar-Rahman but they turn away from it.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmcmxxxviii{Surely they have done with denying; soon will come to them the news of what they were laughing at.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmcmxxxix{Do they not see the earth, how We grow all kinds of noble things upon it?\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmcmxl{Verily there are signs in this; yet many of them do not believe.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmcmxli{Your Lord is surely mighty and merciful.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmcmxlii{When your Lord called upon Moses: ``Go to the wicked people,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmcmxliii{The people of Pharaoh. Will they not fear and take heed?"\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmcmxliv{: He said: ``O Lord, I fear that they will deny me.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmcmxlv{My heart is constrained, my tongue falters, so delegate Aaron;\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmcmxlvi{And they have a charge (of murder) against me. So I fear that they will kill me."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmcmxlvii{(It was) said: ``By no means. Go with My signs, both of you. I am verily with you and I hear.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmcmxlviii{Go to the Pharaoh and tell him: 'We bring a message from the Lord of all the worlds\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmcmxlix{That you should send the children of Israel with us.'\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmcml{(The Pharaoh) said: ``Did we not bring you up as a child? And you lived a number of years of your life with us.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmcmli{And you commited what you did, and you are ungrateful!"\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmcmlii{(Moses) replied: ``I did do that and I was in the wrong,\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmcmliii{So I ran away from you out of fear. But my Lord has given me wisdom, and made me an apostle.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmcmliv{But the favour you oblige me with is that you have enslaved the children of Israel."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmcmlv{The Pharaoh asked: ``And what is the Lord of all the worlds?"\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmcmlvi{(Moses) said: ``The Lord of the heavens and the earth and all that lies between them, if you can believe."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmcmlvii{(The Pharaoh) said to those around him: ``Do you hear?"\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmcmlviii{(Moses continued): ``Your Lord and the Lord of your fathers before you."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmcmlix{(The Pharaoh) said (to his nobles): ``Your apostle who has been sent to you, is certainly mad."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmcmlx{(Moses) said: ``The Lord of the East and the Lord of the West and all that lies between them, if you have sense."\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmcmlxi{(The Pharaoh) said: ``If you took another god apart from me I will have you incarcerated."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmcmlxii{(Moses) said: ``Even though I have brought to you something convincing?"\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmcmlxiii{(The Pharaoh) said: ``Then bring it, if you speak the truth."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmcmlxiv{So (Moses) cast his staff, and lo, it turned into a living serpent.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmcmlxv{And he drew forth his hand, and lo, it looked white to the beholders.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmcmlxvi{The Pharaoh said to the chiefs around him: ``He is certainly a clever magician.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmcmlxvii{He wants to drive you out of your land by his magic. So, what do you bid?"\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmcmlxviii{They said: ``Put him and his brother off awhile, and send summoners to the cities to gather\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmcmlxix{And bring the ablest magicians to you."\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmcmlxx{So the magicians were assembled at a stated time and place on an appointed day.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmcmlxxi{And the people were also asked to assemble.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmcmlxxii{(They said): ``We may haply follow the magicians if they are victorious."\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmcmlxxiii{When the magicians arrived, they said to the Pharaoh: ``Is there a reward for us if we are victorious?" --\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmcmlxxiv{``Yes," he replied. ``You 'will be among the honoured."\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmcmlxxv{Moses said to them: ``Cast what you have to cast."\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmcmlxxvi{So they cast their ropes and rods, and said: ``By the glory of Pharaoh, we shall be victorious."\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmcmlxxvii{Then Moses threw down his staff, and lo, it swallowed up their conjurations.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmcmlxxviii{Then the magicians fell prostrating in adoration,\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmcmlxxix{And said: ``We (affirm and) believe in the Lord of all the worlds,\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmcmlxxx{The Lord of Moses and Aaron."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmcmlxxxi{Said (the Pharaoh): ``You have come to believe in him before I gave you leave. He is surely your chief, who taught you magic. You will soon come to know: I will have your hands and feet cut off on alternate sides, and have every one of you crucified."\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmcmlxxxii{They said: ``There will be no harm. We shall return to our Lord.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmcmlxxxiii{We certainly hope our Lord will forgive our sins as we are the first to believe."\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmcmlxxxiv{We said to Moses: ``Travel by night with My creatures. You will surely be pursued."\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmcmlxxxv{Then the Pharaoh sent announcers to the cities,\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmcmlxxxvi{(Proclaiming): ``Surely they are a small band (of fugitives).\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmcmlxxxvii{They are always harassing us.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmcmlxxxviii{But we are a fully accounted army."\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmcmlxxxix{So We made them leave the gardens and springs of water,\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmcmxc{And treasures and agreeable mansions.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmcmxci{Thus it was; and We made the children of Israel possess them.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmcmxcii{But they pursued them at sunrise.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmcmxciii{When the two forces drew within seeing distance of each other, the people of Moses said: ``We shall certainly be overtaken."\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmcmxciv{Moses replied: ``By no means. My Lord is with me. He will show me the way."\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmcmxcv{We commanded Moses: ``Smite the sea with your staff." And it parted, and every parting was like a lofty mountain.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmcmxcvi{Then We brought the others to that place.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmcmxcvii{We delivered Moses and every one with him,\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmcmxcviii{And We drowned the others.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmcmxcix{Verily there is a sign in this, but most of them do not believe.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmm{Indeed your Lord is mighty and merciful.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmi{Relate the news of Abraham to them.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmii{When he asked his father and his people: ``What do you worship?"\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmiii{They replied: ``We worship idols and are devoted to them."\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmiv{(Abraham) asked: ``Do they hear when you call them?\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmv{Or do they benefit you, or do you harm?"\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmvi{They said: ``No. But we found our fathers doing so."\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmvii{He said: ``Have you considered what you have been worshipping,\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmviii{You and your fathers?\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmix{Yet they are my enemies except the Lord of all the worlds\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmx{Who created me and showed me the way,\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmxi{Who gives me food and drink,\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmmxii{And heals me when I am sick,\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmmxiii{Who will make me die, then give me life again,\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmmxiv{And who, I hope, will condone my faults on the Day of Judgement.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmmxv{O Lord, give me wisdom and admit me among the righteous,\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmmxvi{And uphold my name with posterity,\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmmxvii{And put me among the inheritors of Paradise.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmmxviii{Forgive me and my father: He was surely among those who went astray.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmmxix{And do not disgrace me on the day when they are raised from the graves,\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmmxx{The day when neither wealth nor children will be of any avail\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmmxxi{But to him who comes to God with a tranquil heart."\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmmxxii{Paradise will be brought near those who take heed for themselves and follow the straight path;\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmmxxiii{And Hell made visible to those who had gone astray.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmmxxiv{They will be asked: ``Where are those you worshipped\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmmxxv{Other than God? Can they save you or even save themselves?"\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmmxxvi{They will then be thrown into Hell with those who had gone astray\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mmmxxvii{Together with the hordes of Iblis.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mmmxxviii{Disputing among themselves they will say:\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mmmxxix{``By God, we were plainly in error\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mmmxxx{In equating you with the Lord of all the worlds;\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mmmxxxi{No one but the sinners led us astray.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mmmxxxii{Now we have none to intercede for us,\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mmmxxxiii{Nor any sincere friend.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mmmxxxiv{If only we could return and be among the believers!"\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mmmxxxv{Verily there is a sign in this, but many of them do not believe.\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mmmxxxvi{Verily your Lord is mighty and merciful.\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mmmxxxvii{The people of Noah accused the apostles of lies.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mmmxxxviii{When their brother Noah said to them: ``Will you not take heed?\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mmmxxxix{I have been sent as a trusted messenger to you.\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mmmxl{So be fearful of God and listen to me.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mmmxli{I ask no recompense of you for it. My reward is due from none but the Lord of all the worlds.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mmmxlii{So fear God and follow me."\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mmmxliii{They said: ``Should we place our trust in you when only the condemned follow you?"\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mmmxliv{He said: ``It is not for me to know what they were doing.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@mmmxlv{It is for my Lord to bring them to book, if you can understand.\qt@no{(113)}}
\qt@newcmd\qurantrans@en@mmmxlvi{I am certainly not one to drive away the believers.\qt@no{(114)}}
\qt@newcmd\qurantrans@en@mmmxlvii{I am only a plain admonisher."\qt@no{(115)}}
\qt@newcmd\qurantrans@en@mmmxlviii{They said: ``If you do not desist, O Noah, you will be stoned to death."\qt@no{(116)}}
\qt@newcmd\qurantrans@en@mmmxlix{He prayed: ``O Lord, verily my people accuse me of lies.\qt@no{(117)}}
\qt@newcmd\qurantrans@en@mmml{So adjudge between me and them conclusively, and save me and the believers who are with me."\qt@no{(118)}}
\qt@newcmd\qurantrans@en@mmmli{So We delivered him and those with him in the loaded ark,\qt@no{(119)}}
\qt@newcmd\qurantrans@en@mmmlii{And drowned the rest of them.\qt@no{(120)}}
\qt@newcmd\qurantrans@en@mmmliii{Verily there is a sign in this, yet many of them do not believe.\qt@no{(121)}}
\qt@newcmd\qurantrans@en@mmmliv{But surely your Lord is mighty and merciful.\qt@no{(122)}}
\qt@newcmd\qurantrans@en@mmmlv{The people of 'Ad accused the messengers of lies.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@mmmlvi{When their brother Hud said to them: ``Will you not take heed?\qt@no{(124)}}
\qt@newcmd\qurantrans@en@mmmlvii{I have been sent as a trusted messenger to you.\qt@no{(125)}}
\qt@newcmd\qurantrans@en@mmmlviii{So fear God and listen to me.\qt@no{(126)}}
\qt@newcmd\qurantrans@en@mmmlix{I ask no recompense of you for it. My reward is due from none but the Lord of all the worlds.\qt@no{(127)}}
\qt@newcmd\qurantrans@en@mmmlx{You construct monuments on every hill in vain,\qt@no{(128)}}
\qt@newcmd\qurantrans@en@mmmlxi{Erect palaces (thinking) that you will live for ever,\qt@no{(129)}}
\qt@newcmd\qurantrans@en@mmmlxii{And whenever you apply force become tyrannical.\qt@no{(130)}}
\qt@newcmd\qurantrans@en@mmmlxiii{So be fearful of God and follow me.\qt@no{(131)}}
\qt@newcmd\qurantrans@en@mmmlxiv{Fear Him who has bestowed on you what you know,\qt@no{(132)}}
\qt@newcmd\qurantrans@en@mmmlxv{Gave you increase of cattle and sons,\qt@no{(133)}}
\qt@newcmd\qurantrans@en@mmmlxvi{And orchards and springs.\qt@no{(134)}}
\qt@newcmd\qurantrans@en@mmmlxvii{I fear the punishment of a terrible day for you.\qt@no{(135)}}
\qt@newcmd\qurantrans@en@mmmlxviii{They said: ``It is the same to us if you warn us or do not warn.\qt@no{(136)}}
\qt@newcmd\qurantrans@en@mmmlxix{This is just a habit of antiquated people.\qt@no{(137)}}
\qt@newcmd\qurantrans@en@mmmlxx{We are not going to be damned."\qt@no{(138)}}
\qt@newcmd\qurantrans@en@mmmlxxi{Then they accused him of lies; so We annihilated them. Verily there is a sign in this, but most of them do not believe.\qt@no{(139)}}
\qt@newcmd\qurantrans@en@mmmlxxii{Yet surely your Lord is mighty and merciful.\qt@no{(140)}}
\qt@newcmd\qurantrans@en@mmmlxxiii{The Thamud accused the messengers of lies.\qt@no{(141)}}
\qt@newcmd\qurantrans@en@mmmlxxiv{When their brother Saleh said to them: ``Will you not take heed?"\qt@no{(142)}}
\qt@newcmd\qurantrans@en@mmmlxxv{I have been sent as a trusted messenger to you.\qt@no{(143)}}
\qt@newcmd\qurantrans@en@mmmlxxvi{So fear God and follow me.\qt@no{(144)}}
\qt@newcmd\qurantrans@en@mmmlxxvii{I do not ask any recompense of you for this. My reward is due from none but the Lord of all the worlds.\qt@no{(145)}}
\qt@newcmd\qurantrans@en@mmmlxxviii{(Do you think) you will be left secure here\qt@no{(146)}}
\qt@newcmd\qurantrans@en@mmmlxxix{In these gardens and these springs,\qt@no{(147)}}
\qt@newcmd\qurantrans@en@mmmlxxx{The fields of corn and date-palm trees with soft and tender spathes,\qt@no{(148)}}
\qt@newcmd\qurantrans@en@mmmlxxxi{And dwellings hewed out of mountains ingeniously?\qt@no{(149)}}
\qt@newcmd\qurantrans@en@mmmlxxxii{So be mindful of God and listen to me.\qt@no{(150)}}
\qt@newcmd\qurantrans@en@mmmlxxxiii{Do not follow those who are extravagant,\qt@no{(151)}}
\qt@newcmd\qurantrans@en@mmmlxxxiv{Who corrupt the land and do not reform it."\qt@no{(152)}}
\qt@newcmd\qurantrans@en@mmmlxxxv{They said: ``Surely you are deluded.\qt@no{(153)}}
\qt@newcmd\qurantrans@en@mmmlxxxvi{You are nothing but a man like us. Bring us a token if you speak the truth."\qt@no{(154)}}
\qt@newcmd\qurantrans@en@mmmlxxxvii{(Saleh) said: ``Here is a she-camel. She has a right of drinking water, and you have a right of drinking it on appointed turns.\qt@no{(155)}}
\qt@newcmd\qurantrans@en@mmmlxxxviii{Do not treat her unkindly or the punishment of a grievous day will fall on you."\qt@no{(156)}}
\qt@newcmd\qurantrans@en@mmmlxxxix{But they hamstrung her; and on the morrow were repentant,\qt@no{(157)}}
\qt@newcmd\qurantrans@en@mmmxc{For they were seized by the torment. Verily there was a sign in this, but most of them did not believe.\qt@no{(158)}}
\qt@newcmd\qurantrans@en@mmmxci{Yet verily your Lord is mighty and merciful.\qt@no{(159)}}
\qt@newcmd\qurantrans@en@mmmxcii{The people of Lot accused the messengers of lies.\qt@no{(160)}}
\qt@newcmd\qurantrans@en@mmmxciii{When their brother Lot said to them: ``Will you not take heed?\qt@no{(161)}}
\qt@newcmd\qurantrans@en@mmmxciv{I have been sent as a trusted messenger to you.\qt@no{(162)}}
\qt@newcmd\qurantrans@en@mmmxcv{So fear God and listen to me.\qt@no{(163)}}
\qt@newcmd\qurantrans@en@mmmxcvi{I ask no recompense of you for this. My reward is due from none but the Lord of all the worlds.\qt@no{(164)}}
\qt@newcmd\qurantrans@en@mmmxcvii{Why do you go for males unlike all other creatures\qt@no{(165)}}
\qt@newcmd\qurantrans@en@mmmxcviii{Leaving the consorts your Lord has made for you? But you are a people who exceed the bounds."\qt@no{(166)}}
\qt@newcmd\qurantrans@en@mmmxcix{They said: ``If you do not desist, O Lot, you will be expelled (from the city)."\qt@no{(167)}}
\qt@newcmd\qurantrans@en@mmmc{(Lot) said: ``I am disgusted with your actions,"\qt@no{(168)}}
\qt@newcmd\qurantrans@en@mmmci{(And prayed:) ``O Lord, save me and my family from what they do."\qt@no{(169)}}
\qt@newcmd\qurantrans@en@mmmcii{So We saved him and his whole family\qt@no{(170)}}
\qt@newcmd\qurantrans@en@mmmciii{Except one old woman who remained behind.\qt@no{(171)}}
\qt@newcmd\qurantrans@en@mmmciv{Then We destroyed the rest of them,\qt@no{(172)}}
\qt@newcmd\qurantrans@en@mmmcv{And rained on them a shower (of Stones). How terrible was the rain (that fell) on those who had been warned!\qt@no{(173)}}
\qt@newcmd\qurantrans@en@mmmcvi{Verily in this was a sign, but most of them do not believe.\qt@no{(174)}}
\qt@newcmd\qurantrans@en@mmmcvii{Yet surely your Lord is mighty and powerful.\qt@no{(175)}}
\qt@newcmd\qurantrans@en@mmmcviii{The people of the Wood too called the messengers liars.\qt@no{(176)}}
\qt@newcmd\qurantrans@en@mmmcix{When Shu'aib said to them: ``Will you not take heed?\qt@no{(177)}}
\qt@newcmd\qurantrans@en@mmmcx{I have been sent as a trusted messenger to you.\qt@no{(178)}}
\qt@newcmd\qurantrans@en@mmmcxi{So fear God and follow me.\qt@no{(179)}}
\qt@newcmd\qurantrans@en@mmmcxii{I ask no recompense of you for this. My reward is due from none but the Lord of all the worlds.\qt@no{(180)}}
\qt@newcmd\qurantrans@en@mmmcxiii{Give full measure and do not cheat;\qt@no{(181)}}
\qt@newcmd\qurantrans@en@mmmcxiv{Weigh on an even balance.\qt@no{(182)}}
\qt@newcmd\qurantrans@en@mmmcxv{And do not withhold from people what belongs to them, and do not corrupt the land;\qt@no{(183)}}
\qt@newcmd\qurantrans@en@mmmcxvi{And fear Him who created you and all the earlier people."\qt@no{(184)}}
\qt@newcmd\qurantrans@en@mmmcxvii{They said: ``Surely you are deluded.\qt@no{(185)}}
\qt@newcmd\qurantrans@en@mmmcxviii{You are nothing but a man like us, and we think you are a liar.\qt@no{(186)}}
\qt@newcmd\qurantrans@en@mmmcxix{But in case you are speaking the truth, then make a segment of the sky to fall upon us."\qt@no{(187)}}
\qt@newcmd\qurantrans@en@mmmcxx{(Shu'aib) said: ``My Lord knows well what you are doing."\qt@no{(188)}}
\qt@newcmd\qurantrans@en@mmmcxxi{But they denied him, and We seized them with the torment of the Day of Shadowing (when the cloud had rained down fire). It was indeed the torment of a terrible day!\qt@no{(189)}}
\qt@newcmd\qurantrans@en@mmmcxxii{Verily in this was a sign, but most of them do not believe.\qt@no{(190)}}
\qt@newcmd\qurantrans@en@mmmcxxiii{Yet verily your Lord is mighty and merciful.\qt@no{(191)}}
\qt@newcmd\qurantrans@en@mmmcxxiv{And this (Qur'an) is a revelation from the Lord of all the worlds,\qt@no{(192)}}
\qt@newcmd\qurantrans@en@mmmcxxv{Which the trusted spirit descended with\qt@no{(193)}}
\qt@newcmd\qurantrans@en@mmmcxxvi{To (communicate) to your heart that you may be a warner\qt@no{(194)}}
\qt@newcmd\qurantrans@en@mmmcxxvii{In eloquent Arabic.\qt@no{(195)}}
\qt@newcmd\qurantrans@en@mmmcxxviii{This is (indicated) in the Books of earlier people.\qt@no{(196)}}
\qt@newcmd\qurantrans@en@mmmcxxix{Was it not a proof for them that the learned men of Israel knew about this?\qt@no{(197)}}
\qt@newcmd\qurantrans@en@mmmcxxx{Had We revealed it to a man of obscure tongue\qt@no{(198)}}
\qt@newcmd\qurantrans@en@mmmcxxxi{And he had recited it to them, and they had not believed (it would have been different).\qt@no{(199)}}
\qt@newcmd\qurantrans@en@mmmcxxxii{Thus do We cause (unbelief) to enter the hearts of sinners.\qt@no{(200)}}
\qt@newcmd\qurantrans@en@mmmcxxxiii{They will not believe it until they behold the painful punishment.\qt@no{(201)}}
\qt@newcmd\qurantrans@en@mmmcxxxiv{It will come upon them unawares, and they will not comprehend it.\qt@no{(202)}}
\qt@newcmd\qurantrans@en@mmmcxxxv{Then will they say: ``Can we be given respite?"\qt@no{(203)}}
\qt@newcmd\qurantrans@en@mmmcxxxvi{Do they wish Us then to hasten the punishment?\qt@no{(204)}}
\qt@newcmd\qurantrans@en@mmmcxxxvii{Just think: If We let them enjoy (the good things of life) for a few years more,\qt@no{(205)}}
\qt@newcmd\qurantrans@en@mmmcxxxviii{And then what they were promised comes upon them,\qt@no{(206)}}
\qt@newcmd\qurantrans@en@mmmcxxxix{Of what avail shall their enjoyment be to them?\qt@no{(207)}}
\qt@newcmd\qurantrans@en@mmmcxl{Never have We destroyed a habitation till We had sent admonishers to them\qt@no{(208)}}
\qt@newcmd\qurantrans@en@mmmcxli{To warn. For We are never unjust.\qt@no{(209)}}
\qt@newcmd\qurantrans@en@mmmcxlii{The devils did not bring it down:\qt@no{(210)}}
\qt@newcmd\qurantrans@en@mmmcxliii{They are not worthy of it, nor have they power.\qt@no{(211)}}
\qt@newcmd\qurantrans@en@mmmcxliv{They have been precluded from hearing it.\qt@no{(212)}}
\qt@newcmd\qurantrans@en@mmmcxlv{So call on no other god but God, lest you are condemned to torment;\qt@no{(213)}}
\qt@newcmd\qurantrans@en@mmmcxlvi{And warn your near relations,\qt@no{(214)}}
\qt@newcmd\qurantrans@en@mmmcxlvii{And take those believers under your wing who follow you.\qt@no{(215)}}
\qt@newcmd\qurantrans@en@mmmcxlviii{If they do not obey you, tell them: ``I am not responsible for what you do."\qt@no{(216)}}
\qt@newcmd\qurantrans@en@mmmcxlix{Have trust in the Mighty, the Merciful,\qt@no{(217)}}
\qt@newcmd\qurantrans@en@mmmcl{Who watches you when you get up,\qt@no{(218)}}
\qt@newcmd\qurantrans@en@mmmcli{And your movements among those who bow in homage to God.\qt@no{(219)}}
\qt@newcmd\qurantrans@en@mmmclii{He is all-hearing and all-knowing.\qt@no{(220)}}
\qt@newcmd\qurantrans@en@mmmcliii{Should I tell you on whom the devils descend?\qt@no{(221)}}
\qt@newcmd\qurantrans@en@mmmcliv{They come down to every mendacious sinner,\qt@no{(222)}}
\qt@newcmd\qurantrans@en@mmmclv{Who listens to you (for spreading rumours); but most of them are liars.\qt@no{(223)}}
\qt@newcmd\qurantrans@en@mmmclvi{As for the poets, only those who go astray follow them.\qt@no{(224)}}
\qt@newcmd\qurantrans@en@mmmclvii{Have you not seen that they wander distract in every valley,\qt@no{(225)}}
\qt@newcmd\qurantrans@en@mmmclviii{And they say what they do not do,\qt@no{(226)}}
\qt@newcmd\qurantrans@en@mmmclix{Except those who believe and do the right, and remember God a great deal, who retaliate only when they have been wronged. Yet the oppressors will now come to know through what reversals they will be overthrown!\qt@no{(227)}}
\qt@newcmd\qurantrans@en@mmmclx{\basmalahen TA SIN. THESE are the verses of the Qur'an, and collection of explicit laws,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmclxi{A guidance and good tidings for the believers,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmclxii{Who fulfil their devotional obligations, pay the zakat, and believe with certainty in the life to come.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmclxiii{We make their deeds attractive to those who do not believe in the Hereafter, so that they may wander in perplexity.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmclxiv{They are those who will suffer the worst chastisement in this life, and will be the greatest losers in the life to come.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmclxv{You have been conveyed the Qur'an from One all-wise and all-knowing.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmclxvi{(Remember) when Moses said to his family: ``I see a fire. I shall bring you news from it, or bring an ember that you may warm yourselves."\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmclxvii{But when he reached it, a voice called out: ``Blessed is He who is in the fire and all around it. Praised be God, the Lord of all the worlds.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmclxviii{O Moses, I am that God, the mighty and all-wise.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmclxix{Throw down your staff." When he saw it wriggling like a serpent he turned his back and fled without turning (to look). ``O Moses," (said the voice), ``be not fearful. Surely those sent as messengers do not fear in My presence,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmclxx{Except those who do some wrong but afterwards do good to make up for the wrong. And I am forgiving and merciful.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmclxxi{Put your hand in the bosom of your shirt; it will come out white without any blemish. This will be one of nine tokens for the Pharaoh and his people, who are a wicked lot indeed."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmclxxii{And when Our signs came as distinct proofs, they said: ``This is only magic."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmclxxiii{And they denied them out of malice and pride, though in their hearts they believed that they were true. So see how was the end of evil-doers!\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmclxxiv{We gave David and Solomon knowledge; and they said: ``All praise be to God who has favoured us over many of His creatures who believe."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmclxxv{Solomon was heir to David, and he said: ``O people, we have been taught the language of Tair, and have been given of everything. This is a clear favour indeed."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmclxxvi{His armies of jinns and men and Tair assembled, formed into ranks, (and marched)\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmclxxvii{Till they reached the Valley of Naml. Said the lady of Naml: ``O Naml, go into your dwellings lest Solomon and his hordes should crush you unawares."\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmclxxviii{(Solomon) smiled, amused at her speech, and said: ``O Lord grant me that I should be grateful for the favours You have bestowed on me and my parents, and do good things of Your pleasing; and admit me among Your righteous devotees by Your grace."\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmclxxix{When he reviewed the Tair, he said: ``How is it I do not see Hud-hud? Is he absent?\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmclxxx{I will punish him severely, or cut his throat, unless he bring a valid excuse."\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmclxxxi{But he was not long in coming, and reported: ``I have been around where you have not been. I come from Saba with positive news.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmclxxxii{I found a woman reigning over them, and she has been favoured with everything; and she has a throne that is magnificent.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmclxxxiii{I found that she and her people worship the sun in place of God, for Satan has made their deeds look attractive to them and has turned them away from the Path, so they do not find the way\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmclxxxiv{To worship God who brings to light what is hidden in the heavens and the earth, and is cognisant of what you hide and what you disclose.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmclxxxv{God: There is no god but He, the Lord of the glorious throne."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmclxxxvi{(Solomon) said: 'We shall see if you speak the truth or you are a liar.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmclxxxvii{Take this letter from me, and deliver it to them and withdraw, then see what reply they give in return."\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmclxxxviii{(The Queen said): ``O nobles, a venerable letter has been delivered to me.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmclxxxix{It is from Solomon, and (says): 'In the name of Allah, Ar-Rahman, Ar-Rahim.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmcxc{Do not rise against me, but come to me in submission.'\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmcxci{." Advise me, O nobles," she said ``in this matter. I do not decide any thing until you concur."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmcxcii{They said: ``We are men of valour, and brave fighters. It is for you to decide. So consider what you should command."\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmcxciii{She said: ``Surely when kings enter a city they destroy it and despoil the honour of its nobility. So will they do (to us).\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmcxciv{But I will send them a gift and see what the envoys bring back (in return)."\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmcxcv{So, when the envoys came to Solomon he said: ``Do you wish to increase my wealth? Yet what God has given me is better than what He has given you. No. Be gratified in your present.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmcxcvi{Go back to them. We shall soon come with our armies which they will not be able to face. We shall drive them out of (the land) with ignominy, and they will be humbled."\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmcxcvii{He (then) said (to his courtiers): ``O you nobles, is there any one who can bring me her throne before they come to me in submission?"\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmcxcviii{A crafty jinn said: ``I will bring it before you rise from your seat, for I am strong and trustworthy."\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmcxcix{But one who had knowledge of the letter, said: ``I will bring it to you in the twinkling of an eye." When Solomon saw it before him, (he said): ``This is by the grace of my Lord that He may test me whether I am grateful or I am thankless. Yet if one is grateful, he is grateful for himself, and if one is thankless, then surely my Lord is unconcerned and magnanimous."\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmcc{(Turning to his nobles) he said: ``Change the appearance of her throne. Let us see if she is rightly guided, or is not guided at all."\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmcci{When she arrived, they asked her: ``Is your throne like this?" She said: ``As though this is it. We had come to have knowledge and already submitted."\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmccii{She was (in fact) turned away by what she worshipped other than God, for she came of an unbelieving people.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmcciii{She was invited to enter the court. When she saw it, she took it for a sheet of water, and (pulling up her skirts) uncovered her legs. (Solomon) told her: ``This is paved with tiles of glass." ``O Lord," she said, ``I have wronged myself, and I submit to the Lord of all the worlds with Solomon."\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmcciv{We sent to Thamud their brother Saleh (who said): ``Worship God." But they were divided into two groups disputing with one another.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmccv{(Saleh) said: ``O people, why do you wish to hasten evil rather than good? Why not ask for God's forgiveness? You may well be forgiven."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmccvi{They said: ``You betoken evil, and those with you." (Saleh) replied: ``The evil you presage can only come from God. In reality you are a people under trial (for your own inauspiciousness)."\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmccvii{There were in that city nine persons who spread disorder in the land, and did not reform.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmccviii{They said: ``Let us swear by God that we will attack Saleh and his family at night, and later tell his heirs: 'We did not see his family destroyed, and we speak the truth.'"\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmccix{They hatched up the plot; We also planned without their knowledge.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmccx{Now see the end of their machinations: We destroyed them and their entire people.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmccxi{So these their habitations lie deserted now because of their iniquities. Verily there is a sign in this for those who understand.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmccxii{We deliver those who believe and take heed for themselves.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmccxiii{(Remember) Lot, when he said to his people: ``Why do you indulge in obscenities when you know (it is evil)?\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmccxiv{You lust after men in place of women. You are indeed a stolid people."\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmccxv{His people had no answer except saying: ``Expel the family of Lot from your city. They are a people who would (rather) be pure!"\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmccxvi{So We saved him and his family except his wife who was destined to stay behind.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmccxvii{And We rained down on them a shower (of stones). How ruinous was the rain that fell on those who had been warned (but warned in vain)!\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmccxviii{Say: ``All praise be to God, and peace on those of His creatures whom He has chosen." Is God better or those they associate with Him --\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmccxix{Who created the heavens and the earth, who sends down water from the sky for you, with which He causes graceful gardens to grow? It was not in your power to make trees germinate. Is there any other god along with God. In fact they are a people who turn away (from the truth).\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmccxx{Who then made the earth a habitable place, and made the rivers (flow) in its valleys and dales, and placed upon it firm stabilisers, and kept a barrier between two bodies of water? Is there any other god along with God? In reality most of them do not know.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmccxxi{Who hears the cry of the anguished (soul) when it calls to Him, and relieves its suffering? And who made you trustees on the earth? Is there any other god along with God? How little it is that you reflect!\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmccxxii{Who then really shows you the way in the darkness of the desert and the sea? And who sends breezes bringing news of His benevolence? Is there any other god along with God? He is far too exalted for what they associate with Him!\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmccxxiii{Who creates first then reverts it? And who gives you provision from the heavens and the earth? Is there any other god along with God? Tell them: ``Bring your proof, if you are truthful."\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmccxxiv{Say: ``No one in the heavens and the earth has knowledge of the unknown except God, nor can they know when they will be raised again.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmccxxv{Still less do they comprehend the life to come. In fact they are in doubt about it. Still more, they are blind to it."\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmccxxvi{Those who do not believe, say: ``When we and our fathers have turned to dust, how shall we be raised again?\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmccxxvii{Indeed we and our fathers had been promised this before. It is nothing but the earlier people's lore."\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmccxxviii{Say: ``Travel in the land and see how (bad) was the end of sinners."\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmccxxix{Do not grieve over them, and do not be distressed by what they contrive.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmccxxx{Yet they say: ``When will this promise come to pass? (Tell Us) if you speak the truth."\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmccxxxi{Say: ``Perhaps some of what you wish to hasten is right behind you."\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmccxxxii{Verily your Lord is gracious to men, though most men are ungrateful.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmccxxxiii{Verily your Lord knows what lies hidden in their breasts and what they disclose.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmccxxxiv{There is nothing of the hidden in the heavens and the earth that is not recorded in the luminous Book.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmccxxxv{Indeed this Qur'an explains to the children of Israel much of what they are at variance.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmccxxxvi{It is a guidance and grace for those who believe.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmccxxxvii{Surely your Lord in His wisdom will decide between them. He is all-mighty and all-knowing.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmccxxxviii{So you place your trust in God. Certainly you stand on positive truth.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmmccxxxix{You cannot make the dead to listen, or the deaf to hear the call, when they have turned their backs,\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmmccxl{Nor can you lead the blind when they have gone astray. You can make none hear except those who believe in Our signs and have come to peace and submission.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmmccxli{When the sentence will have been passed against them, We shall bring forth beastly brutes from the earth who will torment them, for men certainly do not believe Our signs.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmmccxlii{The day We shall gather from every community a section of those who denied Our signs, and they will be brought (in separate groups),\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmmccxliii{So that when they come (before the Lord) He will say: ``Did you deny My signs without having understood them? Or what was it that you were doing?"\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmmccxliv{When the sentence will have been passed upon them for their wickedness, they will not be able to say a word.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmmccxlv{Do they not see that We made the night for them to rest, the day to make things clear? Indeed there are signs in this for people who believe.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmmccxlvi{The day the trumpet blast is sounded whoever is in the heavens and the earth will be terrified, save those whom God please, and all will appear before Him in abjectness.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmmccxlvii{You will see the mountains and think they are firmly planted, but they will pass away like flying clouds: Artistry of God who perfected everything. He is indeed fully aware of what you do.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmmccxlviii{Whoever comes with good (deeds) will receive better than (what he had done), and be safe that day from terror.\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmmccxlix{But whosoever comes with evil will be flung face forward into the Fire. Can you expect reward for any thing but what you do?\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmmccl{(Say): ``I am commanded to worship the Lord of this land He has blessed, to whom all things belong; and I am commanded to be one of those who submit,\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmmccli{And to recite the Qur'an." Whoever comes to guidance does so for himself; as for him who stays astray, tell him: ``I am only a warner."\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmmcclii{Say: ``All praise be to God. He will show you His signs, and you will recognise them. Your Lord is not heedless of what you do."\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmmccliii{\basmalahen TA SIN MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmccliv{These are the verses of the illuminating Book.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmcclv{We narrate to you from the history of Moses and Pharaoh in all verity, for those who believe.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmcclvi{The Pharaoh had become high and mighty in the land, and divided the people into different classes, and impoverished one class, slaying its males and sparing its women, for he was indeed a tyrant.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmcclvii{We wished to favour those who were weak in the land and make them leaders and heirs,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmcclviii{And establish them in the country; and to make the Pharaoh, Haman and their hordes beware of what they feared from them.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmcclix{So We conveyed to the mother of Moses: ``Suckle him. If you are afraid for him, cast him in the river without any fear or regret, for We shall restore him to you, and make him an apostle."\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmcclx{Then he was picked up by the family of Pharaoh (unaware) that he would become their enemy and a cause for regret. Surely the Pharaoh, Haman and their hordes were habitual sinners.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmcclxi{The Pharaoh's wife said: ``He will be a comfort to me and to you. Do not kill him. He may well be of some advantage to us, or we may adopt him as a son." They were not aware (of what the future held in store).\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmcclxii{The mother of Moses was perturbed in the morning. Had We not strengthened her heart to remain a believer she had almost given him away.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmcclxiii{She told his sister: ``Follow him." So she kept an eye on him from a distance, unbeknown to them.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmcclxiv{We made (Moses) refuse a wet nurse. So his sister said: ``Should I tell you of a household that could bring him up for you and take care of him?"\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmcclxv{Thus We restored him to his mother that she may be tranquil and not grieve, and know that the promise of God is true, though most men do not know.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmcclxvi{When he had grown up to full maturity, We gave him wisdom and knowledge. Thus do We recompense the doers of good.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmcclxvii{He came to the city when the people were in a care-free mood, and saw two men quarrelling, one belonging to his community, the other to his enemies. The man who belonged to his community appealed for help against the one who belonged to the enemies. Moses struck him a blow with his fist and finished him off. ``This is of Satan's doing," he said. ``He is certainly an enemy and a corrupter."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmcclxviii{``O Lord," he prayed, ``I have done wrong, forgive me." And God forgave him. Verily He is forgiving and kind.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmcclxix{(Moses) said: ``O Lord, as You have been gracious to me I will never aid the guilty."\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmcclxx{In the morning he came to the city, fearful and hesitant. Just then he who had asked him for help the day before called out for help (again). ``You are indeed a meddlesome fellow," Moses said to him.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmcclxxi{Then as he was about to lay hands on the one who was their common enemy, he cried out: ``O Moses, do you want to kill me as you killed that person yesterday? You only want to be a tyrant in the land and no peacemaker."\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmcclxxii{There came a man running from the other part of the city. ``O Moses," he said, ``the chiefs are deliberating to kill you. Go away from the city. I wish you well."\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmcclxxiii{So he left the city, fearful and hesitant, (and) prayed: ``O Lord, deliver me from these wicked people."\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmcclxxiv{Then as he turned his face to Midian, he said: ``Maybe my Lord will show me the right way."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmcclxxv{And when he came to the waters of Midian he found a crowd of people watering (their flocks), and saw two maidens holding back (their cattle). He asked: ``What is the trouble with you?" They said: ``We cannot water our flock till the shepherds have driven away theirs, and our father is a very old man."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmcclxxvi{So he watered (their flock), and moved into the shade and prayed: ``My Lord, I have need of whatever good you send me."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmcclxxvii{Then one of the (maidens) came to him walking bashfully, (and) said: ``My father invites you that he may repay you for having watered our flock." So, when (Moses) came to him and told him his story, he said: ``Have no fear. You have escaped from the wicked people."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmcclxxviii{Said one of the maidens: ``O father, employ him. Surely the best (man) to employ is one who is strong and honest."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmcclxxix{He said: ``I would like to marry one of these two daughters of mine to you if you agree to work for me on hire for eight years. And if you stay on for ten, it is up to you. I do not wish to impose any hardship on you. God willing you will find me a man of honour."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmcclxxx{(Moses) said: ``This is (agreed) between you and me. Whichever term I fulfil, no injustice will be done to me. God is witness to our agreement."\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmcclxxxi{When Moses had fulfilled the term and was journeying with his family, he noticed a fire on the side of the mountain. ``Wait here," he said to his family; ``I have seen a fire. I may haply bring some news from there, or an ember that you may warm yourselves."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmcclxxxii{When he drew near, a voice called out to him from the tree on the blessed spot on the right side of the valley: ``O Moses, I am verily God, the Lord of all the worlds.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmcclxxxiii{Throw down your staff." When he saw it wriggling like a serpent, he turned about and fled without turning. ``O Moses, approach," (said the Voice), ``and have no fear. You will be safe.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmcclxxxiv{Put your hand inside your shirt. It will come out white without a tarnish of blame; and do not be perturbed or afraid. These are two proofs from your Lord for the Pharaoh and his nobles. They are certainly a rebellious people."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmcclxxxv{He said: ``O Lord, I have killed a man of theirs, and fear they would kill me.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmcclxxxvi{So send my brother Aaron with me as helper for he is more fluent than I with words, that he should affirm me, for I fear that they would call me a liar."\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmcclxxxvii{(And) God said: ``We shall strengthen your arm with your brother, and give you power with Our signs and give you authority, so that they will not be able to harm you. Both of you and your followers will be victorious."\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmcclxxxviii{But when Moses came to them with Our clear signs they said: ``This is nothing but magic he has contrived, for we have not heard of this from our fathers of old."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmcclxxxix{But Moses said: ``My Lord knows well who has come with guidance from Him, and for whom is the guerdon of Paradise. But surely the wicked will not prosper."\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmccxc{The Pharaoh said: ``O nobles, I am not aware of any other lord of yours but myself. So, O Haman, fire some clay (bricks) to build a tower for me that I may mount up (and see) the God of Moses; for I think he is a liar."\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmccxci{He and his soldiers had become arrogant in the land for no reason, and did not think that they have to come back to Us in the end.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmccxcii{So We seized him and his hordes and threw them into the sea. Behold then how was the end of the wicked!\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmccxciii{We made them the leaders of those who call to Hell; and on the Day of Judgement they will not be helped.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmccxciv{A curse lies upon them in this world, and on the Day of Resurrection they will be despised.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmccxcv{After We had destroyed the earlier generations We gave Moses the Book as evidence for mankind, and a guidance and grace, so that they may remember.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmccxcvi{You were not there on the western side (of Mount Sinai) when We gave the commandments to Moses, nor were you witness (to the event).\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmccxcvii{We raised (many more) generations and prolonged their lives. You did not live with the people of Midian, nor recited to them Our revelations; but We kept on sending messengers.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmccxcviii{You were not present on the side of Mount Sinai when We called. And all this (knowledge that you are given) is by the grace of your Lord so that you may warn a people to whom no admonisher had come before you, that they may take heed;\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmccxcix{And in case disaster comes upon them for what they have done themselves, they should say: ``O Lord, why did You not send an apostle to us that we should have followed Your commands, and been with those who are believers;"\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmccc{But when the truth came to them from Us, they said: ``Why is he not given the like of what was given to Moses?" Did they not disbelieve before in what was given to Moses? They said: ``Both are imposters one like the other," and added: ``We do not believe in either."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmccci{Say: ``Then bring a Book from God which gives better guidance than these so that I may follow it, if you speak the truth."\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmcccii{Then, if they cannot give you an answer, know that they are only following their lusts. And who can be farther astray than he who follows his lust without any guidance from God? And certainly God does not guide an unjust people.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmccciii{We have been sending word to them that they may take a warning.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmccciv{Those to whom We gave the Book before this do believe in it;\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmcccv{And when it is read out to them, say: ``We believe in it. It's the truth from our Lord. We had committed ourselves before it came."\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmcccvi{These will be given their recompense twice, for they persevered and repelled evil with good, and spent of what We had given them.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmcccvii{When they hear idle talk they turn aside and say: ``To us our actions, to you yours. Peace on you; we do not look for the ignorant."\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmcccviii{You cannot guide any one you like: God guides whosoever He please. He knows best who will come to guidance.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmcccix{They say: ``If we followed your guidance we would be driven from the land by force." Have We not set up a sanctuary for them, to which is brought a wealth of everything as provision from Us? But most of them do not understand.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmcccx{How many habitations that had come to boast of their resources have We destroyed? These their dwellings were never inhabited except rarely after them; and they came back to Us.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmcccxi{But your Lord does not destroy habitations without having sent an apostle to their metropolis to read out Our commandments to them. We would never have destroyed cities if their inhabitants were not given to wickedness.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmcccxii{Whatsoever has been given you is the stuff this life is made of, and only its embellishment. What is with your Lord is better and abiding. Will you not understand?\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmcccxiii{Can one who was given a better promise, which he will find come true, be like him who was given a little enjoyment of this life, but who will afterwards be brought (to judgement) on the Day of Resurrection?\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmcccxiv{That day God will call them and ask: ``Where are they you imagined were My compeers?"\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmcccxv{Those against whom the sentence is justified will say: ``O Lord, these are those we had led astray as we had ourselves gone astray. We clear ourselves before You: They never worshipped us."\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmcccxvi{(The sinners) will be told: ``Invoke your partners." They will call on them, but they will not answer; and they will see the torment (and wish) if only they had come to guidance.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmcccxvii{(God) will ask them on that day: ``What answer did you give the apostles?"\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmcccxviii{Then all news will be blacked out for them, and they will not even ask one another.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmcccxix{But he who repents and believes and does good things may well be among the successful.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmcccxx{Your Lord creates what He wills and chooses. The good is not for them to choose. Too holy and high is God for what they associate with Him.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmcccxxi{Your Lord well knows what they hide in their breasts and what they disclose.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmcccxxii{He is God. There is no god but He. His alone is praise first and last, and His the judgement, and to Him will you be brought back in the end.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmcccxxiii{Say: ``Just think, if God were to cover you up with night for ever until the Day of Doom, what other god apart from God will give you light? Why do you not pay heed?"\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmcccxxiv{Say: ``Just think. If God were to make the day perpetual till the Day of Resurrection, what other god but God would bring you night for rest? Why do you not reflect?\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmcccxxv{Yet in His benevolence He made you night and day that you may rest and seek His bounty during them, and haply maybe grateful."\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmcccxxvi{Upon a day He will call them and ask: ``Where are they you imagined were My compeers?"\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmcccxxvii{And We shall single out one witness from each community and say: ``Bring your proof." Then will they know that God's is the judgement, and what they contrived will avail them not in the least.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmcccxxviii{Verily Qarun was of Moses' people, but he began to oppress them. We had given him treasures, so many that a team of wrestlers could hardly lift their keys. His people said to him: ``Do not be exultant. God does not like those who exult.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmcccxxix{So seek the abode of the Hereafter through what God has given you, and do not forget your part in this world. Do good to others as God has done good to you, and do not try to spread corruption in the land. Surely God does not like corrupters."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmcccxxx{He said: ``This has come to me through my own acumen." Did he not know that God had destroyed many generations before him who possessed far more acumen than he, and more wealth? The sinners will not be asked about their sins.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmcccxxxi{Then he came before his people in all pomp; and those enamoured of this world, said: ``Ah would that we had what Qarun has been given! He indeed possesses great good fortune."\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmmcccxxxii{But those who knew better, said: ``Alack-a-day! God's guerdon is better for those who believe and do the right. Only those who persevere will receive it."\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmmcccxxxiii{So We opened up the earth and sunk him and his mansion. There was not a body that could help him against (the will) of God, nor was he able to save himself.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmmcccxxxiv{Those who were envious of his position only yesterday said on the morrow: ``Indeed God increases the fortunes of those of His creatures as He will, and decreases. Had God not been gracious to us He could have (opened up) the earth and made it swallow us. Surely the infidels will not succeed."\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmmcccxxxv{We shall give the mansion of the Hereafter to those who do not want to be haughty in the land and spread corruption. The future belongs to those who take heed for themselves and follow the straight path.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmmcccxxxvi{Whoever does good will receive better than what he has done; and whoever does ill shall be requited but to the extent of what he does.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmmcccxxxvii{He who has assigned (the propagation) of the Qur'an to you will bring you back to the destination. Say: ``My Lord knows who has come to guidance, and who is clearly in error."\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmmcccxxxviii{You did not expect that the Book would be given to you except by the favour of your Lord. So do not be the helper of unbelievers,\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmmcccxxxix{Nor should you let them turn you away from the commandments of God once they have been delivered to you; and call them to your Lord, and do not be an idolater,\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmmcccxl{And do not call on any other god apart from God. There is no god but He. All things will perish save His magnificence. His is the judgement, and to Him will you be brought back in the end.\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmmcccxli{\basmalahen ALIF LAM MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmcccxlii{Do men think they will get away by saying: ``We believe," and will not be tried?\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmcccxliii{We had tried those who were before them so that God knew who spoke the truth, and who were liars.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmcccxliv{Do those who do evil think that they will get the better of Us? How bad is the judgement that they make!\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmcccxlv{He who hopes to meet God (should know) that God's appointed time will surely come. He is all-hearing and all-knowing.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmcccxlvi{He who strives does so for himself. Verily God is independent of the creatures of the world.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmcccxlvii{We shall pardon the sinful deeds of those who believe and do the right, and give them a reward better than their deeds.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmcccxlviii{We have enjoined on man to be good to his parents; but if they try to make you associate with Me that of which you have no knowledge, then do not obey them. You have to come back to Us, when I will tell you what you used to do.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmcccxlix{We shall admit those who believe and do the right among the righteous.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmcccl{There are among men those who say: ``We believe in God;" yet if they happen to suffer in the cause of God they take oppression by men as punishment from God. And if help comes to them from your Lord, they say: ``We were with you." Does not God know what is hidden in the hearts of men?\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmcccli{God will surely know the believers and know the hypocrites.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmccclii{Those who deny say to those who affirm: ``Follow our way; we shall carry the burden of your sins." But they cannot carry the burden of their sins in the least. They are liars indeed.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmcccliii{They will carry their own loads and other loads besides their own; and will surely be questioned on the Day of Resurrection about what they contrived.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmcccliv{We sent Noah to his people, and he lived with them a thousand years minus fifty. Then they were caught by the deluge for they were evil.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmccclv{But We saved him and those with him in the ark, and made it a sign for the creatures of the world.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmccclvi{And (remember) Abraham who said to his people: ``Worship God and be obedient to Him. This is better for you if you understand.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmccclvii{You worship idols in place of God and invent lies. Surely those you worship other than God have no power over your means of livelihood. So seek your sustenance from God, and worship Him and give Him thanks. To Him will you be brought back in the end.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmccclviii{But if you deny, then many a people have denied before you. The duty of the apostle is to convey the message clearly."\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmccclix{Do they not see how God originates creation, then reverts it back? This is indeed how inevitably the law of God works;\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmccclx{Say: ``Travel on the earth and see how He originated creation. Then (you will know) how God will raise the last raising (of the dead). Surely God has power over everything,\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmccclxi{Punish whom He will, and have mercy on whom He please. And to Him will you be brought back in the end.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmccclxii{Escape Him you cannot either in the earth or in the sky; and you have no friend or helper apart from God.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmccclxiii{Those who deny the signs of God and the meeting with Him, cannot have hope of My mercy. There is a painful punishment for them.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmccclxiv{The people (of Abraham) had no answer except: ``Kill him or burn him;" but God saved him from the fire. There are lessons in this for those who believe.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmccclxv{He said: ``You have taken to idols through mutual affection in this life, in place of God, but on the Day of Resurrection you will disown and curse each other, and your abode will be Hell, and you will have none to help you."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmccclxvi{Then Lot believed in him; and (Abraham) said: ``I will separate myself and take refuge in my Lord. Surely He is all-mighty and all-wise."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmccclxvii{So We bestowed on him Isaac and Jacob and gave his progeny prophethood and scripture, and rewarded him in this world, and in the next he will be among the upright.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmccclxviii{And (remember) Lot when he said to his people: ``You indulge in lecherous acts which none of the creatures had done before you.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmccclxix{You commit unnatural acts with men and cut off the way (of procreation), and commit obscenities in your gatherings." The only answer his people made was: ``Bring the punishment of God, if you are truthful."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmccclxx{``O Lord, help me against the wicked people,"(Lot) prayed.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmccclxxi{When Our messengers came to Abraham with good news, they said: ``We have to destroy this city as its inhabitants have become sinful."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmccclxxii{He said: ``Surely Lot is there." They answered: ``We know who is there. We are to save him and his family except his wife, for she is one of those who will stay behind."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmccclxxiii{So, when Our messengers came to Lot, he was worried on their account as he was unable to protect them. They said: ``Have no fear or regret. We will certainly save you and your family except your wife, for she is one of those who will stay behind.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmccclxxiv{We have to bring a scourge from the heavens on the people of this city as they are depraved."\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmccclxxv{Verily We have left a clear sign of this for people of sense to see.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmccclxxvi{To Midian We sent their brother Shu'aib. He said: ``O people, worship God and be ready for the Day of Resurrection. Do no evil, and create no mischief in the land."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmccclxxvii{But they denied him and were seized by an earthquake, and lay overturned in their homes in the morning.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmccclxxviii{And (remember) 'Ad and Thamud. It will be clear to you from their habitations (how they were destroyed), for Satan had made their deeds look attractive to them, and turned them away from the path; and yet they were a people of acumen.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmccclxxix{(Remember) Qarun, Pharaoh and Haman to whom Moses came with clear signs; but they were haughty (and oppressed) the land. Yet they could not run away from Us;\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmccclxxx{And We seized all of them for their crimes. Against some We sent a violent wind hurling stones, and some We seized with a mighty blast, and some We submerged under the earth, and some We drowned. It was not for God to wrong them, they wronged themselves.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmccclxxxi{The semblance of those who take protectors besides God is that of the spider. She arranges a house for herself, but the flimsiest of houses is the spider's. If only they had sense!\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmccclxxxii{Verily God knows what they invoke in His place, for He is all-mighty and all-wise.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmccclxxxiii{These are precepts of wisdom We offer to men, but only those who are rational understand.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmccclxxxiv{God has created the heavens and the earth with reason. Surely in this is a sign for those who believe.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmccclxxxv{Recite what has been revealed to you of this Book, and be constant in devotion. Surely prayer keeps you away from the obscene and detestable, but the remembrance of God is greater far; and God knows what you do.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmccclxxxvi{Do not argue with the people of the Book unless in a fair way, apart from those who act wrongly, and say to them: ``We believe what has been sent down to us, and we believe what has been sent down to you. Our God and your God is one, and to Him we submit."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmccclxxxvii{That is how We have revealed this Book to you and those to whom We have sent down the Book will believe in it. Only those who are infidels will deny it.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmccclxxxviii{You did not read any Scripture before this, nor wrote one with your right hand, or else these dissemblers would have found a cause to doubt it.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmccclxxxix{In fact, in the minds of those who have intelligence these are clear signs. No one denies Our revelations except those who are unjust.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmcccxc{For they say: ``How Is it no signs were sent down to him from his Lord?" Say: ``The signs are with God. I am only a warner, plain and simple."\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmcccxci{Is it not sufficient for them that We have revealed the Book to you which is read out to them? It is indeed a grace and reminder for people who believe.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmcccxcii{Say: ``God is sufficient as witness between me and you." He knows what is in the heavens and the earth. It is those who believe in falsehood and disbelieve in God who will perish.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmcccxciii{They want you to hasten the punishment: But for a time already determined the punishment would have come upon them. It will come upon them all too suddenly, and they will be caught unawares.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmcccxciv{They want you to hasten the punishment: Hell will indeed surround the unbelievers.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmcccxcv{The day the punishment comes upon them from above and underneath their feet, (God will) say: ``And now taste of what you had done."\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmcccxcvi{O My creatures who believe, surely My earth has plenty of scope and so worship only Me.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmcccxcvii{Every soul has to know the taste of death. You will then be sent back to Us.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmcccxcviii{We shall admit those who believe and do the right to empyreal gardens with rivers rippling by, where they will abide for ever. How excellent the guerdon of those who toil,\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmcccxcix{Who persevere and place their trust in their Lord.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmcd{How many living things there are on the earth that do not Store their food; God provides them as well as you. He is all-hearing and all-knowing.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmcdi{If you ask them: ``Who created the heavens and the earth, and who set the sun and the moon to work?" They will answer: ``God." Why then do they vacillate?\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmcdii{God increases the means of those of His creatures as He please, or limits them for whomsoever He will. He is certainly cognisant of everything.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmcdiii{If you ask them: ``Who sends down rain from the sky and quickens the earth when it is dead?" They will answer: ``God." Say: ``All praise be to God." But most of them do not understand.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmcdiv{The life of this world is only a sport and play. It is surely the home of the Hereafter that will indeed be life extended and new, if only they knew!\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmcdv{When they board a ship they call on God, placing their faith wholly in Him. But when He brings them safely back to shore, they begin to associate others with Him,\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmcdvi{And deny what We had given them, in order to go on enjoying themselves. They will come to know soon.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmcdvii{Do they not see that We have given them a safe sanctuary, while all around them men are being despoiled? Do they then believe what is false, and deny the bounty of God?\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmcdviii{Who is more unjust than he who fabricates a lie about God, or denies the truth when it has come to him? Is there not an abode for unbelievers in Hell?\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmcdix{We shall guide those who strive in Our cause to the paths leading straight to Us. Surely God is with those who do good.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmcdx{\basmalahen ALIF LAM MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmcdxi{The Romans have been conquered\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmcdxii{In the neighbouring land. But having been conquered they will conquer\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmcdxiii{In a few years (less than ten). God's is the imperative first and last. On that day the believers will rejoice\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmcdxiv{In the help of God. He helps whom He will; He is all-mighty, ever-merciful.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmcdxv{It is a promise of God; and God does not go back on His promise. Yet most men do not understand:\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmcdxvi{They only know the palpable life of this world, and are oblivious of the Hereafter.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmcdxvii{Do they not think for themselves that God did not create the heavens and the earth and all that lies between them without reason and a determined purpose? But many men reject the meeting with their Lord.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmcdxviii{Have they not travelled on the earth and seen how the others before them had met their end? They were far more powerful than them, furrowed the earth and colonised it far more than they; and their apostles came to them with visible signs. It was surely not for God to wrong them, they wronged themselves.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmcdxix{Therefore evil was the end of those who did evil, for they denied the signs of God and made fun of them.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmcdxx{God originates creation, and then will revert it, then you will go back to Him.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmcdxxi{The day the Resurrection comes the sinners will be overwhelmed with despair.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmcdxxii{No intercessor will they have among those they associated (with God), and will reject their partners.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmcdxxiii{The day the Hour comes they will be separated into categories.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmcdxxiv{Those who believed and did the right will be feasted in a rich, well-watered meadow.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmcdxxv{Those who did not believe and rejected Our signs and the meeting in the Hereafter, will be given over to punishment.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmcdxxvi{So extol God when the evening comes and the day dawns,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmcdxxvii{For His is the praise in the heavens and the earth, -- and at nightfall and the time of noon.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmcdxxviii{He brings the living from the dead, the dead from the living, and quickens the earth after it had died. So will you be brought forth (from the dead).\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmcdxxix{Among His signs is that He created you from the earth, and you are now human beings dispersed everywhere.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmcdxxx{Another of His signs is that He created mates of your own kind of yourselves so that you may get peace of mind from them, and has put love and compassion between you. Verily there are signs in this for those who reflect.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmcdxxxi{Among other signs of His is the creation of the heavens and the earth, and the variety of your tongues and complexions. Surely there are signs in this for those who understand.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmcdxxxii{Another of His signs is the night, a time for you to sleep, and the day to seek His bounty. Verily there are signs in this for those who pay heed.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmcdxxxiii{Another of His signs is the lightning He shows to fill you both with dread and hope, and the water He sends down from the sky which reawakens the earth that was dead. There are indeed signs in this for those who have sense.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmcdxxxiv{Another of His signs is that the heavens and the earth stay in position by His command; and then when He will call you once you will come out of the earth.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmcdxxxv{All those who are in the heavens and the earth are His, and they are all obedient to Him.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmcdxxxvi{It is He who first creates and then reverts it. This is how His law works inevitably. His semblance is of the most sublime in the heavens and the earth. He is all-mighty and all-wise.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmcdxxxvii{He gives you an example from your own life: Do you possess among your dependants any partners in what We have bestowed on you, so that you and they have equal (share) in it, and that you fear them as you fear each other? That is how We explain Our signs clearly for those who comprehend.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmcdxxxviii{And yet the wicked follow their own lusts without understanding. Who can show the way to those whom God allows to go astray? None will they have to help them.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmcdxxxix{So keep yourself exclusively on the true way, the creational law of God according to which He created man with the quality of choosing right or wrong. There is no altering of God's creation. This is the supreme law. But most men do not understand.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmcdxl{Turn towards Him and be dutiful to Him; be firm in devotion, and do not become an idolater,\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmcdxli{(Or) one of those who created rifts in their order and are divided into sects, with each group exulting in what it has (carved out for itself) --\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmcdxlii{When misfortune befalls men they pray to their Lord and turn to Him; but afterwards when He has given them a taste of His benevolence a section of them begins to ascribe compeers to their Lord\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmcdxliii{So as to deny what We have given them. Please yourselves for a time; you will come to know soon.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmcdxliv{Have We sent down a charter to them which mentions what they associate with Him?\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmcdxlv{When We give men a taste of Our benevolence they start rejoicing in it. When misfortune befalls them as a result of what they have done themselves, they begin to despair.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmcdxlvi{Do they not see God increases or decreases the means of whosoever He please? Verily there are signs in this for those who believe.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmcdxlvii{So, give their share to the relatives, the needy, and the wayfarers. This is best for those who seek the way that leads to God, and they will be successful.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmcdxlviii{What you give on interest to increase (your capital) through others' wealth, does not find increase with God; yet what you give (in alms and charity) with a pure heart, seeking the way of God, will be doubled.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmcdxlix{It is God who created you, then gave you sustenance, then He will make you die, and bring you back to life. Is there one among those you associate with Him who can do the least of these things? Too high and exalted is He for what they associate with Him!\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmcdl{Corruption has spread over land and sea from what men have done themselves that they may taste a little of what they have done: They may haply come back (to the right path).\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmcdli{Say: ``Travel on the earth and see how came the end of those before you." Most of them were idolaters.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmcdlii{So set your face towards the straight path before the day arrives from God which is irreversible. Men will be segregated on that day.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmcdliii{So that he who disbelieves will bear the consequence of his unbelief; and he who does the right will straighten out the way for himself,\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmcdliv{So that God may reward those who believed and did what was good, by His grace. Surely He does not love unbelievers.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmcdlv{Among His signs are the breezes He sends as harbingers of happy news, so that He may allow you to taste of His mercy, and that ships may sail by His command, and you may seek of His bounty, and may haply be grateful.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmcdlvi{Verily We sent many apostles before you to their people, who brought clear signs with them. Then We retributed those who were sinful. It is a duty incumbent on Us to help the believers.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmcdlvii{It is God who sends the breezes that raise clouds, then spreads them over the sky as He please, fold on fold, then you see the drops of rain issue from between them. When He sends it down to those of His creatures as He will, they are filled with joy,\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmcdlviii{Although before it came down they were despondent.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmcdlix{So consider the signs of His benevolence: How He quickens the earth after it had become waste. He is verily the one who will raise the dead. He has power over everything.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmcdlx{If We send a (blighting) wind and they see (the earth) seared autumnal, they would surely become ungrateful.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmcdlxi{You cannot make the dead to listen nor the deaf hear the call when they have turned back and retreated,\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmcdlxii{Nor can you make the blind see the way when they have gone astray. You can make none hear except those who believe Our signs and have come to submission.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmcdlxiii{It is God who created you of weakness, then after weakness gave you strength, then after strength will give you weakness and grey hair. Surely He makes whatever He wills. He is all-knowing and all-powerful.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmcdlxiv{The day Resurrection is set the sinners will swear: ``We did not tarry more than an hour (and cannot be guilty)." That is how they have always been deceived.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmcdlxv{But those who were given the knowledge and belief will say: ``You have tarried, according to the Book of God, as long as the Day of Resurrection, and this is the Day of Resurrection, but 'you do not know."\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmcdlxvi{Their excuses will be of no avail to the sinners on that day, and they will not be allowed to beg for favour.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmcdlxvii{We have offered every kind of example here in this Qur'an to men. Even then if you bring a verse to them, those who disbelieve say: ``You are nothing but a liar."\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmcdlxviii{That is how God seals the hearts of those who do not know.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmcdlxix{So have patience. The promise of God is surely true; and let not those who do not believe make you relax (your endeavours).\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmcdlxx{\basmalahen ALIF LAM MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmcdlxxi{These are the verses of the sagacious Book,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmcdlxxii{And a guidance and grace for those who do good,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmcdlxxiii{Who are constant in devotion, pay the zakat, and are certain of the Hereafter.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmcdlxxiv{They are on guidance from their Lord, and will prosper.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmcdlxxv{But among men are also those who spread frivolous stories to mislead (others) from the way of God, without any knowledge, and take it lightly. For such as these the nemesis will be shameful.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmcdlxxvi{When Our verses are recited before them they turn away haughtily as though they did not hear them, as if a deafness had come into their ears. So give them tidings of a shameful punishment.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmcdlxxvii{Surely for those who believe and do the right are pleasure gardens.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmcdlxxviii{They will abide in them for ever. The promise of God is true; and He is all-mighty and all-wise.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmcdlxxix{He created the skies without a support, as you can see, and placed stabilisers in the earth that you may dwell at ease as it revolves; and dispersed on it all varieties of creatures, and He sent down water from the skies and grew all kinds of splendid things upon it.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmcdlxxx{Such is God's creation. Show me now what those (they worship) beside Him have created. Surely the evil-doers are in clear error.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmcdlxxxi{We bestowed wisdom on Luqman that he may be grateful to God. Whosoever is grateful is so for his own good, and whoever is ungrateful (should remember) that God is above all concern, worthy of praise.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmcdlxxxii{(Remember) when Luqman counselled his son: ``O son, do not associate any one with God. To associate others with God is a grievous wrong."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{We have committed man about his parents. His mother carries him in her womb in weakness and debility, weaning him in two years. So he should be grateful to Me and his parents. To Me is the journeying back.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{If they try to force you to associate with Me that of which you have no knowledge, do not obey them. Live with them honourably in the world, but follow the way of him who turns to Me. Your returning is to Me in the end, when I will tell you what you did.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmcdlxxxv{``O my son, whatsoever it may be, even though equal to a mustard seed in weight, or within a rock or in the sky or in the earth, God will bring it forth. Verily God is perceptive, all-aware.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{O my son, fulfil your moral obligations, bid what is known to be right and forbid what is wrong, and bear with patience what befalls you. These are indeed acts of courage and resolve.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{Do not hold men in contempt, and do not walk with hauteur on the earth. Verily God does not like the proud and boastful.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{Be moderate in your bearing, and keep your voice low. Surely the most repulsive voice is the donkey's."\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmcdlxxxix{Have you not seen that God has subjugated what is in the heavens and the earth to you, and bestowed His favours, external and esoteric, in abundance on you? And yet there are men who contend about God without any knowledge or guidance or the Book enlightening.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmcdxc{When you ask them to follow what God has revealed, they say: ``No. We shall follow what we found our ancestors following," even though the devil were calling them to the torment of Hell!\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmcdxci{He who turns his face to God in submission and does good, holds fast to a handle that is strong; for the resultance of things rests with God.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmcdxcii{So do not let the unbelief of disbelievers grieve you. They will be brought back to Us, when We shall tell them what they used to do. Whatever is in their hearts is known to God.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmcdxciii{We let them enjoy themselves only for a while, then We shall drag them to a severe punishment.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmcdxciv{If you ask them: ``Who created the heavens and the earth?" They will surely answer: ``God." Say: ``All praise be to God." But most of them do not understand.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmcdxcv{To God belongs what is in the heavens and the earth. Verily He is all-sufficient, worthy of praise.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmcdxcvi{If all the trees of the earth were pens and the oceans ink, with many more oceans for replenishing them, the colloquy of God would never come to end. He is indeed all-mighty and all-wise.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmcdxcvii{Your creation and resurrection is but like that of a single cell. Verily He is all-hearing and all-seeing.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmcdxcviii{Do you not see that God makes the night succeed the day, the day succeed the night? And He has harnessed the sun and the moon so that each runs its appointed course. Surely God is aware of all you do.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmcdxcix{That is so for God is the Reality, and what they invoke other than Him is illusion. Indeed God is all-high and supreme.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmd{Do you not see that the ships sail in the ocean by the grace of God, that He may show you some of His glories. Verily there are signs in this for those who are constant and give thanks.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmdi{When the waves overshadow them like a canopy, they pray to God with all-exclusive faith in Him. But after He has safely brought them to the shore, there are some who vacillate between doubt and belief, but no one rejects Our signs except those who are perverse and disbelieve.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmdii{O people, fear your Lord and dread the day when no father will avail a son, nor son his father. Truly the promise of God is true. Do not be deluded by the life of this world, and do not let the deceiver draw you away from God.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmdiii{Only God has the knowledge of the Hour. He sends rain from the heavens, and knows what is in the mothers' wombs. No one knows what he will do on the morrow; no one knows in what land he will die. Surely God knows and is cognisant.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmdiv{\basmalahen ALIF LAM MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmdv{The revelation of this Book free of doubt and involution is from the Lord of all the worlds.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmdvi{Or do they say he has fabricated it? In fact, it is the truth from your Lord so that you may warn the people to whom no admonisher was sent before you. They may haply come to guidance.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmdvii{It is God who created the heavens and the earth and all that lies between them, in six spans, then assumed all authority. You have no protector other than Him, nor any intercessor. Will you not be warned even then?\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmdviii{He regulates all affairs from high to low, then they rise to perfection step by step in a (heavenly) day whose measure is a thousand years of your reckoning.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmdix{Such is (He) the knower of the unknown and the known, the mighty and the merciful,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmdx{Who made all things He created excellent; and first fashioned man from clay,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmdxi{Then made his offspring from the extract of base fluid,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmdxii{Then proportioned and breathed into him of His spirit, and gave you the senses of hearing, sight and feeling. And yet how little are the thanks you offer!\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmdxiii{But they say: ``When we have mingled with the earth, shall we be created anew?" In fact they deny the meeting with their Lord.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmdxiv{Say: ``The angel of death appointed over you will take away your soul, then you will be sent back to your Lord."\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmdxv{If only you could see when the sinners will stand before their Lord, heads hung low, (and say:) ``O Lord, we have seen and heard. So send us back. We shall do the right, for we have come to believe with certainty."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmdxvi{Had We intended We could have given every soul its guidance; but inevitable is My word that I will fill up Hell with men and jinns together.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmdxvii{So now suffer. As you forgot the meeting of this your Day of Doom, so have We forgotten you. Now taste the everlasting punishment for your deeds.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmdxviii{Only they believe in Our revelations who, when they are reminded, bow in adoration, and give praise to their Lord, and do not become arrogant.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmdxix{Their backs do not rest on their beds, and they pray to their Lord in fear and hope, and spend of what We have given them (in charity).\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmdxx{No soul knows what peace and joy lie hidden from them as reward for what they have done.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmdxxi{Is one who is a believer like one who is a transgressor? No, they are not alike.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmdxxii{As for those who believe and do the right, there are gardens for abode as welcome for what they had done.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmdxxiii{As for those who disobey, their abode is Hell. Whensoever they wish to escape from it they would be dragged back into it, and told: ``Taste the torment of the Fire which you used to call a lie."\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmdxxiv{But We shall make them taste the affliction of this world before the greater torment, so that they may retract.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmdxxv{Who is more wicked than he who is reminded of his Lord's revelations yet turns away from them; We will surely requite the sinners.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmdxxvi{Verily We gave Moses the Book; so be not in doubt about his having received it; and We made it a guidance for the children of Israel.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmdxxvii{When they persevered and firmly believed Our revelations We appointed learned men among them who guided them by Our command.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmdxxviii{Surely your Lord will decide between them about what they were at variance, on the Day of Resurrection.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmdxxix{Did they not find guidance in the many generations We had destroyed before them, over whose dwellings they (now) walk? There were indeed signs in this. Will they even then not listen?\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmdxxx{Do they not see that We drive the rain towards a land that is dry, then grow grain from it which their cattle and they themselves eat? Will they not see even then?\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmdxxxi{Yet they say: ``When will this decree come, if you speak the truth?"\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmdxxxii{Say: ``Of no use will be the acceptance of belief to unbelievers on the Day of Decision, nor will they be granted respite.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmdxxxiii{Therefore turn away from them and wait as they are waiting.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmdxxxiv{\basmalahen O PROPHET FEAR God and do not follow the unbelievers and the hypocrites.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmdxxxv{Follow what is revealed to you by your Lord. Verily God is all-knowing and all-wise.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmdxxxvi{Trust in God. God is sufficient as guardian.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmdxxxvii{God has not provided two hearts in the breast of a man, nor made your wives, whom you pronounce ``mothers" (in order to divorce them), your real mothers, nor has He made your adopted sons your real sons. This is only what your lips pronounce. God says what is just, and shows the right way.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmdxxxviii{Call them by the names of their fathers. This is the right course in the sight of God. If you do not know their fathers, they are then your brothers in religion and your friends. It will not be a sin if you make a mistake, unless you do so intentionally; for God is forgiving and kind.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmdxxxix{The Prophet is closer to the faithful than they are themselves; and his wives are as their mothers. Yet blood relations are closer to one another according to God's decree, more than (other) believers and the emigrants (who left their homes in the cause of God), but you should be kind to your friends. This is inscribed in the Book (of decrees).\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmdxl{When We made the covenant with the prophets, and with you, as with Noah and Abraham, Moses and Jesus son of Mary, a binding covenant,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmdxli{(It was) so that God may ask the truthful of their sincerity. As for the infidels, He has prepared a painful punishment for them.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmdxlii{O you who believe, remember the favours of God to you when an army came against you and We sent a wind against them and forces that you did not see. But God sees all that you do.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmdxliii{When they came upon you from above and below you, when the eyes were stupefied with horror, and hearts jumped to the throats, and you made wild suppositions about God.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmdxliv{The faithful were sorely tried there and were shaken completely,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmdxlv{When the hypocrites and those who were filled with doubt, said: ``The promise of God and His Apostle was nothing but deceit."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmdxlvi{When a section of them said: ``O people of Yathrib, there is no place for you here, turn back;" and a section of them asked leave of the Prophet, saying: ``Our homes lie exposed," -- while they were not exposed. Their only intention was to run away.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmdxlvii{If the (enemy) had entered the city from every side and asked them to rise in revolt, they would have done so, and not hesitated but a little;\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmdxlviii{Whereas earlier they had made a promise to God that they would never turn their backs; and a promise made to God is answerable.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmdxlix{Say: ``Of no gain will be your running away if you run from death or being killed, even then you will enjoy the good things of life but only for a while."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmdl{Say: ``Who will save you from God if He decide to afflict you or show you His mercy?" They will never find a friend or helper apart from God.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmdli{Surely God knows who among you obstruct, and those who say to their brethren: ``Come to us," and go to battle but seldom,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmdlii{Being chary of helping you. But when danger appears you will find them looking at you with eyes turning like a man's in the swoon of death. Yet when the danger is past they lash you with sharp tongues, covetous of the best (of booty). Such as these have not come to belief. So God nullifies whatever they have done. This is how (the innate law of) God works inevitably.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmdliii{They think the allied tribes have not withdrawn; and if the allied tribes had advanced they would have wished that they were rather with the Arabs of the desert asking news of you; and had they been among you they would have fought but just a little.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmdliv{You have indeed a noble paradigm in the Apostle of God for him who fears God and the Day of Resurrection, and remembers God frequently.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmdlv{When the faithful saw (the armies of) the allied tribes, they said: ``This is what God and His Apostle had promised us; and God and His Apostle say the truth;" and this enhanced their faith and obedience.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmdlvi{There are men among the faithful who have been true to the covenant they had made with God; and some of them fulfilled their vows (by dying in His cause), and some still wait (prepared for death), and stand firm,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmdlvii{That God may recompense the truthful for their truthfulness, and punish the hypocrites or relent towards them, as He will. God is surely forgiving and kind.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmdlviii{God drove the unbelievers back in their fury, and they gained no advantage. God was sufficient (to help) the believers in the battle. God is all-powerful and all-mighty.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmdlix{He made those of the people of the Book who had helped (the tribes) descend from their forts, and filled their hearts with dread, so that you killed some and made many captive;\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmdlx{And He made you inherit their lands and mansions and wealth, and a country you had not traversed before, for God has power over everything.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmdlxi{O Prophet, say to your wives: ``In case you desire the life and pomp of this world, come, I will provide you handsomely, and let you go with a grace.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmdlxii{But if you desire God, His Apostle, and the joys of life to come, then God has verily set apart for those of you who are good, a great reward."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmdlxiii{O wives of the Prophet, whosoever of you commits an act of clear shamelessness, her punishment will be doubled. This is how (the innate law of) God works inevitably.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmdlxiv{But whoever of you is obedient to God and His Apostle, and does the right, will be given a two-fold reward by Us; and We have a rich provision in readiness for her.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmdlxv{O wives of the Prophet, you are not like other women. If you are mindful of God, do not be too obliging in your speech, lest some one sick of heart should covet your person; so say only customary things.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmdlxvi{Stay at home, and do not deck yourselves with ostentation as in the days of paganism; fulfil your devotional obligations, pay the zakat, and obey God and His Apostle. God desires to remove impurities from you, O inmates of this house, and to cleanse and bring out the best in you.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmdlxvii{Remember God's revelations and the wisdom that are recited in your homes. God is indeed all perceiving, well-informed.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmdlxviii{Verily men and women who have come to submission, men and women who are believers, men and women who are devout, truthful men and truthful women, men and women with endurance, men and women who are modest, men and women who give alms, men and women who observe fasting, men and women who guard their private parts, and those men and women who remember God a great deal, for them God has forgiveness and a great reward.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmdlxix{No believing men and women have any choice in a matter after God and His Apostle have decided it. Whoever disobeys God and His Apostle has clearly lost the way and gone astray.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmdlxx{When you said to him who had been favoured by God and was favoured by you: ``Keep your wife to yourself and fear God," you were hiding something God was about to bring to light, for you had fear of men, though you should fear God more. And when Zaid was through with her, We gave her to you in marriage, so that it may not remain a sin for the faithful (to marry) the wives of their adopted sons when they are through with them. God's command is to be fulfilled.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmdlxxi{There is no constraint on the Prophet in what God has decreed for him. This has been the way of God with (apostles) who have gone before you, and God's command is a determined act.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmdlxxii{(For) those who convey the messages of God, and fear Him and no one else, God is sufficient to keep account.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmdlxxiii{Muhammad is not the father of any man among you, but a messenger of God, and the seal of the prophets. God has knowledge of everything.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmdlxxiv{O you who believe, remember God a great deal,\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmdlxxv{And sing His praises morning and evening.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmdlxxvi{It is He who sends His blessings on you, as (do) His angels, that He may lead you out of darkness into light, for He is benevolent to the believers.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmdlxxvii{Their greeting on the day they meet Him will be: ``Peace;" and He has a generous reward ready for them.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmdlxxviii{O Prophet, We have sent you as a witness and a bearer of happy tidings and an admonisher,\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmdlxxix{And to call (men) to God by His leave, and as a lamp resplendent.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmdlxxx{Give glad tidings to the believers that there is great bounty for them from God.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmdlxxxi{Do not listen to the unbelievers and the hypocrites. Ignore what they do to hurt you, and put your trust in God. God is sufficient as protector.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmdlxxxii{O you who believe, when you marry believing women then divorce them before having (sexual) contact with them, you have no right to demand observance of the 'waiting period' of them. But provide suitably for them, and let them go with honour.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmdlxxxiii{We have made lawful for you, O Prophet, wives to whom you have given their dower, and God-given maids and captives you have married, and the daughters of your father's brothers and daughters of your father's sisters, and daughters of your mother's brothers and sisters, who migrated with you; and a believing woman who offers herself to the Prophet if the Prophet desires to marry her. This is a privilege only for you and not the other believers. We know what We have ordained for them about their wives and maids they possess, so that you may be free of blame, for God is forgiving and kind.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmdlxxxiv{You may defer the turn of any of your wives you like, and may take any other you desire. There is no harm if you take any of those (whose turn) you had deferred. This would be better as it would gladden their hearts and they will not grieve, and each will be happy with what you have given her. God knows what is in your heart, for He is all-wise and benign.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmdlxxxv{No other women are lawful for you after this except those you have married, nor to change your present wives for other women even though their beauty should appeal to you. God is watchful of everything.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmdlxxxvi{O you who believe, do not enter the houses of the Prophet for a meal without awaiting the proper time, unless asked, and enter when you are invited, and depart when you have eaten, and do not stay on talking. This puts the Prophet to inconvenience, and he feels embarrassed before you; but God is not embarrassed in (saying) the truth. And when you ask his wife for some thing of utility, ask for it from behind the screen. This is for the purity of your hearts and theirs. It does not behove you to annoy the prophet of God, or to ever marry his wives after him. This would indeed be serious in the sight of God.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmdlxxxvii{Whether you discuss a thing or conceal it, surely God has knowledge of everything.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmdlxxxviii{There is no harm if they come before their fathers or their sons, or their brothers and their brothers' and sisters' sons, or their women folk or captive maids they possess. Follow the commands of God. Verily God is witness to everything.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmdlxxxix{God and His angels shower their blessings on the Prophet. O believers, you should also send your blessings on him, and salute him with a worthy greeting.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmdxc{Those who offend God and His Prophet will be damned in this world and the next. There is a shameful punishment ready for them.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmdxci{Those who slander believing men and women for what they have not done, will bear the burden of calumny and clear iniquity.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmdxcii{O Prophet, tell your wives and daughters, and the women of the faithful, to draw their wraps a little over them. They will thus be recognised and no harm will come to them. God is forgiving and kind.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmdxciii{If the hypocrites and perverts, and the rumour-mongers of Madinah, do not desist even now, We shall rouse you against them, so they would not be able to live but a short time in the city with you.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmdxciv{Accursed, they would be seized wherever found, and slain mercilessly.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmdxcv{Such was the law of God among those before you; and you will not find any change in the law of God.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmdxcvi{People ask you about the Hour (of the great change). Say: ``Only God has knowledge of it. Who knows? The Hour may be close at hand."\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmdxcvii{Verily God has cursed the infidels, and prepared a blazing fire for them.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmdxcviii{They will live in it for ever, and will find no saviour or helper.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmdxcix{The day their faces would be turned on the fire (as on a spit), they will say: ``Alas! If only we had obeyed God, and obeyed the Prophet."\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmdc{They will say: ``O our Lord, we obeyed our leaders and the elders, but they only led us astray.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmdci{O Lord, give them a double punishment, and put a grievous curse upon them."\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmdcii{O you who believe, do not be like those who maligned Moses, whilst God cleared him of what they alleged; and he was held in high esteem with God.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmdciii{O you who believe, obey the commands of God, and say straightforward things\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmdciv{That He may straighten your affairs for you and forgive your sins; and he who obeys God and His Prophet will be successful.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmdcv{We had offered the Trust (of divine responsibilities) to the heavens, the earth, the mountains, but they refrained from bearing the burden and were frightened of it; but man took it on himself. He is a faithless ignoramus.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmdcvi{So that God punishes men and women hypocrites, the idolaters and idolatrous women, but He turns to faithful men and women in forgiveness, for God is forgiving and kind.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmdcvii{\basmalahen ALL PRAISE BE to God to whom belongs whatsoever is in the heavens and the earth, and His the praise in the world to come. He is all-wise and all-knowing.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmdcviii{He knows whatever goes into the earth and whatsoever issues from it, whatsoever comes down from the sky, and whatsoever goes up to it. He is all-merciful, all-forgiving.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmdcix{The unbelievers say: ``There is no coming of the Hour for us." Say: ``Why not? By my Lord, the knower of the unknown, it will certainly come for you. Not even an atom's weight in the heavens and the earth, or something smaller or greater than it, is hidden from Him, and which is not recorded in the all-too-manifest Book,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmdcx{In order that He may recompense those who have believed and done the right. For them will be forgiveness and worthy sustenance.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmdcxi{As for those who try to subvert Our signs, there is a punishment of painful torment.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmdcxii{Those who have been given knowledge realise what has been revealed by the Lord is the truth, and leads to the path of the mighty and praiseworthy (God).\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmdcxiii{The disbelievers say: ``Shall we tell you of a man who prophesies that when you are reduced to particles and vanished in the dust, you will become a new creation\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmdcxiv{Has he fabricated a lie about God, or is he possessed?" Not so; but those who believe not in the Hereafter are themselves afflicted and far astray.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmdcxv{Do they not see what is before them and what is behind them of the heavens and the earth? We could cleave the earth and sink them, if We pleased, or drop a fragment of the sky upon them. There is surely a sign in this for every penitent creature.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmdcxvi{We favoured David with excellence, (and commanded): ``O Jibal and Tair, glorify the greatness of God with him." And We made iron pliable for him.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmdcxvii{``Make long coats of mail," (We said), ``and fix their links, and do the right. I surely see whatsoever you do."\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmdcxviii{We (subjugated) the wind to Solomon. Its morning's journey took one month, and the evening's one month. We made a spring of molten brass to flow for him; and many jinns laboured for him by the will of his Lord. Anyone of them who turned from Our command was made to taste the torment of blazing fire.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmdcxix{They made for him whatever he wished, synagogues and statues, dishes large as water-troughs, and cauldrons firmly fixed (on ovens; and We said): ``O House of David, act, and give thanks." But few among My creatures are thankful.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmdcxx{When We ordained (Solomon's) death, none but the weevil, that was eating away his staff (on which he rested), pointed out to them that he was dead. When he fell down (dead) the jinns realised that if they had knowledge of the Unknown they would never have suffered demeaning labour.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmdcxxi{There was a sign for the people of Saba in their habitations: Two gardens, on the right and left. (And they were told:) ``Eat of what your Lord has given you and be thankful. Fair is your land, and forgiving your Lord."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmdcxxii{But they turned away. So We let loose on them the inundation of (the dyke of) al-'Arim, replacing their gardens with two other gardens which bore only bitter gourd, and tamarisks and a few sparse lote-trees.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmdcxxiii{That is how We requited them for their ingratitude. We only punish those who are ungrateful.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmdcxxiv{Between them and the cities We had blessed We placed towns along the highway, and made them stages on their journey, (saying): ``Travel between them in safety by day or by night."\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmdcxxv{But they said: ``O Lord, make the distance between the stages of our journeys longer;" but (by doing so) they wronged themselves. So We turned them into bygone tales, and dispersed them, scattered in all directions. Surely there are signs in this for those who endeavour and are grateful.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmdcxxvi{Thus Iblis found his supposition about them to be true; and except for a section of believers they follow him.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmdcxxvii{He had no authority over them save for the purpose of Our knowing who believed in the world to come, and who doubted it. For your Lord keeps a watch over everything.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmdcxxviii{Say: ``Call on those you imagine are gods apart from God. They are not masters even of an atom's weight in the heavens and the earth, nor do they have a share in them, nor is any one of them a helper (of God).\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmdcxxix{No intercession avails with Him except his He allows, so that when their hearts are freed of fear, they ask (one another): ``What did your Lord say?" They will answer: ``What is expedient. He is the all-mighty and supreme."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmdcxxx{Say: ``Who gives you food from the heavens and the earth?" Say: ``God. Surely either you or we are on guidance, or are lost in clear error."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmdcxxxi{Say: ``You will not be questioned about the sins that we have committed, nor shall we be questioned about your deeds."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmdcxxxii{Say: ``Our Lord will gather us together and judge between us equitably, for He is the Judge all-knowing."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmdcxxxiii{Say: ``Just show me those you associate with Him as compeers." No, (you cannot), for He is God, the all-mighty and all-wise."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmdcxxxiv{We have sent you only as a bearer of good tidings and admonisher for all mankind; yet most people do not understand.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmdcxxxv{Instead they say: ``When is this promise going to be, if you speak the truth?"\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmdcxxxvi{Say: ``Determined is the day of the promise, which you can neither put back nor advance an hour.''\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmdcxxxvii{The unbelievers say: ``We do not believe in this Qur'an, nor in what was (sent) before it." If only you could see the sinners when they are made to stand before their Lord, blaming one another! Those who were weak will say to those who were arrogant: ``But for you we would have certainly been believers."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmdcxxxviii{The arrogant will say to the weak: ``Did we hold you back from guidance after it had come to you? Certainly not. In fact you were yourselves guilty."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmdcxxxix{But the weak will say to the arrogant: ``Not in the least. It was your plotting night and day when you ordered us to disbelieve in God and associate compeers with Him." When they see the punishment they will express repentance. But We shall put iron collars round the necks of infidels. Will they be requited for anything but what they did?\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmdcxl{We never sent an admonisher to a habitation but its well-to-do people said: ``We do not believe in what you have brought."\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmdcxli{And (further): ``We have far more wealth and children (than you), and we are not the ones to be punished."\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmdcxlii{Say: ``Verily my Lord increases or restricts the provision of whosoever He will;" but most men do not understand.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmdcxliii{It is not your wealth and children that will bring you closer to Us, except those who believe and do the right. These will be given a two-fold reward for their deeds, and will dwell in peace in the high empyrean.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmdcxliv{But those who try to subvert Our signs will be given over to punishment\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmdcxlv{Say: ``Verily my Lord increases or restricts the provision of any of His creatures as He will, and repays whatsoever you spend. He is the best of all providers."\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmdcxlvi{The day He will gather all of them together, He will ask the angels: ``Did they worship you?"\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmdcxlvii{``God forbid!" (they will answer). ``You are our protector not they. In fact, they worshipped the devils. Most of them believed in them."\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmdcxlviii{That day you will have no power to profit or harm each other; and We shall say to the sinners: ``Taste the punishment of Fire which you had denied."\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmdcxlix{When Our clear revelations are read out to them, they say: ``This is only a man who wants to turn you away from what your fathers used to worship." And they say: ``This is nothing but a fabricated lie." And those who do not believe say of the truth when it has reached them: ``This is nothing but pure sorcery."\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmdcl{We did not give them any scripture to study, nor sent any warner before you.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmdcli{Those before them had also denied, and they could not reach a tenth of (the possibilities) We had given them, and still they called My apostles liars. How great was the change that I wrought in their condition then!\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmdclii{Say: ``I urge upon you only one thing: Stand up for God two by two or one by one, and think and reflect!" There is no madness about your companion. He is a warner against the dreadful affliction (that awaits).\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmdcliii{Say: ``The reward I ask is for yourself. My reward is due from none but God; and He is witness over everything."\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmdcliv{Say: ``My Lord casts the truth: He is the knower of things unknown."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmdclv{Say: ``The truth has come, and falsehood had neither precedence nor will reappear."\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmdclvi{Say: ``If I am in error it is to my own loss; if I am on guidance that is so because of what my Lord reveals to me. He is all-hearing and all-too-near."\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmdclvii{If you could see when they are gripped by terror without any escape, and are seized from close at hand\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmdclviii{They will say: ``We believe in it." How could they reach it from a place of no return?\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmdclix{They had surely denied it before and aimed without seeing from so far away.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmdclx{A barrier shall be raised between them and what they desired, as was done with their partisans before. They too were filled with disquieting doubt.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmdclxi{\basmalahen ALL PRAISE BE to God, the originator of the heavens and the earth, who appointed angels as His messengers, with wings, two, three and four. He adds what He pleases to His creation. He has certainly power over everything.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmdclxii{There is none who can take away the favours He bestows on man; and there is none apart from Him to restore what He has withheld. He is all-mighty and all-wise.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmdclxiii{O you people, remember the favours of God to you. Is there any creator other than God who gives you food from the heavens and the earth? There is no god but He: How then can you turn aside?\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmdclxiv{If they call you a liar, so have other messengers been denied before you. But all things will be brought back to God.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmdclxv{O you people, the promise of God is true. So do not let the life of this world delude you, nor let that (arch) deceiver deceive you about God.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmdclxvi{Satan is certainly your enemy, so hold him as a foe. He only calls his faction to be the residents of Hell.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmdclxvii{For those who are unbelievers, there is severe punishment; but for those who believe and do the right is forgiveness and a great reward.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmdclxviii{Can he, the evil of whose deed is made to look attractive to him so that he considers it good, (be like him who is guided)? God leads whosoever He please astray and guides whosoever He will. So do not waste away your self with grief for them. God is indeed cognisant of things they do.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmdclxix{It is God who sends the winds that raise the clouds. Then We drive the clouds towards the land that was dead, and restore the earth to life after it had died. So will be the Resurrection.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmdclxx{Whosoever desires honour (should remember) that all honour is with God. All good words ascend to Him, and all good deeds He exalts. As for those who are plotting evil, there is severe punishment for them, and their plots will be fruitless.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmdclxxi{It is God who created you from dust, then from a sperm, then formed you into pairs. Neither does a female conceive nor gives birth without His knowledge; nor do the old grow older or become younger in years but in accordance with the law (of nature). Indeed the law of God works inevitably.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmdclxxii{Alike are not two bodies of water: This one is sweet and fresh and pleasant to drink, and this one brine and bitter; yet you get fresh meat to eat from both, and take out ornaments to wear. You see how the ships churn through them so that you may seek of His bounty and, perhaps, give thanks.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmdclxxiii{He makes night run into day, the day run into night, and has harnessed the sun and the moon so that each runs to its determined course. This is God your Lord; His is the kingdom; and those you invoke apart from Him are not masters even of the film on a date-palm stone.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmdclxxiv{You pray to them, but they do not hear your call; and even if they heard you, they could not answer your prayer; and on the Day of Resurrection they will deny your having worshipped them. None can acquaint you (with the reality) as He who is informed of everything.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmdclxxv{O men, it is you who stand in need of God. As for God, He is above all need, worthy of praise.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmdclxxvi{He could take you away if He pleased and bring a new creation (in your place).\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmdclxxvii{This is well within the power of God.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmdclxxviii{No one who carries a burden bears another's load; and even if the burdened soul cry out for help none will carry the least of its burden, however close a relative it may be. You can only warn those who fear their Lord in secret and fulfil their devotional obligations. Whoever grows in goodness does so for himself. To God is the journeying back.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmdclxxix{Equal are not the blind and those who can see,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmdclxxx{Nor darkness and light,\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmdclxxxi{Nor shade and heat of sunshine.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmdclxxxii{Equal are not the living and the dead. Verily God makes those He will to listen; but you cannot make those hear who are in their graves.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmdclxxxiii{You are only a bearer of warnings.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmdclxxxiv{We have sent you with the truth, to give glad tidings and to warn. Never has there been a community to which an admonisher was not sent.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmdclxxxv{If they call you a liar, so had those before them called their apostles liars, who had come to them with clear proofs, scriptures and the splendent Book.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmdclxxxvi{So We seized the unbelievers. How great was the change I wrought in their condition then!\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmdclxxxvii{Do you not see how God sends water from the sky, then We produce fruits from it variegated in colour; and on mountains are tracts of red and white, in different shades and raven black.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmdclxxxviii{And so are among men, beasts and cattle, different shades. Only those of His creatures fear God who have knowledge. Verily He is all-mighty and forgiving.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmdclxxxix{Surely those who read the Book of God, are firm in devotion, and spend of what We have given them in secret or openly, can hope for a commerce that will not decline,\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmdcxc{So that He may reward them in full, and give them a greater increase by His grace. He is verily forgiving and rewarding.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmdcxci{What We have revealed to you of the Book is the truth, and proves (what has been sent) before it to be true. Verily God is informed of His creatures and sees everything.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmdcxcii{So We made those of Our creatures whom We had chosen, heirs to the Book; but some of these exceed themselves, and some follow the middle course, and some surpass others in goodness by God's will, which is the greatest blessing.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmdcxciii{They will enter the gardens of Eden, where they will be adorned with bracelets of gold and pearls, and of silk will be their garments.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmdcxciv{They will say: ``All praise be to God who has removed all care from us. Indeed our Lord is forgiving and rewarding,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmdcxcv{Who has settled us by His grace in the mansions of eternal rest, where there is no labour for us, nor does weariness come upon us."\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmdcxcvi{As for the unbelievers, there is the fire of Hell. It will neither consume them wholly that they should die, nor will its torment be lessened for them. That is how We requite the ungrateful.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmdcxcvii{There they will cry for help: ``O Lord, get us out that we may do the right, and not what we used to do." Did We not give you a long enough span of life so that he who remembered may reflect? And did not the warner come to you? So now taste (the punishment). The iniquitous will have none to help them.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmdcxcviii{Verily God knows the unknown of the heavens and the earth. Indeed He knows what lies in the hearts of men.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmdcxcix{He is the one who made you trustees on the earth. So he who disbelieves, will bear the consequence of his unbelief. but their unbelief will only increase disgust for unbelievers in the sight of their Lord; and their unbelief will only lead the unbelievers to greater loss.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmdcc{Say: ``Look at the compeers you invoke apart from God. Show me, what of the earth have they created, or what share have they in the heavens?" Or have We given them a Book whose testimony they possess? Not in the least. What the unbelievers have been promising one another is nothing but deceit.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmdcci{Verily God holds the heavens and the earth in position lest they deviate; and if they deviated there will be none to hold them in place, apart from Him He is sagacious and forgiving.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmdccii{The unbelievers swore on oath emphatically that if an admonisher came to them they would be guided better than the other communities. But when the admonisher came to them their aversion for the truth increased,\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmdcciii{As did their arrogance in the land, and their plotting of evil. But their evil plots will turn back on the plotters themselves. So can they expect any thing but what befell the earlier people? You will not find any change in the law of God, nor will you find divine law mutable.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmdcciv{Have they not journeyed in the land and seen how the end of those before them, who were far more powerful, came about? There is nothing in the heavens and the earth that can defeat (the law of) God. He is all-knowing and all-powerful.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmdccv{If God were to seize men for their doings, not a living being would be left upon the earth. But He gives them respite for a time ordained. When their time is come, surely God will keep (the interest of) His creatures in view.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmdccvi{\basmalahen YA SIN.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmdccvii{I call to witness the Qur'an, custodian of all laws, --\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmdccviii{That you are indeed one of those sent\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmdccix{On a path that is straight, --\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmdccx{A revelation from the mighty, ever-merciful (God),\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmdccxi{That you may warn a people whose ancestors had never been warned, who are therefore heedless.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmdccxii{The sentence is surely justified against most of them, for they do not believe.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmdccxiii{We will certainly put iron collars on their heel's which will come up to their chins, so that they will not be able to raise their heads.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmdccxiv{And We shall raise a barrier in front of them and a barrier behind them, and cover them over so that they will not be able to see.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmdccxv{Whether you warn them or do not warn, it is all the same; they will not believe.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmdccxvi{You can only warn him who listens to the warning and fears Ar-Rahman secretly. So give him good news of forgiveness and a generous reward.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmdccxvii{It is We indeed who bring back the dead to life, and write down what they send ahead (of their deeds), and traces that they leave behind. We keep an account of all things in a lucid register.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmdccxviii{Narrate to them the example of the people of the city when the messengers came to it.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmdccxix{When We sent two of them they called them liars; so We sent a third to strengthen them. ``We have been sent to you," they said.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmdccxx{``You are only men like us," they replied; ``Ar-Rahman has not sent down any thing. You are speaking only lies."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmdccxxi{(The messengers) said: ``Our Lord knows that we have been sent to you.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmdccxxii{Our duty is to convey the message clearly."\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmdccxxiii{They rejoined: ``We feel you augur ill. If you do not desist, we shall stone you to death, and inflict a grievous punishment on you."\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmdccxxiv{(The messengers) said: ``The augury is within your own selves. Do you (consider it a bad omen) that you should be warned? You are a people guilty of excess."\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmdccxxv{Then a man came running from the other side of the city. ``O my people," he said, ``follow the messengers.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmdccxxvi{Follow those who do not ask for any recompense of you, and are rightly guided.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmdccxxvii{Why should I not worship Him who brought me into being, to whom you will be brought back in the end?\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmdccxxviii{Should I take other gods apart from Him, who would neither be able to intercede for me nor save me if Ar-Rahman brings me harm?\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmdccxxix{In that case I would surely be in clear error.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmdccxxx{I believe in your Lord, so listen to me."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmdccxxxi{(But they stoned him to death.) It was said to him: ``Enter Paradise;" and he said: ``If only my people knew\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmdccxxxii{How my Lord has forgiven me and made me one of those who are honoured!"\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmdccxxxiii{We did not send down any army against his people from heaven, nor did We have to send one.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmdccxxxiv{There was just one blast, and they were extinguished.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmdccxxxv{Alas for men! No apostle ever came to them but they made fun of him.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmdccxxxvi{Have they not seen how many generations have We destroyed before them who will not return again?\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmdccxxxvii{They will all be brought together before Us.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmdccxxxviii{There is a sign in the dead earth for them which We quicken, and produce from it grain which they eat.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmdccxxxix{We have laid out gardens of dates and grapes upon it, and made springs of water flow,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmdccxl{So that they may eat of its fruit; yet it was not done by their hands. Then why do they not acknowledge thanks?\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmdccxli{All glory to Him who created pairs of everything that grows from the earth, and out of themselves, and other things they do not know.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmdccxlii{And there is a sign in the night for them. We strip off the day from it and they are left in darkness,\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmdccxliii{While the sun keeps revolving in its orbit. This is the dispensation of the mighty, all-knowing (God).\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmdccxliv{We have determined the stations of the moon, so that (after its wanderings) it returns as a dried up inflorescent spike of dates.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmdccxlv{Neither can the sun overtake the moon, nor the night outpace the day: Each of them keeps coursing in its orbit.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmdccxlvi{That We bore their progeny in the laden ark is a sign for them;\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmdccxlvii{And We made similar vessels for them to ride.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmdccxlviii{We could have drowned them if We pleased, and none would have answered their cry for help, nor would they have been saved,\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmdccxlix{Unless by Our benevolence, to reap advantage for a time.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmdccl{When it is said to them: ``Beware of what is before you and what is past, that you may be treated with kindness;"\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmdccli{None of the signs of their Lord ever comes to them but they turn away from it.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmdcclii{When they are told: ``Spend of what God has given you," the unbelievers say to those who believe: ``Why should we feed those whom God should have fed if He pleased?" You are only in palpable error.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmdccliii{And they say: ``When will this promise come to pass, if what you say is true?"\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmdccliv{They are only waiting for a single blast that will seize them, but they will go on contending.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmdcclv{Then they would not be able to make a will, or go back to their people.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmdcclvi{When the trumpet blast is sounded they will come out of their graves and hasten to their Lord,\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmdcclvii{Saying: ``Ah woe, who has roused us from our sleep?" This is what Ar-Rahman had promised, and whose truth the apostles had affirmed.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmdcclviii{It would be but a single blast of the trumpet, and they would all be arraigned before Us.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmdcclix{No soul will be wronged the least that Day, nor would be recompensed but only for what it had done.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmdcclx{Surely the inmates of Paradise will be engaged in pastimes.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmdcclxi{They and their companions will recline on couches in the shade.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmdcclxii{For them will be fruits and whatever they ask.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmdcclxiii{``Peace" shall be the greeting from the merciful Lord.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmdcclxiv{(And the guilty will be told:) ``O sinners, separate yourselves this day.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmdcclxv{Did I not commit you, O children of Adam, not to worship Satan who is your acknowledged foe,\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmdcclxvi{But to serve Me; (that) this is the straight path?\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmdcclxvii{But he beguiled a great many of you. Why did you not then understand?\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmdcclxviii{This is the Hell that you were promised.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmdcclxix{Roast in it now for having disbelieved."\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmdcclxx{We shall seal their lips that day; and their hands will speak, their feet testify to what they had done.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmdcclxxi{We could take away their sight if We pleased; then they would run around to find the way: But how then would they see?\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmdcclxxii{And if We pleased We could paralyse them in their tracks, and they would not be able to move forward or turn back.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmdcclxxiii{Whoever reaches old age, We reverse in natural disposition. Do they not have sense (to see)?\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmdcclxxiv{We have not taught (Muhammad) to versify, nor is it worthy of him. This is nothing but a reminder and illuminating discourse,\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmdcclxxv{So that he may warn him who is alive and feels, and justify the word against those who do not believe.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmdcclxxvi{Do they not see the cattle among things We have fashioned by Our power, which they own,\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmdcclxxvii{Whom We made subservient to them so that some of them they ride and some they eat?\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmdcclxxviii{And they derive other advantages and drinks from them. Even then they do not offer thanks,\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmdcclxxix{And take other gods apart from God that they may perhaps give them help.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmdcclxxx{They will not be able to help them and will be brought (to Us) as their levied troops.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmdcclxxxi{So be not grieved by what they say. We certainly know what they hide and disclose.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmdcclxxxii{Does not man see We created him from a drop of semen? Even then he becomes an open contender,\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{And applies comparisons to Us, having forgotten his origin, and says: ``Who can put life into decayed bones?"\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{Say: ``He who created you the first time. He has knowledge of every creation,\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmmdcclxxxv{Who gave you fire from a green tree, with which you ignite the flame."\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{How can He who created the heavens and the earth not be able to create others like them? Why not? He is the real creator all-knowing.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{When He wills a thing He has only to say: ``Be," and it is.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{So all glory to Him who holds all power over everything, to whom you will go back in the end.\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmmdcclxxxix{\basmalahen I CALL TO witness those who stand arrayed in rows,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmdccxc{And those who restrain by reprimanding,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmdccxci{And those who recite the Reminder,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmdccxcii{Verily your God is One,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmdccxciii{The Lord of the heavens and the earth and all that lies between them, and the Lord of the Easts.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmdccxciv{He decked the nearest heavens with ornaments of stars,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmdccxcv{Protecting them against every wayward devil,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmdccxcvi{So that they are not able to listen to the angels of higher (echelons), and are pelted from all sides\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmdccxcvii{And kept far away. There is perpetual punishment for them,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmdccxcviii{Except those who eavesdrop and are pursued by a shooting flame.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmdccxcix{So ask them if they are more difficult to create, or the rest We have created? Indeed (man) We created from fermented clay.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmdccc{Yet while you are filled with wonder, they just scoff;\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmdccci{And when they are warned they pay no heed.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmdcccii{When they see a sign, they laugh at it,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmdccciii{And say: ``This is only magic.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmdccciv{When we are dead and turned to dust and bones, how can we be raised again,\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmdcccv{And our fathers too?"\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmdcccvi{You say: ``Yes; and you will be lowly made."\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmdcccvii{There will only be a single jerk, and they will gape,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmdcccviii{And say: ``Ah woe! This is the Day of Reckoning."\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmdcccix{``(Yes,) this is the Day of Judgement you had called a lie."\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmdcccx{Gather all the wicked together and their comrades, and those they had worshipped\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmdcccxi{Other than God," (the angels will be told), ``then show them the way to Hell,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmdcccxii{And detain them, for they will be questioned."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmdcccxiii{``What is the matter with you that you do not help each other?"\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmdcccxiv{They will submit to questioning then,\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmdcccxv{And some of them will confront the others,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmdcccxvi{Saying: ``It were you who imposed yourselves upon us."\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmdcccxvii{They will say: ``No, you were the ones who would not believe.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmdcccxviii{We had no power over you. In fact, you were a people rebellious.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmdcccxix{The sentence of our Lord has come true for us. We have certainly to taste (the punishment),\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmdcccxx{For we had led you astray. In fact we ourselves were astray."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmdcccxxi{So, they will become partners in punishment.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmdcccxxii{That is how We deal with sinners.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmdcccxxiii{They were those who, when it was said to them, ``There is no god but God," behaved with insolence,\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmdcccxxiv{And said: ``Should we abandon our gods for the sake of an insane poet?"\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmdcccxxv{Not in the least. He has brought the truth and confirmed the other messengers.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmdcccxxvi{You will indeed taste a painful punishment,\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmdcccxxvii{And be rewarded but only for what you had done,\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmdcccxxviii{Except the chosen creatures of God,\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmdcccxxix{Whose provision is predetermined --\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmdcccxxx{Fruits of every kind, and they will be honoured\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmdcccxxxi{In gardens of delight,\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmdcccxxxii{(Sitting) on couches, face to face,\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{With cups from a flowing stream being passed around,\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{Clear, delicious to drink,\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmdcccxxxv{Neither dulling the senses nor intoxicating,\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{And with them maidens of modest look and large lustrous eyes,\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{Like sheltered eggs in a nest.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{Then one turned to the other in an enquiry.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmdcccxxxix{Said one of the speakers: ``I had a friend\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmdcccxl{Who used to say: 'Are you one of those who can testify to the truth?\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmdcccxli{(Do you think) we would be paid back our due when we are dead and reduced to dust and bones?'\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmdcccxlii{He said: 'Will you look down?'\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmdcccxliii{He looked down and saw (his friend) in the midst of Hell.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmdcccxliv{'By God', he said, 'you had almost ruined me.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmdcccxlv{Had it not been for the grace of my Lord I too would have been there (in Hell).\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmdcccxlvi{(Another will say:)"Is it true, we are not going to die\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmdcccxlvii{Other than our first death, and we shall not be punished?\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmdcccxlviii{This will indeed be great happiness.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmdcccxlix{For this the toilers should strive."\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmdcccl{Is this better or the tree of Zaqqum\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmdcccli{Which We have reserved as punishment for evil-doers?\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmdccclii{It is a tree that grows at the bottom of Hell.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmdcccliii{Its spathes are like the prickly pear.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmdcccliv{They will eat and fill their bellies with it,\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmdccclv{Washing it down with boiling water.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmdccclvi{Then to Hell they will surely be returned.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmdccclvii{They had found their fathers astray,\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmdccclviii{Yet they hasten to follow in their footsteps.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmdccclix{So had many an earlier people gone astray,\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmdccclx{And We had sent admonishers to them.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmdccclxi{Look, then how was the end of those who had been warned,\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmdccclxii{Other than the chosen creatures of God.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmdccclxiii{Noah had verily called to Us. And how gracious was He who answered (him).\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmdccclxiv{We saved him and his family from the great affliction,\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmdccclxv{And made his progeny survive,\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmdccclxvi{And left (his name) for posterity.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmdccclxvii{Peace on Noah among all men.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmmdccclxviii{That is how We reward those who do good.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmmdccclxix{Surely he was among Our faithful creatures.\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmmdccclxx{Afterwards We drowned the others.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmmdccclxxi{And Abraham indeed was of his inducement,\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmmdccclxxii{When he came to his Lord with a heart compliant,\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmmdccclxxiii{When he said to his father and his people: ``What is this you worship?\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmmdccclxxiv{Why do you solicit false gods instead of God?\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmmdccclxxv{What do you imagine the Lord of the worlds to be?"\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmmdccclxxvi{Then he looked up at the stars (they worshipped),\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmmdccclxxvii{And said: ``I am sick (of what you worship)!"\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmmdccclxxviii{But they turned their backs on him and went away.\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmmdccclxxix{Then he turned towards their gods and said: ``Why do you not eat (of these offerings)?\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmmdccclxxx{What is wrong with you that you do not speak?"\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmmdccclxxxi{Then he started striking them down with his right hand.\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmmdccclxxxii{So the people descended upon him.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{``Why do you worship these you carve yourselves," he asked,\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{``When God has created you and what you make?"\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mmmdccclxxxv{``Build a pyre for him and throw him into the raging fire."\qt@no{(97)}}
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{So they contrived a plot against him, but We made them abject.\qt@no{(98)}}
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{And he said: ``I am going away to my Lord who will show me the way.\qt@no{(99)}}
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{(And he prayed:) ``O Lord, grant me a righteous son."\qt@no{(100)}}
\qt@newcmd\qurantrans@en@mmmdccclxxxix{So We gave him the good news of a clement son.\qt@no{(101)}}
\qt@newcmd\qurantrans@en@mmmdcccxc{When he was old enough to go about with him, he said: ``O my son, I dreamt that I was sacrificing you. Consider, what you think?" He replied: ``Father, do as you are commanded. If God pleases you will find me firm."\qt@no{(102)}}
\qt@newcmd\qurantrans@en@mmmdcccxci{When they submitted to the will of God, and (Abraham) laid (his son) down prostrate on his temple,\qt@no{(103)}}
\qt@newcmd\qurantrans@en@mmmdcccxcii{We called out: ``O Abraham,\qt@no{(104)}}
\qt@newcmd\qurantrans@en@mmmdcccxciii{You have fulfilled your dream." Thus do We reward the good.\qt@no{(105)}}
\qt@newcmd\qurantrans@en@mmmdcccxciv{That was indeed a trying test.\qt@no{(106)}}
\qt@newcmd\qurantrans@en@mmmdcccxcv{So We ransomed him for a great sacrifice,\qt@no{(107)}}
\qt@newcmd\qurantrans@en@mmmdcccxcvi{And left (his hallowed memory) for posterity.\qt@no{(108)}}
\qt@newcmd\qurantrans@en@mmmdcccxcvii{Peace be on Abraham.\qt@no{(109)}}
\qt@newcmd\qurantrans@en@mmmdcccxcviii{That is how We reward those who do good.\qt@no{(110)}}
\qt@newcmd\qurantrans@en@mmmdcccxcix{He is truly among Our faithful creatures.\qt@no{(111)}}
\qt@newcmd\qurantrans@en@mmmcm{So We gave him the good news of Isaac, apostle, who is among the righteous.\qt@no{(112)}}
\qt@newcmd\qurantrans@en@mmmcmi{And We blessed him and Isaac. Among their descendants are some who do good, but some who wrong themselves.\qt@no{(113)}}
\qt@newcmd\qurantrans@en@mmmcmii{We were indeed gracious to Moses and Aaron,\qt@no{(114)}}
\qt@newcmd\qurantrans@en@mmmcmiii{And saved them and their people from great distress,\qt@no{(115)}}
\qt@newcmd\qurantrans@en@mmmcmiv{And helped them, so they were victorious.\qt@no{(116)}}
\qt@newcmd\qurantrans@en@mmmcmv{We gave them the explicit Book,\qt@no{(117)}}
\qt@newcmd\qurantrans@en@mmmcmvi{And showed them the straight path,\qt@no{(118)}}
\qt@newcmd\qurantrans@en@mmmcmvii{And left (their remembrance) for posterity.\qt@no{(119)}}
\qt@newcmd\qurantrans@en@mmmcmviii{Peace be on Moses and Aaron.\qt@no{(120)}}
\qt@newcmd\qurantrans@en@mmmcmix{That is how We reward those who do good.\qt@no{(121)}}
\qt@newcmd\qurantrans@en@mmmcmx{They are among Our faithful devotees.\qt@no{(122)}}
\qt@newcmd\qurantrans@en@mmmcmxi{Verily Elias is one of the apostles.\qt@no{(123)}}
\qt@newcmd\qurantrans@en@mmmcmxii{When he said to his people: ``Will you not be mindful of God?\qt@no{(124)}}
\qt@newcmd\qurantrans@en@mmmcmxiii{Would you call on Baal and leave the best of creators,\qt@no{(125)}}
\qt@newcmd\qurantrans@en@mmmcmxiv{God, your Lord, and the Lord of your fathers?"\qt@no{(126)}}
\qt@newcmd\qurantrans@en@mmmcmxv{They denied him, and will surely be brought to punishment,\qt@no{(127)}}
\qt@newcmd\qurantrans@en@mmmcmxvi{Except the chosen creatures of God.\qt@no{(128)}}
\qt@newcmd\qurantrans@en@mmmcmxvii{And We left his (memory) for posterity.\qt@no{(129)}}
\qt@newcmd\qurantrans@en@mmmcmxviii{Peace be on Elias.\qt@no{(130)}}
\qt@newcmd\qurantrans@en@mmmcmxix{That is how We reward those who do good.\qt@no{(131)}}
\qt@newcmd\qurantrans@en@mmmcmxx{He is truly among Our faithful devotees.\qt@no{(132)}}
\qt@newcmd\qurantrans@en@mmmcmxxi{Verily Lot was one of the apostles,\qt@no{(133)}}
\qt@newcmd\qurantrans@en@mmmcmxxii{Wherefore We saved him and his entire family\qt@no{(134)}}
\qt@newcmd\qurantrans@en@mmmcmxxiii{Except an old woman who was one of those who stayed behind.\qt@no{(135)}}
\qt@newcmd\qurantrans@en@mmmcmxxiv{Then We destroyed the others.\qt@no{(136)}}
\qt@newcmd\qurantrans@en@mmmcmxxv{You pass by (their habitations) in the morning\qt@no{(137)}}
\qt@newcmd\qurantrans@en@mmmcmxxvi{Or at night. Then how is it you do not understand?\qt@no{(138)}}
\qt@newcmd\qurantrans@en@mmmcmxxvii{Verily Jonah is one of the apostles.\qt@no{(139)}}
\qt@newcmd\qurantrans@en@mmmcmxxviii{When he fled on the laden ship,\qt@no{(140)}}
\qt@newcmd\qurantrans@en@mmmcmxxix{And lots were cast (when a storm overtook them), he was rejected, (and thrown overboard).\qt@no{(141)}}
\qt@newcmd\qurantrans@en@mmmcmxxx{Then he was swallowed by a large fish as he was worthy of blame.\qt@no{(142)}}
\qt@newcmd\qurantrans@en@mmmcmxxxi{Had he not been one of those who struggled hard,\qt@no{(143)}}
\qt@newcmd\qurantrans@en@mmmcmxxxii{He would have stayed in its belly till the day the dead are raised.\qt@no{(144)}}
\qt@newcmd\qurantrans@en@mmmcmxxxiii{So We cast him, sick, on a barren shore,\qt@no{(145)}}
\qt@newcmd\qurantrans@en@mmmcmxxxiv{And We made a gourd tree grow over him.\qt@no{(146)}}
\qt@newcmd\qurantrans@en@mmmcmxxxv{We sent him to a hundred thousand men or more,\qt@no{(147)}}
\qt@newcmd\qurantrans@en@mmmcmxxxvi{And they came to believe; so We allowed them to enjoy the good things of life for an age.\qt@no{(148)}}
\qt@newcmd\qurantrans@en@mmmcmxxxvii{Now ask them if their Lord has daughters, and they sons?\qt@no{(149)}}
\qt@newcmd\qurantrans@en@mmmcmxxxviii{Or did We make the angels females, and they witnessed it?\qt@no{(150)}}
\qt@newcmd\qurantrans@en@mmmcmxxxix{Is it not a lie invented by them when they say:\qt@no{(151)}}
\qt@newcmd\qurantrans@en@mmmcmxl{``God has begotten (children)?" They are liars indeed!\qt@no{(152)}}
\qt@newcmd\qurantrans@en@mmmcmxli{Does He prefer sons to daughters?\qt@no{(153)}}
\qt@newcmd\qurantrans@en@mmmcmxlii{What ails you that you judge in such a wise?\qt@no{(154)}}
\qt@newcmd\qurantrans@en@mmmcmxliii{Why do you not reflect?\qt@no{(155)}}
\qt@newcmd\qurantrans@en@mmmcmxliv{Or have you received some clear authority?\qt@no{(156)}}
\qt@newcmd\qurantrans@en@mmmcmxlv{Then bring your scripture, if what you say is true.\qt@no{(157)}}
\qt@newcmd\qurantrans@en@mmmcmxlvi{They link Him with jinns by lineage, yet the jinns know they will be brought before Him.\qt@no{(158)}}
\qt@newcmd\qurantrans@en@mmmcmxlvii{God is too glorious for what they ascribe to Him\qt@no{(159)}}
\qt@newcmd\qurantrans@en@mmmcmxlviii{Except His chosen creatures who do not.\qt@no{(160)}}
\qt@newcmd\qurantrans@en@mmmcmxlix{So neither you nor those you worship\qt@no{(161)}}
\qt@newcmd\qurantrans@en@mmmcml{Can mislead anyone away from Him,\qt@no{(162)}}
\qt@newcmd\qurantrans@en@mmmcmli{Except one who is (destined) to burn in Hell.\qt@no{(163)}}
\qt@newcmd\qurantrans@en@mmmcmlii{``There is not one of us who does not have his appointed place," (declare the angels.)\qt@no{(164)}}
\qt@newcmd\qurantrans@en@mmmcmliii{``And we are truly those who stand in rows,\qt@no{(165)}}
\qt@newcmd\qurantrans@en@mmmcmliv{And we are those who sing hallelujas to Him."\qt@no{(166)}}
\qt@newcmd\qurantrans@en@mmmcmlv{They used to say:\qt@no{(167)}}
\qt@newcmd\qurantrans@en@mmmcmlvi{If we had the account of earlier people with us,\qt@no{(168)}}
\qt@newcmd\qurantrans@en@mmmcmlvii{We would have been the chosen creatures of God."\qt@no{(169)}}
\qt@newcmd\qurantrans@en@mmmcmlviii{Yet now (that it has come) they refuse to believe in it; but they will come to know soon.\qt@no{(170)}}
\qt@newcmd\qurantrans@en@mmmcmlix{Our word had already been given before to Our votaries, the apostles, --\qt@no{(171)}}
\qt@newcmd\qurantrans@en@mmmcmlx{That they would be helped,\qt@no{(172)}}
\qt@newcmd\qurantrans@en@mmmcmlxi{And that certainly Our armies will be victorious.\qt@no{(173)}}
\qt@newcmd\qurantrans@en@mmmcmlxii{So you ignore them for a time\qt@no{(174)}}
\qt@newcmd\qurantrans@en@mmmcmlxiii{And wait; they will come to know soon.\qt@no{(175)}}
\qt@newcmd\qurantrans@en@mmmcmlxiv{Do they want to hasten Our punishment?\qt@no{(176)}}
\qt@newcmd\qurantrans@en@mmmcmlxv{When it comes down on their plains, it will be an evil dawn for those who had been warned.\qt@no{(177)}}
\qt@newcmd\qurantrans@en@mmmcmlxvi{So turn away from them for a time\qt@no{(178)}}
\qt@newcmd\qurantrans@en@mmmcmlxvii{And watch; they will come to know soon.\qt@no{(179)}}
\qt@newcmd\qurantrans@en@mmmcmlxviii{Too glorious is your Lord, the Lord of power, for what they ascribe to Him.\qt@no{(180)}}
\qt@newcmd\qurantrans@en@mmmcmlxix{So peace be on the messengers,\qt@no{(181)}}
\qt@newcmd\qurantrans@en@mmmcmlxx{And all praise to God, the Lord of all the worlds.\qt@no{(182)}}
\qt@newcmd\qurantrans@en@mmmcmlxxi{\basmalahen SAD. I CALL to witness the admonishing Qur'an.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmcmlxxii{But the unbelievers are still full of pride and hostility.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmcmlxxiii{How many generations have We destroyed before them who cried (for mercy) when it was too late for escape.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmcmlxxiv{They were surprised that one of them had come to them as warner; and the unbelievers said: ``He is a deceiving sorcerer.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmcmlxxv{Has he turned so many gods into one deity? This is indeed a strange thing!"\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmcmlxxvi{And their leading chiefs said: ``Remain attached to your gods. There is surely some motive behind it.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmcmlxxvii{We never heard of it in the former faith. It is surely a fabrication.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmcmlxxviii{To him of all of us has the Reminder been sent down?" They are still in doubt about My admonition; but they have not tasted My punishment yet!\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmcmlxxix{Do they have the stores of the mercy of your Lord, the mighty and munificent?\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmcmlxxx{Or is the kingdom of the heavens and the earth and all that lies between them, theirs? Then let them climb up the ladders (to the heavens).\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmcmlxxxi{They will be one more army vanquished among the many routed hordes.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmcmlxxxii{Even before them the people of Noah, 'Ad, the mighty Pharoah,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{And the Thamud, the people of Lot, as well as the dwellers of the Wood, had denied. These were the hordes.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{Of all these there was not one who did not deny the messengers. So My retribution was justified.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmcmlxxxv{They await but a single blast which will not be repeated.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{Still they say: ``O Lord, give us our share before the Day of Reckoning."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{Bear with patience what they say, and remember Our votary David, man of strength. He surely turned to Us in penitence.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{We subjugated the chiefs (of tribes) to struggle day and night with him,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmcmlxxxix{And the levied Tair. They were all obedient to him.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmcmxc{So We further strengthened his kingdom, and bestowed wisdom on him, and judgement in legal matters.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmcmxci{Have you heard of the litigants who jumped over the wall into his chamber?\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmcmxcii{When they came before David, he was frightened of them. ``Do not be afraid," they said. ``The two of us are disputing the wrong one has done the other. So judge between us with equity, and do not be unjust, and guide us to the right path.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmcmxciii{This man here is my brother. He has ninety and nine ewes while I have only one. He demands that I should give him my ewe, and wants to get the better of me in argument."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmcmxciv{(David) said: ``He is unjust in demanding your ewe to add to his (many) ewes. Many partners are surely -- unjust to one another, except those who believe and do the right; but there are only a few of them." It occurred to David that he was being tried by Us, and he begged his Lord to forgive him, and fell down in homage and repented.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmcmxcv{So We forgave him. He has surely a high rank with Us and an excellent place of return.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmcmxcvi{``O David, We have made you trustee on the earth. So judge between men equitably, and do not follow your lust lest it should lead you astray from the way of God. Surely for those who go astray from the way of God, is severe punishment, for having forgotten the Day of Reckoning.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmcmxcvii{We have not created the heavens and the earth and all that lies between them, all for nothing. Only those who deny imagine so. So for the unbelievers there is woe from the fire.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmcmxcviii{Should We equate those who do the right with those who spread corruption in the land? Should We make those who are morally integrated equal to those who seek disintegration?\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmcmxcix{We have sent down a Book to you which is blessed, so that people may apply their minds to its revelations, and the men of wisdom may reflect.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmm{We bestowed Solomon on David who was an excellent devotee, for he turned to God in penitence.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmi{When they brought fleet-footed chargers in the evening to show him,\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmii{He said: ``The love of horses is worthy of desire to me for the remembrance of my Lord;" and when they were out of sight, (he said):\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmiii{``Bring them back to me," and he began to rub and stroke their shanks and necks.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmiv{We surely tried Solomon, and placed another body on his throne. So he turned to God\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmv{Saying: ``O Lord, forgive me, and give me such a dominion as none will merit after me. You are the great bestower."\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmvi{So we subjugated the wind to his service which carried his merchandise wheresoever he wished;\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmvii{And the devils -- the builders and divers of all kinds,\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmviii{And many others bound in bond.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmix{``This is Our gift," (We said to him), ``so bestow freely or withhold without reckoning."\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmx{He has a high position with Us and an excellent abode.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmxi{Remember Our votary Job because he called to his Lord: ``Satan has afflicted me with disease and distress."\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmxii{``Go swiftly to the spring," (We said). ``This cold water is for bathing and for drinking."\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmxiii{We restored his family to him with others similar to them, as a blessing from Us and a reminder for men of wisdom. --\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmxiv{``Take a handful of herbs," (We said to him), and apply and rub them, and do not make a mistake." We found him patient in adversity, an excellent devotee, always turning in repentance.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmxv{Remember Our votaries Abraham, Isaac and Jacob, men of power and insight.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmxvi{We distinguished them for the distinct remembrance of the abode (of the Hereafter).\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmxvii{They are the chosen ones, the excellent in Our sight.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmxviii{And remember Ishmael, Elisha and Dhu'l-Kifl. Every one of them is among the best.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmxix{This is a commemoration. Surely for those who take heed for themselves is an excellent place of return --\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmxx{Gardens of Eden with gates open wide to them,\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmxxi{Where they will take their ease, calling for fruits in plenty, and for wine,\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmxxii{With companions of modest look, the same in age, by their side.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmxxiii{This is what is promised you for the Day of Reckoning.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmxxiv{This is surely Our provision never-ending.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmxxv{This (for the virtuous); but for the transgressors the evil destination,\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmxxvi{Hell, in which they will burn. How vile a resting place!\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmxxvii{There will be boiling water for them and cold, clammy, fetid drink to taste,\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmmxxviii{And other similar torments.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmmxxix{Here is a multitude rushing headlong with you. There is no welcome for them. They will roast in the fire.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmmxxx{They will say: ``In fact, it is you who will have no welcome. It is you who brought this upon us. What an evil place of rest!"\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmmxxxi{They will say: ``O Lord, give him who has brought this upon us two times more the torment of Hell;"\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmmxxxii{And will add: ``O what has happened to us that we do not see the men we counted among the wicked.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmmxxxiii{Did we laugh at them (for nothing), or our eyes fail to pick them out?"\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmmxxxiv{This contending of the inmates of Hell will surely be real.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmmxxxv{Say: ``I am only a warner, and there is no other god but God, the one, the omnipotent,\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmmxxxvi{Lord of the heavens and the earth and all that lies between them, all-mighty, all-forgiving."\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmmxxxvii{Say: ``This is a momentous message,\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmmxxxviii{To which you pay no heed.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmmxxxix{I had no knowledge of the higher Assembly when they discussed it among themselves.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmmxl{Only this has been revealed to me that I am a distinct warner.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmmxli{When your Lord said to the angels: ``I am going to create a man from clay;\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmmxlii{And when I have made him and have breathed into him of My spirit. Fall down in homage before him."\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmmxliii{Then the angels bowed before him in a body,\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmmxliv{Except Iblis. He was filled with pride and turned an unbeliever.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmmxlv{Said (God): ``O Iblis, what hindered you from adoring what I created by My own authority? Are you too proud, or too high and mighty?"\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmmxlvi{He said: ``I am better than he. You created me from fire, and him from clay."\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmmxlvii{(God) said: ``Then go hence, ostracised.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmmxlviii{Upon you will be My damnation till the Day of Doom."\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmmxlix{He said: ``O Lord, give me respite till the day the dead rise from their graves."\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmmml{(God) said: ``You have the respite\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmmmli{Till the appointed day."\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmmmlii{He said: ``By Your authority, I will lead them astray,\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmmmliii{Other than the chosen ones among Your creatures."\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmmmliv{(God) said: ``This is right by Me, and what I say is right.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmmmlv{I will fill up Hell with you together with those who follow you."\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmmmlvi{Say: ``I do not ask any compensation of you for it, nor am I a specious pretender.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmmmlvii{This is only a warning for mankind.\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmmmlviii{You will come to know its truth in time."\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmmmlix{\basmalahen THE REVELATION OF this Book is from God, the mighty and all-wise.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmlx{We have revealed to you the Scripture with exactitude; so worship God with devotion all exclusive for Him.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmlxi{Remember that devotion is exclusively for God. Those who have taken protectors other than Him, say: ``We worship them that they may bring us nearer to God." Surely God will judge between them in what they are differing about. Verily God does not show the way to an ungrateful liar.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmlxii{Had God pleased to take a son, He could have chosen whom He liked from among those He has created. Glory be to Him. He is God, the one, the omnipotent.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmlxiii{He has created the heavens and the earth with precision. He folds the day up over the night, and folds the night up over the day. He has subjugated the sun and moon, (so that) each runs its appointed course. Is He not all-mighty and forgiving?\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmlxiv{He created you from a single cell, then from it created its mate; arid provided eight varieties of cattle for you. He formed you in the mother's womb, formation after formation in three (veils of) darkness. He is God your Lord. His is the kingdom. There is no god other than He. How then can you turn away?\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmlxv{If you are ungrateful, then remember! God is independent of you, and He does not favour ingratitude on the part of His creatures. If you are grateful He will be pleased with you. For no one who carries a burden bears another's load; and your returning is to your Lord, when He will tell you what you used to do. Surely He knows what is in the hearts.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmlxvi{When man is afflicted with adversity he turns to his Lord, and prays to Him. But when He bestows His favour on him, he forgets what he prayed for before, and sets up others as compeers of God to mislead (people) from His way. Say: ``Take advantage of your denying for a while: You will be among the inmates of Hell."\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmlxvii{Can one who prays in the watches of the night, bowing in homage or standing attentive, fearful of the life to come, and hoping for the mercy of his Lord, (be like one who does not)? Say: ``Can those who know, and those who do not know, be equal? Only they think who are wise."\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmlxviii{Tell them: ``O my creatures who have come to belief, have fear of displeasing your Lord. There is good for those who do good in this world, and productive is God's earth. Only those who persevere will get their reward measureless."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmlxix{Say: ``I am commanded to worship God with obedience all-exclusive for Him;\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmlxx{And I am commanded to be the first of those who submit."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmlxxi{Say: ``If I disobey my Lord, I fear the punishment of an evil Day."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmlxxii{Say: ``I worship God with devotion all-exclusive for Him.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmlxxiii{You may worship what you will apart from Him." Say: ``Surely the greatest losers will be those who will lose their own selves and their people on the Day of Resurrection." Remember, this will be an all-too-evident loss.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmlxxiv{Above them will be a covering of fire, below them a cloud (of flames). With this does God warn His creatures: ``O My creatures, fear Me."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmlxxv{There are happy tidings for those who keep away from the worship of false gods and turn to God in repentance. Give glad tidings to My creatures.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmlxxvi{Those who listen to the Word and then follow the best it contains, are the ones who have been guided by God, and are men of wisdom.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmlxxvii{Can he against whom the sentence of punishment has been justified (be rescued)? Can you save him who is in the Fire?\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmlxxviii{But for those who fear displeasing their Lord there are lofty mansions built above mansions, with rivers rippling past below them: A promise of God; (and) God does not go back on His promise.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmlxxix{Do you not see that God sends down water from the sky, then makes it flow in rills on the earth, and brings forth corn from it which, having passed through changes of shade and colour, comes to ripen, and you see it autumnal yellow; then He reduces it to chaff. There are indeed lessons in this for those who are wise.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmlxxx{Will he whose breast has been opened up to peace (not be) in luminescence from his Lord? Alas for those whose hearts have been hardened to God's remembrance! They wander (astray) in clear error.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmlxxxi{God has sent down the very best discourse, the Book conformable in its juxtapositions, which makes all of those who fear their Lord, shudder. So their hearts and bodies become receptive to the remembrance of God. This is the guidance of God with which He guides whosoever He will; but whosoever God allows to go astray has none to show him the way.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmlxxxii{Can he who will have to shield himself against the torment of the Day of Resurrection (be the same as one at peace)? The evil-doers will be told: ``So taste what you earned."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmlxxxiii{Those before them had denied, then punishment had overtaken them is from a quarter they did not suspect.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmlxxxiv{Then God made them taste of disgrace in this life; and the torment of the life to come is greater, if they understand.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmlxxxv{We have given examples of every kind for men in this Qur'an so that they may contemplate:\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmlxxxvi{A clear discourse which expounds all things without any obliquity, so that they may take heed for themselves.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmlxxxvii{God advances the example of a man who is owned (as slave in common) by a number of men at loggerheads, and another man who is owned by only one. Are these two alike in attribute? God be praised; yet many of them do not know.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmlxxxviii{Verily you will die, and so will they.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmlxxxix{Then on the Day of Resurrection you will dispute before your Lord.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmxc{Who does greater wrong than he who tells a lie against God, and denies the truth when it has come to him? Is there no place for unbelievers in Hell?\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmxci{He who brings the truth and verifies it, -- such are the people who are God-fearing.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmxcii{They shall have what they wish from their Lord. This is the recompense for the good,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmxciii{That God may absolve them of their sins and reward them for the best that they had done.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmxciv{Is not God sufficient for His devotee? Still they frighten you with others apart from Him. Whoever God allows to go astray has none to show him the way.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmxcv{And none can lead him astray who has been guided by God. Is not God all-mighty, the lord of retribution?\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmxcvi{If you ask them, ``Who created the heavens and the earth?" they will answer: ``God." Say: ``Then just think. Can those whom you worship apart from God remove the distress God is pleased to visit upon me, or withhold a blessing God is pleased to favour me with?' Say: ``God is all-sufficient for me. The trusting place their trust in Him."\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmxcvii{Say: ``O people, act as best you can on your part, I am acting too. You will come to know in time\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmxcviii{Who suffers the shameful punishment, and on whom falls the everlasting torment.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmxcix{We have Sent down this Book to you with the truth for all mankind. So, he who comes to guidance does so for himself, and he who goes astray does so for his own loss; on you does not lie their guardianship.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmc{God gathers up the souls of those who die, and of those who do not die, in their sleep; then He keeps back those ordained for death, and sends the others back for an appointed term. Surely there are signs in this for those who reflect.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmci{Have they appointed intercessors other than God? Say: ``Even though they have no power in the least, nor do they understand?"\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmcii{Say: ``God's is the intercession entirely; His is the kingdom of the heavens and the earth; then to Him you will return."\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmciii{When God alone is mentioned the hearts of those who do not believe in the life to come, are filled with resentment. But when others are mentioned apart from God, they begin to rejoice.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmciv{Say: ``O God, the originator of the heavens and the earth, the knower of the unknown and the known, You alone will judge between Your creatures for things they differed about."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmcv{Even if the sinners possessed whatever is in the heavens and the earth, and as much more, they would offer it to ransom themselves from the torment of the Day of Resurrection; yet what they did not even imagine would appear to them from God;\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmcvi{And the evil of what they had earned would become visible to them; and what they used to mock would surround them from all sides.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmcvii{When a man is in trouble, he prays to God; but when We bestow a favour on him he says: ``It has come to me through my acumen." In fact, this is an illusion, but most men do not know.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmcviii{Those before them had also said so, and yet nothing of what they did availed them in the least.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmcix{Then the worst of what they had done overtook them. So will the evil deeds of those who are sinners among them recoil back on them. They cannot get the better (of Us).\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmcx{Do they not know that God enhances or restricts the provision of any one He will. Surely there are signs in this for people who believe.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmcxi{Say: ``O creatures of God, those of you who have acted against your own interests should not be disheartened of the mercy of God. Surely God forgives all sins. He is all-forgiving and all-merciful.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmcxii{Turn towards your Lord and obey Him before the punishment comes upon you when you will not be helped.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmcxiii{Follow the best of what has been revealed to you by your Lord before the punishment overtakes you suddenly and you are caught unawares,\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmcxiv{Lest a soul should say: ``Alas, I was heedless of God and only laughed;"\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmcxv{Or say: ``If only God had guided me I would have been a man of fear and piety;"\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmmcxvi{Or say on seeing the punishment: ``If I could only return I would be among the good."\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmmcxvii{Why, My revelations had come to you, but you denied them and were filled with pride, and were among the disbelievers.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmmcxviii{If you see those who had imputed lies to God on the Day of Resurrection, black would be their faces (with disgrace). Is there not a place in Hell for the arrogant?\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmmcxix{God would rescue those who fear Him (and guide them) to places of safety. Neither will evil touch them nor regret.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmmcxx{God is the creator of all things, and He is the guarantor of all things.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmmcxxi{He has the keys of the heavens and the earth; and those who deny the revelations of God will be losers.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmmcxxii{Say: ``O you ignorant people, do you bid me to worship someone other than God?\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmmcxxiii{Surely you have been commanded, as those before you were: ``If you associate (any one with God), wasted will be all your deeds, arid you will perish."\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmmcxxiv{So, you should worship only God, arid be among the grateful.\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmmcxxv{They do not esteem God as is rightly due to Him. The whole earth would be a fistful of His on the Day of Resurrection, and the heavens would be rolled up in His right hand. Too immaculate is He and too high for what they associate with Him!\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmmcxxvi{When the trumpet blast is sounded whoever is in the heavens and the earth will swoon away, except those God please. When the blast is sounded the second time, they will stand up all expectant.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmmcxxvii{The earth will light up with the effulgence of her Lord; and the ledger (of account) will be placed (in each man's hand), and the apostles and the witnesses will be called, and judgement passed between them equitably, and no wrong will be done to them.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmmcxxviii{Each soul will be paid in full for what it had done. He is cognisant of what you do.\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmmcxxix{The unbelievers will be driven into Hell in groups till, when they reach it and its doors are opened up, its keepers will say to them: ``Did not apostles of your own come to you reciting your Lord's revelations, warning you of this your day of Doom?" They will answer: ``Yes;" but the sentence of punishment was justified against the unbelievers.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmmcxxx{``Enter the gates of Hell," they will be told, ``and there abide for ever." How grievous a destination for the haughty!\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmmcxxxi{Those who were mindful of their duty to their Lord will be driven in groups to Paradise, till they reach it and its gates are opened, and its keepers say to them: ``Peace be on you; you are the joyous. So enter here to live for ever."\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmmcxxxii{They will say: ``All praise be to God Who has fulfilled the promise He had made to us, and bequeathed to us this land for dwelling in the garden wheresoever we like." How excellent the recompense for those who act!\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmmcxxxiii{You will see the angels hover round the Throne, singing the praises of their Lord; and justice will be done between them equitably, and it would be said: ``All praise to God the Lord of all the worlds."\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmmcxxxiv{\basmalahen HA MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmcxxxv{The revelation of this Book is from God the all-mighty and all-knowing,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmcxxxvi{Forgiver of trespasses, acceptor of repentance, severe of retribution, lord of power. There is no god but He. Towards Him is your destination.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmcxxxvii{Only the unbelievers dispute the revelations of God. So do not let their activities in the land deceive you.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmcxxxviii{The people of Noah had denied before them, and many factions after them. Every nation has intrigued against its apostle and afflicted him, and argued with false arguments to condemn the truth. Then I seized them. How was then My retribution!\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmcxxxix{In this way the sentence of your Lord against the infidels that they would be the inmates of Hell, was justified.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmcxl{The bearers of the Throne, and those around it, sing the praises of their Lord and believe in Him, and seek forgiveness for those who believe: ``O our Lord, Your mercy and knowledge embrace everything; so forgive those who turn to You in repentance and follow Your path; and preserve them from the torment of Hell.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmcxli{Admit them, O Lord, to the garden of Eden which You promised them, and those of their fathers, spouses and progeny who are upright. You are truly all-mighty and all-wise.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmcxlii{Protect them from evil; and whosoever You preserve from evil on that Day shall have surely received Your mercy. This will be the great triumph."\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmcxliii{Those who disbelieve will certainly be told: ``God's displeasure was greater than your disgust of your selves when you were called to belief and refused to believe."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmcxliv{They say: ``O Lord, twice You made us die, and twice You made us live. We admit our sins. Is there still a way out for us?"\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmcxlv{This has come upon you because when God alone was invoked you disbelieved; but when partners were associated with Him, you believed. But judgement belongs to God, the all-high and supreme.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmcxlvi{It is He who shows you His signs, and sends you food from the heavens. Yet none takes a warning except him who turns to Him.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmcxlvii{So call on God with exclusive obedience, howsoever the unbelievers may dislike it.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmcxlviii{Most exalted of position, Lord of power, He directs inspiration by His command to any of His creatures as He will, to warn (men) of the Day of Meeting,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmcxlix{The day when they will come out (of their graves), with nothing of them hidden from God. Whose then will be the kingdom? -- God's, the one, the omnipotent.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmcl{Each soul will be recompensed that Day for what it had earned. There will be no depriving on that Day. Surely God is swift at reckoning.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmcli{Warn them of the coming day inevitable, when hearts would jump to the throats, filling them with anguish. The sinners will have neither friend nor intercessor whose (word) will be heeded.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmclii{Known to Him is the treachery of the eye, and what the breasts conceal.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmcliii{God decides with justice. But those they call apart from Him can not adjudge in the least. Verily God is all-hearing, all-perceiving.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmcliv{Have they not travelled on the earth that they could see what happened to those before them? They were greater in strength than they, and have left behind them traces on the earth. Yet they were seized by God for their sins, and had none to protect them against God.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmclv{This was so because their apostles came with clear proofs to them, but they refused to believe. So they were seized by God. Surely God is powerful, unrelenting in retribution.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmclvi{We sent Moses with Our signs and clear authority\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmclvii{To Pharaoh, Haman and Qarun. But they said: ``He is only a deceiving sorcerer."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmclviii{And when he brought the truth to them from Us, they said: ``Slay the sons of those who believe with him, and spare their women." But the unbelievers' stratagem is bound to fail.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmclix{``Let me kill Moses," the Pharaoh said, ``and let him call to his Lord. I fear that he will change your faith and spread corruption in the land."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmclx{Moses said: ``I seek refuge in my Lord and your Lord from every insolent imposter who does not believe in the Day of Reckoning."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmclxi{A believer from the House of Pharaoh who had kept his faith to himself, said: ``Will you kill a man because he says: 'My Lord is God,' when he has brought clear signs from his Lord to you? If he is a liar his lie will recoil back on him; but in case he speaks the truth, then what he predicts will befall you. Surely God does not show the way to the shameful liar.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmclxii{O my people, authority is yours today being the most powerful in the land; but who will save us from the scourge of God if it fall upon us?" ``I show you," said the Pharaoh, ``only what I see (is right), and guide you but to the right path."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmclxiii{But the man of belief said: ``O my people, what I fear for you is the like of what befell the communities (of old).\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmclxiv{Like the people of Noah, 'Ad and Thamud, and those that came after them. God does not want to be unjust to His creatures.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmclxv{O my people, what I fear for you is the day of gathering, crying and calling,\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmclxvi{The day you will turn your backs and flee, with none to defend you against God. Whoever God allows to go astray has none to show him the way.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmclxvii{Joseph had indeed come to you before with clear proofs, but you did not cease to doubt what he had brought until he died, when you said: 'God will not send a prophet after him.' That is how God leads the waster, the sceptic astray.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmclxviii{Those who dispute God's revelations, with no authority having come to them, (are) greatly odious in the sight of God, and the sight of those who believe. That is how God seals every proud and perverse heart."\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmclxix{The Pharaoh said: ``O Haman, build me a lofty tower that I may perhaps find the means\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmclxx{Of reaching the tracts of heaven and look at the god of Moses, though I think that he is a liar." Thus were the evil deeds of Pharaoh made to look attractive to him, and he was hindered from the path. So the stratagem of Pharaoh was bound to perish.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmclxxi{The man who believed said: ``O my people, follow me; I will guide you to the right path.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmclxxii{O people, the life of this world is ephemeral; but enduring is the abode of the Hereafter.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmclxxiii{Whoever does evil will be requited in accordance with it; but whoever does right, whether man or woman, and is a believer, will enter Paradise, where they will have provision in abundance.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmclxxiv{O my people, what is wrong with me that I am calling you to preservation, while you invite me to the Fire!\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmclxxv{You are asking me to disbelieve in God, and to associate with Him that of which I have no knowledge, yet I invite you to the all-mighty, all-forgiving.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmclxxvi{What you are calling me to is surely not worth the calling in this world or in the next, because our returning is to God; and because the transgressors will be inmates of Hell.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmclxxvii{You will remember what I say in time to come; I submit my case to the judgement of God. Surely God keeps an eye on His creatures."\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmclxxviii{So God preserved him from the evil they were planning; and a dreadful doom encompassed the people of Pharaoh:\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmclxxix{Fire, to which they are exposed morning and evening. The day the Hour is proclaimed (it will be said:) ``Admit the people of Pharaoh to the severest punishment,"\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmclxxx{As they will noisily argue in the Fire, the weaker ones will say to the arrogant: ``We were your followers, so will you take over some of our share of the fire?"\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmclxxxi{The arrogant will answer: ``All of us are in it. Surely God has judged between His creatures."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmclxxxii{Those in the Fire will say to the warders of Hell: ``Ask your Lord to reduce the punishment by a day for us."\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmclxxxiii{They will say: ``Did not your apostles come to you with clear proofs?" They will answer: ``Indeed, they did." ``Then pray," will (the warders) say. But the praying of unbelievers will be all in vain.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmclxxxiv{We will certainly help Our messengers and those who believe, in this world, and on the day the witnesses take their stand,\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmclxxxv{The day upon which their excuses will not benefit the evil-doers, and the condemnation and evil abode will be theirs.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmclxxxvi{Verily We showed Moses the way, and bequeathed the Book to the children of Israel,\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmclxxxvii{A guidance and reminder for men of wisdom.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmclxxxviii{So persevere; the promise of God is true; and seek forgiveness for your sins, and chant the praises of your Lord evening and morning.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmclxxxix{Verily those who argue in the matter of God's revelations, without authority having reached them, have nothing but pride in their hearts, and they will not achieve their end. So take refuge in God: Surely He is all-hearing and all-seeing.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmcxc{The creation of the heavens and the earth is indeed of greater magnitude than the creation of mankind; but most men do not understand.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmmcxci{The blind and the seeing are surely not alike, nor those who believe and act rightly and those who do evil. Little do you reflect!\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmmcxcii{The Hour will certainly come; there is no mystery about it; but most men do not believe.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmmcxciii{Your Lord has said: ``Call to Me that I may answer your call. Surely those who disdain worshipping Me will enter Hell, disgraced."\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmmcxciv{It is God who made the night for you to rest, the day to make things visible. Indeed God is gracious to men, but most men are not grateful.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmmcxcv{He is God your Lord, creator of everything. There is no god but He. How then do you turn away (from Him)?\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmmcxcvi{Only they are turned away thus who deny the signs of God.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmmcxcvii{It is God who made the earth a dwelling for you, and the sky a vaulted roof, who fashioned you and gave you excellent form and provided you with clean and wholesome things. He is God, your Lord. So blessed be God, the Lord of all the worlds.\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmmcxcviii{He is the living. There is no god but He. Therefore pray to Him with obedience all-exclusive. Praise be to God, the Lord of all the worlds.\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmmcxcix{Say: ``I am forbidden to worship those you call apart from God, since clear signs have come to me from my Lord, and I am commanded to submit to the Lord of all the worlds."\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmmcc{It is He who created you from dust, then a drop of semen, then the embryo; afterwards He brings you forth as a child; then you attain the age of manhood, and then reach old age. But some of you die before you reach the appointed term that you may haply understand.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmmcci{It is He who gives you life and death. When He creates a thing, He has only to say: ``Be," and it is.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmmccii{Have you not seen how those who dispute the signs of God are turned away?\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmmcciii{Those who deny the Book and what We have sent down with Our apostles, will soon come to know\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmmcciv{When, with (iron) collars and chains around their necks, they will be dragged\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmmccv{Through boiling water, and then burnt in the Fire.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmmccvi{They will then be asked: ``Where are they you took as partners\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmmccvii{Apart from God?" They will answer: ``They have left us in the lurch and fled. In fact it was nothing that we prayed to before." That is how God sends the unbelievers astray.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmmccviii{``This is so because you went about exulting wrongfully in the land," (will they be told), ``and you were insolent.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmmccix{So enter the gates of Hell to abide in it for ever." How evil the abode of the arrogant!\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmmccx{So you persevere with patience (in your mission). The promise of God is true. Whether We show you some of the punishment We have promised them, or gather you up in death, they have to come back to Us.\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmmccxi{Surely We have sent apostles before you, some of whose account We have related to you, and that of some We have not told you. But no apostle was given a miracle unless God dispensed. But when the decree of God comes the sentence is passed with justice; and the lovers of vice and vanity will then come to grief.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmmccxii{It is God who made the cattle for you so that some you ride and some you eat.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmmmccxiii{There are advantages for you in them, so that you may satisfy your needs through them, and may be borne upon them and on ships.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmmmccxiv{He shows His signs. How many of God's signs will you then deny?\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmmmccxv{Have they not travelled in the land and seen how was the end of those before them who were far more numerous than they and more strong, and have left behind them traces on the earth. And yet nothing of what they did profited them.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmmmccxvi{For when Our apostles came to them with clear proofs, they boasted and exulted at the knowledge they possessed; but what they used to mock recoiled back on them,\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmmmccxvii{So that when they saw Our might, they said: ``We believe in God the one and single, and reject those we associated (with Him)." --\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmmmccxviii{But then their affirming served them nothing after they had seen Our torment. This is the law of God that has prevailed among His creatures, Then the unbelievers went to rack and ruin.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmmmccxix{\basmalahen HA MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmccxx{A revelation from the most benevolent, ever-merciful,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmccxxi{A Book whose verses have been distinguished and explained, a lucid discourse for people who understand,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmccxxii{Announcing happy news and warnings. And yet most of them are averse and do not listen,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmccxxiii{And say: ``Our hearts are immured against what you call us to. There is a deafness in our ears, and a veil lies between us and you. So act (your way), we are acting (ours)."\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmccxxiv{Say: ``I am a man like you, (but) it is revealed to me that your God is one God, so take the straight path to Him, and ask Him to forgive your sins. Woe to the idolaters\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmccxxv{Who do not give a due share of their wealth for the welfare of others, and do not believe in the Hereafter.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmccxxvi{But those who believe and do the right, will have a continuing reward.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmccxxvii{Say: ``Do you refuse to believe in Him who created the earth in two spans of time, and set up compeers to Him, the Lord of all the worlds?\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmccxxviii{He placed firm stabilisers rising above its surface, blessed it with plenty and growth, and ingrained the means of growing its food within it, sufficient for all seekers, in four spans.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmccxxix{Then He turned to the heavens, and it was smoke. So He said to it and the earth: ``Come with willing obedience or perforce." They said: ``We come willingly."\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmccxxx{Then He created several skies in two spans, and ingrained in each sky its function, decking the nearest heaven with lamps, and guarded it. This has been determined by the mighty and all-knowing.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmccxxxi{If even then they turn away, tell them: ``I forewarn you of a terrible punishment like the thunderbolt that fell upon the 'Ad and Thamud."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmccxxxii{Their apostles came to them one after the other (saying): ``Do not worship any one but God." They said: ``If our Lord had pleased He would have sent the angels down. We reject what is sent with you."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmccxxxiii{So those who were 'Ad turned insolent unjustly in the land, and said: ``Who is stronger than us?" Did they not see that God who created them was greater far in power than they? Yet they refused to believe Our signs.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmccxxxiv{So We let loose on them a violent wind for several days of distress to make them taste a most disgraceful punishment here in this world, and far more shameful will be the punishment in the Hereafter, and there will be no succour for them.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmccxxxv{As for the (tribe of) Thamud, We tried to guide them, but they preferred blindness to guidance; then they were seized by the torment of a humiliating punishment as requital for their misdeeds;\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmccxxxvi{But We saved those who believed and took heed for themselves.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmccxxxvii{The day the enemies of God will be gathered at the Fire and the records of their deeds will be distributed,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmccxxxviii{So that when they reach it their ears and eyes and persons will testify to what they did.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmccxxxix{And they will say to their bodies: ``Why did you testify against us?" They will answer: ``God, who gave all things power of articulation, made us speak. It is He who created you the first time, and to Him you will return.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmccxl{You did not hide your (doings) so that your ears or eyes or persons should not testify against you. In fact you thought that God did not know the things you used to do.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmccxli{It is this notion you had of your Lord that caused your ruin, and you are lost."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmccxlii{Even if they are patient, their abode is Hell; and if they beg for favour, none will favour them.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmccxliii{We had assigned to them close companions who made their past and present look attractive to them; and the fate that had once befallen the communities of jinns and men before them was justified upon them. They were indeed bound to perish.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmccxliv{The disbelievers say: ``Do not listen to this Qur'an, and shout away (its reading); you may haply prevail."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmccxlv{We shall make the disbelievers taste the severest punishment, and retribute them for the worst that they had done.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmccxlvi{This is the requital for God's enemies: Hell, where they will have their lasting home, as punishment for denying Our revelations.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmccxlvii{Those who disbelieve will say: ``O Lord, show us those among the jinns and men who had led us astray that we may trample them underfoot and make them wholly abject."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmccxlviii{Surely the angels will come down to those who say, 'Our Lord is God' and then remain steadfast, saying: ``You should have neither fear nor regret, but rejoice in the happy news of Paradise that has been promised you.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmccxlix{We are your friends in this life and in the Hereafter where you will get whatever your hearts desire, and have whatsoever you ask for,\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmccl{As a gift from the forgiving, ever-merciful (God)."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmccli{Whose word is better than his who calls to God and does the right, and says: ``I am of the obedient?"\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmcclii{Good and evil are not alike. Repel evil with what is good. Then you will find your erstwhile enemy like a close. affectionate friend.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmccliii{Only they attain it who forbear, and only a man of great good fortune can achieve it.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmccliv{If the Devil incite you to evil, seek refuge in God. He is all-hearing and all-knowing.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmcclv{The night and day and the sun and moon are (only) some of His signs. So do not bow before the sun and the moon, but bow in homage to God who created them, if you truly worship Him.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmcclvi{But if they become haughty (then remember) that those who are close to your Lord sing His praises night and day and do not grow weary of (doing so).\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmcclvii{It is among His signs that the earth you see all barren and desolate begins to stir and sprout when We send down rain upon it. Surely He who gives it life will also give life to the dead. Indeed He has power over everything.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmcclviii{Surely those who slander Our signs are not hidden from Us. Then, is he better who will be cast into Hell, or he who will come out safe on the Day of Resurrection? Do whatever you will, He sees whatsoever you do.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmcclix{Those who reject the Reminder when it has come to them (should know) that it is a Book inviolate.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmcclx{Falsehood cannot enter it from any side: It's a revelation from the all-wise and praiseworthy (God).\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmcclxi{Nothing is said to you which had not been said to other apostles before you. Surely your Lord is the lord of forgiveness, but also the lord of severe retribution.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmcclxii{If We had made it a discourse in an obscure tongue, they would have said: ``Why were its revelations not expounded distinctly? A foreign tongue and an Arab (audience)?" Say: ``For those who believe it is a guidance and a healing; but for those who do not believe it is a deafness in the ears, and a blindness. They are those one calls to from far away.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmcclxiii{Verily We gave Moses the Book; but they began to differ about it. If the Word of your Lord had not preceded it the matter would have been settled between them. They are still in doubt about it and uneasy.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmcclxiv{Whoever does good does so for himself, and whoever does wrong bears the guilt thereof. Your Lord does no wrong to His creatures.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmcclxv{He alone has knowledge of the Hour (of change): No fruit comes Out of its spathe, no female conceives or gives birth, but He has knowledge of it. The day He will call them (and ask): ``Where are the compeers (you ascribed to Me)?" They will answer: ``We profess to You not one of us can vouch for them."\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmcclxvi{And those they used to worship will leave them in the lurch, and they will realise there is no escape for them.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmcclxvii{Man never tires of praying for good; but if evil assails him he begins to despair.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmcclxviii{If We give him a taste of Our favour after some distress he has known, he says: ``It was my due. I cannot imagine the Hour will come. And even if I go back to my Lord, there will surely still be the best for me with Him." We shall tell those who do not believe what they used to do, and inflict on them a heavy punishment.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmcclxix{When We show Our favours to man he moves away and turns aside; but when in trouble he prays a great deal.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmcclxx{Say: ``Just think. If this is from God and you deny it, who will be in greater error than he who is in open dissent?"\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmcclxxi{We will show Our signs to them in the horizons of the external world and within themselves, until it becomes clear to them that it's the truth. Is your Lord not sufficient? He is a witness over all things.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmcclxxii{In truth they are in doubt that they will ever face their Lord. Do they not know that He surrounds all things?\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmcclxxiii{\basmalahen HA MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmcclxxiv{'Am Sin Qaf.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmcclxxv{So has God, all-mighty and all-wise, been revealing to you and to others before you.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmcclxxvi{Whatever is in the heavens and the earth, belongs to Him. He is all-high and supreme.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmcclxxvii{The skies are near to bursting asunder above them (for awe of Him), and the angels sing the praises of their Lord, imploring forgiveness for the dwellers of the earth. Is it not that God is forgiving and merciful?\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmcclxxviii{Those who have taken protectors other than Him, are watched over by God. It is not for you to be their guardian.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmcclxxix{We have, therefore, revealed to you the eloquent Qur'an that you may warn the people of the Metropolis, and those who live around it, of the Day of Gathering, of which there is no doubt, (when mankind would be assembled) some in Heaven, some in Hell.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmcclxxx{If God had pleased He would have made them one community of belief; but He admits whom He please to His grace; yet the sinners have neither friend nor helper.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmcclxxxi{Have they taken others beside Him as protectors? It is God who protects; it is He who gives life to the dead, for He has power over everything.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmcclxxxii{In whatever matter you disagree the ultimate judgement rests with God. This is God, my Lord; in Him have I placed my trust, if to Him I turn.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{Originator of the heavens and the earth, He has made your consorts from among you, and made pairs of cattle. He multiplies you in this way. There is no other like Him. He is all-hearing and all-seeing.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{He holds the keys of the heavens and the earth. He increases or decreases the provision of any one He will. He has knowledge of everything.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmcclxxxv{He has laid down for you the (same) way of life and belief which He had commended to Noah, and which We have enjoined on you, and which We had bequeathed to Abraham, Moses and Jesus, so that they should maintain the order and not be divided among themselves. Heavy is to idolaters what you invite them to. God chooses whom He please for Himself, and guides to Himself whoever turns to Him.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{Yet they did not differ about it until knowledge came to them, through rivalries among themselves. If the Word of your Lord, (staying) it for a time ordained, had not preceded it, the matter would have been settled among them. But those who came to inherit the Book after them are also in doubt and disturbed about it.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{Yet to that (law) you should call them, and be constant as commanded. Do not follow their passing whims, but say: ``I believe in whatever Scripture God has revealed, and I am commanded to act with equivalence among you. God is our Lord and your Lord. To us our actions, to you your deeds. There is no dispute between you and us. God will gather us all together, and to Him is our returning."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{As for those who argue in the matter of God after He has been fully acknowledged, their disputing has no force with their Lord. Upon them is (God's) anger, and the punishment for them will be severe.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmcclxxxix{It is God who has sent down the Book with the truth, and the Balance. How do you know the Hour is not near?\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmccxc{Only they who do not believe in it wish to hasten it; but those who believe are in fear of it, for they know it to be true. Surely those who are in doubt about the Hour are wandering far astray.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmccxci{God is gracious to His creatures, and bestows favours on whosoever He will. He is all-powerful and all-mighty.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmccxcii{Whoever desires the fruits of the Hereafter, We shall add to his fruit. As for him who desires the fruits of this world, We shall give to him of these, but he will have no share in the Hereafter.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmccxciii{Have they other associates who have prescribed another law for them which has not been dispensed by God? But for the decisive Word (of God) a sentence would have been passed amongst them. Surely there is a grievous punishment for the ungodly.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmccxciv{You will see the evil-doers full of fear of what they deserve, yet it will come to pass. But those who believe and do the right will be in gardens of Paradise. They will receive what they wish from their Lord; and this will be the greatest favour.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmccxcv{This is the good news that God gives to His creatures who believe and do good. Say: ``I ask no recompense of you for it other than obligations of relationship." We shall give more excellence to him who acquires excellence. Surely God forgives and accepts (gratitude).\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmccxcvi{Do they say he has fabricated a lie about God? He could have sealed your hearts if He pleased; but God blots out the false and vindicates the truth by His dispensations, for He knows the secrets of the hearts.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmccxcvii{It is He who accepts repentance from His creatures and forgives their trespasses, for He knows what you do.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmccxcviii{He answers (the prayers) of those who believe and do good, and gives them more of His bounty. But for the unbelievers there is severe punishment.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmccxcix{If God were to give in abundance to His creatures they would fill the earth with oppression. So He gives according to measure as He will. He knows (what is good for) His creatures. He is all-aware and all-seeing.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmccc{It is He who sends down rain when they had despaired of it, and showers His benevolence. He is the protector worthy of praise.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmccci{The creation of the heavens and the earth and all the living things dispersed in them, are a sign of His. He has the power to gather them together when He will.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmcccii{Whatever misfortune befalls you is a consequence of your deeds; yet He forgives much.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmccciii{You cannot thwart Him on the earth, and have no friend or helper apart from Him.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmccciv{Ships sailing in the ocean like ensigns are a sign of His.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmcccv{He could stop the wind if He pleased, then they would be stranded on its surface. Surely there are signs in this for every one who perseveres and is grateful.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmcccvi{Or He could wreck them for what they have done; yet there is much that He pardons.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmcccvii{Let those who dispute Our signs know that there is no way of escape for them.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmcccviii{Whatsoever you have been given is only this life's merchandise; but what is with God is better and more lasting for those who believe and place their trust in their Lord,\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmcccix{Who avoid the deadly sins, immoral acts, and forgive when they are angered,\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmcccx{Who obey the commands of their Lord and fulfil their devotional obligations, whose affairs are settled by mutual consultation, who spend of what We have given them,\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmcccxi{And those who defend themselves when they are wronged.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmcccxii{The retribution of evil is the equal of evil (done); yet those who forgive and rehabilitate will be rewarded by God. Verily He does not like those who do wrong.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmcccxiii{If one avenges himself after he has been wronged, there is no way of blaming him.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmcccxiv{Blame lies on those who oppress, and terrorise the land unjustly. For them there is painful punishment.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmcccxv{But he who bears with patience and forgives, surely complies with divine resolve.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmcccxvi{He whom God leads astray has no one except God to protect him. You should see the sinners when they face the punishment. They will say: ``Isn't there a way of going back?"\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmcccxvii{You should see them brought before the Fire, abject in disgrace, looking stealthily. And those who believe will say: ``They who forfeit their souls and families on the Day of Resurrection will really be losers." Is it not that sinners will suffer a lasting torment?\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmcccxviii{They will have no protector to help them other than God. He whom God allows to go astray has no way.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmcccxix{Hearken to your Lord before the Day arrives from God that will not be averted. You will have no place of refuge then nor time for denying.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmcccxx{If they turn away (you are not responsible); We have not appointed you a warden over them. Your duty is to deliver the message. When We let man taste of Our favours he begins to exult; but if misfortune befalls him, as a consequence of his own deeds, man is surely then ungrateful.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmcccxxi{To God belongs the kingdom of the heavens and the earth. He creates whatsoever He wills, bestows daughters on whosoever He will, and gives sons to whom He choose.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmcccxxii{On some He bestows both sons and daughters, and some He leaves issueless. He is all-knowing and all-powerful.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmcccxxiii{It is not given to man that God should speak to him except by suggestion or indirectly, or send a messenger to convey by His command whatsoever He please. He is all-high and all-wise.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmcccxxiv{So have We revealed to you the Qur'an by Our command. You did not know what the Scripture was before, nor (the laws of) faith. And We made it a light by which We show the way to those of Our creatures as We please; and you certainly guide them to the right path,\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmcccxxv{The path of God to whom belongs the kingdom of the heavens and the earth. And will not all things go back to God?\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmcccxxvi{\basmalahen HA MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmcccxxvii{I call to witness the lucent Book,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmcccxxviii{That We made it a distinctly lucid Qur'an that you may understand.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmcccxxix{It is inscribed in the original Book (of Books) with Us, sublime, dispenser of (all) laws.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmcccxxx{Should We have withdrawn the Reminder from you as you are a people who exceed the bounds?\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmcccxxxi{Many a prophet had We sent to the earlier communities,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmcccxxxii{But never did a prophet come at whom they did not scoff.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{So We destroyed far more powerful (nations) than they. The example of earlier people is there.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{If you ask them: ``Who created the heavens and the earth?" they will answer: ``The Mighty and All-knowing created them,"\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmcccxxxv{He who made the earth a bed for you, and laid out tracks upon it so that you may find the way;\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{Who sent down water in due measure from the sky, then quickened a region that was dead -- So shall We bring you forth --\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{He who created pairs of everything, and fashioned for you boats and beasts on which you ride,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{So that when you sit astride of them and think of the bounties of your Lord, you may say: ``All glory to Him who subjugated these for us. We were incapable of doing so.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmcccxxxix{Surely we have to go back to our Lord."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmcccxl{Yet they make some of His creatures His offspring! Man is surely most ungrateful.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmcccxli{Or has He taken from those He has created daughters for Himself, and assigned sons to you?\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmcccxlii{Yet when news of (a daughter) they had reserved for Ar-Rahman comes to one of them, his face is blackened (with shame), and he grieves in silence inwardly.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmcccxliii{Can one who has been raised on ornaments and cannot present her case coolly in a dispute (be associated with God?)\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmcccxliv{Yet they have made the angels, who are creatures of Ar-Rahman, females. Did they witness their creation? We shall record their testimony, and they will be interrogated.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmcccxlv{Yet they say: ``If Ar-Rahman had so pleased we would not have worshipped them." They have no knowledge of it in the least. They only make up lies.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmcccxlvi{Did We give them a Scripture before this to which they are holding fast?\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmcccxlvii{In fact they say: ``We found our fathers following a certain way, and are guided by their footprints."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmcccxlviii{Thus, We never sent an admonisher to a settlement before you but the decadent among them said. ``We found our fathers following this way, and we are walking in their footsteps."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmcccxlix{``Even if I bring you a better guidance," he rejoined, ``than the one you found your fathers on?" Still they said: ``We do not believe in what you have brought."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmcccl{Then We punished them. So look at the fate of those who denied.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmcccli{When Abraham said to his father and his people: ``I am rid of what you worship\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmccclii{Other than Him who created me. He will show me the right way."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmcccliii{This is the legacy he left to his descendants so that they may turn (to God).\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmcccliv{In fact, I allowed them and their fathers to enjoy this life till the truth, and the apostle preaching it lucidly, came to them.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmccclv{Yet when the truth had come to them, they said: ``This is sorcery. We shall never believe in it."\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmccclvi{They also said: ``Why was this Qur'an not sent down to some great man of the two cities?"\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmccclvii{Are they the ones who dispense the favour of your Lord? It is He who apportions the means of livelihood among them in this world, and raises some in position over the others to make some others submissive. The favours of your Lord are better than what they amass.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmccclviii{Had it not been that all people would become one community (of unbelievers), We might have given those who disbelieve in Ar-Rahman roofs of silver for their dwellings and (silver) stairs for mounting,\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmccclix{And doors (of silver) for their houses, (silver) couches for reclining,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmccclx{And ornaments of gold. But all this would have been nothing but the vanity of this world. The Hereafter with your Lord is for those who take heed for themselves and follow the straight path.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmccclxi{We shall attach to him who goes blind to the remembrance of Ar-Rahman a devil as companion, --\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmccclxii{Surely the (devils) obstruct them from the path, though they think they are rightly guided, --\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmccclxiii{Until when he comes before Us he will say (to the devil): ``Would to God there was a distance of the East and West between you and me, for you were an evil companion!"\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmccclxiv{But nothing will avail you on that day, for you were unjust, and you will be partners in the punishment.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmccclxv{Can you make the deaf to hear, or show the blind, and those lost in clear error, the way?\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmccclxvi{We shall punish them whether We take you away,\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmccclxvii{Or show you some of what We have promised them. They are certainly well within Our power.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmccclxviii{So hold fast to what has been revealed to you. You are truly on the right path.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmccclxix{It is a (source) of greatness for you and your people. You will surely be questioned about it.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmccclxx{Inquire of apostles We had sent before you if We appointed gods to be worshipped other than Ar-Rahman.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmccclxxi{We sent Moses with Our signs to the Pharaoh and his nobles. He said: ``I have been sent by the Lord of all the worlds."\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmccclxxii{But when he brought to them Our signs they laughed at them,\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmccclxxiii{(Even though) each miracle that We showed them was greater than the other. So We seized them with chastisement so that they may turn back.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmccclxxiv{But they said: ``O sorcerer, call on your Lord for us in accordance with the compact He has made with you. We shall certainly come to guidance."\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmccclxxv{Yet no sooner did We take away the affliction from them than they broke their pledge.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmccclxxvi{And the Pharaoh said to his people: ``O people, is not mine the kingdom of Egypt and these rivers that flow at my feet? Can you still not comprehend?\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmccclxxvii{Am I (not) better than him who is contemptible, and cannot even express himself clearly?\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmccclxxviii{Why were then no bracelets of gold shed upon him from above, or angels sent down as a retinue with him?"\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmccclxxix{Thus he made light (of the matter) to his people, and they obeyed him. They were certainly wicked.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmccclxxx{But when they roused Our anger We inflicted retributive punishment and drowned them all,\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmccclxxxi{And made them a precedent and example for posterity.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmccclxxxii{When the example of Mary's son is quoted before them, your people cry out at it,\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{And say: ``Are our deities better or he?" They say this only for disputing. Surely they are a contentious people.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{(Jesus) was only a creature whom We favoured and made an example for the children of Israel.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmmccclxxxv{If We pleased We could have put angels in place of you as trustees on the earth.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{He is certainly the sign of the Hour (of change). So have no doubt about it, and listen to me. This is the straight path.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{Let not Satan misdirect you. He is your open enemy.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{When Jesus came with the signs, he said: ``I have come to you with authority, and to explain some thing about which you are at variance. So fear God, and follow me.\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmmccclxxxix{Verily God is my Lord and your Lord; so worship Him. This is the straight path."\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmmcccxc{But the factions differed among themselves. Woe alas to the sinners for the torment of the grievous Day!\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmmcccxci{Are they waiting (for any thing) but the Hour (of Doom) which would descend upon them suddenly, and catch them unawares?\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmmcccxcii{Friends will turn into enemies on that day, except those who fear and follow the straight path.\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmmcccxciii{O My creatures, there will be no fear or regret\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmmcccxciv{For (those of) you on that day who believed in My revelations and submitted.\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmmcccxcv{(You will) enter the garden, you and your spouses, and be glad."\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmmcccxcvi{Golden platters and goblets will be passed around, and everything the heart desires and pleases the eye will be there, where you will abide for ever.\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmmcccxcvii{This is the Paradise you will inherit (as meed) for your deeds.\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmmcccxcviii{You will have fruits in abundance there to eat.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmmcccxcix{The sinners will certainly dwell for ever in the torment of Hell.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmmcd{It will not decrease for them; dumb with despair they will stay in it.\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmmcdi{We did not wrong them, they wronged themselves.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmmcdii{They will call (to the keeper of Hell-gate): ``O Malik, let your Lord decide our fate." He will answer: ``You are to stay."\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmmcdiii{We have brought to you the truth, but most of you despise the truth.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmmcdiv{Have they settled upon a plan? We shall also settle on one.\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmmmcdv{Or do they think We do not hear their secrecies and stealthy consultations? In fact, Our messengers who attend them record everything.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmmmcdvi{Say: ``If Ar-Rahman had a son I would have been the first of worshippers."\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmmmcdvii{All too glorious is He, Lord of the heavens and the earth, the Lord of all power, for what they ascribe to Him\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmmmcdviii{Leave them to their vain discoursing and horse-play till they come to meet their promised day (of reckoning).\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmmmcdix{He is God in heaven and God on earth, and He is all-wise and all-knowing.\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmmmcdx{Blessed be He, who holds the kingdom of the heavens and the earth and all that lies between them. He alone has knowledge of the Hour, and to Him will you return.\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmmmcdxi{Those they invoke apart from Him have no power of intercession, except those who testify to the truth and have knowledge.\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmmmcdxii{If you ask them who created them, they will answer: ``God." How then can they turn away?\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmmmcdxiii{And (the Prophet) will say: ``O Lord, these are certainly a people who do not believe."\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmmmcdxiv{Turn away from them and say: ``Peace." They will come to know soon.\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmmmcdxv{\basmalahen HA MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmcdxvi{The perspicuous Book is witness\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmcdxvii{(That) We sent it down one night of blessing -- so that We could warn --\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmcdxviii{On which all affairs are sorted out and decided\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmcdxix{As commands from Us. It is indeed We who send (messengers),\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmcdxx{A mercy from your Lord. Verily He is all-hearing and all-knowing,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmcdxxi{The Lord of the heavens and the earth and all that lies between them, if you really do believe.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmcdxxii{There is no god other than He, who gives you life and death, your Lord and the Lord of your fathers of old.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmcdxxiii{Yet they are lost in doubt and play.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmcdxxiv{So watch for the day when the sky begins to emit clear smoke,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmcdxxv{Which would envelope mankind. That would be a grievous affliction.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmcdxxvi{``O Lord, take away this torment from us," (they will pray); ``we have come to believe."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmcdxxvii{How can a warning benefit them? The Apostle who explained all things clearly had come to them,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmcdxxviii{But they turned away from him, and said: ``He is well-instructed, (but) possessed."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmcdxxix{If We remove the torment a little, you revert back (to misdeeds).\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmcdxxx{The day that We shall seize them with a grievous hold, We will indeed castigate them.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmcdxxxi{We had tried the people of Pharaoh before them. A respected prophet had come to them (saying):\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmcdxxxii{``Deliver the creatures of God to me. I am the trusted messenger sent to you.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{Do not think yourselves to be above God: I have come to you with clear authority.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{I have taken refuge in my Lord and your Lord against your stoning me to death.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmcdxxxv{If you do not believe in me, leave me alone."\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{Then he called to his Lord: ``These are a sinful people."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{``Journey by night with My devotees," (it was said); ``you will certainly be pursued.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{(Cross and) leave the sea undisturbed. The (pursuing) hosts will surely be drowned,"\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmcdxxxix{How many gardens and fountains did they leave behind,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmcdxl{And fields and stately mansions,\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmcdxli{And the comfort they enjoyed.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmcdxlii{Thus it was; and We passed them on to another people.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmcdxliii{Neither did the heavens weep for them, nor the earth, nor were they granted respite.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmcdxliv{So We saved the children of Israel from degrading suffering\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmcdxlv{They (had experienced) under the Pharaoh. He was certainly a tyrant, guilty of excess.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmcdxlvi{And We exalted them over the other people knowingly,\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmcdxlvii{And sent them tokens to bring out the best in them.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmcdxlviii{Even then they say:\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmcdxlix{``There is no dying for us but once; and we shall not be raised again.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmcdl{So bring our ancestors back, if you are truthful."\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmcdli{Are they better than the people of Tubba, and those who had lived before them, whom We destroyed as they were sinners?\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmcdlii{We have not created the heavens and the earth and all that lies between them, out of play.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmcdliii{We created them with definite purpose; but most of them do not understand.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmcdliv{The Day of Judgement is your promised day of meeting,\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmcdlv{The day when friend will help no friend in the least, nor will they be helped,\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmcdlvi{Apart from those to whom God is kind. He is all-mighty and all-merciful.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmcdlvii{The tree of Zaqqum will indeed be\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmcdlviii{The food of sinners.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmcdlix{It is like pitch. It will fume in the belly\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmcdlx{As does boiling water.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmcdlxi{``Seize him and drag him into the depths of Hell," (it will be said),\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmcdlxii{``Then pour over his head the torment of scalding water."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmcdlxiii{``Taste it," (they will be told). ``You were indeed the mighty and noble!\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmcdlxiv{This is certainly what you had denied."\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmcdlxv{Surely those who fear and follow the straight path will be in a place of peace and security\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmcdlxvi{In the midst of gardens and of springs,\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmcdlxvii{Dressed in brocade and shot silk, facing one another.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmcdlxviii{Just like that. We shall pair them with companions with large black eyes.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmcdlxix{They will call for every kind of fruit with satisfaction.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmcdlxx{There they will not know any death apart from the first death they had died, and will be kept safe from the torment of Hell\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxi{By the beneficence of your Lord. This will be the great success.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxii{Therefore We have made this (Qur'an) easy in your tongue. They may haply take a warning.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{So you wait. They are also waiting.\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{\basmalahen HA MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxv{The revelation of this Book is from God, the mighty and all-wise.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{Indeed there are signs for believers in the heavens and the earth.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{In creating you and spreading all the moving things (on earth) are signs for people firm of faith,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{As there are signs in the alternation of night and day, and in rain that God sends with which He revives the earth once dead, as there are in the changing of the winds, for people who can understand.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxix{These are revelations of God which we recite to you correctly: In what other lore but God and His manifestations would they then believe?\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxx{Alas the woe for every dissembling sinner\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{Who hears the revelations of God being recited to him, yet persists in denying with arrogance as though he had never heard them! So warn him of a painful punishment.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{When he comes to know something of Our messages he makes fun of them: For them is shameful punishment.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{There is Hell before them; and whatever they have earned will not avail them in the least, nor those whom they take as friends apart from God. There is great chastisement for them.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{This is guidance. Those who deny the revelations of their Lord will suffer a dreadful doom.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{It is God who subjugated the ocean for you so that ships may ply through it by His command, and you may seek His bounty, and may haply be grateful.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{He subjugated for you whatsoever is in the heavens and the earth, each and everything. Verily there are signs in this for those who reflect.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{Tell the believers to forgive those who do not fear the visitations of God, so that He may requite the people for their deeds.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{He who does good does so for himself; and he who does evil suffers the consequence thereof. You have then to go back to your Lord.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{We gave the children of Israel the Book, and the judgement and the prophethood, provided them with good things, favoured them over other people,\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmcdxc{And gave them a clear exposition of Our laws. And they did not differ until after knowledge came to them, through mutual jealousies. Verily your Lord will judge between them on the Day of Judgement in what they differed about.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmcdxci{We have put you on the right way in the matter (of divine law). So follow it, and do not follow the wishes of those who are ignorant.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmcdxcii{They will not avail you in the least against God. Surely the wicked are each other's friends, but God befriends those who fear and follow the right path.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmcdxciii{These are precepts of wisdom for men, and guidance and grace for people who believe with certainty.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmcdxciv{Do those who seek evil think that We shall make them equal in life and death to those who believe and do good? How bad is the judgement that they make!\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmcdxcv{God has created the heavens and the earth with reason, so that He may reward each soul in accordance with what it has done; and no wrong will be done to them.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmcdxcvi{Just think: Who apart from God can show the way to him who deifies his ego into his god, whom God allows to go astray knowingly, and seals his ears and heart, and covers over his eyes with a veil? Why then do you not contemplate?\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmcdxcvii{Yet they say: ``There is nothing but the life of this world. We die and we live, and only time annihilates us." Yet they have no knowledge of this: They only speculate.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmcdxcviii{When Our clear revelations are recited to them, their only argument is to say: ``Bring our ancestors back, if what you say is true."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmcdxcix{Say: ``God, who gives you life and makes you die, will (raise the dead) then gather you (and your ancestors) together on the Day of Resurrection of which there is no doubt." And yet most men do not understand.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmd{God's is the kingdom of the heavens and the earth. The day the Hour is proclaimed the liars will be losers.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmdi{You will see each community kneeling down; and each community will be summoned to its ledger (of good and evil deeds). You will receive upon that day your recompense for what you had done.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmdii{This, Our record, will speak about you truthfully. We had everything you did recorded in it.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmdiii{So, those who believed and did good things will be admitted to His favour by their Lord. This will be a clear triumph.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmdiv{As for the infidels, (it will be said): ``Were not My messages read out to you? But you behaved with self-conceit, and became a sinful people.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmdv{Whenever it was said: 'God's promise is certainly true, and there is no doubt about the Hour,' you replied: 'We know not what the Hour is. We have only a vague idea, but are not certain.'\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmdvi{The evil of what they had done will become clear to them, and they will be seized by what they had scorned.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmdvii{``We shall ignore you today," they will be told, ``as you had forgotten the meeting of this Day. Your dwelling place is Hell, and there is none to save you:\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmdviii{This because you laughed at God's revelations and were taken in by the life of the world." So they will neither be taken out of it, nor will be asked to seek God's favour on that day.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmdix{All praise be to God, Lord of the heavens, Lord of the earth, Lord of all the worlds.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmdx{His is the supremacy in the heavens and the earth; and He is the all-mighty and all-wise.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmdxi{\basmalahen HA MIM.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmdxii{The revelation of this Book is from God, the mighty and all-wise.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmdxiii{We have not created the heavens and the earth and all that lies between them but with a purpose for an appointed time. Yet the unbelievers turn away from the warning.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmdxiv{Say: ``Have you thought of those you invoke apart from God? Show me what they have created of the earth, or, do they have a share in the heavens? Bring me an earlier Book than this, or inherited knowledge, if you are truthful."\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmdxv{Who is more astray than he who calls on those, apart from God, who cannot answer their prayers till the Day of Resurrection, and are even unaware of being called.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmdxvi{When all men are gathered together (on that Day) they will become their enemies and deny their worship.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmdxvii{When Our clear revelations are read out to them, the infidels say of the truth, when it has come to them: ``This is pure magic."\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmdxviii{Do they say: ``He has fabricated it?" Tell them: ``If I have fabricated it, you have no power to save me from God. He knows what you are busy with concerning this. He is sufficient as witness between you and me; yet He is forgiving, ever-merciful."\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmdxix{Say: ``I am not a new Messenger to come, nor do I know what is to be done to me or you. I only follow what is revealed to me. My duty is only to warn you clearly."\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmdxx{Tell them: ``Think (of the consequence) if this is from God and you deny it when a witness from the people of Israel had testified to the like of it and come to believe, while you spurn it?" Assuredly God does not guide a wicked people.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmdxxi{Those who deny say of those who believe: ``Had there been any good in it they would not have preceded us in coming to it." Since they have not taken guidance from it, they will say: ``This is the same old lie."\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmdxxii{There was the Book of Moses before this, a guide and a mercy; and here is this Book confirming it in lucid language, warning those who are wicked, and giving happy tidings to the righteous.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmdxxiii{Surely for those who say, ``God is our Lord," and then remain firm, there is no fear or regret.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmdxxiv{They are men of Paradise where they will abide for ever as a recompense for what they had done.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmdxxv{We have enjoined on man to be good to his parents: His mother carries him in her womb with hardship, and gives birth to him in pain. Thirty months is the period of her carrying and weaning him. When he attains to manhood and the age of forty, he says: ``O Lord, guide me to thank You for the favours You have bestowed on me and my parents, and to do things good as may please You, and give me a righteous off-spring. I turn to You in penitence and submit."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmdxxvi{They are those from whom We accept the very best of what they have done, and overlook their faults. They will be among the inmates of Paradise: A true promise they have been made.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmdxxvii{But he who says to his parents: ``Shame on you: You intimidate me that I will be resurrected when many generations will have passed before me?" And (the parents) would implore God's help: ``Woe to you. You better believe. The promise of God is certainly true." Yet he answers: ``These are only fables of long ago."\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmdxxviii{They are those on whom the sentence of God would be justified as on communities of jinns and men before them. They will surely perish.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmdxxix{Each will have a position in accordance with his deeds; and no wrong will be done to them.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmdxxx{The day the unbelievers are brought to the Fire, (it will be said): ``You wasted all your good deeds in the life of the world, and enjoyed them to the full. You will now be requited with a shameful punishment, for you behaved with arrogance for no reason on the earth, and acted wickedly."\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmdxxxi{Remember (Hud) the brother of 'Ad. When he warned his people in Ahqaf -- though many a warner had come and gone before and after him: ``Do not worship any one but God, for I fear the punishment of an awful day for you,"\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmdxxxii{They said: ``Have you come to turn us away from our gods? Then bring upon us what you predict for us, if you are a man of truth."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmdxxxiii{He said: ``Only God has the knowledge. I only convey to you what I have been sent with. But I see you are a foolish people."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmdxxxiv{So when they saw it as a cloud advancing towards their valleys, they said: ``This is just a passing cloud that will bring us rain." ``No. It is what you were trying to hasten: The wind which carries the grievous punishment!\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmdxxxv{It will destroy everything at the bidding of its Lord." So in the morning there was nothing but their empty dwellings to be seen. That is how We requite the sinners.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmdxxxvi{We had strengthened them as We have not strengthened you, had given them ears and eyes and hearts; but nothing stood them in good stead, neither their ears nor eyes nor hearts, for they rejected the signs of God, and were seized by what they had mocked.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmdxxxvii{We have destroyed habitations all around you, having explained Our signs in different ways to them that they may turn back.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmdxxxviii{Why then did the gods they had taken apart from God as propitiators, not come to their aid? In fact they strayed away from them. It was all a lie what they had contrived!\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmdxxxix{And (remember), when We turned a company of jinns towards you to listen to the Qur'an, they arrived when it was being recited, and they said: ``Keep silent." When it was over they came back to their people, warning them:\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmdxl{``O our people:" they said: ``we have listened to a Book which has come down after Moses, confirming what was (sent down) before it, showing the way to the truth and a path that is straight.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmdxli{O our people, hearken to the summoner of God, and believe in him, so that He may forgive you your sins and save you from a painful doom.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmdxlii{He who does not listen to the summoner of God cannot weaken (the power of) God on earth, nor will he have protectors other than Him. They are clearly in the wrong."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmdxliii{Do they not realise that God who created the heavens and the earth, and did not tire creating them, is able to bring the dead to life? And why not? He has the power over everything.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmdxliv{The day the unbelievers will be stood before the Fire, (they will be asked:) ``Is this not the reality?" They will answer: ``In truth, by our Lord!" It will be said: ``Then taste the torment of what you had denied."\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmdxlv{So bear with patience, as the apostles who were constant, bore; and do not be hasty (in demanding punishment) for them. On the day they see what they had been foretold, (they will realise) that they did not stay in the world but only an hour of the day. This is the message to be conveyed: Shall any perish but the ungodly?\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmdxlvi{\basmalahen THOSE WHO DISBELIEVE and obstruct (others) from the way of God will have wasted their deeds.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmdxlvii{But those who believe and do the right, and believe what has been revealed to Muhammad, which is the truth from their Lord, will have their faults condoned by Him and their state improved.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmdxlviii{That is because those who refuse to believe only follow what is false; but those who believe follow the truth from their Lord. That is how God gives men precepts of wisdom.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmdxlix{So, when you clash with the unbelievers, smite their necks until you overpower them, then hold them in bondage. Then either free them graciously or after taking a ransom, until war shall have come to end. If God had pleased He could have punished them (Himself), but He wills to test some of you through some others. He will not allow the deeds of those who are killed in the cause of God to go waste.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmdl{He will show them the way, and better their state,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmdli{And will admit them into gardens with which he has acquainted them.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmdlii{O you who believe, if you help (in the cause of) God He will surely come to your aid, and firmly plant your feet.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmdliii{As for the unbelievers, they will suffer misfortunes, and their deeds will be rendered ineffective.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmdliv{That is so as they were averse to what has been revealed by God, and their actions will be nullified.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmdlv{Have they not journeyed in the land and seen the fate of those before them? Destroyed they were utterly by God; and a similar (fate) awaits the unbelievers.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmdlvi{This is so for God is the friend of those who believe while the unbelievers have no friend.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmdlvii{Verily God will admit those who believe and do the right into gardens with streams of water running by. But the unbelievers revel and carouse and subsist like beasts, and Hell will be their residence.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmdlviii{How many were the habitations, mightier than your city which has turned you out, which We destroyed; and they did not have a helper.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmdlix{Can one who stands on a clear proof from his Lord, be like one enamoured of his evil deeds and follows his inane desires?\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmdlx{The semblance of Paradise promised the pious and devout (is that of a garden) with streams of water that will not go rank, and rivers of milk whose taste will not undergo a change, and rivers of wine delectable to drinkers, and streams of purified honey, and fruits of every kind in them, and forgiveness of their Lord. Are these like those who will live for ever in the Fire and be given boiling water to drink which will cut their intestines to shreds?\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmdlxi{There are some who listen to you; but as soon as they go from you they say to those who were given knowledge: ``What is this he is saying now?" They are those whose hearts have been sealed by God, and they follow their own lusts.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmdlxii{But those who are rightly guided will be given greater guidance by Him, and they will have their intrinsic piety.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmdlxiii{Do they wait for any thing but the Hour (of change), that it may come upon them suddenly? Its signs have already appeared. How then will they be warned when it has come upon them?\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmdlxiv{Know then, therefore, there is no god but He, and ask forgiveness for your sins and those of believing men and women. God knows your wanderings and your destination.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmdlxv{Those who believe say: ``How is it no Surah was revealed?" But when a categorical Surah is revealed that mentions war, you should see those who are sceptical staring at you like a man in the swoon of death. Alas the woe for them!\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmdlxvi{Obedience and modest speech (would have been more becoming). And when the matter has been determined it is best for them to be true to God.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmdlxvii{Is it possible that if placed in authority you will create disorder in the land and sever your bonds of relationship?\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmdlxviii{They are those who were condemned by God, whose ears were blocked by Him and their eyes blinded.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmdlxix{Do they not ponder on what the Qur'an says? Or have their hearts been sealed with locks?\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmdlxx{Those who turn their backs after the way of guidance has been opened to them, have been surely tempted by Satan and beguiled by illusory hopes.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmdlxxi{This was so because they said to those who disdain what God has revealed: ``We shall obey you in some things." But God knows their secret intentions well.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmdlxxii{How will it be when the angels draw out their souls striking their faces and their backs?\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmdlxxiii{Because they followed what displeases God, and they were averse to pleasing Him. So We nullified their deeds.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmdlxxiv{Do they whose minds are filled with doubt, think that God will not expose their malice?\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmdlxxv{Had We pleased We could have shown them to you that you could know them by their marks, and recognise them from the way they twist their words. Yet God knows all your deeds.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmdlxxvi{We shall try you in order to know who are the fighters among you, and who are men of fortitude, and verify your histories.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmdlxxvii{Surely those who do not believe, and obstruct others from the path of God, and oppose the Prophet after the way of guidance has been opened to them, will not hurt God in the least, and He will nullify all that they have done.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmdlxxviii{O you who believe, obey God and the Prophet, and do not waste your deeds.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmdlxxix{Those who do not believe and obstruct others from the way of God, and die disbelieving, will not be pardoned by God.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmdlxxx{So do not become weak-kneed and sue for peace, for you will have the upper hand as God is with you and will not overlook your deeds.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmdlxxxi{Verily the life of this world is no more than a sport and frivolity. If you believe and fear God, he will give you your reward, and will not ask for your possessions.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmdlxxxii{If He asks for all you possess and insist upon it, you will become niggardly, and it will bring out your malevolence.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{Beware! You are called to spend in the way of God, yet some among you close their fists. But he who is niggardly is so for his own self: God is above need, and it is you who are needy. If you turn away then God will bring other people in your place who, moreover, will not be like you.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{\basmalahen WE HAVE GIVEN you a splendent victory\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmdlxxxv{That God may save you from earlier and subsequent blames, and complete His favours on you, and guide you on the straight path,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{And help you with surpassing help.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{It is He who sent down the sense of security into the hearts of believers so that their faith may increase with belief, -- God's are the armies of the heavens and the earth; and God is all-knowing and all-wise; --\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{And that He may admit men and women who believe into gardens with rivers running by, to live for ever there, and absolve their evil, -- This, in the sight of God, will be the great fulfilment --\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmdlxxxix{And that He may punish men and women (who are) hypocrites, and idolaters and idolatresses who entertain evil notions of God: It is against them that the wheel of misfortune will turn, and God will be wroth with them, and condemn them. For them He has prepared Hell, an evil destination!\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmdxc{For God's are the armies of the heavens and the earth; and God is all-knowing and all-wise.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmdxci{We have sent you as witness (of the truth) and harbinger of good news and a warner,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmdxcii{So that (men) may believe in God and His Apostle, and honour Him and revere Him, and sing His praises morning and evening.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmdxciii{Those who swear allegiance to you indeed swear allegiance to God; and God's protection is over them. Then whosoever breaks the promise breaks it to his own loss; but whosoever fulfills the promise made to God will receive a great reward from Him.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmdxciv{The Arabs of the desert who had stayed behind will now say to you: ``We were occupied with our flocks and herds and families, so ask forgiveness for us. They say with their tongues what is not in their hearts. Tell them: ``Who can prevail with God for you if He wish you harm or benefit? Surely God is well aware of what you do.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmdxcv{In fact you imagined that the Prophet and the faithful would never come back home; and this seemed pleasing to your hearts, and you entertained evil thoughts. You are a people lost.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmdxcvi{He who does not believe in God and His Apostle (should know) We have prepared for unbelievers a blazing fire."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmdxcvii{To God belongs the kingdom of the heavens and the earth; He may forgive whosoever He please, and afflict whosoever He will. Yet God is forgiving and kind.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmdxcviii{Those who had stayed behind will say: ``When you depart for taking the spoils, allow us to follow you." They wish to change the word of God. Tell them: ``You will not follow us. That is what God has already said before." They will say: ``You are envious of our gain." The fact is they understand but little.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmdxcix{Say to the desert Arabs who had stayed behind: ``You will be called against a formidable people. You will fight them till they surrender. If you obey, then He will give you a good reward; but if you turn back, as you had done before, He will punish you with a grievous affliction."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmdc{It is not binding on the blind, the lame or the sick (to follow this command); but those who obey God and His Apostle will be admitted by God to gardens with running streams; but those who turn back will suffer a painful doom.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmdci{God was pleased with the believers when they swore allegiance to you under the tree, for He knew well what was in their hearts, and sent down tranquility on them, and rewarded them with an expeditious victory\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmdcii{And the many spoils that they were to take. God is all-mighty and all-wise.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmdciii{God had promised you many spoils that you would capture; so He gave this soon enough to you, and stayed the hands of men from you that it may serve as a sign for believers, and guide you on the straight path;\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmdciv{And other (benefits) which you have not yet obtained, are within the compass of God, for God has power over everything.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmdcv{Had the unbelievers fought you they would have turned their backs and not found a protector or helper.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmdcvi{This is the law of God, effective as before: You will not find any change in the law of God.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmdcvii{It was He who restrained their hands from you in the heart of Makkah, and your hands from them, after He had given you victory over them, as God sees all that you do.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmdcviii{It were those who disbelieved who hindered you from (going to) the Holy Mosque, preventing your offerings from arriving at the place of sacrifice. Had it not been for (the presence of) believers, men and women, (among the unbelievers) of whom you were unaware, and whom you might have trampled and thus incurred guilt unknowingly on account of them, (the matter would have been settled). (But this was not done) so that God may admit into His favour whom He willed. If these (believers) had been separated from them, He would have inflicted a grievous punishment on the unbelievers.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmdcix{When the unbelievers fostered a sense of honour in their hearts, a sense of pagan honour, God sent down a sense of tranquility on His Apostle and the believers, and obliged them to an act of self-restraint, for they were deserving and worthy of it. God is cognisant of everything.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmdcx{God has truly made the vision of His Apostle come true: You will surely enter the Holy Mosque in security if God please, without any fear, having shaved your heads and cut your hair. He knew what you did not know, and has vouchsafed you, apart from this, a victory near at hand.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmdcxi{It is He who has sent His Apostle with the guidance and the true faith, so that He may exalt it over every other creed. God is sufficient as a witness.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmdcxii{Muhammad is the Prophet of God; and those who are with him are severe with infidels but compassionate among themselves. You may see them kneeling and bowing in reverence, seeking His favour and acceptance. Their mark is on their foreheads from the effect of prostrations. Their likeness in the Torah, and their likeness in the Gospel, is like a seed that sends out a stalk, then makes it firm, and it becomes strong and rises straight upon its stem, gladdening the cultivator's heart, in order to fill the unbelievers with dismay. God has promised those who believe and do the right forgiveness and a great reward.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmdcxiii{\basmalahen O YOU WHO believe, do not forestall the judgements of God and His Apostle, and have fear of God. Verily God hears all and knows everything.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmdcxiv{O you who believe, do not raise your voices above the voice of the Prophet, and do not speak loudly to him as you do with one another lest your deeds are nullified unconsciously.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmdcxv{They who speak in a low voice in the presence of God's Apostle, have had their hearts tried by God for reverence. There is forgiveness for them and a great reward.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmdcxvi{Many of those who call you from outside the apartments are not considerate.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmdcxvii{If they had waited for you to come out it would have been better for them. But God is forgiving and kind.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmdcxviii{O you who believe, if a dissolute person brings some news, verify it first lest you attack a people ignorantly and later regret what you had done.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmdcxix{Know that the Apostle of God is among you: If he agreed with you in most matters you would surely come to grief. But God has made faith more desirable to you, and attractive to your hearts, and rendered disbelief and sin and disobedience repugnant. They are those who are well directed\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmdcxx{By God's benevolence and His grace. God is all-knowing and all-wise.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmdcxxi{If two groups of believers come to fight one another, promote peace between them. Then if one of them turns aggressive against the other, fight against the aggressive party till it returns to God's authority. If it does so, make peace among them equitably and be impartial. Verily God loves those who are just.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmdcxxii{The faithful are surely brothers; so restore friendship among your brothers, and fear God that you may be favoured.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmdcxxiii{O you who believe, men should not laugh at other men, for it may be they are better than them; and women should not laugh at other women, for they may perhaps be better than them. Do not slander one another, nor give one another nick-names. After believing, it is bad to give (another) a bad name. Those who do not repent behave wickedly.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmdcxxiv{O you who believe, avoid most suspicions: Some suspicions are indeed sins. So do not pry into others' secrets and do not backbite. Would any of you like to eat a dead brother's flesh? You would surely be revolted by it Then fear God. He is certainly forgiving and kind.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmdcxxv{O men, We created you from a male and female, and formed you into nations and tribes that you may recognise each other. He who has more integrity has indeed greater honour with God. Surely God is all-knowing and well-informed.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmdcxxvi{The Arabs of the desert say: ``We believe." Tell them: ``You do not believe. Better say: 'We submit'; for belief has not yet penetrated your hearts." If you begin to obey God and His Apostle, He will not withhold the least (of the recompense) of your labour. Verily God is forgiving and kind."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmdcxxvii{They alone are believers who come to believe in God and His Apostle, then never doubt again, and struggle wealth and soul in the way of God. They are the truthful and sincere.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmdcxxviii{Say: ``Are you trying to convince God of your faithfulness? But God knows all there is in the heavens and the earth, for God has knowledge of everything."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmdcxxix{They impress upon you that they have submitted. Tell them: ``Do not favour me with your submission. In fact God has favoured you by showing you the way to belief, if you are men of truth."\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmdcxxx{Verily God knows the unknown of the heavens and the earth; and God perceives all you do.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmdcxxxi{\basmalahen QAF. I CALL to witness the glorious Qur'an.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmdcxxxii{They are rather surprised that a warner from among themselves has come to them. So the unbelievers say: ``This is astonishing:\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{When we are dead and turned to dust, this returning (to life) is most far-fetched."\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{We know what the earth consumes of them, for We have the Book that preserves everything.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmdcxxxv{But no! They called the truth a lie when it came to them; so they are in a confused state.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{Have they not looked at the sky above them, how We have fashioned and adorned it, and it has no flaw?\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{We stretched the earth and placed upon it firm stabilisers and We made every kind of splendid thing to grow upon it\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{As instruction and reminder to every penitent creature.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmdcxxxix{And We send down water as a blessing from the sky, and grow gardens with it and the grain for harvest,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmdcxl{And tall date-palms with their spathes pile on pile\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmdcxli{As a provision for men, and enlivened a region that was dead. Even thus will be the life after death.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmdcxlii{The people of Noah, Ar-Rass and Thamud denied before you,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmdcxliii{As did the people of 'Ad and Pharaoh and the brethren of Lot,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmdcxliv{And the dwellers of the Wood and people of Tubba'. Each of them denied the apostles. So My threat became a reality.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmdcxlv{Were We exhausted by the act of the first creation? And yet they are confused about a new creation.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmdcxlvi{He created man and surely know what misdoubts arise in their hearts; for We are closer to him than his jugular vein.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmdcxlvii{When the two (angels) who keep the account, one sitting on the right, one on the left, take it down,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmdcxlviii{There is not a word he utters but an observer is ready (to make note of it).\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmdcxlix{The palsy of death will surely come. This is what you wished to avert.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmdcl{And the trumpet blast will sound: It would be the Day of Doom.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmdcli{Each soul will come with a driver and a witness.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmdclii{(And the driver will say:) ``You were oblivious of this, so we have removed the veil, and how keen is your sight today!"\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmdcliii{His companion will say: ``Here is (the record) I have ready with me."\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmdcliv{``Cast each stubborn unbeliever into Hell," (they will be told),\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmdclv{``Every obstructor of good, transgressor, and the sceptic,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmdclvi{Who had set up another god with God. Cast him into severe torment."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmdclvii{His companion will say: ``O Lord, I did not lead him to wickedness, but he was himself far astray."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmdclviii{``Do not argue in My presence. I had announced the promise of doom in advance.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmdclix{There is no changing of My word, nor am I unjust to My creatures."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmdclx{We shall ask Hell that day: ``Are you full?" It will answer: ``Are there still more?"\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmdclxi{And Paradise will be brought near, not far from those who took heed for themselves and feared God.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmdclxii{``This is what you had been promised," (will be said) to every penitent who remembered (his duty),\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmdclxiii{Who feared Ar-Rahman in secret, and came with a penitent heart:\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmdclxiv{``Enter it in peace. This is the day of life abiding."\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmdclxv{Theirs will be whatsoever they wish: And with Us there is more.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmdclxvi{How many generations have We destroyed before them who were mightier in power than they. Then they searched throughout the land to see if there was a way of escape.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmdclxvii{Surely there is a reminder in this for whosoever has a heart (to feel), or takes heed.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmdclxviii{We created the heavens and the earth and all that lies between them, in six spans, and no weariness came upon Us.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmdclxix{So you bear with patience what they say, and sing the praises of your Lord before the rising of the sun and its setting,\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmdclxx{And glorify Him for some portion of the night, and additional adorations.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmdclxxi{Take heed that the day the crier calls from a place close (to every one),\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmdclxxii{The day they actually hear the blast, will be the Day of rising of the dead.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmdclxxiii{We are the one who give life and death, and to Us will be the destination.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmdclxxiv{The day the earth will split asunder they will come out hurriedly. This gathering together is easy for Us.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmdclxxv{We are cognisant of what they say; but it is not for you to compel them. So keep on reminding through the Qur'an whoever fears My warning.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmdclxxvi{\basmalahen I CALL TO witness those who scatter (dust) by dispersing,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmdclxxvii{And those who bear the load (of rain),\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmdclxxviii{And those who move (on the water) gently,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmdclxxix{And those who distribute (it) by command,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmdclxxx{Verily the promise made to you is true:\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmdclxxxi{The Judgement will indeed take place.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmdclxxxii{The heavens webbed-with-tracks is witness\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{You are surely caught in contradictions.,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{From which only he turns who is turned away.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmdclxxxv{Perish will those who just guess and speculate,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{Who are lost in deception.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{They ask: ``When is the Day of Judgement?" --\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{The day they will be burnt in the Fire,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmdclxxxix{(And told:) ``Taste your punishment. This is what you were trying to hasten."\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmdcxc{Surely those who fear God and follow the straight path will be amidst gardens and fresh springs of water,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmdcxci{Receiving what is given them by their Lord. They were surely the virtuous before this.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmdcxcii{They slept little in the night,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmdcxciii{And every morning asked forgiveness,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmdcxciv{In whose wealth the suppliant and the deprived had a share.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmdcxcv{There are signs in the earth for those who are firm in their faith,\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmdcxcvi{And within yourselves. Can you not perceive?\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmdcxcvii{There is in the heavens your sustenance, and whatever has been promised you.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmdcxcviii{By the Lord of the heavens and the earth, this is certainly true even as you speak.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmdcxcix{Has the story of Abraham's honoured guests come to you?\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmdcc{When they came to him, they said: ``Peace." He answered: ``Peace." They were a people he did not recognise.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmdcci{So he hurried to the house and brought a fatted calf,\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmdccii{And placing it before them said: ``Won't you eat?"\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmdcciii{He felt afraid of them; but they said: ``Have no fear," and gave him the good news of a wise son.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmdcciv{His wife came out lamenting, striking her forehead, and said: ``I, am old and barren woman?"\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmdccv{They said: ``Thus said your Lord. He is indeed all-wise and all-knowing."\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmdccvi{He said: ``What is then your business, O messengers?"\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmdccvii{They said: ``We have been sent to a wicked people\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmdccviii{So as to let loose clods of clay on them\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmdccix{Marked by your Lord for those who waste their substance."\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmdccx{So We evacuated everyone who was a believer there,\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmdccxi{But did not find more than a single family of believers.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmdccxii{We left a sign in this for those who fear the grievous punishment,\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmdccxiii{As (there was) in Moses when We sent him to the Pharaoh with clear authority.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmdccxiv{But he turned to his counsellors, and said: ``He is a magician or lunatic."\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmdccxv{So We seized him and his armies, and threw them into the sea, for he was worthy of blame.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmdccxvi{In 'Ad (also is a sign), when We sent a blasting wind against them,\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmdccxvii{Which turned everything it touched to ashes.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmdccxviii{And in Thamud, when We said to them: ``Enjoy yourselves for a while;"\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmdccxix{But they disobeyed the command of their Lord; so they were destroyed by a thunderbolt, and they could only gape,\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmdccxx{And neither stand up nor defend themselves.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmdccxxi{(So had We destroyed) the people of Noah before them: They were surely a sinful people.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmdccxxii{We built the heavens by Our authority; and We are the Lord of power and expanse.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmdccxxiii{We spread the earth a carpet; what comfort We provide!\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmdccxxiv{And We created pairs of everything that you may contemplate.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmdccxxv{So turn to God. I give you a clear warning from Him.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmdccxxvi{Do not set up another god with God. I give you a clear warning from Him.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmdccxxvii{Even thus no apostle came to those before them but they said: ``He is a sorcerer or a mad man."\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmdccxxviii{Is this the legacy they have passed down from one to the other? In fact, they are a rebellious people.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmdccxxix{Turn away from them. You will not be blamed.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmdccxxx{But go on reminding them, as reminding benefits the believers.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmdccxxxi{I have not created the jinns and men but to worship Me.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmdccxxxii{I want no sustenance from them nor do I want them to feed Me.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{God is certainly the great provider, Lord of strength and power.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{Those who do wrong will indeed come to the same end as their fellows (of old). So let them not ask Me to hasten (the punishment).\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmmdccxxxv{Alas the woe for those who refuse to believe in the Day which has been promised them.\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{\basmalahen I CALL TO witness the Mount Sinai,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{And the Scripture inscribed\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{On a parchment scroll unrolled,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmdccxxxix{The house ever-peopled,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmdccxl{The roof raised high,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmdccxli{And the swollen sea,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmdccxlii{The punishment of your Lord is certain to come.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmdccxliii{There is none who could avert it.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmdccxliv{The day the sky will tremble,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmdccxlv{The mountains move and fly away,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmdccxlvi{Will be the day of woe for those\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmdccxlvii{Who, ignoring the Reality, engage in pleasantries.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmdccxlviii{The day they are dragged and pushed into Hell,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmdccxlix{(And told:) ``This is the fire which you denied.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmdccl{Is it magic, or you cannot see?\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmdccli{Roast in it. Bear it with patience or impatience, it will be the same for you. You will be requited for what you had done."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmdcclii{Those who fear God and follow the straight path will surely be in gardens and in bliss,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmdccliii{Rejoicing at what their Lord has given them; and their Lord will preserve them from the torment of Hell.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmdccliv{``Eat and drink with relish," (they will be told), (as recompense) for what you had done."\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmdcclv{They would recline on couches set in rows, paired with fair companions (clean of thought and) bright of eye.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmdcclvi{And those who believed, and whose progeny also followed them in their faith, will be united with their offspring. We will not deprive them of their labour in the least. Every man is bound to what he does.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmdcclvii{We shall give them fruits and meats, and what they desire.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmdcclviii{They will exchange cups of wine free of (incitement to) pleasantry or sin.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmdcclix{And young attendants like pearls within their shells, will go round.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmdcclx{They will ask each other questions,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmdcclxi{Saying: ``We were also once full of fear at home.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmdcclxii{But God has been gracious to us, and has saved us from the torment of scorching wind.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmdcclxiii{We used to pray to Him erstwhile; He is the just and merciful.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmdcclxiv{Remind them, therefore, that by the grace of your Lord you are neither a soothsayer nor possessed.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmdcclxv{Do they say: ``He is a poet for whom we expect an adverse turn of fortune?"\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmdcclxvi{Tell them: ``Keep on expecting, I am expecting with you."\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmdcclxvii{Does their reasoning prompt them to this, or they are a people rebellious?\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmdcclxviii{Or do they say: ``He has fabricated it?" In fact, they will never believe.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmdcclxix{So let them bring a discourse like it, if they are truthful\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmdcclxx{Or were they created of themselves? Or are they the creators?\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxi{Or have they created the heavens and the earth? In fact they are certain of nothing.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxii{Do they possess the treasures of your Lord? Or are they the treasurers?\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{Or do they have a ladder (climbing which) they can hear (the secrets of heaven)? Let one who has heard then bring a clear proof.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{Has (God) daughters and they sons?\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxv{Or do you demand any wages from them so that they are burdened with expense?\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{Or do they have knowledge of the Unknown which they write down?\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{Or do they want to stage a deception? -- Then only those who do not believe will be the ones who will be tricked.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{Or do they have a god apart from God? He is too exalted for what they associate with Him!\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxix{If they should see a segment falling from the sky, they would say: ``It is only a massive cloud."\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxx{So, leave them until they face their day (of doom) when they will be stunned.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{Their deception will not avail them in the least on that day, nor will they be helped.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{Surely there are other torments besides this for those who are wicked, though most of them do not know.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{Await the judgement of your Lord, for you are always before Our eyes, and glorify your Lord with praises when you rise,\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{And glorify Him in the night and when the stars begin to wane.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{\basmalahen I CALL TO witness the star of the pleiades when it has dipped\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{That your companion is not confused, nor has he gone astray,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{Neither does he speak of his own will.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{This is only revelation communicated,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{Bestowed on him by the Supreme Intellect,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmdccxc{Lord of power and wisdom. So he acquired poise and balance,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmdccxci{And reached the highest pinnacle.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmdccxcii{Then he drew near and drew closer\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmdccxciii{Until a space of two bow (arcs) or even less remained,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmdccxciv{When He revealed to His votary what He revealed.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmdccxcv{His heart did not falsify what he perceived.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmdccxcvi{Will you dispute with him what he saw?\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmdccxcvii{He saw Him indeed another time\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmdccxcviii{By the Lote-tree beyond which none can pass,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmdccxcix{Close to which is the Garden of Tranquility,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmdccc{When the Lote-tree was covered over with what it was covered over;\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmdccci{Neither did sight falter nor exceed the bounds.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmdcccii{Indeed he saw some of the greatest signs of His Lord.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmdccciii{Have you considered Lat and 'Uzza,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmdccciv{And Manat, the other third (of the pagan deities)?\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmdcccv{Are there sons for you, and daughters for Him?\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmdcccvi{This is certainly an unjust apportioning.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmdcccvii{These are only names which you and your fathers have invented. No authority was sent down by God for them. They only follow conjecture and wish-fulfilment, even though guidance had come to them already from their Lord.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmdcccviii{Can ever man get what he desires?\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmdcccix{To God belong the End and the Beginning.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmdcccx{Many as the angels be in heaven their intercession will not avail in the least without God's permission for whomsoever He please and approve.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmdcccxi{Those who do not believe in the Hereafter give the angels names of females.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmdcccxii{Yet they have no knowledge of this, and follow nothing but conjecture, but conjecture cannot replace the truth.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmdcccxiii{So you turn away from him who turns away from Our rememberance and wants nothing but the life of this world:\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmdcccxiv{This is the farthest limit of their knowledge. Surely your Lord alone knows best who has strayed away from the path and who has come to guidance.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmdcccxv{To God belongs whatever is in the heavens and the earth, that He may requite those who do evil, in accordance with their deeds, and those who do good with good.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmdcccxvi{As for those who avoid the greater sins and shameful acts, except minor trespasses, your Lord's forgiveness surely has great amplitude. He is fully knowledgeable of you as He produced you from the earth, and since you were a foetus in your mother's womb. So do not assert your goodness; he is better who takes heed and preserves himself.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmdcccxvii{Have you seen him who turns his back,\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmdcccxviii{Who gives but little, and is niggardly?\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmdcccxix{Has he knowledge of the Unknown that he perceives everything?\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmdcccxx{Has he not heard what is contained in the Book of Moses,\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxi{And of Abraham who fulfilled his trust? --\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxii{That no one who carries a burden bears another's load;\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{That a man receives but only that for which he strives;\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{That his endeavours will be judged,\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxv{And only then will he receive his recompense in full;\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{And that to your Lord is your returning;\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{That it is He who makes you happy and morose,\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{And He who ordains death and life;\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxix{That He created pairs, male and female,\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxx{From a drop of semen when emitted;\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{That the second creation is incumbent on Him;\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{That it is He who makes you rich and contented;\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{That He is the Lord of Sirius;\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{That it was He who destroyed the 'Ad of old,\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{And Thamud, and did not leave them,\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{Like the people of Noah before them, who were surely oppressors and rebellious;\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{And He overthrew the Cities of the Plain,\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{So that they were covered over by what they were covered over.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{How many favours of your Lord will you then deny?\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmdcccxl{He who warns you is one of the warners of old.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmdcccxli{What is to come is imminent.\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmmdcccxlii{There is no one to unveil it apart from God.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmmdcccxliii{Are you astonished at this news,\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmmdcccxliv{And keep laughing and do not weep,\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmmdcccxlv{Indulging in pleasantries?\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{Bow instead in adoration before God and worship Him.\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{\basmalahen THE HOUR HAS come and split is the moon.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{But if they see a sign they turn away, and say: ``This is the same old lie continuing,"\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmdcccxlix{And deny, and follow their own vain desires; but every matter is determined at its time.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmdcccl{Messages deterring them from evil had come to them,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmdcccli{Containing consummate wisdom; yet warnings were of no avail.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmdccclii{So turn away from them. When on the Day the crier calls to the painful business,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmdcccliii{They will come out of the graves with downcast eyes like an expanding swarm of locusts.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmdcccliv{They will hasten forward to the caller, gazes fixed. And the unbelievers will say: ``This is the day of untold woe."\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmdccclv{The people of Noah had denied before them, and had called Our votary a liar, and said: ``He is possessed," and repulsed him.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmdccclvi{So he prayed to his Lord: ``I am helpless, deliver me."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmdccclvii{And We opened up the flood gates of the sky with water pouring down in torrents,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmdccclviii{And We opened up the springs of the earth; and the waters met for a decreed end.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmdccclix{But We bore him on a (vessel made) of planks and oakum,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmdccclx{Which sailed right under Our eyes: A recompense for him who had been denied.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmdccclxi{And We left it as a sign. Is there anyone who will be warned?\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmdccclxii{How was then My punishment and My commination!\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmdccclxiii{Easy have We made the Qur'an to understand: So is there any one who will be warned?\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmdccclxiv{The 'Ad had also disavowed. How was then My punishment and My commination!\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmdccclxv{We let loose against them a violent roaring wind on a day of ill omen, continuous,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmdccclxvi{Which snatched away men as though they were palm trees pulled out by the roots.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmdccclxvii{How was then My punishment and My commination!\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmdccclxviii{Easy have We made the Qur'an to understand: So is there any one who will pay heed?\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmdccclxix{The Thamud rejected the warnings,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmdccclxx{And said: ``Should we follow only one man among us? In that case we shall he in error and insane.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxi{Was he the one of all of us to have been given the exposition? He is surely an impudent liar."\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxii{``Tomorrow they will know who is the impudent liar!\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{We shall send the she-camel to try them. So watch them, and be constant.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{Tell them that the water is to be apportioned between them (and her); and every turn of drinking will be fixed (for each)."\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxv{But they called their commander, who seized and hamstrung her.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{How was then My punishment of which they had been warned?\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{We sent a single blast against them, and they were reduced to husks of a decayed fence.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{Easy have We made the Qur'an to understand: So is there any one who will be warned?\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxix{The people of Lot rejected the warnings.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxx{We sent a stone-hurtling storm against them, except the family of Lot whom We saved in the early hours of the morning\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{As a favour from Us. That is how We reward the grateful.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{He had warned them of Our might, but they passed over the warnings.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{They lusted after his guests, so We put out their eyes (and said): ``Taste My punishment and My commination."\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{And early in the morning the decreed punishment came upon them.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{So now taste My punishment and My commination!\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{Easy have We made the Qur'an to understand: So is there any one who will be warned?\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{The warnings came to the people of Pharaoh.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{They rejected each one of Our signs. So We seized them with the grip of one mighty and powerful.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{Are the unbelievers among you any better than they? Or is there immunity for you in the Scriptures?\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmdcccxc{Or do they say: ``We are a well-accoutred army?"\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmdcccxci{The army will be routed and put to flight.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmdcccxcii{Surely the Hour will be the moment of their promise, and that moment will be calamitous and distressing.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmdcccxciii{Surely the sinners are misguided and insane.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmdcccxciv{On that Day they will be dragged into the fire faces foremost, (and told:) ``Taste the feel of Hell."\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmdcccxcv{We have indeed created all things by measure;\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{And Our command is but one (word) swift as the winking of an eye.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{We have destroyed the likes of you in the past: So is there any one who will be warned?\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{All things they do are (recorded) in the books;\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmdcccxcix{All things small or great have been written down.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmcm{Surely those who fear God and follow the straight path will be amidst gardens and light,\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmcmi{At the still centre in the proximity of the King all-powerful.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmcmii{\basmalahen AR-RAHMAN\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmcmiii{Bestowed the Qur'an,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmcmiv{Created man,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmcmv{And taught him to express clearly.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmcmvi{The sun and moon revolve to a computation;\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmcmvii{And the grasses and the trees bow (to Him) in adoration.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmcmviii{He raised the sky and set the Balance\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmcmix{So that none may err against the scales,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmcmx{And observe correct measure, weigh with justice, and not cheat the balance.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmcmxi{He positioned the earth for all the creatures:\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmcmxii{There are fruits of all kinds on it, and date-palms with their clusters sheathed,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmcmxiii{Grain with husk, and fragrant grasses.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmcmxiv{How many favours of your Lord will then both of you deny?\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmcmxv{He created man of fermented clay dried tinkling hard like earthen ware,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmcmxvi{And created jinns from the white-hot flame of fire.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmcmxvii{How many favours of your Lord will you then deny?\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmcmxviii{Lord of the two Easts, Lord of the two Wests.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmcmxix{How many favours of your Lord will then both of you deny?\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmcmxx{He has set two seas in motion that flow side by side together,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmcmxxi{With an interstice between them which they cannot cross.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmcmxxii{How many favours of your Lord will then both of you deny? --\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmcmxxiii{Out of them come pearls and coral.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmcmxxiv{How many favours of your Lord will you then deny?\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmcmxxv{His are the high-sailed vessels in deep ocean like the mountains.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmcmxxvi{How many favours of your Lord will then both of you deny?\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmcmxxvii{All that is on the earth is passing,\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmcmxxviii{But abiding is the glory of your Lord, full of majesty and beneficence.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmcmxxix{How many favours of your Lord will you then deny?\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmcmxxx{All those there are in the heavens and the earth turn to Him with solicitation, intent on His purpose all the time.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmcmxxxi{How many favours of your Lord will you then deny?\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmcmxxxii{We shall soon be free to turn to you, O weary caravans,\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{How many favours of your Lord will you then deny?\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{O society of jinns and men, cross the bounds of the heavens and the earth if you have the ability, then pass beyond them; but you cannot unless you acquire the law.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmcmxxxv{How many favours of your Lord will you then deny?\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{Let loose at you will be smokeless flames of fire so that you will not be able to defend yourselves.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{How many favours of your Lord will then both of you deny?\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{When the sky will split asunder, and turn rosy like the dregs of annointing oil,\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmcmxxxix{Which of the favours of your Lord will you then deny?\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmcmxl{Neither man nor jinn will be questioned on that day about his sin.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmcmxli{How many favours of your Lord will you then deny?\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmcmxlii{The sinners will be recognised by their marks, and seized by the forelock and their feet.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmcmxliii{Which of the favours of your Lord will you then deny?\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmcmxliv{This is Hell the sinners called a lie.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmcmxlv{They will go round and around between it and boiling water.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmcmxlvi{Which of the favours of your Lord will you then deny?\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmcmxlvii{But for him who lived in awe of the sublimity of his Lord, there will be two gardens --\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmcmxlviii{How many favours of your Lord will then both of you deny? --\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmcmxlix{Full of overhanging branches --\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmcml{Which of the favours of your Lord will you then deny? --\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmcmli{With two springs of water flowing through them both. --\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmcmlii{Which of the favours of your Lord will then both of you deny?\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmcmliii{In both of them there will be every kind of fruits in pairs. --\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmcmliv{Which of the favours of your Lord will then both of you deny? --\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmcmlv{Reclining there on carpets lined with brocade, fruits of the garden hanging low within reach.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmcmlvi{How many favours of your Lord will then both of you deny?\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmcmlvii{In them maidens with averted glances, undeflowered by man or by jinn before them, --\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmcmlviii{Which of the favours of your Lord will then both of you deny? --\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmmcmlix{As though rubies and pearls.\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmmcmlx{Which of the favours of your Lord will then both of you deny?\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmmcmlxi{Should the reward of goodness be aught else but goodness? --\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmmcmlxii{How many favours of your Lord will then both of you deny? --\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmmcmlxiii{And besides these two other gardens --\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmmcmlxiv{Which of the favours of your Lord will then both of you deny? --\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmmcmlxv{Of darkest verdant green --\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmmcmlxvi{How many favours of your Lord will then both of you deny? --\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmmcmlxvii{With two fountains gushing constantly, --\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmmcmlxviii{How many favours of your Lord will then both of you deny? --\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmmcmlxix{With fruits in them, and dates and pomegranates --\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmmcmlxx{How many favours of your Lord will then both of you deny? --\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxi{In them good and comely maidens --\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxii{How many favours of your Lord will you then deny? --\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{Houris cloistered in pavilions --\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{How many favours of your Lord will you then deny? --\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxv{Undeflowered by man or by jinn before them, --\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{How many favours of your Lord will then both of you deny? --\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{Reclining on green cushions and rich carpets excellent.\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{How many favours of your Lord will you then deny?\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxix{Blessed be the name of your Lord, full of majesty and beneficience.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxx{\basmalahen WHEN WHAT IS to happen comes to pass --\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{Which is bound to happen undoubtedly --\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{Degrading (some) and exalting (others);\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{When the earth is shaken up convulsively,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{The mountains bruised and crushed,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{Turned to dust, floating in the air,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{You will become three categories:\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{Those of the right hand -- how (happy) will be those of the right hand!\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{Then those of the left hand -- how (unhappy) will be those of the left hand!\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{Then the foremost, how pre-excellent,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmcmxc{Who will be honoured\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmcmxci{In gardens of tranquility;\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmcmxcii{A number of the earlier peoples,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmcmxciii{And a few of later ages,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmcmxciv{On couches wrought of gold,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmcmxcv{Reclining face to face.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmcmxcvi{Youths of never-ending bloom will pass round to them\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmcmxcvii{Cups and decanters, beakers full of sparkling wine,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmcmxcviii{Unheady, uninebriating;\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmcmxcix{And such fruits as they fancy,\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmm{Bird meats that they relish,\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmi{And companions with big beautiful eyes\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmii{Like pearls within their shells,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmiii{As recompense for all they had done.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmiv{They will hear no nonsense there or talk of sin,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmv{Other than ``Peace, peace" the salutation.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmvi{As for those of the right hand -- how (happy) those of the right hand --\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmvii{They will be in (the shade) of thornless lote\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmviii{And acacia covered with heaps of bloom,\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmix{Lengthened shadows,\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmx{Gushing water,\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmxi{And fruits numberless,\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmxii{Unending, unforbidden,\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmxiii{And maidens incomparable.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmxiv{We have formed them in a distinctive fashion,\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmxv{And made them virginal,\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmxvi{Loving companions matched in age,\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmxvii{For those of the right hand.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmxviii{A crowd of earlier generations\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmxix{And a crowd of the later.\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmxx{But those of the left hand -- how (unhappy) those of the left hand --\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmmxxi{Will be in the scorching wind and boiling water,\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmmxxii{Under the shadow of thick black smoke\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmmxxiii{Neither cool nor agreeable.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmmxxiv{They were endowed with good things\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmmxxv{But persisted in that greater sin,\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmmxxvi{And said: ``What! When we are dead and turned to dust and bones, shall we then be raised again?\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmmxxvii{And so will our fathers?"\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmmxxviii{Say: ``Indeed, the earlier and the later generations\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmmxxix{Will be gathered together on a certain day which is predetermined.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmmxxx{Then you, the erring and the deniers,\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmmxxxi{Will eat of the tree of Zaqqum,\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmmxxxii{Fill your bellies with it,\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmmxxxiii{And drink over it scalding water,\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmmxxxiv{Lapping it up like female camels raging of thirst with disease."\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmmxxxv{Such will be their welcome on the Day of Judgement.\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmmxxxvi{It is He who created you, then why do you not affirm the truth?\qt@no{(57)}}
\qt@newcmd\qurantrans@en@mmmmmxxxvii{Just consider (the semen) that you emit,\qt@no{(58)}}
\qt@newcmd\qurantrans@en@mmmmmxxxviii{Do you create it, or We are its creator?\qt@no{(59)}}
\qt@newcmd\qurantrans@en@mmmmmxxxix{We have incorporated death in your constitution, and We shall not be hindered\qt@no{(60)}}
\qt@newcmd\qurantrans@en@mmmmmxl{From replacing you with others or raising you in a way you do not know.\qt@no{(61)}}
\qt@newcmd\qurantrans@en@mmmmmxli{You have known the first creation, then why do you not reflect?\qt@no{(62)}}
\qt@newcmd\qurantrans@en@mmmmmxlii{Just ponder over what you sow:\qt@no{(63)}}
\qt@newcmd\qurantrans@en@mmmmmxliii{Do you give it its increase, or are We the giver?\qt@no{(64)}}
\qt@newcmd\qurantrans@en@mmmmmxliv{We could turn it, if We pleased, into straw; then you would rue the day,\qt@no{(65)}}
\qt@newcmd\qurantrans@en@mmmmmxlv{(And say:) ``We have fallen into debt;\qt@no{(66)}}
\qt@newcmd\qurantrans@en@mmmmmxlvi{Indeed, we have been deprived of the fruits of our labour."\qt@no{(67)}}
\qt@newcmd\qurantrans@en@mmmmmxlvii{Consider the water that you drink.\qt@no{(68)}}
\qt@newcmd\qurantrans@en@mmmmmxlviii{Do you send it down from the clouds, or We send it down?\qt@no{(69)}}
\qt@newcmd\qurantrans@en@mmmmmxlix{We could make it brackish, if We pleased; so why do you not acknowledge thanks?\qt@no{(70)}}
\qt@newcmd\qurantrans@en@mmmmml{Consider the fire that you strike (and get by friction).\qt@no{(71)}}
\qt@newcmd\qurantrans@en@mmmmmli{Have you raised its tree, or We have raised it?\qt@no{(72)}}
\qt@newcmd\qurantrans@en@mmmmmlii{We have made it as a reminder and convenience for the needy.\qt@no{(73)}}
\qt@newcmd\qurantrans@en@mmmmmliii{So glorify your Lord, the most supreme.\qt@no{(74)}}
\qt@newcmd\qurantrans@en@mmmmmliv{So I call the placement of the stars to witness --\qt@no{(75)}}
\qt@newcmd\qurantrans@en@mmmmmlv{And this surely is great evidence if you can understand --\qt@no{(76)}}
\qt@newcmd\qurantrans@en@mmmmmlvi{That this is indeed the glorious Qur'an\qt@no{(77)}}
\qt@newcmd\qurantrans@en@mmmmmlvii{(Inscribed) in the well-kept Book.\qt@no{(78)}}
\qt@newcmd\qurantrans@en@mmmmmlviii{Only they can reach it who are clean (of mind).\qt@no{(79)}}
\qt@newcmd\qurantrans@en@mmmmmlix{It has been revealed by the Lord of all the worlds.\qt@no{(80)}}
\qt@newcmd\qurantrans@en@mmmmmlx{Then why do you dissimulate this Revelation?\qt@no{(81)}}
\qt@newcmd\qurantrans@en@mmmmmlxi{You live by calling it a lie.\qt@no{(82)}}
\qt@newcmd\qurantrans@en@mmmmmlxii{Then how is it that when the (dying) breath is withdrawn into the throat (and rattles),\qt@no{(83)}}
\qt@newcmd\qurantrans@en@mmmmmlxiii{And you wait for the moment (of death),\qt@no{(84)}}
\qt@newcmd\qurantrans@en@mmmmmlxiv{We are closer to him than you, even though you cannot see?\qt@no{(85)}}
\qt@newcmd\qurantrans@en@mmmmmlxv{Then why, if you are not indebted (to Us for life),\qt@no{(86)}}
\qt@newcmd\qurantrans@en@mmmmmlxvi{Can you not bring him back? (Answer) if you are truthful\qt@no{(87)}}
\qt@newcmd\qurantrans@en@mmmmmlxvii{Then, if he is one of the honoured,\qt@no{(88)}}
\qt@newcmd\qurantrans@en@mmmmmlxviii{There will be peace and plenty, and gardens of tranquility for him.\qt@no{(89)}}
\qt@newcmd\qurantrans@en@mmmmmlxix{If he is of those of the right hand,\qt@no{(90)}}
\qt@newcmd\qurantrans@en@mmmmmlxx{There will be the salutation by those of the right hand: ``Peace on you.\qt@no{(91)}}
\qt@newcmd\qurantrans@en@mmmmmlxxi{But if he is of the deniers and the errants,\qt@no{(92)}}
\qt@newcmd\qurantrans@en@mmmmmlxxii{The welcome will be boiling water\qt@no{(93)}}
\qt@newcmd\qurantrans@en@mmmmmlxxiii{And the roasting in Hell.\qt@no{(94)}}
\qt@newcmd\qurantrans@en@mmmmmlxxiv{This is indeed the ultimate truth.\qt@no{(95)}}
\qt@newcmd\qurantrans@en@mmmmmlxxv{Then praise your Lord, the most supreme.\qt@no{(96)}}
\qt@newcmd\qurantrans@en@mmmmmlxxvi{\basmalahen WHATSOEVER IS IN the heavens and the earth sings the praises of God. He is all-mighty and all-wise.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmlxxvii{His is the kingdom of the heavens and the earth, He is the giver of life and death, and He has power over everything.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmlxxviii{He is the first and He the last, the transcendent and the immanent; and He has knowledge of everything.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmlxxix{It is He who created the heavens and the earth in six stages, then assumed the throne. He knows whatsoever enters the earth, and whatsoever comes out of it, and what comes down from the sky and what goes up to it; and He is with you wheresoever you may be, and He perceives whatsoever you do.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmlxxx{His is the kingdom of the heavens and the earth, and all things will go back to Him.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmlxxxi{He turns night into day, and turns day into night; and He knows whatsoever is in your hearts.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmlxxxii{Believe in God and His Apostle, and spend of what He has given you as His trustee. And those of you who believe and spend in charity will have a great reward.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{What has come upon you that you believe not in God, though the Prophet is calling you to believe in your Lord? And He has already taken your pledge, if you are believers.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{It is He who sends down splendent revelations to His votary that he may take you out of darkness into light; for surely God is gracious and kind to you.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmlxxxv{What has come upon you that you do not spend in the way of God, when the heritage of the heavens and the earth belongs to God? Those of you who spent before the victory and fought, are not equal (to those who did not). They are higher in position than those who spent after (the victory) and fought. To each one God has made the promise of excellence, for God is aware of all you do.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{Who will give a goodly loan to God which He will double for him, and be for him a splendid reward?\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{The day you see the believers, men and women, with their light advancing ahead and to the right of them, (they will be told:) ``There is good news for you this day, of gardens with rivers flowing by where you will live for ever." This will be the great attainment.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{The day the hypocrites, men and women, will say to the believers: ``Wait for us that we may borrow a little light from your light," they will be told: ``Go back, and look for your light." A wall shall be raised between them in which there will be a door. Within it will be benevolence and retribution without.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmlxxxix{They will call to them: ``Were we not with you?" They will answer: ``Certainly; but then you let yourselves be tempted, and waited in expectation but were suspicious and were deceived by vain desires, till the decree of God came to pass, and the deceiver duped you in respect of God.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmxc{So no ransom will be accepted of you on this day, or of those who refused to believe. Hell will be your refuge and the only friend -- and how evil a destination!"\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmxci{Has the moment not yet come when the hearts of believers should be moved by the thought of God and the truth that has been sent down, so that they should not be like those who received the Book before them but whose hearts were hardened after a lapse of time, and many of them turned disobedient?\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmxcii{Know that God enlivens the earth even after it has died. We have explained to you clearly Our signs that you may understand.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmxciii{Surely the men and women who spend in charity and give a goodly loan to God, will have it doubled for them and will receive a generous reward.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmxciv{Those who believe in God and His apostles are true of word and deed; and by their Lord are considered testifiers of the truth. They have their guerdon and their light. As for those who do not believe and reject Our revelations, are the people of Hell.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmxcv{Know that the life of this world is only a frolic and mummery, an ornamentation, boasting and bragging among yourselves, and lust for multiplying wealth and children. It is like rain so pleasing to the cultivator for his vegetation which sprouts and swells, and then begins to wither, and you see it turn to yellow and reduced to chaff. There is severe punishment in the Hereafter, but also forgiveness from God, and acceptance. As for the life of this world, it is no more than merchandise of vanity.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmxcvi{Hasten for the forgiveness of your Lord and Paradise whose expanse is as wide as that of the heavens and the earth, which has been prepared for those who believe in God and His apostles. This is the bounty of God which He bestows on whosoever He please; and the bounty of God is infinite.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmxcvii{There is no calamity that befalls the earth or your own selves but in accordance with the law (of causation) before We make it evident. This is indeed how the law of God works inevitably.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmxcviii{Lest you grieve for what you missed, or rejoice at what you received. God does not love the egoist and the braggart,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmxcix{Who hold back what they possess and enjoin stinginess on others. Whoever turns away (from God, should remember) that God is self-sufficient, worthy of praise.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmc{We have surely sent apostles with clear signs, and sent with them the Book and the Balance, so that men may stand by justice; and We sent down iron which causes much distress but also has advantages for men, so that God may know who helps Him and His apostles in secret. Verily God is all-powerful and all-mighty.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmci{We sent Noah and Abraham, and gave prophethood to their progeny and the Book, and some of them are well-directed, but many of them are disobedient.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmcii{Then in their train We sent Our apostles, and succeeding them Jesus, son of Mary, and gave him the Gospel, and put into the hearts of his followers compassion and kindness. But they created monasticism which had not been prescribed for them by Us except for seeking the pleasure of God; yet they did not observe it as it should have been rightly observed. So We gave those among them who were believers their reward; but most of them are disobedient.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmciii{O you who believe, have fear of displeasing God, and believe in His Prophet. He will give you twice as much of His bounty and place a light for you to walk in, and forgive you, for God is forgiving and kind;\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmciv{So that the people of the Book may know that they have not the least power over the bounty of God, and that the bounty is wholly in the hands of God to give whosoever He please, for God is the master of infinite bounty.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmcv{\basmalahen GOD CERTAINLY HEARD what the woman who argued with you about her husband, said, and complained to God; and God heard your interrogation. Verily God hears all, and sees everything.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcvi{Those of you who divorce your wives by calling them 'mothers,' cannot (make them) their mothers. Their mothers are only those who gave birth to them. They surely utter what is unseemly and a lie. But God is forbearing and forgiving.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcvii{Those who call their wives their mothers then revoke what they had said, should free a slave before having physical contact (with them). This is to warn you, as God is aware of what you do.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcviii{If one does not have the means (of doing so) then he should fast for two months continuously before he has physical contact; but any one who is unable to do so, should feed sixty needy persons. This (is enjoined) so that you may be faithful to God and His Apostle. These are the limits set by God. As for the unbelievers, there is painful punishment for them.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcix{Those who oppose God will be disgraced, as those before them were. We have sent down very clear signs. For unbelievers there is a shameful punishment.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcx{On the day when God will raise them up together, He will tell them what they did. God takes account of it although they forget, for all things are evident to God.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcxi{Have you not considered that God knows whatever is in the heavens and the earth? No three persons confer secretly but He is the fourth among them, and no five but He is the sixth; and neither fewer nor more but He is with them wheresoever they be. And on the Day of Judgement He will announce their deeds to them. Verily God has knowledge of everything.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcxii{Have you not considered those who were forbidden to conspire, but reverted after a time to what was forbidden them, and conspired evil, rebellion and disobedience to the Prophet? Yet when they come to you they greet you with a greeting even God does not greet you with; and say to themselves, ``Why doesn't God punish us for what we say?" Hell is sufficient for them, in which they will be burnt: And what an evil consequence!\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcxiii{O you who believe, when you converse privately, do not talk of iniquity, rebellion, and disobedience to the Prophet, but talk of goodness and piety, and fear God before whom you will be gathered.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcxiv{Surely scheming is the work of Satan that he may cause the faithful grief; but he cannot harm them unless God dispense. So in God should the believers place their trust.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcxv{O you who believe, when you are told to make room in the assemblies, then make room; God will give you more room to spread. When you are told to rise, then rise; God will raise those of you who believe, and those who have knowledge, in position. God is aware of what you do.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcxvi{O you who believe, if you confer with the Prophet in private, give alms in the name of God before you go to confer. This is better for you and becoming. If you do not have the means, then surely God is forgiving and kind.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcxvii{Are you afraid of giving alms before confering? Then, if you cannot do this, and God forgives you, be constant in your devotional obligations and pay the due share of your wealth for the welfare of others, and obey God and His Prophet. God is aware of all you do.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcxviii{Have you not seen those who have taken a people who have roused the wrath of God, as friends? They are neither of you nor of them, and swear to a lie, and knowingly.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcxix{God has reserved a severe punishment for them. Evil indeed are the things they do!\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcxx{They have made their oaths a shield, and obstruct people from the way of God. There is shameful punishment for them.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcxxi{Neither their wealth nor children will avail them against God. They are the people of Hell, and there will abide for ever.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcxxii{On the day that God will raise them together, they will swear before Him as they swear before you, and imagine they are on the right path. Is it not they who are liars?\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcxxiii{Satan has got the better of them. and made them forget to remember God. Indeed they belong to Satan's faction. Will not Satan's faction perish?\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcxxiv{Surely those who oppose God and His Prophet will be among the vilest.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcxxv{God has decreed: ``I will prevail, I and My apostles." Verily God is powerful and all-mighty.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcxxvi{You will not find those who believe in God and the Day of Resurrection, loving those who oppose God and His Prophet, even though they be their fathers, sons, or brothers or their kin. God has inscribed on their hearts belief, and has succoured them with His own grace, and will admit them to gardens with rivers flowing by, where they will abide for ever, God accepting them, and they, happy in the pleasure of God. They are verily the army of God. Will not the army of God be victorious?\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcxxvii{\basmalahen WHATEVER IS IN the heavens and the earth sings the praises of God. He is all-mighty and all-wise.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcxxviii{It is He who drove those among the people of the Book who refused to believe, from their homes for the first confrontation. You did not think that they would go away, and they imagined that their forts would protect them against God. But God came upon them from where they did not suspect, and filled their hearts with terror, so that they destroyed their homes with their own hands (or were destroyed) by the hands of believers. So take heed, O men of sight!\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcxxix{Had God not decreed the expulsion for them He would have punished them in this world, and in the next the punishment of Hell would have been theirs.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcxxx{For they had opposed God and His Apostle; and whosoever opposes God, then God is severe in retribution.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcxxxi{The palm trees that you cut down or left standing intact was by God's dispensation, so that He might disgrace the transgressors.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcxxxii{You did not charge with horse or camel for whatever (spoils) God gave His Apostle from them. In any case, God gives authority to His Apostle over whomsoever He please. God has power over everything.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{Whatever booty God gives to His Apostle from the people of the cities, is for God and His Apostle, the near relations, the orphans, the needy and wayfarers, so that it does not concentrate in the hands of those who are rich among you. Accept what the Apostle gives you, and refrain from what he forbids, and take heed for yourself and fear God. Surely God is severe of retribution.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{The spoils are also for the poor emigrants who were deprived of their homes and possessions and are seeking the bounty and protection of God, and are helping God and His Apostle. They are the ones who are true of word and deed.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcxxxv{Those who came to the city and to faith before them, love those who take refuge with them, and do not feel for themselves any need for what is given them, and give them preference over themselves even if they are indigent. Whoever preserves himself from his own greed will be prosperous.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{(And the spoils are for) those who came after them, who say: ``O Lord, forgive us and our brothers who came to faith before us, and do not put a grudge in our hearts against those who believe O Lord, You are compassionate and kind."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{Have you never considered the hypocrites? They say to their brethren among the people of the Book who do not believe: ``If you are driven out we shall go with you, and will not listen to any one in what concerns you; and if there is war against you, we shall aid you." But God is witness they are liars.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{If they are driven out, they will not go with them; and if they are attacked, they will not aid them. And even if they aided them, they will turn their backs, then they will not be helped.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcxxxix{Surely they have greater fear of you in their hearts than of God, because they do not understand.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcxl{They will not fight you in a body except in fortified cities, or from behind the walls. Their enmity among themselves is great. You think they are united, but divided are their hearts. That is because these people are devoid of sense,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcxli{Like those who had tasted the gravity of their actions a little before them. There is a grievous punishment for them.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcxlii{(They are) like Satan who says to man: ``Do not believe;" and when he becomes a disbeliever, he says: ``I have nothing to do with you. I fear God, the Lord of all the worlds."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcxliii{Both of them will end up in Hell, where they will abide for ever. This is the punishment for the wicked.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcxliv{O you who believe, be fearful of God. Let each soul consider what it has sent (of good deeds) in advance for the morrow, and fear God. Surely God is aware of what you do.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcxlv{And be not like those who have forgotten God, so that God has made them forget themselves. Such are the reprobates.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcxlvi{Alike are not the inmates of Hell and the residents of Paradise. The men of Paradise will be felicitous.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcxlvii{If We had sent down this Qur'an to a mountain you would have seen it turn desolate and split into two for fear of God. We offer these examples to men that they may think and reflect.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcxlviii{He is God; there is no god but He, the knower of the unknown and the known. He is the benevolent, ever-merciful.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcxlix{He is God; there is no god but He, the King, the Holy, the Preserver, Protector, Guardian, the Strong, the Powerful, Omnipotent. Far too exalted is God for what they associate with Him.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmcl{He is God, the Creator, the Maker, the Fashioner. His are all the names beautiful. Whatever is in the heavens and the earth sings His praises. He is all-mighty and all-wise.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmcli{\basmalahen O YOU WHO BELIEVE, do not take My enemies and your enemies as friends. You show kindness to them, but they reject the true way that has come to you. They expelled the Prophet and you, for you believe in God your Lord. If you have come out to struggle in My cause having sought My acceptance, (do not be) friendly with them in secret. I know what you hide and what you disclose. Whoever of you does this will have gone astray from the right path.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmclii{If they gain ascendancy over you, they will become your enemies, and employ their hands and tongues with evil designs, and wish that you also became disbelievers.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcliii{Neither your blood relations nor your children will be of any avail to you on the Day of Resurrection. He will judge between you, for God sees what you do.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcliv{You have an excellent model in Abraham and those who were with him, when he said to his people: ``We are through with you, and those you worship other than God. We reject you. Enmity and hate have come between you and us for ever, unless you believe in God the One," -- except for what he said to his father: ``I shall ask forgiveness for you, but I have no power to prevail with God for you." ``O Lord, we place our trust in You, and turn to You in penitence, and to You is our returning.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmclv{O Lord, make us not an example of punishment for infidels, and forgive us, O Lord. You are all-mighty and all-wise."\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmclvi{Those of you who have hope in God and the Last Day have certainly a good example in them. But whosoever turns away, then surely God is above concern, worthy of praise.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmclvii{It maybe that God will create love between you and your enemies. God is all-powerful, and God is forgiving, ever-merciful.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmclviii{God does not forbid you from being kind and acting justly towards those who did not fight over faith with you, nor expelled you from your homes. God indeed loves those who are just.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmclix{He only forbids you from making friends with those who fought over faith with you and banished you from your homes, and aided in your exile. Whoever makes friends with them is a transgressor.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmclx{O believers, when believing women come over to you as refugees, then examine them. God alone is cognisant of their faith. If you find that they are believers, do not send them back to unbelievers. They are not lawful for them, nor are infidels lawful for believing women. Give the unbelievers what they have spent on them. There is no sin if you marry them provided you give their dowers to them. Do not retain your (marriage) ties with unbelieving women. Ask for the return of what you have spent (on them); and the unbelievers should ask for the return of what they have spent. This is the judgement of God. He judges between you. God is all-knowing and all-wise.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmclxi{If any of your women go away to the unbelievers, and you succeed in your turn (and have a chance of getting spoils), then give to those whose wives have so gone away as much as they had spent on them; but take heed and fear God in whom you believe.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmclxii{O Prophet, when believing women come to you and swear on oath that they will not associate anything with God, nor steal, nor fornicate, nor kill their children, nor accuse others for what they have fabricated themselves, nor disobey you in any rightful thing, then you should accept their allegiance, and ask forgiveness of God for them. Certainly God is forgiving and kind.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmclxiii{O you who believe, do not make friends with those who have suffered the anger of God by having become despondent of the life to come like those unbelievers who are despondent of those who are in the graves.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmclxiv{\basmalahen ALL THAT IS in the heavens and the earth sings the praises of God. He is all-mighty and all-wise.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmclxv{O you who believe, why do you profess what you do not practise?\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmclxvi{Saying what you do not practice is odious to God.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmclxvii{Surely God loves those who fight in His cause in full formations as though they were a compact wall.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmclxviii{When Moses said to his people: ``O my people, why do you afflict me though you know that I have been sent to you by God?" But when they turned aside God made their hearts turn farther away; for God does not show the transgressors the way.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmclxix{And when Jesus, son of Mary, said: ``O children of Israel, I am sent to you by God to confirm the Torah (sent) before me, and to give you good tidings of an apostle who will come after me, whose name is Ahmad (the praised one)." Yet when he has come to them with clear proofs, they say: ``This is only magic."\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmclxx{Who is more unjust than he who invents a lie against God when he is called to submit? God does not show the evil-doers the way.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmclxxi{They want to extinguish the light of God by uttering blasphemies. But God wills to perfect His light, however the unbelievers may dislike it.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmclxxii{It is He who sent His Apostle with the guidance and the true way to raise it above all faiths, however the idolaters may dislike it.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmclxxiii{O you who believe, may I offer you a bargain which will save you from a painful punishment?\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmclxxiv{Come to believe in God and His Apostle, and struggle in the cause of God, wealth and soul. This will be good for you, if you can understand.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmclxxv{He will forgive you your sins and admit you to gardens with rivers flowing by, and excellent mansions in the garden of Eden. This will be a great fulfilment.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmclxxvi{And (He will give you) what is dearest to you -- help from God and early victory. So give good tidings to those who believe.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmclxxvii{O you who believe, be helpers of God, as Jesus, son of Mary, had said to the disciples: ``Who will help me in the way of God?" and they had answered: ``We are the helpers of God." Then a section among the children of Israel believed, but a section among them did not. So We helped those who believed against their enemies, and they prevailed over them.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmclxxviii{\basmalahen ALL THAT IS in the heavens and the earth sings the praises of God the King, the Holy, Omnipotent, the Wise.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmclxxix{It is He who raised among the gentiles an apostle from amongst them, who recites His revelations to them, reforms them and teaches them the Scripture and the Law, for before him they were clearly in error.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmclxxx{And for others among them who have not joined them yet. He is all-mighty and all-wise.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmclxxxi{This is the bounty of God, He gives whosoever He please. God is master of great bounty.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmclxxxii{The likeness of those who were charged with (the law of) the Torah which they did not observe, is that of a donkey who carries a load of books (oblivious of what they contain). How wretched the semblance of the people who deny the words of God! God does not show an unjust people the way.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{Say: ``O you Jews, if you claim that you are the favourites of God apart from all men, then wish for death, if you speak the truth.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{But they will never wish for death because of what they had done in the past, and God knows the sinners well.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmclxxxv{Tell them: ``Death from which you run, will surely come to you. You will then be sent back to Him who knows the unknown and the known, who will tell you what you used to do.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{O you who believe, when the call to prayer is made on the day of congregation, hasten to remember God, putting aside your business. This is better for you if you can understand.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{And when the service of prayer is over spread out in the land, and look for the bounty of God. and remember God a great deal that you may prosper.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{Yet when they see some buying and selling, or some sport, they go for it, leaving you standing. Tell them: ``What is with God is better than your sport and commerce. And God is the best of providers."\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmclxxxix{\basmalahen WHEN THE HYPOCRITES come to you, they say: ``We affirm that you are the Apostle of God." God indeed knows you are His Apostle. God bears witness that the hypocrites are indeed liars.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcxc{They have made their oaths a shield in order to obstruct others from the way of God. It is certainly evil what they do.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcxci{That is because they came to believe, and then renounced (their faith). So their hearts were sealed; and now they do not understand.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcxcii{Pleasing seem their persons when you look at them; and when they talk, you listen to their speech. Yet they are like the wooden panelling of a wall. They imagine every rebuke to be directed against them. They are the enemies, beware of them. May God damn them, how pervert are they!\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcxciii{When you tell them: ``Come, let the Apostle of God ask forgiveness for you," they turn their heads, and you see them turning away with arrogance.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcxciv{Whether you ask forgiveness for them or do not ask, it is all the same; God will not forgive them. Surely God does not show a disobedient people the way.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcxcv{They are the ones who say: ``Do not spend on those who are with the Apostle of God till they break away (from him)." To God belong the treasures of the heavens and the earth; but the hypocrites do not understand.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcxcvi{They say: ``If we now go back to Madina, the stronger will turn the weaker out." But power belongs to God, His Apostle and the faithful, though the hypocrites do not know.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcxcvii{O you who believe, let not your wealth and children make you negligent of the remembrance of God. Those who do so will be losers.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcxcviii{Spend of what We have given you before death comes to one of you, when he will say: ``O Lord, why did you not defer my term for a while that I could give alms and be among the doers of good?"\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcxcix{But God does not grant a soul respite once its term has come to end. And God is aware of what you do.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcc{\basmalahen ALL THAT THERE is in the heavens and the earth sings the praises of God. His the sovereignty and His is the praise, and He has power over everything.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcci{It is He who created you, though one of you is an infidel and one of you a believer; yet God perceives what you do.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmccii{He created the heavens and the earth with deliberation, and gave you form, and shaped you well; and to Him is your returning.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcciii{He knows what is in the heavens and the earth, and knows what you hide and what you disclose; God knows what is in the hearts.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcciv{Has not the account of those who disbelieved before come to you, who tasted the torment of their action, and for whom is grievous punishment?\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmccv{This was so because their apostles came to them with clear proofs, but they said: ``What. Can a mortal show us the way?" And they denied and turned away; but God was unconcerned. God is all-sufficient, worthy of praise.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmccvi{The unbelievers claim that they will not be raised again. Tell them: ``Why not? By my Lord, you will certainly be raised again, and then informed of what you had done. That is how the law of God works inevitably."\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmccvii{So believe in God, His Apostle and the Light We have sent down. God is well aware of what you do.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmccviii{The day He will gather you together on the Day of Gathering, will be the day of Judgement. He who believed and did the right, will have his evil deeds expunged by God and admitted to gardens with rivers flowing by, and abide there perpetually. This will be the great achievement of success.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmccix{Those who did not believe and denied Our revelations will be inmates of Hell, where they will abide for ever, and how evil a journey's end!\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmccx{No calamity befalls unless God dispenses. He guides the heart of whosoever believes in God; and God has knowledge of everything.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmccxi{Obey God and obey His Apostle. If you turn away, the duty of the Apostle is to convey the message clearly.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmccxii{God: There is no god but He; and in God should believers place their trust.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmccxiii{O believers, some of your spouses and children are your enemies, so beware of them! Yet if you forbear, overlook, and forgive, God is indeed forgiving and kind.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmccxiv{Your wealth and children are surely meant as trial for you: But with God is the great reward.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmccxv{So fear God as much as you can, and listen and obey, and spend in charity for your own good. He who is saved from his own avarice will be successful.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmccxvi{If you lend a goodly loan to God, He will double it for you, and forgive you. God knows the worth of good deeds and is clement,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmccxvii{The knower of the unknown and the known, all-mighty and all-wise.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmccxviii{\basmalahen O PROPHET WHEN you divorce women, divorce them at their appointed period, and calculate that period, and fear God, your Lord. Do not expel them from their houses, nor should they go away themselves, unless they are openly guilty of adultery. These are the limits set by God. Any one who exceeds the limits set by God sins against his own self. You never know that God may perchance lead to a new situation after this.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmccxix{When they have reached their appointed time, then either keep them lawfully or let them go honourably; but have two witnesses from among you, and give truthful evidence for (being acceptable to) God. This is to warn him who believes in God and the Last Day. God will furnish a way out for him who fears Him,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmccxx{And provide for him from where he does not reckon. God is sufficient for him who places his trust in Him. Certainly God fulfills His purpose. God has indeed fixed a measure of everything.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmccxxi{As for your women who have lost hope of menstruation, and in case you have a doubt, the prescribed period (of waiting) for them is three months, as also for those who have not menstruated yet. As for those who are pregnant, their prescribed period is until the delivery of the child. God will make things easy for him who is mindful of God.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmccxxii{This is the commandment of God that is sent down to you. God will forgive the ills of those who fear Him, and increase their reward.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmccxxiii{House the (divorced) women where you live, according to your means; but do not harass them so as to reduce them to straitened circumstances. If they are pregnant, then spend on them until they give birth to the child. And if they suckle the child for you, then make the due payment to them, and consult each other appropriately. But if you find this difficult, let some other woman suckle (the child) for her.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmccxxiv{Let the man of means spend according to his means, and he whose means are limited, should spend of what God has given him. God does not burden a soul beyond what He has given him. God will bring ease after hardship.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmccxxv{How many habitations rebelled against their Lord's command and His apostles; but We took them to severe task, and punished them with the harshest punishment.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmccxxvi{So they tasted the pain of their actions; and the consequence of their deeds was ruin.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmccxxvii{God has prepared for them severe punishment. So, you men of wisdom, and those who believe, take heed for yourselves and fear God. God has indeed sent down a Reminder for you,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmccxxviii{An Apostle who recites before you the explicating revelations of God that He may bring those who believe and do the right out of darkness into light. Whosoever believes in God and does the right, He will admit into gardens with rivers flowing by, where they will abide for ever. How excellent a provision has God made for him\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmccxxix{It is God who created several skies, and as many earths. The commandment is sent down among them so that you may know that God has power over everything, and everything is held within the knowledge of God.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmccxxx{\basmalahen O PROPHET, WHY should you forbid (yourself) what God has made lawful for you, in order to please your wives? Yet God is forgiving and kind.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmccxxxi{Surely God has sanctioned the dissolution of your vows. God is your Lord: He is all-knowing, and all-wise.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmccxxxii{When the Prophet told one of his wives something in confidence and she disclosed it, God revealed this to him. So he made some of it known to her, and held back some. When, however, he informed her about it, she asked: ``Who told you this?" He said: ``I was told this by the All-knowing, All-Informed."\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{If both of you two (women) turn to God in penitence (it would be better). Your hearts have been impaired; and if you assist one another against him, then surely his helper is God, and Gabriel and the righteous believers, and, besides them, the angels are his helpers.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{In case he divorces you, his Lord will give him better wives in return, who will be modest, true believers, obedient to God, repentant, observant of prayer and fasting, both widows and virgins.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmccxxxv{O you who believe, save yourselves and your families from the Fire whose fuel is men and rocks, over which are appointed angels stern and severe as wardens who never disobey what God commands them, and do what they are commanded;\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{(And say:) ``O you who do not believe, make no excuses today. You will be requited only for what you had done."\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{O you who believe, turn to God truly in repentance. Perhaps your Lord may forgive your ills and admit you to gardens with rivers flowing by on the day when God will not humiliate the Prophet and those who believe with him. Their light will move in front of them and to their right, and they will say: ``O Lord, perfect our light and forgive us. You have power over every thing."\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{O Prophet, fight the unbelievers and the hypocrites, and be severe with them. Their abode is Hell, an evil destination?\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmccxxxix{God advances the example of Noah's wife and the wife of Lot for those who do not believe. They were married to Our two pious devotees, but they were unfaithful to them, and even (the apostles) could not avail them in the least against God; and it was said to them: ``Enter Hell with those (who are condemned) to enter it."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmccxl{And God presents the example of Pharaoh's wife for those who believe, when she said: ``O Lord, build me a house in Paradise, and save me from Pharaoh and his deeds, and save me from a wicked people;"\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmccxli{And of Mary, daughter of 'Imran, who guarded her chastity, so that We breathed into her a new life from Us, and she believed the words of her Lord and His Books, and was among the obedient.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmccxlii{\basmalahen BLESSED BE HE who holds the (reins of) Kingship in His hand, who has power over everything,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmccxliii{Who created death and life in order to try you to see who of you are best of deed. He is all-mighty and forgiving,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmccxliv{Who created the seven skies one above the other. Do you see any disproportion in the creations of Ar-Rahman? Turn your eyes again. Do you see any fissures?\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmccxlv{Turn your eyes again and again. Your gaze turns back dazed and tired.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmccxlvi{We have adorned the lowest sky with lamps, and made them missiles against the devils, for whom We have prepared a torment of most intense fire.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmccxlvii{For those who believe not in their Lord there is the punishment of Hell; and what a wretched destination\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmccxlviii{When they are cast into it, they will hear it roar and raging\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmccxlix{As though it would burst with fury. Every time a crowd is thrown into it, its wardens will ask: ``Did no warner come to you?"\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmccl{And they will answer: ``Surely; a warner came to us, but we denied him, and said: 'God did not send down any thing; you are greatly deluded, in fact.'"\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmccli{They will say: ``If we had listened and been wise, we would not have been among the inmates of Hell."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcclii{So will they confess their guilt. Deprived (of all joys) will be the inmates of Hell.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmccliii{For those who fear their Lord in secret is forgiveness and a great reward.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmccliv{Whether you say a thing secretly or openly, He knows the innermost secrets of your hearts.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcclv{Can He who has created not know (His creation)? He is all-penetrating, all-aware.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcclvi{It is He who made the earth subservient to you that you may travel all around it, and eat of things He has provided; and to Him will be your resurrection.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcclvii{Are you so unafraid that He who is in Heaven will not open up the earth to swallow you, when it will begin to tremble?\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcclviii{Or have you become so unafraid that He who is in Heaven will not send a violent wind to shower stones at you? Then you will know the import of My commination!\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcclix{Those before them had also denied. And how was My punishment then!\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcclx{Do they not see the birds above them flying wings spread out or folded? Nothing holds them aloft but God. All things are within His purview.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcclxi{What other army do you have to help you apart from Ar-Rahman? The unbelievers are surely lost in delusion.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcclxii{Who is there to give you food in case He withholds His bounty? Yet they persist in rebellion and aversion.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcclxiii{Will he find the way who grovels flat on his face, or he who walks straight on the right path?\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcclxiv{Say: ``It is He who raised you and gave you ears and eyes and hearts. How little are the thanks you offer!"\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmcclxv{Say: ``It is He who dispersed you all over the earth, and to Him you will be gathered."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmcclxvi{But they say: ``When will this promise come to pass, if what you say is true?"\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmcclxvii{Say: ``God alone has knowledge. My duty is only to warn you clearly."\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmcclxviii{When they realise it has come upon them, distraught will be the faces of unbelievers. They will be told: ``This is what you asked for."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmcclxix{Say: ``Just think: If God destroys me and those with me, or is benevolent to us, who will then protect the unbelievers from a painful doom?"\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmcclxx{Say: ``He is the benevolent; in Him do we believe, and in Him do we place our trust. You will now realise who is in manifest error."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxi{Say: ``Just think: If your water were to dry up in the morning who will bring you water from a fresh, flowing stream?"\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxii{\basmalahen NUN. I CALL to witness the pen and what they inscribe,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{You are not demented by the grace of your Lord.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{There is surely reward unending for you,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxv{For you are verily born of sublime nature.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{So you will see, and they will realise,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{Who is distracted.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{Verily your Lord knows those who have gone astray from His path, and He knows those who are guided on the way.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxix{So do not comply with those who deny:\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxx{They only want that you should relent, so that they may come to terms.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{Do not heed a contemptible swearer,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{Or backbiter, calumniator, slanderer,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{Who hinders men from (doing) good, the transgressor, the iniquitous,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{Crude, and above all, mean and infamous,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{Simply because he possesses wealth and children.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{When you recite Our revelations to him, he says: ``These are fables of long ago."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{We shall brand him on the muzzle.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{We have tried you as We tried the owners of the garden when they vowed to gather the fruits in the morning\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{But did not add: ``If God may please."\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmccxc{Then a calamity from your Lord fell upon it, but they remained fast asleep.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmccxci{So by the morning it seemed as though picked clean.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmccxcii{At daybreak they called to each other:\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmccxciii{``If you want to gather the fruits, let us go early to the plantation."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmccxciv{So they departed, talking in low voices:\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmccxcv{``Let no needy person come to you within it today."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmccxcvi{They left early in the morning bent on this purpose.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmccxcvii{When they saw (and did not recognise it) they said: ``Surely we have lost the way.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmccxcviii{No. In fact we have been deprived of it."\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmccxcix{One who was temperate among them, said: ``Did I not say: 'Why don't you priase God?'"\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmccc{``Glory to our Lord," they said; we were really in the wrong."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmccci{Then they started blaming one another,\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmcccii{Saying: ``Alas the woe, we were iniquitous.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmccciii{Maybe our Lord will give us better than this. We turn to our Lord in supplication."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmccciv{Such is Our chastisement; and the punishment of the Hereafter will be greater, if only they knew!\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmcccv{For those who fear God there are pleasure gardens with their Lord.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmcccvi{Should We treat those who submit and obey in the same way as those who are culpable?\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmcccvii{What has come upon you that you judge in such a wise?\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmcccviii{Or have you a Book in which you read\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmcccix{That you can surely have whatever you choose?\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmcccx{Or have you taken a binding promise from Us which would hold till the Day of Judgement, that you will get whatever you demand?\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmcccxi{Ask them: ``Which of you is able to vouch for this?"\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmcccxii{Or have they any partners? Let them bring their partners then, if what they say is true.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmmcccxiii{On the day the great calamity befalls, and they are called to bow in homage, they will not be able to do so.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmmcccxiv{Lowered will be their eyes, disgrace overwhelming them. They had indeed been called to bow in homage when they were free of blame.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmmcccxv{So leave those who deny this Discourse to Me. We shall lead them step by step to (ruin) in a way they will not know.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmmcccxvi{Yet I will give them respite: Surely My plan is compact.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmmcccxvii{Do you ask for any compensation from them that they are burdened with want?\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmmcccxviii{Or do they have knowledge of the unknown which they copy down?\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmmcccxix{So wait with patience for the judgement of your Lord, and do not be like (onah) of the fish who called (to his Lord) when he was choked with anger.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmmcccxx{Had it not been for a favour from his Lord he would have been cast blame-worthy on a barren plain.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxi{Then his Lord chose him and placed him among the upright.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxii{But the unbelievers would like to stare you out of balance when they hear the warning, and say: ``Surely he is possessed;"\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{Whilst it is no more than reminder for the people of the world.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{\basmalahen THE CONCRETE REALITY.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxv{What is the concrete reality?\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{What do you comprehend by the concrete reality?\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{The Thamud and 'Ad denied the consequential calamity.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{So destroyed were the Thamud by a storm of thunder and lightning;\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxix{And the 'Ad were destroyed by the furious cold blast of roaring wind\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxx{Which He sent to assail them for seven nights and eight days running. You should have seen the people prostrate like the decayed trunks of date-palm trees.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{Do you see any trace of them?\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{Then came the Pharaoh, and those before him whose habitations were overthrown while they were committing crimes.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{When they disobeyed the apostle of their Lord He seized them with an overwhelming punishment.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{When the water rose in flood, We bore you in the ark,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{In order to make it a warning for you, and that the ear retentive may preserve it.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{When the single blast is sounded on the trumpet,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{And the earth and mountains heaved and crushed to powder with one levelling blow,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{On that Day will come what is to come.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{The sky will cleave asunder on that day and fall to pieces.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcccxl{On its fringes will be angels, eight of them, bearing their Lord's throne aloft.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcccxli{You will then be set before Him, and not one of you will remain unexposed.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcccxlii{He who is given his ledger in his right hand, will say: ``Here, read my ledger.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcccxliii{I was certain I'll be given my account."\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcccxliv{So he shall have an agreeable life\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcccxlv{In high empyrean\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{With fruits hanging low within reach,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{(And told:) ``Eat and drink to your fill as reward for (good) deeds you had done in days of yore."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{But whosoever gets his ledger in his left hand, will say: ``Would that I were never given my ledger,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmcccxlix{And not known my account!\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmcccl{I wish death had put an end to me.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmcccli{Of no use was even my wealth.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmccclii{Vanished has my power from me."\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmcccliii{``Seize him and manacle him,\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmcccliv{Then cast him to be burnt in Hell;\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmccclv{And string him to a chain seventy cubits long.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmccclvi{He did not believe in God the supreme,\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmccclvii{Nor urged others to feed the poor.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmccclviii{That is why he has no friend today,\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmccclix{Nor food other than suppuration (filth)\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmccclx{Which none but the hellish eat."\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmccclxi{So, I call to witness what you see\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmccclxii{And what you do not see,\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmccclxiii{That this is indeed the word of the noble Messenger,\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmccclxiv{And not the word of a poet. How little is it that you believe!\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmmccclxv{Nor is it the word of a soothsayer. Little is it that you reflect!\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmmccclxvi{It has been sent down by the Lord of all the worlds.\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmmccclxvii{Had he attributed falsely any words to Us,\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmmccclxviii{We would have seized him by his right hand,\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmmccclxix{Then cut off his aorta,\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmmccclxx{And not one of you would have been able to stop (Us).\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxi{It is really a reminder for those who fear God and follow the straight path.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxii{We certainly know that some among you do deny it.\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{It is surely the nemesis of unbelievers.\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{And He, He is indeed the ultimate Reality.\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxv{So glorify your Lord, the most supreme.\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{\basmalahen AN INQUIRER ASKED for the affliction that is to come\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{Upon the infidels -- which none would be able to repel --\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{From God, the Lord of the steps (of progression),\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxix{To whom the angels and the soul take a day to ascend, whose length is fifty thousand years.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxx{So persevere with becoming patience.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{They surely take it to be far away,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{But We see it very near.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{The day the sky becomes like molten brass,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{The mountains like the tufts of (carded) wool,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{And no friend inquires after friend\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{Though within sight of one another. The sinner would like to ransom himself from the torment of that Day by offering his sons,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{His wife and his brother,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{And his family who had stood by him,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{And all those who are on the earth, to save himself.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcccxc{But never. It is pure white flame\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcccxci{That would skin the scalp.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcccxcii{It will summon whoever turns his back and flees,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcccxciii{Who amasses and then hoards.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcccxciv{Surely man is greedy by nature.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcccxcv{If evil befalls him he is perturbed;\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{If good comes to him he holds back his hand,\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{Except those who closely follow (the Book of God),\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{Who persevere in devotion,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmcccxcix{In whose wealth a due share is included\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmcd{For the needy and those dispossessed,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmcdi{And those who believe in the Day of Judgement,\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmcdii{And those who fear the punishment of their Lord, --\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmcdiii{Surely no one can be secure from the punishment of his Lord, --\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmcdiv{And those who guard their sex except from their wives and women slaves of old\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmcdv{Are free of blame,\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmcdvi{But those who seek more than this will be transgressors;\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmcdvii{And those who fulfil their trusts and covenants,\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmcdviii{Who uphold their testimonies,\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmcdix{And those who are mindful of their moral obligations.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmcdx{They will live in gardens with honour.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmcdxi{What is the matter with unbelievers that they stare at you with fixed gazes and hasten towards you\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmcdxii{In crowds, right and left?\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmcdxiii{Does every one of them wish to enter the garden of tranquility?\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmcdxiv{Never so. We have created them from what they know.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmcdxv{So I swear by the Lord of the Easts and the Wests that We are certainly able\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmcdxvi{To bring better people than they in their place; and they will not be able to thwart Us.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmmcdxvii{So leave them to their vain disputes and amusement till they meet their day (of reckoning) promised them,\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmmcdxviii{The day when they will come out of their graves in all haste as though rushing to their altars,\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmmcdxix{Eyes lowered, shame attending. That is the day they have been promised!\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmmcdxx{\basmalahen SENT NOAH to his people to warn them before the painful punishment came upon them.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxi{He said: ``O my people, I warn you clearly\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxii{That you should worship God and fear Him, and follow me\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{That He may forgive some of your sins and prolong your term till an appointed time. Surely when God's appointed time is come it will not be put off, if only you knew!\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{He said: ``O Lord, I called my people night and day,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxv{But the more I called, they only ran the farther away.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{And every time I called them that You may forgive them, they thrust their fingers into their ears, and covered themselves with their garments, and became wayward, and behaved with downright insolence.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{Then I called them loudly and more openly,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{And declared to them in public and in private,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxix{And I told them: 'Ask your Lord to forgive you. He is verily forgiving.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxx{He will send you abundant rain from the sky,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{And will give you increase of wealth and sons, and give you gardens and springs of water.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{What has come upon you that you do not fear the majesty of God,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{Knowing that He has created you by various stages?\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{Do you not see how God has fashioned seven skies one above the other,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{And has placed the moon therein, an illumination, and has placed the sun, a lighted lamp?\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{God produced you from the earth like a vegetable growth;\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{He will then return you back to it, and bring you out again.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{God has made the earth for you a spreading,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{So that you may walk upon its spacious paths.'\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcdxl{But they did not listen to me," Noah said, ``and followed him whose wealth and children only added to his ruin.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcdxli{And they contrived a plot of great magnitude,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcdxlii{And said: 'Do not abandon your gods, and do not abandon Wadda or Suwa', or Yaghuth, Ya'uq or Nasr.'\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmcdxliii{And they misled many. So do not give the evil-doers increase but in error.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmcdxliv{They were drowned because of their habitual sinfulness, and sent to Hell, and did not find any helper other than God.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmcdxlv{Noah said: ``O Lord, do not leave a single habitation of unbelievers on the earth.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{If you leave them, they will lead Your creatures astray, and beget but iniquitous and ungrateful offspring.\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{O Lord, forgive me, my parents, and any one who enters my house as a believer, and all believing men and women, and do not give the evil-doers increase save in ruin.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{\basmalahen SAY: ``I HAVE been informed that a number of jinns had listened; then said: 'We have heard the wondrous Qur'an,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcdxlix{Which guides to the right path; and we have come to believe in it, and will not associate any one with our Lord.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcdl{Exalted is the glory of our Lord; He has neither wife nor son.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcdli{Certainly the foolish among us say preposterous things of God.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcdlii{We had in fact thought that men and jinns would never speak a lie about God,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcdliii{But some men used to seek refuge with some jinns, and this increased their waywardness;\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcdliv{So they began to think, even as you do, that God would not resurrect any one.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcdlv{We sought to pry into the secrets of the heavens, but found it full of fierce guards and shooting flames.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcdlvi{We sat in observatories to listen; but any one who listened found a shooting star in wait for him.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcdlvii{We do not know if this means ill for the dwellers of the earth, or their Lord wishes guidance for them.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcdlviii{For some of us are upright and some otherwise: Surely we follow different ways.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcdlix{We realised that we could not weaken the power of God on earth, nor outpace Him by running away.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcdlx{So when we heard the guidance we believed in it; and he who believes in his Lord will neither fear loss nor force.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxi{Some of us have come to submission, and some of us are iniquitous.'" Those who have submitted have taken the right course;\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxii{But those who are iniquitous will be fuel for Hell.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{(Say): ``If they keep to the right path We shall give them water in abundance to drink\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{In order to try them through it. But whoever turns away from the remembrance of his Lord, will be given increasing torment by Him."\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxv{All places of worship are for God; so do not invoke any one with God.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{When the devotee of God stood up to invoke Him (the jinns) crowded upon him (to listen).\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{Say: ``I call on my Lord alone and I do not associate any one with Him."\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{Say: ``Neither is your loss within my power nor bringing you to guidance."\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxix{Say: ``No one can save me from God, nor can I find a place of refuge apart from Him,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxx{Unless I convey from God and deliver His message." For those who disobey God and His Apostle is the fire of Hell, where they will abide for ever;\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{Until they see what they are promised, when they will understand who is weaker in aid and poorer in numbers.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{Say: ``I do not know if what is promised you is near, or if my Lord prolongs its term.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{He is the knower of the Unknown, and He does not divulge His secret to any one\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{Other than an apostle He has chosen, when He makes a sentinel walk in front of him and a sentinel behind,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{So that He may know if they have delivered their Lord's messages. He comprehends all that has been given them, and keeps count of everything.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{\basmalahen O YOU ENWRAPPED in the cloak (of Prophethood),\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{Keep watch all the night except some,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{A half of it or a little less\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{Or a little more, and recite the Qur'an slowly and distinctly.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{We shall soon entrust to you a message heavy (with solemnity).\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{Surely in the watches of the night the soul is most receptive and words more telling.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{Indeed during the day you have a long schedule of occupations.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{But recite the name of your Lord withdrawing yourself from everything, devoting yourself exclusively to Him.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{He is the Lord of the East and the West. There is no god but He. So take Him alone as your protector.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{Bear with patience what they say, and gracefully come away from them.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{Leave those to Me who deny, the lovers of ease and comfort; and bear with them for a while.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{Verily We shall have fetters with Us, and a roaring furnace,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{And food that will stick in the throat, and painful torment\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{On the day the earth and mountains will rock violently, and the mountains turn to a heap of poured-out sand.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcdxc{We have sent an Apostle to you as a witness against you, as We had sent an apostle to the Pharaoh.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcdxci{But the Pharaoh disobeyed the apostle; so We seized him with a grievous punishment.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcdxcii{How then, if you disbelieve, will you preserve yourselves on the day which will even turn the children hoary?\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcdxciii{The heavens itself will be rent asunder (on that day). His promise is bound to be fulfilled.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcdxciv{Verily this is a reminder. So let him who desires take the way to his Lord.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcdxcv{Your Lord surely knows that you are occupied with your devotions for nearly two-thirds of the night, or half the night, or one-third of it, as do many others with you. Yet God prescribes the measure of night and day. He knows you cannot calculate it, and so turns to you in benevolence. So recite as much of the Qur'an as you can easily. He knows some among you will be sick, and some will be travelling over the earth in search of the bounty of God, and some fighting in the way of God. So read as much from it as you can easily, and be firm in devotion, pay the zakat, and lend a goodly loan to God. And what you send for yourself of the good, you will find it with God better and greater in reward. So ask for God's forgiveness. Indeed God is forgiving and kind.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{\basmalahen O YOU ENFOLDED in your mantle (of reform),\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{Arise and warn,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{Glorify your Lord,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcdxcix{Purify your inner self,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmd{And banish all trepidation.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdi{Do not bestow favours in expectation of return,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdii{And persevere in the way of your Lord.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdiii{For when the trumpet blows\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdiv{It will be a day of distress,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdv{Dolorous for the unbelievers.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdvi{Leave him to Me whom I created alone,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdvii{And gave him abundant wealth\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdviii{And sons always present by his side,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdix{And made things easy for them.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdx{Yet he wants that I should give him more.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdxi{Never. He is refractory of Our signs.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdxii{I shall inflict on him hardship,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdxiii{For he had thought and calculated.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdxiv{May he be accursed, how he planned!\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdxv{May be then be accursed, how he plotted!\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmdxvi{Then he looked around,\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmdxvii{And frowned and puckered his brow,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmdxviii{Then turned his back and waxed proud,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmdxix{And said: ``This is nothing but the magic of old,\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmdxx{Nothing more than the speech of a man!"\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmdxxi{I will cast him into the fire of Hell.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmdxxii{What do you think Hell-fire is?\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmdxxiii{It leaves nothing, nor does it spare;\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmdxxiv{It glows and burns the skin.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmdxxv{Over it are nineteen (guards).\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmdxxvi{We have not appointed any one but angels as keepers of Hell, and their number that We have fixed is to make it a means of contention for disbelievers, so that those who were given the Book may be certain, and the faith of the believers may have greater increase, and the people of the Book and believers may not be deceived, and the sceptics and infidels may say: ``What does God mean by this parable?" That is how God leads whosoever He will astray, and guides whosoever He will. None knows the armies of your Lord save Him self. This is no more than reminder for mankind.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmdxxvii{I say the truth, and call the moon to witness,\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmdxxviii{And the night when on the wane,\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmdxxix{The morning when it is unveiled,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmdxxx{That (Hell) is surely one of the greater (signs),\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmdxxxi{A warning for people --\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmdxxxii{Whoever of you desires to progress or lag behind.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{Every soul is pledged to what it does,\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{Except those of the right hand\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmdxxxv{Sitting in the gardens, asking\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{Of evil-doers:\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{``What was it that brought you to Hell?"\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{They will answer: ``We did not fulfil our devotional obligations,\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmmdxxxix{And did not feed the needy,\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmmdxl{And plunged into useless things with those who were obstinate,\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmmdxli{And rejected the Day of Judgement as a lie\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmmdxlii{Until the certainty (of death) had come upon us.\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmmdxliii{So, the intercession of intercessors will not avail them.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmmdxliv{Why then do they turn away from the admonition\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmmdxlv{As though they were frightened asses\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmmdxlvi{Fleeing from a lion?\qt@no{(51)}}
\qt@newcmd\qurantrans@en@mmmmmdxlvii{In fact every one of them wants to be given open books (like the prophets).\qt@no{(52)}}
\qt@newcmd\qurantrans@en@mmmmmdxlviii{By no means. In fact they do not fear the Hereafter.\qt@no{(53)}}
\qt@newcmd\qurantrans@en@mmmmmdxlix{Never so, as this is a reminder.\qt@no{(54)}}
\qt@newcmd\qurantrans@en@mmmmmdl{Let him then who heeds remember it.\qt@no{(55)}}
\qt@newcmd\qurantrans@en@mmmmmdli{But they will not remember except as God wills: He is worthy to be feared, and He is worthy of forgiving\qt@no{(56)}}
\qt@newcmd\qurantrans@en@mmmmmdlii{\basmalahen I CALL TO WITNESS the Day of Resurrection,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdliii{And I call the reprehensive soul to witness:\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdliv{Does man think We shall not put his bones together?\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdlv{Surely We are able to reform even his finger-tips.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdlvi{Yet man is sceptical of what is right before him.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdlvii{He asks: ``When will the Day of Resurrection be?"\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdlviii{Yet when the eyes are dazzled,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdlix{The moon eclipsed,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdlx{And the sun and moon are conjoined,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdlxi{That day man will say: ``Where can I find escape?"\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdlxii{Never so, for there will be no escape.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdlxiii{With your Lord alone will be the retreat on that day.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdlxiv{Then man will be told what he had sent ahead (of good) and what he had left behind.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdlxv{In fact man is a witness against himself,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdlxvi{Whatever the excuses he may offer.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdlxvii{Do not forestall (the revelation before its completion) by acting in haste.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdlxviii{Surely its collection and recitation are Our responsibility.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdlxix{So, as We recite it, follow its reading.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdlxx{The exposition of its meaning surely rests on Us.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxi{But no. You love this transient life,\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxii{And neglect the Hereafter.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{How many faces will be refulgent on that Day,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{Waiting for their Lord.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxv{And how many faces on that Day will be woe-begone\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{Fearing that a great disaster is going to befall them.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{Never so, for when life withdraws into the clavicula,\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{And it is asked: ``Is there any reciter of charms and amulets?"\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxix{He will then realise it is the parting,\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxx{And anguish will be heaped upon anguish:\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{To your Lord then will be the driving.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{For he neither believed nor prayed,\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{But only disavowed and turned away;\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{Then he strutted back to his people.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{Alas the woe for you, alas!\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{Alas, the woe for you!\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{Does man think that he will be left alone to himself, free?\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{Was he not an emitted drop of semen,\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{Then formed into an embryo? Then He fashioned, shaped and proportioned\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmdxc{And assigned it sexes, male and female.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmdxci{Cannot such as He bring the dead to life?\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmdxcii{\basmalahen WAS THERE NOT a time in the life of man when he was not even a mentionable thing?\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdxciii{Verily We created man from a sperm yoked (to the ovum) to bring out his real substance, then gave him hearing and sight.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdxciv{We surely showed him the way that he may either be grateful or deny.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdxcv{We have prepared for unbelievers chains and collars and a blazing fire.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdxcvi{Surely the devotees will drink cups flavoured with palm blossoms\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdxcvii{From a spring of which the votaries of God will drink and make it flow in abundance.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdxcviii{Those who fulfil their vows and fear the Day whose evil shall be diffused far and wide,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdxcix{And feed the needy for the love of Him, and the orphans and the captives,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdc{(Saying): ``We feed you for the sake of God, desiring neither recompense nor thanks.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdci{We fear the dismal day calamitous from our Lord."\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdcii{So God will protect them from the evil of that day, and grant them happiness and joy,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdciii{And reward them for their perseverence Paradise and silken robes,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdciv{Where they will recline on couches feeling neither heat of the sun nor intense cold.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdcv{The shadows will bend over them, and low will hang the clusters of grapes.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdcvi{Passed round will be silver flagons and goblets made of glass,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdcvii{And crystal clear bottles of silver, of which they will determine the measure themselves.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdcviii{There will they drink a cup flavoured with ginger\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdcix{From a spring by the name of Ever-flowing-Salsabil.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdcx{And boys of everlasting youth will go about attending them. Looking at them you would think that they were pearls dispersed.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdcxi{When you look around, you will see delights and great dominion.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmdcxii{On their bodies will be garments of the finest green silk and brocade, and they will be adorned with bracelets of silver; and their Lord will give them a purest draught to drink.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmdcxiii{``This in truth is your recompense, and acceptance of your endeavours."\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmdcxiv{We have revealed the Qur'an to you gradually;\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmdcxv{So wait for your Lord's command, and do not follow any sinner or disbeliever among them.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmdcxvi{Meditate upon the name of your Lord morning and evening;\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmdcxvii{And bow in homage part of the night, and glorify Him far into the night.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmdcxviii{Surely men love what hastes away and forget the grievous day (ahead).\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmdcxix{We created them and fixed their bones and joints; and We could replace them when We like with others like them.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmdcxx{This surely is a reminder: Therefore whosoever desires may take the way to his Lord.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxi{But you will not desire except as God wills. Verily He is all-knowing and all-wise.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxii{He admits whosoever He will to His benevolence. But for the evil-doers He has prepared a painful punishment.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{\basmalahen I CALL TO WITNESS those who are sent consecutively,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{And those that strike violently,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxv{And those that revive by quickening,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{And those that distinguish distinctly,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{And those that bring down the Reminder\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{To end all argument or to warn.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxix{What is promised will surely come to pass.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxx{When the stars are obliterated,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{The heavens split asunder,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{The mountains reduced to dust and blown away,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{And when the time comes for raising the little girls (buried alive) --\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{For what day is that time fixed?\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{The Day of Judgement.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{How will you comprehend what the Day of Judgement is?\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{Alas the woe that day for those who deny!\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{Have We not destroyed the earlier generations?\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{So shall We make the later ones to follow them.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdcxl{That is what We shall do to those who are guilty of crime.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdcxli{Alas the woe that day for those who deny!\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdcxlii{Did We not create you from contemptible water?\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmdcxliii{Then We lodged you in a secure place (the womb)\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmdcxliv{For a certain appointed time,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmdcxlv{Then We facilitated (your birth). How well do We calculate!\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{Alas the woe that day for those who deny!\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{Have We not made the earth a repository\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{For the living and the dead,\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmdcxlix{And placed in it lofty and broad stablisers, and gave you sweet water to drink?\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmdcl{Alas the woe that day for those who deny!\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmdcli{``Go to what you used to deny;\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmdclii{Go to the shadow with three ramifications,\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmdcliii{Neither shady nor protecting against the blazing Fire.\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmdcliv{It will throw out sparks as logs of wood\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmdclv{So like golden camels."\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmdclvi{Alas the woe that day for those who deny!\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmdclvii{They will not be able to speak that day,\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmdclviii{Nor given leave to make excuses.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmdclix{Alas the woe that day for those who deny!\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmdclx{That will be the Day of Reckoning. Gathered will be (you) and the earlier (generations).\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmdclxi{So if you have any plot to devise against Me, then devise it.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmdclxii{Alas the woe that day for those who deny!\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmdclxiii{Those who take heed for themselves and fear God, will be amidst shade and springs of water,\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmmdclxiv{And such fruits as they desire.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmmdclxv{``Eat and drink with relish as reward for what you had done."\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmmdclxvi{That is how We reward the good.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmmdclxvii{Alas the woe that day for those who deny!\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmmdclxviii{Eat and enjoy for a while: You are certainly sinners.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmmdclxix{Alas the woe that day for those who deny!\qt@no{(47)}}
\qt@newcmd\qurantrans@en@mmmmmdclxx{When it is said to them: ``Bow in homage," they do not bow.\qt@no{(48)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxi{Alas the woe that day for those who deny!\qt@no{(49)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxii{In what other lore after this will they then believe?\qt@no{(50)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{\basmalahen OF WHAT ARE they asking one another?\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{(Is it) of the great announcement\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxv{About which they have been differing?\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{Indeed they will come to know soon;\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{They will indeed come to know soon.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{Did We not make the earth a spreading,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxix{The mountains tent-pins?\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxx{We created you in pairs,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{And made sleep for you to rest,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{The night a covering,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{And the day for seeking livelihood.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{We raised over you several secure (skies),\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{And placed a lamp therein brightly burning.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{And We sent down rain from water-laden clouds pouring in torrents\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{That We may produce from it grain and vegetation,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{And orchards full of trees and interlacing boughs.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{Surely a time is fixed for the Day of Judgement.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdcxc{The day the trumpet blast is sounded you will come in hordes;\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdcxci{The heavens will be opened wide and turn into so many doors,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdcxcii{The mountains put in motion turning into a mirage.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmdcxciii{Certainly Hell lies in wait,\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmdcxciv{The rebels' abode,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmdcxcv{Where they will remain for aeons,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{Finding neither sleep nor any thing to drink\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{Except boiling water and benumbing cold:\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{, A fitting reward.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmdcxcix{They were those who did not expect a reckoning,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmdcc{And rejected Our signs as lies.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmdcci{We have kept account of everything in a book.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmdccii{So taste (the fruit of what you sowed), for We shall add nothing but torment,\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmdcciii{As for those who preserve themselves from evil and follow the straight path, there is attainment for them:\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmdcciv{Orchards and vineyards,\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmdccv{And graceful maidens of the same age,\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmdccvi{And flasks full and flowing.\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmdccvii{They will hear no blasphemies there or disavowals:\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmdccviii{A recompense from your Lord, a sufficient gift,\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmdccix{The Lord of the heavens and the earth, and all that lies between them, most benevolent, to whom none may dare address a word.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmdccx{The day the Spirit takes its stand, with the angels ranged in rows. None will speak except who is permitted by Ar-Rahman and says what is right.\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmdccxi{That day is certain. So whosoever likes may prepare a way to his Lord.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmdccxii{We have indeed warned you of a calamity near at hand, a day when man will see what he had sent (of his deeds) ahead, and the unbeliever will say: ``Woe alas. Ah would that I were dust!"\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmdccxiii{\basmalahen I CALL TO WITNESS those who dive and drag,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdccxiv{And those who undo the bonds gently,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdccxv{And those who glide swimmingly,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdccxvi{Then outpace the others swiftly\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdccxvii{And direct affairs by command,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdccxviii{The day the convulsive (first blast) shatters convulsively\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdccxix{Followed by the second blast,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdccxx{Hearts will pound loudly on that day,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxi{Eyes be lowered in submission.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxii{They say: ``Shall we go back to our original state\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{After having turned to carious bones?"\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{They say: ``Then this returning will be a dead loss."\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxv{It will only be a single blast,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{And they will wake up suddenly.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{Has the story of Moses come to you\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{When his Lord called to him in Tuwa's holy vale?\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxix{``Go to the Pharaoh who has become refractory,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxx{And say: 'Would you like to grow (in virtue)?\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{Then I will guide you to your Lord that you may come to fear Him.'"\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{So he showed him the greater sign;\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{But (the Pharaoh) disavowed and disobeyed.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{Then he turned away, deliberating,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{And assembled (his council) and proclaimed,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{Saying: ``I am alone your lord, the highest of them all."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{So God seized him for the punishment of the Hereafter and this world.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{Truly there is a lesson in this for those who fear (the consequences).\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{Are you more difficult to create or the heavens? He built it,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmdccxl{Raised it high, proportioned it,\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmdccxli{Gave darkness to its night, and brightness to its day;\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmdccxlii{And afterwards spread out the earth.\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmdccxliii{He brought out its water and its pastures from it,\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmdccxliv{And stabilized the mountains\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmdccxlv{As convenience for you and your cattle.\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{When the great calamity comes,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{The day when man remembers all that he had done,\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{And Hell made visible to him who can see,\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmdccxlix{Then he who had been rebellious\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmdccl{And who preferred the life of the world,\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmdccli{Will surely have Hell for his abode.\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmdcclii{But he who feared standing before his Lord, and restrained his self from vain desires,\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmdccliii{Will surely have Paradise for abode.\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmmdccliv{They ask you: ``When will the Hour be? When is its time fixed?"\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmmdcclv{What do you have to do with explaining it?\qt@no{(43)}}
\qt@newcmd\qurantrans@en@mmmmmdcclvi{The extent of its knowledge goes to your Lord.\qt@no{(44)}}
\qt@newcmd\qurantrans@en@mmmmmdcclvii{Your duty is only to warn him who fears it.\qt@no{(45)}}
\qt@newcmd\qurantrans@en@mmmmmdcclviii{The day they see it, it will seem they had stayed in the world but only an evening or its turning into dawn.\qt@no{(46)}}
\qt@newcmd\qurantrans@en@mmmmmdcclix{\basmalahen HE FROWNED AND turned away,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdcclx{Because a blind man came to him.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxi{What made you think that he will not grow in virtue,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxii{Or be admonished, and the admonition profit him?\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{As for him who is not in want of any thing,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{You pay full attention,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxv{Though it is not your concern if he should not grow (in fulness).\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{As for him who comes to you striving (after goodness),\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{And is also fearful (of God),\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{You neglect.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxix{Assuredly this is a reminder\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxx{For any one who desires to bear it in mind,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{(Contained) in honoured pages,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{Exalted and holy,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{In the hands of scribes\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{Noble and pious.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{Accursed is man. How ungrateful is he!\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{Of what substance God created him?\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{From a single sperm He created, then proportioned him,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{Then made his passage easy (at birth);\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{He will then send him to death and have him laid in the grave.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{Then He will raise him up again when He please.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{But no. He has not fulfilled what was enjoined on him.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{Let man therefore consider (the sources of) his food.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{We poured down rain abundantly,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{Then We cracked the earth open under pressure (of germination)\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{And We made corn grow,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{And grapes and herbage,\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{Olives and dates,\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{Orchards thick with trees,\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{And fruits and fodder:\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmdccxc{A provision for you and your cattle.\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmdccxci{But when the great calamity comes\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmdccxcii{Man will fly from his brother,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmdccxciii{Mother and father,\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmdccxciv{As well as his wife and children.\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmdccxcv{Each man will have enough cares that day.\qt@no{(37)}}
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{Many faces will that day be bright,\qt@no{(38)}}
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{Laughing and full of joy,\qt@no{(39)}}
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{And many will be dust-begrimed,\qt@no{(40)}}
\qt@newcmd\qurantrans@en@mmmmmdccxcix{Covered with the blackness (of shame):\qt@no{(41)}}
\qt@newcmd\qurantrans@en@mmmmmdccc{They will be the unbelievers, transgressors.\qt@no{(42)}}
\qt@newcmd\qurantrans@en@mmmmmdccci{\basmalahen WHEN THE SUN is folded up,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdcccii{The stars turn dim and scatter,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdccciii{The mountains made to move,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdccciv{The ten-month pregnant female camels are abandoned,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdcccv{The wild beasts stampede on the run,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdcccvi{When the oceans surge and swell,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdcccvii{When souls are reunited (with the bodies)\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdcccviii{And the little girl buried alive is asked\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdcccix{For what crime she was put to death;\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdcccx{When the ledgers are laid open,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxi{The curtain drawn back from the skies,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxii{When Hell is set ablaze,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{And Paradise brought near,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{(Then) every soul will know what it had prepared (for itself).\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxv{So, I call the receding stars to witness,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{The planets withdrawing into themselves,\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{The closing night,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{The rising dawn,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxix{That this is indeed the word of an honoured Messenger,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxx{Full of power, well-established (in position) with the Lord and Master of the Throne,\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{Obeyed and worthy there of trust.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{Your companion is not mad.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{He had surely seen Him on the clear horizon.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{He is not chary of making public what is unknown.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{This is not the utterance of an accursed devil.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{So whither do you stray?\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{This is a reminder for all the peoples of the world,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{For those of you who desire to walk the path that is straight,\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{Though you cannot desire except as God will, the Lord of all the worlds.\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{\basmalahen WHEN THE SKY is split asunder,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{And the stars dispersed,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{When the oceans begin to flow,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{When the graves are overturned,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{Each soul will know what it had sent ahead and what it had left behind.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{O man, what seduced you from your munificent Lord\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{Who created you then formed your symmetry, then gave you right proportion,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{Shaping you into any form He pleased?\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{Even then you deny the Judgement.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{Surely there are guardians over you,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxl{Illustrious scribes\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxli{Who know what you do.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{The pious will surely be in heaven,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{The wicked certainly in Hell:\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{They will burn in it on the Day of Judgement,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{And will not be removed from it.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{How can you comprehend what the Day of Judgement is?\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{How then can you comprehend what the Day of Judgement is?\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{It is the day when no soul will have power to do the least for a soul, and God's alone will be done.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{\basmalahen WOE TO THOSE who give short measure,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdcccl{Who insist on being given full when they take from others,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdcccli{Whilst when they measure or weigh for them, give less.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdccclii{Do they not think they will be raised (to life) again\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdcccliii{On a grievous day,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdcccliv{The day all mankind will stand before the Lord of all the worlds?\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdccclv{Indeed the ledger of the wicked will be in (the lowest depths) Sijjin.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdccclvi{How will you comprehend what Sijjin is?\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdccclvii{It is a (repository of) distinctly written record.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdccclviii{Ah the woe that day for those who deny,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdccclix{Who call the Day of judgement a lie!\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdccclx{None denies it but the sinful transgressors.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxi{When Our revelations are recited before him, he says: ``These are fables of long ago."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxii{No. In fact what they have been doing has rusted their hearts.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{Therefore they will be screened off from their Lord that day,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{Then they will indeed burn in Hell.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxv{They will then be told: ``This is what you had denied."\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{Surely the ledger of the pious will be in 'Illiyun (heights above the heights).\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{But how will you comprehend what 'Illiyun is?\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{It is a (repository of) distinctly written record\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxix{Witnessed by those who are honoured.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxx{Verily the pious will be in heaven,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{On couches face to face.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{On their faces you will see the glow of beatitude.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{They will be served the choicest wine, sealed\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{With a sealing of musk, which those who aspire for the best should desire, --\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{Blended with the water of Tasnim, (heights ultimate of evolution),\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{A fountain from which only they who are honoured drink.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{The sinners indeed laughed at believers\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{And winked at one another as they passed by them;\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{And when they went back to their people turned to make fun of them;\qt@no{(31)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{And when they saw them, they said: ``They have indeed gone astray."\qt@no{(32)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{But they were not Sent to be guardians over them!\qt@no{(33)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{So, the believers will laugh at the infidels on that day,\qt@no{(34)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{Regarding them from their cushioned seats.\qt@no{(35)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{Will not the infidels pay for what they had done?\qt@no{(36)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{\basmalahen WHEN THE SKY is cleft asunder,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{And hearkens to its Lord and is dutiful,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{When the earth is stretched out taut\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{And throws out whatever it contains and is empty,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{And hearkens to its Lord and is dutiful,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxc{O man, you have to strive and go on striving towards your Lord, then will you meet Him.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxci{And he who is given his ledger in his right hand\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{Will have an easy reckoning,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{And will return to his people full of joy.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{But he who is given his ledger from behind his back\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{Will pray for death,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{But will be roasted in the fire.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{He lived rejoicing among his people,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{Never thinking he will return.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{Why not? His Lord was always watching him.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcm{So indeed I call to witness the evening twilight,\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcmi{And the night and all it gathers,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcmii{And the moon when at the full,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcmiii{That you will climb from stage to stage.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcmiv{So, wherefore do they not believe?\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcmv{And when the Qur'an is recited to them do not bow in adoration?\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcmvi{In fact the unbelievers disavow.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcmvii{But God knows what they harbour in their breasts.\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmcmviii{So give them news of painful punishment,\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmcmix{Except those who believe and do the right: For them there is reward unending.\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmcmx{\basmalahen I CALL TO witness the sky (bespangled) with the signs of the Zodiac,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcmxi{And the promised day,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcmxii{And the witness and the witnessed,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcmxiii{That accursed are the men of the trench\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcmxiv{Full of fire fed by faggots,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcmxv{As they sat around it\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcmxvi{Witnessing what they had done to the believers!\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcmxvii{They had no other reason for hating them except that they believed in God the mighty, worthy of praise,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcmxviii{Whose kingdom spreads over the heavens and the earth. God is witness over everything.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcmxix{Surely for those who persecute believers, men and women, and do not repent afterwards, is the punishment of Hell, and the punishment of burning.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcmxx{Surely for those who believe and do the right are gardens with rivers running by. That is the greatest success.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxi{The grip of your Lord is severe indeed!\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxii{It is verily He who initiates and repeats.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{He is the forgiving and the loving,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{The Lord of the glorious Throne,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxv{Who does as He pleases.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{Has the story of the hordes\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{Of Pharaoh and Thamud come to you?\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{Yet the infidels persist in denial.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxix{But God surrounds them from all sides.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxx{This is indeed the glorious Qur'an\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{(Preserved) on the guarded tablet.\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{\basmalahen I CALL TO witness the heavens and the night Star --\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{How will you comprehend what the night star is?\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{It is the star that shines with a piercing brightness --\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{That over each soul there is a guardian.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{Let man consider what he was made of:\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{He was created of spurting water\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{Issuing from (the pelvis) between the backbone and the ribs.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{God has certainly power to bring him back (from the dead).\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcmxl{The day all secrets are examined\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcmxli{He will have no strength or helper.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcmxlii{So I call to witness the rain-producing sky,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcmxliii{And the earth which opens up (with verdure),\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcmxliv{That this (Qur'an) is a decisive word\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcmxlv{And no trifle.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{They are hatching up a plot,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{But I too am devising a plan.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{So bear with unbelievers with patience, and give them respite for a while.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcmxlix{\basmalahen GLORIFY THE NAME of your Lord, most high,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcml{Who creates and proportions,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcmli{Who determines and directs,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcmlii{Who brings out the pastures\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcmliii{Then reduces them to rusty rubbish.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcmliv{We shall make you recite (the Qur'an) so that you will not forget it,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcmlv{Unless God may please. He knows the visible and knows what is hidden.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcmlvi{We shall take you slowly towards ease.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcmlvii{So remind them if reminder is profitable:\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcmlviii{Those who fear will understand.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcmlix{Only the wretch will turn aside,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcmlx{Who will burn in the terrible Fire,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxi{In which he will neither die nor live.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxii{Surely he will succeed who grows in goodness,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{And recites the name of his Lord and serves with devotion.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{But no, you prefer the life of the world,\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxv{Though the life to come is better and abiding.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{This is surely in the earlier Books,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{The Books of Abraham and Moses.\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{\basmalahen HAS NEWS OF the Overpowering Event reached you?\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxix{Many faces will be contrite on that day,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxx{Labouring, wearied out,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{Burning in the scorching fire,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{Given water from the boiling spring to drink.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{They will have no food except bitter thorn,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{Neither nourishing nor banishing hunger.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{Many faces will be joyous on that day,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{Well-pleased with their endeavour,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{In the high empyrean,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{Never hearing idle talk.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{There is a stream of running water in it;\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{And within it are couches placed on high,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{Goblets set,\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{Cushions arranged,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{And rich carpets spread.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{Do they not then ponder how the clouds were formed;\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{And the heavens, how it was raised high;\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{And the mountains, how they were fixed;\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{And the earth, how it was spread out?\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{Remind them; you are surely a reminder.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{You are not a warden over them,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmcmxc{Other than him who turns his back and denies,\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmcmxci{In which case he will be punished by God with the severest punishment.\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmcmxcii{To Us is surely their returning;\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmcmxciii{Ours is surely then to reckon with them.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmcmxciv{\basmalahen I CALL TO witness the dawn\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmcmxcv{And the Ten Nights,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{The multiple and the one,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{The night as it advances,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{Is there not an evidence in this for those who have sense?\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmcmxcix{Have you not seen what your Lord did to the 'Ad\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmm{Of Eram with lofty pillars (erected as signposts in the desert),\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmi{The like of whom were never created in the realm;\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmii{And with Thamud who carved rocks in the valley;\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmmiii{And the mighty Pharaoh\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmmiv{Who terrorised the region,\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmmv{And multiplied corruption.\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmmvi{So your Lord poured a scourge of punishment over them.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmmvii{Your Lord is certainly in wait.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmmviii{As for man, whenever his Lord tries him and then is gracious and provides good things for him, he says: ``My Lord has been gracious to me."\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmmix{But when He tries him by restraining his means, he says: ``My Lord despises me."\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmmx{No. In fact you are not generous to the orphans,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmmxi{Nor do you urge one another to feed the poor,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmmxii{And you devour (others') inheritance greedily,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmmxiii{And love wealth with all your heart.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmmxiv{Surely when We pound the earth to powder grounded, pounded to dust,\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmmxv{And comes your Lord, and angels row on row,\qt@no{(22)}}
\qt@newcmd\qurantrans@en@mmmmmmxvi{And Hell is brought near, that day will man remember, but of what avail will then remembering be?\qt@no{(23)}}
\qt@newcmd\qurantrans@en@mmmmmmxvii{He will say: ``Alas the woe! Would that I had sent ahead something in my life."\qt@no{(24)}}
\qt@newcmd\qurantrans@en@mmmmmmxviii{None can punish as He will punish on that day,\qt@no{(25)}}
\qt@newcmd\qurantrans@en@mmmmmmxix{And none can bind as He will bind.\qt@no{(26)}}
\qt@newcmd\qurantrans@en@mmmmmmxx{O you tranquil soul,\qt@no{(27)}}
\qt@newcmd\qurantrans@en@mmmmmmxxi{Return to your Lord, well-pleased and well-pleasing Him.\qt@no{(28)}}
\qt@newcmd\qurantrans@en@mmmmmmxxii{``Enter then among My votaries,\qt@no{(29)}}
\qt@newcmd\qurantrans@en@mmmmmmxxiii{Enter then My garden."\qt@no{(30)}}
\qt@newcmd\qurantrans@en@mmmmmmxxiv{\basmalahen I CALL THIS earth to witness --\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmxxv{And you are free to live upon it, --\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmxxvi{And the parent and the offspring,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmxxvii{That We created man in toil and trouble.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmxxviii{Does he think that no one has power over him?\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmxxix{He says: ``I have wasted a great deal of wealth."\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmxxx{Does he think that no one sees him?\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmxxxi{Did We not give him two eyes,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmxxxii{One tongue, and two lips,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{And showed him two highways (of good and evil)?\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{But he could not scale the steep ascent.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmmxxxv{How will you comprehend what the Steep ascent is? --\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{To free a neck (from the burden of debt or slavery),\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{Or to feed in times of famine\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{The orphan near in relationship,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmmxxxix{Or the poor in distress;\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmmxl{And to be of those who believe, and urge upon one another to persevere, and urge upon each other to be kind.\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmmxli{They are the people of the right hand (and will succeed).\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmmxlii{But those who deny Our revelations are the people of the left hand:\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmmxliii{The Fire will vault them over.\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmmxliv{\basmalahen I CALL TO witness the sun and his early morning splendour,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmxlv{And the moon as she follows in his wake,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmxlvi{The day when it reveals his radiance,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmxlvii{The night when it covers him over,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmxlviii{The heavens and its architecture,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmxlix{The earth and its spreading out,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmml{The soul and how it was integrated\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmli{And given the faculty of knowing what is disruptive and what is intrinsic to it.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmlii{He who nourishes it will surely be successful,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmmliii{And he who confines it will surely come to grief.\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmmliv{The Thamud denied (the truth) in their perverseness\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmmlv{When among them the great wretch arose,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmmlvi{And the apostle of God had to tell them: ``This is God's she-camel, let her drink."\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmmlvii{But they called him a liar and hamstrung her. So God obliterated them for their crime, and (destroyed) all of them alike.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmmlviii{He does not fear the consequence.\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmmlix{\basmalahen I CALL THE night to witness when it covers over,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmlx{And the day when it shines in all its glory,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmlxi{And Him who created the male and female,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmlxii{That your endeavour is for different ends.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmlxiii{Yet he who gives to others and has fear,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmlxiv{And affirms goodness,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmlxv{We shall ease the way of fortune for him.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmlxvi{But he who does not give and is unconcerned,\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmlxvii{And rejects goodness,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmmlxviii{For him We shall ease the way of adversity,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmmlxix{And his riches will not avail him when he falls headlong (into the Abyss).\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmmlxx{It is indeed for Us to show the way,\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxi{And to Us belong the End and the Beginning.\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxii{So, I warn you of the blazing Fire.\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{No one will burn in it but the most wretched,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{Who denied (the truth) and turned away.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxv{But save him who fears\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{And gives of his wealth that he may grow in virtue,\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{And is under no one's obligation to return his favour,\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{Other than seeking the glory of his Lord, most high,\qt@no{(20)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxix{Will surely be gratified.\qt@no{(21)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxx{\basmalahen I CALL TO witness the early hours of morning,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{And the night when dark and still,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{Your Lord has neither left you, nor despises you.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{What is to come is better for you than what has gone before;\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{For your Lord will certainly give you, and you will be content.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{Did He not find you an orphan and take care of you?\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{Did He not find you perplexed, and show you the way?\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{Did He not find you poor and enrich you?\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{So do not oppress the orphan,\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{And do not drive the beggar away,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmmxc{And keep recounting the favours of your Lord.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmmxci{\basmalahen HAVE WE NOT opened up your breast\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmxcii{And removed your burden\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmxciii{Which had left you devoid of hope,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmxciv{And exalted your fame?\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmxcv{Surely with hardship there is ease.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmxcvi{With hardship indeed there is ease.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmxcvii{So when you are free work diligently,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmxcviii{And turn to your Lord with all your love.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmxcix{\basmalahen I CALL TO witness the Fig and the Olive,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmc{The Mount Sinai,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmci{And this Soil Secure,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmcii{That We created man of finest possibilities,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmciii{Then brought him down to the lowest of the low,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmciv{Except those who believe and do the right, for whom there is reward undiminished.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmcv{Who should then make you deny the Judgement after this?\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmcvi{Is not God the most equitable of all judges?\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmcvii{\basmalahen READ IN THE name of your Lord who created,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmcviii{Created man from an embryo;\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmcix{Read, for your Lord is most beneficent,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmcx{Who taught by the pen,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmcxi{Taught man what he did not know.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmcxii{And yet, but yet man is rebellious,\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmcxiii{For he thinks he is sufficient in himself.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmcxiv{Surely your returning is to your Lord.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmcxv{Have you seen him who restrains\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmmcxvi{A votary when he turns to his devotions?\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmmcxvii{Have you thought, if he had been on guidance\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmmcxviii{Or had enjoined piety, (it would have been better)?\qt@no{(12)}}
\qt@newcmd\qurantrans@en@mmmmmmcxix{Have you thought that if he denies and turns away,\qt@no{(13)}}
\qt@newcmd\qurantrans@en@mmmmmmcxx{Does he not know that God sees?\qt@no{(14)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxi{And yet indeed if he does not desist We shall drag him by the forelock,\qt@no{(15)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxii{By the lying, the sinful forelock.\qt@no{(16)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{So let him call his associates,\qt@no{(17)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{We shall call the guards of Hell.\qt@no{(18)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxv{Beware! Do not obey him, but bow in adoration and draw near (to your Lord).\qt@no{(19)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{\basmalahen TRULY WE REVEALED it on the Night of Determination.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{How will you know what the Night of Determination is?\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{Better is the Night of Determination than a thousand months.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxix{On (this night) the angels and grace descend by the dispensation of their Lord, for settling all affairs.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxx{It is peace till the dawning of the day.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{\basmalahen THOSE AMONG THE people of the Book who disbelieve, and the idolaters, would not have been freed (from false beliefs) until the clear proof came to them --\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{An Apostle from God, reading out hallowed pages\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{Containing firm decrees.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{The people of the Book were not divided among themselves till after the clear proof had come to them.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{They were commanded only to serve God with all-exclusive faith in Him, to be upright, and to fulfil their devotional obligations, and to give zakat; for this is the even way.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{Surely the unbelievers among the people of the Book and the idolaters, will abide in the fire of Hell. They are the worst of creatures.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{But those who believe and do the right are surely the best of created beings,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{Whose reward is with their Lord -- gardens of Eden with rivers flowing by, where they will abide for ever, God pleased with their service, they with obedience to Him. This (awaits) him who stands in awe of his Lord.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{\basmalahen WHEN THE WORLD is shaken up by its cataclysm,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmcxl{And the earth throws out its burdens,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmcxli{And man enquires: ``What has come over it?"\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmcxlii{That day it will narrate its annals,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmcxliii{For your Lord will have commanded it.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmcxliv{That day people will proceed separately to be shown their deeds.\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmcxlv{Whosoever has done even an atom's weight of good will behold it;\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{And whosoever has done even an atom's weight of evil will behold that.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{\basmalahen I CALL TO witness the chargers, snorting, rushing to battle before the others,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{Then those striking sparks of fire,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmcxlix{Then those charging in the morning\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmcl{Raising clouds of dust,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmcli{Penetrating deep into the armies,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmclii{That man is ungrateful to his Lord\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmcliii{And is himself witness to it,\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmcliv{And is intractable in his love of worldly goods.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmclv{Does he not know when the contents of the graves are laid bare\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmmclvi{And the secrets of the hearts exposed,\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmmclvii{Surely their Lord will be aware of their (deeds).\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmmclviii{\basmalahen THE STARTLING CALAMITY.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmclix{What is the startling calamity?\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmclx{How will you comprehend what the startling calamity is? --\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmclxi{A Day on which human beings would be like so many scattered moths,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmclxii{The mountains like the tufts of carded wool.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmclxiii{Then he whose deeds shall weigh heavier in the scale\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmclxiv{Will have a tranquil life;\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmclxv{But he whose deeds are lighter in the balance\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmclxvi{Will have the Abyss for abode.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmmclxvii{How will you comprehend what that is?\qt@no{(10)}}
\qt@newcmd\qurantrans@en@mmmmmmclxviii{It is the scorching fire.\qt@no{(11)}}
\qt@newcmd\qurantrans@en@mmmmmmclxix{\basmalahen THE AVARICE OF plenitude keeps you occupied\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmclxx{Till you reach the grave.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxi{But you will come to know soon; --\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxii{Indeed you will come to know soon.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{And yet if you knew with positive knowledge\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{You have indeed to behold Hell;\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxv{Then you will see it with the eye of certainty.\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{Then on that day you will surely be asked about the verity of pleasures.\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{\basmalahen TIME AND AGE are witness\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{Man is certainly loss,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxix{Except those who believe, and do good and enjoin truth on one another, and enjoin one another to bear with fortitude (the trials that befall).\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxx{\basmalahen WOE TO EVERY slanderer, back-biter,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{Who amasses wealth and hordes it.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{Does he think his wealth will abide for ever with him?\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{By no means. He will be thrown into Hutama.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{How will you comprehend what Hutama is?\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{It is the fire kindled by God\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{Which penetrates the hearts\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{(And) vaults them over\qt@no{(8)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{In extending columns.\qt@no{(9)}}
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{\basmalahen HAVE YOU NOT seen how your Lord dealt with the people of the elephants?\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmcxc{Did He not make their plan go wrong,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmcxci{And sent hordes of chargers flying against them,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmcxcii{(While) you were pelting them with stones of porphyritic lava,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmcxciii{And turned them into pastured fields of corn?\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmcxciv{\basmalahen SINCE THE QURAISH have been united,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmcxcv{United to fit out caravans winter and summer,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{Let them worship the Lord of this House,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{Who provided them against destitution and gave them security against fear.\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{\basmalahen HAVE YOU SEEN him who denies the Day of Judgement?\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmcxcix{It is he who pushes the orphan away,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmcc{And does not induce others to feed the needy.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmcci{Woe to those who pray\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmccii{But who are oblivious of their moral duties,\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmcciii{Who dissimulate\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmcciv{And withhold things of common use (from others).\qt@no{(7)}}
\qt@newcmd\qurantrans@en@mmmmmmccv{\basmalahen HAVE SURELY given you pre-eminence (in numbers and following);\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmccvi{So serve your Lord with full dedication and sacrifice.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmccvii{It is surely your opponents whose line will come to end.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmccviii{\basmalahen SAY: ``O YOU unbelievers,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmccix{I do not worship what you worship,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmccx{Nor do you worship who I worship,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmccxi{Nor will I worship what you worship,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmccxii{Nor will you worship who I worship:\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmccxiii{To you your way, to me my way\qt@no{(6)}}
\qt@newcmd\qurantrans@en@mmmmmmccxiv{\basmalahen WHEN THE HELP of God arrives and victory,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmccxv{And you see men enter God's discipline horde on horde,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmccxvi{Then glorify your Lord and seek His forgiveness. Verily He is relenting.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmccxvii{\basmalahen DESTROYED WILL BE the hands of Abu Lahab, and he himself will perish.\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmccxviii{Of no avail shall be his wealth, nor what he has acquired.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmccxix{He will be roasted in the fire,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmccxx{And his wife, the portress of fire wood,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxi{Will have a strap of fibre rope around her neck.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxii{\basmalahen SAY: ``HE IS God the one the most unique,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{God the immanently indispensable.\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{He has begotten no one, and is begotten of none.\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxv{There is no one comparable to Him."\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{\basmalahen SAY: ``I SEEK refuge with the Lord of rising day\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{From the evil of what He has created,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{And the evil of evening darkness when it overspreads,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxix{From the evil of sorceresses who blow incantations on knots,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxx{From the evil of the envier when he envies.\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{\basmalahen SAY: ``I SEEK refuge with the Lord of men,\qt@no{(1)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{The King of men,\qt@no{(2)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{The God of men,\qt@no{(3)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{From the evil of him who breathes temptations into the minds of men,\qt@no{(4)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{Who suggests evil thoughts to the hearts of men --\qt@no{(5)}}
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{From among the jinns and men.\qt@no{(6)}}
