%% This is file `qurantext-fr.translation.def',
%%
%% Copyright © 2015-2021
%% Seiied-Mohammad-Javad Razavian <javadr@gmail.com>
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%%
%% This work is “author-maintained” (as per LPPL maintenance status).
%%
%% The Current Maintainer of this work is Seiied-Mohammad-Javad Razavian.
%%
%% to one who has devoted his life to Quran
%%
\qt@newcmd\qurantrans@fr@i{Au nom d'Allah, le Tout Miséricordieux, le Très Miséricordieux.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@ii{Louange à Allah, Seigneur de l'univers.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@iii{Le Tout Miséricordieux, le Très Miséricordieux,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@iv{Maître du Jour de la rétribution.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@v{C'est Toi [Seul] que nous adorons, et c'est Toi [Seul] dont nous implorons secours.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@vi{Guide-nous dans le droit chemin,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@vii{le chemin de ceux que Tu as comblés de faveurs, non pas de ceux qui ont encouru Ta colère, ni des égarés.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@viii{\basmalahfr Alif, Lâm, Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@ix{C'est le Livre au sujet duquel il n'y a aucun doute, c'est un guide pour les pieux,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@x{qui croient à l'invisible et accomplissent la Salât et dépensent (dans l'obéissance à Allah), de ce que Nous leur avons attribué,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@xi{Ceux qui croient à ce qui t'a été descendu (révélé) et à ce qui a été descendu avant toi et qui croient fermement à la vie future.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@xii{Ceux-là sont sur le bon chemin de leur Seigneur, et ce sont eux qui réussissent (dans cette vie et dans la vie future).\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@xiii{[Mais] certes les infidèles que tu les avertisses ou que tu ne les avertisses pas, ils ne croient pas.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@xiv{Allah a scellé leurs cœurs et leurs oreilles; et un voile épais leur couvre la vue; et pour eux il y aura un grand châtiment.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@xv{Parmi les gens, il y a ceux qui disent: «Nous croyons en Allah et au Jour dernier!» tandis qu'en fait, ils n'y croient pas.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@xvi{Ils cherchent à tromper Allah et les croyants; mais ils ne trompent qu'eux-mêmes, et ils ne s'en rendent pas compte.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@xvii{Il y a dans leurs cœurs une maladie (de doute et d'hypocrisie), et Allah laisse croître leur maladie. Ils auront un châtiment douloureux, pour avoir menti.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@xviii{Et quand on leur dit: «Ne semez pas la corruption sur la terre», ils disent: «Au contraire nous ne sommes que des réformateurs!»\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@xix{Certes, ce sont eux les véritables corrupteurs, mais ils ne s'en rendent pas compte.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@xx{Et quand on leur dit: «Croyez comme les gens ont cru», ils disent: «Croirons-nous comme ont cru les faibles d'esprit?» Certes, ce sont eux les véritables faibles d'esprit, mais ils ne le savent pas.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@xxi{Quand ils rencontrent ceux qui ont cru, ils disent: «Nous croyons» mais quand ils se trouvent seuls avec leurs diables, ils disent: «Nous sommes avec vous; en effet nous ne faisions que nous moquer (d'eux)».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@xxii{C'est Allah qui Se moque d'eux et les endurcira dans leur révolte et prolongera sans fin leur égarement.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@xxiii{Ce sont eux qui ont troqué le droit chemin contre l'égarement. Eh bien, leur négoce n'a point profité. Et ils ne sont pas sur la bonne voie.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@xxiv{Ils ressemblent à quelqu'un qui a allumé un feu; puis quand le feu a illuminé tout à l'entour, Allah a fait disparaître leur lumière et les a abandonnés dans les ténèbres où ils ne voient plus rien.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@xxv{Sourds, muets, aveugles, ils ne peuvent donc pas revenir (de leur égarement).\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@xxvi{(On peut encore les comparer à ces gens qui,) au moment où les nuées éclatent en pluies, chargées de ténèbres, de tonnerre et éclairs, se mettent les doigts dans les oreilles, terrorisés par le fracas de la foudre et craignant la mort; et Allah encercle de tous côtés les infidèles.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@xxvii{L'éclair presque leur emporte la vue: chaque fois qu'il leur donne de la lumière, ils avancent; mais dès qu'il fait obscur, ils s'arrêtent. Si Allah le voulait Il leur enlèverait certes l'ouïe et la vue, car Allah a pouvoir sur toute chose.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@xxviii{O hommes! Adorez votre Seigneur, qui vous a créés vous et ceux qui vous ont précédés. Ainsi atteindriez-vous à la piété.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@xxix{C'est Lui qui vous a fait la terre pour lit, et le ciel pour toit; qui précipite la pluie du ciel et par elle fait surgir toutes sortes de fruits pour vous nourrir, ne Lui cherchez donc pas des égaux, alors que vous savez (tout cela).\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@xxx{Si vous avez un doute sur ce que Nous avons révélé à Notre Serviteur, tâchez donc de produire une sourate semblable et appelez vos témoins, (les idoles) que vous adorez en dehors d'Allah, si vous êtes véridiques.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@xxxi{Si vous n'y parvenez pas et, à coup sûr, vous n'y parviendrez jamais, parez-vous donc contre le feu qu'alimenteront les hommes et les pierres, lequel est réservé aux infidèles.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@xxxii{Annonce à ceux qui croient et pratiquent de bonnes œuvres qu'ils auront pour demeures des jardins sous lesquels coulent les ruisseaux; chaque fois qu'ils seront gratifiés d'un fruit des jardins ils diront: «C'est bien là ce qui nous avait été servi auparavant». Or c'est quelque chose de semblable (seulement dans la forme); ils auront là des épouses pures, et là ils demeureront éternellement.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@xxxiii{Certes, Allah ne se gêne point de citer en exemple n'importe quoi: un moustique ou quoi que ce soit au-dessus; quant aux croyants, ils savent bien qu'il s'agit de la vérité venant de la part de leur Seigneur; quant aux infidèles, ils se demandent «Qu'a voulu dire Allah par un tel exemple?» Par cela, nombreux sont ceux qu'Il égare et nombreux sont ceux qu'Il guide; mais Il n'égare par cela que les pervers,\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@xxxiv{qui rompent le pacte qu'ils avaient fermement conclu avec Allah, coupent ce qu'Allah a ordonné d'unir, et sèment la corruption sur la terre. Ceux-là sont les vrais perdants.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@xxxv{Comment pouvez-vous renier Allah alors qu'Il vous a donné la vie, quand vous en étiez privés? Puis Il vous fera mourir; puis Il vous fera revivre et enfin c'est à Lui que vous retournerez.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@xxxvi{C'est Lui qui a créé pour vous tout ce qui est sur la terre, puis Il a orienté Sa volonté vers le ciel et en fit sept cieux. Et Il est Omniscient.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@xxxvii{Lorsque Ton Seigneur confia aux Anges: «Je vais établir sur la terre un vicaire «Khalifa». Ils dirent: «Vas-Tu y désigner un qui y mettra le désordre et répandra le sang, quand nous sommes là à Te sanctifier et à Te glorifier?» - Il dit: «En vérité, Je sais ce que vous ne savez pas!».\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@xxxviii{Et Il apprit à Adam tous les noms (de toutes choses), puis Il les présenta aux Anges et dit: «Informez-Moi des noms de ceux-là, si vous êtes véridiques!» (dans votre prétention que vous êtes plus méritants qu'Adam).\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@xxxix{- Ils dirent: «Gloire à Toi! Nous n'avons de savoir que ce que Tu nous a appris. Certes c'est Toi l'Omniscient, le Sage».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@xl{Il dit: «O Adam, informe-les de ces noms ;» Puis quand celui-ci les eut informés de ces noms, Allah dit: «Ne vous ai-Je pas dit que Je connais les mystères des cieux et de la terre, et que Je sais ce que vous divulguez et ce que vous cachez?»\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@xli{Et lorsque Nous demandâmes aux Anges de se prosterner devant Adam, ils se prosternèrent à l'exception d'Iblis qui refusa, s'enfla d'orgueil et fut parmi les infidèles.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@xlii{Et Nous dîmes: «O Adam, habite le Paradis toi et ton épouse, et nourrissez-vous-en de partout à votre guise; mais n'approchez pas de l'arbre que voici: sinon vous seriez du nombre des injustes».\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@xliii{Peu de temps après, Satan les fit glisser de là et les fit sortir du lieu où ils étaient. Et Nous dîmes: «Descendez (du Paradis); ennemis les uns des autres. Et pour vous il y aura une demeure sur la terre, et un usufruit pour un temps.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@xliv{Puis Adam reçut de son Seigneur des paroles, et Allah agréa son repentir car c'est Lui certes, le Repentant, le Miséricordieux.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@xlv{- Nous dîmes: «Descendez d'ici, vous tous! Toutes les fois que Je vous enverrai un guide, ceux qui [le] suivront n'auront rien à craindre et ne seront point affligés».\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@xlvi{Et ceux qui ne croient pas (à nos messagers) et traitent de mensonge Nos révélations, ceux-là sont les gens du Feu où ils demeureront éternellement.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@xlvii{O enfants d'Israël, rappelez-vous Mon bienfait dont Je vous ai comblés. Si vous tenez vos engagements vis-à-vis de Moi, Je tiendrai les miens. Et c'est Moi que vous devez redouter.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@xlviii{Et croyez à ce que J'ai fait descendre, en confirmation de ce qui était déjà avec vous; et ne soyez pas les premiers à le rejeter. Et n'échangez pas Mes révélations contre un vil prix. Et c'est Moi que vous devez craindre.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@xlix{Et ne mêlez pas le faux à la vérité. Ne cachez pas sciemment la vérité.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@l{Et accomplissez la Salât, et acquittez la Zakât, et inclinez-vous avec ceux qui s'inclinent.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@li{Commanderez-vous aux gens de faire le bien, et vous oubliez vous-mêmes de le faire, alors que vous récitez le Livre? Etes-vous donc dépourvus de raison?\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@lii{Et cherchez secours dans l'endurance et la salât: certes, la Salât est une lourde obligation, sauf pour les humbles,\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@liii{qui ont la certitude de rencontrer leur Seigneur (après leur résurrection) et retourner à Lui seul.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@liv{O Enfants d'Israël, rappelez-vous Mon bienfait dont Je vous ai comblés, (Rappelez-vous) que Je vous ai préférés à tous les peuples (de l'époque).\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@lv{Et redoutez le jour où nulle âme ne suffira en quoi que ce soit à une autre; où l'on n'acceptera d'elle aucune intercession; et où on ne recevra d'elle aucune compensation. Et ils ne seront point secourus.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@lvi{Et [rappelez-vous] lorsque Nous vous avons délivrés des gens de Pharaon; qui vous infligeaient le pire châtiment: en égorgeant vos fils et épargnant vos femmes. C'était là une grande épreuve de la part de votre Seigneur.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@lvii{Et [rappelez-vous] lorsque Nous avons fendu la mer pour vous donner passage!... Nous vous avons donc délivrés, et noyé les gens de Pharaon, tandis que vous regardiez.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@lviii{Et [rappelez-vous] lorsque Nous donnâmes rendez-vous à Moïse pendant quarante nuits!... Puis en son absence vous avez pris le Veau pour idole alors que vous étiez injustes (à l'égard de vous-mêmes en adorant autre qu'Allah).\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@lix{Mais en dépit de cela Nous vous pardonnâmes, afin que vous reconnaissiez (Nos bienfaits à votre égard).\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@lx{Et [rappelez-vous] lorsque Nous avons donné à Moïse le Livre et le Discernement afin que vous soyez guidés.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@lxi{Et [rappelez-vous] lorsque Moïse dit à son peuple: «O mon peuple, certes vous vous êtes fait du tort à vous-mêmes en prenant le Veau pour idole. Revenez donc à votre Créateur; puis, tuez donc les coupables vous-mêmes: ce serait mieux pour vous, auprès de votre Créateur!»... C'est ainsi qu'Il agréa votre repentir; car c'est Lui, certes, le Repentant et le Miséricordieux!\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@lxii{Et [rappelez-vous] lorsque vous dites: «O Moïse, nous ne te croirons qu'après avoir vu Allah clairement»!... Alors la foudre vous saisit tandis que vous regardiez.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@lxiii{Puis Nous vous ressuscitâmes après votre mort afin que vous soyez reconnaissants.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@lxiv{Et Nous vous couvrîmes de l'ombre d'un nuage; et fîmes descendre sur vous la manne et les cailles: - «Mangez des délices que Nous vous avons attribués!» - Ce n'est pas à Nous qu'ils firent du tort, mais ils se firent tort à eux-mêmes.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@lxv{Et [rappelez-vous] lorsque Nous dîmes: «Entrez dans cette ville, et mangez-y à l'envie où il vous plaira; mais entrez par la porte en vous prosternant et demandez la «rémission» (de vos péchés); Nous vous pardonnerons vos fautes si vous faites cela et donnerons davantage de récompense pour les bienfaisants.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@lxvi{Mais, à ces paroles, les pervers en substituèrent d'autres, et pour les punir de leur fourberie Nous leur envoyâmes du ciel un châtiment avilissant.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@lxvii{Et [rappelez-vous] quand Moïse demanda de l'eau pour désaltérer son peuple, c'est alors que Nous dîmes: «Frappe le rocher avec ton bâton». Et tout d'un coup, douze sources en jaillirent, et certes, chaque tribu sut où s'abreuver! - «Mangez et buvez de ce qu'Allah vous accorde; et ne semez pas de troubles sur la terre comme des fauteurs de désordre».\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@lxviii{Et [rappelez-vous] quand vous dîtes: «O Moïse, nous ne pouvons plus tolérer une seule nourriture. Prie donc ton Seigneur pour qu'Il nous fasse sortir de la terre ce qu'elle fait pousser, de ses légumes, ses concombres, son ail (ou blé), ses lentilles et ses oignons!» - Il vous répondit: «Voulez-vous échanger le meilleur pour le moins bon? Descendez donc à n'importe quelle ville; vous y trouverez certainement ce que vous demandez!». L'avilissement et la misère s'abattirent sur eux; ils encoururent la colère d'Allah. Cela est parce qu'ils reniaient les révélations d'Allah, et qu'ils tuaient sans droit les prophètes. Cela parce qu'ils désobéissaient et transgressaient.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@lxix{Certes, ceux qui ont cru, ceux qui se sont judaïsés, les Nazaréens, et les sabéens, quiconque d'entre eux a cru en Allah au Jour dernier et accompli de bonnes œuvres, sera récompensé par son Seigneur; il n'éprouvera aucune crainte et il ne sera jamais affligé.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@lxx{(Et rappelez-vous) quand Nous avons contracté un engagement avec vous et brandi sur vous le Mont -: «Tenez ferme ce que Nous vous avons donné et souvenez-vous de ce qui s'y trouve afin que vous soyez pieux!»\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@lxxi{Puis vous vous en détournâtes après vos engagements, n'eût été donc la grâce d'Allah et Sa miséricorde, vous seriez certes parmi les perdants.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@lxxii{Vous avez certainement connu ceux des vôtres qui transgressèrent le Sabbat. Et bien Nous leur dîmes: «Soyez des singes abjects!»\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@lxxiii{Nous fîmes donc de cela un exemple pour les villes qui l'entouraient alors et une exhortation pour les pieux.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@lxxiv{(Et rappelez-vous) lorsque Moïse dit à son peuple: «Certes Allah vous ordonne d'immoler une vache». Ils dirent: «Nous prends-tu en moquerie?» «Qu'Allah me garde d'être du nombre des ignorants» dit-il.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@lxxv{- Ils dirent: «Demande pour nous à ton Seigneur qu'Il nous précise ce qu'elle doit être». - Il dit: «Certes Allah dit que c'est bien une vache, ni vieille ni vierge, d'un âge moyen, entre les deux. Faites donc ce qu'on vous commande».\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@lxxvi{- Ils dirent: «Demande donc pour nous à ton Seigneur qu'Il nous précise sa couleur». - Il dit: «Allah dit que c'est une vache jaune, de couleur vive et plaisante à voir».\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@lxxvii{- Ils dirent: «Demande pour nous à ton Seigneur qu'Il nous précise ce qu'elle est car pour nous, les vaches se confondent. Mais, nous y serions certainement bien guidés, si Allah le veut».\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@lxxviii{- Il dit: «Allah dit que c'est bien une vache qui n'a pas été asservie à labourer la terre ni à arroser le champ, indemne d'infirmité et dont la couleur est unie». - Ils dirent: «Te voilà enfin, tu nous as apporté la vérité!» Ils l'immolèrent alors mais il s'en fallut qu'ils ne l'eussent pas fait.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@lxxix{Et quand vous aviez tué un homme et que chacun de vous cherchait à se disculper!... Mais Allah démasque ce que vous dissimuliez.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@lxxx{Nous dîmes donc: «Frappez le tué avec une partie de la vache». - Ainsi Allah ressuscite les morts et vous montre les signes (de Sa puissance) afin que vous raisonniez\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@lxxxi{Puis, et en dépit de tout cela, vos cœurs se sont endurcis; ils sont devenus comme des pierres ou même plus durs encore; car il y a des pierres d'où jaillissent les ruisseaux, d'autres se fendent pour qu'en surgisse l'eau, d'autres s'affaissent par crainte d'Allah. Et Allah n'est certainement jamais inattentif à ce que vous faites\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@lxxxii{- Eh bien, espérez-vous [Musulmans] que des pareils gens (les Juifs) vous partageront la foi? alors qu'un groupe d'entre eux; après avoir entendu et compris la parole d'Allah, la falsifièrent sciemment.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@lxxxiii{Et quand ils rencontrent des croyants, ils disent: «Nous croyons» et, une fois seuls entre eux, ils disent: «Allez-vous confier aux musulmans ce qu'Allah vous a révélé pour leur fournir, ainsi, un argument contre vous devant votre Seigneur! Etes-vous donc dépourvus de raison?».\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@lxxxiv{- Ne savent-ils pas qu'en vérité Allah sait ce qu'ils cachent et ce qu'ils divulguent?\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@lxxxv{Et il y a parmi eux des illettrés qui ne savent rien du Livre hormis des prétentions et ils ne font que des conjectures.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@lxxxvi{Malheur, donc, à ceux qui de leurs propres mains composent un livre puis le présentent comme venant d'Allah pour en tirer un vil profit! - Malheur à eux, donc, à cause de ce que leurs mains ont écrit, et malheur à eux à cause de ce qu'ils en profitent!\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@lxxxvii{Et ils ont dit: «Le Feu ne nous touchera que pour quelques jours comptés!». Dis: «Auriez-vous pris un engagement avec Allah - car Allah ne manque jamais à Son engagement; - non, mais vous dites sur Allah ce que vous ne savez pas».\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@lxxxviii{Bien au contraire! Ceux qui font le mal et qui se font cerner par leurs péchés, ceux-là sont les gens du Feu où ils demeureront éternellement.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@lxxxix{Et ceux qui croient et pratiquent les bonnes œuvres, ceux-là sont les gens du Paradis où ils demeureront éternellement.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@xc{Et [rappelle-toi], lorsque Nous avons pris l'engagement des enfants d'Israël de n'adorer qu'Allah, de faire le bien envers les pères, les mères, les proches parents, les orphelins et les nécessiteux, d'avoir de bonnes paroles avec les gens; d'accomplir régulièrement la Salât et d'acquitter la Zakât! - Mais à l'exception d'un petit nombre de vous, vous manquiez à vos engagements en vous détournant de Nos commandements.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@xci{Et rappelez-vous, lorsque Nous obtînmes de vous l'engagement de ne pas vous verser le sang, [par le meurtre] de ne pas vous expulser les uns les autres de vos maisons. Puis vous y avez souscrit avec votre propre témoignage.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@xcii{Quoique ainsi engagés, voilà que vous vous entretuez, que vous expulsez de leurs maisons une partie d'entre vous contre qui vous prêtez main forte par péché et agression. Mais quelle contradiction! Si vos coreligionnaires vous viennent captifs vous les rançonnez alors qu'il vous était interdit de les expulser (de chez eux). Croyez-vous donc en une partie du Livre et rejetez-vous le reste? Ceux d'entre vous qui agissent de la sorte ne méritent que l'ignominie dans cette vie, et au Jour de la Résurrection ils seront refoulés au plus dur châtiment, et Allah n'est pas inattentif à ce que vous faites.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@xciii{Voilà ceux qui échangent la vie présente contre la vie future. Eh bien, leur châtiment ne sera pas diminué. Et ils ne seront point secourus.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@xciv{Certes, Nous avons donné le Livre à Moïse; Nous avons envoyé après lui des prophètes successifs. Et Nous avons donné des preuves à Jésus fils de Marie, et Nous l'avons renforcé du Saint-Esprit. Est-ce qu'à chaque fois, qu'un Messager vous apportait des vérités contraires à vos souhaits vous vous enfliez d'orgueil? Vous traitiez les uns d'imposteurs et vous tuiez les autres.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@xcv{Et ils dirent: «Nos cœurs sont enveloppés et impénétrables» - Non mais Allah les a maudits à cause de leur infidélité, leur foi est donc médiocre.\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@xcvi{Et quand leur vint d'Allah un Livre confirmant celui qu'ils avaient déjà, - alors qu'auparavant ils cherchaient la suprématie sur les mécréants, - quand donc leur vint cela même qu'ils reconnaissaient, ils refusèrent d'y croire. Que la malédiction d'Allah soit sur les mécréants!\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@xcvii{Comme est vil ce contre quoi ils ont troqué leurs âmes! Ils ne croient pas en ce qu'Allah a fait descendre, révoltés à l'idée qu'Allah, de par Sa grâce, fasse descendre la révélation sur ceux de Ses serviteurs qu'Il veut. Ils ont donc acquis colère sur colère, car un châtiment avilissant attend les infidèles!\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@xcviii{Et quand on leur dit: «Croyez à ce qu'Allah a fait descendre», ils disent: «Nous croyons à ce qu'on a fait descendre à nous». Et ils rejettent le reste, alors qu'il est la vérité confirmant ce qu'il y avait déjà avec eux. - Dis: «Pourquoi donc avez-vous tué auparavant les prophètes d'Allah, si vous étiez croyants?».\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@xcix{Et en effet Moïse vous est venu avec les preuves. Malgré cela, une fois absent, vous avez pris le Veau pour idole, alors que vous étiez injustes.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@c{Et rappelez-vous, lorsque Nous avons pris l'engagement de vous, et brandi sur vous AT-Tûr (le Mont Sinaï) en vous disant: «Tenez ferme à ce que Nous vous avons donné, et écoutez!». Ils dirent: «Nous avons écouté et désobéi». Dans leur impiété, leurs cœurs étaient passionnément épris du Veau (objet de leur culte). Dis-[leur]: «Quelles mauvaises prescriptions ordonnées par votre foi, si vous êtes croyants».\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@ci{- Dis: «Si l'Ultime demeure auprès d'Allah est pour vous seuls, à l'exclusion des autres gens, souhaitez donc la mort [immédiate] si vous êtes véridiques!»\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@cii{Or, ils ne la souhaiteront jamais, sachant tout le mal qu'ils ont perpétré de leurs mains. Et Allah connait bien les injustes.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@ciii{Et certes tu les trouveras les plus attachés à la vie [d'ici-bas], pire en cela que les Associateurs. Tel d'entre eux aimerait vivre mille ans. Mais une pareille longévité ne le sauvera pas du châtiment! Et Allah voit bien leurs actions.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@civ{Dis: «Quiconque est ennemi de Gabriel doit connaître que c'est lui qui, avec la permission d'Allah, a fait descendre sur ton cœur cette révélation qui déclare véridiques les messages antérieurs et qui sert aux croyants de guide et d'heureuse annonce»\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@cv{[Dis:] «Quiconque est ennemi d'Allah, de Ses anges, de Ses messagers, de Gabriel et de Michaël... [Allah sera son ennemi] car Allah est l'ennemi des infidèles».\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@cvi{Et très certainement Nous avons fait descendre vers toi des signes évidents. Et seuls les pervers n'y croient pas.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@cvii{Faudrait-il chaque fois qu'ils concluent un pacte, qu'une partie d'entre eux le dénonce? C'est que plutôt la plupart d'entre eux ne sont pas croyants.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@cviii{Et quand leur vint d'Allah un messager confirmant ce qu'il y avait déjà avec eux, certains à qui le Livre avait été donné, jetèrent derrière leur dos le Livre d'Allah comme s'ils ne savaient pas!\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@cix{Et ils suivirent ce que les diables racontent contre le règne de Solayman. Alors que Solayman n'a jamais été mécréant mais bien les diables: ils enseignent aux gens la magie ainsi que ce qui est descendu aux deux anges Hârout et Mârout, à Babylone; mais ceux-ci n'enseignaient rien à personne, qu'ils n'aient dit d'abord: «Nous ne sommes rien qu'une tentation: ne sois pas mécréant» ils apprennent auprès d'eux ce qui sème la désunion entre l'homme et son épouse. Or ils ne sont capables de nuire à personne qu'avec la permission d'Allah. Et les gens apprennent ce qui leur nuit et ne leur est pas profitable. Et ils savent, très certainement, que celui qui acquiert [ce pouvoir] n'aura aucune part dans l'au-delà. Certes, quelle détestable marchandise pour laquelle ils ont vendu leurs âmes! Si seulement ils savaient!\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@cx{Et s'ils croyaient et vivaient en piété, une récompense de la part d'Allah serait certes meilleure. Si seulement ils savaient!\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@cxi{O vous qui croyez! Ne dites pas: «Râ'inâ» (favorise-nous) mais dites: «Onzurnâ» (regarde-nous); et écoutez! Un châtiment douloureux sera pour les infidèles.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@cxii{Ni les mécréants parmi les gens du Livre, ni les Associateurs n'aiment qu'on fasse descendre sur vous un bienfait de la part de votre Seigneur, alors qu'Allah réserve à qui Il veut sa Miséricorde. Et c'est Allah le Détenteur de l'abondante grâce.\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@cxiii{Si Nous abrogeons un verset quelconque ou que Nous le fassions oublier, Nous en apportons un meilleur, ou un semblable. Ne sais-tu pas qu'Allah est Omnipotent?\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@cxiv{Ne sais-tu pas qu'à Allah, appartient le royaume des cieux et de la terre, et qu'en dehors d'Allah vous n'avez ni protecteur ni secoureur?\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@cxv{Voudriez-vous interroger votre Messager comme auparavant on interrogea Moïse? Quiconque substitue la mécréance à la foi s'égare certes du droit chemin.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@cxvi{Nombre de gens du Livre aimeraient par jalousie de leur part, pouvoir vous rendre mécréants après que vous ayez cru. Et après que la vérité s'est manifestée à eux! Pardonnez et oubliez jusqu'à ce qu'Allah fasse venir Son commandement. Allah est très certainement Omnipotent!\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@cxvii{Et accomplissez la Salât et acquittez la Zakât. Et tout ce que vous avancez de bien pour vous-mêmes, vous le retrouverez auprès d'Allah, car Allah voit parfaitement ce que vous faites.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@cxviii{Et ils ont dit: «Nul n'entrera au Paradis que Juifs ou Chrétiens». Voilà leurs chimères. - Dis: «Donnez votre preuve, si vous êtes véridiques».\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@cxix{Non, mais quiconque soumet à Allah son être tout en faisant le bien, aura sa rétribution auprès de son Seigneur. Pour eux, nulle crainte, et ils ne seront point attristés.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@cxx{Et les Juifs disent: «Les Chrétiens ne tiennent sur rien» et les Chrétiens disent: «Les Juifs ne tiennent sur rien», alors qu'ils lisent le Livre! De même ceux qui ne savent rien tiennent un langage semblable au leur. Eh bien, Allah jugera sur ce quoi ils s'opposent, au Jour de la Résurrection.\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@cxxi{Qui est plus injuste que celui qui empêche que dans les mosquées d'Allah, on mentionne Son Nom, et qui s'efforce à les détruire? De tels gens ne devraient y entrer qu'apeurés. Pour eux, ignominie ici-bas; et dans l'au-delà un énorme châtiment.\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@cxxii{A Allah seul appartiennent l'Est et l'Ouest. Où que vous vous tourniez, la Face (direction) d'Allah est donc là, car Allah a la grâce immense; Il est Omniscient.\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@cxxiii{Et ils ont dit: «Allah s'est donné un fils»! Gloire à Lui! Non! mais c'est à Lui qu'appartient ce qui est dans les cieux et la terre et c'est à Lui que tous obéissent.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@cxxiv{Il est le Créateur des cieux et de la terre à partir du néant. Lorsqu'Il décide une chose, Il dit seulement: «Sois», et elle est aussitôt.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@cxxv{Et ceux qui ne savent pas ont dit: «Pourquoi Allah ne nous parle-t-Il pas [directement], ou pourquoi un signe ne nous vient-il pas?» De même, ceux d'avant eux disaient une parole semblable. Leurs cœurs se ressemblent. Nous avons clairement exposé les signes pour des gens qui ont la foi ferme.\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@cxxvi{Certes, Nous t'avons envoyé avec la vérité, en annonciateur et avertisseur; et on ne te demande pas compte des gens de l'Enfer.\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@cxxvii{Ni les Juifs, ni les Chrétiens ne seront jamais satisfaits de toi, jusqu'à ce que tu suives leur religion. - Dis: «Certes, c'est la direction d'Allah qui est la vraie direction». Mais si tu suis leurs passions après ce que tu as reçu de science, tu n'auras contre Allah ni protecteur ni secoureur.\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@cxxviii{Ceux à qui Nous avons donné le Livre, qui le récitent comme il se doit, ceux-là y croient. Et ceux qui n'y croient pas sont les perdants.\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@cxxix{O Enfants d'Israël, rappelez-vous Mon bienfait dont Je vous ai comblés et que Je vous ai favorisés par-dessus le reste du monde (de leur époque).\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@cxxx{Et redoutez le jour où nulle âme ne bénéficiera à une autre, où l'on n'acceptera d'elle aucune compensation, et où aucune intercession ne lui sera utile. Et ils ne seront point secourus.\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@cxxxi{[Et rappelle-toi] quand ton Seigneur eut éprouvé Abraham par certains commandements, et qu'il les eut accomplis, le Seigneur lui dit: «Je vais faire de toi un exemple à suivre pour les gens». - «Et parmi ma descendance?» demanda-t-il. - «Mon engagement, dit Allah, ne s'applique pas aux injustes»\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@cxxxii{[Et rappelle-toi], quand nous fîmes de la Maison un lieu de visite et un asile pour les gens - Adoptez donc pour lieu de prière, ce lieu où Abraham se tint debout - Et Nous confiâmes à Abraham et à Ismaël ceci: «Purifiez Ma Maison pour ceux qui tournent autour, y font retraite pieuse, s'y inclinent et s'y prosternent.\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@cxxxiii{Et quand Abraham supplia: «O mon Seigneur, fais de cette cité un lieu de sécurité, et fais attribution des fruits à ceux qui parmi ses habitants auront cru en Allah et au Jour dernier», le Seigneur dit: «Et quiconque n'y aura pas cru, alors Je lui concèderai une courte jouissance [ici-bas], puis Je le contraindrai au châtiment du Feu [dans l'au-delà]. Et quelle mauvaise destination!»\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@cxxxiv{Et quand Abraham et Ismaël élevaient les assises de la Maison: «O notre Seigneur, accepte ceci de notre part! Car c'est Toi l'Audient, l'Omniscient.\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@cxxxv{Notre Seigneur! Fais de nous Tes Soumis, et de notre descendance une communauté soumise à Toi. Et montre nous nos rites et accepte de nous le repentir. Car c'est Toi certes l'Accueillant au repentir, le Miséricordieux.\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@cxxxvi{Notre Seigneur! Envoie l'un des leurs comme messager parmi eux, pour leur réciter Tes versets, leur enseigner le Livre et la Sagesse, et les purifier. Car c'est Toi certes le Puissant, le Sage!\qt@no{(129)}}
\qt@newcmd\qurantrans@fr@cxxxvii{Qui donc aura en aversion la religion d'Abraham, sinon celui qui sème son âme dans la sottise? Car très certainement Nous l'avons choisi en ce monde; et, dans l'au-delà, il est certes du nombre des gens de bien.\qt@no{(130)}}
\qt@newcmd\qurantrans@fr@cxxxviii{Quand son Seigneur lui avait dit: «Soumets-toi», il dit: «Je me soumets au Seigneur de l'Univers».\qt@no{(131)}}
\qt@newcmd\qurantrans@fr@cxxxix{Et c'est ce qu'Abraham recommanda à ses fils, de même que Jacob: «O mes fils, certes Allah vous a choisi la religion: ne mourrez point, donc, autrement qu'en Soumis!» (à Allah).\qt@no{(132)}}
\qt@newcmd\qurantrans@fr@cxl{Etiez-vous témoins quand la mort se présenta à Jacob et qu'il dit à ses fils: «Qu'adorerez-vous après moi?» - Ils répondirent: «Nous adorerons ta divinité et la divinité de tes pères, Abraham, Ismaël et Isaac, Divinité Unique et à laquelle nous sommes Soumis».\qt@no{(133)}}
\qt@newcmd\qurantrans@fr@cxli{Voilà une génération bel et bien révolue. A elle ce qu'elle a acquis, et à vous ce que vous avez acquis. On ne vous demandera pas compte de ce qu'ils faisaient.\qt@no{(134)}}
\qt@newcmd\qurantrans@fr@cxlii{Ils ont dit : «Soyez Juifs ou Chrétiens, vous serez donc sur la bonne voie». - Dis: «Non, mais nous suivons la religion d'Abraham le modèle même de la droiture et qui ne fut point parmi les Associateurs».\qt@no{(135)}}
\qt@newcmd\qurantrans@fr@cxliii{Dites: «Nous croyons en Allah et en ce qu'on nous a révélé, et en ce qu'on a fait descendre vers Abraham et Ismaël et Isaac et Jacob et les Tribus, et en ce qui a été donné à Moïse et à Jésus, et en ce qui a été donné aux prophètes, venant de leur Seigneur: nous ne faisons aucune distinction entre eux. Et à Lui nous sommes Soumis».\qt@no{(136)}}
\qt@newcmd\qurantrans@fr@cxliv{Alors, s'ils croient à cela même à quoi vous croyez, ils seront certainement sur la bonne voie. Et s'ils s'en détournent, ils seront certes dans le schisme! Alors Allah te suffira contre eux. Il est l'Audient, l'Omniscient.\qt@no{(137)}}
\qt@newcmd\qurantrans@fr@cxlv{«Nous suivons la religion d'Allah! Et qui est meilleur qu'Allah en Sa religion? C'est Lui que nous adorons».\qt@no{(138)}}
\qt@newcmd\qurantrans@fr@cxlvi{Dis: «Discutez vous avec nous au sujet d'Allah, alors qu'Il est notre Seigneur et le vôtre? A nous nos actions et à vous les vôtres! C'est à Lui que nous sommes dévoués.\qt@no{(139)}}
\qt@newcmd\qurantrans@fr@cxlvii{Ou dites-vous qu'Abraham, Ismaël, Isaac et Jacob et les tribus étaient Juifs ou Chrétiens?» - Dis: «Est-ce vous les plus savants ou Allah?» - Qui est plus injuste que celui qui cache un témoignage qu'il détient d'Allah? Et Allah n'est pas inattentif à ce que vous faites.\qt@no{(140)}}
\qt@newcmd\qurantrans@fr@cxlviii{Voilà une génération bel et bien révolue. A elle ce qu'elle a acquis, et à vous ce que vous avez acquis. Et on ne vous demandera pas compte de ce qu'ils faisaient.\qt@no{(141)}}
\qt@newcmd\qurantrans@fr@cxlix{Les faibles d'esprit parmi les gens vont dire: «Qui les a détournés de la direction (Qibla) vers laquelle ils s'orientaient auparavant?» - Dis: «C'est à Allah qu'appartiennent le Levant et le Couchant. Il guide qui Il veut vers un droit chemin».\qt@no{(142)}}
\qt@newcmd\qurantrans@fr@cl{Et aussi Nous avons fait de vous une communauté de justes pour que vous soyez témoins aux gens, comme le Messager sera témoin à vous. Et Nous n'avions établi la direction (Qibla) vers laquelle tu te tournais que pour savoir qui suit le Messager [Muhammad] et qui s'en retourne sur ses talons. C'était un changement difficile, mais pas pour ceux qu'Allah guide. Et ce n'est pas Allah qui vous fera perdre [la récompense de] votre foi, car Allah, certes est Compatissant et Miséricordieux pour les hommes.\qt@no{(143)}}
\qt@newcmd\qurantrans@fr@cli{Certes nous te voyons tourner le visage en tous sens dans le ciel. Nous te faisons donc orienter vers une direction qui te plaît. Tourne donc ton visage vers la Mosquée sacrée. Où que vous soyez, tournez-y vos visages. Certes, ceux à qui le Livre a été donné savent bien que c'est la vérité venue de leur Seigneur. Et Allah n'est pas inattentif à ce qu'ils font.\qt@no{(144)}}
\qt@newcmd\qurantrans@fr@clii{Certes si tu apportais toutes les preuves à ceux à qui le Livre a été donné, ils ne suivraient pas ta direction (Qibla)! Et tu ne suivras pas la leur; et entre eux, les uns ne suivent pas la direction des autres. Et si tu suivais leurs passions après ce que tu as reçu de science, tu serais, certes, du nombre des injustes.\qt@no{(145)}}
\qt@newcmd\qurantrans@fr@cliii{Ceux à qui Nous avons donné le Livre, le reconnaissent comme ils reconnaissent leurs enfants. Or une partie d'entre eux cache la vérité, alors qu'ils la savent!\qt@no{(146)}}
\qt@newcmd\qurantrans@fr@cliv{La vérité vient de ton Seigneur. Ne sois donc pas de ceux qui doutent.\qt@no{(147)}}
\qt@newcmd\qurantrans@fr@clv{A chacun une orientation vers laquelle il se tourne. Rivalisez donc dans les bonnes œuvres. Où que vous soyez, Allah vous ramènera tous vers Lui, car Allah est, certes Omnipotent.\qt@no{(148)}}
\qt@newcmd\qurantrans@fr@clvi{Et d'où que tu sortes, tourne ton visage vers la Mosquée sacrée. Oui voilà bien la vérité venant de ton Seigneur. Et Allah n'est pas inattentif à ce que vous faites.\qt@no{(149)}}
\qt@newcmd\qurantrans@fr@clvii{Et d'où que tu sortes, tourne ton visage vers la Mosquée sacrée. Et où que vous soyez, tournez-y vos visages, afin que les gens n'aient pas d'argument contre vous, sauf ceux d'entre eux qui sont de vrais injustes. Ne les craignez donc pas; mais craignez-Moi pour que Je parachève Mon bienfait à votre égard, et que vous soyez bien guidés!\qt@no{(150)}}
\qt@newcmd\qurantrans@fr@clviii{Ainsi, Nous avons envoyé parmi vous un messager de chez vous qui vous récite Nos versets, vous purifie, vous enseigne le Livre et la Sagesse et vous enseigne ce que vous ne saviez pas.\qt@no{(151)}}
\qt@newcmd\qurantrans@fr@clix{Souvenez-vous de Moi donc. Je vous récompenserai. Remerciez-Moi et ne soyez pas ingrats envers Moi!\qt@no{(152)}}
\qt@newcmd\qurantrans@fr@clx{O les croyants! Cherchez secours dans l'endurance et la Salât. Car Allah est avec ceux qui sont endurants.\qt@no{(153)}}
\qt@newcmd\qurantrans@fr@clxi{Et ne dites pas de ceux qui sont tués dans le sentier d'Allah qu'ils sont morts. Au contraire ils sont vivants, mais vous en êtes inconscients.\qt@no{(154)}}
\qt@newcmd\qurantrans@fr@clxii{Très certainement, Nous vous éprouverons par un peu de peur, de faim et de diminution de biens, de personnes et de fruits. Et fais la bonne annonce aux endurants,\qt@no{(155)}}
\qt@newcmd\qurantrans@fr@clxiii{qui disent, quand un malheur les atteint: «Certes nous sommes à Allah, et c'est à Lui que nous retournerons.\qt@no{(156)}}
\qt@newcmd\qurantrans@fr@clxiv{Ceux-là reçoivent des bénédictions de leur Seigneur, ainsi que la miséricorde; et ceux-là sont les biens guidés.\qt@no{(157)}}
\qt@newcmd\qurantrans@fr@clxv{AS-Safâ et Al-Marwah sont vraiment parmi les lieux sacrés d'Allah. Donc, quiconque fait pèlerinage à la Maison ou fait l'Umra ne commet pas de péché en faisant le va-et-vient entre ces deux monts. Et quiconque fait de son propre gré une bonne œuvre, alors Allah est Reconnaissant, Omniscient.\qt@no{(158)}}
\qt@newcmd\qurantrans@fr@clxvi{Certes ceux qui cachent ce que Nous avons fait descendre en fait de preuves et de guide après l'exposé que Nous en avons fait aux gens, dans le Livre, voilà ceux qu'Allah maudit et que les maudisseurs maudissent,\qt@no{(159)}}
\qt@newcmd\qurantrans@fr@clxvii{sauf ceux qui se sont repentis, corrigés et déclarés: d'eux Je reçois le repentir. Car c'est Moi, l'Accueillant au repentir, le Miséricordieux.\qt@no{(160)}}
\qt@newcmd\qurantrans@fr@clxviii{Ceux qui ne croient pas et meurent mécréants, recevront la malédiction d'Allah, des Anges et de tous les hommes.\qt@no{(161)}}
\qt@newcmd\qurantrans@fr@clxix{Ils y demeureront éternellement; le châtiment ne leur sera pas allégé, et on ne leur accordera pas de répit.\qt@no{(162)}}
\qt@newcmd\qurantrans@fr@clxx{Et votre Divinité est une divinité unique. Pas de divinité à part Lui, le Tout Miséricordieux, le Très Miséricordieux.\qt@no{(163)}}
\qt@newcmd\qurantrans@fr@clxxi{Certes dans la création des cieux et de la terre, dans l'alternance de la nuit et du jour, dans le navire qui vogue en mer chargé de choses profitables aux gens, dans l'eau qu'Allah fait descendre du ciel, par laquelle Il rend la vie à la terre une fois morte et y répand des bêtes de toute espèce dans la variation des vents, et dans les nuages soumis entre le ciel et la terre, en tout cela il y a des signes, pour un peuple qui raisonne.\qt@no{(164)}}
\qt@newcmd\qurantrans@fr@clxxii{Parmi les hommes, il en est qui prennent, en dehors d'Allah, des égaux à Lui, en les aimant comme on aime Allah. Or les croyants sont les plus ardents en l'amour d'Allah. Quand les injustes verront le châtiment, ils sauront que la force tout entière est à Allah et qu'Allah est dur en châtiment!...\qt@no{(165)}}
\qt@newcmd\qurantrans@fr@clxxiii{Quand les meneurs désavoueront les suiveurs à la vue du châtiment, les liens entre eux seront bien brisés!\qt@no{(166)}}
\qt@newcmd\qurantrans@fr@clxxiv{Et les suiveurs diront: «Ah! Si un retour nous était possible! Alors nous les désavouerions comme ils nous ont désavoués!» - Ainsi Allah leur montra leurs actions; source de remords pour eux; mais ils ne pourront pas sortir du Feu.\qt@no{(167)}}
\qt@newcmd\qurantrans@fr@clxxv{O gens! De ce qui existe sur la terre; mangez le licite pur; ne suivez point les pas du Diable car il est vraiment pour vous, un ennemi déclaré.\qt@no{(168)}}
\qt@newcmd\qurantrans@fr@clxxvi{Il ne vous commande que le mal et la turpitude et de dire contre Allah ce que vous ne savez pas.\qt@no{(169)}}
\qt@newcmd\qurantrans@fr@clxxvii{Et quand on leur dit: «Suivez ce qu'Allah a fait descendre», ils disent: «Non, mais nous suivrons les coutumes de nos ancêtres.» - Quoi! et si leurs ancêtres n'avaient rien raisonné et s'ils n'avaient pas été dans la bonne direction?\qt@no{(170)}}
\qt@newcmd\qurantrans@fr@clxxviii{Les mécréants ressemblent à [du bétail] auquel on crie et qui entend seulement appel et voix confus. Sourds, muets, aveugles, ils ne raisonnent point.\qt@no{(171)}}
\qt@newcmd\qurantrans@fr@clxxix{O les croyants! Mangez des (nourritures) licites que Nous vous avons attribuées. Et remerciez Allah, si c'est Lui que vous adorez.\qt@no{(172)}}
\qt@newcmd\qurantrans@fr@clxxx{Certes, Il vous interdit la chair d'une bête morte, le sang, la viande de porc et ce sur quoi on a invoqué un autre qu'Allah. Il n'y a pas de péché sur celui qui est contraint sans toutefois abuser ni transgresser, car Allah est Pardonneur et Miséricordieux.\qt@no{(173)}}
\qt@newcmd\qurantrans@fr@clxxxi{Ceux qui cachent ce qu'Allah a fait descendre du Livre et le vendent à vil prix, ceux-là ne s'emplissent le ventre que de Feu. Allah ne leur adressera pas la parole, au Jour de la Résurrection, et ne les purifiera pas. Et il y aura pour eux un douloureux châtiment.\qt@no{(174)}}
\qt@newcmd\qurantrans@fr@clxxxii{Ceux-là ont échangé la bonne direction contre l'égarement et le pardon contre le châtiment. Qu'est-ce qui leur fera supporter le Feu?!\qt@no{(175)}}
\qt@newcmd\qurantrans@fr@clxxxiii{C'est ainsi, car c'est avec la vérité qu'Allah a fait descendre le Livre; et ceux qui s'opposent au sujet du Livre sont dans une profonde divergence.\qt@no{(176)}}
\qt@newcmd\qurantrans@fr@clxxxiv{La bonté pieuse ne consiste pas à tourner vos visages vers le Levant ou le Couchant. Mais la bonté pieuse est de croire en Allah, au Jour dernier, aux Anges, au Livre et aux prophètes, de donner de son bien, quelqu'amour qu'on en ait, aux proches, aux orphelins, aux nécessiteux, aux voyageurs indigents et à ceux qui demandent l'aide et pour délier les jougs, d'accomplir la Salât et d'acquitter la Zakât. Et ceux qui remplissent leurs engagements lorsqu'ils se sont engagés, ceux qui sont endurants dans la misère, la maladie et quand les combats font rage, les voilà les véridiques et les voilà les vrais pieux!\qt@no{(177)}}
\qt@newcmd\qurantrans@fr@clxxxv{O les croyants! On vous a prescrit le talion au sujet des tués: homme libre pour homme libre, esclave pour esclave, femme pour femme. Mais celui à qui son frère aura pardonné en quelque façon doit faire face à une requête convenable et doit payer des dommages de bonne grâce. Ceci est un allègement de la part de votre Seigneur, et une miséricorde. Donc, quiconque après cela transgresse, aura un châtiment douloureux.\qt@no{(178)}}
\qt@newcmd\qurantrans@fr@clxxxvi{C'est dans le talion que vous aurez la préservation de la vie, ô vous doués d'intelligence, ainsi atteindrez-vous la piété.\qt@no{(179)}}
\qt@newcmd\qurantrans@fr@clxxxvii{On vous a prescrit, quand la mort est proche de l'un de vous et s'il laisse des biens, de faire un testament en règle en faveur de ses père et mère et de ses plus proches. C'est un devoir pour les pieux.\qt@no{(180)}}
\qt@newcmd\qurantrans@fr@clxxxviii{Quiconque l'altère après l'avoir entendu, le péché ne reposera que sur ceux qui l'ont altéré; certes, Allah est Audient et Omniscient.\qt@no{(181)}}
\qt@newcmd\qurantrans@fr@clxxxix{Mais quiconque craint d'un testateur quelque partialité (volontaire ou involontaire), et les réconcilie, alors, pas de péché sur lui car Allah est certes Pardonneur et Miséricordieux!\qt@no{(182)}}
\qt@newcmd\qurantrans@fr@cxc{O les croyants! On vous a prescrit aS-Siyâm comme on l'a prescrit à ceux d'avant vous, ainsi atteindrez-vous la piété,\qt@no{(183)}}
\qt@newcmd\qurantrans@fr@cxci{pendant un nombre déterminé de jours. Quiconque d'entre vous est malade ou en voyage, devra jeûner un nombre égal d'autres jours. Mais pour ceux qui ne pourraient le supporter qu'(avec grande difficulté), il y a une compensation: nourrir un pauvre. Et si quelqu'un fait plus de son propre gré, c'est pour lui; mais il est mieux pour vous de jeûner; si vous saviez!\qt@no{(184)}}
\qt@newcmd\qurantrans@fr@cxcii{(Ces jours sont) le mois de Ramadân au cours duquel le Coran a été descendu comme guide pour les gens, et preuves claires de la bonne direction et du discernement. Donc, quiconque d'entre vous est présent en ce mois, qu'il jeûne! Et quiconque est malade ou en voyage, alors qu'il jeûne un nombre égal d'autres jours. - Allah veut pour vous la facilité, Il ne veut pas la difficulté pour vous, afin que vous en complétiez le nombre et que vous proclamiez la grandeur d'Allah pour vous avoir guidés, et afin que vous soyez reconnaissants!\qt@no{(185)}}
\qt@newcmd\qurantrans@fr@cxciii{Et quand Mes serviteurs t'interrogent sur Moi.. alors Je suis tout proche: Je réponds à l'appel de celui qui Me prie quand il Me prie. Qu'ils répondent à Mon appel, et qu'ils croient en Moi, afin qu'ils soient bien guidés.\qt@no{(186)}}
\qt@newcmd\qurantrans@fr@cxciv{On vous a permis, la nuit d'as-Siyâm, d'avoir des rapports avec vos femmes; elles sont un vêtement pour vous et vous êtes un vêtement pour elles. Allah sait que vous aviez clandestinement des rapports avec vos femmes. Il vous a pardonné et vous a graciés. Cohabitez donc avec elles, maintenant, et cherchez ce qu'Allah a prescrit en votre faveur; mangez et buvez jusqu'à ce que se distingue, pour vous, le fil blanc de l'aube du fil noir de la nuit. Puis accomplissez le jeûne jusqu'à la nuit. Mais ne cohabitez pas avec elles pendant que vous êtes en retraite rituelle dans les mosquées. Voilà les lois d'Allah: ne vous en approchez donc pas (pour les transgresser). C'est ainsi qu'Allah expose aux hommes Ses enseignements, afin qu'ils deviennent pieux!\qt@no{(187)}}
\qt@newcmd\qurantrans@fr@cxcv{Et ne dévorez pas mutuellement et illicitement vos biens; et ne vous en servez pas pour corrompre des juges pour vous permettre de dévorer une partie des biens des gens, injustement et sciemment.\qt@no{(188)}}
\qt@newcmd\qurantrans@fr@cxcvi{Ils t'interrogent sur les nouvelles lunes - Dis: «Elles servent aux gens pour compter le temps, et aussi pour le hajj [pèlerinage]. Et ce n'est pas un acte de bienfaisance que de rentrer chez vous par l'arrière des maisons. Mais la bonté pieuse consiste à craindre Allah. Entrez donc dans les maisons par leurs portes. Et craignez Allah, afin que vous réussissiez!\qt@no{(189)}}
\qt@newcmd\qurantrans@fr@cxcvii{Combattez dans le sentier d'Allah ceux qui vous combattent, et ne transgressez pas. Certes, Allah n'aime pas les transgresseurs!\qt@no{(190)}}
\qt@newcmd\qurantrans@fr@cxcviii{Et tuez-les, où que vous les rencontriez; et chassez-les d'où ils vous ont chassés: l'association est plus grave que le meurtre. Mais ne les combattez pas près de la Mosquée sacrée avant qu'ils ne vous y aient combattus. S'ils vous y combattent, tuez-les donc. Telle est la rétribution des mécréants.\qt@no{(191)}}
\qt@newcmd\qurantrans@fr@cxcix{S'ils cessent, Allah est, certes, Pardonneur et Miséricordieux.\qt@no{(192)}}
\qt@newcmd\qurantrans@fr@cc{Et combattez-les jusqu'à ce qu'il n'y ait plus d'association et que la religion soit entièrement à Allah seul. S'ils cessent, donc plus d'hostilités, sauf contre les injustes.\qt@no{(193)}}
\qt@newcmd\qurantrans@fr@cci{Le Mois sacré pour le mois sacré! - Le talion s'applique à toutes choses sacrées -. Donc, quiconque transgresse contre vous, transgressez contre lui, à transgression égale. Et craignez Allah. Et sachez qu'Allah est avec les pieux.\qt@no{(194)}}
\qt@newcmd\qurantrans@fr@ccii{Et dépensez dans le sentier d'Allah. Et ne vous jetez pas par vos propres mains dans la destruction. Et faites le bien. Car Allah aime les bienfaisants.\qt@no{(195)}}
\qt@newcmd\qurantrans@fr@cciii{Et accomplissez pour Allah le pèlerinage et l'Umra. Si vous en êtes empêchés, alors faites un sacrifice qui vous soit facile. Et ne rasez pas vos têtes avant que l'offrande [l'animal à sacrifier] n'ait atteint son lieu d'immolation. Si l'un d'entre vous est malade ou souffre d'une affection de la tête (et doit se raser), qu'il se rachète alors par un Siyâm ou par une aumône ou par un sacrifice. Quand vous retrouverez ensuite la paix, quiconque a joui d'une vie normale après avoir fait l'Umra en attendant le pèlerinage, doit faire un sacrifice qui lui soit facile. S'il n'a pas les moyens qu'il jeûne trois jours pendant le pèlerinage et sept jours une fois rentré chez lui, soit en tout dix jours. Cela est prescrit pour celui dont la famille n'habite pas auprès de la Mosquée sacrée. Et craignez Allah. Et sachez qu'Allah est dur en punition.\qt@no{(196)}}
\qt@newcmd\qurantrans@fr@cciv{Le pèlerinage a lieu dans des mois connus. Si l'on se décide de l'accomplir, alors point de rapport sexuel, point de perversité, point de dispute pendant le pèlerinage. Et le bien que vous faites, Allah le sait. Et prenez vos provisions; mais vraiment la meilleure provision est la piété. Et redoutez-Moi, ô doués d'intelligence\qt@no{(197)}}
\qt@newcmd\qurantrans@fr@ccv{Ce n'est pas un péché que d'aller en quête de quelque grâce de votre Seigneur. Puis, quand vous déferlez depuis 'Arafât, invoquez Allah, à Al-Mach'ar-al-haram (Al-Muzdalifa). Et invoquez-Le comme Il vous a montré la bonne voie, quoiqu'auparavant vous étiez du nombre des égarés.\qt@no{(198)}}
\qt@newcmd\qurantrans@fr@ccvi{Ensuite déferlez par où les gens déferlèrent, et demandez pardon à Allah. Car Allah est Pardonneur et Miséricordieux.\qt@no{(199)}}
\qt@newcmd\qurantrans@fr@ccvii{Et quand vous aurez achevé vos rites, alors invoquez Allah comme vous invoquez vos pères, et plus ardemment encore. Mais il est des gens qui disent seulement: «Seigneur! Accorde nous [le bien] ici-bas!» - Pour ceux-là, nulle part dans l'au-delà.\qt@no{(200)}}
\qt@newcmd\qurantrans@fr@ccviii{Et il est des gens qui disent: «Seigneur! Accorde nous belle part ici-bas, et belle part aussi dans l'au-delà; et protège-nous du châtiment du Feu!»\qt@no{(201)}}
\qt@newcmd\qurantrans@fr@ccix{Ceux-là auront une part de ce qu'ils auront acquis. Et Allah est prompt à faire rendre compte.\qt@no{(202)}}
\qt@newcmd\qurantrans@fr@ccx{Et invoquez Allah pendant un nombre de jours déterminés. Ensuite, il n'y a pas de péché, pour qui se comporte en piété, à partir au bout de deux jours, à s'attarder non plus. Et craignez Allah. Et sachez que c'est vers Lui que vous serez rassemblés.\qt@no{(203)}}
\qt@newcmd\qurantrans@fr@ccxi{Il y a parmi les gens celui dont la parole sur la vie présente te plaît, et qui prend Allah à témoin de ce qu'il a dans le cœur, tandis que c'est le plus acharné disputeur.\qt@no{(204)}}
\qt@newcmd\qurantrans@fr@ccxii{Dès qu'il tourne le dos, il parcourt la terre pour y semer le désordre et saccager culture et bétail. Et Allah n'aime pas le désordre!\qt@no{(205)}}
\qt@newcmd\qurantrans@fr@ccxiii{Et quand on lui dit: «Redoute Allah», l'orgueil criminel s'empare de lui. L'Enfer lui suffira, et quel mauvais lit, certes!\qt@no{(206)}}
\qt@newcmd\qurantrans@fr@ccxiv{Et il y a parmi les gens celui qui se sacrifie pour la recherche de l'agrément d'Allah. Et Allah est Compatissant envers Ses serviteurs.\qt@no{(207)}}
\qt@newcmd\qurantrans@fr@ccxv{O les croyants! Entrez en plein dans l'Islam, et ne suivez point les pas du diable, car il est certes pour vous un ennemi déclaré.\qt@no{(208)}}
\qt@newcmd\qurantrans@fr@ccxvi{Puis, si vous bronchez, après que les preuves vous soient venues, sachez alors qu'Allah est Puissant et Sage.\qt@no{(209)}}
\qt@newcmd\qurantrans@fr@ccxvii{Qu'attendent-ils sinon qu'Allah leur vienne à l'ombre des nuées de même que les Anges et que leur sort soit réglé? Et c'est à Allah que toute chose est ramenée.\qt@no{(210)}}
\qt@newcmd\qurantrans@fr@ccxviii{Demande aux enfants d'Israël combien de miracles évidents Nous leur avons apportés! Or, quiconque altère le bienfait d'Allah après qu'il lui soit parvenu... alors, Allah vraiment est dur en punition.\qt@no{(211)}}
\qt@newcmd\qurantrans@fr@ccxix{On a enjolivé la vie présente à ceux qui ne croient pas, et ils se moquent de ceux qui croient. Mais les pieux seront au-dessus d'eux, au Jour de la Résurrection. Et Allah accorde Ses bienfaits à qui Il veut, sans compter.\qt@no{(212)}}
\qt@newcmd\qurantrans@fr@ccxx{Les gens formaient (à l'origine) une seule communauté (croyante). Puis, (après leurs divergences,) Allah envoya des prophètes comme annonciateurs et avertisseurs; et Il fit descendre avec eux le Livre contenant la vérité, pour régler parmi les gens leurs divergences. Mais, ce sont ceux-là mêmes à qui il avait été apporté, qui se mirent à en disputer, après que les preuves leur furent venues, par esprit de rivalité! Puis Allah, de par Sa Grâce, guida ceux qui crurent vers cette Vérité sur laquelle les autres disputaient. Et Allah guide qui Il veut vers le chemin droit.\qt@no{(213)}}
\qt@newcmd\qurantrans@fr@ccxxi{Pensez-vous entrer au Paradis alors que vous n'avez pas encore subi des épreuves semblables à celles que subirent ceux qui vécurent avant vous? Misère et maladie les avaient touchés; et ils furent secoués jusqu'à ce que le Messager, et avec lui, ceux qui avaient cru, se fussent écriés: «Quand viendra le secours d'Allah?» - Quoi! le secours d'Allah est sûrement proche.\qt@no{(214)}}
\qt@newcmd\qurantrans@fr@ccxxii{Ils t'interrogent: «Qu'est-ce qu'on doit dépenser?» Dis: «Ce que vous dépensez de bien devrait être pour les père et mère, les proches, les orphelins, les pauvres et les voyageurs indigents. Et tout ce que vous faites de bien, vraiment Allah le sait».\qt@no{(215)}}
\qt@newcmd\qurantrans@fr@ccxxiii{Le combat vous a été prescrit alors qu'il vous est désagréable. Or, il se peut que vous ayez de l'aversion pour une chose alors qu'elle vous est un bien. Et il se peut que vous aimiez une chose alors qu'elle vous est mauvaise. C'est Allah qui sait, alors que vous ne savez pas.\qt@no{(216)}}
\qt@newcmd\qurantrans@fr@ccxxiv{Ils t'interrogent sur le fait de faire la guerre pendant les mois sacrés. - Dis: «Y combattre est un péché grave, mais plus grave encore auprès d'Allah est de faire obstacle au sentier d'Allah, d'être impie envers Celui-ci et la Mosquée sacrée, et d'expulser de là ses habitants. L'association est plus grave que le meurtre.» Or, ils ne cesseront de vous combattre jusqu'à, s'ils peuvent, vous détourner de votre religion. Et ceux qui parmi vous abjureront leur religion et mourront infidèles, vaines seront pour eux leurs actions dans la vie immédiate et la vie future. Voilà les gens du Feu: ils y demeureront éternellement.\qt@no{(217)}}
\qt@newcmd\qurantrans@fr@ccxxv{Certes, ceux qui ont cru, émigré et lutté dans le sentier d'Allah, ceux-là espèrent la miséricorde d'Allah. Et Allah est Pardonneur et Miséricordieux.\qt@no{(218)}}
\qt@newcmd\qurantrans@fr@ccxxvi{Ils t'interrogent sur le vin et les jeux de hasard. Dis: «Dans les deux il y a un grand péché et quelques avantages pour les gens; mais dans les deux, le péché est plus grand que l'utilité». Et ils t'interrogent: «Que doit-on dépenser (en charité)?» Dis: «L'excédent de vos biens.» Ainsi, Allah vous explique Ses versets afin que vous méditiez\qt@no{(219)}}
\qt@newcmd\qurantrans@fr@ccxxvii{sur ce monde et sur l'au-delà! Et ils t'interrogent au sujet des orphelins. Dis: «Leur faire du bien est la meilleure action. Si vous vous mêlez à eux, ce sont alors vos frères [en religion]. Allah distingue celui qui sème le désordre de celui qui fait le bien. Et si Allah avait voulu, Il vous aurait accablés. Certes Allah est Puissant et Sage.\qt@no{(220)}}
\qt@newcmd\qurantrans@fr@ccxxviii{Et n'épousez pas les femmes associatrices tant qu'elles n'auront pas la foi, et certes, une esclave croyante vaut mieux qu'une associatrice même si elle vous enchante. Et ne donnez pas d'épouses aux associateurs tant qu'ils n'auront pas la foi, et certes, un esclave croyant vaut mieux qu'un associateur même s'il vous enchante. Car ceux-là [les associateurs] invitent au Feu; tandis qu'Allah invite, de par Sa Grâce, au Paradis et au pardon Et Il expose aux gens Ses enseignements afin qu'ils se souviennent!\qt@no{(221)}}
\qt@newcmd\qurantrans@fr@ccxxix{- Et ils t'interrogent sur la menstruation des femmes. - Dis: «C'est un mal. Eloignez-vous donc des femmes pendant les menstrues, et ne les approchez que quand elles sont pures. Quand elles se sont purifiées, alors cohabitez avec elles suivant les prescriptions d'Allah car Allah aime ceux qui se repentent, et Il aime ceux qui se purifient».\qt@no{(222)}}
\qt@newcmd\qurantrans@fr@ccxxx{Vos épouses sont pour vous un champ de labour; allez à votre champ comme [et quand] vous le voulez et œuvrez pour vous-mêmes à l'avance. Craignez Allah et sachez que vous Le rencontrerez. Et fais gracieuse annonce aux croyants!\qt@no{(223)}}
\qt@newcmd\qurantrans@fr@ccxxxi{Et n'usez pas du nom d'Allah, dans vos serments, pour vous dispenser de faire le bien, d'être pieux et de réconcilier les gens. Et Allah est Audient et Omniscient.\qt@no{(224)}}
\qt@newcmd\qurantrans@fr@ccxxxii{Ce n'est pas pour les expressions gratuites dans vos serments qu'Allah vous saisit: Il vous saisit pour ce que vos cœurs ont acquis. Et Allah est Pardonneur et Patient.\qt@no{(225)}}
\qt@newcmd\qurantrans@fr@ccxxxiii{Pour ceux qui font le serment de se priver de leurs femmes, il y a un délai d'attente de quatre mois. Et s'ils reviennent (de leur serment) celui-ci sera annulé, car Allah est certes Pardonneur et Miséricordieux!\qt@no{(226)}}
\qt@newcmd\qurantrans@fr@ccxxxiv{Mais s'ils se décident au divorce, (celui-ci devient exécutoire) car Allah est certes Audient et Omniscient.\qt@no{(227)}}
\qt@newcmd\qurantrans@fr@ccxxxv{Et les femmes divorcées doivent observer un délai d'attente de trois menstrues; et il ne leur est pas permis de taire ce qu'Allah a créé dans leurs ventres, si elles croient en Allah et au Jour dernier. Et leurs époux seront plus en droit de les reprendre pendant cette période, s'ils veulent la réconciliation. Quant à elles, elles ont des droits équivalents à leurs obligations, conformément à la bienséance. Mais les hommes ont cependant une prédominance sur elles. Et Allah est Puissant et Sage.\qt@no{(228)}}
\qt@newcmd\qurantrans@fr@ccxxxvi{Le divorce est permis pour seulement deux fois. Alors, c'est soit la reprise conformément à la bienséance, ou la libération avec gentillesse. Et il ne vous est pas permis de reprendre quoi que ce soit de ce que vous leur aviez donné, - à moins que tous deux ne craignent de ne point pouvoir se conformer aux ordres imposés par Allah. Si donc vous craignez que tous deux ne puissent se conformer aux ordres d'Allah, alors ils ne commettent aucun péché si la femme se rachète avec quelque bien. Voilà les ordres d'Allah. Ne les transgressez donc pas. Et ceux qui transgressent les ordres d'Allah ceux-là sont les injustes.\qt@no{(229)}}
\qt@newcmd\qurantrans@fr@ccxxxvii{S'il divorce avec elle (la troisième fois) alors elle ne lui sera plus licite tant qu'elle n'aura pas épousé un autre. Et si ce (dernier) la répudie alors les deux ne commettent aucun péché en reprenant la vie commune, pourvu qu'ils pensent pouvoir tous deux se conformer aux ordres d'Allah. Voilà les ordres d'Allah, qu'Il expose aux gens qui comprennent.\qt@no{(230)}}
\qt@newcmd\qurantrans@fr@ccxxxviii{Et quand vous divorcez d'avec vos épouses, et que leur délai expire, alors, reprenez-les conformément à la bienséance ou libérez-les conformément à la bienséance. Mais ne les retenez pas pour leur faire du tort: vous transgresseriez alors et quiconque agit ainsi se fait du tort à lui-même. Ne prenez pas en moquerie les versets d'Allah. Et rappelez-vous le bienfait d'Allah envers vous, ainsi que le Livre et la Sagesse qu'Il vous a fait descendre; par lesquels Il vous exhorte. Et craignez Allah, et sachez qu'Allah est Omniscient.\qt@no{(231)}}
\qt@newcmd\qurantrans@fr@ccxxxix{Et quand vous divorcez d'avec vos épouses, et que leur délai expire, alors ne les empêchez pas de renouer avec leurs époux, s'ils s'agréent l'un l'autre, et conformément à la bienséance. Voilà à quoi est exhorté celui d'entre vous qui croit en Allah et au Jour dernier. Ceci est plus décent et plus pur pour vous. Et Allah sait, alors que vous ne savez pas.\qt@no{(232)}}
\qt@newcmd\qurantrans@fr@ccxl{Et les mères, qui veulent donner un allaitement complet, allaiteront leurs bébés deux ans complets. Au père de l'enfant de les nourrir et vêtir de manière convenable. Nul ne doit supporter plus que ses moyens. La mère n'a pas à subir de dommage à cause de son enfant, ni le père, à cause de son enfant. Même obligation pour l'héritier. Et si, après s'être consultés, tous deux tombent d'accord pour décider le sevrage, nul grief à leur faire. Et si vous voulez mettre vos enfants en nourrice, nul grief à vous faire non plus, à condition que vous acquittiez la rétribution convenue, conformément à l'usage. Et craignez Allah, et sachez qu'Allah observe ce que vous faites.\qt@no{(233)}}
\qt@newcmd\qurantrans@fr@ccxli{Ceux des vôtres que la mort frappe et qui laissent des épouses: celles-ci doivent observer une période d'attente de quatre mois et dix jours. Passé ce délai, on ne vous reprochera pas la façon dont elles disposeront d'elles-mêmes d'une manière convenable. Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(234)}}
\qt@newcmd\qurantrans@fr@ccxlii{Et on ne vous reprochera pas de faire, aux femmes, allusion à une proposition de mariage, ou d'en garder secrète l'intention. Allah sait que vous allez songer à ces femmes. Mais ne leur promettez rien secrètement sauf à leur dire des paroles convenables. Et ne vous décidez au contrat de mariage qu'à l'expiration du délai prescrit. Et sachez qu'Allah sait ce qu'il y a dans vos âmes. Prenez donc garde à Lui, et sachez aussi qu'Allah est Pardonneur et Plein de mansuétude.\qt@no{(235)}}
\qt@newcmd\qurantrans@fr@ccxliii{Vous ne faites point de péché en divorçant d'avec des épouses que vous n'avez pas touchées, et à qui vous n'avez pas fixé leur mahr. Donnez-leur toutefois - l'homme aisé selon sa capacité, l'indigent selon sa capacité - quelque bien convenable dont elles puissent jouir. C'est un devoir pour les bienfaisants..\qt@no{(236)}}
\qt@newcmd\qurantrans@fr@ccxliv{Et si vous divorcez d'avec elles sans les avoir touchées, mais après fixation de leur mahr versez-leur alors la moitié de ce que vous avez fixé, à moins qu'elles ne s'en désistent, ou que ne se désiste celui entre les mains de qui est la conclusion du mariage. Le désistement est plus proche de la piété. Et n'oubliez pas votre faveur mutuelle. Car Allah voit parfaitement ce que vous faites.\qt@no{(237)}}
\qt@newcmd\qurantrans@fr@ccxlv{Soyez assidus aux Salâts et surtout la Salât médiane; et tenez-vous debout devant Allah, avec humilité.\qt@no{(238)}}
\qt@newcmd\qurantrans@fr@ccxlvi{Mais si vous craignez (un grand danger), alors priez en marchant ou sur vos montures. Puis quand vous êtes en sécurité, invoquez Allah comme Il vous a enseigné ce que vous ne saviez pas.\qt@no{(239)}}
\qt@newcmd\qurantrans@fr@ccxlvii{Ceux d'entre vous que la mort frappe et qui laissent des épouses, doivent laisser un testament en faveur de leurs épouses pourvoyant à un an d'entretien sans les expulser de chez elles. Si ce sont elles qui partent, alors on ne vous reprochera pas ce qu'elles font de convenable pour elles-mêmes. Allah est Puissant et Sage.\qt@no{(240)}}
\qt@newcmd\qurantrans@fr@ccxlviii{Les divorcées ont droit à la jouissance d'une allocation convenable, [constituant] un devoir pour les pieux.\qt@no{(241)}}
\qt@newcmd\qurantrans@fr@ccxlix{C'est ainsi qu'Allah vous explique Ses versets, afin que vous raisonniez!\qt@no{(242)}}
\qt@newcmd\qurantrans@fr@ccl{N'as-tu pas vu ceux qui sortirent de leurs demeures, - il y en avait des milliers -, par crainte de la mort? Puis Allah leur dit: «Mourez». Après quoi Il les rendit à la vie. Certes, Allah est Détenteur de la Faveur, envers les gens; mais la plupart des gens ne sont pas reconnaissants.\qt@no{(243)}}
\qt@newcmd\qurantrans@fr@ccli{Et combattez dans le sentier d'Allah. Et sachez qu'Allah est Audient et Omniscient.\qt@no{(244)}}
\qt@newcmd\qurantrans@fr@cclii{Quiconque prête à Allah de bonne grâce, Il le lui rendra multiplié plusieurs fois. Allah restreint ou étend (Ses faveurs.) Et c'est à Lui que vous retournerez.\qt@no{(245)}}
\qt@newcmd\qurantrans@fr@ccliii{N'as-tu pas su l'histoire des notables, parmi les enfants d'Israël, lorsqu'après Moïse ils dirent à un prophète à eux: «Désigne-nous un roi, pour que nous combattions dans le sentier d'Allah». Il dit: «Et si vous ne combattez pas, quand le combat vous sera prescrit?» Ils dirent: «Et qu'aurions-nous à ne pas combattre dans le sentier d'Allah, alors qu'on nous a expulsés de nos maisons et qu'on a capturé nos enfants?» Et quand le combat leur fut prescrit, ils tournèrent le dos, sauf un petit nombre d'entre eux. Et Allah connaît bien les injustes.\qt@no{(246)}}
\qt@newcmd\qurantrans@fr@ccliv{Et leur prophète leur dit: «Voici qu'Allah vous a envoyé Tâlût pour roi.» Ils dirent: «Comment règnerait-il sur nous? Nous avons plus de droit que lui à la royauté. On ne lui a même pas prodigué beaucoup de richesses!» Il dit: «Allah, vraiment l'a élu sur vous, et a accru sa part quant au savoir et à la condition physique.» - Et Allah alloue Son pouvoir à qui Il veut. Allah a la grâce immense et Il est Omniscient.\qt@no{(247)}}
\qt@newcmd\qurantrans@fr@cclv{Et leur prophète leur dit: «Le signe de son investiture sera que le Coffre va vous revenir; objet de quiétude inspiré par votre Seigneur, et contenant les reliques de ce que laissèrent la famille de Moïse et la famille d'Aaron. Les Anges le porteront. Voilà bien là un signe pour vous, si vous êtes croyants!»\qt@no{(248)}}
\qt@newcmd\qurantrans@fr@cclvi{Puis, au moment de partir avec les troupes, Tâlût dit: «Voici: Allah va vous éprouver par une rivière: quiconque y boira ne sera plus des miens; et quiconque n'y goûtera pas sera des miens; - passe pour celui qui y puisera un coup dans le creux de sa main.» Ils en burent, sauf un petit nombre d'entre eux. Puis, lorsqu'ils l'eurent traversée, lui et ceux des croyants qui l'accompagnaient, ils dirent: «Nous voilà sans force aujourd'hui contre Goliath et ses troupes!» Ceux qui étaient convaincus qu'ils auront à rencontrer Allah dirent: «Combien de fois une troupe peu nombreuse a, par la grâce d'Allah, vaincu une troupe très nombreuse! Et Allah est avec les endurants»\qt@no{(249)}}
\qt@newcmd\qurantrans@fr@cclvii{Et quand ils affrontèrent Goliath et ses troupes, ils dirent: «Seigneur! Déverse sur nous l'endurance, affermis nos pas et donne-nous la victoire sur ce peuple infidèle».\qt@no{(250)}}
\qt@newcmd\qurantrans@fr@cclviii{Ils les mirent en déroute, par la grâce d'Allah. Et David tua Goliath; et Allah lui donna la royauté et la sagesse, et lui enseigna ce qu'Il voulut. Et si Allah ne neutralisait pas une partie des hommes par une autre, la terre serait certainement corrompue. Mais Allah est Détenteur de la Faveur pour les mondes.\qt@no{(251)}}
\qt@newcmd\qurantrans@fr@cclix{Voilà les versets d'Allah, que Nous te (Muhammad) récitons avec la vérité. Et tu es, certes parmi les Envoyés.\qt@no{(252)}}
\qt@newcmd\qurantrans@fr@cclx{Parmi ces messagers, Nous avons favorisé certains par rapport à d'autres. Il en est à qui Allah a parlé; et Il en a élevé d'autres en grade. A Jésus fils de Marie Nous avons apporté les preuves, et l'avons fortifié par le Saint-Esprit. Et si Allah avait voulu, les gens qui vinrent après eux ne se seraient pas entretués, après que les preuves leur furent venues; mais ils se sont opposés: les uns restèrent croyants, les autres furent infidèles. Si Allah avait voulu, ils ne se seraient pas entretués; mais Allah fait ce qu'Il veut.\qt@no{(253)}}
\qt@newcmd\qurantrans@fr@cclxi{O les croyants! Dépensez de ce que Nous vous avons attribué, avant que vienne le jour où il n'y aura ni rançon ni amitié ni intercession. Et ce sont les mécréants qui sont les injustes.\qt@no{(254)}}
\qt@newcmd\qurantrans@fr@cclxii{Allah! Point de divinité à part Lui, le Vivant, Celui qui subsiste par lui-même «Al-Qayyûm». Ni somnolence ni sommeil ne Le saisissent. A Lui appartient tout ce qui est dans les cieux et sur la terre. Qui peut intercéder auprès de Lui sans Sa permission? Il connaît leur passé et leur futur. Et, de Sa science, ils n'embrassent que ce qu'Il veut. Son Trône «Kursiy», déborde les cieux et la terre, dont la garde ne Lui coûte aucune peine. Et Il est le Très Haut, le Très Grand.\qt@no{(255)}}
\qt@newcmd\qurantrans@fr@cclxiii{Nulle contrainte en religion! Car le bon chemin s'est distingué de l'égarement. Donc, quiconque mécroit au Rebelle tandis qu'il croit en Allah saisit l'anse la plus solide, qui ne peut se briser. Et Allah est Audient et Omniscient.\qt@no{(256)}}
\qt@newcmd\qurantrans@fr@cclxiv{Allah est le défenseur de ceux qui ont la foi: Il les fait sortir des ténèbres à la lumière. Quant à ceux qui ne croient pas, ils ont pour défenseurs les Tâghût, qui les font sortir de la lumière aux ténèbres. Voilà les gens du Feu, où ils demeurent éternellement.\qt@no{(257)}}
\qt@newcmd\qurantrans@fr@cclxv{N'as-tu pas su (l'histoire de) celui qui, parce qu'Allah l'avait fait roi, argumenta contre Abraham au sujet de son Seigneur? Abraham ayant dit: «J'ai pour Seigneur Celui qui donne la vie et la mort», «Moi aussi, dit l'autre, je donne la vie et la mort.» Alors dit Abraham: «Puisqu'Allah fait venir le soleil du Levant, fais-le donc venir du Couchant.» Le mécréant resta alors confondu. Allah ne guide pas les gens injustes.\qt@no{(258)}}
\qt@newcmd\qurantrans@fr@cclxvi{Ou comme celui qui passait par un village désert et dévasté: «Comment Allah va-t-Il redonner la vie à celui-ci après sa mort?» dit-il. Allah donc le fit mourir et le garda ainsi pendant cent ans. Puis Il le ressuscita en disant: «Combien de temps as-tu demeuré ainsi?» «Je suis resté un jour, dit l'autre, ou une partie d'une journée.» «Non! dit Allah, tu es resté cent ans. Regarde donc ta nourriture et ta boisson: rien ne s'est gâté; mais regarde ton âne... Et pour faire de toi un signe pour les gens, et regarde ces ossements, comment Nous les assemblons et les revêtons de chair». Et devant l'évidence, il dit: «Je sais qu'Allah est Omnipotent».\qt@no{(259)}}
\qt@newcmd\qurantrans@fr@cclxvii{Et quand Abraham dit: «Seigneur! Montre-moi comment Tu ressuscites les morts», Allah dit: «Ne crois-tu pas encore?» «Si! dit Abraham; mais que mon cœur soit rassuré». «Prends donc, dit Allah, quatre oiseaux, apprivoise-les (et coupe-les) puis, sur des monts séparés, mets-en un fragment ensuite appelle-les: ils viendront à toi en toute hâte. Et sache qu'Allah est Puissant et sage.»\qt@no{(260)}}
\qt@newcmd\qurantrans@fr@cclxviii{Ceux qui dépensent leurs biens dans le sentier d'Allah ressemblent à un grain d'où naissent sept épis, à cent grains l'épi. Car Allah multiplie la récompense à qui Il veut et la grâce d'Allah est immense, et Il est Omniscient.\qt@no{(261)}}
\qt@newcmd\qurantrans@fr@cclxix{Ceux qui dépensent leurs biens dans le sentier d'Allah sans faire suivre leurs largesses ni d'un rappel ni d'un tort, auront leur récompense auprès de leur Seigneur. Nulle crainte pour eux, et ils ne seront point affligés.\qt@no{(262)}}
\qt@newcmd\qurantrans@fr@cclxx{Une parole agréable et un pardon valent mieux qu'une aumône suivie d'un tort. Allah n'a besoin de rien, et Il est Indulgent.\qt@no{(263)}}
\qt@newcmd\qurantrans@fr@cclxxi{O les croyants! N'annulez pas vos aumônes par un rappel ou un tort, comme celui qui dépense son bien par ostentation devant les gens sans croire en Allah et au Jour dernier. Il ressemble à un rocher recouvert de terre: qu'une averse l'atteigne, elle le laisse dénué. De pareils hommes ne tirent aucun profit de leurs actes. Et Allah ne guide pas les gens mécréants.\qt@no{(264)}}
\qt@newcmd\qurantrans@fr@cclxxii{Et ceux qui dépensent leurs biens cherchant l'agrément d'Allah, et bien rassurés (de Sa récompense), ils ressemblent à un jardin sur une colline. Qu'une averse l'atteigne, il double ses fruits; à défaut d'une averse qui l'atteint, c'est la rosée. Et Allah voit parfaitement ce que vous faites.\qt@no{(265)}}
\qt@newcmd\qurantrans@fr@cclxxiii{L'un de vous aimerait-il avoir un jardin de dattiers et de vignes sous lequel coulent les ruisseaux, et qui lui donne toutes espèces de fruits, que la vieillesse le rattrape, tandis que ses enfants sont encore petits, et qu'un tourbillon contenant du feu s'abatte sur son jardin et le brûle? Ainsi Allah vous explique les signes afin que vous méditiez!\qt@no{(266)}}
\qt@newcmd\qurantrans@fr@cclxxiv{O les croyants! Dépensez des meilleures choses que vous avez gagnées et des récoltes que Nous avons fait sortir de la terre pour vous. Et ne vous tournez pas vers ce qui est vil pour en faire dépense. Ne donnez pas ce que vous-mêmes n'accepteriez qu'en fermant les yeux! Et sachez qu'Allah n'a besoin de rien et qu'Il est digne de louange.\qt@no{(267)}}
\qt@newcmd\qurantrans@fr@cclxxv{Le Diable vous fait craindre l'indigence et vous commande des actions honteuses; tandis qu'Allah vous promet pardon et faveur venant de Lui. La grâce d'Allah est immense et Il est Omniscient.\qt@no{(268)}}
\qt@newcmd\qurantrans@fr@cclxxvi{Il donne la sagesse à qui Il veut. Et celui à qui la sagesse est donnée, vraiment, c'est un bien immense qui lui est donné. Mais les doués d'intelligence seulement s'en souviennent.\qt@no{(269)}}
\qt@newcmd\qurantrans@fr@cclxxvii{Quelles que soient les dépenses que vœus avez faites, ou le vou que vous avez voué, Allah le sait. Et pour les injustes, pas de secoureurs!\qt@no{(270)}}
\qt@newcmd\qurantrans@fr@cclxxviii{Si vous donnez ouvertement vos aumônes, c'est bien; c'est mieux encore, pour vous, si vous êtes discrets avec elles et vous les donniez aux indigents. Allah effacera une partie de vos méfaits. Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(271)}}
\qt@newcmd\qurantrans@fr@cclxxix{Ce n'est pas à toi de les guider (vers la bonne voie), mais c'est Allah qui guide qui Il veut. Et tout ce que vous dépensez de vos biens sera à votre avantage et vous ne dépensez que pour la recherche de la Face «Wajh» d'Allah. Et tout ce que vous dépensez de vos biens dans les bonnes œuvres vous sera récompensé pleinement. Et vous ne serez pas lésés.\qt@no{(272)}}
\qt@newcmd\qurantrans@fr@cclxxx{Aux nécessiteux qui se sont confinés dans le sentier d'Allah, ne pouvant pas parcourir le monde, et que l'ignorant croit riches parce qu'ils ont honte de mendier - tu les reconnaîtras à leur aspect - Ils n'importunent personne en mendiant. Et tout ce que vous dépensez de vos biens, Allah le sait parfaitement.\qt@no{(273)}}
\qt@newcmd\qurantrans@fr@cclxxxi{Ceux qui, de nuit et de jour, en secret et ouvertement, dépensent leurs biens (dans les bonnes œuvres), ont leur salaire auprès de leur Seigneur. Ils n'ont rien à craindre et ils ne seront point affligés.\qt@no{(274)}}
\qt@newcmd\qurantrans@fr@cclxxxii{Ceux qui mangent [pratiquent] de l'intérêt usuraire ne se tiennent (au jour du Jugement dernier) que comme se tient celui que le toucher de Satan a bouleversé. Cela, parce qu'ils disent: «Le commerce est tout à fait comme l'intérêt». Alors qu'Allah a rendu licite le commerce, et illicite l'intérêt. Celui, donc, qui cesse dès que lui est venue une exhortation de son Seigneur, peut conserver ce qu'il a acquis auparavant; et son affaire dépend d'Allah. Mais quiconque récidive... alors les voilà, les gens du Feu! Ils y demeureront éternellement.\qt@no{(275)}}
\qt@newcmd\qurantrans@fr@cclxxxiii{Allah anéantit l'intérêt usuraire et fait fructifier les aumônes. Et Allah n'aime pas le mécréant pécheur.\qt@no{(276)}}
\qt@newcmd\qurantrans@fr@cclxxxiv{Ceux qui ont la foi, ont fait de bonnes œuvres, accompli la Salât et acquitté la Zakât auront certes leur récompense auprès de leur Seigneur. Pas de crainte pour eux, et ils ne seront point affligés.\qt@no{(277)}}
\qt@newcmd\qurantrans@fr@cclxxxv{O les croyants! Craignez Allah; et renoncez au reliquat de l'intérêt usuraire, si vous êtes croyants.\qt@no{(278)}}
\qt@newcmd\qurantrans@fr@cclxxxvi{Et si vous ne le faites pas, alors recevez l'annonce d'une guerre de la part d'Allah et de Son messager. Et si vous vous repentez, vous aurez vos capitaux. Vous ne léserez personne, et vous ne serez point lésés.\qt@no{(279)}}
\qt@newcmd\qurantrans@fr@cclxxxvii{A celui qui est dans la gêne, accordez un sursis jusqu'à ce qu'il soit dans l'aisance. Mais il est mieux pour vous de faire remise de la dette par charité! Si vous saviez!\qt@no{(280)}}
\qt@newcmd\qurantrans@fr@cclxxxviii{Et craignez le jour où vous serez ramenés vers Allah. Alors chaque âme sera pleinement rétribuée de ce qu'elle aura acquis. Et ils ne seront point lésés.\qt@no{(281)}}
\qt@newcmd\qurantrans@fr@cclxxxix{O les croyants! Quand vous contractez une dette à échéance déterminée, mettez-la en écrit; et qu'un scribe l'écrive, entre vous, en toute justice; un scribe n'a pas à refuser d'écrire selon ce qu'Allah lui a enseigné; qu'il écrive donc, et que dicte le débiteur: qu'il craigne Allah son Seigneur, et se garde d'en rien diminuer. Si le débiteur est gaspilleur ou faible, ou incapable de dicter lui-même, que son représentant dicte alors en toute justice. Faites-en témoigner par deux témoins d'entre vos hommes; et à défaut de deux hommes, un homme et deux femmes d'entre ceux que vous agréez comme témoins, en sorte que si l'une d'elles s'égare, l'autre puisse lui rappeler. Et que les témoins ne refusent pas quand ils sont appelés. Ne vous lassez pas d'écrire la dette, ainsi que son terme, qu'elle soit petite ou grande: c'est plus équitable auprès d'Allah, et plus droit pour le témoignage, et plus susceptible d'écarter les doutes. Mais s'il s'agit d'une marchandise présente que vous négociez entre vous: dans ce cas, il n'y a pas de péché à ne pas l'écrire. Mais prenez des témoins lorsque vous faites une transaction entre vous; et qu'on ne fasse aucun tort à aucun scribe ni à aucun témoin. Si vous le faisiez, cela serait une perversité en vous. Et craignez Allah. Alors Allah vous enseigne et Allah est Omniscient.\qt@no{(282)}}
\qt@newcmd\qurantrans@fr@ccxc{Mais si vous êtes en voyage et ne trouvez pas de scribe, un gage reçu suffit. S'il y a entre vous une confiance réciproque, que celui à qui on a confié quelque chose la restitue; et qu'il craigne Allah son Seigneur. Et ne cachez pas le témoignage: quiconque le cache a, certes, un cœur pécheur. Allah, de ce que vous faites, est Omniscient.\qt@no{(283)}}
\qt@newcmd\qurantrans@fr@ccxci{C'est à Allah qu'appartient tout ce qui est dans les cieux et sur la terre. Que vous manifestiez ce qui est en vous ou que vous le cachiez, Allah vous en demandera compte. Puis Il pardonnera à qui Il veut, et châtiera qui Il veut. Et Allah est Omnipotent.\qt@no{(284)}}
\qt@newcmd\qurantrans@fr@ccxcii{Le Messager a cru en ce qu'on a fait descendre vers lui venant de son Seigneur, et aussi les croyants: tous ont cru en Allah, en Ses anges, à Ses livres et en Ses messagers; (en disant): «Nous ne faisons aucune distinction entre Ses messagers». Et ils ont dit: «Nous avons entendu et obéi. Seigneur, nous implorons Ton pardon. C'est à Toi que sera le retour».\qt@no{(285)}}
\qt@newcmd\qurantrans@fr@ccxciii{Allah n'impose à aucune âme une charge supérieure à sa capacité. Elle sera récompensée du bien qu'elle aura fait, punie du mal qu'elle aura fait. Seigneur, ne nous châtie pas s'il nous arrive d'oublier ou de commettre une erreur. Seigneur! Ne nous charge pas d'un fardeau lourd comme Tu as chargé ceux qui vécurent avant nous. Seigneur! Ne nous impose pas ce que nous ne pouvons supporter, efface nos fautes, pardonne-nous et fais nous miséricorde. Tu es Notre Maître, accorde-nous donc la victoire sur les peuples infidèles.\qt@no{(286)}}
\qt@newcmd\qurantrans@fr@ccxciv{\basmalahfr Alif, Lâm, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@ccxcv{Allah! Pas de divinité à part Lui, le Vivant, Celui qui subsiste par Lui-même «Al-Qayyum».\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@ccxcvi{Il a fait descendre sur toi le Livre avec la vérité, confirmant les Livres descendus avant lui. Et Il fit descendre la Thora et l'Evangile.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@ccxcvii{auparavant, en tant que guide pour les gens. Et Il a fait descendre le Discernement. Ceux qui ne croient pas aux Révélations d'Allah auront, certes, un dur châtiment! Et, Allah est Puissant, Détenteur du pouvoir de punir.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@ccxcviii{Rien, vraiment, ne se cache d'Allah de ce qui existe sur la terre ou dans le ciel.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@ccxcix{C'est Lui qui vous donne forme dans les matrices comme Il veut. Point de divinité à part Lui, le Puissant, le Sage.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@ccc{C'est Lui qui a fait descendre sur toi le Livre: il s'y trouve des versets sans équivoque, qui sont la base du Livre, et d'autres versets qui peuvent prêter à d'interprétations diverses. Les gens, donc, qui ont au cœur une inclination vers l'égarement, mettent l' accent sur les versets à équivoque cherchant la dissension en essayant de leur trouver une interprétation, alors que nul n'en connaît l'interprétation, à part Allah. Mais ceux qui sont bien enracinés dans la science disent: «Nous y croyons: tout est de la part de notre Seigneur!» Mais, seuls les doués d'intelligence s'en rappellent.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@ccci{«Seigneur! Ne laisse pas dévier nos cœurs après que Tu nous aies guidés; et accorde-nous Ta miséricorde. C'est Toi, certes, le Grand Donateur!\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@cccii{Seigneur! C'est Toi qui rassembleras les gens, un jour - en quoi il n'y a point de doute - Allah, vraiment, ne manque jamais à Sa promesse.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@ccciii{Ceux qui ne croient pas, ni leurs biens ni leurs enfants ne les mettront aucunement à l' abri de la punition d'Allah. Ils seront du combustible pour le Feu,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@ccciv{comme les gens de Pharaon et ceux qui vécurent avant eux. Ils avaient traité de mensonges Nos preuves. Allah les saisit donc, pour leurs péchés. Et Allah est dur en punition.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@cccv{Dis à ceux qui ne croient pas: «Vous serez vaincus bientôt; et vous serez rassemblés vers l'Enfer. Et quel mauvais endroit pour se reposer!»\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@cccvi{Il y eut déjà pour vous un signe dans ces deux troupes qui s'affrontèrent: l'une combattait dans le sentier d'Allah; et l'autre, était mécréante. Ces derniers voyaient (les croyants) de leurs propres yeux, deux fois plus nombreux qu'eux-mêmes. Or Allah secourt qui Il veut de Son aide. Voilà bien là un exemple pour les doués de clairvoyance!\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@cccvii{On a enjolivé aux gens l'amour des choses qu'ils désirent: femmes, enfants, trésors thésaurisés d'or et d'argent, chevaux marqués, bétail et champs; tout cela est l'objet de jouissance pour la vie présente, alors que c'est près d'Allah qu'il y a bon retour.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@cccviii{Dis: «Puis-je vous apprendre quelque chose de meilleur que tout cela? Pour les pieux, il y a, auprès de leur Seigneur, des jardins sous lesquels coulent les ruisseaux, pour y demeurer éternellement, et aussi, des épouses purifiées, et l'agrément d'Allah.» Et Allah est Clairvoyant sur [Ses] serviteurs,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@cccix{qui disent: «O notre Seigneur, nous avons la foi; pardonne-nous donc nos péchés, et protège-nous du châtiment du Feu»,\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@cccx{ce sont les endurants, les véridiques, les obéissants, ceux qui dépensent [dans le sentier d'Allah] et ceux qui implorent pardon juste avant l'aube.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@cccxi{Allah atteste, et aussi les Anges et les doués de science, qu'il n'y a point de divinité à part Lui, le Mainteneur de la justice. Point de divinité à part Lui, le Puissant, le Sage!\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@cccxii{Certes, la religion acceptée d'Allah, c'est l'Islam. Ceux auxquels le Livre a été apporté ne se sont disputés, par agressivité entre eux, qu'après avoir reçu la science. Et quiconque ne croit pas aux signes d'Allah... alors Allah est prompt à demander compte!\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@cccxiii{S'ils te contredisent, dis leur: «Je me suis entièrement soumis à Allah, moi et ceux qui m'ont suivi». Et dis à ceux à qui le Livre a été donné, ainsi qu'aux illettrés: «Avez-vous embrassé l'Islam?» S'ils embrassent l'Islam, ils seront bien guidés. Mais; s'ils tournent le dos... Ton devoir n'est que la transmission (du message). Allah, sur [Ses] serviteurs est Clairvoyant.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@cccxiv{Ceux qui ne croient pas aux signes d'Allah, tuent sans droit les prophètes et tuent les gens qui commandent la justice, annonce-leur un châtiment douloureux.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@cccxv{Ce sont eux dont les œuvres sont devenues vaines, ici-bas comme dans l'au-delà. Et pour eux, pas de secoureurs!\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@cccxvi{N'as-tu pas vu comment agissent ceux qui ont reçu une part du Livre, et qui sont maintenant invités au Livre d'Allah pour trancher leurs différends; comment un groupe des leurs tourne le dos et s'esquive?\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@cccxvii{C'est parce qu'ils disent: «Le Feu ne nous touchera que pour un nombre de jours déterminés.» Et leurs mensonges les trompent en religion.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@cccxviii{Eh bien comment seront-ils, quand Nous les aurons rassemblés, en un jour sur quoi il n'y a point de doute, et que chaque âme sera pleinement rétribuée selon ce qu'elle aura acquis? Et ils ne seront point lésés.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@cccxix{- Dis: «O Allah, Maître de l'autorité absolue. Tu donnes l'autorité à qui Tu veux, et Tu arraches l'autorité à qui Tu veux; et Tu donnes la puissance à qui Tu veux, et Tu humilies qui Tu veux. Le bien est en Ta main et Tu es Omnipotent.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@cccxx{Tu fais pénétrer la nuit dans le jour, et Tu fais pénétrer le jour dans la nuit, et Tu fais sortir le vivant du mort, et Tu fais sortir le mort du vivant. Et Tu accordes attribution à qui Tu veux, sans compter».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@cccxxi{Que les croyants ne prennent pas, pour alliés, des infidèles, au lieu de croyants. Quiconque le fait contredit la religion d'Allah, à moins que vous ne cherchiez à vous protéger d'eux. Allah vous met en garde à l'égard de Lui-même. Et c'est à Allah le retour.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@cccxxii{Dis: «Que vous cachiez ce qui est dans vos poitrines ou bien vous le divulguiez, Allah le sait. Il connaît tout ce qui est dans les cieux et sur la terre. Et Allah est Omnipotent.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@cccxxiii{Le jour où chaque âme se trouvera confrontée avec ce qu'elle aura fait de bien et ce qu'elle aura fait de mal; elle souhaitera qu'il y ait entre elle et ce mal une longue distance! Allah vous met en garde à l'égard de Lui-même. Allah est Compatissant envers [Ses] serviteurs.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@cccxxiv{Dis: «Si vous aimez vraiment Allah, suivez-moi, Allah vous aimera alors et vous pardonnera vos péchés. Allah est Pardonneur et Miséricordieux.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@cccxxv{Dis: «Obéissez à Allah et au Messager. Et si vous tournez le dos... alors Allah n'aime pas les infidèles!\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@cccxxvi{Certes, Allah a élu Adam, Noé, la famille d'Abraham et la famille d''Imran au-dessus de tout le monde.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@cccxxvii{En tant que descendants les uns des autres, et Allah est Audient et Omniscient.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@cccxxviii{(Rappelle-toi) quand la femme de 'Imran dit: «Seigneur, je T'ai voué en toute exclusivité ce qui est dans mon ventre. Accepte-le donc, de moi. C'est Toi certes l' Audient et l'Omniscient.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@cccxxix{Puis, lorsqu'elle en eut accouché, elle dit: «Seigneur, voilà que j'ai accouché d'une fille» or Allah savait mieux ce dont elle avait accouché! Le garçon n'est pas comme la fille. «Je l'ai nommée Marie, et je la place, ainsi que sa descendance, sous Ta protection contre le Diable, le banni».\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@cccxxx{Son Seigneur l'agréa alors du bon agrément, la fit croître en belle croissance. Et Il en confia la garde à Zacharie. Chaque fois que celui-ci entrait auprès d'elle dans le Sanctuaire, il trouvait près d'elle de la nourriture. Il dit: «O Marie, d'où te vient cette nourriture?» - Elle dit: «Cela me vient d'Allah». Il donne certes la nourriture à qui Il veut sans compter.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@cccxxxi{Alors, Zacharie pria son Seigneur, et dit: «O mon Seigneur, donne-moi, venant de Toi, une excellente descendance. Car Tu es Celui qui entend bien la prière».\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@cccxxxii{Alors, les Anges l'appelèrent pendant que, debout, il priait dans le Sanctuaire: «Voilà qu'Allah t'annonce la naissance de Yahya, confirmateur d'une parole d'Allah. Il sera un chef, un chaste, un prophète et du nombre des gens de bien».\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@cccxxxiii{Il dit: «O mon Seigneur, comment aurais-je un garçon maintenant que la vieillesse m'a atteint et que ma femme est stérile?» Allah dit: «Comme cela!», Allah fait ce qu'Il veut.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@cccxxxiv{- «Seigneur, dit Zacharie, donne-moi un signe.» - «Ton signe, dit Allah, c'est que pendant trois jours tu ne pourras parler aux gens que par geste. Invoque beaucoup Ton Seigneur; et, glorifie-Le, en fin et en début de journée.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@cccxxxv{(Rappelle-toi) quand les Anges dirent: «O Marie, certes Allah t'a élue et purifiée; et Il t'a élue au-dessus des femmes des mondes.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@cccxxxvi{«O Marie, obéis à Ton Seigneur, prosterne-toi, et incline-toi avec ceux qui s'inclinent».\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@cccxxxvii{- Ce sont là des nouvelles de l'Inconnaissable que Nous te révélons. Car tu n'étais pas là lorsqu'ils jetaient leurs calames pour décider qui se chargerait de Marie! Tu n'étais pas là non plus lorsqu'ils se disputaient!\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@cccxxxviii{(Rappelle-toi) quand les Anges dirent: «O Marie, voilà qu'Allah t'annonce une parole de Sa part: son nom sera «Al-Masîh», «'Issâ», fils de Marie, illustre ici-bas comme dans l'au-delà, et l'un des rapprochés d'Allah».\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@cccxxxix{Il parlera aux gens, dans le berceau et en son âge mûr et il sera du nombre des gens de bien».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@cccxl{- Elle dit: «Seigneur! Comment aurais-je un enfant, alors qu'aucun homme ne m'a touchée?» - «C'est ainsi!» dit-Il. Allah crée ce qu'Il veut. Quand Il décide d'une chose, Il lui dit seulement: «Sois» et elle est aussitôt.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@cccxli{Et (Allah) lui enseignera l'écriture, la sagesse, la Thora et l'Evangile,\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@cccxlii{et Il sera le messager aux enfants d'Israël, [et leur dira]: «En vérité, je viens à vous avec un signe de la part de votre Seigneur. Pour vous, je forme de la glaise comme la figure d'un oiseau, puis je souffle dedans: et, par la permission d'Allah, cela devient un oiseau. Et je guéris l'aveugle-né et le lépreux, et je ressuscite les morts, par la permission d'Allah. Et je vous apprends ce que vous mangez et ce que vous amassez dans vos maisons. Voilà bien là un signe, pour vous, si vous êtes croyants!\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@cccxliii{Et je confirme ce qu'il y a dans la Thora révélée avant moi, et je vous rends licite une partie de ce qui vous était interdit. Et j'ai certes apporté un signe de votre Seigneur. Craignez Allah donc, et obéissez-moi.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@cccxliv{Allah est mon Seigneur et votre Seigneur. Adorez-Le donc: voilà le chemin droit.»\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@cccxlv{Puis, quand Jésus ressentit de l'incrédulité, de leur part, il dit: «Qui sont mes alliés dans la voie d'Allah?» Les apôtres dirent: «Nous sommes les alliés d'Allah. Nous croyons en Allah. Et sois témoin que nous lui sommes soumis.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@cccxlvi{Seigneur! Nous avons cru à ce que Tu as fait descendre et suivi le messager. Inscris-nous donc parmi ceux qui témoignent».\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@cccxlvii{Et ils [les autres] se mirent à comploter. Allah a fait échouer leur complot. Et c'est Allah qui sait le mieux leur machination!\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@cccxlviii{(Rappelle-toi) quand Allah dit: «O Jésus, certes, Je vais mettre fin à ta vie terrestre t'élever vers Moi, te débarrasser de ceux qui n'ont pas cru et mettre jusqu'au Jour de la Résurrection, ceux qui te suivent au-dessus de ceux qui ne croient pas. Puis, c'est vers Moi que sera votre retour, et Je jugerai, entre vous, ce sur quoi vous vous opposiez.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@cccxlix{Quant à ceux qui n'ont pas cru, Je les châtierai d'un dur châtiment, ici-bas tout comme dans l'au-delà; et pour eux, pas de secoureurs.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@cccl{Et quant à ceux qui ont la foi et font de bonnes œuvres, Il leur donnera leurs récompenses. Et Allah n'aime pas les injustes.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@cccli{Voilà ce que Nous te récitons des versets et de la révélation précise.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@ccclii{Pour Allah, Jésus est comme Adam qu'Il créa de poussière, puis Il lui dit: «Sois»: et il fut.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@cccliii{La vérité vient de ton Seigneur. Ne sois donc pas du nombre des sceptiques.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@cccliv{A ceux qui te contredisent à son propos, maintenant que tu en es bien informé, tu n'as qu'à dire: «Venez, appelons nos fils et les vôtres, nos femmes et les vôtres, nos propres personnes et les vôtres, puis proférons exécration réciproque en appelant la malédiction d'Allah sur les menteurs.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@ccclv{Voilà, certes, le récit véridique. Et il n'y a pas de divinité à part Allah. En vérité, c'est Allah qui est le Puissant, le Sage.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@ccclvi{Si donc ils tournent le dos... alors Allah connaît bien les semeurs de corruption!\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@ccclvii{- Dis: «O gens du Livre, venez à une parole commune entre nous et vous: que nous n'adorions qu'Allah, sans rien Lui associer, et que nous ne prenions point les uns les autres pour seigneurs en dehors d'Allah». Puis, s'ils tournent le dos, dites: «Soyez témoins que nous, nous sommes soumis».\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@ccclviii{O gens du Livre, pourquoi disputez-vous au sujet d'Abraham, alors que la Thora et l'Evangile ne sont descendus qu'après lui? Ne raisonnez-vous donc pas?\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@ccclix{Vous avez bel et bien disputé à propos d'une chose dont vous avez connaissance. Mais pourquoi disputez-vous des choses dont vous n'avez pas connaissance? Or Allah sait, tandis que vous ne savez pas.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@ccclx{Abraham n'était ni Juif ni Chrétien. Il était entièrement soumis à Allah (Musulman). Et il n'était point du nombre des Associateurs.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@ccclxi{Certes les hommes les plus dignes de se réclamer d'Abraham, sont ceux qui l'ont suivi, ainsi que ce Prophète-ci, et ceux qui ont la foi. Et Allah est l'allié des croyants.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@ccclxii{Une partie des gens du Livre aurait bien voulu vous égarer. Or ils n'égarent qu'eux-mêmes; et ils n'en sont pas conscients.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@ccclxiii{O gens du Livre, pourquoi ne croyez vous pas aux versets d'Allah (le Coran), cependant que vous en êtes témoins?\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@ccclxiv{O gens du Livre, pourquoi mêlez-vous le faux au vrai et cachez-vous sciemment la vérité?\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@ccclxv{Ainsi dit une partie des gens du Livre: «Au début du jour, croyez à ce qui a été révélé aux Musulmans, mais, à la fin du jour, rejetez-le, afin qu'ils retournent (à leur ancienne religion).\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@ccclxvi{[Et les gens du Livre disent à leurs coreligionnaires]: «Ne croyez que ceux qui suivent votre religion...» Dis: «La vraie direction est la direction d'Allah» - [et ils disent encore: Vous ne devez ni approuver ni reconnaître] que quelqu'un d'autre que vous puisse recevoir comme ce que vous avez reçu de sorte qu'ils (les musulmans) ne puissent argumenter contre vous auprès de votre Seigneur. Dis-[leur]: En vérité, la grâce est en la main d'Allah. Il la donne à qui Il veut. La grâce d'Allah est immense et Il est Omniscient.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@ccclxvii{Il réserve à qui Il veut sa miséricorde. Et Allah est Détenteur d'une grâce immense.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@ccclxviii{Et parmi les gens du Livre, il y en a qui, si tu lui confies un qintâr, te le rend. Mais il y en a aussi qui, si tu lui confies un dinâr, ne te le rendra que si tu l'y contrains sans relâche. Tout cela parce qu'ils disent: «Ces (arabes) qui n'ont pas de livre n'ont aucun chemin pour nous contraindre.» Ils profèrent des mensonges contre Allah alors qu'ils savent.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@ccclxix{Au contraire, quiconque remplit sa promesse et craint Allah... Allah aime les pieux.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@ccclxx{Ceux qui vendent à vil prix leur engagement avec Allah ainsi que leurs serments n'auront aucune part dans l'au-delà, et Allah ne leur parlera pas, ni les regardera, au Jour de la Résurrection, ni ne les purifiera; et ils auront un châtiment douloureux.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@ccclxxi{Et il y a parmi eux certains qui roulent leurs langues en lisant le Livre pour vous faire croire que cela provient du Livre, alors qu'il n'est point du Livre; et ils disent: «Ceci vient d'Allah, alors qu'il ne vient point d'Allah. Ils disent sciemment des mensonges contre Allah.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@ccclxxii{Il ne conviendrait pas à un être humain à qui Allah a donné le Livre, la Compréhension et la Prophétie, de dire ensuite aux gens: «Soyez mes adorateurs, à l'exclusion d'Allah; mais au contraire, [il devra dire]: «Devenez des savants, obéissant au Seigneur, puisque vous enseignez le Livre et vous l'étudiez».\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@ccclxxiii{Et il ne va pas vous commander de prendre pour seigneurs anges et prophètes. Vous commanderait-il de rejeter la foi, vous qui êtes Musulmans?\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@ccclxxiv{Et lorsqu'Allah prit cet engagement des prophètes: «Chaque fois que Je vous accorderai un Livre et de la Sagesse, et qu'ensuite un messager vous viendra confirmer ce qui est avec vous, vous devez croire en lui, et vous devrez lui porter secours.» Il leur dit: «Consentez-vous et acceptez-vous Mon pacte à cette condition?» - «Nous consentons», dirent-ils. «Soyez-en donc témoins, dit Allah. Et Me voici, avec vous, parmi les témoins.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@ccclxxv{Quiconque ensuite tournera le dos... alors ce sont eux qui seront les pervers».\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@ccclxxvi{Désirent-ils une autre religion que celle d'Allah, alors que se soumet à Lui, bon gré, mal gré, tout ce qui existe dans les cieux et sur la terre, et que c'est vers Lui qu'ils seront ramenés?\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@ccclxxvii{Dis: «Nous croyons en Allah, à ce qu'on a fait descendre sur nous, à ce qu'on a fait descendre sur Abraham, Ismaël, Isaac, Jacob et les Tribus, et à ce qui a été apporté à Moïse, à Jésus et aux prophètes, de la part de leur Seigneur: nous ne faisons aucune différence entre eux; et c'est à Lui que nous sommes Soumis».\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@ccclxxviii{Et quiconque désire une religion autre que l'Islam, ne sera point agréé, et il sera, dans l'au-delà, parmi les perdants.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@ccclxxix{Comment Allah guiderait-Il des gens qui n'ont plus la foi après avoir cru et témoigné que le Messager est véridique, et après que les preuves leur sont venues? Allah ne guide pas les gens injustes.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@ccclxxx{Ceux là, leur rétribution sera qu'ils auront sur eux la malédiction d'Allah, des Anges et de tous les êtres humains.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@ccclxxxi{Ils y demeureront éternellement. Le châtiment ne leur sera pas allégé, et ils n'auront aucun répit,\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@ccclxxxii{excepté ceux qui par la suite se repentiront et se réformeront: car Allah est certes Pardonneur et Miséricordieux.\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@ccclxxxiii{En vérité, ceux qui ne croient plus après avoir eu la foi, et laissent augmenter encore leur mécréance, leur repentir ne sera jamais accepté. Ceux-là sont vraiment les égarés.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@ccclxxxiv{Ceux qui ne croient pas et qui meurent mécréants, il ne sera jamais accepté, d'aucun d'eux de se racheter même si pour cela il (donnait) le contenu, en or, de la terre. Ils auront un châtiment douloureux, et ils n'auront point de secoureurs.\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@ccclxxxv{Vous n'atteindrez la (vraie) piété, que si vous faites largesses de ce que vous chérissez. Tout ce dont vous faites largesses, Allah le sait certainement bien.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@ccclxxxvi{Toute nourriture était licite aux enfants d'Israël, sauf celle qu'Israël lui-même s'interdit avant que ne descendît la Thora. Dis-[leur]: «Apportez la Thora et lisez-la, si ce que vous dites est vrai!»\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@ccclxxxvii{Donc, quiconque, après cela, invente des mensonges contre Allah... ceux-là sont, donc, les vrais injustes.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@ccclxxxviii{Dis: «C'est Allah qui dit la vérité. Suivez donc la religion d'Abraham, Musulman droit. Et il n'était point des associateurs».\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@ccclxxxix{La première Maison qui ait été édifiée pour les gens, c'est bien celle de Bakka (la Mecque) bénie et une bonne direction pour l'univers.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@cccxc{Là sont des signes évidents, parmi lesquels l'endroit où Abraham s'est tenu debout; et quiconque y entre est en sécurité. Et c'est un devoir envers Allah pour les gens qui ont les moyens, d'aller faire le pèlerinage de la Maison. Et quiconque ne croit pas... Allah Se passe largement des mondes.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@cccxci{- Dis: «O gens du Livre, pourquoi ne croyez-vous pas aux versets d'Allah (al-Qur'ân), alors qu'Allah est témoin de ce que vous faites?»\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@cccxcii{- Dis: «O gens du Livre, pourquoi obstruez-vous la voie d'Allah à celui qui a la foi, et pourquoi voulez-vous rendre cette voie tortueuse, alors que vous êtes témoins de la vérité!» Et Allah n'est pas inattentif à ce que vous faites.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@cccxciii{O les croyants! Si vous obéissez à un groupe de ceux auxquels on a donné le Livre, il vous rendra mécréants après que vous ayez eu la foi.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@cccxciv{Et comment pouvez-vous ne pas croire, alors que les versets d'Allah vous sont récités, et qu'au milieu de vous se tient Son messager? Quiconque s'attache fortement à Allah, il est certes guidé vers un droit chemin.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@cccxcv{O les croyants! Craignez Allah comme Il doit être craint. Et ne mourez qu'en pleine soumission.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@cccxcvi{Et cramponnez-vous tous ensemble au «Habl» (câble) d'Allah et ne soyez pas divisés; et rappelez-vous le bienfait d'Allah sur vous: lorsque vous étiez ennemis, c'est Lui qui réconcilia vos cœurs. Puis, par Son bienfait, vous êtes devenus frères. Et alors que vous étiez au bord d'un abîme de Feu, c'est Lui qui vous en a sauvés. Ainsi Allah vous montre Ses signes afin que vous soyez bien guidés.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@cccxcvii{Que soit issue de vous une communauté qui appelle au bien, ordonne le convenable, et interdit le blâmable. Car ce seront eux qui réussiront.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@cccxcviii{Et ne soyez pas comme ceux qui se sont divisés et se sont mis à disputer, après que les preuves leur furent venues, et ceux-là auront un énorme châtiment.\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@cccxcix{Au jour où certains visages s'éclaireront, et que d'autres s'assombriront. A ceux dont les visages seront assombris (il sera dit): «avez-vous mécru après avoir eu la foi?» Eh bien, goûtez au châtiment, pour avoir renié la foi.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@cd{Et quant à ceux dont les visages s'éclaireront, ils seront dans la miséricorde d'Allah, où ils demeureront éternellement.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@cdi{Tels sont les versets d'Allah; Nous te (Muhammad) les récitons avec vérité. Et Allah ne veut point léser les mondes.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@cdii{A Allah appartient tout ce qui est dans les cieux et sur la terre. Et c'est vers Allah que toute chose sera ramenée.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@cdiii{Vous êtes la meilleure communauté, qu'on ait fait surgir pour les hommes. Vous ordonnez le convenable, interdisez le blâmable et croyez à Allah. Si les gens du Livre croyaient, ce serait meilleur pour eux, il y en a qui ont la foi, mais la plupart d'entre eux sont des pervers.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@cdiv{Ils ne sauront jamais vous causer de grand mal, seulement une nuisance (par la langue); et s'ils vous combattent, ils vous tourneront le dos, et ils n'auront alors point de secours.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@cdv{Où qu'ils se trouvent, ils sont frappés d'avilissement, à moins d'un secours providentiel d'Allah ou d'un pacte conclu avec les hommes. Ils ont encouru la colère d'Allah, et les voilà frappés de malheur, pour n'avoir pas cru aux signes d'Allah, et assassiné injustement les prophètes, et aussi pour avoir désobéi et transgressé.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@cdvi{Mais ils ne sont pas tous pareils. Il est, parmi les gens du Livre, une communauté droite qui, aux heures de la nuit, récite les versets d'Allah en se prosternant.\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@cdvii{Ils croient en Allah et au Jour dernier, ordonnent le convenable, interdisent le blâmable et concourent aux bonnes œuvres. Ceux-là sont parmi les gens de bien.\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@cdviii{Et quelque bien qu'ils fassent, il ne leur sera pas dénié. Car Allah connaît bien les pieux.\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@cdix{Quant à ceux qui ne croient pas, ni leurs biens, ni leurs enfants ne pourront jamais leur servir contre la punition d'Allah. Et ce sont les gens du Feu: ils y demeureront éternellement.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@cdx{Ce qu'ils dépensent dans la vie présente ressemble à un vent glacial qui s'abat sur un champ appartenant à des gens qui se sont lésés eux-mêmes, et le détruit. Car ce n'est pas Allah qui leur cause du mal, mais ils se font du mal à eux-mêmes.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@cdxi{O les croyants, ne prenez pas de confidents en dehors de vous-mêmes: ils ne failliront pas à vous bouleverser. Ils souhaiteraient que vous soyez en difficulté. La haine certes s'est manifestée dans leurs bouches, mais ce que leurs poitrines cachent est encore plus énorme. Voilà que Nous vous exposons les signes. Si vous pouviez raisonner!\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@cdxii{Vous, (Musulmans) vous les aimez, alors qu'ils ne vous aiment pas; et vous avez foi dans le Livre tout entier. Et lorsqu'ils vous rencontrent, ils disent: «Nous croyons» et une fois seuls, de rage contre vous, ils se mordent les bouts des doigts. Dis: «mourez de votre rage». En vérité, Allah connaît fort bien le contenu des cœurs.\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@cdxiii{Qu'un bien vous touche, ils s'en affligent. Qu'un mal vous atteigne, ils s'en réjouissent. Mais si vous êtes endurants et pieux, leur manigance ne vous causera aucun mal. Allah connaît parfaitement tout ce qu'ils font.\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@cdxiv{Lorsqu'un matin, tu (Muhammad) quittas ta famille, pour assigner aux croyants les postes de combat et Allah est Audient et Omniscient.\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@cdxv{Quand deux de vos groupes songèrent à fléchir! Alors qu'Allah est leur allié à tous deux! Car, c'est en Allah que les croyants doivent placer leur confiance.\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@cdxvi{Allah vous a donné la victoire, à Badr, alors que vous étiez humiliés. Craignez Allah donc. Afin que vous soyez reconnaissants!\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@cdxvii{(Allah vous a bien donné la victoire) lorsque tu disais aux croyants; «Ne vous suffit-il pas que votre Seigneur vous fasse descendre en aide trois milliers d'Anges?»\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@cdxviii{Mais oui! Si vous êtes endurants et pieux, et qu'ils [les ennemis] vous assaillent immédiatement, votre Seigneur vous enverra en renfort cinq mille Anges marqués distinctement.\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@cdxix{Et Allah ne le fit que (pour vous annoncer) une bonne nouvelle, et pour que vos cœurs s'en rassurent. La victoire ne peut venir que d'Allah, le Puissant, le Sage;\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@cdxx{pour anéantir une partie des mécréants ou pour les humilier (par la défaite) et qu'ils en retournent donc déçus.\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@cdxxi{- Tu n'as (Muhammad) aucune part dans l'ordre (divin) - qu'Il (Allah) accepte leur repentir (en embrassant l'Islam) ou qu'Il les châtie, car ils sont bien des injustes.\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@cdxxii{A Allah appartient tout ce qui est dans les cieux et sur la terre. Il pardonne à qui Il veut, et Il châtie qui Il veut... Et Allah est Pardonneur et Miséricordieux.\qt@no{(129)}}
\qt@newcmd\qurantrans@fr@cdxxiii{O les croyants! Ne pratiquez pas l'usure en multipliant démesurément votre capital. Et craignez Allah afin que vous réussissiez!\qt@no{(130)}}
\qt@newcmd\qurantrans@fr@cdxxiv{Et craignez le Feu préparé pour les mécréants.\qt@no{(131)}}
\qt@newcmd\qurantrans@fr@cdxxv{Et obéissez à Allah et au Messager afin qu'il vous soit fait miséricorde!\qt@no{(132)}}
\qt@newcmd\qurantrans@fr@cdxxvi{Et concourez au pardon de votre Seigneur, et à un Jardin (paradis) large comme les cieux et la terre, préparé pour les pieux,\qt@no{(133)}}
\qt@newcmd\qurantrans@fr@cdxxvii{qui dépensent dans l'aisance et dans l'adversité, qui dominent leur rage et pardonnent à autrui - car Allah aime les bienfaisants -\qt@no{(134)}}
\qt@newcmd\qurantrans@fr@cdxxviii{et pour ceux qui, s'ils ont commis quelque turpitude ou causé quelque préjudice à leurs propres âmes (en désobéissant à Allah), se souviennent d'Allah et demandent pardon pour leurs péchés - et qui est-ce qui pardonne les péchés sinon Allah? - et qui ne persistent pas sciemment dans le mal qu'ils ont fait.\qt@no{(135)}}
\qt@newcmd\qurantrans@fr@cdxxix{Ceux-là ont pour récompense le pardon de leur Seigneur, ainsi que les Jardins sous lesquels coulent les ruisseaux, pour y demeurer éternellement. Comme est beau le salaire de ceux qui font le bien!\qt@no{(136)}}
\qt@newcmd\qurantrans@fr@cdxxx{Avant vous, certes, beaucoup d'événements se sont passés. Or, parcourez la terre, et voyez ce qu'il est advenu de ceux qui traitaient (les prophètes) de menteurs.\qt@no{(137)}}
\qt@newcmd\qurantrans@fr@cdxxxi{Voilà un exposé pour les gens, un guide, et une exhortation pour les pieux.\qt@no{(138)}}
\qt@newcmd\qurantrans@fr@cdxxxii{Ne vous laissez pas battre, ne vous affligez pas alors que vous êtes les supérieurs, si vous êtes de vrais croyants.\qt@no{(139)}}
\qt@newcmd\qurantrans@fr@cdxxxiii{Si une blessure vous atteint, pareille blessure atteint aussi l'ennemi. Ainsi faisons-Nous alterner les jours (bons et mauvais) parmi les gens, afin qu'Allah reconnaisse ceux qui ont cru, et qu'Il choisisse parmi vous des martyrs - et Allah n'aime pas les injustes,\qt@no{(140)}}
\qt@newcmd\qurantrans@fr@cdxxxiv{et afin qu'Allah purifie ceux qui ont cru, et anéantisse les mécréants.\qt@no{(141)}}
\qt@newcmd\qurantrans@fr@cdxxxv{Comptez-vous entrer au Paradis sans qu'Allah ne distingue parmi vous ceux qui luttent et qui sont endurants?\qt@no{(142)}}
\qt@newcmd\qurantrans@fr@cdxxxvi{Bien sûr, vous souhaitiez la mort avant de la rencontrer. Or vous l'avez vue, certes, tandis que vous regardiez!\qt@no{(143)}}
\qt@newcmd\qurantrans@fr@cdxxxvii{Muhammad n'est qu'un messager - des messagers avant lui sont passés -. S'il mourait, donc, ou s'il était tué, retourneriez-vous sur vos talons? Quiconque retourne sur ses talons ne nuira en rien à Allah; et Allah récompensera bientôt les reconnaissants.\qt@no{(144)}}
\qt@newcmd\qurantrans@fr@cdxxxviii{Personne ne peut mourir que par la permission d'Allah, et au moment prédéterminé. Quiconque veut la récompense d'ici-bas, Nous lui en donnons. Quiconque veut la récompense de l'au-delà, Nous lui en donnons, et Nous récompenserons bientôt les reconnaissants.\qt@no{(145)}}
\qt@newcmd\qurantrans@fr@cdxxxix{Combien de prophètes ont combattu, en compagnie de beaucoup de disciples, ceux-ci ne fléchirent pas à cause de ce qui les atteignit dans le sentier d'Allah. Ils ne faiblirent pas et ils ne cédèrent point. Et Allah aime les endurants.\qt@no{(146)}}
\qt@newcmd\qurantrans@fr@cdxl{Et ils n'eurent que cette parole: «Seigneur, pardonne-nous nos péchés ainsi que nos excès dans nos comportements, affermis nos pas et donne-nous la victoire sur les gens mécréants».\qt@no{(147)}}
\qt@newcmd\qurantrans@fr@cdxli{Allah, donc, leur donna la récompense d'ici-bas, ainsi que la belle récompense de l'au-delà. Et Allah aime les gens bienfaisants.\qt@no{(148)}}
\qt@newcmd\qurantrans@fr@cdxlii{O les croyants! Si vous obéissez à ceux qui ne croient pas, ils vous feront retourner en arrière. Et vous reviendrez perdants.\qt@no{(149)}}
\qt@newcmd\qurantrans@fr@cdxliii{Mais c'est Allah votre Maître. Il est le meilleur des secoureurs.\qt@no{(150)}}
\qt@newcmd\qurantrans@fr@cdxliv{Nous allons jeter l'effroi dans les cœurs des mécréants. Car ils ont associé à Allah (des idoles) sans aucune preuve descendue de Sa part. Le Feu sera leur refuge. Quel mauvais séjour, que celui des injustes!\qt@no{(151)}}
\qt@newcmd\qurantrans@fr@cdxlv{Et certes, Allah a tenu Sa promesse envers vous, quand par Sa permission vous les tuiez sans relâche, jusqu'au moment où vous avez fléchi, où vous vous êtes disputés à propos de l'ordre donné, et vous avez désobéi après qu'Il vous eut montré (la victoire) que vous aimez! Il en était parmi vous qui désiraient la vie d'ici-bas et il en était parmi vous qui désiraient l'au-delà. Puis Il vous a fait reculer devant eux, afin de vous éprouver. Et certes Il vous a pardonné. Et Allah est Détenteur de la grâce envers les croyants.\qt@no{(152)}}
\qt@newcmd\qurantrans@fr@cdxlvi{(Rappelez-vous) quand vous fuyiez sans vous retourner vers personne, cependant que, derrière vous, le Messager vous appelait. Alors Il vous infligea angoisse sur angoisse, afin que vous n'ayez pas de chagrin pour ce qui vous a échappé ni pour les revers que vous avez subis. Et Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(153)}}
\qt@newcmd\qurantrans@fr@cdxlvii{Puis Il fit descendre sur vous, après l'angoisse, la tranquillité, un sommeil qui enveloppa une partie d'entre vous, tandis qu'une autre partie était soucieuse pour elle-même et avait des pensées sur Allah non conformes à la vérité, des pensées dignes de l'époque de l'Ignorance. - Ils disaient: «Est-ce que nous avons une part dans cette affaire?» Dis: «L'affaire toute entière est à Allah.» Ce qu'ils ne te révèlent pas, ils le cachent en eux-mêmes: «Si nous avions eu un choix quelconque dans cette affaire, disent-ils, Nous n'aurions pas été tués ici.» Dis: «Eussiez-vous été dans vos maisons, ceux pour qui la mort était décrétée seraient sortis pour l'endroit où la mort les attendait. Ceci afin qu'Allah éprouve ce que vous avez dans vos poitrines, et qu'Il purifie ce que vous avez dans vos cœurs. Et Allah connaît ce qu'il y a dans les cœurs.\qt@no{(154)}}
\qt@newcmd\qurantrans@fr@cdxlviii{Ceux d'entre vous qui ont tourné le dos, le jour où les deux armées se rencontrèrent, c'est seulement le Diable qui les a fait broncher, à cause d'une partie de leurs (mauvaises) actions. Mais, certes, Allah leur a pardonné. Car vraiment Allah est Pardonneur et Indulgent!\qt@no{(155)}}
\qt@newcmd\qurantrans@fr@cdxlix{O les croyants! Ne soyez pas comme ces mécréants qui dirent à propos de leurs frères partis en voyage ou pour combattre: «S'ils étaient chez nous, ils ne seraient pas morts, et ils n'auraient pas été tués.» Allah en fit un sujet de regret dans leurs cœurs. C'est Allah qui donne la vie et la mort. Et Allah observe bien ce que vous faites.\qt@no{(156)}}
\qt@newcmd\qurantrans@fr@cdl{Et si vous êtes tués dans le sentier d'Allah ou si vous mourez, un pardon de la part d'Allah et une miséricorde valent mieux que ce qu'ils amassent.\qt@no{(157)}}
\qt@newcmd\qurantrans@fr@cdli{Que vous mouriez ou que vous soyez tués, c'est vers Allah que vous serez rassemblés.\qt@no{(158)}}
\qt@newcmd\qurantrans@fr@cdlii{C'est par quelque miséricorde de la part d'Allah que tu (Muhammad) as été si doux envers eux! Mais si tu étais rude, au cœur dur, ils se seraient enfuis de ton entourage. Pardonne-leur donc, et implore pour eux le pardon (d'Allah). Et consulte-les à propos des affaires; puis une fois que tu t'es décidé, confie-toi donc à Allah, Allah aime, en vérité, ceux qui Lui font confiance.\qt@no{(159)}}
\qt@newcmd\qurantrans@fr@cdliii{Si Allah vous donne Son secours, nul ne peut vous vaincre. S'Il vous abandonne, qui donc après Lui vous donnera secours? C'est à Allah que les croyants doivent faire confiance.\qt@no{(160)}}
\qt@newcmd\qurantrans@fr@cdliv{Un prophète n'est pas quelqu'un à s'approprier du butin. Quiconque s'en approprie, viendra avec ce qu'il se sera approprié le Jour de la Résurrection. Alors, à chaque individu on rétribuera pleinement ce qu'il aura acquis. Et ils ne seront point lésés.\qt@no{(161)}}
\qt@newcmd\qurantrans@fr@cdlv{Est-ce que celui qui se conforme à l'agrément d'Allah ressemble à celui qui encourt le courroux d'Allah? Son refuge sera l'Enfer; et quelle mauvaise destination!\qt@no{(162)}}
\qt@newcmd\qurantrans@fr@cdlvi{Ils ont des grades (différents) auprès d'Allah et Allah observe bien ce qu'ils font.\qt@no{(163)}}
\qt@newcmd\qurantrans@fr@cdlvii{Allah a très certainement fait une faveur aux croyants lorsqu'Il a envoyé chez eux un messager de parmi eux-mêmes, qui leur récite Ses versets, les purifie et leur enseigne le Livre et la Sagesse, bien qu'ils fussent auparavant dans un égarement évident.\qt@no{(164)}}
\qt@newcmd\qurantrans@fr@cdlviii{Quoi! Quand un malheur vous atteint - mais vous en avez jadis infligé le double - vous dites: «D'où vient cela?» Réponds-leur: «Il vient de vous-mêmes». Certes Allah est Omnipotent.\qt@no{(165)}}
\qt@newcmd\qurantrans@fr@cdlix{Et tout ce que vous avez subi, le jour où les deux troupes se rencontrèrent, c'est par permission d'Allah, et afin qu'Il distingue les croyants,\qt@no{(166)}}
\qt@newcmd\qurantrans@fr@cdlx{et qu'Il distingue les hypocrites. On avait dit à ceux-ci: «Venez combattre dans le sentier d'Allah, ou repoussez [l'ennemi»], ils dirent: «Bien sûr que nous vous suivrions si nous étions sûrs qu'il y aurait une guerre.» Ils étaient, ce jour-là, plus près de la mécréance que de la foi. Ils disaient de leurs bouches ce qui n'était pas dans leurs cœurs. Et Allah sait fort bien ce qu'ils cachaient.\qt@no{(167)}}
\qt@newcmd\qurantrans@fr@cdlxi{Ceux qui sont restés dans leurs foyers dirent à leurs frères: «S'ils nous avaient obéi, ils n'auraient pas été tués.» Dis: «Ecartez donc de vous la mort, si vous êtes véridiques».\qt@no{(168)}}
\qt@newcmd\qurantrans@fr@cdlxii{Ne pense pas que ceux qui ont été tués dans le sentier d'Allah, soient morts. Au contraire, ils sont vivants, auprès de leur Seigneur, bien pourvus\qt@no{(169)}}
\qt@newcmd\qurantrans@fr@cdlxiii{et joyeux de la faveur qu'Allah leur a accordée, et ravis que ceux qui sont restés derrière eux et ne les ont pas encore rejoints, ne connaîtront aucune crainte et ne seront point affligés.\qt@no{(170)}}
\qt@newcmd\qurantrans@fr@cdlxiv{Ils sont ravis d'un bienfait d'Allah et d'une faveur, et du fait qu'Allah ne laisse pas perdre la récompense des croyants.\qt@no{(171)}}
\qt@newcmd\qurantrans@fr@cdlxv{Ceux qui, quoiqu'atteints de blessure, répondirent à l'appel d'Allah et du Messager, il y aura une énorme récompense pour ceux d'entre eux qui ont agi en bien et pratiqué la piété.\qt@no{(172)}}
\qt@newcmd\qurantrans@fr@cdlxvi{Certes ceux auxquels l'on disait: «Les gens se sont rassemblés contre vous; craignez-les» - cela accrut leur foi - et ils dirent: «Allah nous suffit; Il est notre meilleur garant».\qt@no{(173)}}
\qt@newcmd\qurantrans@fr@cdlxvii{Ils revinrent donc avec un bienfait de la part d'Allah et une grâce. Nul mal ne les toucha et ils suivirent ce qui satisfait Allah. Et Allah est Détenteur d'une grâce immense.\qt@no{(174)}}
\qt@newcmd\qurantrans@fr@cdlxviii{C'est le Diable qui vous fait peur de ses adhérents. N'ayez donc pas peur d'eux. Mais ayez peur de Moi, si vous êtes croyants.\qt@no{(175)}}
\qt@newcmd\qurantrans@fr@cdlxix{N'aie (ô Muhammad) aucun chagrin pour ceux qui se jettent rapidement dans la mécréance. En vérité, ils ne nuiront en rien à Allah. Allah tient à ne leur assigner aucune part de biens dans l'au-delà. Et pour eux il y aura un énorme châtiment.\qt@no{(176)}}
\qt@newcmd\qurantrans@fr@cdlxx{Ceux qui auront troqué la croyance contre la mécréance ne nuiront en rien à Allah. Et pour eux un châtiment douloureux.\qt@no{(177)}}
\qt@newcmd\qurantrans@fr@cdlxxi{Que ceux qui n'ont pas cru ne comptent pas que ce délai que Nous leur accordons soit à leur avantage. Si Nous leur accordons un délai, c'est seulement pour qu'ils augmentent leurs péchés. Et pour eux un châtiment avilissant.\qt@no{(178)}}
\qt@newcmd\qurantrans@fr@cdlxxii{Allah n'est point tel qu'Il laisse les croyants dans l'état où vous êtes jusqu'à ce qu'Il distingue le mauvais du bon. Et Allah n'est point tel qu'Il vous dévoile l'Inconnaissable. Mais Allah choisit parmi Ses messagers qui Il veut. Croyez donc en Allah et en Ses messagers. Et si vous avez la foi et la piété, vous aurez alors une récompense énorme.\qt@no{(179)}}
\qt@newcmd\qurantrans@fr@cdlxxiii{Que ceux qui gardent avec avarice ce qu'Allah leur donne par Sa grâce, ne comptent point cela comme bon pour eux. Au contraire, c'est mauvais pour eux: au Jour de la Résurrection, on leur attachera autour du cou ce qu'ils ont gardé avec avarice. C'est Allah qui a l'héritage des cieux et de la terre. Et Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(180)}}
\qt@newcmd\qurantrans@fr@cdlxxiv{Allah a certainement entendu la parole de ceux qui ont dit: «Allah est pauvre et nous sommes riches.» Nous enregistrons leur parole, ainsi que leur meurtre, sans droit, des prophètes. Et Nous leur dirons: «Goûtez au châtiment de la fournaise.\qt@no{(181)}}
\qt@newcmd\qurantrans@fr@cdlxxv{Cela, à cause de ce que vos mains ont accompli (antérieurement)!» Car Allah ne fait point de tort aux serviteurs.\qt@no{(182)}}
\qt@newcmd\qurantrans@fr@cdlxxvi{Ceux-là mêmes qui ont dit: «Vraiment Allah nous a enjoint de ne pas croire en un messager tant qu'Il ne nous a pas apporté une offrande que le feu consume». - Dis: «Des messagers avant moi vous sont, certes, venus avec des preuves, et avec ce que vous avez dit [demandé]. Pourquoi donc les avez-vous tués, si vous êtes véridiques?»\qt@no{(183)}}
\qt@newcmd\qurantrans@fr@cdlxxvii{S'ils te (Muhammad) traitent de menteur, des prophètes avant toi, ont certes été traités de menteurs. Ils étaient venus avec les preuves claires, les Psaumes et le Livre lumineux.\qt@no{(184)}}
\qt@newcmd\qurantrans@fr@cdlxxviii{Toute âme goûtera la mort. Mais c'est seulement au Jour de la Résurrection que vous recevrez votre entière rétribution. Quiconque donc est écarté du Feu et introduit au Paradis, a certes réussi. Et la vie présente n'est qu'un objet de jouissance trompeuse.\qt@no{(185)}}
\qt@newcmd\qurantrans@fr@cdlxxix{Certes vous serez éprouvés dans vos biens et vos personnes; et certes vous entendrez de la part de ceux à qui le Livre a été donné avant vous, et de la part des Associateurs, beaucoup de propos désagréables. Mais si vous êtes endurants et pieux... voilà bien la meilleure résolution à prendre.\qt@no{(186)}}
\qt@newcmd\qurantrans@fr@cdlxxx{Allah prit, de ceux auxquels le Livre était donné, cet engagement: «Exposez-le, certes, aux gens et ne le cachez pas». Mais ils l'ont jeté derrière leur dos et l'ont vendu à vil prix. Quel mauvais commerce ils ont fait!\qt@no{(187)}}
\qt@newcmd\qurantrans@fr@cdlxxxi{Ne pense point que ceux-là qui exultent de ce qu'ils ont fait, et qui aiment qu'on les loue pour ce qu'ils n'ont pas fait, ne pense point donc, qu'ils trouvent une échappatoire au châtiment. Pour eux, il y aura un châtiment douloureux!\qt@no{(188)}}
\qt@newcmd\qurantrans@fr@cdlxxxii{A Allah appartient le royaume des cieux et de la terre. Et Allah est Omnipotent.\qt@no{(189)}}
\qt@newcmd\qurantrans@fr@cdlxxxiii{En vérité, dans la création des cieux et de la terre, et dans l'alternance de la nuit et du jour, il y a certes des signes pour les doués d'intelligence,\qt@no{(190)}}
\qt@newcmd\qurantrans@fr@cdlxxxiv{qui, debout, assis, couchés sur leurs côtés, invoquent Allah et méditent sur la création des cieux et de la terre (disant): «Notre Seigneur! Tu n'as pas créé cela en vain. Gloire à Toi! Garde-nous du châtiment du Feu.\qt@no{(191)}}
\qt@newcmd\qurantrans@fr@cdlxxxv{Seigneur! Quiconque Tu fais entrer dans le Feu, Tu le couvres vraiment d'ignominie. Et pour les injustes, il n'y a pas de secoureurs!\qt@no{(192)}}
\qt@newcmd\qurantrans@fr@cdlxxxvi{Seigneur! Nous avons entendu l'appel de celui qui a appelé ainsi à la foi: «Croyez en votre Seigneur» et dès lors nous avons cru. Seigneur, pardonne-nous nos péchés, efface de nous nos méfaits, et place nous, à notre mort, avec les gens de bien.\qt@no{(193)}}
\qt@newcmd\qurantrans@fr@cdlxxxvii{Seigneur! Donne-nous ce que Tu nous as promis par Tes messagers. Et ne nous couvre pas d'ignominie au Jour de la Résurrection. Car Toi, Tu ne manques pas à Ta promesse».\qt@no{(194)}}
\qt@newcmd\qurantrans@fr@cdlxxxviii{Leur Seigneur les a alors exaucés (disant): «En vérité, Je ne laisse pas perdre le bien que quiconque parmi vous a fait, homme ou femme, car vous êtes les uns des autres. Ceux donc qui ont émigré, qui ont été expulsés de leurs demeures, qui ont été persécutés dans Mon chemin, qui ont combattu, qui ont été tués, Je tiendrai certes pour expiées leurs mauvaises actions, et les ferai entrer dans les Jardins sous lesquels coulent les ruisseaux, comme récompense de la part d'Allah.» Quant à Allah, c'est auprès de Lui qu'est la plus belle récompense.\qt@no{(195)}}
\qt@newcmd\qurantrans@fr@cdlxxxix{Que ne t'abuse point la versatilité [pour la prospérité] dans le pays, de ceux qui sont infidèles.\qt@no{(196)}}
\qt@newcmd\qurantrans@fr@cdxc{Piètre jouissance! Puis leur refuge sera l'Enfer. Et quelle détestable couche!\qt@no{(197)}}
\qt@newcmd\qurantrans@fr@cdxci{Mais quant à ceux qui craignent leur Seigneur, ils auront des Jardins sous lesquels coulent les ruisseaux, pour y demeurer éternellement, un lieu d'accueil de la part d'Allah. Et ce qu'il y a auprès d'Allah est meilleur, pour les pieux.\qt@no{(198)}}
\qt@newcmd\qurantrans@fr@cdxcii{Il y a certes, parmi les gens du Livre ceux qui croient en Allah et en ce qu'on a fait descendre vers vous et en ce qu'on a fait descendre vers eux. Ils sont humbles envers Allah, et ne vendent point les versets d'Allah à vil prix. Voilà ceux dont la récompense est auprès de leur Seigneur. En vérité, Allah est prompt à faire les comptes.\qt@no{(199)}}
\qt@newcmd\qurantrans@fr@cdxciii{O les croyants! Soyez endurants. Incitez-vous à l'endurance. Luttez constamment (contre l'ennemi) et craignez Allah, afin que vous réussissiez!\qt@no{(200)}}
\qt@newcmd\qurantrans@fr@cdxciv{\basmalahfr O hommes! Craignez votre Seigneur qui vous a créés d'un seul être, et a créé de celui-ci son épouse, et qui de ces deux là a fait répandre (sur la terre) beaucoup d'hommes et de femmes. Craignez Allah au nom duquel vous vous implorez les uns les autres, et craignez de rompre les liens du sang. Certes Allah vous observe parfaitement.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@cdxcv{Et donnez aux orphelins leurs biens; n'y substituez pas le mauvais au bon. Ne mangez pas leurs biens avec les vôtres: c'est vraiment un grand péché.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@cdxcvi{Et si vous craignez de n'être pas justes envers les orphelins,... Il est permis d'épouser deux, trois ou quatre, parmi les femmes qui vous plaisent, mais, si vous craignez de n'être pas justes avec celles-ci, alors une seule, ou des esclaves que vous possédez. Cela, afin de ne pas faire d'injustice (ou afin de ne pas aggraver votre charge de famille).\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@cdxcvii{Et donnez aux épouses leur mahr, de bonne grâce. Si de bon gré, elles vous en abandonnent quelque chose, disposez-en alors à votre aise et de bon cœur.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@cdxcviii{Et ne confiez pas aux incapables vos biens dont Allah a fait votre subsistance. Mais prélevez-en, pour eux, nourriture et vêtement; et parlez-leur convenablement.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@cdxcix{Et éprouvez (la capacité) des orphelins jusqu'à ce qu'ils atteignent (l'aptitude) au mariage; et si vous ressentez en eux une bonne conduite, remettez-leur leurs biens. Ne les utilisez pas (dans votre intérêt) avec gaspillage et dissipation, avant qu'ils ne grandissent. Quiconque est aisé, qu'il s'abstienne d'en prendre lui-même. S'il est pauvre, alors qu'il en utilise raisonnablement: et lorsque vous leur remettez leurs biens, prenez des témoins à leur encontre. Mais Allah suffit pour observer et compter.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@d{Aux hommes revient une part de ce qu'ont laissé les père et mère ainsi que les proches; et aux femmes une part de ce qu'ont laissé les père et mère ainsi que les proches, que ce soit peu ou beaucoup: une part fixée.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@di{Et lorsque les proches parents, les orphelins, les nécessiteux assistent au partage, offrez-leur quelque chose de l'héritage, et parlez-leur convenablement.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@dii{Que la crainte saisisse ceux qui laisseraient après eux une descendance faible, et qui seraient inquiets à leur sujet; qu'ils redoutent donc Allah et qu'ils prononcent des paroles justes.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@diii{Ceux qui mangent [disposent] injustement des biens des orphelins ne font que manger du feu dans leurs ventres. Ils brûleront bientôt dans les flammes de l'Enfer.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@div{Voici ce qu'Allah vous enjoint au sujet de vos enfants: au fils, une part équivalente à celle de deux filles. S'il n'y a que des filles, même plus de deux, à elles alors deux tiers de ce que le défunt laisse. Et s'il n'y en a qu'une, à elle alors la moitié. Quant aux père et mère du défunt, à chacun d'eux le sixième de ce qu'il laisse, s'il a un enfant. S'il n'a pas d'enfant et que ses père et mère héritent de lui, à sa mère alors le tiers. Mais s'il a des frères, à la mère alors le sixième, après exécution du testament qu'il aurait fait ou paiement d'une dette. De vos ascendants ou descendants, vous ne savez pas qui est plus près de vous en utilité. Ceci est un ordre obligatoire de la part d'Allah, car Allah est, certes, Omniscient et Sage.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@dv{Et à vous la moitié de ce que laissent vos épouses, si elles n'ont pas d'enfants. Si elles ont un enfant, alors à vous le quart de ce qu'elles laissent, après exécution du testament qu'elles auraient fait ou paiement d'une dette. Et à elles un quart de ce que vous laissez, si vous n'avez pas d'enfant. Mais si vous avez un enfant, à elles alors le huitième de ce que vous laissez après exécution du testament que vous auriez fait ou paiement d'une dette. Et si un homme, ou une femme meurt sans héritier direct, cependant qu'il laisse un frère ou une sœur, à chacun de ceux-ci alors, un sixième. S'ils sont plus de deux, tous alors participeront au tiers, après exécution du testament ou paiement d'une dette, sans préjudice à quiconque. (Telle est l') Injonction d'Allah! Et Allah est Omniscient et Indulgent.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@dvi{Tels sont les ordres d'Allah. Et quiconque obéit à Allah et à Son messager, Il le fera entrer dans les Jardins sous lesquels coulent les ruisseaux, pour y demeurer éternellement. Et voilà la grande réussite.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@dvii{Et quiconque désobéit à Allah et à Son messager, et transgresse Ses ordres, Il le fera entrer au Feu pour y demeurer éternellement. Et celui-là aura un châtiment avilissant.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@dviii{Celles de vos femmes qui forniquent, faites témoigner à leur encontre quatre d'entre vous. S'ils témoignent, alors confinez ces femmes dans vos maisons jusqu'à ce que la mort les rappelle ou qu'Allah décrète un autre ordre à leur égard.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@dix{Les deux d'entre vous qui l'ont commise [la fornication], sévissez contre eux. S'ils se repentent ensuite et se réforment, alors laissez-les en paix. Allah demeure Accueillant au repentir et Miséricordieux.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@dx{Allah accueille seulement le repentir de ceux qui font le mal par ignorance et qui aussitôt se repentent. Voilà ceux de qui Allah accueille le repentir. Et Allah est Omniscient et Sage.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@dxi{Mais l'absolution n'est point destinée à ceux qui font de mauvaises actions jusqu'au moment où la mort se présente à l'un d'eux, et qui s'écrie: «Certes, je me repens maintenant» - non plus pour ceux qui meurent mécréants. Et c'est pour eux que Nous avons préparé un châtiment douloureux.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@dxii{O les croyants! Il ne vous est pas licite d'hériter des femmes contre leur gré. Ne les empêchez pas de se remarier dans le but de leur ravir une partie de ce que vous aviez donné, à moins qu'elles ne viennent à commettre un péché prouvé. Et comportez-vous convenablement envers elles. Si vous avez de l'aversion envers elles durant la vie commune, il se peut que vous ayez de l'aversion pour une chose où Allah a déposé un grand bien.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@dxiii{Si vous voulez substituer une épouse à une autre, et que vous ayez donné à l'une un qintâr, n'en reprenez rien. Quoi! Le reprendriez-vous par injustice et péché manifeste?\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@dxiv{Comment oseriez-vous le reprendre, après que l'union la plus intime vous ait associés l'un à l'autre et qu'elles aient obtenu de vous un engagement solennel?\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@dxv{Et n'épousez pas les femmes que vos pères ont épousées, exception faite pour le passé. C'est une turpitude, une abomination, et quelle mauvaise conduite!\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@dxvi{Vous sont interdites vos mères, filles, sœurs, tantes paternelles et tantes maternelles, filles d'un frère et filles d'une sœur, mères qui vous ont allaités, sœurs de lait, mères de vos femmes, belles-filles sous votre tutelle et issues des femmes avec qui vous avez consommé le mariage; si le mariage n'a pas été consommé, ceci n'est pas un péché de votre part; les femmes de vos fils nés de vos reins; de même que deux sœurs réunies - exception faite pour le passé. Car vraiment Allah est Pardonneur et Miséricordieux;\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@dxvii{et, parmi les femmes, les dames (qui ont un mari), sauf si elles sont vos esclaves en toute propriété. Prescription d'Allah sur vous! A part cela, il vous est permis de les rechercher, en vous servant de vos biens et en concluant mariage, non en débauchés. Puis, de même que vous jouissez d'elles, donnez-leur leur mahr comme une chose due. Il n'y a aucun péché contre vous à ce que vous concluez un accord quelconque entre vous après la fixation du mahr Car Allah est, certes, Omniscient et Sage.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@dxviii{Et quiconque parmi vous n'a pas les moyens pour épouser des femmes libres (non esclaves) croyantes, eh bien (il peut épouser) une femme parmi celles de vos esclaves croyantes. Allah connaît mieux votre foi, car vous êtes les uns des autres (de la même religion). Et épousez-les avec l'autorisation de leurs maîtres (Waliy) et donnez-leur un mahr convenable; (épousez-les) étant vertueuses et non pas livrées à la débauche ni ayant des amants clandestins. Si, une fois engagées dans le mariage, elles commettent l'adultère, elles reçoivent la moitié du châtiment qui revient aux femmes libres (non esclaves) mariées. Ceci est autorisé à celui d'entre vous qui craint la débauche; mais ce serait mieux pour vous d'être endurant. Et Allah est Pardonneur et Miséricordieux.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@dxix{Allah veut vous éclairer, vous montrer les voies des hommes d'avant vous, et aussi accueillir votre repentir. Et Allah est Omniscient et Sage.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@dxx{Et Allah veut accueillir votre repentir. Mais ceux qui suivent les passions veulent que vous vous incliniez grandement (vers l'erreur comme ils le font).\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@dxxi{Allah veut vous alléger (les obligations,) car l'homme a été créé faible.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@dxxii{O les croyants! Que les uns d'entre vous ne mangent pas les biens des autres illégalement. Mais qu'il y ait du négoce (légal), entre vous, par consentement mutuel. Et ne vous tuez pas vous-mêmes. Allah, en vérité, est Miséricordieux envers vous.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@dxxiii{Et quiconque commet cela, par excès et par iniquité, Nous le jetterons au Feu, voilà qui est facile pour Allah.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@dxxiv{Si vous évitez les grands péchés qui vous sont interdits, Nous effacerons vos méfaits de votre compte, et Nous vous ferons entrer dans un endroit honorable (le Paradis).\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@dxxv{Ne convoitez pas ce qu'Allah a attribué aux uns d'entre vous plus qu'aux autres; aux hommes la part qu'ils ont acquise, et aux femmes la part qu'elles ont acquise. Demandez à Allah de Sa grâce. Car Allah, certes, est Omniscient.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@dxxvi{A tous Nous avons désigné des héritiers pour ce que leur laissent leurs père et mère, leurs proches parents, et ceux envers qui, de vos propres mains, vous vous êtes engagés, donnez leur donc leur part, car Allah, en vérité, est témoin de tout.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@dxxvii{Les hommes ont autorité sur les femmes, en raison des faveurs qu'Allah accorde à ceux-là sur celles-ci, et aussi à cause des dépenses qu'ils font de leurs biens. Les femmes vertueuses sont obéissantes (à leurs maris), et protègent ce qui doit être protégé, pendant l'absence de leurs époux, avec la protection d'Allah. Et quant à celles dont vous craignez la désobéissance, exhortez-les, éloignez-vous d'elles dans leurs lits et frappez-les. Si elles arrivent à vous obéir, alors ne cherchez plus de voie contre elles, car Allah est certes, Haut et Grand!\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@dxxviii{Si vous craignez le désaccord entre les deux [époux], envoyez alors un arbitre de sa famille à lui, et un arbitre de sa famille à elle. Si les deux veulent la réconciliation, Allah rétablira l'entente entre eux. Allah est certes, Omniscient et Parfaitement Connaisseur.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@dxxix{Adorez Allah et ne Lui donnez aucun associé. Agissez avec bonté envers (vos) père et mère, les proches, les orphelins, les pauvres, le proche voisin, le voisin lointain, le collègue et le voyageur, et les esclaves en votre possession, car Allah n'aime pas, en vérité, le présomptueux, l'arrogant,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@dxxx{Ceux qui sont avares et ordonnent l'avarice aux autres, et cachent ce qu'Allah leur a donné de par Sa grâce. Nous avons préparé un châtiment avilissant pour les mécréants.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@dxxxi{Et ceux qui dépensent leurs biens avec ostentation devant les gens, et ne croient ni en Allah ni au Jour dernier. Quiconque a le Diable pour camarade inséparable, quel mauvais camarade!\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@dxxxii{Qu'auraient-ils à se reprocher s'ils avaient cru en Allah et au Jour dernier et dépensé (dans l'obéissance) de ce qu'Allah leur a attribué? Allah, d'eux, est Omniscient.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@dxxxiii{Certes, Allah ne lèse (personne), fût-ce du poids d'un atome. S'il est une bonne action, Il la double, et accorde une grosse récompense de Sa part.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@dxxxiv{Comment seront-ils quand Nous ferons venir de chaque communauté un témoin, et que Nous te (Muhammad) ferons venir comme témoin contre ces gens-ci?\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@dxxxv{Ce jour-là, ceux qui n'ont pas cru et ont désobéi au Messager, préfèreraient que la terre fût nivelée sur eux et ils ne sauront cacher à Allah aucune parole.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@dxxxvi{O les croyants! N'approchez pas de la Salât alors que vous êtes ivres jusqu'à ce que vous compreniez ce que vous dites, et aussi quand vous êtes en état d'impureté [pollués] - à moins que vous ne soyez en voyage - jusqu'à ce que vous ayez pris un bain rituel. Si vous êtes malades ou en voyage, ou si l'un de vous revient du lieu où il a fait ses besoins, ou si vous avez touché à des femmes et que vous ne trouviez pas d'eau, alors recourez à une terre pure, et passez-vous-en sur vos visages et sur vos mains. Allah, en vérité, est Indulgent et Pardonneur.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@dxxxvii{N'as-tu (Muhammad) pas vu ceux qui ont reçu une partie du Livre acheter l'égarement et chercher à ce que vous vous égariez du [droit] chemin?\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@dxxxviii{Allah connaît mieux vos ennemis. Et Allah suffit comme protecteur. Et Allah suffit comme secoureur.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@dxxxix{Il en est parmi les Juifs qui détournent les mots de leur sens, et disent: «Nous avions entendu, mais nous avons désobéi», «Ecoute sans qu'il te soit donné d'entendre», et favorise nous «Ra'inâ», tordant la langue et attaquant la religion. Si au contraire ils disaient: «Nous avons entendu et nous avons obéi», «Ecoute», et «Regarde-nous», ce serait meilleur pour eux, et plus droit. Mais Allah les a maudits à cause de leur mécréance; leur foi est donc bien médiocre.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@dxl{O vous à qui on a donné le Livre, croyez à ce que Nous avons fait descendre, en confirmation de ce que vous aviez déjà, avant que Nous effacions des visages et les retournions sens devant derrière, ou que Nous les maudissions comme Nous avons maudit les gens du Sabbat. Car le commandement d'Allah est toujours exécuté.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@dxli{Certes Allah ne pardonne pas qu'on Lui donne quelqu'associé. A part cela, Il pardonne à qui Il veut. Mais quiconque donne à Allah quelqu'associé commet un énorme péché.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@dxlii{N'as-tu pas vu ceux-là qui se déclarent purs? Mais c'est Allah qui purifie qui Il veut; et ils ne seront point lésés, fût-ce d'un brin de noyau de datte.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@dxliii{Regarde comme ils inventent le mensonge à l'encontre d'Allah. Et çà, c'est assez comme péché manifeste!\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@dxliv{N'as-tu pas vu ceux-là, à qui une partie du Livre a été donnée, avoir foi à la magie (gibt) et au Tâghhoût, et dire en faveur de ceux qui ne croient pas: «Ceux-là sont mieux guidés (sur le chemin) que ceux qui ont cru»?\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@dxlv{Voilà ceux qu'Allah a maudits; et quiconque Allah maudit, jamais tu ne trouveras pour lui de secoureur.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@dxlvi{Possèdent-ils une partie du pouvoir? Ils ne donneraient donc rien aux gens, fût-ce le creux d'un noyau de datte.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@dxlvii{Envient-ils aux gens ce qu'Allah leur a donné de par Sa grâce? Or, Nous avons donné à la famille d'Abraham le Livre et la Sagesse; et Nous leur avons donné un immense royaume.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@dxlviii{Certains d'entre eux ont cru en lui, d'autres d'entre eux s'en sont écartés. L'Enfer leur suffira comme flamme (pour y brûler).\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@dxlix{Certes, ceux qui ne croient pas à Nos Versets, (le Coran) Nous les brûlerons bientôt dans le Feu. Chaque fois que leurs peaux auront été consumées, Nous leur donnerons d'autres peaux en échange afin qu'ils goûtent au châtiment. Allah est certes, Puissant et Sage!\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@dl{Et quant à ceux qui ont cru et fait de bonnes œuvres, bientôt Nous les ferons entrer aux Jardins sous lesquels coulent des ruisseaux. Ils y demeureront éternellement. Il y aura là pour eux des épouses purifiées. Et Nous les ferons entrer sous un ombrage épais.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@dli{Certes, Allah vous commande de rendre les dépôts à leurs ayants-droit, et quand vous jugez entre des gens, de juger avec équité. Quelle bonne exhortation qu'Allah vous fait! Allah est, en vérité, Celui qui entend et qui voit tout.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@dlii{O les croyants! Obéissez à Allah, et obéissez au Messager et à ceux d'entre vous qui détiennent le commandement. Puis, si vous vous disputez en quoi que ce soit, renvoyez-le à Allah et au Messager, si vous croyez en Allah et au Jour dernier. Ce sera bien mieux et de meilleure interprétation (et aboutissement).\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@dliii{N'as-tu pas vu ceux qui prétendent croire à ce qu'on a fait descendre vers toi [prophète] et à ce qu'on a fait descendre avant toi? Ils veulent prendre pour juge le Tâghût, alors que c'est en lui qu'on leur a commandé de ne pas croire. Mais le Diable veut les égarer très loin, dans l'égarement.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@dliv{Et lorsqu'on leur dit: «Venez vers ce qu'Allah a fait descendre et vers le Messager», tu vois les hypocrites s'écarter loin de toi.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@dlv{Comment (agiront-ils) quand un malheur les atteindra, à cause de ce qu'ils ont préparé de leurs propres mains? Puis ils viendront alors près de toi, jurant par Allah: «Nous n'avons voulu que le bien et la réconciliation».\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@dlvi{Voilà ceux dont Allah sait ce qu'ils ont dans leurs cœurs. Ne leur tiens donc pas rigueur, exhorte-les, et dis-leur sur eux-mêmes des paroles convaincantes.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@dlvii{Nous n'avons envoyé de Messager que pour qu'il soit obéi par la permission d'Allah. Si, lorsqu'ils ont fait du tort à leurs propres personnes ils venaient à toi en implorant le pardon d'Allah et si le Messager demandait le pardon pour eux, ils trouveraient, certes, Allah, Très Accueillant au repentir, Miséricordieux.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@dlviii{Non!... Par ton Seigneur! Ils ne seront pas croyants aussi longtemps qu'ils ne t'auront demandé de juger de leurs disputes et qu'ils n'auront éprouvé nulle angoisse pour ce que tu auras décidé, et qu'ils se soumettent complètement [à ta sentence].\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@dlix{Si Nous leur avions prescrit ceci: «Tuez-vous vous-mêmes», ou «Sortez de vos demeures», ils ne l'auraient pas fait, sauf un petit nombre d'entre eux. S'ils avaient fait ce à quoi on les exhortait, cela aurait été certainement meilleur pour eux, et (leur foi) aurait été plus affermie.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@dlx{Alors Nous leur aurions donné certainement, de Notre part, une grande récompense,\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@dlxi{et Nous les aurions guidé certes, vers un droit chemin.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@dlxii{Quiconque obéit à Allah et au Messager... ceux-là seront avec ceux qu'Allah a comblés de Ses bienfaits: les prophètes, les véridiques, les martyrs, et les vertueux. Et quels bons compagnons que ceux-là!\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@dlxiii{Cette grâce vient d'Allah. Et Allah suffit comme Parfait Connaisseur.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@dlxiv{O les croyants! Prenez vos précautions et partez en expédition par détachements ou en masse.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@dlxv{Parmi vous, il y aura certes, quelqu'un qui tardera [à aller au combat] et qui, si un malheur vous atteint, dira: «Certes, Allah m'a fait une faveur en ce que je ne me suis pas trouvé en leur compagnie»\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@dlxvi{et si c'est une grâce qui vous atteint de la part d'Allah, il se mettra, certes, à dire, comme s'il n'y avait aucune affection entre vous et lui: «Quel dommage! Si j'avais été avec eux, j'aurais alors acquis un gain énorme».\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@dlxvii{Qu'ils combattent donc dans le sentier d'Allah, ceux qui troquent la vie présente contre la vie future. Et quiconque combat dans le sentier d'Allah, tué ou vainqueur, Nous lui donnerons bientôt une énorme récompense.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@dlxviii{Et qu'avez-vous à ne pas combattre dans le sentier d'Allah, et pour la cause des faibles: hommes, femmes et enfants qui disent: «Seigneur! Fais-nous sortir de cette cité dont les gens sont injustes, et assigne-nous de Ta part un allié, et assigne-nous de Ta part un secoureur».\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@dlxix{Les croyants combattent dans le sentier d'Allah, et ceux qui ne croient pas combattent dans le sentier du Tâghût. Eh bien, combattez les alliés du Diable, car la ruse du Diable est, certes, faible.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@dlxx{N'as-tu pas vu ceux auxquels on avait dit: «Abstenez-vous de combattre, accomplissez la Salât et acquittez la Zakât!» Puis lorsque le combat leur fut prescrit, voilà qu'une partie d'entre eux se mit à craindre les gens comme on craint Allah, ou même d'une crainte plus forte encore, et à dire: «O notre Seigneur! Pourquoi nous as-Tu prescrit le combat? Pourquoi n'as-Tu pas reporté cela à un peu plus tard?» Dis: «La jouissance d'ici-bas est éphémère, mais la vie future est meilleure pour quiconque est pieux. Et on ne vous lésera pas, fût-ce d'un brin de noyau de datte.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@dlxxi{Où que vous soyez, la mort vous atteindra, fussiez-vous dans des tours imprenables. Qu'un bien les atteigne, ils disent: «C'est de la part d'Allah.» Qu'un mal les atteigne, ils disent: «C'est dû à toi (Muhammad).» Dis: «Tout est d'Allah.» Mais qu'ont-ils ces gens, à ne comprendre presque aucune parole?\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@dlxxii{Tout bien qui t'atteint vient d'Allah, et tout mal qui t'atteint vient de toi-même. Et nous t'avons envoyé aux gens comme Messager. Et Allah suffit comme témoin.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@dlxxiii{Quiconque obéit au Messager obéit certainement à Allah. Et quiconque tourne le dos... Nous ne t'avons pas envoyé à eux comme gardien.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@dlxxiv{Ils disent: «Obéissance!» Puis, sitôt sortis de chez toi, une partie d'entre eux délibère au cours de la nuit de tout autre chose que ce qu'elle t'a dit. [Cependant] Allah enregistre ce qu'ils font la nuit. Pardonne-leur donc et place ta confiance en Allah. Et Allah suffit comme Protecteur.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@dlxxv{Ne méditent-ils donc pas sur le Coran? S'il provenait d'un autre qu'Allah, ils y trouveraient certes maintes contradictions!\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@dlxxvi{Quand leur parvient une nouvelle rassurante ou alarmante, ils la diffusent. S'ils la rapportaient au Messager et aux détenteurs du commandement parmi eux, ceux d'entre eux qui cherchent à être éclairés, auraient appris (la vérité de la bouche du Prophète et des détenteurs du commandement). Et n'eussent été la grâce d'Allah sur vous et Sa miséricorde, vous auriez suivi le Diable, à part quelques-uns.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@dlxxvii{Combats donc dans le sentier d'Allah, tu n'es responsable que de toi même, et incite les croyants (au combat) Allah arrêtera certes la violence des mécréants. Allah est plus redoutable en force et plus sévère en punition.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@dlxxviii{Quiconque intercède d'une bonne intercession, en aura une part; et quiconque intercède d'une mauvaise intercession en portera une part de responsabilité. Et Allah est Puissant sur toute chose.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@dlxxix{Si on vous fait une salutation, saluez d'une façon meilleure; ou bien rendez-la (simplement). Certes, Allah tient compte de tout.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@dlxxx{Allah! Pas de divinité à part Lui! Très certainement Il vous rassemblera au Jour de la Résurrection, point de doute là-dessus. Et qui est plus véridique qu'Allah en parole?\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@dlxxxi{Qu'avez-vous à vous diviser en deux factions au sujet des hypocrites? Alors qu'Allah les a refoulés (dans leur infidélité) pour ce qu'ils ont acquis. Voulez-vous guider ceux qu'Allah égare? Et quiconque Allah égare, tu ne lui trouveras pas de chemin (pour le ramener).\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@dlxxxii{Ils aimeraient vous voir mécréants comme ils ont mécru: alors vous seriez tous égaux! Ne prenez donc pas d'alliés parmi eux, jusqu'à ce qu'ils émigrent dans le sentier d'Allah. Mais s'ils tournent le dos, saisissez-les alors, et tuez-les où que vous les trouviez; et ne prenez parmi eux ni allié ni secoureur,\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@dlxxxiii{excepté ceux qui se joignent à un groupe avec lequel vous avez conclu une alliance, ou ceux qui viennent chez vous, le cœur serré d'avoir à vous combattre ou à combattre leur propre tribu. Si Allah avait voulu, Il leur aurait donné l'audace (et la force) contre vous, et ils vous auraient certainement combattu. (Par conséquent,) s'ils restent neutres à votre égard et ne vous combattent point, et qu'ils vous offrent la paix, alors, Allah ne vous donne pas de chemin contre eux.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@dlxxxiv{Vous en trouverez d'autres qui cherchent à avoir votre confiance, et en même temps la confiance de leur propre tribu. Toutes les fois qu'on les pousse vers l'Association, (l'idolâtrie) ils y retombent en masse. (Par conséquent,) s'ils ne restent pas neutres à votre égard, ne vous offrent pas la paix et ne retiennent pas leurs mains (de vous combattre), alors, saisissez-les et tuez les où que vous les trouviez. Contre ceux-ci, Nous vous avons donné une autorité manifeste.\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@dlxxxv{Il n'appartient pas à un croyant de tuer un autre croyant, si ce n'est par erreur. Quiconque tue par erreur un croyant, qu'il affranchisse alors un esclave croyant et remette à sa famille le prix du sang, à moins que celle-ci n'y renonce par charité. Mais si [le tué] appartenait à un peuple ennemi à vous et qu'il soit croyant, qu'on affranchisse alors un esclave croyant. S'il appartenait à un peuple auquel vous êtes liés par un pacte, qu'on verse alors à sa famille le prix du sang et qu'on affranchisse un esclave croyant. Celui qui n'en trouve pas les moyens, qu'il jeûne deux mois d'affilée pour être pardonné par Allah. Allah est Omniscient et Sage.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@dlxxxvi{Quiconque tue intentionnellement un croyant, Sa rétribution alors sera l'Enfer, pour y demeurer éternellement. Allah l'a frappé de Sa colère, l'a maudit et lui a préparé un énorme châtiment.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@dlxxxvii{O les croyants! Lorsque vous sortez pour lutter dans le sentier d'Allah, voyez bien clair (ne vous hâtez pas) et ne dites pas à quiconque vous adresse le salut (de l'Islam): «Tu n'es pas croyant», convoitant les biens de la vie d'ici-bas. Or c'est auprès d'Allah qu'il y a beaucoup de butin. C'est ainsi que vous étiez auparavant; puis Allah vous a accordé Sa grâce. Voyez donc bien clair. Allah est, certes, Parfaitement Connaisseur de ce que vous faites.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@dlxxxviii{Ne sont pas égaux ceux des croyants qui restent chez eux - sauf ceux qui ont quelque infirmité - et ceux qui luttent corps et biens dans le sentier d'Allah. Allah donne à ceux qui luttent corps et biens un grade d'excellence sur ceux qui restent chez eux. Et à chacun Allah a promis la meilleure récompense; et Allah a mis les combattants au-dessus des non combattants en leur accordant une rétribution immense;\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@dlxxxix{des grades de supériorité de Sa part ainsi qu'un pardon et une miséricorde. Allah est Pardonneur et Miséricordieux.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@dxc{Ceux qui ont fait du tort à eux-mêmes, les Anges enlèveront leurs âmes en disant: «Où en étiez-vous?» (à propos de votre religion) - «Nous étions impuissants sur terre», dirent-ils. Alors les Anges diront: «La terre d'Allah n'était-elle pas assez vaste pour vous permettre d'émigrer?» Voilà bien ceux dont le refuge est l'Enfer. Et quelle mauvaise destination!\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@dxci{A l'exception des impuissants: hommes, femmes et enfants, incapables de se débrouiller, et qui ne trouvent aucune voie:\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@dxcii{A ceux-là, il se peut qu'Allah donne le pardon. Allah est Clément et Pardonneur.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@dxciii{Et quiconque émigre dans le sentier d'Allah trouvera sur terre maints refuges et abondance. Et quiconque sort de sa maison, émigrant vers Allah et Son messager, et que la mort atteint, sa récompense incombe à Allah. Et Allah est Pardonneur et Miséricordieux.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@dxciv{Et quand vous parcourez la terre, ce n'est pas un péché pour vous de raccourcir la Salât, si vous craignez que les mécréants ne vous mettent à l'épreuve, car les mécréants demeurent pour vous un ennemi déclaré.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@dxcv{Et lorsque tu (Muhammad) te trouves parmi eux, et que tu les diriges dans la Salât, qu'un groupe d'entre eux se mette debout en ta compagnie, en gardant leurs armes. Puis lorsqu'ils ont terminé la prosternation, qu'ils passent derrière vous et que vienne l'autre groupe, ceux qui n'ont pas encore célébré la Salât. A ceux-ci alors d'accomplir la Salât avec toi, prenant leurs précautions et leurs armes. Les mécréants aimeraient vous voir négliger vos armes et vos bagages, afin de tomber sur vous en une seule masse. Vous ne commettez aucun péché si, incommodés par la pluie ou malades, vous déposez vos armes; cependant prenez garde. Certes, Allah a préparé pour les mécréants un châtiment avilissant.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@dxcvi{Quand vous avez accompli la Salât, invoquez le nom d'Allah, debout, assis ou couchés sur vos côtés. Puis lorsque vous êtes en sécurité, accomplissez la Salât (normalement), car la Salât demeure, pour les croyants, une prescription, à des temps déterminés.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@dxcvii{Ne faiblissez pas dans la poursuite du peuple [ennemi]. Si vous souffrez, lui aussi souffre comme vous souffrez, tandis que vous espérez d'Allah ce qu'il n'espère pas. Allah est Omniscient et Sage.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@dxcviii{Nous avons fait descendre vers toi le Livre avec la vérité, pour que tu juges entre les gens, selon ce qu'Allah t'a appris. Et ne te fais pas l'avocat des traîtres.\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@dxcix{Et implore d'Allah le pardon car Allah est certes Pardonneur et Miséricordieux.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@dc{Et ne dispute pas en faveur de ceux qui se trahissent eux-mêmes. Allah, vraiment, n'aime pas le traître et le pécheur.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@dci{Ils cherchent à se cacher des gens, mais ils ne cherchent pas à se cacher d'Allah. Or, Il est avec eux quand ils tiennent la nuit des paroles qu'Il (Allah) n'agrée pas. Et Allah ne cesse de cerner (par Sa science) ce qu'ils font.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@dcii{Voilà les gens en faveur desquels vous disputez dans la vie présente. Mais qui va disputer pour eux devant Allah au Jour de la Résurrection? Ou bien qui sera leur protecteur?\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@dciii{Quiconque agit mal ou fait du tort à lui-même, puis aussitôt implore d'Allah le pardon, trouvera Allah Pardonneur et Miséricordieux.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@dciv{Quiconque acquiert un péché, ne l'acquiert que contre lui-même. Et Allah est Omniscient et Sage.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@dcv{Et quiconque acquiert une faute ou un péché puis en accuse un innocent, se rend coupable alors d'une injustice et d'un péché manifeste.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@dcvi{Et n'eût été la grâce d'Allah sur toi (Muhammad) et Sa miséricorde, une partie d'entre eux t'aurait bien volontiers égaré. Mais ils n'égarent qu'eux-mêmes, et ne peuvent en rien te nuire. Allah a fait descendre sur toi le Livre et la Sagesse, et t'a enseigné ce que tu ne savais pas. Et la grâce d'Allah sur toi est immense.\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@dcvii{Il n'y a rien de bon dans la plus grande partie de leurs conversations secrètes, sauf si l'un d'eux ordonne une charité, une bonne action, ou une conciliation entre les gens. Et quiconque le fait, cherchant l'agrément d'Allah, à celui-là Nous donnerons bientôt une récompense énorme.\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@dcviii{Et quiconque fait scission d'avec le Messager, après que le droit chemin lui est apparu et suit un sentier autre que celui des croyants, alors Nous le laisserons comme il s'est détourné, et le brûlerons dans l'Enfer. Et quelle mauvaise destination!\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@dcix{Certes, Allah ne pardonne pas qu'on Lui donne des associés. A part cela, Il pardonne à qui Il veut. Quiconque donne des associés à Allah s'égare, très loin dans l'égarement.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@dcx{Ce ne sont que des femelles qu'ils invoquent, en dehors de Lui. Et ce n'est qu'un diable rebelle qu'ils invoquent.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@dcxi{Allah l'a (le Diable) maudit et celui-ci a dit: «Certainement, je saisirai parmi Tes serviteurs, une partie déterminée.\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@dcxii{Certes, je ne manquerai pas de les égarer, je leur donnerai de faux espoirs, je leur commanderai, et ils fendront les oreilles aux bestiaux; je leur commanderai, et ils altèreront la création d'Allah. Et quiconque prend le Diable pour allié au lieu d'Allah, sera, certes, voué à une perte évidente.\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@dcxiii{Il leur fait des promesses et leur donne de faux espoirs. Et le Diable ne leur fait que des promesses trompeuses.\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@dcxiv{Voilà ceux dont le refuge est l'Enfer. Et ils ne trouveront aucun moyen d'y échapper!\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@dcxv{Et quant à ceux qui ont cru et fait de bonnes œuvres, Nous les ferons entrer bientôt aux Jardins sous lesquels coulent les ruisseaux, pour y demeurer éternellement. Promesse d'Allah en vérité. Et qui est plus véridique qu'Allah en parole?\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@dcxvi{Ceci ne dépend ni de vos désirs ni des désirs des gens du Livre. Quiconque fait un mal sera rétribué pour cela, et ne trouvera en sa faveur, hors d'Allah, ni allié ni secoureur.\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@dcxvii{Et quiconque, homme ou femme, fait de bonnes œuvres, tout en étant croyant... les voilà ceux qui entreront au Paradis; et on ne leur fera aucune injustice, fût-ce d'un creux de noyau de datte.\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@dcxviii{Qui est meilleur en religion que celui qui soumet à Allah son être, tout en se conformant à la Loi révélée et suivant la religion d'Abraham, homme de droiture? Et Allah avait pris Abraham pour ami privilégié.\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@dcxix{C'est à Allah qu'appartient tout ce qui est dans les cieux et sur la terre. Et Allah embrasse toute chose (de Sa science et de Sa puissance).\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@dcxx{Et ils te consultent à propos de ce qui a été décrété au sujet des femmes. Dis: «Allah vous donne Son décret là-dessus, en plus de ce qui vous est récité dans le Livre, au sujet des orphelines auxquelles vous ne donnez pas ce qui leur a été prescrit, et que vous désirez épouser, et au sujet des mineurs encore d'âge faible». Vous devez agir avec équité envers les orphelins. Et de tout ce que vous faites de bien, Allah en est, certes, Omniscient.\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@dcxxi{Et si une femme craint de son mari abandon ou indifférence, alors ce n'est pas un péché pour les deux s'ils se réconcilient par un compromis quelconque, et la réconciliation est meilleure, puisque les âmes sont portées à la ladrerie. Mais si vous agissez en bien et vous êtes pieux... Allah est, certes, Parfaitement Connaisseur de ce que vous faites.\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@dcxxii{Vous ne pourrez jamais être équitables entre vos femmes, même si vous en êtes soucieux. Ne vous penchez pas tout à fait vers l'une d'elles, au point de laisser l'autre comme en suspens. Mais si vous vous réconciliez et vous êtes pieux... donc Allah est, certes, Pardonneur et Miséricordieux.\qt@no{(129)}}
\qt@newcmd\qurantrans@fr@dcxxiii{Si les deux se séparent, Allah de par Sa largesse, accordera à chacun d'eux un autre destin. Et Allah est plein de largesses et parfaitement Sage.\qt@no{(130)}}
\qt@newcmd\qurantrans@fr@dcxxiv{A Allah seul appartient tout ce qui est dans les cieux et sur la terre. «Craignez Allah!» Voilà ce que Nous avons enjoint à ceux auxquels avant vous le Livre fut donné, tout comme à vous-mêmes. Et si vous ne croyez pas (cela ne nuit pas à Allah, car) très certainement à Allah seul appartient tout ce qui est dans les cieux et sur la terre. Et Allah se suffit à Lui-même et Il est digne de louange.\qt@no{(131)}}
\qt@newcmd\qurantrans@fr@dcxxv{A Allah seul appartient tout ce qui est dans les cieux et sur la terre. Et Allah suffit pour s'occuper de tout.\qt@no{(132)}}
\qt@newcmd\qurantrans@fr@dcxxvi{S'Il voulait, il vous ferait disparaître, ô gens, et en ferait venir d'autres. Car Allah en est très capable.\qt@no{(133)}}
\qt@newcmd\qurantrans@fr@dcxxvii{Quiconque désire la récompense d'ici-bas, c'est auprès d'Allah qu'est la récompense d'ici-bas tout comme celle de l'au-delà. Et Allah entend et observe tout.\qt@no{(134)}}
\qt@newcmd\qurantrans@fr@dcxxviii{O les croyants! Observez strictement la justice et soyez des témoins (véridiques) comme Allah l'ordonne, fût-ce contre vous-mêmes, contre vos père et mère ou proches parents. Qu'il s'agisse d'un riche ou d'un besogneux, Allah a priorité sur eux deux (et Il est plus connaisseur de leur intérêt que vous). Ne suivez donc pas les passions, afin de ne pas dévier de la justice. Si vous portez un faux témoignage ou si vous le refusez, [sachez qu'] Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(135)}}
\qt@newcmd\qurantrans@fr@dcxxix{O les croyants! Soyez fermes en votre foi en Allah, en Son messager, au Livre qu'Il a fait descendre sur Son messager, et au Livre qu'Il a fait descendre avant. Quiconque ne croit pas en Allah, en Ses anges, en Ses Livres, en Ses messagers et au Jour dernier, s'égare, loin dans l'égarement.\qt@no{(136)}}
\qt@newcmd\qurantrans@fr@dcxxx{Ceux qui ont cru, puis sont devenus mécréants, puis ont cru de nouveau, ensuite sont redevenus mécréants, et n'ont fait que croître en mécréance, Allah ne leur pardonnera pas, ni les guidera vers un chemin (droit).\qt@no{(137)}}
\qt@newcmd\qurantrans@fr@dcxxxi{Annonce aux hypocrites qu'il y a pour eux un châtiment douloureux,\qt@no{(138)}}
\qt@newcmd\qurantrans@fr@dcxxxii{ceux qui prennent pour alliés des mécréants au lieu des croyants, est-ce la puissance qu'ils recherchent auprès d'eux? (En vérité) la puissance appartient entièrement à Allah.\qt@no{(139)}}
\qt@newcmd\qurantrans@fr@dcxxxiii{Dans le Livre, Il vous a déjà révélé ceci: lorsque vous entendez qu'on renie les versets (le Coran) d'Allah et qu'on s'en raille, ne vous asseyez point avec ceux-là jusqu'à ce qu'ils entreprennent une autre conversation. Sinon, vous serez comme eux. Allah rassemblera, certes, les hypocrites et les mécréants, tous, dans l'Enfer.\qt@no{(140)}}
\qt@newcmd\qurantrans@fr@dcxxxiv{Ils restent dans l'expectative à votre égard; si une victoire vous vient de la part d'Allah, ils disent: «N'étions-nous pas avec vous?» et s'il en revient un avantage aux mécréants, ils leur disent: «Est-ce que nous n'avons pas mis la main sur vous pour vous soustraire aux croyants?» Eh bien, Allah jugera entre vous au Jour de la Résurrection. Et jamais Allah ne donnera une voie aux mécréants contre les croyants.\qt@no{(141)}}
\qt@newcmd\qurantrans@fr@dcxxxv{Les hypocrites cherchent à tromper Allah, mais Allah retourne leur tromperie (contre eux-mêmes). Et lorsqu'ils se lèvent pour la Salât, ils se lèvent avec paresse et par ostentation envers les gens. A peine invoquent-ils Allah.\qt@no{(142)}}
\qt@newcmd\qurantrans@fr@dcxxxvi{Ils sont indécis (entre les croyants et les mécréants,) n'appartenant ni aux uns ni aux autres. Or, quiconque Allah égare, jamais tu ne trouveras de chemin pour lui.\qt@no{(143)}}
\qt@newcmd\qurantrans@fr@dcxxxvii{O les croyants! Ne prenez pas pour alliés les mécréants au lieu des croyants. Voudriez-vous donner à Allah une preuve évidente contre vous?\qt@no{(144)}}
\qt@newcmd\qurantrans@fr@dcxxxviii{Les hypocrites seront, certes, au plus bas fond du Feu, et tu ne leur trouveras jamais de secoureur,\qt@no{(145)}}
\qt@newcmd\qurantrans@fr@dcxxxix{sauf ceux qui se repentent, s'amendent, s'attachent fermement à Allah, et Lui vouent une foi exclusive. Ceux-là seront avec les croyants. Et Allah donnera aux croyants une énorme récompense.\qt@no{(146)}}
\qt@newcmd\qurantrans@fr@dcxl{Pourquoi Allah vous infligerait-Il un châtiment si vous êtes reconnaissants et croyants? Allah est Reconnaissant et Omniscient.\qt@no{(147)}}
\qt@newcmd\qurantrans@fr@dcxli{Allah n'aime pas qu'on profère de mauvaises paroles sauf quand on a été injustement provoqué. Et Allah est Audient et Omniscient.\qt@no{(148)}}
\qt@newcmd\qurantrans@fr@dcxlii{Que vous fassiez du bien, ouvertement ou en cachette, ou bien que vous pardonniez un mal... Alors Allah est Pardonneur et Omnipotent.\qt@no{(149)}}
\qt@newcmd\qurantrans@fr@dcxliii{Ceux qui ne croient pas en Allah et en Ses messagers, et qui veulent faire distinction entre Allah et Ses messagers et qui disent: «Nous croyons en certains d'entre eux mais ne croyons pas en d'autres», et qui veulent prendre un chemin intermédiaire (entre la foi et la mécréance),\qt@no{(150)}}
\qt@newcmd\qurantrans@fr@dcxliv{les voilà les vrais mécréants! Et Nous avons préparé pour les mécréants un châtiment avilissant.\qt@no{(151)}}
\qt@newcmd\qurantrans@fr@dcxlv{Et ceux qui croient en Allah et en Ses messagers et qui ne font point de différence entre ces derniers, voilà ceux à qui Il donnera leurs récompenses. Et Allah est Pardonneur et Miséricordieux.\qt@no{(152)}}
\qt@newcmd\qurantrans@fr@dcxlvi{Les gens du Livre te demandent de leur faire descendre du ciel un Livre. Ils ont déjà demandé à Moïse quelque chose de bien plus grave quand ils dirent: «Fais-nous voir Allah à découvert!» Alors la foudre les frappa pour leur tort. Puis ils adoptèrent le Veau (comme idole) même après que les preuves leur furent venues. Nous leur pardonnâmes cela et donnâmes à Moïse une autorité déclarée.\qt@no{(153)}}
\qt@newcmd\qurantrans@fr@dcxlvii{Et pour (obtenir) leur engagement, Nous avons brandi au-dessus d'eux le Mont Tor, Nous leur avons dit: «Entrez par la porte en vous prosternant» Nous leur avons dit: «Ne transgressez pas le Sabbat» et Nous avons pris d'eux un engagement ferme.\qt@no{(154)}}
\qt@newcmd\qurantrans@fr@dcxlviii{(Nous les avons maudits) à cause de leur rupture de l'engagement, leur mécréance aux révélations d'Allah, leur meurtre injustifié des prophètes, et leur parole: «Nos cœurs sont (enveloppés) et imperméables». En réalité, c'est Allah qui a scellé leurs cœurs à cause de leur mécréance, car ils ne croyaient que très peu.\qt@no{(155)}}
\qt@newcmd\qurantrans@fr@dcxlix{Et à cause de leur mécréance et de l'énorme calomnie qu'ils prononcent contre Marie,\qt@no{(156)}}
\qt@newcmd\qurantrans@fr@dcl{et à cause de leur parole: «Nous avons vraiment tué le Christ, Jésus, fils de Marie, le Messager d'Allah»... Or, ils ne l'ont ni tué ni crucifié; mais ce n'était qu'un faux semblant! Et ceux qui ont discuté sur son sujet sont vraiment dans l'incertitude: ils n'en ont aucune connaissance certaine, ils ne font que suivre des conjectures et ils ne l'ont certainement pas tué,\qt@no{(157)}}
\qt@newcmd\qurantrans@fr@dcli{mais Allah l'a élevé vers Lui. Et Allah est Puissant et Sage.\qt@no{(158)}}
\qt@newcmd\qurantrans@fr@dclii{Il n'y aura personne, parmi les gens du Livre, qui n'aura pas foi en lui avant sa mort. Et au Jour de la Résurrection, il sera témoin contre eux.\qt@no{(159)}}
\qt@newcmd\qurantrans@fr@dcliii{C'est à cause des iniquités des Juifs que Nous leur avons rendu illicites les bonnes nourritures qui leur étaient licites, et aussi à cause de ce qu'ils obstruent le sentier d'Allah, (à eux-mêmes et) à beaucoup de monde,\qt@no{(160)}}
\qt@newcmd\qurantrans@fr@dcliv{et à cause de ce qu'ils prennent des intérêts usuraires- qui leur étaient pourtant interdits - et parce qu'ils mangent illégalement les biens des gens. A ceux d'entre eux qui sont mécréants Nous avons préparé un châtiment douloureux.\qt@no{(161)}}
\qt@newcmd\qurantrans@fr@dclv{Mais ceux d'entre eux qui sont enracinés dans la connaissance, ainsi que les croyants, (tous) ont foi à ce qu'on a fait descendre sur toi et à ce qu'on a fait descendre avant toi. Et quant à ceux qui accomplissent la Salât, paient la Zakât et croient en Allah et au Jour dernier, ceux-là Nous leur donnerons une énorme récompense.\qt@no{(162)}}
\qt@newcmd\qurantrans@fr@dclvi{Nous t'avons fait une révélation comme Nous fîmes à Noé et aux prophètes après lui. Et Nous avons fait révélation à Abraham, à Ismaël, à Isaac, à Jacob aux Tribus, à Jésus, à Job, à Jonas, à Aaron et à Salomon, et Nous avons donné le Zabour à David.\qt@no{(163)}}
\qt@newcmd\qurantrans@fr@dclvii{Et il y a des messagers dont Nous t'avons raconté l'histoire précédemment, et des messagers dont Nous ne t'avons point raconté l'histoire - et Allah a parlé à Moïse de vive voix -\qt@no{(164)}}
\qt@newcmd\qurantrans@fr@dclviii{en tant que messagers, annonciateurs et avertisseurs, afin qu'après la venue des messagers il n'y eût pour les gens point d'argument devant Allah. Allah est Puissant et Sage.\qt@no{(165)}}
\qt@newcmd\qurantrans@fr@dclix{Mais Allah témoigne de ce qu'Il a fait descendre vers toi, Il l'a fait descendre en toute connaissance. Et les Anges en témoignent. Et Allah suffit comme témoin.\qt@no{(166)}}
\qt@newcmd\qurantrans@fr@dclx{Ceux qui ne croient pas et qui obstruent le sentier d'Allah, s'égarent certes loin dans l'égarement.\qt@no{(167)}}
\qt@newcmd\qurantrans@fr@dclxi{Ceux qui ne croient pas et qui pratiquent l'injustice, Allah n'est nullement disposé à leur pardonner, ni à les guider dans un chemin\qt@no{(168)}}
\qt@newcmd\qurantrans@fr@dclxii{(autre) que le chemin de l'Enfer où ils demeureront éternellement. Et cela est facile à Allah.\qt@no{(169)}}
\qt@newcmd\qurantrans@fr@dclxiii{O gens! Le Messager vous a apporté la vérité de la part de votre Seigneur. Ayez la foi, donc, cela vous sera meilleur. Et si vous ne croyez pas (qu'importe!), c'est à Allah qu'appartient tout ce qui est dans les cieux et sur la terre. Et Allah est Omniscient et Sage.\qt@no{(170)}}
\qt@newcmd\qurantrans@fr@dclxiv{O gens du Livre (Chrétiens), n'exagérez pas dans votre religion, et ne dites d'Allah que la vérité. Le Messie Jésus, fils de Marie, n'est qu'un Messager d'Allah, Sa parole qu'Il envoya à Marie, et un souffle (de vie) venant de Lui. Croyez donc en Allah et en Ses messagers. Et ne dites pas «Trois». Cessez! Ce sera meilleur pour vous. Allah n'est qu'un Dieu unique. Il est trop glorieux pour avoir un enfant. C'est à Lui qu'appartient tout ce qui est dans les cieux et sur la terre et Allah suffit comme protecteur.\qt@no{(171)}}
\qt@newcmd\qurantrans@fr@dclxv{Jamais le Messie ne trouve indigne d'être un serviteur d'Allah, ni les Anges rapprochés [de Lui]. Et ceux qui trouvent indigne de L'adorer et s'enflent d'orgueil... Il les rassemblera tous vers Lui.\qt@no{(172)}}
\qt@newcmd\qurantrans@fr@dclxvi{Quant à ceux qui ont cru et fait de bonnes œuvres, Il leur accordera leurs pleines récompenses et y ajoutera le surcroît de Sa grâce. Et quant à ceux qui ont eu la morgue et se sont enflés d'orgueil, Il les châtiera d'un châtiment douloureux. Et ils ne trouveront, pour eux, en dehors d'Allah, ni allié ni secoureur,\qt@no{(173)}}
\qt@newcmd\qurantrans@fr@dclxvii{O gens! Certes, une preuve évidente vous est venue de la part de votre Seigneur. Et Nous avons fait descendre vers vous une lumière éclatante.\qt@no{(174)}}
\qt@newcmd\qurantrans@fr@dclxviii{Alors ceux qui croient en Allah et qui s'attachent à Lui, Il les fera entrer dans une miséricorde venue de Lui, et dans une grâce aussi. Et Il les guidera vers Lui dans un chemin droit.\qt@no{(175)}}
\qt@newcmd\qurantrans@fr@dclxix{Ils te demandent ce qui a été décrété. Dis: «Au sujet du défunt qui n'a pas de père ni de mère ni d'enfant, Allah vous donne Son décret: si quelqu'un meurt sans enfant, mais a une sœur, à celle-ci revient la moitié de ce qu'il laisse. Et lui, il héritera d'elle en totalité si elle n'a pas d'enfant. Mais s'il a deux sœurs (ou plus), à elles alors les deux tiers de ce qu'il laisse; et s'il a des frères et des sœurs, à un frère alors revient une portion égale à celle de deux sœurs. Allah vous donne des explications pour que vous ne vous égariez pas. Et Allah est Omniscient.\qt@no{(176)}}
\qt@newcmd\qurantrans@fr@dclxx{\basmalahfr O les croyants! Remplissez fidèlement vos engagements. Vous est permise la bête du cheptel, sauf ce qui sera énoncé [comme étant interdit]. Ne vous permettez point la chasse alors que vous êtes en état d'ihrâm. Allah en vérité, décide ce qu'Il veut.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@dclxxi{O les croyants! Ne profanez ni les rites du pèlerinage (dans les endroits sacrés) d'Allah, ni le mois sacré, ni les animaux de sacrifice, ni les guirlandes, ni ceux qui se dirigent vers la Maison sacrée cherchant de leur Seigneur grâce et agrément. Une fois désacralisés, vous êtes libres de chasser. Et ne laissez pas la haine pour un peuple qui vous a obstrué la route vers la Mosquée sacrée vous inciter à transgresser. Entraidez-vous dans l'accomplissement des bonnes œuvres et de la piété et ne vous entraidez pas dans le péché et la transgression. Et craignez Allah, car Allah est, certes, dur en punition!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@dclxxii{Vous sont interdits la bête trouvée morte, le sang, la chair de porc, ce sur quoi on a invoqué un autre nom que celui d'Allah, la bête étouffée, la bête assommée ou morte d'une chute ou morte d'un coup de corne, et celle qu'une bête féroce a dévorée - sauf celle que vous égorgez avant qu'elle ne soit morte -. (Vous sont interdits aussi la bête) qu'on a immolée sur les pierres dressées, ainsi que de procéder au partage par tirage au sort au moyen de flèches. Car cela est perversité. Aujourd'hui, les mécréants désespèrent (de vous détourner) de votre religion: ne les craignez donc pas et craignez-Moi. Aujourd'hui, J'ai parachevé pour vous votre religion, et accompli sur vous Mon bienfait. Et J'agrée l'Islam comme religion pour vous. Si quelqu'un est contraint par la faim, sans inclination vers le péché... alors, Allah est Pardonneur et Miséricordieux.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@dclxxiii{Ils t'interrogent sur ce qui leur est permis. Dis: «Vous sont permises les bonnes nourritures, ainsi que ce que capturent les carnassiers que vous avez dressés, en leur apprenant ce qu'Allah vous a appris. Mangez donc de ce qu'elles capturent pour vous et prononcez dessus le nom d'Allah. Et craignez Allah. Car Allah est, certes, prompt dans les comptes.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@dclxxiv{«Vous sont permises, aujourd'hui, les bonnes nourritures. Vous est permise la nourriture des gens du Livre, et votre propre nourriture leur est permise. (Vous sont permises) les femmes vertueuses d'entre les croyantes, et les femmes vertueuses d'entre les gens qui ont reçu le Livre avant vous, si vous leur donnez leur mahr avec contrat de mariage, non en débauchés ni en preneurs d'amantes. Et quiconque abjure la foi, alors vaine devient son action, et il sera dans l'au-delà, du nombre des perdants\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@dclxxv{O les croyants! Lorsque vous vous levez pour la Salât, lavez vos visages et vos mains jusqu'aux coudes; passez les mains mouillées sur vos têtes; et lavez-vous les pieds jusqu'aux chevilles. Et si vous êtes pollués «junub», alors purifiez-vous (par un bain); mais si vous êtes malades, ou en voyage, ou si l'un de vous revient du lieu où il a fait ses besoins ou si vous avez touché aux femmes et que vous ne trouviez pas d'eau, alors recourez à la terre pure, passez-en sur vos visages et vos mains. Allah ne veut pas vous imposer quelque gêne, mais Il veut vous purifier et parfaire sur vous Son bienfait. Peut-être serez-vous reconnaissants.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@dclxxvi{Et rappelez-vous le bienfait d'Allah sur vous, ainsi que l'alliance qu'Il a conclue avec vous, quand vous avez dit: «Nous avons entendu et nous avons obéi». Et craignez Allah. Car Allah connaît parfaitement le contenu des cœurs.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@dclxxvii{O les croyants! Soyez stricts (dans vos devoirs) envers Allah et (soyez) des témoins équitables. Et que la haine pour un peuple ne vous incite pas à être injustes. Pratiquez l'équité: cela est plus proche de la piété. Et craignez Allah. Car Allah est certes Parfaitement Connaisseur de ce que vous faites.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@dclxxviii{Allah a promis à ceux qui croient et font de bonnes œuvres qu'il y aura pour eux un pardon et une énorme récompense.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@dclxxix{Quant à ceux qui ne croient pas et traitent de mensonge Nos preuves, ceux-là sont des gens de l'Enfer.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@dclxxx{O les croyants! Rappelez-vous le bienfait d'Allah à votre égard, le jour où un groupe d'ennemis s'apprêtait à porter la main sur vous (en vue de vous attaquer) et qu'Il repoussa leur tentative. Et craignez Allah. C'est en Allah que les croyants doivent mettre leur confiance.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@dclxxxi{Et Allah certes prit l'engagement des enfants d'Israël. Nous nommâmes douze chefs d'entre eux. Et Allah dit: «Je suis avec vous, pourvu que vous accomplissiez la Salât, acquittiez la Zakât, croyiez en Mes messagers, les aidiez et fassiez à Allah un bon prêt. Alors, certes, j'effacerai vos méfaits, et vous ferai entrer aux Jardins sous lesquels coulent les ruisseaux. Et quiconque parmi vous, après cela, mécroit, s'égare certes du droit chemin»!\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@dclxxxii{Et puis, à cause de leur violation de l'engagement, Nous les avons maudits et endurci leurs cœurs: ils détournent les paroles de leur sens et oublient une partie de ce qui leur a été rappelé. Tu ne cesseras de découvrir leur trahison, sauf d'un petit nombre d'entre eux. Pardonne-leur donc et oublie [leurs fautes]. Car Allah aime, certes, les bienfaisants.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@dclxxxiii{Et de ceux qui disent: «Nous sommes chrétiens», Nous avons pris leur engagement. Mais ils ont oublié une partie de ce qui leur a été rappelé. Nous avons donc suscité entre eux l'inimitié et la haine jusqu'au Jour de la Résurrection. Et Allah les informera de ce qu'ils faisaient.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@dclxxxiv{O gens du Livre! Notre Messager (Muhammad) vous est certes venu, vous exposant beaucoup de ce que vous cachiez du Livre, et passant sur bien d'autres choses! Une lumière et un Livre explicite vous sont certes venus d'Allah!\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@dclxxxv{Par ceci (le Coran), Allah guide aux chemins du salut ceux qui cherchent Son agrément. Et Il les fait sortir des ténèbres à la lumière par Sa grâce. Et Il les guide vers un chemin droit.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@dclxxxvi{Certes sont mécréants ceux qui disent: «Allah, c'est le Messie, fils de Marie!» - Dis: «Qui donc détient quelque chose d'Allah (pour L'empêcher), s'Il voulait faire périr le Messie, fils de Marie, ainsi que sa mère et tous ceux qui sont sur la terre?... A Allah seul appartient la royauté des cieux et de la terre et de ce qui se trouve entre les deux». Il crée ce qu'Il veut. Et Allah est Omnipotent.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@dclxxxvii{Les Juifs et les Chrétiens ont dit: «Nous sommes les fils d'Allah et Ses préférés.» Dis: «Pourquoi donc vous châtie-t-Il pour vos péchés?» En fait, vous êtes des êtres humains d'entre ceux qu'Il a créés. Il pardonne à qui Il veut et Il châtie qui Il veut. Et à Allah seul appartient la royauté des cieux et de la terre et de ce qui se trouve entre les deux. Et c'est vers Lui que sera la destination finale.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@dclxxxviii{O gens du Livre! Notre Messager (Muhammad) est venu pour vous éclairer après une interruption des messagers afin que vous ne disiez pas: «Il ne nous est venu ni annonciateur ni avertisseur». Voilà, certes, que vous est venu un annonciateur et un avertisseur. Et Allah est Omnipotent.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@dclxxxix{(Souvenez-vous) Lorsque Moïse dit à son peuple: «O, mon peuple! Rappelez-vous le bienfait d'Allah sur vous, lorsqu'Il a désigné parmi vous des prophètes. Et Il a fait de vous des rois. Et Il vous a donné ce qu'Il n'avait donné à nul autre aux mondes.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@dcxc{O mon peuple! Entrez dans la terre sainte qu'Allah vous a prescrite. Et ne revenez point sur vos pas [en refusant de combattre] car vous retourneriez perdants.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@dcxci{Ils dirent: «O Moïse, il y a là un peuple de géants. Jamais nous n'y entrerons jusqu'à ce qu'ils en sortent. S'ils en sortent, alors nous y entrerons».\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@dcxcii{Deux hommes d'entre ceux qui craignaient Allah et qui étaient comblés par Lui de bienfaits dirent: «Entrez chez eux par la porte; puis quand vous y serez entrés, vous serez sans doute les dominants. Et c'est en Allah qu'il faut avoir confiance, si vous êtes croyants».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@dcxciii{Ils dirent: «Moïse! Nous n'y entrerons jamais, aussi longtemps qu'ils y seront. Va donc, toi et ton Seigneur, et combattez tous deux. Nous restons là où nous sommes».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@dcxciv{Il dit: «Seigneur! Je n'ai de pouvoir, vraiment, que sur moi-même et sur mon frère: sépare-nous donc de ce peuple pervers».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@dcxcv{Il (Allah) dit: «Eh bien, ce pays leur sera interdit pendant quarante ans, durant lesquels ils erreront sur la terre. Ne te tourmente donc pas pour ce peuple pervers».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@dcxcvi{Et raconte-leur en toute vérité l'histoire des deux fils d'Adam. Les deux offrirent des sacrifices; celui de l'un fut accepté et celui de l'autre ne le fut pas. Celui-ci dit: «Je te tuerai sûrement». «Allah n'accepte, dit l'autre, que de la part des pieux».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@dcxcvii{Si tu étends vers moi ta main pour me tuer, moi, je n'étendrai pas vers toi ma main pour te tuer: car je crains Allah, le Seigneur de l'Univers.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@dcxcviii{Je veux que tu partes avec le péché de m'avoir tué et avec ton propre péché: alors tu seras du nombre des gens du Feu. Telle est la récompense des injustes.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@dcxcix{Son âme l'incita à tuer son frère. Il le tua donc et devint ainsi du nombre des perdants.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@dcc{Puis Allah envoya un corbeau qui se mit à gratter la terre pour lui montrer comment ensevelir le cadavre de son frère. Il dit: «Malheur à moi! Suis-je incapable d'être, comme ce corbeau, à même d'ensevelir le cadavre de mon frère?» Il devint alors du nombre de ceux que ronge le remords.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@dcci{C'est pourquoi Nous avons prescrit pour les Enfants d'Israël que quiconque tuerait une personne non coupable d'un meurtre ou d'une corruption sur la terre, c'est comme s'il avait tué tous les hommes. Et quiconque lui fait don de la vie, c'est comme s'il faisait don de la vie à tous les hommes. En effet Nos messagers sont venus à eux avec les preuves. Et puis voilà, qu'en dépit de cela, beaucoup d'entre eux se mettent à commettre des excès sur la terre.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@dccii{La récompense de ceux qui font la guerre contre Allah et Son messager, et qui s'efforcent de semer la corruption sur la terre, c'est qu'ils soient tués, ou crucifiés, ou que soient coupées leur main et leur jambe opposées, ou qu'ils soient expulsés du pays. Ce sera pour eux l'ignominie ici-bas; et dans l'au-delà, il y aura pour eux un énorme châtiment,\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@dcciii{excepté ceux qui se sont repentis avant de tomber en votre pouvoir: sachez qu'alors, Allah est Pardonneur et Miséricordieux.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@dcciv{O les croyants! Craignez Allah, cherchez le moyen de vous rapprocher de Lui et luttez pour Sa cause. Peut-être serez-vous de ceux qui réussissent!\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@dccv{Si les mécréants possédaient tout ce qui est sur la terre et autant encore, pour se racheter du châtiment du Jour de la Résurrection, on ne l'accepterait pas d'eux. Et pour eux il y aura un châtiment douloureux.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@dccvi{Ils voudront sortir du Feu, mais ils n'en sortiront point. Et ils auront un châtiment permanent.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@dccvii{Le voleur et la voleuse, à tous deux coupez la main, en punition de ce qu'ils se sont acquis, et comme châtiment de la part d'Allah. Allah est Puissant et Sage.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@dccviii{Mais quiconque se repent après son tort et se réforme, Allah accepte son repentir. Car, Allah est, certes, Pardonneur et Miséricordieux.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@dccix{Ne sais-tu pas qu'à Allah appartient la royauté des cieux et de la terre? Il châtie qui Il veut et pardonne à qui Il veut. Et Allah est Omnipotent.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@dccx{O Messager! Que ne t'affligent point ceux qui concourent en mécréance; parmi ceux qui ont dit: «Nous avons cru» avec leurs bouches sans que leurs cœurs aient jamais cru et parmi les Juifs qui aiment bien écouter le mensonge et écouter d'autres gens qui ne sont jamais venus à toi et qui déforment le sens des mots une fois bien établi. Ils disent: «Si vous avez reçu ceci, acceptez-le et si vous ne l'avez pas reçu, soyez méfiants». Celui qu'Allah veut éprouver, tu n'as pour lui aucune protection contre Allah. Voilà ceux dont Allah n'a point voulu purifier les cœurs. A eux, seront réservés, une ignominie ici-bas et un énorme châtiment dans l'au-delà.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@dccxi{Ils sont attentifs au mensonge et voraces de gains illicites. S'ils viennent à toi, sois juge entre eux ou détourne toi d'eux. Et si tu te détournes d'eux, jamais ils ne pourront te faire aucun mal. Et si tu juges, alors juge entre eux en équité. Car Allah aime ceux qui jugent équitablement.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@dccxii{Mais comment te demanderaient-ils d'être leur juge quand ils ont avec eux la Thora dans laquelle se trouve le jugement d'Allah? Et puis, après cela, ils rejettent ton jugement. Ces gens-là ne sont nullement les croyants.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@dccxiii{Nous avons fait descendre la Thora dans laquelle il y a guide et lumière. C'est sur sa base que les prophètes qui se sont soumis à Allah, ainsi que les rabbins et les docteurs jugent les affaires des Juifs. Car on leur a confié la garde du Livre d'Allah, et ils en sont les témoins. Ne craignez donc pas les gens, mais craignez Moi. Et ne vendez pas Mes enseignements à vil prix. Et ceux qui ne jugent pas d'après ce qu'Allah a fait descendre, les voilà les mécréants.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@dccxiv{Et Nous y avons prescrit pour eux vie pour vie, œil pour œil, nez pour nez, oreille pour oreille, dent pour dent. Les blessures tombent sous la loi du talion. Après, quiconque y renonce par charité, cela lui vaudra une expiation. Et ceux qui ne jugent pas d'après ce qu'Allah a fait descendre, ceux-là sont des injustes.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@dccxv{Et Nous avons envoyé après eux Jésus, fils de Marie, pour confirmer ce qu'il y avait dans la Thora avant lui. Et Nous lui avons donné l'Evangile, où il y a guide et lumière, pour confirmer ce qu'il y avait dans la Thora avant lui, et un guide et une exhortation pour les pieux.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@dccxvi{Que les gens de l'Evangile jugent d'après ce qu'Allah y a fait descendre. Ceux qui ne jugent pas d'après ce qu'Allah a fait descendre, ceux-là sont les pervers.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@dccxvii{Et sur toi (Muhammad) Nous avons fait descendre le Livre avec la vérité, pour confirmer le Livre qui était là avant lui et pour prévaloir sur lui. Juge donc parmi eux d'après ce qu'Allah a fait descendre. Ne suis pas leurs passions, loin de la vérité qui t'est venue. A chacun de vous Nous avons assigné une législation et un plan à suivre. Si Allah avait voulu, certes Il aurait fait de vous tous une seule communauté. Mais Il veut vous éprouver en ce qu'Il vous donne. Concurrencez donc dans les bonnes cœvres. C'est vers Allah qu'est votre retour à tous; alors Il vous informera de ce en quoi vous divergiez.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@dccxviii{Juge alors parmi eux d'après ce qu'Allah a fait descendre. Ne suis pas leurs passions, et prends garde qu'ils ne tentent de t'éloigner d'une partie de ce qu'Allah t'a révélé. Et puis, s'ils refusent (le jugement révélé) sache qu'Allah veut les affliger [ici-bas] pour une partie de leurs péchés. Beaucoup de gens, certes, sont des pervers.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@dccxix{Est-ce donc le jugement du temps de l'Ignorance qu'ils cherchent? Qu'y a-t-il de meilleur qu'Allah, en matière de jugement pour des gens qui ont une foi ferme?\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@dccxx{O les croyants! Ne prenez pas pour alliés les Juifs et les Chrétiens; ils sont alliés les uns des autres. Et celui d'entre vous qui les prend pour alliés, devient un des leurs. Allah ne guide certes pas les gens injustes.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@dccxxi{Tu verras, d'ailleurs, que ceux qui ont la maladie au cœur se précipitent vers eux et disent: «Nous craignons qu'un revers de fortune ne nous frappe.» Mais peut-être qu'Allah fera venir la victoire ou un ordre émanant de Lui. Alors ceux-là regretteront leurs pensées secrètes.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@dccxxii{Et les croyants diront: «Est-ce là ceux qui juraient par Allah de toute leur force qu'ils étaient avec vous?» Mais leurs actions sont devenues vaines et ils sont devenus perdants.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@dccxxiii{O les croyants! Quiconque parmi vous apostasie de sa religion... Allah va faire venir un peuple qu'Il aime et qui L'aime, modeste envers les croyants et fier et puissant envers les mécréants, qui lutte dans le sentier d'Allah, ne craignant le blâme d'aucun blâmeur. Telle est la grâce d'Allah. Il la donne à qui Il veut. Allah est Immense et Omniscient.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@dccxxiv{Vous n'avez d'autres alliés qu'Allah, Son messager, et les croyants qui accomplissent la Salât, s'acquittent de la Zakât, et s'inclinent (devant Allah).\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@dccxxv{Et quiconque prend pour alliés Allah, Son messager et les croyants, [réussira] car c'est le parti d'Allah qui sera victorieux.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@dccxxvi{O les croyants! N'adoptez pas pour alliés ceux qui prennent en raillerie et jeu votre religion, parmi ceux à qui le Livre fut donné avant vous et parmi les mécréants. Et craignez Allah si vous êtes croyants.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@dccxxvii{Et lorsque vous faites l'appel à la Salât, ils la prennent en raillerie et jeu. C'est qu'ils sont des gens qui ne raisonnent point.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@dccxxviii{Dis: «O gens du Livre! Est-ce que vous nous reprochez autre chose que de croire en Allah, à ce qu'on a fait descendre vers nous et à ce qu'on a fait descendre auparavant? Mais la plupart d'entre vous sont des pervers.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@dccxxix{Dis: «Puis-je vous informer de ce qu'il y a de pire, en fait de rétribution auprès d'Allah? Celui qu'Allah a maudit, celui qui a encouru Sa colère, et ceux dont Il a fait des singes, des porcs, et de même, celui qui a adoré le Tâghût, ceux-là ont la pire des places et sont les plus égarés du chemin droit».\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@dccxxx{Lorsqu'ils viennent chez vous, ils disent: «Nous croyons.» Alors qu'ils sont entrés avec la mécréance et qu'ils sont sortis avec. Et Allah sait parfaitement ce qu'ils cachent.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@dccxxxi{Et tu verras beaucoup d'entre eux se précipiter vers le péché et l'iniquité, et manger des gains illicites. Comme est donc mauvais ce qu'ils œuvrent!\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@dccxxxii{Pourquoi les rabbins et les docteurs (de la Loi religieuse) ne les empêchent-ils pas de tenir des propos mensongers et de manger des gains illicites? Que leurs actions sont donc mauvaises!\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@dccxxxiii{Et les Juifs disent: «La main d'Allah est fermée!» Que leurs propres mains soient fermées, et maudits soient-ils pour l'avoir dit. Au contraire, Ses deux mains sont largement ouvertes: Il distribue Ses dons comme Il veut. Et certes, ce qui a été descendu vers toi de la part de ton Seigneur va faire beaucoup croître parmi eux la rébellion et la mécréance. Nous avons jeté parmi eux l'inimitié et la haine jusqu'au Jour de la Résurrection. Toutes les fois qu'ils allument un feu pour la guerre, Allah l'éteint. Et ils s'efforcent de semer le désordre sur la terre, alors qu'Allah n'aime pas les semeurs de désordre.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@dccxxxiv{Si les gens du Livre avaient la foi et la piété, Nous leur aurions certainement effacé leurs méfaits et les aurions certainement introduits dans les Jardins du délice.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@dccxxxv{S'ils avaient appliqué la Thora et l'Evangile et ce qui est descendu sur eux de la part de leur Seigneur, ils auraient certainement joui de ce qui est au-dessus d'eux et de ce qui est sous leurs pieds. Il y a parmi eux un groupe qui agit avec droiture; mais pour beaucoup d'entre eux, comme est mauvais ce qu'ils font!\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@dccxxxvi{O Messager, transmets ce qui t'a été descendu de la part de ton Seigneur. Si tu ne le faisais pas, alors tu n'aurais pas communiqué Son message. Et Allah te protègera des gens. Certes, Allah ne guide pas les gens mécréants.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@dccxxxvii{Dis: «O gens du Livre, vous ne tenez sur rien, tant que vous ne vous conformez pas à la Thora et à l'Evangile et à ce qui vous a été descendu de la part de votre Seigneur.» Et certes, ce qui t'a été descendu de la part de ton Seigneur va accroître beaucoup d'entre eux en rébellion et en mécréance. Ne te tourmente donc pas pour les gens mécréants.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@dccxxxviii{Ceux qui ont cru, ceux qui se sont judaïsés, les Sabéens, et les Chrétiens, ceux parmi eux qui croient en Allah, au Jour dernier et qui accomplissent les bonnes œuvres, pas de crainte sur eux, et ils ne seront point affligés.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@dccxxxix{Certes, Nous avions déjà pris l'engagement des Enfants d'Israël, et Nous leur avions envoyé des messagers. Mais chaque fois qu'un Messager leur vient avec ce qu'ils ne désirent pas, ils en traitent certains de menteurs et ils en tuent d'autres.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@dccxl{Comptant qu'il n'y aurait pas de tentation contre eux, ils étaient devenus aveugles et sourds. Puis Allah accueillit leur repentir. Ensuite, beaucoup d'entre eux redevinrent aveugles et sourds. Et Allah voit parfaitement ce qu'ils font.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@dccxli{Ce sont, certes, des mécréants ceux qui disent: «En vérité, Allah c'est le Messie, fils de Marie.» Alors que le Messie a dit: «O enfants d'Israël, adorez Allah, mon Seigneur et votre Seigneur». Quiconque associe à Allah (d'autres divinités,) Allah lui interdit le Paradis; et son refuge sera le Feu. Et pour les injustes, pas de secoureurs!\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@dccxlii{Ce sont certes des mécréants, ceux qui disent: «En vérité, Allah est le troisième de trois.» Alors qu'il n'y a de divinité qu'Une Divinité Unique! Et s'ils ne cessent de le dire, certes, un châtiment douloureux touchera les mécréants d'entre eux.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@dccxliii{Ne vont-ils donc pas se repentir à Allah et implorer Son pardon? Car Allah est Pardonneur et Miséricordieux.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@dccxliv{Le Messie, fils de Marie, n'était qu'un Messager. Des messagers sont passés avant lui. Et sa mère était une véridique. Et tous deux consommaient de la nourriture. Vois comme Nous leur expliquons les preuves et puis vois comme ils se détournent.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@dccxlv{Dis: «Adorez-vous, au lieu d'Allah, ce qui n'a le pouvoir de vous faire ni le mal ni le bien?» Or c'est Allah qui est l'Audient et l'Omniscient.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@dccxlvi{Dis: «O gens du Livre, n'exagérez pas en votre religion, s'opposant à la vérité. Ne suivez pas les passions des gens qui se sont égarés avant cela, qui ont égaré beaucoup de monde et qui se sont égarés du chemin droit.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@dccxlvii{Ceux des Enfants d'Israël qui n'avaient pas cru ont été maudits par la bouche de David et de Jésus fils de Marie, parce qu'ils désobéissaient et transgressaient.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@dccxlviii{Ils ne s'interdisaient pas les uns aux autres ce qu'ils faisaient de blâmable. Comme est mauvais, certes, ce qu'ils faisaient!\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@dccxlix{Tu vois beaucoup d'entre eux s'allier aux mécréants. Comme est mauvais, certes, ce que leurs âmes ont préparé, pour eux-mêmes, de sorte qu'ils ont encouru le courroux d'Allah, et c'est dans le supplice qu'ils éterniseront.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@dccl{S'ils croyaient en Allah, au Prophète et à ce qui lui a été descendu, ils ne prendraient pas ces mécréants pour alliés. Mais beaucoup d'entre eux sont pervers.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@dccli{Tu trouveras certainement que les Juifs et les associateurs sont les ennemis les plus acharnés des croyants. Et tu trouveras certes que les plus disposés à aimer les croyants sont ceux qui disent: «Nous sommes chrétiens». C'est qu'il y a parmi eux des prêtres et des moines, et qu'ils ne s'enflent pas d'orgueil.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@dcclii{Et quand ils entendent ce qui a été descendu sur le Messager [Muhammad], tu vois leurs yeux déborder de larmes, parce qu'ils ont reconnu la vérité. Ils disent: «O notre Seigneur! Nous croyons: inscris-nous donc parmi ceux qui témoignent (de la véracité du Coran).\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@dccliii{Pourquoi ne croirions-nous pas en Allah et à ce qui nous est parvenu de la vérité. Pourquoi ne convoitions-nous pas que notre Seigneur nous fasse entrer en la compagnie des gens vertueux?»\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@dccliv{Allah donc les récompense pour ce qu'ils disent par des Jardins sous lesquels coulent les ruisseaux, où ils demeureront éternellement. Telle est la récompense des bienfaisants.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@dcclv{Et quant à ceux qui ne croient pas et qui traitent de mensonges Nos versets, ce sont les gens de la Fournaise.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@dcclvi{O les croyants: ne déclarez pas illicites les bonnes choses qu'Allah vous a rendues licites. Et ne transgressez pas. Allah, (en vérité,) n'aime pas les transgresseurs.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@dcclvii{Et mangez de ce qu'Allah vous a attribué de licite et de bon. Craignez Allah, en qui vous avez foi.\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@dcclviii{Allah ne vous sanctionne pas pour la frivolité dans vos serments, mais Il vous sanctionne pour les serments que vous avez l'intention d'exécuter. L'expiation en sera de nourrir dix pauvres, de ce dont vous nourrissez normalement vos familles, ou de les habiller, ou de libérer un esclave. Quiconque n'en trouve pas les moyens devra jeûner trois jours. Voilà l'expiation pour vos serments, lorsque vous avez juré. Et tenez à vos serments. Ainsi Allah vous explique Ses versets, afin que vous soyez reconnaissants!\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@dcclix{O les croyants! Le vin, le jeu de hasard, les pierres dressées, les flèches de divination ne sont qu'une abomination, œuvre du Diable. Ecartez-vous en, afin que vous réussissiez.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@dcclx{Le Diable ne veut que jeter parmi vous, à travers le vin et le jeu de hasard, l'inimitié et la haine, et vous détourner d'invoquer Allah et de la Salât. Allez-vous donc y mettre fin?\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@dcclxi{Obéissez à Allah, obéissez au Messager, et prenez garde! Si ensuite vous vous détournez... alors sachez qu'il n'incombe à Notre messager que de transmettre le message clairement.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@dcclxii{Ce n'est pas un péché pour ceux qui ont la foi et font de bonnes œuvres en ce qu'ils ont consommé (du vin et des gains des jeux de hasard avant leur prohibition) pourvu qu'ils soient pieux (en évitant les choses interdites après en avoir eu connaissance) et qu'ils croient (en acceptant leur prohibition) et qu'ils fassent de bonnes œuvres; puis qui (continuent) d'être pieux et de croire et qui (demeurent) pieux et bienfaisants. Car Allah aime les bienfaisants.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@dcclxiii{O les croyants! Allah va certainement vous éprouver par quelque gibier à la portée de vos mains et de vos lances. C'est pour qu'Allah sache celui qui Le craint en secret. Quiconque après cela transgresse aura un châtiment douloureux.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@dcclxiv{O les croyants! Ne tuez pas de gibier pendant que vous êtes en état d'Ihram. Quiconque parmi vous en tue délibérément, qu'il compense alors, soit par quelque bête de troupeau, semblable à ce qu'il a tué, d'après le jugement de deux personnes intègres parmi vous, et cela en offrande qu'il fera parvenir à (destination des pauvres de) la Ka'aba, ou bien par une expiation, en nourrissant des pauvres, ou par l'équivalent en jeûne. Cela afin qu'il goûte à la mauvaise conséquence de son acte. Allah a pardonné ce qui est passé; mais quiconque récidive, Allah le punira. Allah est Puissant et Détenteur du pouvoir de punir.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@dcclxv{La chasse en mer vous est permise, et aussi d'en manger, pour votre jouissance et celle des voyageurs. Et vous est illicite la chasse à terre tant que vous êtes en état d'Ihram. Et craignez Allah vers qui vous serez rassemblés.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@dcclxvi{Allah a institué la Ka'aba, la Maison sacrée, comme un lieu de rassemblement pour les gens. (Il a institué) le mois sacré, l'offrande (d'animaux,) et les guirlandes, afin que vous sachiez que vraiment Allah sait tout ce qui est dans les cieux et sur la terre; et que vraiment Allah est Omniscient.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@dcclxvii{Sachez qu'Allah est sévère en punition, mais aussi qu'Allah est Pardonneur et Miséricordieux.\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@dcclxviii{Il n'incombe au Messager que de transmettre (le message). Et Allah sait ce que vous divulguez tout comme ce que vous cachez.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@dcclxix{Dis: «Le mauvais et le bon ne sont pas semblables, même si l'abondance du mal te séduit. Craignez Allah, donc, ô gens intelligents, afin que vous réussissiez.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@dcclxx{O les croyants! Ne posez pas de questions sur des choses qui, si elles vous étaient divulguées, vous mécontenteraient. Et si vous posez des questions à leur sujet, pendant que le Coran est révélé, elles vous seront divulguées. Allah vous a pardonné cela. Et Allah est Pardonneur et Indulgent.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@dcclxxi{Un peuple avant vous avait posé des questions (pareilles) puis, devinrent de leur fait mécréants.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@dcclxxii{Allah n'a pas institué la Bahira, la Sâïba, la Wasîlani le Hâm. Mais ceux qui ont mécru ont inventé ce mensonge contre Allah, et la plupart d'entre eux ne raisonnent pas.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@dcclxxiii{Et quand on leur dit: «Venez vers ce qu'Allah a fait descendre (la Révélation), et vers le Messager», ils disent: «Il nous suffit de ce sur quoi nous avons trouvé nos ancêtres.» Quoi! Même si leurs ancêtres ne savaient rien et n'étaient pas sur le bon chemin...?\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@dcclxxiv{O les croyants! Vous êtes responsables de vous-mêmes! Celui qui s'égare ne vous nuira point si vous vous avez pris la bonne voie. C'est Vers Allah que vous retournerez tous; alors Il vous informera de ce que vous faisiez.\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@dcclxxv{O les croyants! Quand la mort se présente à l'un de vous, le testament sera attesté par deux hommes intègres d'entre vous, ou deux autres, non des vôtres, si vous êtes en voyage dans le monde et que la mort vous frappe. Vous les retiendrez (les deux témoins), après la Sal?t, puis, si vous avez des doutes, vous les ferez jurer par Allah: «Nous ne faisons aucun commerce ou profit avec cela, même s'il s'agit d'un proche, et nous ne cacherons point le témoignage d'Allah. Sinon, nous serions du nombre des pécheurs».\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@dcclxxvi{Si l'on découvre que ces deux témoins sont coupables de péché, deux autres plus intègres, parmi ceux auxquels le tort a été fait, prendront leur place et tous deux jureront par Allah: «En vérité, notre témoignage est plus juste que le témoignage de ces deux-là; et nous ne transgressons point. Sinon, nous serions certainement du nombre des injustes».\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@dcclxxvii{C'est le moyen le plus sûr pour les inciter à fournir le témoignage dans sa forme réelle; ou leur faire craindre de voir d'autres serments se substituer aux leurs. Et craignez Allah et écoutez. Allah ne guide pas les gens pervers.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@dcclxxviii{(Rappelle-toi) le jour où Allah rassemblera (tous) les messagers, et qu'Il dira: «Que vous a-t-on donné comme réponse?» Ils diront: «Nous n'avons aucun savoir: c'est Toi, vraiment, le grand connaisseur de tout ce qui est inconnu».\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@dcclxxix{Et quand Allah dira: «O Jésus, fils de Marie, rappelle-toi Mon bienfait sur toi et sur ta mère quand Je te fortifiais du Saint-Esprit. Au berceau tu parlais aux gens, tout comme en ton âge mûr. Je t'enseignais le Livre, la Sagesse, la Thora et l'Evangile! Tu fabriquais de l'argile comme une forme d'oiseau par Ma permission; puis tu soufflais dedans. Alors par Ma permission, elle devenait oiseau. Et tu guérissais par Ma permission, l'aveugle-né et le lépreux. Et par Ma permission, tu faisais revivre les morts. Je te protégeais contre les Enfants d'Israël pendant que tu leur apportais les preuves. Mais ceux d'entre eux qui ne croyaient pas dirent: «Ceci n'est que de la magie évidente».\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@dcclxxx{Et quand J'ai révélé aux Apôtres ceci: «Croyez en Moi et en Mon messager (Jésus)». Ils dirent: «Nous croyons; et atteste que nous sommes entièrement soumis».\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@dcclxxxi{Rappelle-toi le moment) où les Apôtres dirent: «O Jésus, fils de Marie, se peut-il que ton Seigneur fasse descendre sur nous du ciel une table servie?» Il leur dit: «Craignez plutôt Allah, si vous êtes croyants».\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@dcclxxxii{Ils dirent: «Nous voulons en manger, rassurer ainsi nos cœurs, savoir que tu nous as réellement dit la vérité et en être parmi les témoins».\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@dcclxxxiii{«O Allah, notre Seigneur, dit Jésus, fils de Marie, fais descendre du ciel sur nous une table servie qui soit une fête pour nous, pour le premier d'entre nous, comme pour le dernier, ainsi qu'un signe de Ta part. Nourris-nous: Tu es le meilleur des nourrisseurs.»\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@dcclxxxiv{«Oui, dit Allah, Je la ferai descendre sur vous. Mais ensuite, quiconque d'entre vous refuse de croire, Je le châtierai d'un châtiment dont Je ne châtierai personne d'autre dans l'univers.»\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@dcclxxxv{(Rappelle-leur) le moment où Allah dira: «O Jésus, fils de Marie, est-ce toi qui as dit aux gens: «Prenez-moi, ainsi que ma mère, pour deux divinités en dehors d'Allah?» Il dira: «Gloire et pureté à Toi! Il ne m'appartient pas de déclarer ce que je n'ai pas le droit de dire! Si je l'avais dit, Tu l'aurais su, certes. Tu sais ce qu'il y a en moi, et je ne sais pas ce qu'il y a en Toi. Tu es, en vérité, le grand connaisseur de tout ce qui est inconnu.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@dcclxxxvi{Je ne leur ai dit que ce que Tu m'avais commandé, (à savoir): «Adorez Allah, mon Seigneur et votre Seigneur». Et je fus témoin contre eux aussi longtemps que je fus parmi eux. Puis quand Tu m'as rappelé, c'est Toi qui fus leur observateur attentif. Et Tu es témoin de toute chose.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@dcclxxxvii{Si Tu les châties, ils sont Tes serviteurs. Et si Tu leur pardonnes, c'est Toi le Puissant, le Sage».\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@dcclxxxviii{Allah dira: «Voilà le jour où leur véracité va profiter aux véridiques: ils auront des Jardins sous lesquels coulent les ruisseaux pour y demeurer éternellement.» Allah les a agréés et eux L'ont agréé. Voilà l'énorme succès.\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@dcclxxxix{A Allah seul appartient le royaume des cieux, de la terre et de ce qu'ils renferment. Et Il est Omnipotent.\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@dccxc{\basmalahfr Louange à Allah qui a créé les cieux et la terre, et établi les ténèbres et la lumière. Pourtant, les mécréants donnent des égaux à leur Seigneur.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@dccxci{C'est Lui qui vous a créés d'argile; puis il vous a décrété un terme, et il y a un terme fixé auprès de Lui. Pourtant, vous doutez encore!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@dccxcii{Et Lui, Il est Allah dans les cieux et sur la terre. Il connaît ce que vous cachez en vous et ce que vous divulguez et Il sait ce que vous acquérez.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@dccxciii{Et il ne leur vient aucun des signes d'entre les signes de leur Seigneur, sans qu'ils ne s'en détournent.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@dccxciv{Ils traitent de mensonge la vérité quand celle-ci leur vient. Mais ils vont avoir des nouvelles de ce dont ils se moquent.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@dccxcv{N'ont-ils pas vu combien de générations, avant eux, Nous avons détruites, auxquelles Nous avions donné pouvoir sur terre, bien plus que ce que Nous vous avons donnés? Nous avions envoyé, sur eux, du ciel, la pluie en abondance, et Nous avions fait couler des rivières à leurs pieds. Puis Nous les avons détruites, pour leurs péchés; et Nous avons créé après eux, une nouvelle génération.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@dccxcvi{Même si Nous avions fait descendre sur toi (Muhammad) un Livre en papier qu'ils pouvaient toucher de leurs mains, ceux qui ne croient pas auraient certainement dit: «Ce n'est que de la magie évidente!»\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@dccxcvii{Et ils disent: «Pourquoi n'a-t-on pas fait descendre sur lui (Muhammad) un Ange?» Si Nous avions fait descendre un Ange, c'eût été, sûrement, affaire faite; puis on ne leur eût point donné de délai.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@dccxcviii{Si Nous avions désigné un Ange [comme prophète], Nous aurions fait de lui un homme et Nous leur aurions causé la même confusion que celle dans laquelle ils sont.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@dccxcix{Certes, on s'est moqué de messagers avant toi, mais ceux qui se sont raillés d'eux, leur propre raillerie les enveloppa.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@dccc{Dis: «Parcourez la terre et regardez ce qu'il est advenu de ceux qui traitaient la vérité de mensonge».\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@dccci{Dis: «A qui appartient ce qui est dans les cieux et la terre?» Dis: «A Allah!» Il S'est à Lui-même prescrit la miséricorde. Il vous rassemblera, certainement, au Jour de la Résurrection: il n'y a pas de doute là-dessus. Ceux qui font leur propre perte sont ceux qui ne croient pas.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@dcccii{Et à Lui tout ce qui réside dans la nuit et le jour. C'est Lui qui est l'Audient, l'Omniscient.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@dccciii{Dis: «Devais-je prendre pour allié autre qu'Allah, le Créateur des cieux et de la terre? C'est Lui qui nourrit et personne ne Le nourrit. Dis: «On m'a commandé d'être le premier à me soumettre». Et ne sois jamais du nombre des associateurs.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@dccciv{Dis: «Je crains, si je désobéis à mon Seigneur, le châtiment d'un jour redoutable».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@dcccv{En ce jour, quiconque est épargné, c'est qu'[Allah] lui a fait miséricorde. Et voilà le succès éclatant.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@dcccvi{Et si Allah fait qu'un malheur te touche, nul autre que Lui ne peut l'enlever. Et s'Il fait qu'un bonheur te touche... c'est qu'Il est Omnipotent.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@dcccvii{C'est Lui le Dominateur Suprême sur Ses serviteurs; c'est Lui le Sage, le Parfaitement Connaisseur.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@dcccviii{Dis: «Qu'y a-t-il de plus grand en fait de témoignage?» Dis: «Allah est témoin entre moi et vous; et ce Coran m'a été révélé pour que je vous avertisse, par sa voie, vous et tous ceux qu'il atteindra. «Est-ce vous vraiment qui attestez qu'il y ait avec Allah d'autres divinités? Dis: «Je n'atteste pas». Dis [aussi]: «Il n'y a qu'une Divinité Unique. Et moi, je désavoue ce que vous (Lui) associez».\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@dcccix{Ceux à qui Nous avons donné le Livre reconnaissent (le Messager Muhammad) comme ils reconnaissent leurs propres enfants. Ceux qui font leur propre perte sont ceux qui ne croient pas.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@dcccx{Qui donc est plus injuste que celui qui invente un mensonge contre Allah, ou qui traite de mensonge Ses versets? Les injustes ne réussiront pas.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@dcccxi{Et le Jour où Nous les rassemblerons tous puis dirons à ceux qui auront donné des associés: «Où sont donc vos associés que vous prétendiez?»\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@dcccxii{Alors il ne leur restera comme excuse que de dire: «Par Allah notre Seigneur! Nous n'étions jamais des associateurs».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@dcccxiii{Vois comment ils mentent à eux-mêmes! Et comment les abandonnent (les associés) qu'ils inventaient!\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@dcccxiv{Il en est parmi eux qui viennent t'écouter, cependant que Nous avons entouré de voiles leurs cœurs, qui les empêchent de comprendre (le Coran), et dans leurs oreilles est une lourdeur. Quand même ils verraient toutes sortes de preuves, ils n'y croiraient pas. Et quand ils viennent disputer avec toi, ceux qui ne croient pas disent alors: «Ce ne sont que des légendes des anciens».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@dcccxv{Ils empêchent [les gens] de s'approcher de lui et s'en écartent eux-mêmes. Ils ne feront périr qu'eux-mêmes sans s'en rendre compte.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@dcccxvi{Si tu les voyais, quand ils seront placés devant le Feu. Ils diront alors: «Hélas! Si nous pouvions être renvoyés (sur la terre), nous ne traiterions plus de mensonges les versets de notre Seigneur et nous serions du nombre des croyants».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@dcccxvii{Mais non! Voilà que leur apparaîtra ce qu'auparavant ils cachaient. Or, s'ils étaient rendus [à la vie terrestre], ils reviendraient sûrement à ce qui leur était interdit. Ce sont vraiment des menteurs.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@dcccxviii{Et ils disent: «Il n'y a pour nous [d'autre vie] que celle d'ici-bas; et nous ne serons pas ressuscités».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@dcccxix{Si tu les voyais, quand ils comparaîtront devant leur Seigneur. Il leur dira: «Cela n'est-il pas la vérité?» Ils diront: «Mais si! Par notre Seigneur!» Et, il dira: «Goûtez alors au châtiment pour n'avoir pas cru».\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@dcccxx{Sont perdants certes ceux qui traitent de mensonge la rencontre d'Allah. Et quand soudain l'Heure leur viendra, ils diront: «Malheur à nous pour notre négligence à son égard, Et ils porteront leurs fardeaux sur leurs dos, et quels mauvais fardeaux!\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@dcccxxi{La présente vie n'est que jeu et amusement. La demeure dans l'au-delà sera meilleure pour ceux qui sont pieux. Eh bien, ne comprenez-vous pas?\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@dcccxxii{Nous savons qu'en vérité ce qu'ils disent te chagrine. Or, vraiment ils ne croient pas que tu es menteur, mais ce sont les versets (le Coran) d'Allah, que les injustes renient.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@dcccxxiii{Certes, des messagers avant toi (Muhammad) ont été traités de menteurs. Ils endurèrent alors avec constance d'être traités de menteurs et d'être persécutés, jusqu'à ce que Notre secours leur vînt. Et nul ne peut changer les paroles d'Allah, et il t'est déjà parvenu une partie de l'histoire des Envoyés.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@dcccxxiv{Et si leur indifférence t'afflige énormément, et qu'il est dans ton pouvoir de chercher un tunnel à travers la terre, ou une échelle pour aller au ciel pour leur apporter un miracle, [fais-le donc]. Et si Allah voulait, Il pourrait les mettre tous sur le chemin droit. Ne sois pas du nombre des ignorants.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@dcccxxv{Seuls ceux qui entendent répondent à l'appel [de la foi]. Et quant aux morts, Allah les ressuscitera; puis ils Lui seront ramenés.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@dcccxxvi{Et ils disent: «Pourquoi n'a-t-on pas fait descendre sur lui (Muhammad) un miracle de la part de son Seigneur?» Dis: «Certes Allah est capable de faire descendre un miracle. Mais la plupart d'entre eux ne savent pas».\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@dcccxxvii{Nulle bête marchant sur terre, nul oiseau volant de ses ailes, qui ne soit comme vous en communauté. Nous n'avons rien omis d'écrire dans le Livre. Puis, c'est vers leur Seigneur qu'ils seront ramenés.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@dcccxxviii{Et ceux qui traitent de mensonges Nos versets sont sourds et muets, dans les ténèbres. Allah égare qui Il veut; et Il place qui Il veut sur un chemin droit.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@dcccxxix{Dis: «Informez-moi: si le châtiment d'Allah vous vient, ou que vous vient l'Heure, ferez-vous appel à autre qu'Allah, si vous êtes véridiques?»\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@dcccxxx{C'est plutôt à Lui que vous ferez appel. Puis, Il dissipera, s'Il veut, l'objet de votre appel et vous oublierez ce que vous [Lui] associez.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@dcccxxxi{Nous avons, certes, envoyé (des messagers) aux communautés avant toi. Ensuite Nous les avons saisies par l'adversité et la détresse - peut-être imploreront-ils (la miséricorde)! -\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@dcccxxxii{Pourquoi donc, lorsque Notre rigueur leur vînt, n'ont-ils pas imploré (la miséricorde)? Mais leurs cœurs s'étaient endurcis et le Diable enjolivait à leurs yeux ce qu'ils faisaient.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@dcccxxxiii{Puis, lorsqu'ils eurent oublié ce qu'on leur avait rappelé, Nous leur ouvrîmes les portes donnant sur toute chose (l'abondance); et lorsqu'ils eurent exulté de joie en raison de ce qui leur avait été donné, Nous les saisîmes soudain, et les voilà désespérés.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@dcccxxxiv{Ainsi fut exterminé le dernier reste de ces injustes. Et louange à Allah, Seigneur de l'Univers!\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@dcccxxxv{Dis: «Voyez-vous? Si Allah prenait votre ouïe et votre vue, et scellait vos cœurs, quelle divinité autre qu'Allah vous les rendrait? Regarde comment, à leur intention, Nous clarifions les preuves! Pourtant ils s'en détournent.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@dcccxxxvi{Dis: «Que vous en semble? Si le châtiment d'Allah vous venait à l'improviste ou au grand jour, qui seront détruits sinon les gens injustes?»\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@dcccxxxvii{Nous n'envoyons des messagers qu'en annonciateurs et avertisseurs: ceux qui croient donc et se réforment, nulle crainte sur eux et ils ne seront point affligés.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@dcccxxxviii{Et ceux qui traitent de mensonges Nos preuves, le châtiment les touchera, à cause de leur perversité.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@dcccxxxix{Dis-[leur]: «Je ne vous dis pas que je détiens les trésors d'Allah, ni que je connais l'Inconnaissable, et je ne vous dis pas que je suis un ange. Je ne fais que suivre ce qui m'est révélé.» Dis: «Est-ce que sont égaux l'aveugle et celui qui voit? Ne réfléchissez-vous donc pas?»\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@dcccxl{Et avertis par ceci (le Coran), ceux qui craignent d'être rassemblés devant leur Seigneur, qu'ils n'auront hors d'Allah ni allié ni intercesseur. Peut-être deviendraient-ils pieux!\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@dcccxli{Et ne repousse pas ceux qui, matin et soir, implorent leur Seigneur, cherchant sa Face «Wajh». Leur demander compte ne t'incombe en rien, et te demander compte ne leur incombe en rien. En les repoussant donc, tu serais du nombre des injustes.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@dcccxlii{Ainsi, éprouvons-Nous (les gens) les uns par les autres, pour qu'ils disent: «Est-ce là ceux qu'Allah a favorisés parmi nous?» N'est-ce pas Allah qui sait le mieux lesquels sont reconnaissants?\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@dcccxliii{Et lorsque viennent vers toi ceux qui croient à nos versets (le Coran), dis: «Que la paix soit sur vous! Votre Seigneur S'est prescrit à Lui-même la miséricorde. Et quiconque d'entre vous a fait un mal par ignorance, et ensuite s'est repenti et s'est réformé... Il est, alors, Pardonneur et Miséricordieux».\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@dcccxliv{C'est ainsi que Nous détaillons les versets, afin qu'apparaisse clairement le chemin des criminels.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@dcccxlv{Dis: «il m'a été interdit d'adorer ceux que vous priez en dehors d'Allah». Dis: «Je ne suivrai pas vos passions: car ce serait m'égarer, et je ne serais plus parmi les bien-guidés».\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@dcccxlvi{Dis: «Je m'appuie sur une preuve évidente de la part de mon Seigneur, et vous avez traité cela de mensonge. Ce (le châtiment) que vous voulez hâter ne dépend pas de moi. Le jugement n'appartient qu'à Allah: Il tranche en toute vérité et Il est le meilleur des juges.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@dcccxlvii{Dis: «Si ce que vous voulez hâter dépendait de moi, ce serait affaire faite entre vous et moi.» C'est Allah qui connaît le mieux les injustes.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@dcccxlviii{C'est Lui qui détient les clefs de l'Inconnaissable. Nul autre que Lui ne les connaît. Et Il connaît ce qui est dans la terre ferme, comme dans la mer. Et pas une feuille ne tombe qu'Il ne le sache. Et pas une graine dans les ténèbres de la terre, rien de frais ou de sec, qui ne soit consigné dans un livre explicite.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@dcccxlix{Et, la nuit, c'est Lui qui prend vos âmes, et Il sait ce que vous avez acquis pendant le jour. Puis Il vous ressuscite le jour afin que s'accomplisse le terme fixé. Ensuite, c'est vers Lui que sera votre retour, et Il vous informera de ce que vous faisiez.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@dcccl{Et Il est le Dominateur Suprême sur Ses serviteurs. Et Il envoie sur vous des gardiens. Et lorsque la mort atteint l'un de vous, Nos messagers (les Anges) enlèvent son âme sans aucune négligence.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@dcccli{Ils sont ensuite ramenés vers Allah, leur vrai Maître. C'est à Lui qu'appartient le jugement et Il est le plus prompt des juges.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@dccclii{Dis: «Qui vous délivre des ténèbres de la terre et de la mer?» Vous l'invoquez humblement et en secret: «S'Il nous délivre de ceci, nous serons du nombre des reconnaissants.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@dcccliii{Dis: «C'est Allah qui vous en délivre ainsi que de toute angoisse. Pourtant, vous Lui donnez des associés».\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@dcccliv{Dis: «Il est capable, Lui, de susciter contre vous, d'en haut, ou de dessous vos pieds, un châtiment, ou de vous confondre dans le sectarisme. Et Il vous fait goûter l'ardeur [au combat] les uns aux autres.» Regarde comment Nous exposons Nos versets. Peut-être comprendront-ils?\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@dccclv{Et ton peuple traite cela (le Coran) de mensonge, alors que c'est la vérité. Dis: «Je ne suis pas votre garant.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@dccclvi{Chaque annonce arrive en son temps et en son lieu. Et bientôt vous le saurez.»\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@dccclvii{Quand tu vois ceux qui pataugent dans des discussions à propos de Nos versets, éloigne-toi d'eux jusqu'à ce qu'ils entament une autre discussion. Et si le Diable te fait oublier, alors, dès que tu te rappelles, ne reste pas avec les injustes.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@dccclviii{Il n'incombe nullement à ceux qui sont pieux de rendre compte pour ces gens là. Mais c'est à titre de rappel. Peut-être craindront-ils [Allah].\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@dccclix{Laisse ceux qui prennent leur religion pour jeu et amusement, et qui sont séduits par la vie sur terre. Et rappelle par ceci (le Coran) pour qu'une âme ne s'expose pas à sa perte selon ce qu'elle aura acquis, elle n'aura en dehors d'Allah, ni allié ni intercesseur. Et quelle que soit la compensation qu'elle offrirait, elle ne sera pas acceptée d'elle. Ceux-là se sont abandonnés à leur perdition à cause de ce qu'ils ont acquis. Leur breuvage sera l'eau bouillante et ils auront un châtiment douloureux, pour avoir mécru.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@dccclx{Dis: «Invoquerons-nous, au lieu d'Allah, ce qui ne peut nous profiter ni nous nuire? Et reviendrons-nous sur nos talons après qu'Allah nous a guidés, comme quelqu'un que les diables ont séduit et qui erre perplexe sur la terre, bien que des amis l'appellent vers le droit chemin (lui disant): - «Viens à nous». Dis: «Le vrai chemin, c'est le chemin d'Allah. Et il nous a été commandé de nous soumettre au Seigneur de l'Univers,\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@dccclxi{Et d'accomplir la Salât et de Le craindre. C'est vers Lui que vous serez rassemblés».\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@dccclxii{Et c'est Lui qui a créé les cieux et la terre, en toute vérité. Et le jour où Il dit: «Sois!» Cela est, Sa parole est la vérité. A Lui, [seul,] la royauté, le jour où l'on soufflera dans la Trompe. C'est Lui le Connaisseur de ce qui est voilé et de ce qui est manifeste. Et c'est Lui le Sage et le Parfaitement Connaisseur.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@dccclxiii{(Rappelle le moment) où Abraham dit à `Azar, son père: «Prends-tu des idoles comme divinités? Je te vois, toi et ton peuple, dans un égarement évident!»\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@dccclxiv{Ainsi avons-Nous montré à Abraham le royaume des cieux et de la terre, afin qu'il fût de ceux qui croient avec conviction.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@dccclxv{Quand la nuit l'enveloppa, il observa une étoile, et dit: «Voilà mon Seigneur!» Puis, lorsqu'elle disparut, il dit: «Je n'aime pas les choses qui disparaissent».\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@dccclxvi{Lorsqu'ensuite il observa la lune se levant, il dit: «Voilà mon Seigneur!» Puis, lorsqu'elle disparut, il dit: «Si mon Seigneur ne me guide pas, je serai certes du nombre des gens égarés».\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@dccclxvii{Lorsqu'ensuite il observa le soleil levant, il dit: «Voilà mon Seigneur! Celui-ci est plus grand» Puis lorsque le soleil disparut, il dit: «O mon peuple, je désavoue tout ce que vous associez à Allah.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@dccclxviii{Je tourne mon visage exclusivement vers Celui qui a créé (à partir du néant) les cieux et la terre; et je ne suis point de ceux qui Lui donnent des associés.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@dccclxix{Son peuple disputa avec lui; mais il dit: «Allez-vous disputer avec moi au sujet d'Allah, alors qu'Il m'a guidé? Je n'ai pas peur des associés que vous Lui donnez. Je ne crains que ce que veut mon Seigneur. Mon Seigneur embrasse tout dans Sa science. Ne vous rappelez-vous donc pas?\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@dccclxx{Et comment aurais-je peur des associés que vous Lui donnez, alors que vous n'avez pas eu peur d'associer à Allah des choses pour lesquelles Il ne vous a fait descendre aucune preuve? Lequel donc des deux partis a le plus droit à la sécurité? (Dites-le) si vous savez.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@dccclxxi{Ceux qui ont cru et n'ont point troublé la pureté de leur foi par quelqu'inéquité (association), ceux-là ont la sécurité; et ce sont eux les bien-guidés».\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@dccclxxii{Tel est l'argument que Nous inspirâmes à Abraham contre son peuple. Nous élevons en haut rang qui Nous voulons. Ton Seigneur est Sage et Omniscient.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@dccclxxiii{Et Nous lui avons donné Isaac et Jacob et Nous les avons guidés tous les deux. Et Noé, Nous l'avons guidé auparavant, et parmi la descendance (d'Abraham) (ou de Noé), David, Salomon, Job, Joseph, Moïse et Aaron. Et c'est ainsi que Nous récompensons les bienfaisants.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@dccclxxiv{De même, Zacharie, Jean-Baptiste, Jésus et Elie, tous étant du nombre des gens de bien.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@dccclxxv{De même, Ismaël, Elisée, Jonas et Lot. Chacun d'eux Nous l'avons favorisé par dessus le reste du monde.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@dccclxxvi{De même une partie de leurs ancêtres, de leurs descendants et de leurs frères et Nous les avons choisis et guidés vers un chemin droit.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@dccclxxvii{Telle est la direction par laquelle Allah guide qui Il veut parmi Ses serviteurs. Mais s'ils avaient donné à Allah des associés, alors, tout ce qu'ils auraient fait eût certainement été vain.\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@dccclxxviii{C'est à eux que Nous avons apporté le Livre, la sagesse et la prophétie. Si ces autres-là n'y croient pas, du moins Nous avons confié ces choses à des gens qui ne les nient pas.\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@dccclxxix{Voilà ceux qu'Allah a guidés: suis donc leur direction. Dis: «Je ne vous demande pas pour cela de salaire». Ce n'est qu'un rappel à l'intention de tout l'univers.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@dccclxxx{Ils n'apprécient pas Allah comme Il le mérite quand ils disent: «Allah n'a rien fait descendre sur un humain.» Dis: «Qui a fait descendre le Livre que Moïse a apporté comme lumière et guide, pour les gens? Vous le mettez en feuillets, pour en montrer une partie, tout en cachant beaucoup. Vous avez été instruits de ce que vous ne saviez pas, ni vous ni vos ancêtres. Dis: «C'est Allah». Et puis, laisse-les s'amuser dans leur égarement.\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@dccclxxxi{Voici un Livre (le Coran) béni que Nous avons fait descendre, confirmant ce qui existait déjà avant lui, afin que tu avertisses la Mère des Cités (la Mecque) et les gens tout autour. Ceux qui croient au Jour dernier, y croient et demeurent assidus dans leur Salât.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@dccclxxxii{Et quel pire injuste que celui qui fabrique un mensonge contre Allah ou qui dit: «Révélation m'a été faite», quand rien ne lui a été révélé. De même celui qui dit: «Je vais faire descendre quelque chose de semblable à ce qu'Allah a fait descendre.» Si tu voyais les injustes lorsqu'ils seront dans les affres de la mort, et que les Anges leur tendront les mains (disant): «Laissez sortir vos âmes. Aujourd'hui vous allez être récompensés par le châtiment de l'humiliation pour ce que vous disiez sur Allah d'autre que la vérité et parce que vous vous détourniez orgueilleusement de Ses enseignements».\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@dccclxxxiii{Et vous voici venus à Nous, seuls, tout comme Nous vous avions créés la première fois, abandonnant derrière vos dos tout ce que Nous vous avions accordé. Nous ne vous voyons point accompagnés des intercesseurs que vous prétendiez être des associés. Il y a certainement eu rupture entre vous: ils vous ont abandonnés, ceux que vous prétendiez (être vos intercesseurs).\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@dccclxxxiv{C'est Allah qui fait fendre la graine et le noyau: du mort il fait sortir le vivant, et du vivant, il fait sortir le mort. Tel est Allah. Comment donc vous laissez-vous détourner?\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@dccclxxxv{Fendeur de l'aube, Il a fait de la nuit une phase de repos; le soleil et la lune pour mesurer le temps. Voilà l'ordre conçu par le Puissant, l'Omniscient.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@dccclxxxvi{Et c'est Lui qui vous a assigné les étoiles, pour que, par elles, vous vous guidiez dans les ténèbres de la terre et de la mer. Certes, Nous exposons les preuves pour ceux qui savent!\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@dccclxxxvii{Et c'est Lui qui vous a créés à partir d'une personne unique (Adam). Et il y a une demeure et un lieu de dépôt (pour vous.) Nous avons exposé les preuves pour ceux qui comprennent.\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@dccclxxxviii{Et c'est Lui qui, du ciel, a fait descendre l'eau. Puis par elle, Nous fîmes germer toute plante, de quoi Nous fîmes sortir une verdure, d'où Nous produisîmes des grains, superposés les uns sur les autres; et du palmier, de sa spathe, des régimes de dattes qui se tendent. Et aussi les jardins de raisins, l'olive et la grenade, semblables ou différents les uns des autres. Regardez leurs fruits au moment de leur production et de leur mûrissement. Voilà bien là des signes pour ceux qui ont la foi.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@dccclxxxix{Et ils ont désigné des associés à Allah: les djinns, alors que c'est Lui qui les a créés. Et ils Lui ont inventé, dans leur ignorance, des fils et des filles, Gloire à Lui! Il transcende tout ce qu'ils lui attribuent.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@dcccxc{Créateur des cieux et de la terre. Comment aurait-Il un enfant, quand Il n'a pas de compagne? C'est Lui qui a tout créé, et Il est Omniscient.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@dcccxci{Voilà Allah, votre Seigneur! Il n'y a de divinité que Lui, Créateur de tout. Adorez-Le donc. C'est Lui qui a charge de tout.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@dcccxcii{Les regards ne peuvent l'atteindre, cependant qu'Il saisit tous les regards. Et Il est le Doux, le Parfaitement Connaisseur.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@dcccxciii{Certes, il vous est parvenu des preuves évidentes, de la part de votre Seigneur. Donc, quiconque voit clair, c'est en sa faveur; et quiconque reste aveugle, c'est à son détriment, car je ne suis nullement chargé de votre sauvegarde.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@dcccxciv{C'est ainsi que Nous expliquons les versets. Et afin qu'ils disent: «Tu as étudié». Et afin de l'exposer clairement à des gens qui savent.\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@dcccxcv{Suis ce qui t'est révélé de la part de ton Seigneur. Point de divinité autre que Lui. Et écarte-toi des associateurs.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@dcccxcvi{Si Allah voulait, ils ne seraient point associateurs! Mais Nous ne t'avons pas désigné comme gardien sur eux; et tu n'es pas leur garant.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@dcccxcvii{N'injuriez pas ceux qu'ils invoquent, en dehors d'Allah, car par agressivité, ils injurieraient Allah, dans leur ignorance. De même, Nous avons enjolivé (aux yeux) de chaque communauté sa propre action. Ensuite, c'est vers leur Seigneur que sera leur retour; et Il les informera de ce qu'ils œuvraient.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@dcccxcviii{Et ils jurent par Allah de toute la force de leurs serments, que s'il leur venait un miracle, ils y croiraient (sans hésiter,) Dis: «En vérité, les miracles ne dépendent que d'Allah.» Mais qu'est ce qui vous fait penser que quand cela (le signe) arrivera, ils n'y croiront pas?\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@dcccxcix{Parce qu'ils n'ont pas cru la première fois, nous détournerons leurs cœurs et leurs yeux; nous les laisserons marcher aveuglement dans leur rébellion.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@cm{Et si Nous faisions descendre les Anges vers eux, [comme ils l'avaient proposé] si les morts leur parlaient, et si Nous rassemblions toute chose devant eux, ils ne croiraient que si Allah veut. Mais la plupart d'entre eux ignorent.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@cmi{Ainsi, à chaque prophète avons-Nous assigné un ennemi: des diables d'entre les hommes et les djinns, qui s'inspirent trompeusement les uns aux autres des paroles enjolivées. Si ton Seigneur avait voulu, ils ne l'auraient pas fait; laisse-les donc avec ce qu'ils inventent.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@cmii{Et pour que les cœurs de ceux qui ne croient pas à l'au-delà se penchent vers elles, qu'ils les agréent, et qu'ils perpètrent ce qu'ils perpètrent.\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@cmiii{Chercherai-je un autre juge qu'Allah, alors que c'est Lui qui a fait descendre vers vous ce Livre bien exposé? Ceux auxquels Nous avons donné le Livre savent qu'il est descendu avec la vérité venant de ton Seigneur. Ne sois donc point du nombre de ceux qui doutent.\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@cmiv{Et la parole de ton Seigneur s'est accomplie en toute vérité et équité. Nul ne peut modifier Ses paroles. Il est l'Audient, l'Omniscient.\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@cmv{Et si tu obéis à la majorité de ceux qui sont sur la terre, ils t'égareront du sentier d'Allah: ils ne suivent que la conjecture et ne font que fabriquer des mensonges.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@cmvi{Certes ton Seigneur connaît le mieux ceux qui s'égarent de Son sentier, et c'est Lui qui connaît le mieux les bien-guidés.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@cmvii{Mangez donc de ce sur quoi on a prononcé le nom d'Allah si vous êtes croyants en Ses versets (le Coran).\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@cmviii{Qu'avez-vous à ne pas manger de ce sur quoi le nom d'Allah a été prononcé? Alors qu'Il vous a détaillé ce qu'Il vous a interdit, à moins que vous ne soyez contraints d'y recourir. Beaucoup de gens égarent, sans savoir, par leurs passions. C'est ton Seigneur qui connaît le mieux les transgresseurs.\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@cmix{Evitez le péché apparent ou caché, (car) ceux qui acquièrent le péché seront rétribués selon ce qu'ils auront commis.\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@cmx{Et ne mangez pas de ce sur quoi le nom d'Allah n'a pas été prononcé, car ce serait (assurément) une perversité. Les diables inspirent à leurs alliés de disputer avec vous. Si vous leur obéissez, vous deviendrez certes des associateurs.\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@cmxi{Est-ce que celui qui était mort et que Nous avons ramené à la vie et à qui Nous avons assigné une lumière grâce à laquelle il marche parmi les gens, est pareil à celui qui est dans les ténèbres sans pouvoir en sortir? Ainsi on a enjolivé aux mécréants ce qu'ils œuvrent.\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@cmxii{Ainsi, Nous avons placé dans chaque cité de grands criminels qui y ourdissent des complots. Mais ils ne complotent que contre eux-mêmes et ils n'en sont pas conscients.\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@cmxiii{Et lorsqu'une preuve leur vient, ils disent: «Jamais nous ne croirons tant que nous n'aurons pas reçu un don semblable à celui qui a été donné aux messagers d'Allah». Allah sait mieux où placer Son message. Ceux qui ont commis le crime seront atteints d'un rapetissement auprès d'Allah ainsi que d'un supplice sévère pour les ruses qu'ils tramaient.\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@cmxiv{Et puis, quiconque Allah veut guider, Il lui ouvre la poitrine à l'Islam. Et quiconque Il veut égarer, Il rend sa poitrine étroite et gênée, comme s'il s'efforçait de monter au ciel. Ainsi Allah inflige Sa punition à ceux qui ne croient pas.\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@cmxv{Telle est la voie de ton Seigneur dans toute sa rectitude. Nous avons [effectivement] bien détaillé les signes (ou versets) à des gens qui se rappellent.\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@cmxvi{Pour eux la maison du Salut auprès de leur Seigneur. Et c'est Lui qui est leur protecteur, pour ce qu'ils faisaient (sur terre).\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@cmxvii{Et le jour où Il les rassemblera tous: «O communauté des djinns, vous avez trop abusé des humains». Et leurs alliés parmi les humains diront: «O notre Seigneur, nous avons profité les uns des autres, et nous avons atteint le terme que Tu avais fixé pour nous.» Il leur dira: «l'Enfer est votre demeure, pour y rester éternellement, sauf si Allah en décide autrement.» Vraiment ton Seigneur est Sage et Omniscient.\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@cmxviii{Et ainsi accordons-Nous, à certains injustes l'autorité sur d'autres, (injustes) à cause de ce qu'ils ont acquis.\qt@no{(129)}}
\qt@newcmd\qurantrans@fr@cmxix{O communauté des djinns et des humains, ne vous est-il pas venu des messagers, choisis parmi vous, qui vous ont raconté Mes signes et averti de la rencontre de ce jour? Ils diront: «Nous témoignons contre nous-mêmes.» La vie présente les a trompés; et ils ont témoigné contre eux-mêmes qu'en (vérité) ils étaient mécréants.\qt@no{(130)}}
\qt@newcmd\qurantrans@fr@cmxx{C'est que ton Seigneur n'anéantit point injustement des cités dont les gens ne sont pas encore avertis.\qt@no{(131)}}
\qt@newcmd\qurantrans@fr@cmxxi{A chacun des rangs (des récompenses) selon ses œuvres. Or ton Seigneur n'est pas inattentif à ce qu'ils font.\qt@no{(132)}}
\qt@newcmd\qurantrans@fr@cmxxii{Ton Seigneur est le Suffisant à Soi-même, le Détenteur de la miséricorde. S'Il voulait, Il vous ferait périr et mettrait à votre place qui Il veut, de même qu'Il vous a créés d'une descendance d'un autre peuple.\qt@no{(133)}}
\qt@newcmd\qurantrans@fr@cmxxiii{Ce qui vous a été promis arrivera (certainement.) Et vous n'êtes pas à même de [Nous] réduire à l'impuissance.\qt@no{(134)}}
\qt@newcmd\qurantrans@fr@cmxxiv{Dis: «O mon peuple! Continuez à agir selon votre méthode; moi aussi j'agirai selon la mienne. Ensuite, vous saurez qui aura un meilleur (sort) dans l'au-delà.» Certes, les injustes ne réussiront jamais.\qt@no{(135)}}
\qt@newcmd\qurantrans@fr@cmxxv{Et ils assignent à Allah une part de ce qu'Il a Lui-même créé, en fait de récoltes et de bestiaux, et ils disent: «Ceci est à Allah - selon leur prétention! - et ceci à nos divinités.» Mais ce qui est pour leurs divinités ne parvient pas à Allah, tandis que ce qui est pour Allah parvient à leurs divinités. Comme leur jugement est mauvais!\qt@no{(136)}}
\qt@newcmd\qurantrans@fr@cmxxvi{Et c'est ainsi que leurs divinités ont enjolivé à beaucoup d'associateurs le meurtre de leurs enfants, afin de les ruiner et de travestir à leurs yeux leur religion. Or si Allah voulait, ils ne le feraient pas. Laisse-les donc, ainsi que ce qu'ils inventent.\qt@no{(137)}}
\qt@newcmd\qurantrans@fr@cmxxvii{Et ils dirent: «Voilà des bestiaux et des champs frappés d'interdiction: n'en mangeront que ceux que nous voudrons.» - selon leur prétention! - Et voilà des bêtes dont le dos est tabou, et des bêtes sur lesquelles ils ne mentionnent pas le nom d'Allah. Des inventions contre Lui! Il les rétribuera pour ce qu'ils inventaient comme mensonges.\qt@no{(138)}}
\qt@newcmd\qurantrans@fr@cmxxviii{Et ils dirent: «Ce qui est dans le ventre de ces bêtes est réservé aux mâles d'entre nous, et interdit à nos femmes.» Et si c'est un mort-né, ils y participent tous. Bientôt Il les rétribuera pour leur prescription, car Il est Sage et Omniscient.\qt@no{(139)}}
\qt@newcmd\qurantrans@fr@cmxxix{Ils sont certes perdants, ceux qui ont, par sottise et ignorance tué leurs enfants, et ceux qui ont interdit ce qu'Allah leur a attribué de nourriture, inventant des mensonges contre Allah. Ils se sont égarés et ne sont point guidés.\qt@no{(140)}}
\qt@newcmd\qurantrans@fr@cmxxx{C'est Lui qui a créé les jardins, treillagés et non treillagés; ainsi que les palmiers et la culture aux récoltes diverses; [de même que] l'olive et la grenade, d'espèces semblables et différentes. Mangez de leurs fruits, quand ils en produisent; et acquittez-en les droits le jour de la récolte. Et ne gaspillez point car Il n'aime pas les gaspilleurs.\qt@no{(141)}}
\qt@newcmd\qurantrans@fr@cmxxxi{Et (Il a créé) parmi les bestiaux, certains pour le transport, et d'autres pour diverses utilités; mangez de ce qu'Allah vous a attribué, et ne suivez pas les pas du Diable, car il est pour vous un ennemi déclaré.\qt@no{(142)}}
\qt@newcmd\qurantrans@fr@cmxxxii{(Il en a créé) huit, en couples: deux pour les ovins, deux pour les caprins... dis: «Est-ce les deux mâles qu'Il a interdits ou les deux femelles, ou ce qui est dans les matrices des deux femelles? Informez-moi de toute connaissance, si vous êtes véridiques»\qt@no{(143)}}
\qt@newcmd\qurantrans@fr@cmxxxiii{...deux pour les camélidés, deux pour les bovins... Dis: «Est-ce les deux mâles qu'Il a interdits ou les deux femelles, ou ce qui est dans les matrices des deux femelles? Ou bien étiez-vous témoins quand Allah vous l'enjoignit?» Qui est donc plus injuste que celui qui invente un mensonge contre Allah pour égarer les gens sans se baser sur aucun savoir? Allah ne guide pas les gens injustes.\qt@no{(144)}}
\qt@newcmd\qurantrans@fr@cmxxxiv{Dis: «Dans ce qui m'a été révélé, je ne trouve d'interdit, à aucun mangeur d'en manger, que la bête (trouvée) morte, ou le sang qu'on a fait couler, ou la chair de porc - car c'est une souillure - ou ce qui, par perversité, a été sacrifié à autre qu'Allah». Quiconque est contraint, sans toutefois abuser ou transgresser, ton Seigneur est certes Pardonneur et Miséricordieux.\qt@no{(145)}}
\qt@newcmd\qurantrans@fr@cmxxxv{Aux Juifs, Nous avons interdit toute bête à ongle unique. Des bovins et des ovins, Nous leurs avons interdit les graisses, sauf ce que portent leur dos, leurs entrailles, ou ce qui est mêlé à l'os. Ainsi les avons-Nous punis pour leur rébellion. Et Nous sommes bien véridiques.\qt@no{(146)}}
\qt@newcmd\qurantrans@fr@cmxxxvi{Puis, s'ils te traitent de menteur, alors dis: «Votre Seigneur est Détenteur d'une immense miséricorde cependant que Sa rigueur ne saura être détournée des gens criminels».\qt@no{(147)}}
\qt@newcmd\qurantrans@fr@cmxxxvii{Ceux qui ont associé diront: «Si Allah avait voulu, nous ne Lui aurions pas donné des associés, nos ancêtres non plus et nous n'aurions rien déclaré interdit.» Ainsi leurs prédécesseurs traitaient de menteurs (les messagers) jusqu'à ce qu'ils eurent goûté Notre rigueur. Dis: «Avez-vous quelque science à nous produire? Vous ne suivez que la conjecture et ne faites que mentir».\qt@no{(148)}}
\qt@newcmd\qurantrans@fr@cmxxxviii{Dis: «L'argument décisif appartient à Allah. S'Il avait voulu certainement Il vous aurait tous guidés. (sur le droit chemin)\qt@no{(149)}}
\qt@newcmd\qurantrans@fr@cmxxxix{Dis: «Amenez vos témoins qui attesteraient qu'Allah a interdit cela.» Si ensuite ils témoignent, alors toi, ne témoigne pas avec eux et ne suis pas les passions de ceux qui traitent de mensonges Nos signes et qui ne croient pas à l'au-delà, tandis qu'ils donnent des égaux à leur Seigneur.\qt@no{(150)}}
\qt@newcmd\qurantrans@fr@cmxl{Dis: «Venez, je vais réciter ce que votre Seigneur vous a interdit: ne Lui associez rien; et soyez bienfaisants envers vos père et mère. Ne tuez pas vos enfants pour cause de pauvreté. Nous vous nourrissons tout comme eux. N'approchez pas des turpitudes ouvertement, ou en cachette. Ne tuez qu'en toute justice la vie qu'Allah a fait sacrée. Voilà ce qu'[Allah] vous a recommandé de faire; peut-être comprendrez-vous.\qt@no{(151)}}
\qt@newcmd\qurantrans@fr@cmxli{Et ne vous approchez des biens de l'orphelin que de la plus belle manière, jusqu'à ce qu'il ait atteint sa majorité. Et donnez la juste mesure et le bon poids, en toute justice. Nous n'imposons à une âme que selon sa capacité. Et quand vous parlez, soyez équitables même s'il s'agit d'un proche parent. Et remplissez votre engagement envers Allah. Voilà ce qu'Il vous enjoint. Peut-être vous rappellerez-vous.\qt@no{(152)}}
\qt@newcmd\qurantrans@fr@cmxlii{«Et voilà Mon chemin dans toute sa rectitude, suivez-le donc; et ne suivez pas les sentiers qui vous écartent de Sa voie.» Voilà ce qu'Il vous enjoint. Ainsi atteindrez-vous la piété.\qt@no{(153)}}
\qt@newcmd\qurantrans@fr@cmxliii{Puis Nous avons donné à Moïse le Livre complet en récompense pour le bien qu'il avait fait, et comme un exposé détaillé de toute chose, un guide et une miséricorde. Peut-être croiraient-ils en leur rencontre avec leur Seigneur (au jour du Jugement dernier).\qt@no{(154)}}
\qt@newcmd\qurantrans@fr@cmxliv{Et voici un Livre (le Coran) béni que Nous avons fait descendre - suivez-le donc et soyez pieux, afin de recevoir la miséricorde -\qt@no{(155)}}
\qt@newcmd\qurantrans@fr@cmxlv{afin que vous ne disiez point: «On n'a fait descendre le Livre que sur deux peuples avant nous, et nous avons été inattentifs à les étudier.\qt@no{(156)}}
\qt@newcmd\qurantrans@fr@cmxlvi{Ou que vous disiez: «Si c'était à nous qu'on avait fait descendre le Livre, nous aurions certainement été mieux guidés qu'eux.» Voilà certes que vous sont venus, de votre Seigneur, preuve, guidée et miséricorde. Qui est plus injuste que celui qui traite de mensonges les versets d'Allah et qui s'en détourne? Nous punirons ceux qui se détournent de Nos versets, par un mauvais châtiment, pour s'en être détournés.\qt@no{(157)}}
\qt@newcmd\qurantrans@fr@cmxlvii{Qu'attendent-ils? Que les Anges leur viennent? Que vienne ton Seigneur? Ou que viennent certains signes de ton Seigneur? Le jour où certains signes de ton Seigneur viendront, la foi en Lui ne profitera à aucune âme qui n'avait pas cru auparavant ou qui n'avait acquis aucun mérite de sa croyance. Dis: «Attendez!» Nous attendons, Nous aussi.\qt@no{(158)}}
\qt@newcmd\qurantrans@fr@cmxlviii{Ceux qui émiettent leur religion et se divisent en sectes, de ceux-là tu n'es responsable en rien: leur sort ne dépend que d'Allah. Puis Il les informera de ce qu'ils faisaient.\qt@no{(159)}}
\qt@newcmd\qurantrans@fr@cmxlix{Quiconque viendra avec le bien aura dix fois autant; et quiconque viendra avec le mal ne sera rétribué que par son équivalent. Et on ne leur fera aucune injustice.\qt@no{(160)}}
\qt@newcmd\qurantrans@fr@cml{Dis: «Moi, mon Seigneur m'a guidé vers un chemin droit, une religion droite, la religion d'Abraham, le soumis exclusivement à Allah et qui n'était point parmi les associateurs.\qt@no{(161)}}
\qt@newcmd\qurantrans@fr@cmli{Dis: «En vérité, ma Salât, mes actes de dévotion, ma vie et ma mort appartiennent à Allah, Seigneur de l'Univers.\qt@no{(162)}}
\qt@newcmd\qurantrans@fr@cmlii{A Lui nul associé! Et voilà ce qu'il m'a été ordonné, et je suis le premier à me soumettre.»\qt@no{(163)}}
\qt@newcmd\qurantrans@fr@cmliii{Dis: «Chercherais-je un autre Seigneur qu'Allah, alors qu'Il est le Seigneur de toute chose? Chacun n'acquiert [le mal] qu'à son détriment: personne ne portera le fardeau (responsabilité) d'autrui. Puis vers votre Seigneur sera votre retour et Il vous informera de ce en quoi vous divergez.\qt@no{(164)}}
\qt@newcmd\qurantrans@fr@cmliv{C'est Lui qui a fait de vous les successeurs sur terre et qui vous a élevés, en rangs, les uns au-dessus des autres, afin de vous éprouver en ce qu'Il vous a donné. (Vraiment) ton Seigneur est prompt en punition, Il est aussi Pardonneur et Miséricordieux.\qt@no{(165)}}
\qt@newcmd\qurantrans@fr@cmlv{\basmalahfr Alif, Lâm, Mîm, Sâd.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@cmlvi{C'est un Livre qui t'a été descendu; qu'il n'y ait, à son sujet, nulle gêne dans ton cœur; afin que par cela tu avertisses, et (qu'il soit) un Rappel aux croyants.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@cmlvii{Suivez ce qui vous a été descendu venant de votre Seigneur et ne suivez pas d'autres alliés que Lui. Mais vous vous souvenez peu.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@cmlviii{Que de cités Nous avons détruites! Or, Notre rigueur les atteignit au cours du repos nocturne ou durant leur sieste.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@cmlix{Leur invocation, lorsque leur survint notre rigueur, se limita à ces paroles: «Certes nous étions injustes».\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@cmlx{Nous interrogerons ceux vers qui furent envoyés des messagers et Nous interrogerons aussi les envoyés.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@cmlxi{Nous leur raconterons en toute connaissance (ce qu'ils faisaient) car Nous n'étions pas absent!\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@cmlxii{Et la pesée, ce jour-là, sera équitable. Donc, celui dont les bonnes actions pèseront lourd... voilà ceux qui réussiront!\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@cmlxiii{Et quant à celui dont les bonnes actions pèseront léger... voilà ceux qui auront causé la perte de leurs âmes parce qu'ils étaient injustes envers Nos enseignements.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@cmlxiv{Certes, Nous vous avons donné du pouvoir sur terre et Nous vous y avons assigné subsistance. (Mais) vous êtes très peu reconnaissants!\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@cmlxv{Nous vous avons créés, puis Nous vous avons donné une forme, ensuite Nous avons dit aux Anges: «Prosternez-vous devant Adam.» Ils se prosternèrent, à l'exception de Iblis qui ne fut point de ceux qui se prosternèrent.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@cmlxvi{[Allah] dit: «Qu'est-ce qui t'empêche de te prosterner quand Je te l'ai commandé?» Il répondit: «Je suis meilleur que lui: Tu m'as créé de feu, alors que Tu l'as créé d'argile».\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@cmlxvii{[Allah] dit: «Descends d'ici, Tu n'as pas à t'enfler d'orgueil ici. Sors, te voilà parmi les méprisés.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@cmlxviii{«Accorde-moi un délai, dit (Satan,) jusqu'au jour où ils seront ressuscités.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@cmlxix{[Allah] dit: «Tu es de ceux à qui délai est accordé.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@cmlxx{«Puisque Tu m'as mis en erreur, dit [Satan], je m'assoirai pour eux sur Ton droit chemin,\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@cmlxxi{puis je les assaillerai de devant, de derrière, de leur droite et de leur gauche. Et, pour la plupart, Tu ne les trouveras pas reconnaissants.»\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@cmlxxii{«Sors de là», dit (Allah,) banni et rejeté. Quiconque te suit parmi eux... de vous tous, J'emplirai l'Enfer».\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@cmlxxiii{«O Adam, habite le Paradis, toi et ton épouse; et mangez en vous deux, à votre guise; et n'approchez pas l'arbre que voici; sinon, vous seriez du nombre des injustes.»\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@cmlxxiv{Puis le Diable, afin de leur rendre visible ce qui leur était caché - leurs nudités - leur chuchota, disant: «Votre Seigneur ne vous a interdit cet arbre que pour vous empêcher de devenir des Anges ou d'être immortels».\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@cmlxxv{Et il leur jura: «Vraiment, je suis pour vous deux un bon conseiller».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@cmlxxvi{Alors il les fit tomber par tromperie. Puis, lorsqu'ils eurent goûté de l'arbre, leurs nudités leur devinrent visibles; et ils commencèrent tous deux à y attacher des feuilles du Paradis. Et leur Seigneur les appela: «Ne vous avais-Je pas interdit cet arbre? Et ne vous avais-Je pas dit que le Diable était pour vous un ennemi déclaré?»\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@cmlxxvii{Tous deux dirent: «O notre Seigneur, nous avons fait du tort à nous-mêmes. Et si Tu ne nous pardonnes pas et ne nous fais pas miséricorde, nous serons très certainement du nombre des perdants».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@cmlxxviii{«Descendez, dit [Allah], vous serez ennemis les uns des autres. Et il y aura pour vous sur terre séjour et jouissance, pour un temps.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@cmlxxix{«Là, dit (Allah), vous vivrez, là vous mourrez, et de là on vous fera sortir.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@cmlxxx{O enfants d'Adam! Nous avons fait descendre sur vous un vêtement pour cacher vos nudités, ainsi que des parures. - Mais le vêtement de la piété voilà qui est meilleur - C'est un des signes (de la puissance) d'Allah. Afin qu'ils se rappellent.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@cmlxxxi{O enfants d'Adam! Que le Diable ne vous tente point, comme il a fait sortir du Paradis vos père et mère, leur arrachant leur vêtement pour leur rendre visibles leurs nudités. Il vous voit, lui et ses suppôts, d'où vous ne les voyez pas. Nous avons désigné les diables pour alliés à ceux qui ne croient point,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@cmlxxxii{et quand ceux-ci commettent une turpitude, ils disent: «C'est une coutume léguée par nos ancêtres et prescrite par Allah.» Dis: «[Non,] Allah ne commande point la turpitude. Direz-vous contre Allah ce que vous ne savez pas?»\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@cmlxxxiii{Dis: «Mon Seigneur a commandé l'équité. Que votre prosternation soit exclusivement pour Lui. Et invoquez-Le, sincères dans votre culte. De même qu'Il vous a créés, vous retournerez à Lui».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@cmlxxxiv{Il guide une partie, tandis qu'une autre partie a mérité l'égarement parce qu'ils ont pris, au lieu d'Allah, les diables pour alliés, et ils pensent qu'ils sont bien-guidés!\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@cmlxxxv{O enfants d'Adam, dans chaque lieu de Salât portez votre parure (vos habits). Et mangez et buvez; et ne commettez pas d'excès, car Il [Allah] n'aime pas ceux qui commettent des excès.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@cmlxxxvi{Dis: «Qui a interdit la parure d'Allah, qu'Il a produite pour Ses serviteurs, ainsi que les bonnes nourritures?» Dis: «Elles sont destinées à ceux qui ont la foi, dans cette vie, et exclusivement à eux au Jour de la Résurrection.» Ainsi exposons-Nous clairement les versets pour les gens qui savent.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@cmlxxxvii{Dis: «Mon Seigneur n'a interdit que les turpitudes (les grands péchés), tant apparentes que secrètes, de même que le péché, l'agression sans droit et d'associer à Allah ce dont Il n'a fait descendre aucune preuve, et de dire sur Allah ce que vous ne savez pas».\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@cmlxxxviii{Pour chaque communauté il y a un terme. Quand leur terme vient, ils ne peuvent le retarder d'une heure et ils ne peuvent le hâter non plus.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@cmlxxxix{O enfants d'Adam! Si des messagers [choisis] parmi vous viennent pour vous exposer Mes signes, alors ceux qui acquièrent la piété et se réforment, n'auront aucune crainte et ne seront point affligés.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@cmxc{Et ceux qui traitent de mensonges Nos signes et s'en écartent avec orgueil, sont les gens du Feu et ils y demeureront éternellement.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@cmxci{Quel pire injuste, que celui qui invente un mensonge contre Allah, ou qui traite de mensonges Ses signes? Ceux là auront la part qui leur a été prescrite; jusqu'au moment où Nos Envoyés [Nos Anges] viennent à eux pour leur enlever l'âme, en leur disant: «Où sont ceux que vous invoquiez en dehors d'Allah?» - Ils répondront: «Nous ne les trouvons plus». Et ils témoigneront contre eux-mêmes qu'ils étaient mécréants.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@cmxcii{«Entrez dans le Feu», dira [Allah,] «parmi les djinns et les hommes des communautés qui vous ont précédés.» Chaque fois qu'une communauté entrera, elle maudira celle qui l'aura précédée. Puis, lorsque tous s'y retrouveront, la dernière fournée dira de la première: «O notre Seigneur! Voilà ceux qui nous ont égarés: donne-leur donc double châtiment du feu.» Il dira: «A chacun le double, mais vous ne savez pas».\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@cmxciii{Et la première fournée dira à la dernière: «Mais vous n'avez sur nous aucun avantage. Goûtez donc au châtiment, pour ce que vous avez acquis».\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@cmxciv{Pour ceux qui traitent de mensonges Nos enseignements et qui s'en écartent par orgueil, les portes du ciel ne leur seront pas ouvertes, et ils n'entreront au Paradis que quand le chameau pénètre dans le chas de l'aiguille. Ainsi rétribuons-Nous les criminels.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@cmxcv{L'Enfer leur servira de lit et, comme couverture, ils auront des voiles de ténèbres. Ainsi rétribuons-Nous les injustes.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@cmxcvi{Et ceux qui croient et font de bonnes œuvres - Nous n'imposons aucune charge à personne que selon sa capacité - ceux-là seront les gens du Paradis: ils y demeureront éternellement.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@cmxcvii{Et Nous enlèverons toute la rancune de leurs poitrines, sous eux couleront les ruisseaux, et ils diront: «Louange à Allah qui nous a guidés à ceci. Nous n'aurions pas été guidés, si Allah ne nous avait pas guidés. Les messagers de notre Seigneur sont venus avec la vérité.» Et on leur proclamera: «Voilà le Paradis qui vous a été donné en héritage pour ce que vous faisiez».\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@cmxcviii{Les gens du Paradis crieront aux gens du Feu: «Certes, nous avons trouvé vrai ce que notre Seigneur nous avait promis. Avez-vous aussi trouvé vrai ce que votre Seigneur avait promis?» «Oui», diront-ils. Un héraut annoncera alors au milieu d'eux: Que la malédiction d'Allah soit sur les injustes,\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@cmxcix{qui obstruaient le sentier d'Allah, qui voulaient le rendre tortueux, et qui ne croyaient pas à l'au-delà.»\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@m{Et entre les deux, il y aura un mur, et, sur al-A'râf seront des gens qui reconnaîtront tout le monde par leurs traits caractéristiques. Et ils crieront aux gens du Paradis: «Paix sur vous!» Ils n'y sont pas entrés bien qu'ils le souhaitent.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mi{Et quand leurs regards seront tournés vers les gens du Feu, ils diront; «O notre Seigneur! Ne nous mets pas avec le peuple injuste».\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mii{Et les gens d'al-A'râf, appelant certains hommes qu'ils reconnaîtront par leurs traits caractéristiques, diront: «Vous n'avez tiré aucun profit de tout ce que vous aviez amassé et de l'orgueil dont vous étiez enflés!\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@miii{Est-ce donc ceux-là au sujet desquels vous juriez qu'ils n'obtiendront de la part d'Allah aucune miséricorde...? - Entrez au Paradis! Vous serez à l'abri de toute crainte et vous ne serez point affligés.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@miv{Et les gens du Feu crieront aux gens du Paradis: «Déversez sur nous de l'eau, ou de ce qu'Allah vous a attribué.» «Ils répondront: Allah les a interdits aux mécréants».\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mv{Ceux-ci prenaient leur religion comme distraction et jeu, et la vie d'ici-bas les trompait. Aujourd'hui, Nous les oublierons comme ils ont oublié la rencontre de leur jour que voici, et parce qu'ils reniaient Nos enseignements.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mvi{Nous leur avons, certes, apporté un Livre que Nous avons détaillé, en toute connaissance, à titre de guide et de miséricorde pour les gens qui croient.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mvii{Attendent-ils uniquement la réalisation (de Sa menace et de Ses promesses?). Le jour où sa (véritable) réalisation viendra, ceux qui auparavant l'oubliaient diront: «Les messagers de notre Seigneur sont venus avec la vérité. Y a-t-il pour nous des intercesseurs qui puissent intercéder en notre faveur? Ou pourrons-nous être renvoyés [sur terre], afin que nous œuvrions autrement que ce que nous faisions auparavant?» Ils ont certes créé leur propre perte; et ce qu'ils inventaient les a délaissés.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mviii{Votre Seigneur, c'est Allah, qui a créé les cieux et la terre en six jours, puis S'est établi «'istawâ» sur le Trône. Il couvre le jour de la nuit qui poursuit celui-ci sans arrêt. (Il a créé) le soleil, la lune et les étoiles, soumis à Son commandement. La création et le commandement n'appartiennent qu'à Lui. Toute gloire à Allah, Seigneur de l'Univers!\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mix{Invoquez votre Seigneur en toute humilité et recueillement et avec discrétion. Certes, Il n'aime pas les transgresseurs.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mx{Et ne semez pas la corruption sur la terre après qu'elle ait été réformée. Et invoquez-Le avec crainte et espoir, car la miséricorde d'Allah est proche des bienfaisants.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mxi{C'est Lui qui envoie les vents comme une annonce de Sa Miséricorde. Puis, lorsqu'ils transportent une nuée lourde, Nous la dirigeons vers un pays mort [de sécheresse], puis Nous en faisons descendre l'eau, ensuite Nous en faisons sortir toutes espèces de fruits. Ainsi ferons-Nous sortir les morts. Peut-être vous rappellerez-vous.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mxii{Le bon pays, sa végétation pousse avec la grâce de son Seigneur; quant au mauvais pays, (sa végétation) ne sort qu'insuffisamment et difficilement. Ainsi déployons-Nous les enseignements pour des gens reconnaissants.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mxiii{Nous avons envoyé Noé vers son peuple. Il dit: «O mon peuple, adorez Allah. Pour vous, pas d'autre divinité que Lui. Je crains pour vous le châtiment d'un jour terrible».\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mxiv{Les notables de son peuple dirent: «Nous te voyons dans un égarement manifeste».\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mxv{Il dit: «O mon peuple, il n'y a pas d'égarement en moi; mais je suis un Messager de la part du Seigneur de l'Univers.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mxvi{Je vous communique les messages de mon Seigneur, et je vous donne conseil sincère, et je sais d'Allah ce que vous ne savez pas.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mxvii{Est-ce que vous vous étonnez qu'un rappel vous vienne de votre Seigneur à travers un homme issu de vous, pour qu'il vous avertisse et que vous deveniez pieux et que la miséricorde vous soit accordée?»\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mxviii{Et ils le traitèrent de menteur. Or, Nous le sauvâmes, lui et ceux qui étaient avec lui dans l'arche, et noyâmes ceux qui traitaient de mensonges Nos miracles. C'étaient des gens aveugles, vraiment.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mxix{Et aux 'Aad, leur frère Hûd: «O mon peuple, dit-il, adorez Allah. Pour vous, pas d'autre divinité que Lui. Ne [Le] craignez-vous donc pas?»\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mxx{Les notables de son peuple qui ne croyaient pas dirent: «Certes, nous te voyons en pleine sottise, et nous pensons que tu es du nombre des menteurs».\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mxxi{Il dit: «O mon peuple, il n'y a point de sottise en moi; mais je suis un Messager de la part du Seigneur de l'Univers.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mxxii{Je vous communique les messages de mon Seigneur, et je suis pour vous un conseiller digne de confiance.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mxxiii{Quoi! Vous vous étonnez qu'un rappel vous vienne de votre Seigneur à travers un homme issu de vous, pour qu'il vous avertisse? Et rappelez-vous quand Il vous a fait succéder au peuple de Noé, et qu'Il accrut votre corps en hauteur (et puissance). Eh bien, rappelez-vous les bienfaits d'Allah afin que vous réussissiez.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mxxiv{Ils dirent: «Es-tu venu à nous pour que nous adorions Allah seul, et que nous délaissions ce que nos ancêtres adoraient? Fais donc venir ce dont tu nous menaces, si tu es du nombre des véridiques».\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mxxv{Il dit: «Vous voilà, frappés de la part de votre Seigneur d'un supplice et d'une colère. Allez vous vous disputer avec moi au sujet de noms que vous et vos ancêtres avez donnés, sans qu'Allah n'y fasse descendre la moindre preuve? Attendez donc! Moi aussi j'attends avec vous.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mxxvi{Or, Nous l'avons sauvé, (lui) et ceux qui étaient avec lui par miséricorde, de Notre part, et Nous avons exterminé ceux qui traitaient de mensonges Nos enseignements et qui n'étaient pas croyants.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mxxvii{Et aux Thamûd, leur frère Sâlih: «O mon peuple, dit-il, adorez Allah. Pour vous, pas d'autre divinité que Lui. Certes, une preuve vous est venue de votre Seigneur: voici la chamelle d'Allah, un signe pour vous. Laissez-la donc manger sur la terre d'Allah et ne lui faites aucun mal; sinon un châtiment douloureux vous saisira.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mxxviii{Et rappelez-vous quand Il vous fit succéder aux Aad et vous installa sur la terre. Vous avez édifié des palais dans ses plaines, et taillé en maisons les montagnes. Rappelez-vous donc les bienfaits d'Allah et ne répandez pas la corruption sur la terre «comme des fauteurs de trouble».\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mxxix{Les notables de son peuple qui s'enflaient d'orgueil dirent aux opprimés, à ceux d'entre eux qui avaient la foi: «Savez-vous si Sâlih est envoyé de la part de son Seigneur?» Ils dirent: «Oui, nous sommes croyants à son message».\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mxxx{Ceux qui s'enflaient d'orgueil dirent: «Nous, nous ne croyons certainement pas en ce que vous avez cru».\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mxxxi{Ils tuèrent la chamelle, désobéirent au commandement de leur Seigneur et dirent: «O Sâlih, fais nous venir ce dont tu nous menaces, si tu es du nombre des Envoyés».\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mxxxii{Le cataclysme les saisit; et les voilà étendus gisant dans leurs demeures.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mxxxiii{Alors il se détourna d'eux et dit: «O mon peuple, je vous avais communiqué le message de mon Seigneur et vous avais conseillé sincèrement. Mais vous n'aimez pas les conseillers sincères!»\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mxxxiv{Et Lot, quand il dit à son peuple: «Vous livrez vous à cette turpitude que nul, parmi les mondes, n'a commise avant vous?\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mxxxv{Certes, vous assouvissez vos désirs charnels avec les hommes au lieu des femmes! Vous êtes bien un peuple outrancier.»\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mxxxvi{Et pour toute réponse, son peuple ne fit que dire: «Expulsez-les de votre cité. Ce sont des gens qui veulent se garder purs!»\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mxxxvii{Or, Nous l'avons sauvé, lui et sa famille, sauf sa femme qui fut parmi les exterminés.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mxxxviii{Et Nous avons fait pleuvoir sur eux une pluie. Regarde donc ce que fut la fin des criminels!\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mxxxix{Et aux Madyan, leur frère Chu'aïb: «O mon peuple, dit-il, adorez Allah. Pour vous, pas d'autre divinité que Lui. Une preuve vous est venue de votre Seigneur. Donnez donc la pleine mesure et le poids et ne donnez pas aux gens moins que ce qui leur est dû. Et ne commettez pas de la corruption sur la terre après sa réforme. Ce sera mieux pour vous si vous êtes croyants.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mxl{Et ne vous placez pas sur tout chemin, menaçant, empêchant du sentier d'Allah celui qui croit en Lui et cherchant à rendre ce sentier tortueux. Rappelez-vous quand vous étiez peu nombreux et qu'Il vous a multipliés en grand nombre. Et regardez ce qui est advenu aux fauteurs de désordre.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mxli{Si une partie d'entre vous a cru au message avec lequel j'ai été envoyé, et qu'une partie n'a pas cru, patientez donc jusqu'à ce qu'Allah juge parmi nous car Il est le Meilleur des juges.»\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mxlii{Les notables de son peuple qui s'enflaient d'orgueil, dirent: «Nous t'expulserons certes de notre cité, ô Chu'aïb, toi et ceux qui ont cru avec toi. Ou que vous reveniez à notre religion.» - Il dit: «Est-ce même quand cela nous répugne?»\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mxliii{Certes, nous aurions forgé un mensonge contre Allah si nous revenions à votre religion après qu'Allah nous en a sauvés. Il ne nous appartient pas d'y retourner à moins qu'Allah notre Seigneur ne le veuille. Notre Seigneur embrasse toute chose de Sa science. C'est en Allah que nous plaçons notre confiance. O notre Seigneur, tranche par la vérité, entre nous et notre peuple car Tu es le meilleur des juges.»\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mxliv{Et les notables de son peuple qui ne croyaient pas, dirent: «Si vous suivez Chu'aïb, vous serez assurément perdants».\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mxlv{Alors le tremblement (de terre) les saisit; et les voilà étendus, gisant dans leurs demeures.\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mxlvi{Ceux qui traitaient Chu'aïb de menteur (disparurent) comme s'ils n'y avaient jamais vécu. Ceux qui traitaient Chu'aïb de menteur furent eux les perdants.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mxlvii{Il se détourna d'eux et dit: «O mon peuple, je vous ai bien communiqué les messages de mon Seigneur et donné des conseils. Comment donc m'attristerais-je sur des gens mécréants?»\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mxlviii{Nous n'avons envoyé aucun prophète dans une cité, sans que Nous n'ayons pris ses habitants ensuite par l'adversité et la détresse afin qu'ils implorent (le pardon).\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mxlix{Puis Nous avons changé leur mauvaise condition en y substituant le bien, au point qu'ayant grandi en nombre et en richesse, ils dirent: «La détresse et l'aisance ont touché nos ancêtres aussi.» Eh bien, Nous les avons saisis soudain, sans qu'ils s'en rendent compte.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@ml{Si les habitants des cités avaient cru et avaient été pieux, Nous leur aurions certainement accordé des bénédictions du ciel et de la terre. Mais ils ont démenti et Nous les avons donc saisis, pour ce qu'ils avaient acquis.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mli{Les gens des cités sont-ils sûrs que Notre châtiment rigoureux ne les atteindra pas la nuit, pendant qu'ils sont endormis?\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mlii{Les gens des cités sont-ils sûrs que Notre châtiment rigoureux ne les atteindra pas le jour, pendant qu'ils s'amusent?\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mliii{Sont-ils à l'abri du stratagème d'Allah? Seuls les gens perdus se sentent à l'abri du stratagème d'Allah.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mliv{N'est-il pas prouvé à ceux qui reçoivent la terre en héritage des peuples précédents que, si Nous voulions, Nous les frapperions pour leurs péchés et scellerions leurs cœurs, et ils n'entendraient plus rien?\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mlv{Voilà les cités dont Nous te racontons certaines de leurs nouvelles. [A ceux-là,] en vérité, leurs messagers leur avaient apporté les preuves, mais ils n'étaient pas prêts à accepter ce qu'auparavant ils avaient traité de mensonge. C'est ainsi qu'Allah scelle les cœurs des mécréants.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mlvi{Et Nous n'avons trouvé chez la plupart d'entre eux aucun respect de l'engagement; mais Nous avons trouvé la plupart d'entre eux pervers.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mlvii{Puis, après [ces messagers,] Nous avons envoyé Moïse avec Nos miracles vers Pharaon et ses notables. Mais ils se montrèrent injustes envers Nos signes. Considère donc quelle fut la fin des corrupteurs.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mlviii{Et Moïse dit: «O Pharaon, je suis un Messager de la part du Seigneur de l'Univers,\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mlix{je ne dois dire sur Allah que la vérité. Je suis venu à vous avec une preuve de la part de votre Seigneur. Laisse donc partir avec moi les Enfants d'Israël.»\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mlx{«Si tu es venu avec un miracle, dit (Pharaon,) apporte-le donc, si tu es du nombre des véridiques.»\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mlxi{Il jeta son bâton et voilà que c'était un serpent évident.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mlxii{Et il sortit sa main et voilà qu'elle était blanche (éclatante), pour ceux qui regardaient.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mlxiii{Les notables du peuple de Pharaon dirent: «Voilà, certes, un magicien chevronné.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mlxiv{Il veut vous expulser de votre pays.» - «Alors, que commandez-vous?»\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mlxv{Ils dirent: «Fais-le attendre, lui et son frère, et envoie des rassembleurs dans les villes,\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mlxvi{qui t'amèneront tout magicien averti.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@mlxvii{Et les magiciens vinrent à Pharaon en disant: «Y aura-t-il vraiment une récompense pour nous, si nous sommes les vainqueurs?»\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@mlxviii{Il dit: «Oui, et vous serez certainement du nombre de mes rapprochés».\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@mlxix{Ils dirent: «O Moïse, ou bien tu jetteras (le premier), ou bien nous serons les premiers à jeter».\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@mlxx{«Jetez» dit-il. Puis lorsqu'ils eurent jeté, ils ensorcelèrent les yeux des gens et les épouvantèrent, et vinrent avec une puissante magie.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@mlxxi{Et Nous révélâmes à Moïse: «Jette ton bâton». Et voilà que celui-ci se mit à engloutir ce qu'ils avaient fabriqué.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@mlxxii{Ainsi la vérité se manifesta et ce qu'ils firent fût vain.\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@mlxxiii{Ainsi ils furent battus et se trouvèrent humiliés.\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@mlxxiv{Et les magiciens se jetèrent prosternés.\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@mlxxv{Ils dirent: «Nous croyons au Seigneur de l'Univers,\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@mlxxvi{au Seigneur de Moïse et d'Aaron.»\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@mlxxvii{«Y avez-vous cru avant que je ne vous (le) permette? dit Pharaon. C'est bien un stratagème que vous avez manigancé dans la ville, afin d'en faire partir ses habitants. Vous saurez bientôt...\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@mlxxviii{Je vais vous couper la main et la jambe opposées, et puis, je vous crucifierai tous.»\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@mlxxix{Ils dirent: «En vérité, c'est vers notre Seigneur que nous retournerons.\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@mlxxx{Tu ne te venges de nous que parce que nous avons cru aux preuves de notre Seigneur, lorsqu'elles nous sont venues. O notre Seigneur! Déverse sur nous l'endurance et fais nous mourir entièrement soumis.»\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@mlxxxi{Et les notables du peuple de Pharaon dirent: «Laisseras-tu Moïse et son peuple commettre du désordre sur la terre, et lui-même te délaisser, toi et tes divinités?» Il dit: «Nous allons massacrer leurs fils et laisser vivre leurs femmes. Nous aurons le dessus sur eux et les dominerons.»\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@mlxxxii{Moïse dit à son peuple: «Demandez aide auprès d'Allah et soyez patients, car la terre appartient à Allah. Il en fait héritier qui Il veut parmi Ses serviteurs. Et la fin (heureuse) sera aux pieux».\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@mlxxxiii{Ils dirent: «Nous avons été persécutés avant que tu ne viennes à nous, et après ton arrivée.» Il dit: «Il se peut que votre Seigneur détruise votre ennemi et vous donne la lieutenance sur terre, et Il verra ensuite comment vous agirez».\qt@no{(129)}}
\qt@newcmd\qurantrans@fr@mlxxxiv{Nous avons éprouvé les gens de Pharaon par des années de disette et par une diminution des fruits afin qu'ils se rappellent.\qt@no{(130)}}
\qt@newcmd\qurantrans@fr@mlxxxv{Et quand le bien-être leur vint, ils dirent: «Cela nous est dû» et si un mal les atteignait, ils voyaient en Moïse et ceux qui étaient avec lui un mauvais augure. En vérité leur sort dépend uniquement d'Allah? Mais la plupart d'entre eux ne savent pas.\qt@no{(131)}}
\qt@newcmd\qurantrans@fr@mlxxxvi{Et ils dirent: «Quel que soit le miracle que tu nous apportes pour nous fasciner, nous ne croirons pas en toi».\qt@no{(132)}}
\qt@newcmd\qurantrans@fr@mlxxxvii{Et Nous avons alors envoyé sur eux l'inondation, les sauterelles, les poux (ou la calandre), les grenouilles et le sang, comme signes explicites. Mais ils s'enflèrent d'orgueil et demeurèrent un peuple criminel.\qt@no{(133)}}
\qt@newcmd\qurantrans@fr@mlxxxviii{Et quand le châtiment les frappa, ils dirent: «O Moïse, invoque pour nous ton Seigneur en vertu de l'engagement qu'Il t'a donné. Si tu éloignes de nous le châtiment, nous croirons certes en toi et laisserons partir avec toi les enfants d'Israël».\qt@no{(134)}}
\qt@newcmd\qurantrans@fr@mlxxxix{Et quand Nous eûmes éloigné d'eux le châtiment jusqu'au terme fixé qu'ils devaient atteindre, voilà qu'ils violèrent l'engagement.\qt@no{(135)}}
\qt@newcmd\qurantrans@fr@mxc{Alors Nous Nous sommes vengés d'eux; Nous les avons noyés dans les flots, parce qu'ils traitaient de mensonges Nos signes et n'y prêtaient aucune attention.\qt@no{(136)}}
\qt@newcmd\qurantrans@fr@mxci{Et les gens qui étaient opprimés, Nous les avons fait hériter les contrées orientales et occidentales de la terre que Nous avons bénies. Et la très belle promesse de ton Seigneur sur les enfants d'Israël s'accomplit pour prix de leur endurance. Et Nous avons détruit ce que faisaient Pharaon et son peuple, ainsi que ce qu'ils construisaient.\qt@no{(137)}}
\qt@newcmd\qurantrans@fr@mxcii{Et Nous avons fait traverser la Mer aux Enfants d'Israël. Ils passèrent auprès d'un peuple attaché à ses idoles et dirent: «O Moïse, désigne-nous une divinité semblable à leurs dieux.» Il dit: «Vous êtes certes des gens ignorants.\qt@no{(138)}}
\qt@newcmd\qurantrans@fr@mxciii{Le culte, auquel ceux-là s'adonnent, est caduc; et tout ce qu'ils font est nul et sans valeur.»\qt@no{(139)}}
\qt@newcmd\qurantrans@fr@mxciv{Il dit: «Chercherai-je pour vous une autre divinité qu'Allah, alors que c'est Lui qui vous a préférés à toutes les créatures [de leur époque]?»\qt@no{(140)}}
\qt@newcmd\qurantrans@fr@mxcv{(Rappelez-vous) le moment où Nous vous sauvâmes des gens de Pharaon qui vous infligeaient le pire châtiment. Ils massacraient vos fils et laissaient vivre vos femmes. C'était là une terrible épreuve de la part de votre Seigneur.\qt@no{(141)}}
\qt@newcmd\qurantrans@fr@mxcvi{Et Nous donnâmes à Moïse rendez-vous pendant trente nuits, et Nous les complétâmes par dix, de sorte que le temps fixé par son Seigneur se termina au bout de quarante nuits. Et Moïse dit à Aaron son frère: «Remplace-moi auprès de mon peuple, et agis en bien, et ne suis pas le sentier des corrupteurs».\qt@no{(142)}}
\qt@newcmd\qurantrans@fr@mxcvii{Et lorsque Moïse vint à Notre rendez-vous et que son Seigneur lui eut parlé, il dit: «O mon Seigneur, montre Toi à moi pour que je Te voie!» Il dit: «Tu ne Me verras pas; mais regarde le Mont: s'il tient en sa place, alors tu Me verras.» Mais lorsque son Seigneur Se manifesta au Mont, Il le pulvérisa, et Moïse s'effondra foudroyé. Lorsqu'il se fut remis, il dit: «Gloire à Toi! A Toi je me repens; et je suis le premier des croyants».\qt@no{(143)}}
\qt@newcmd\qurantrans@fr@mxcviii{Et (Allah) dit: «O Moïse, Je t'ai préféré à tous les hommes, par Mes messages et par Ma parole. Prends donc ce que Je te donne, et sois du nombre des reconnaissants».\qt@no{(144)}}
\qt@newcmd\qurantrans@fr@mxcix{Et Nous écrivîmes pour lui, sur les tablettes, une exhortation concernant toute chose, et un exposé détaillé de toute chose. «Prends-les donc fermement et commande à ton peuple d'en adopter le meilleur. Bientôt Je vous ferai voir la demeure des pervers.\qt@no{(145)}}
\qt@newcmd\qurantrans@fr@mc{J'écarterai de Mes signes ceux qui, sans raison, s'enflent d'orgueil sur terre. Même s'ils voyaient tous les miracles, ils n'y croiraient pas. Et s'ils voient le bon sentier, ils ne le prennent pas comme sentier. Mais s'ils voient le sentier de l'erreur, ils le prennent comme sentier. C'est qu'en vérité ils traitent de mensonges Nos preuves et ils ne leur accordaient aucune attention.\qt@no{(146)}}
\qt@newcmd\qurantrans@fr@mci{Et ceux qui traitent de mensonges Nos preuves ainsi que la rencontre de l'au-delà, leurs œuvres sont vaines. Seraient-ils rétribués autrement que selon leurs œuvres?»\qt@no{(147)}}
\qt@newcmd\qurantrans@fr@mcii{Et le peuple de Moïse adopta après lui un veau, fait de leurs parures: un corps qui semblait mugir. N'ont-ils pas vu qu'il ne leur parlait point et qu'il ne les guidait sur aucun chemin? Ils l'adoptèrent [comme divinité], et ils étaient des injustes.\qt@no{(148)}}
\qt@newcmd\qurantrans@fr@mciii{Et quand ils éprouvèrent des regrets, et qu'ils virent qu'ils étaient bel et bien égarés, ils dirent: «Si notre Seigneur ne nous fait pas miséricorde et ne nous pardonne pas, nous serons très certainement du nombre des perdants».\qt@no{(149)}}
\qt@newcmd\qurantrans@fr@mciv{Et lorsque Moïse retourna à son peuple, fâché, attristé, il dit: «Vous avez très mal agi pendant mon absence! Avez-vous voulu hâter le commandement de votre Seigneur?» Il jeta les tablettes et prit la tête de son frère, en la tirant à lui: «O fils de ma mère, dit (Aaron), le peuple m'a traité en faible, et peu s'en est fallu qu'ils ne me tuent. Ne fais donc pas que les ennemis se réjouissent à mes dépens, et ne m'assigne pas la compagnie des gens injustes».\qt@no{(150)}}
\qt@newcmd\qurantrans@fr@mcv{Et (Moïse) dit: «O mon Seigneur, pardonne à moi et à mon frère et fais-nous entrer en Ta miséricorde, car Tu es Le plus Miséricordieux des miséricordieux».\qt@no{(151)}}
\qt@newcmd\qurantrans@fr@mcvi{Ceux qui prenaient le veau (comme divinité), bientôt tombera sur eux de la part de leur Seigneur, une colère, et un avilissement dans la vie présente. Ainsi, Nous rétribuons les inventeurs (d'idoles).\qt@no{(152)}}
\qt@newcmd\qurantrans@fr@mcvii{Ceux qui ont fait de mauvaises actions et qui ensuite se sont repentis et ont cru... ton Seigneur, après cela est sûrement Pardonneur et Miséricordieux.\qt@no{(153)}}
\qt@newcmd\qurantrans@fr@mcviii{Et quand la colère de Moïse se fut calmée, il prit les tablettes. Il y avait dans leur texte guide et miséricorde à l'intention de ceux qui craignent leur Seigneur.\qt@no{(154)}}
\qt@newcmd\qurantrans@fr@mcix{Et Moïse choisit de son peuple soixante-dix hommes pour un rendez-vous avec Nous. Puis lorsqu'ils furent saisis par le tremblement (de terre), il dit: «Mon Seigneur, si Tu avais voulu, Tu les aurais détruits avant, et moi avec. Vas-Tu nous détruire pour ce que des sots d'entre nous ont fait? Ce n'est là qu'une épreuve de Toi, par laquelle Tu égares qui Tu veux, et guides qui Tu veux. Tu es notre Maître. Pardonne-nous et fais-nous miséricorde, car Tu es le Meilleur des pardonneurs.\qt@no{(155)}}
\qt@newcmd\qurantrans@fr@mcx{Et prescris pour nous le bien ici-bas ainsi que dans l'au-delà. Nous voilà revenus vers Toi, repentis.» Et (Allah) dit: «Je ferai que Mon châtiment atteigne qui Je veux. Et Ma miséricorde embrasse toute chose. Je la prescrirai à ceux qui (Me) craignent, acquittent la Zakât, et ont foi en Nos signes,\qt@no{(156)}}
\qt@newcmd\qurantrans@fr@mcxi{Ceux qui suivent le Messager, le Prophète illettré qu'ils trouvent écrit (mentionné) chez eux dans la Thora et l'Evangile. Il leur ordonne le convenable, leur défend le blâmable, leur rend licites les bonnes choses, leur interdit les mauvaises, et leur ôte le fardeau et les jougs qui étaient sur eux. Ceux qui croiront en lui, le soutiendront, lui porteront secours et suivront la lumière descendue avec lui; ceux-là seront les gagnants.\qt@no{(157)}}
\qt@newcmd\qurantrans@fr@mcxii{Dis: «O hommes! Je suis pour vous tous le Messager d'Allah, à Qui appartient la royauté des cieux et de la terre. Pas de divinité à part Lui. Il donne la vie et Il donne la mort. Croyez donc en Allah, en Son messager, le Prophète illettré qui croit en Allah et en Ses paroles. Et suivez-le afin que vous soyez bien guidés».\qt@no{(158)}}
\qt@newcmd\qurantrans@fr@mcxiii{Parmi le peuple de Moïse, il est une communauté qui guide (les autres) avec la vérité, et qui, par là, exerce la justice.\qt@no{(159)}}
\qt@newcmd\qurantrans@fr@mcxiv{Nous les répartîmes en douze tribus, (en douze) communautés. Et Nous révélâmes à Moïse, lorsque son peuple lui demanda de l'eau: «Frappe le rocher avec ton bâton.» Et voilà qu'en jaillirent douze sources. Chaque tribu sut son abreuvoir. Nous les couvrîmes de l'ombre du nuage, et fîmes descendre sur eux la manne et les cailles: «Mangez des bonnes choses que Nous vous avons attribuées.» Et ce n'est pas à Nous qu'ils ont fait du tort, mais c'est à eux-mêmes qu'ils en faisaient.\qt@no{(160)}}
\qt@newcmd\qurantrans@fr@mcxv{Et lorsqu'il leur fut dit: «Habitez cette cité et mangez [de ses produits] à votre guise, mais dites: rémission [à nos péchés] et entrez par la porte en vous prosternant. Nous vous pardonnerons vos fautes; et aux bienfaisants (d'entre vous,) Nous accorderons davantage».\qt@no{(161)}}
\qt@newcmd\qurantrans@fr@mcxvi{Puis, les injustes parmi eux changèrent en une autre, la parole qui leur était dite. Alors, Nous envoyâmes du ciel un châtiment sur eux, pour le méfait qu'ils avaient commis.\qt@no{(162)}}
\qt@newcmd\qurantrans@fr@mcxvii{Et interroge-les au sujet de la cité qui donnait sur la mer, lorsqu'on y transgressait le Sabbat! Que leurs poissons venaient à eux faisant surface, au jour de leur Sabbat, et ne venaient pas à eux le jour où ce n'était pas Sabbat! Ainsi les éprouvions-Nous pour la perversité qu'ils commettaient.\qt@no{(163)}}
\qt@newcmd\qurantrans@fr@mcxviii{Et quand parmi eux une communauté dit: «Pourquoi exhortez-vous un peuple qu'Allah va anéantir ou châtier d'un châtiment sévère?» Ils répondirent: «Pour dégager notre responsabilité vis-à-vis de votre Seigneur; et que peut-être ils deviendront pieux!»\qt@no{(164)}}
\qt@newcmd\qurantrans@fr@mcxix{Puis, lorsqu'ils oublièrent ce qu'on leur avait rappelé, Nous sauvâmes ceux qui (leur) avaient interdit le mal et saisîmes par un châtiment rigoureux les injustes pour leurs actes pervers.\qt@no{(165)}}
\qt@newcmd\qurantrans@fr@mcxx{Puis, lorsqu'ils refusèrent (par orgueil) d'abandonner ce qui leur avait été interdit, Nous leur dîmes: «Soyez des singes abjects».\qt@no{(166)}}
\qt@newcmd\qurantrans@fr@mcxxi{Et lorsque ton Seigneur annonça qu'Il enverra certes contre eux quelqu'un qui leur imposera le pire châtiment jusqu'au Jour de la Résurrection. En vérité ton Seigneur est prompt à punir mais Il est aussi Pardonneur et Miséricordieux.\qt@no{(167)}}
\qt@newcmd\qurantrans@fr@mcxxii{Et Nous les avons répartis en communautés sur la terre. Il y a parmi eux des gens de bien, mais il y en a qui le sont moins. Nous les avons éprouvés par des biens et par des maux, peut-être reviendraient-ils (au droit chemin).\qt@no{(168)}}
\qt@newcmd\qurantrans@fr@mcxxiii{Puis les suivirent des successeurs qui héritèrent le Livre, mais qui préférèrent ce qu'offre la vie d'ici-bas en disant: «Nous aurons le pardon.» Et si des choses semblables s'offrent à eux, ils les acceptent. N'avait-on pas pris d'eux l'engagement du Livre, qu'ils ne diraient sur Allah que la vérité? Ils avaient pourtant étudié ce qui s'y trouve. Et l'ultime demeure est meilleure pour ceux qui pratiquent la piété, - Ne comprendrez-vous donc pas? -\qt@no{(169)}}
\qt@newcmd\qurantrans@fr@mcxxiv{Et ceux qui se conforment au Livre et accomplissent laSalât, [en vérité], Nous ne laissons pas perdre la récompense de ceux qui s'amendent.\qt@no{(170)}}
\qt@newcmd\qurantrans@fr@mcxxv{Et lorsque Nous avons brandi au-dessus d'eux le Mont, comme si c'eût été une ombrelle. Ils pensaient qu'il allait tomber sur eux. «Tenez fermement à ce que Nous vous donnons et rappelez-vous son contenu. Peut-être craindrez vous Allah».\qt@no{(171)}}
\qt@newcmd\qurantrans@fr@mcxxvi{Et quand ton Seigneur tira une descendance des reins des fils d'Adam et les fit témoigner sur eux-mêmes: «Ne suis-Je pas votre Seigneur?» Ils répondirent: «Mais si, nous en témoignons...» - afin que vous ne disiez point, au Jour de la Résurrection: «Vraiment, nous n'y avons pas fait attention»,\qt@no{(172)}}
\qt@newcmd\qurantrans@fr@mcxxvii{ou que vous auriez dit (tout simplement): «Nos ancêtres autrefois donnaient des associés à Allah, et nous sommes leurs descendants, après eux. Vas-Tu nous détruire pour ce qu'ont fait les imposteurs?»\qt@no{(173)}}
\qt@newcmd\qurantrans@fr@mcxxviii{Et c'est ainsi que Nous expliquons intelligemment les signes. Peut-être reviendront-ils!\qt@no{(174)}}
\qt@newcmd\qurantrans@fr@mcxxix{Et raconte-leur l'histoire de celui à qui Nous avions donné Nos signes et qui s'en écarta. Le Diable, donc, l'entraîna dans sa suite et il devint ainsi du nombre des égarés.\qt@no{(175)}}
\qt@newcmd\qurantrans@fr@mcxxx{Et si Nous avions voulu, Nous l'aurions élevé par ces mêmes enseignements, mais il s'inclina vers la terre et suivit sa propre passion. Il est semblable à un chien qui halète si tu l'attaques, et qui halète aussi si tu le laisses. Tel est l'exemple des gens qui traitent de mensonges Nos signes. Eh bien, raconte le récit. Peut-être réfléchiront-ils!\qt@no{(176)}}
\qt@newcmd\qurantrans@fr@mcxxxi{Quel mauvais exemple que ces gens qui traitent de mensonges Nos signes, cependant que c'est à eux-mêmes qu'ils font du tort.\qt@no{(177)}}
\qt@newcmd\qurantrans@fr@mcxxxii{Quiconque Allah guide, voilà le bien guidé. Et quiconque Il égare, voilà les perdants.\qt@no{(178)}}
\qt@newcmd\qurantrans@fr@mcxxxiii{Nous avons destiné beaucoup de djinns et d'hommes pour l'Enfer. Ils ont des cœurs, mais ne comprennent pas. Ils ont des yeux, mais ne voient pas. Ils ont des oreilles, mais n'entendent pas. Ceux-là sont comme les bestiaux, même plus égarés encore. Tels sont les insouciants.\qt@no{(179)}}
\qt@newcmd\qurantrans@fr@mcxxxiv{C'est à Allah qu'appartiennent les noms les plus beaux. Invoquez-Le par ces noms et laissez ceux qui profanent Ses noms: ils seront rétribués pour ce qu'ils ont fait.\qt@no{(180)}}
\qt@newcmd\qurantrans@fr@mcxxxv{Parmi ceux que Nous avons créés, il y a une communauté qui guide (les autres) selon la vérité et par celle-ci exerce la justice.\qt@no{(181)}}
\qt@newcmd\qurantrans@fr@mcxxxvi{Ceux qui traitent de mensonges Nos enseignements, Nous allons les conduire graduellement vers leur perte par des voies qu'ils ignorent.\qt@no{(182)}}
\qt@newcmd\qurantrans@fr@mcxxxvii{Et Je leur accorderai un délai, car Mon stratagème est solide!\qt@no{(183)}}
\qt@newcmd\qurantrans@fr@mcxxxviii{Est-ce qu'ils n'ont pas réfléchi? Il n'y a point de folie en leur compagnon (Muhammad): il n'est qu'un avertisseur explicite!\qt@no{(184)}}
\qt@newcmd\qurantrans@fr@mcxxxix{N'ont-ils pas médité sur le royaume des cieux et de la terre, et toute chose qu'Allah a créée, et que leur terme est peut-être déjà proche? En quelle parole croiront-ils après cela?\qt@no{(185)}}
\qt@newcmd\qurantrans@fr@mcxl{Quiconque Allah égare, pas de guide pour lui. Et Il les laisse dans leur transgression confus et hésitants.\qt@no{(186)}}
\qt@newcmd\qurantrans@fr@mcxli{Ils t'interrogent sur l'Heure: «Quand arrivera-t-elle?» Dis: «Seul mon Seigneur en a connaissance. Lui seul la manifestera en son temps. Lourde elle sera dans les cieux et (sur) la terre et elle ne viendra à vous que soudainement.» Ils t'interrogent comme si tu en étais averti. Dis: «Seul Allah en a connaissance.» Mais beaucoup de gens ne savent pas.\qt@no{(187)}}
\qt@newcmd\qurantrans@fr@mcxlii{Dis: «Je ne détiens pour moi-même ni profit ni dommage, sauf ce qu'Allah veut. Et si je connaissais l'Inconnaissable, j'aurais eu des biens en abondance et aucun mal ne m'aurait touché. Je ne suis, pour les gens qui croient, qu'un avertisseur et un annonciateur».\qt@no{(188)}}
\qt@newcmd\qurantrans@fr@mcxliii{C'est Lui qui vous a créés d'un seul être dont il a tiré son épouse, pour qu'il trouve de la tranquillité auprès d'elle; et lorsque celui-ci eut cohabité avec elle, elle conçut une légère grossesse, avec quoi elle se déplaçait (facilement). Puis lorsqu'elle se trouva alourdie, tous deux invoquèrent leur Seigneur: «Si Tu nous donnes un (enfant) sain, nous serons certainement du nombre des reconnaissants».\qt@no{(189)}}
\qt@newcmd\qurantrans@fr@mcxliv{Puis, lorsqu'Il leur eût donné un (enfant) sain, tous deux assignèrent à Allah des associés en ce qu'Il leur avait donné. Mais Allah est bien au-dessus des associés qu'on Lui assigne.\qt@no{(190)}}
\qt@newcmd\qurantrans@fr@mcxlv{Est-ce qu'ils assignent comme associés ce qui ne crée rien et qui eux-mêmes sont créés,\qt@no{(191)}}
\qt@newcmd\qurantrans@fr@mcxlvi{et qui ne peuvent ni les secourir ni se secourir eux-mêmes?\qt@no{(192)}}
\qt@newcmd\qurantrans@fr@mcxlvii{Si vous les appelez vers le chemin droit, ils ne vous suivront pas. Le résultat pour vous est le même, que vous les appeliez ou que vous gardiez le silence.\qt@no{(193)}}
\qt@newcmd\qurantrans@fr@mcxlviii{Ceux que vous invoquez en dehors d'Allah sont des serviteurs comme vous. Invoquez-les donc et qu'ils vous répondent, si vous êtes véridiques.\qt@no{(194)}}
\qt@newcmd\qurantrans@fr@mcxlix{Ont-ils des jambes pour marcher? Ont-ils de mains pour frapper? Ont-ils des yeux pour observer? Ont-ils des oreilles pour entendre? Dis: «Invoquez vos associés, et puis, rusez contre moi; et ne me donnez pas de répit.\qt@no{(195)}}
\qt@newcmd\qurantrans@fr@mcl{Certes mon Maître, c'est Allah qui a fait descendre le Livre (le Coran). C'est Lui qui se charge (de la protection) des vertueux.\qt@no{(196)}}
\qt@newcmd\qurantrans@fr@mcli{Et ceux que vous invoquez en dehors de Lui ne sont capables ni de vous secourir, ni de se secourir eux-mêmes.»\qt@no{(197)}}
\qt@newcmd\qurantrans@fr@mclii{Et si tu les appelles vers le chemin droit, ils n'entendent pas. Tu les vois qui te regardent, (mais) ils ne voient pas.\qt@no{(198)}}
\qt@newcmd\qurantrans@fr@mcliii{Accepte ce qu'on t'offre de raisonnable, commande ce qui est convenable et éloigne-toi des ignorants.\qt@no{(199)}}
\qt@newcmd\qurantrans@fr@mcliv{Et si jamais le Diable t'incite à faire le mal, cherche refuge auprès d'Allah. Car Il entend, et sait tout.\qt@no{(200)}}
\qt@newcmd\qurantrans@fr@mclv{Ceux qui pratiquent la piété, lorsqu'une suggestion du Diable les touche se rappellent [du châtiment d'Allah]: et les voilà devenus clairvoyants.\qt@no{(201)}}
\qt@newcmd\qurantrans@fr@mclvi{(Quant aux méchants), leurs partenaires diaboliques les enfoncent dans l'aberration, puis ils ne cessent (de s'enfoncer).\qt@no{(202)}}
\qt@newcmd\qurantrans@fr@mclvii{Quand tu ne leur apportes pas de miracle, ils disent: «Pourquoi ne l'inventes-tu pas?» Dis: «Je ne fais que suivre ce qui m'est révélé de mon Seigneur. Ces [versets coraniques] sont des preuves illuminantes venant de votre Seigneur, un guide et une grâce pour des gens qui croient.\qt@no{(203)}}
\qt@newcmd\qurantrans@fr@mclviii{Et quand on récite le Coran, prêtez-lui l'oreille attentivement et observez le silence, afin que vous obteniez la miséricorde (d'Allah).\qt@no{(204)}}
\qt@newcmd\qurantrans@fr@mclix{Et invoque ton Seigneur en toi-même, en humilité et crainte, à mi-voix, le matin et le soir, et ne sois pas du nombre des insouciants.\qt@no{(205)}}
\qt@newcmd\qurantrans@fr@mclx{Ceux qui sont auprès de ton Seigneur [les anges] ne dédaignent pas de L'adorer. Ils Le glorifient et se prosternent devant Lui.\qt@no{(206)}}
\qt@newcmd\qurantrans@fr@mclxi{\basmalahfr Ils t'interrogent au sujet du butin. Dis: «Le butin est à Allah et à Son messager.» Craignez Allah, maintenez la concorde entre vous et obéissez à Allah et à Son messager, si vous êtes croyants.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mclxii{Les vrais croyants sont ceux dont les cœurs frémissent quand on mentionne Allah. Et quand Ses versets leur sont récités, cela fait augmenter leur foi. Et ils placent leur confiance en leur Seigneur.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mclxiii{Ceux qui accomplissent la Salât et qui dépensent [dans le sentier d'Allah] de ce que Nous leur avons attribué.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mclxiv{Ceux-là sont, en toute vérité les croyants: à eux des degrés (élevés) auprès de leur Seigneur, ainsi qu'un pardon et une dotation généreuse.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mclxv{De même, c'est au nom de la vérité que ton Seigneur t'a fait sortir de ta demeure, malgré la répulsion d'une partie des croyants.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mclxvi{Ils discutent avec toi au sujet de la vérité après qu'elle fut clairement apparue; comme si on les poussait vers la mort et qu'ils (la) voyaient.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mclxvii{(Rappelez-vous), quand Allah vous promettait qu'une des deux bandes sera à vous. Vous désiriez vous emparer de celle qui était sans armes, alors qu'Allah voulait par Ses paroles faire triompher la vérité et anéantir les mécréants jusqu'au dernier.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mclxviii{afin qu'Il fasse triompher la vérité et anéantir le faux, en dépit de la répulsion qu'en avaient les criminels.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mclxix{(Et rappelez-vous) le moment où vous imploriez le secours de votre Seigneur et qu'Il vous exauça aussitôt: «Je vais vous aider d'un millier d'Anges déferlant les uns à la suite des autres.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mclxx{Allah ne fit cela que pour (vous) apporter une bonne nouvelle et pour qu'avec cela vos cœurs se tranquillisent. Il n'y a de victoire que de la part d'Allah. Allah est Puissant et Sage.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mclxxi{Et quand Il vous enveloppa de sommeil comme d'une sécurité de Sa part, et du ciel Il fit descendre de l'eau sur vous afin de vous en purifier, d'écarter de vous la souillure du Diable, de renforcer les cœurs et d'en raffermir les pas! [vos pas].\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mclxxii{Et ton Seigneur révéla aux Anges: «Je suis avec vous: affermissez donc les croyants. Je vais jeter l'effroi dans les cœurs des mécréants. Frappez donc au-dessus des cous et frappez-les sur tous les bouts des doigts.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mclxxiii{Ce, parce qu'ils ont désobéi à Allah et à Son messager.» Et quiconque désobéit à Allah et à Son messager... Allah est certainement dur en punition!\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mclxxiv{Voilà (votre sort); goûtez-le donc! Et aux mécréants le châtiment du Feu (sera réservé).\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mclxxv{O vous qui croyez quand vous rencontrez (l'armée) des mécréants en marche, ne leur tournez point le dos.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mclxxvi{Quiconque, ce jour-là, leur tourne le dos, - à moins que ce soit par tactique de combat, ou pour rallier un autre groupe, - celui-là encourt la colère d'Allah et son refuge sera l'Enfer. Et quelle mauvaise destination!\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mclxxvii{Ce n'est pas vous qui les avez tués: mais c'est Allah qui les a tués. Et lorsque tu lançais (une poignée de terre), ce n'est pas toi qui lançais: mais c'est Allah qui lançait, et ce pour éprouver les croyants d'une belle épreuve de Sa part! Allah est Audient et Omniscient.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mclxxviii{Voilà! Allah réduit à rien la ruse des mécréants.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mclxxix{Si vous avez imploré l'arbitrage d'Allah vous connaissez maintenant la sentence [d'Allah] Et si vous cessez [la mécréance et l'hostilité contre le Prophète..], c'est mieux pour vous. Mais si vous revenez, Nous reviendrons, et votre masse, même nombreuse, ne vous sera d'aucune utilité. Car Allah est vraiment avec les croyants.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mclxxx{O vous qui croyez! Obéissez à Allah et à Son messager et ne vous détournez pas de lui quand vous l'entendez (parler).\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mclxxxi{Et ne soyez pas comme ceux qui disent: «Nous avons entendu», alors qu'ils n'entendent pas.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mclxxxii{Les pires des bêtes auprès d'Allah, sont, [en vérité], les sourds-muets qui ne raisonnent pas.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mclxxxiii{Et si Allah avait reconnu en eux quelque bien, Il aurait fait qu'ils entendent. Mais, même s'Il les faisait entendre, ils tourneraient [sûrement] le dos en s'éloignant.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mclxxxiv{O vous qui croyez! Répondez à Allah et au Messager lorsqu'il vous appelle à ce qui vous donne la (vraie) vie, et sachez qu'Allah s'interpose entre l'homme et son cœur, et que c'est vers Lui que vous serez rassemblés.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mclxxxv{Et craignez une calamité qui n'affligera pas exclusivement les injustes d'entre vous. Et sachez qu'Allah est dur en punition.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mclxxxvi{Et rappelez-vous quand vous étiez peu nombreux, opprimés sur terre, craignant de vous faire enlever par des gens. Il vous donna asile, vous renforça de Son secours et vous attribua de bonnes choses afin que vous soyez reconnaissants.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mclxxxvii{O vous qui croyez! Ne trahissez pas Allah et le Messager. Ne trahissez pas sciemment la confiance qu'on a placée en vous?\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mclxxxviii{Et sachez que vos biens et vos enfants ne sont qu'une épreuve et qu'auprès d'Allah il y a une énorme récompense.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mclxxxix{O vous qui croyez! Si vous craignez Allah, Il vous accordera la faculté de discerner (entre le bien et le mal), vous effacera vos méfaits et vous pardonnera. Et Allah est le Détenteur de l'énorme grâce.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mcxc{(Et rappelle-toi) le moment où les mécréants complotaient contre toi pour t'emprisonner ou t'assassiner ou te bannir. Ils complotèrent. mais Allah a fait échouer leur complot, et Allah est le meilleur en stratagèmes.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mcxci{Et lorsque Nos versets leur sont récités, ils disent: «Nous avons écouté, certes! Si nous voulions, nous dirions pareil à cela, ce ne sont que des légendes d'anciens.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mcxcii{Et quand ils dirent: «O Allah, si cela est la vérité de Ta part, alors, fais pleuvoir du ciel des pierres sur nous, ou fais venir sur nous un châtiment douloureux».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mcxciii{Allah n'est point tel qu'Il les châtie, alors que tu es au milieu d'eux. Et Allah n'est point tel qu'il les châtie alors qu'Ils demandent pardon.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mcxciv{Qu'ont-ils donc pour qu'Allah ne les châtie pas, alors qu'ils repoussent (les croyants) de la Mosquée sacrée, quoiqu'ils n'en soient pas les gardiens, car ses gardiens ne sont que les pieux. Mais la plupart d'entre eux ne le savent pas.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mcxcv{Et leur prière, auprès de la Maison, n'est que sifflement et battements de mains: «Goûtez donc au châtiment, à cause de votre mécréance!»\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mcxcvi{Ceux qui ne croient pas dépensent leurs biens pour éloigner (les gens) du sentier d'Allah. Or, après les avoir dépensés, ils seront pour eux un sujet de regret. Puis ils seront vaincus, et tous ceux qui ne croient pas seront rassemblés vers l'Enfer,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mcxcvii{afin qu'Allah distingue le mauvais du bon, et qu'Il place les mauvais les uns sur les autres, pour en faire un amoncellement qu'Il jettera dans l'Enfer. Ceux-là sont les perdants.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mcxcviii{Dis à ceux qui ne croient pas que, s'ils cessent, on leur pardonnera ce qui s'est passé. Et s'ils récidivent, (ils seront châtiés); à l'exemple de (leurs) devanciers.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mcxcix{Et combattez-les jusqu'à ce qu'il ne subsiste plus d'association, et que la religion soit entièrement à Allah. Puis, s'ils cessent (ils seront pardonnés car) Allah observe bien ce qu'ils œuvrent.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mcc{Et s'ils tournent le dos, sachez alors qu'Allah est votre Maître. Quel excellent Maître et quel excellent Protecteur!\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mcci{Et sachez que, de tout butin que vous avez ramassé, le cinquième appartient à Allah, au messager, à ses proches parents, aux orphelins, aux pauvres, et aux voyageurs (en détresse), si vous croyez en Allah et en ce que Nous avons fait descendre sur Notre serviteur, le jour du Discernement: le jour où les deux groupes s'étaient rencontrés, et Allah est Omnipotent.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mccii{Vous étiez sur le versant le plus proche, et eux (les ennemis) sur le versant le plus éloigné, tandis que la caravane était plus bas que vous. Si vous vous étiez donné rendez-vous, vous l'auriez manqué (effrayés par le nombre de l'ennemi). Mais il fallait qu'Allah accomplît un ordre qui devait être exécuté, pour que, sur preuve, pérît celui qui (devait) périr, et vécût, sur preuve, celui qui (devait) vivre. Et certes Allah est Audient et Omniscient.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mcciii{En songe, Allah te les avait montrés peu nombreux! Car s'Il te les avait montrés nombreux, vous auriez certainement fléchi, et vous vous seriez certainement disputés à propos de l'affaire. Mais Allah vous en a préservés. Il connait le contenu des cœurs.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mcciv{Et aussi, au moment de la rencontre, Il vous les montrait peu nombreux à Vos yeux, de même qu'Il vous faisant paraître à leurs yeux peu nombreux afin qu'Allah parachève un ordre qui devait être exécuté. C'est à Allah que sont ramenées les choses.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mccv{O vous qui croyez! Lorsque vous rencontrez une troupe (ennemie), soyez fermes, et invoquez beaucoup Allah afin de réussir.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mccvi{Et obéissez à Allah et à Son messager; et ne vous disputez pas, sinon vous fléchirez et perdrez votre force. Et soyez endurants, car Allah est avec les endurants.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mccvii{Et ne soyez pas comme ceux qui sortirent de leurs demeures pour repousser la vérité et avec ostentation publique, obstruant le chemin d'Allah. Et Allah cerne ce qu'ils font.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mccviii{Et quand le Diable leur eut embelli leurs actions et dit: «Nul parmi les humains ne peut vous dominer aujourd'hui, et je suis votre soutien.» Mais, lorsque les deux groupes furent en vue l'un de l'autre, il tourna les deux talons et dit: «Je vous désavoue. Je vois ce que vous ne voyez pas; je crains Allah, et Allah est dur en punition».\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mccix{(Et rappelez-vous), quand les hypocrites et ceux qui ont une maladie au cœur [dont la foi est douteuse] disaient: «Ces gens-là, leur religion les trompe.» Mais quiconque place sa confiance en Allah (sera victorieux)... car Allah est Puissant et Sage.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mccx{Si tu voyais, lorsque les Anges arrachaient les âmes aux mécréants! Ils les frappaient sur leurs visages et leurs derrières, (en disant): «Goûtez au châtiment du Feu.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mccxi{Cela (le châtiment), pour ce que vos mains ont accompli.» Et Allah n'est point injuste envers les esclaves.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mccxii{Il en fut de même des gens de Pharaon et ceux qui avant eux n'avaient pas cru aux signes (enseignements) d'Allah. Allah les saisit pour leurs péchés. Allah est certes Fort et sévère en punition.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mccxiii{C'est qu'en effet Allah ne modifie pas un bienfait dont Il a gratifié un peuple avant que celui-ci change ce qui est en lui-même. Et Allah est, Audient et Omniscient.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mccxiv{Il en fut de même des gens de Pharaon et ceux qui avant eux avaient traité de mensonges les signes (enseignements) de leur Seigneur. Nous les avons fait périr pour leurs péchés. Et Nous avons noyé les gens de Pharaon. Car ils étaient tous des injustes.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mccxv{Les pires bêtes, auprès d'Allah, sont ceux qui ont été infidèles (dans le passé) et qui ne croient donc point (actuellement),\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mccxvi{ceux-là mêmes avec lesquels tu as fait un pacte et qui chaque fois le rompent, sans aucune crainte [d'Allah].\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mccxvii{Donc, si tu les maîtrises à la guerre, inflige-leur un châtiment exemplaire de telle sorte que ceux qui sont derrière eux soient effarouchés. Afin qu'ils se souviennent.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mccxviii{Et si jamais tu crains vraiment une trahison de la part d'un peuple, dénonce alors le pacte (que tu as conclu avec), d'une façon franche et loyale car Allah n'aime pas les traîtres.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mccxix{Que les mécréants ne pensent pas qu'ils Nous ont échappé. Non, ils ne pourront jamais Nous empêcher (de les rattraper à n'importe quel moment).\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mccxx{Et préparez [pour lutter] contre eux tout ce que vous pouvez comme force et comme cavalerie équipée, afin d'effrayer l'ennemi d'Allah et le vôtre, et d'autres encore que vous ne connaissez pas en dehors de ceux-ci mais qu'Allah connaît. Et tout ce que vous dépensez dans le sentier d'Allah vous sera remboursé pleinement et vous ne serez point lésés.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mccxxi{Et s'ils inclinent à la paix, incline vers celle-ci (toi aussi) et place ta confiance en Allah, car c'est Lui l'Audient, l'Omniscient.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mccxxii{Et s'ils veulent te tromper, alors Allah te suffira. C'est Lui qui t'a soutenu par Son secours, ainsi que par (l'assistance) des croyants.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mccxxiii{Il a uni leurs cœurs (par la foi). Aurais-tu dépensé tout ce qui est sur terre, tu n'aurais pu unir leurs cœurs; mais c'est Allah qui les a unis, car Il est Puissant et Sage.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mccxxiv{O Prophète, Allah et ceux des croyants qui te suivent te suffisent.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mccxxv{O Prophète, incite les croyants au combat. S'il se trouve parmi vous vingt endurants, ils vaincront deux cents; et s'il s'en trouve cent, ils vaincront mille mécréants, car ce sont vraiment des gens qui ne comprennent pas.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mccxxvi{Maintenant, Allah a allégé votre tâche, sachant qu'il y a de la faiblesse en vous. S'il y a cent endurants parmi vous, ils vaincront deux cents; et s'il y en a mille, ils vaincront deux mille, par la grâce d'Allah. Et Allah est avec les endurants.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mccxxvii{Un prophète ne devrait pas faire de prisonniers avant d'avoir prévalu [mis les mécréants hors de combat] sur la terre. Vous voulez les biens d'ici-bas, tandis qu'Allah veut l'au-delà. Allah est Puissant et Sage.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mccxxviii{N'eût-été une prescription préalable d'Allah, un énorme châtiment vous aurait touché pour ce que vous avez pris. [de la rançon]\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mccxxix{Mangez donc de ce qui vous est échu en butin, tant qu'il est licite et pur. Et craignez Allah, car Allah est Pardonneur et Miséricordieux.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mccxxx{O Prophète, dis aux captifs qui sont entre vos mains: «Si Allah sait qu'il y a quelque bien dans vos cœurs, Il vous donnera mieux que ce qui vous a été pris et vous pardonnera. Allah est Pardonneur et Miséricordieux.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mccxxxi{Et s'ils veulent te trahir..., c'est qu'ils ont déjà trahi Allah [par la mécréance]; mais Il a donné prise sur eux [le jour de Badr]. Et Allah est Omniscient et Sage.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mccxxxii{Ceux qui ont cru, émigré et lutté de leurs biens et de leurs personnes dans le sentier d'Allah, ainsi que ceux qui leur ont donné refuge et secours, ceux-là sont alliés les uns des autres. Quant à ceux qui ont cru et n'ont pas émigré, vous ne serez pas liés à eux, jusqu'à ce qu'ils émigrent. Et s'ils vous demandent secours au nom de la religion, à vous alors de leur porter secours, mais pas contre un peuple auquel vous êtes liés par un pacte. Et Allah observe bien ce que vous œuvrez.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mccxxxiii{Et ceux qui n'ont pas cru sont alliés les uns des autres. Si vous n'agissez pas ainsi [en rompant les liens avec les infidèles], il y aura discorde sur terre et grand désordre.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mccxxxiv{Et ceux qui ont cru, émigré et lutté dans le sentier d'Allah, ainsi que ceux qui leur ont donné refuge et porté secours, ceux-là sont les vrais croyants: à eux, le pardon et une récompense généreuse.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mccxxxv{Et ceux qui après cela ont cru et émigré et lutté en votre compagnie, ceux-là sont des vôtres. Cependant ceux qui sont liés par la parenté ont priorité les uns envers les autres, d'après le Livre d'Allah. Certes, Allah est Omniscient.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mccxxxvi{\basmalahfr Désaveu de la part d'Allah et de Son messager à l'égard des associateurs avec qui vous avez conclu un pacte:\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mccxxxvii{Parcourez la terre durant quatre mois; et sachez que vous ne réduirez pas Allah à l'impuissance et qu'Allah couvre d'ignominie les mécréants.»\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mccxxxviii{Et proclamation aux gens, de la part d'Allah et de Son messager, au jour du Grand Pèlerinage, qu'Allah et Son messager, désavouent les associateurs. Si vous vous repentez, ce sera mieux pour vous. Mais si vous vous détournez, sachez que vous ne réduirez pas Allah à l'impuissance. Et annonce un châtiment douloureux à ceux qui ne croient pas.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mccxxxix{A l'exception des associateurs avec lesquels vous avez conclu un pacte, puis ils ne vous ont manqué en rien, et n'ont soutenu personne [à lutter] contre vous: respectez pleinement le pacte conclu avec eux jusqu'au terme convenu. Allah aime les pieux.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mccxl{Après que les mois sacrés expirent, tuez les associateurs où que vous les trouviez. Capturez-les, assiégez-les et guettez-les dans toute embuscade. Si ensuite ils se repentent, accomplissent la Salât et acquittent la Zakât, alors laissez-leur la voie libre, car Allah est Pardonneur et Miséricordieux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mccxli{Et si l'un des associateurs te demande asile, accorde-le lui, afin qu'il entende la parole d'Allah, puis fais-le parvenir à son lieu de sécurité. Car ce sont des gens qui ne savent pas.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mccxlii{Comment y aurait-il pour les associateurs un pacte admis par Allah et par Son messager? A l'exception de ceux avec lesquels vous avez conclu un pacte près de la Mosquée sacrée. Tant qu'ils sont droits envers vous, soyez droits envers eux. Car Allah aime les pieux.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mccxliii{Comment donc! Quand ils triomphent de vous, ils ne respectent à votre égard, ni parenté ni pacte conclu. Ils vous satisfont de leurs bouches, tandis que leurs cœurs se refusent; et la plupart d'entre eux sont des pervers.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mccxliv{Ils troquent à vil prix les versets d'Allah (le Coran) et obstruent Son chemin. Ce qu'ils font est très mauvais!\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mccxlv{Ils ne respectent, à l'égard d'un croyant, ni parenté ni pacte conclu. Et ceux-là sont les transgresseurs.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mccxlvi{Mais s'ils se repentent, accomplissent la Salât et acquittent la Zakat, ils deviendront vos frères en religion. Nous exposons intelligiblement les versets pour des gens qui savent.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mccxlvii{Et si, après le pacte, ils violent leurs serments et attaquent votre religion, combattez alors les chefs de la mécréance - car, ils ne tiennent aucun serment - peut-être cesseront-ils?\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mccxlviii{Ne combattrez-vous pas des gens qui ont violé leurs serments, qui ont voulu bannir le Messager et alors que ce sont eux qui vous ont attaqués les premiers? Les redoutiez-vous? C'est Allah qui est plus digne de votre crainte si vous êtes croyants!\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mccxlix{Combattez-les. Allah, par vos mains, les châtiera, les couvrira d'ignominie, vous donnera la victoire sur eux et guérira les poitrines d'un peuple croyant.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mccl{Et il fera partir la colère de leurs cœurs. Allah accueille le repentir de qui Il veut. Allah est Omniscient et Sage.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mccli{Pensez-vous que vous serez délaissés, cependant qu'Allah n'a pas encore distingué ceux d'entre vous qui ont lutté et qui n'ont pas cherché des alliés en dehors d'Allah, de Son messager et des croyants? Et Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mcclii{Il n'appartient pas aux associateurs de peupler les mosquées d'Allah, vu qu'ils témoignent contre eux-mêmes de leur mécréance. Voilà ceux dont les œuvres sont vaines; et dans le Feu ils demeureront éternellement.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mccliii{Ne peupleront les mosquées d'Allah que ceux qui croient en Allah et au Jour dernier, accomplissent la Salât, acquittent la Zakât et ne craignent qu'Allah. Il se peut que ceux-là soient du nombre des bien-guidés.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mccliv{Ferez-vous de la charge de donner à boire aux pèlerins et d'entretenir la Mosquée sacrée (des devoirs) comparables [au mérite] de celui qui croit en Allah et au Jour dernier et lutte dans le sentier d'Allah? Ils ne sont pas égaux auprès d'Allah et Allah ne guide pas les gens injustes.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mcclv{Ceux qui ont cru, qui ont émigré et qui ont lutté par leurs biens et leurs personnes dans le sentier d'Allah, ont les plus hauts rangs auprès d'Allah... et ce sont eux les victorieux.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mcclvi{Leur Seigneur leur annonce de Sa part, miséricorde et agrément, et des Jardins où il y aura pour eux un délice permanent\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mcclvii{où ils demeureront éternellement. Certes il y a auprès d'Allah une énorme récompense.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mcclviii{O vous qui croyez! Ne prenez pas pour alliés, vos pères et vos frères s'ils préfèrent la mécréance à la foi. Et quiconque parmi vous les prend pour alliés... ceux-là sont les injustes.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mcclix{Dis: «Si vos pères, vos enfants, vos frères, vos épouses, vos clans, les biens que vous gagnez, le négoce dont vous craignez le déclin et les demeures qui vous sont agréables, vous sont plus chers qu'Allah, Son messager et la lutte dans le sentier d'Allah, alors attendez qu'Allah fasse venir Son ordre. Et Allah ne guide pas les gens pervers».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mcclx{Allah vous a déjà secourus en maints endroits. Et [rappelez-vous] le jour de Hunayn, quand vous étiez fiers de votre grand nombre et que cela ne vous a servi à rien. La terre, malgré son étendue vous devint bien étroite; puis vous avez tourné le dos en fuyards.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mcclxi{Puis, Allah fit descendre Sa quiétude [Sa «sakîna»] sur Son messager et sur les croyants. Il fit descendre des troupes (Anges) que vous ne voyiez pas, et châtia ceux qui ont mécru. Telle est la rétribution des mécréants.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mcclxii{Après cela Allah, accueillera le repentir de qui Il veut, car Allah est Pardonneur et Miséricordieux.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mcclxiii{O vous qui croyez! Les associateurs ne sont qu'impureté: qu'ils ne s'approchent plus de la Mosquée sacrée, après cette année-ci. Et si vous redoutez une pénurie, Allah vous enrichira, s'Il veut, de par Sa grâce. Car Allah est Omniscient et Sage.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mcclxiv{Combattez ceux qui ne croient ni en Allah ni au Jour dernier, qui n'interdisent pas ce qu'Allah et Son messager ont interdit et qui ne professent pas la religion de la vérité, parmi ceux qui ont reçu le Livre, jusqu'à ce qu'ils versent la capitation par leurs propres mains, après s'être humiliés.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mcclxv{Les Juifs disent: «'Uzayr est fils d'Allah» et les Chrétiens disent: «Le Christ est fils d'Allah». Telle est leur parole provenant de leurs bouches. Ils imitent le dire des mécréants avant eux. Qu'Allah les anéantisse! Comment s'écartent-ils (de la vérité)?\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mcclxvi{Ils ont pris leurs rabbins et leurs moines, ainsi que le Christ fils de Marie, comme Seigneurs en dehors d'Allah, alors qu'on ne leur a commandé que d'adorer un Dieu unique. Pas de divinité à part Lui! Gloire à Lui! Il est au-dessus de ce qu'ils [Lui] associent.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mcclxvii{Ils veulent éteindre avec leurs bouches la lumière d'Allah, alors qu'Allah ne veut que parachever Sa lumière, quelque répulsion qu'en aient les mécréants.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mcclxviii{C'est Lui qui a envoyé Son messager avec la bonne direction et la religion de la vérité, afin qu'elle triomphe sur toute autre religion, quelque répulsion qu'en aient les associateurs.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mcclxix{O vous qui croyez! Beaucoup de rabbins et de moines dévorent, les biens des gens illégalement et [leur] obstruent le sentier d'Allah. A ceux qui thésaurisent l'or et l'argent et ne les dépensent pas dans le sentier d'Allah, annonce un châtiment douloureux,\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mcclxx{le jour où (ces trésors) seront portés à l'incandescence dans le feu de l'Enfer et qu'ils en seront cautérisés, front, flancs et dos: voici ce que vous avez thésaurisé pour vous-mêmes. Goûtez de ce que vous thésaurisiez.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mcclxxi{Le nombre de mois, auprès d'Allah, est de douze [mois], dans la prescription d'Allah, le jour où Il créa les cieux et la terre. Quatre d'entre eux sont sacrés: telle est la religion droite. [Durant ces mois], ne faites pas de tort à vous-mêmes. Combattez les associateurs sans exception, comme ils vous combattent sans exception. Et sachez qu'Allah est avec les pieux.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mcclxxii{Le report d'un mois sacré à un autre est un surcroît de mécréance. Par là, les mécréants sont égarés: une année, ils le font profane, et une année, ils le font sacré, afin d'ajuster le nombre de mois qu'Allah a fait sacrés. Ainsi rendent-ils profane ce qu'Allah a fait sacré. Leurs méfaits leurs sont enjolivés. Et Allah ne guide pas les gens mécréants.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mcclxxiii{O vous qui croyez! Qu'avez-vous? Lorsque l'on vous a dit: «Elancez-vous dans le sentier d'Allah» vous vous êtes appesantis sur la terre. La vie présente vous agrée-t-elle plus que l'au-delà? - Or, la jouissance de la vie présente ne sera que peu de chose, comparée à l'au-delà!\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mcclxxiv{Si vous ne vous lancez pas au combat, Il vous châtiera d'un châtiment douloureux et vous remplacera par un autre peuple. Vous ne Lui nuirez en rien. Et Allah est Omnipotent.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mcclxxv{Si vous ne lui portez pas secours... Allah l'a déjà secouru, lorsque ceux qui avaient mécru l'avaient banni, deuxième de deux. Quand ils étaient dans la grotte et qu'il disait à son compagnon: «Ne t'afflige pas, car Allah est avec nous.» Allah fit alors descendre sur Lui Sa sérénité «Sa sakîna» et le soutint de soldats (Anges) que vous ne voyiez pas, et Il abaissa ainsi la parole des mécréants, tandis que la parole d'Allah eut le dessus. Et Allah est Puissant et Sage.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mcclxxvi{Légers ou lourds, lancez-vous au combat, et luttez avec vos biens et vos personnes dans le sentier d'Allah. Cela est meilleur pour vous, si vous saviez.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mcclxxvii{S'il s'était agi d'un profit facile ou d'un court voyage, ils t'auraient suivi; mais la distance leur parut longue. Et ils jureront par Allah: «Si nous avions pu, nous serions sortis en votre compagnie.» Ils se perdent eux-mêmes. Et Allah sait bien qu'ils mentent.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mcclxxviii{Qu'Allah te pardonne! Pourquoi leur as-tu donné permission avant que tu ne puisses distinguer ceux qui disaient vrai et reconnaître les menteurs?\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mcclxxix{Ceux qui croient en Allah et au Jour dernier ne te demandent pas permission quand il s'agit de mener combat avec leurs biens et leurs personnes. Et Allah connaît bien les pieux.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mcclxxx{Ne te demandent permission que ceux qui ne croient pas en Allah et au Jour dernier, et dont les cœurs sont emplis de doute. Ils ne font qu'hésiter dans leur incertitude.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mcclxxxi{Et s'ils avaient voulu partir (au combat), ils lui auraient fait des préparatifs. Mais leur départ répugna à Allah; Il les a rendus paresseux. Et il leur fut dit: «Restez avec ceux qui restent».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mcclxxxii{S'ils étaient sortis avec vous, ils n'auraient fait qu'accroître votre trouble et jeter la dissension dans vos rangs, cherchant à créer la discorde entre vous. Et il y en a parmi vous qui les écoutent. Et Allah connaît bien les injustes.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mcclxxxiii{Ils ont, auparavant, cherché à semer la discorde (dans vos rangs) et à embrouiller tes affaires jusqu'à ce que vînt la vérité et triomphât le commandement d'Allah, en dépit de leur hostilité.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mcclxxxiv{Parmi eux il en est qui dit: «Donne-moi la permission (de rester) et ne me mets pas en tentation.» Or, c'est bien dans la tentation qu'ils sont tombés; l'Enfer est tout autour des mécréants.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mcclxxxv{Qu'un bonheur t'atteigne, ça les afflige. Et que t'atteigne un malheur, ils disent: «Heureusement que nous avions pris d'avance nos précautions.» Et ils se détournent tout en exultant.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mcclxxxvi{Dis: «Rien ne nous atteindra, en dehors de ce qu'Allah a prescrit pour nous. Il est notre Protecteur. C'est en Allah que les croyants doivent mettre leur confiance».\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mcclxxxvii{Dis: «Qu'attendez-vous pour nous, sinon l'une des deux meilleures choses? Tandis que ce que nous attendons pour vous, c'est qu'Allah vous inflige un châtiment de Sa part ou par nos mains. Attendez donc! Nous attendons aussi, avec vous».\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mcclxxxviii{Dis: «Dépensez bon gré, mal gré: jamais cela ne sera accepté de vous, car vous êtes des gens pervers».\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mcclxxxix{Ce qui empêche leurs dons d'être agréés, c'est le fait qu'ils n'ont pas cru en Allah et Son messager, qu'ils ne se rendent à la Salât que paresseusement, et qu'ils ne dépensent (dans les bonnes œuvres) qu'à contrecœur.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mccxc{Que leurs biens et leurs enfants ne t'émerveillent point! Allah ne veut par là que les châtier dans la vie présente, et que (les voir) rendre péniblement l'âme en état de mécréance.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mccxci{Et ils (les hypocrites) jurent par Allah qu'ils sont vraiment des vôtres; alors qu'ils ne le sont pas. Mais ce sont des gens peureux.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mccxcii{S'ils trouvaient un refuge, des cavernes ou un souterrain, ils s'y tourneraient donc et s'y précipiteraient à bride abattue.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mccxciii{Il en est parmi eux qui te critiquent au sujet des Sadaqats: s'il leur en est donné, les voilà contents; mais s'il ne leur en est pas donné, les voilà pleins de rancœur.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mccxciv{S'ils s'étaient contentés de ce qu'Allah leur avait donné ainsi que Son messager et avaient dit: «Allah nous suffit. Bientôt Allah nous accordera Sa faveur de même que Son messager!... C'est vers Allah que va tout notre désir».\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mccxcv{Les Sadaqâts ne sont destinés que pour les pauvres, les indigents, ceux qui y travaillent, ceux dont les cœurs sont à gagner (à l'Islam), l'affranchissement des jougs, ceux qui sont lourdement endettés, dans le sentier d'Allah, et pour le voyageur (en détresse). C'est un décret d'Allah! Et Allah est Omniscient et Sage.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mccxcvi{Et il en est parmi eux ceux qui font du tort au Prophète et disent: «Il est tout oreille». - Dis: «Une oreille pour votre bien. Il croit en Allah et fait confiance aux croyants, et il est une miséricorde pour ceux d'entre vous qui croient. Et ceux qui font du tort au Messager d'Allah auront un châtiment douloureux».\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mccxcvii{Ils vous jurent par Allah pour vous satisfaire. Alors qu'Allah - ainsi que Son messager - est plus en droit qu'ils Le satisfassent, s'ils sont vraiment croyants.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mccxcviii{Ne savent-ils pas qu'en vérité quiconque s'oppose à Allah et à Son messager, aura le feu de l'Enfer pour y demeurer éternellement? Et voilà l'immense opprobre.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mccxcix{Les hypocrites craignent que l'on fasse descendre sur eux une Sourate leur dévoilant ce qu'il y a dans leurs cœurs. Dis: «Moquez-vous! Allah fera surgir ce que vous prenez la précaution (de cacher)».\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mccc{Et si tu les interrogeais, ils diraient très certainement: «Vraiment, nous ne faisions que bavarder et jouer.» Dis: «Est-ce d'Allah, de Ses versets (le Coran) et de Son messager que vous vous moquiez?»\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mccci{Ne vous excusez pas: vous avez bel et bien rejeté la foi après avoir cru. Si Nous pardonnons à une partie des vôtres, Nous en châtierons une autre pour avoir été des criminels.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mcccii{Les hypocrites, hommes et femmes, appartiennent les uns aux autres. Ils commandent le blâmable, interdisent le convenable, et replient leurs mains (d'avarice). Ils ont oublié Allah et Il les a alors oubliés. En vérité, les hypocrites sont les pervers.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mccciii{Aux hypocrites, hommes et femmes, et aux mécréants, Allah a promis le feu de l'Enfer pour qu'ils y demeurent éternellement. C'est suffisant pour eux. Allah les a maudits. Et pour eux, il y aura un châtiment permanent.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mccciv{[Il en fut] de même de ceux qui vous ont précédés: ils étaient plus forts que vous, plus riches et avaient plus d'enfants. Ils jouirent de leur lot [en ce monde] et vous avez joui de votre lot comme ont joui vos prédécesseurs de leur lot. Et vous avez discuté à tort et à travers comme ce qu'ils avaient discuté. Ceux-là verront leurs œuvres anéanties dans ce monde et dans l'autre et ceux-là sont les perdants.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mcccv{Est-ce que ne leur est pas parvenue l'histoire de ceux qui les ont précédés: le peuple de Noé, des 'Aad, des Tamûd, d'Abraham, des gens de Madyan, et des Villes renversées? Leurs messagers leur avaient apporté des preuves évidentes. Ce ne fut pas Allah qui leur fit du tort, mais ils se firent du tort à eux-mêmes.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mcccvi{Les croyants et les croyantes sont alliés les uns des autres. Ils commandent le convenable, interdisent le blâmable accomplissent la ?alât, acquittent la Zakât et obéissent à Allah et à Son messager. Voilà ceux auxquels Allah fera miséricorde, car Allah est Puissant et Sage.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mcccvii{Aux croyants et aux croyantes, Allah a promis des Jardins sous lesquels coulent les ruisseaux, pour qu'ils y demeurent éternellement, et des demeures excellentes, aux jardins d'Eden [du séjour permanent]. Et la satisfaction d'Allah est plus grande encore, et c'est là l'énorme succès.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mcccviii{O Prophète, lutte contre les mécréants et les hypocrites, et sois rude avec eux; l'Enfer sera leur refuge, et quelle mauvaise destination!\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mcccix{Ils jurent par Allah qu'ils n'ont pas dit (ce qu'ils ont proféré), alors qu'en vérité ils ont dit la parole de la mécréance et ils ont rejeté la foi après avoir été musulmans. Ils ont projeté ce qu'ils n'ont pu accomplir. Mais ils n'ont pas de reproche à faire si ce n'est qu'Allah - ainsi que Son messager - les a enrichis par Sa grâce. S'ils se repentaient, ce serait mieux pour eux. Et s'ils tournent le dos, Allah les châtiera d'un douloureux châtiment, ici-bas et dans l'au-delà; et ils n'auront sur terre ni allié ni secoureur.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mcccx{Et parmi eux il en est qui avaient pris l'engagement envers Allah: «S'Il nous donne de Sa grâce, nous payerons, certes, la Zakât, et serons du nombre des gens de bien».\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mcccxi{Mais, lorsqu'Il leur donna de Sa grâce, ils s'en montrèrent avares et tournèrent le dos en faisant volte-face.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mcccxii{Il a donc suscité l'hypocrisie dans leurs cœurs, et cela jusqu'au jour où ils Le rencontreront, pour avoir violé ce qu'ils avaient promis à Allah et pour avoir menti.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mcccxiii{Ne savent-ils pas qu'Allah connaît leur secret et leurs conversations confidentielles et qu'Allah connaît parfaitement les (choses) inconnaissables.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mcccxiv{Ceux-là qui dirigent leurs calomnies contre les croyants qui font des aumônes volontaires et contre ceux qui ne trouvent que leurs faibles moyens (à offrir), et ils se moquent alors d'eux. Qu'Allah les raille. Et ils auront un châtiment douloureux.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mcccxv{Que tu demandes pardon pour eux, ou que tu ne le demandes pas - et si tu demandes pardon pour eux soixante dix fois - Allah ne leur pardonnera point. Et ce parce qu'ils n'ont pas cru en Allah et en Son messager et Allah ne guide pas les gens pervers.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mcccxvi{Ceux qui ont été laissés à l'arrière se sont réjouis de pouvoir rester chez eux à l'arrière du Messager d'Allah, ils ont répugné à lutter par leurs biens et leurs personnes dans le sentier d'Allah, et ont dit: «Ne partez pas au combat pendant cette chaleur!» Dis: «Le feu de l'Enfer est plus intense en chaleur.» - S'ils comprenaient!\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mcccxvii{Qu'ils rient un peu et qu'ils pleurent beaucoup en récompense de ce qu'ils se sont acquis.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mcccxviii{Si Allah te ramène vers un groupe de ces (gens-là), et qu'ils te demandent permission de partir au combat, alors dis: «Vous ne sortirez plus jamais en ma compagnie, et vous ne combattrez plus jamais d'ennemis avec moi. Vous avez été plus contents de rester chez vous la première fois; demeurez donc chez vous en compagnie de ceux qui se tiennent à l'arrière».\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mcccxix{Et ne fais jamais la Salât sur l'un d'entre eux qui meurt, et ne te tiens pas debout auprès de sa tombe, parce qu'ils n'ont pas cru en Allah et en Son messager, et ils sont morts tout en étant pervers.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mcccxx{Et que ni leurs biens ni leurs enfants ne t'émerveillent! Allah ne veut par là, que les châtier ici-bas, et qu'ils rendent péniblement l'âme en mécréants.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mcccxxi{Et lorsqu'une Sourate est révélée: «Croyez en Allah et luttez en compagnie de Son messager», les gens qui ont tous les moyens (de combattre) parmi eux te demandent de les dispenser (du combat), et disent: «Laisse-nous avec ceux qui restent».\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mcccxxii{Il leur plaît, (après le départ des combattants) de demeurer avec celles qui sont restées à l'arrière. Leurs cœurs ont été scellés et ils ne comprennent rien.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mcccxxiii{Mais le Messager et ceux qui ont cru avec lui ont lutté avec leurs biens et leurs personnes. Ceux-là auront les bonnes choses et ce sont eux qui réussiront.\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mcccxxiv{Allah a préparé pour eux des Jardins sous lesquels coulent les ruisseaux, pour qu'ils y demeurent éternellement. Voilà l'énorme succès!\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mcccxxv{Et parmi les Bédouins, certains sont venus demander d'être dispensés (du combat). Et ceux qui ont menti à Allah et à Son messager sont restés chez eux. Un châtiment douloureux affligera les mécréants d'entre eux.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mcccxxvi{Nul grief sur les faibles, ni sur les malades, ni sur ceux qui ne trouvent pas de quoi dépenser (pour la cause d'Allah), s'ils sont sincères envers Allah et Son messager. Pas de reproche contre les bienfaiteurs. Allah est Pardonneur et Miséricordieux.\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mcccxxvii{(Pas de reproche) non plus à ceux qui vinrent te trouver pour que tu leur fournisses une monture et à qui tu dis: «Je ne trouve pas de monture pour vous.» Ils retournèrent les yeux débordant de larmes, tristes de ne pas trouver de quoi dépenser.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mcccxxviii{Il n'y a de voie (de reproche à), vraiment, que contre ceux qui demandent d'être dispensés, alors qu'ils sont riches. Il leur plaît de demeurer avec celles qui sont restées à l'arrière. Et Allah a scellé leurs cœurs et ils ne savent pas.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mcccxxix{Ils vous présentent des excuses quand vous revenez à eux. Dis: «Ne présentez pas d'excuses: nous ne vous croyons pas. Allah nous a déjà informés de vos nouvelles. Et Allah verra votre œuvre, ainsi que Son messager. Puis vous serez ramenés vers Celui qui connaît bien l'invisible et le visible, et alors, Il vous informera de ce que vous faisiez.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mcccxxx{Ils vous feront des serments par Allah, quand vous êtes de retour vers eux, afin que vous passiez (sur leur tort). Détournez-vous d'eux. Ils sont une souillure et leur refuge est l'Enfer, en rétribution de ce qu'ils acquéraient.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mcccxxxi{Ils vous font des serments pour se faire agréer de vous, même si vous les agréez, Allah n'agrée pas les gens pervers.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mcccxxxii{Les Bédouins sont plus endurcis dans leur impiété et dans leur hypocrisie, et les plus enclins à méconnaître les préceptes qu'Allah a révélés à Son messager. Et Allah est Omniscient et Sage.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mcccxxxiii{Parmi les Bédouins, certains prennent leur dépense (en aumône ou à la guerre) comme une charge onéreuse, et attendent pour vous un revers de fortune. Que le malheur retombe sur eux! Allah est Audient et Omniscient.\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mcccxxxiv{(Tel autre,) parmi les Bédouins, croit en Allah et au Jour dernier et prend ce qu'il dépense comme moyen de se rapprocher d'Allah et afin de bénéficier des invocations du Messager. C'est vraiment pour eux (un moyen) de se rapprocher (d'Allah) et Allah les admettra en Sa miséricorde. Car Allah est Pardonneur et Miséricordieux.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mcccxxxv{Les tout premiers [croyants] parmi les Emigrés et les Auxiliaires et ceux qui les ont suivis dans un beau comportement, Allah les agrée, et ils L'agréent. Il a préparé pour eux des Jardins sous lesquels coulent les ruisseaux, et ils y demeureront éternellement. Voilà l'énorme succès!\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mcccxxxvi{Et parmi les Bédouins qui vous entourent, il y a des hypocrites, tout comme une partie des habitants de Médine. Ils s'obstinent dans l'hypocrisie. Tu ne les connais pas mais Nous les connaissons. Nous les châtierons deux fois puis ils seront ramenés vers un énorme châtiment.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mcccxxxvii{D'autres ont reconnu leurs péchés, ils ont mêlé de bonnes actions à d'autres mauvaises. Il se peut qu'Allah accueille leur repentir. Car Allah est Pardonneur et Miséricordieux.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mcccxxxviii{Prélève de leurs biens une Sadaqa par laquelle tu les purifies et les bénis, et prie pour eux. Ta prière est une quiétude pour eux. Et Allah est Audient et Omniscient.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mcccxxxix{Ne savent-ils pas que c'est Allah qui accueille le repentir de Ses serviteurs, et qui reçoit les Sadaqât, et qu'Allah est L'Accueillant au repentir et le Miséricordieux.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mcccxl{Et dis: «Oeuvrez, car Allah va voir votre œuvre, de même que Son messager et les croyants, et vous serez ramenés vers Celui qui connaît bien l'invisible et le visible. Alors Il vous informera de ce que vous faisiez».\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mcccxli{Et d'autres sont laissés dans l'attente de la décision d'Allah, soit qu'Il les punisse, soit qu'Il leur pardonne. Et Allah est Omniscient et Sage.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mcccxlii{Ceux qui ont édifié une mosquée pour en faire [un mobile] de rivalité, d'impiété et de division entre les croyants, qui la préparent pour celui qui auparavant avait combattu Allah et son Envoyé et jurent en disant: «Nous ne voulions que le bien!» [Ceux-là], Allah atteste qu'ils mentent.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mcccxliii{Ne te tiens jamais dans (cette mosquée). Car une Mosquée fondée dès le premier jour, sur la piété, est plus digne que tu t'y tiennes debout [pour y prier]. On y trouve des gens qui aiment bien se purifier, et Allah aime ceux qui se purifient.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mcccxliv{Lequel est plus méritant? Est-ce celui qui a fondé son édifice sur la piété et l'agrément d'Allah, ou bien celui qui a placé les assises de sa construction sur le bord d'une falaise croulante et qui croula avec lui dans le feu de l'Enfer? Et Allah ne guide pas les gens injustes.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mcccxlv{La construction qu'ils ont édifiée sera toujours une source de doute dans leurs cœurs, jusqu'à ce que leurs cœurs se déchirent. Et Allah est Omniscient et Sage.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mcccxlvi{Certes, Allah a acheté des croyants, leurs personnes et leurs biens en échange du Paradis. Ils combattent dans le sentier d'Allah: ils tuent, et ils se font tuer. C'est une promesse authentique qu'Il a prise sur Lui-même dans la Thora, l'Evangile et le Coran. Et qui est plus fidèle qu'Allah à son engagement? Réjouissez-vous donc de l'échange que vous avez fait: Et c'est là le très grand succès.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mcccxlvii{Ils sont ceux qui se repentent, qui adorent, qui louent, qui parcourent la terre (ou qui jeûnent), qui s'inclinent, qui se prosternent, qui commandent le convenable et interdisent le blâmable et qui observent les lois d'Allah... et fais bonne annonce aux croyants.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@mcccxlviii{Il n'appartient pas au Prophète et aux croyants d'implorer le pardon en faveur des associateurs, fussent-ils des parents alors qu'il leur est apparu clairement que ce sont les gens de l'Enfer.\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@mcccxlix{Abraham ne demanda pardon en faveur de son père qu'à cause d'une promesse qu'il lui avait faite. Mais, dès qu'il lui apparut clairement qu'il était un ennemi d'Allah, il le désavoua. Abraham était certes plein de sollicitude et indulgent.\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@mcccl{Allah n'est point tel à égarer un peuple après qu'Il les a guidés, jusqu'à ce qu'Il leur ait montré clairement ce qu'ils doivent éviter. Certes, Allah est Omniscient.\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@mcccli{A Allah appartient la royauté des cieux et de la terre. Il donne la vie et Il donne la mort. Et il n'y a pour vous, en dehors d'Allah, ni allié ni protecteur.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@mccclii{Allah a accueilli le repentir du Prophète, celui des Emigrés et des Auxiliaires qui l'ont suivi à un moment difficile, après que les cœurs d'un groupe d'entre eux étaient sur le point de dévier. Puis Il accueillit leur repentir car Il est Compatissant et Miséricordieux à leur égard.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@mcccliii{Et [Il accueillit le repentir] des trois qui étaient restés à l'arrière si bien que, toute vaste qu'elle fût, la terre leur paraissait exiguë; ils se sentaient à l'étroit, dans leur propre personne et ils pensaient qu'il n'y avait d'autre refuge d'Allah qu'auprès de Lui. Puis Il agréa leur repentir pour qu'ils reviennent [à Lui], car Allah est l'accueillant au repentir, le Miséricordieux.\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@mcccliv{O vous qui croyez! Craignez Allah et soyez avec les véridiques.\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@mccclv{Il n'appartient pas aux habitants de Médine, ni aux Bédouins qui sont autour d'eux, de traîner loin derrière le Messager d'Allah, ni de préférer leur propre vie à la sienne. Car ils n'éprouveront ni soif, ni fatigue, ni faim dans le sentier d'Allah, ils ne fouleront aucune terre en provoquant la colère des infidèles, et n'obtiendront aucun avantage sur un ennemi, sans qu'il ne leur soit écrit pour cela une bonne action. En vérité Allah ne laisse pas perdre la récompense des bienfaiteurs.\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@mccclvi{Ils ne supporteront aucune dépense, minime ou importante, ne traverseront aucune vallée, sans que (cela) ne soit inscrit à leur actif, en sorte qu'Allah les récompense pour le meilleur de ce qu'ils faisaient.\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@mccclvii{Les croyants n'ont pas à quitter tous leurs foyers. Pourquoi de chaque clan quelques hommes ne viendraient-ils pas s'instruire dans la religion, pour pouvoir à leur retour, avertir leur peuple afin qu'ils soient sur leur garde.\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@mccclviii{O vous qui croyez! Combattez ceux des mécréants qui sont près de vous; et qu'ils trouvent de la dureté en vous. Et sachez qu'Allah est avec les pieux.\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@mccclix{Et quand une Sourate est révélée, il en est parmi eux qui dit: «Quel est celui d'entre vous dont elle fait croître la foi?» Quant aux croyants, elle fait certes croître leur foi, et ils s'en réjouissent.\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@mccclx{Mais quant à ceux dont les cœurs sont malades, elle ajoute une souillure à leur souillure, et ils meurent dans la mécréance.\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@mccclxi{Ne voient-ils pas que chaque année on les éprouve une ou deux fois? Malgré cela, ils ne se repentent, ni ne se souviennent.\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@mccclxii{Et quand une Sourate est révélée, ils se regardent les uns les autres [et se disent]: «Quelqu'un vous voit-il?» Puis ils se détournent. Qu'Allah détourne leurs cœurs, puisque ce sont des gens qui ne comprennent rien.\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@mccclxiii{Certes, un Messager pris parmi vous, est venu à vous, auquel pèsent lourd les difficultés que vous subissez, qui est plein de sollicitude pour vous, qui est compatissant et miséricordieux envers les croyants.\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@mccclxiv{Alors, s'ils se détournent dis: «Allah me suffit. Il n'y a de divinité que Lui. En Lui je place ma confiance; et Il est le Seigneur du Trône immense».\qt@no{(129)}}
\qt@newcmd\qurantrans@fr@mccclxv{\basmalahfr Alif, Lâm, Râ. Voici les versets du Livre plein de sagesse.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mccclxvi{Est-il étonnant pour les gens, que Nous ayons révélé à un homme d'entre eux: «Avertis les gens, et annonce la bonne nouvelle aux croyants qu'ils ont auprès de leur Seigneur une présence méritée [pour leur loyauté antérieure]? Les mécréants dirent alors: «Celui-ci est certainement un magicien évident».\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mccclxvii{Votre Seigneur est, Allah qui créa les cieux et la terre en six jours, puis S'est établi «Istawâ» sur le Trône, administrant toute chose. Il n'y a d'intercesseur qu'avec Sa permission. Tel est Allah votre Seigneur. Adorez-Le donc. Ne réfléchissez-vous pas?\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mccclxviii{C'est vers Lui que vous retournerez tous, c'est là, la promesse d'Allah en toute vérité! C'est Lui qui fait la création une première fois puis la refait (en la ressuscitant) afin de rétribuer en toute équité ceux qui ont cru et fait de bonnes œuvres. Quant à ceux qui n'ont pas cru, ils auront un breuvage d'eau bouillante et un châtiment douloureux à cause de leur mécréance!\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mccclxix{C'est Lui qui a fait du soleil une clarté et de la lune une lumière, et Il en a déterminé les phases afin que vous sachiez le nombre des années et le calcul (du temps). Allah n'a créé cela qu'en toute vérité. Il expose les signes pour les gens doués de savoir.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mccclxx{Dans l'alternance de la nuit et du jour, et aussi dans tout ce qu'Allah a créé dans les cieux et la terre, il y a des signes, certes, pour des gens qui craignent (Allah).\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mccclxxi{Ceux qui n'espèrent pas Notre rencontre, qui sont satisfaits de la vie présente et s'y sentent en sécurité, et ceux qui sont inattentifs à Nos signes [ou versets],\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mccclxxii{leur refuge sera le Feu, pour ce qu'ils acquéraient.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mccclxxiii{Ceux qui croient et font de bonnes œuvres, leur Seigneur les guidera à cause de leur foi. A leurs pieds les ruisseaux couleront dans les Jardins des délices.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mccclxxiv{Là, leur invocation sera «Gloire à Toi, O Allah», et leur salutation: «Salâm», [Paix!] et la fin de leur invocation: «Louange à Allah, Seigneur de l'Univers».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mccclxxv{Et si Allah hâtait le malheur des gens avec autant de hâte qu'ils cherchent le bonheur, le terme de leur vie aurait été décrété. Mais Nous laissons ceux qui n'espèrent pas Notre rencontre confus et hésitants dans leur transgression.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mccclxxvi{Et quand le malheur touche l'homme, il fait appel à Nous, couché sur le côté, assis, ou debout. Puis quand Nous le délivrons de son malheur, il s'en va comme s'il ne Nous avait point imploré pour un mal qui l'a touché. C'est ainsi que furent embellies aux outranciers leurs actions.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mccclxxvii{Nous avons fait périr les générations d'avant vous lorsqu'elles eurent été injustes alors que leurs messagers leur avaient apporté des preuves. Cependant, elles n'étaient pas disposées à croire. C'est ainsi que Nous rétribuons les gens criminels.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mccclxxviii{Puis nous fîmes de vous des successeurs sur terre après eux, pour voir comment vous agiriez.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mccclxxix{Et quand leur sont récités Nos versets en toute clarté, ceux qui n'espèrent pas notre rencontre disent: «Apporte un Coran autre que celui-ci» ou bien «Change-le». Dis: «Il ne m'appartient pas de le changer de mon propre chef. Je ne fais que suivre ce qui m'est révélé. Je crains, si je désobéis à mon Seigneur, le châtiment d'un jour terrible».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mccclxxx{Dis: «Si Allah avait voulu, je ne vous l'aurais pas récité et Il ne vous l'aurait pas non plus fait connaître. Je suis bien resté, avant cela, tout un âge parmi vous. Ne raisonnez-vous donc pas?»\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mccclxxxi{Qui est plus injuste que celui qui invente un mensonge contre Allah, ou qui traite de mensonges Ses versets (le Coran)? Vraiment, les criminels ne réussissent pas.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mccclxxxii{Ils adorent au lieu d'Allah ce qui ne peut ni leur nuire ni leur profiter et disent: «Ceux-ci sont nos intercesseurs auprès d'Allah». Dis: «Informerez-vous Allah de ce qu'Il ne connaît pas dans les cieux et sur la terre?» Pureté à Lui, Il est Très élevé au-dessus de ce qu'Ils Lui associent!\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mccclxxxiii{Les gens ne formaient (à l'origine) qu'une seule communauté. Puis ils divergèrent. Et si ce n'était une décision préalable de ton Seigneur, les litiges qui les opposaient auraient été tranchés.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mccclxxxiv{Et ils disent: «Que ne fait-on descendre sur lui (Muhammad) un miracle de son Seigneur?» Alors, dis: «L'inconnaissable relève seulement d'Allah. Attendez donc; je serai avec vous parmi ceux qui attendent.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mccclxxxv{Et quand Nous faisons goûter aux gens une miséricorde après qu'un malheur les a touchés, voilà qu'ils dénigrent Nos versets. Dis: «Allah est plus prompt à réprimer (ceux qui dénigrent Ses versets)». Car Nos anges enregistrent vos dénigrements.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mccclxxxvi{C'est Lui qui vous fait aller sur terre et sur mer, quand vous êtes en bateau. [Ces bateaux] les emportèrent, grâce à un bon vent. Ils s'en réjouirent jusqu'au moment où, assaillis par un vent impétueux, assaillis de tous côtés par les vagues, se jugeant enveloppés [par la mort], ils prièrent Allah, Lui vouant le culte [et disant]: «Certes, si Tu nous sauves de ceci, nous serons parmi les reconnaissants!»\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mccclxxxvii{Lorsqu'Il les a sauvés, les voilà qui, sur terre, transgressent injustement. O gens! Votre transgression ne retombera que sur vous-mêmes. C'est une jouissance temporaire de la vie présente. Ensuite, c'est vers Nous que sera votre retour, et Nous vous rappellerons alors ce que vous faisiez.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mccclxxxviii{La vie présente est comparable à une eau que Nous faisons descendre du ciel et qui se mélange à la végétation de la terre dont se nourrissent les hommes et les bêtes. Puis, lorsque la terre prend sa parure et s'embellit, et que ses habitants pensent qu'elle est à leur entière disposition, Notre Ordre lui vient, de nuit ou de jour, c'est alors que Nous la rendrons toute moissonnée, comme si elle n'avait pas été florissante la veille. Ainsi exposons-Nous les preuves pour des gens qui réfléchissent.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mccclxxxix{Allah appelle à la demeure de la paix et guide qui Il veut vers un droit chemin.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mcccxc{A ceux qui agissent en bien est réservée la meilleure (récompense) et même davantage. Nulle fumée noircissante, nul avilissement ne couvriront leurs visages. Ceux-là sont les gens du Paradis, où ils demeureront éternellement.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mcccxci{Et ceux qui ont commis de mauvaises actions, la rétribution d'une mauvaise action sera l'équivalent. Un avilissement les couvrira, - pas de protecteur pour eux contre Allah -, comme si leurs visages se couvraient de lambeaux de ténèbres nocturnes. Ceux-là sont là les gens du Feu où ils demeureront éternellement.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mcccxcii{(Et rappelle-toi) le jour où Nous les rassemblerons tous. Puis, Nous dirons à ceux qui ont donné [à Allah] des associés: «A votre place, vous et vos associés.» Nous les séparerons les uns des autres et leurs associés diront: «Ce n'est pas nous que vous adoriez».\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mcccxciii{Allah suffit comme témoin entre nous et vous. En vérité, nous étions indifférents à votre adoration».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mcccxciv{Là, chaque âme éprouvera (les conséquences de) ce qu'elle a précédemment accompli. Et ils seront ramenés vers Allah leur vrai Maître; et leurs inventions (idoles) s'éloigneront d'eux.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mcccxcv{Dis: «Qui vous attribue de la nourriture du ciel et de la terre? Qui détient l'ouïe et la vue, et qui fait sortir le vivant du mort et fait sortir le mort du vivant, et qui administre tout?» Ils diront: «Allah». Dis alors: «Ne Le craignez-vous donc pas?»\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mcccxcvi{Tel est Allah, votre vrai Seigneur. Au delà de la vérité qu'y a-t-il donc sinon l'égarement? Comment alors pouvez-vous, vous détourner?»\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mcccxcvii{C'est ainsi que s'est réalisée la parole de ton Seigneur contre ceux qui sont pervers: «Ils ne croiront pas».\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mcccxcviii{Dis: «Parmi vos associés, qui donne la vie par une première création et la redonne [après la mort]?» Dis: «Allah [seul] donne la vie par une première création et la redonne. Comment pouvez-vous vous écarter [de l'adoration d'Allah]?\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mcccxcix{Dis: «Est-ce qu'il y a parmi vos associés un qui guide vers la vérité?» Dis: «C'est Allah qui guide vers la vérité. Celui qui guide vers la vérité est-il plus digne d'être suivi, ou bien celui qui ne se dirige qu'autant qu'il est lui-même dirigé? Qu'avez-vous donc? Comment jugez-vous ainsi?»\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mcd{Et la plupart d'entre eux ne suivent que conjecture. Mais, la conjecture ne sert à rien contre la vérité! Allah sait parfaitement ce qu'ils font.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mcdi{Ce Coran n'est nullement à être forgé en dehors d'Allah mais c'est la confirmation de ce qui existait déjà avant lui, et l'exposé détaillé du Livre en quoi il n'y a pas de doute, venu du Seigneur de l'Univers.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mcdii{Ou bien ils disent: «Il (Muhammad) l'a inventé?» Dis: «Composez donc une sourate semblable à ceci, et appelez à votre aide n'importe qui vous pourrez, en dehors d'Allah, si vous êtes véridiques».\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mcdiii{Bien au contraire: ils ont traité de mensonge ce qu'ils ne peuvent embrasser de leur savoir, et dont l'interprétation ne leur est pas encore parvenue. Ainsi ceux qui vivaient avant eux traitaient d'imposteurs (leurs messagers). Regarde comment a été la fin des injustes!\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mcdiv{Certains d'entre eux y croient, et d'autres n'y croient pas. Et ton Seigneur connaît le mieux les fauteurs de désordre.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mcdv{Et s'ils te traitent de menteur, dis alors: «A moi mon œuvre, et à vous la vôtre. Vous êtes irresponsables de ce que je fais et je suis irresponsable de ce que vous faites».\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mcdvi{Et il en est parmi eux qui te prêtent l'oreille. Est-ce toi qui fait entendre les sourds, même s'ils sont incapables de comprendre.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mcdvii{Et il en est parmi eux qui te regardent. Est-ce toi qui peux guider les aveugles, même s'ils ne voient pas?\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mcdviii{En vérité, Allah n'est point injuste à l'égard des gens, mais ce sont les gens qui font du tort à eux-mêmes.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mcdix{Et le jour où Il les rassemblera, ce sera comme s'ils n'étaient restés [dans leur tombeau] qu'une heure du jour et ils se reconnaîtront mutuellement. Perdants seront alors ceux qui auront traité de mensonge la rencontre d'Allah, et ils n'auront pas été bien guidés.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mcdx{Que Nous te fassions voir une partie de ce dont Nous les menaçons, ou que Nous te fassions mourir, (en tout cas), c'est vers Nous que sera leur retour. Allah est en outre, témoin de ce qu'ils font.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mcdxi{A chaque communauté un Messager. Et lorsque leur messager vint, tout se décida en équité entre eux et ils ne furent point lésés.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mcdxii{Et ils disent «A quand cette promesse, si vous êtes véridiques»?\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mcdxiii{Dis: «Je ne détiens pour moi rien qui peut me nuire ou me profiter, excepté ce qu'Allah veut. A chaque communauté un terme. Quand leur terme arrive, ils ne peuvent ni le retarder d'une heure ni l'avancer».\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mcdxiv{Dis: «Voyez-vous! Si Son châtiment vous arrivait de nuit ou de jour, les criminels pourraient-ils en hâter quelque chose?\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mcdxv{«Est-ce au moment où le châtiment se produira que vous croirez? [Il vous sera dit: «Inutile».] Maintenant! Autrefois, vous en réclamiez [ironiquement] la prompte arrivée!»\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mcdxvi{Puis il sera dit aux injustes: «Goûtez au châtiment éternel! Etes-vous rétribués autrement qu'en rapport de ce que vous acquériez?»\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mcdxvii{Et ils s'informent auprès de toi: «Est-ce vrai?» - Dis: «Oui! Par mon Seigneur! C'est bien vrai. Et vous ne pouvez vous soustraire à la puissance d'Allah.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mcdxviii{Si chaque âme injuste possédait tout ce qu'il y a sur terre, elle le donnerait pour sa rançon. Ils dissimuleront leur regret quand ils verront le châtiment. Et il sera décidé entre eux en toute équité, et ils ne seront point lésés.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mcdxix{C'est à Allah qu'appartient, certes, tout ce qui est dans les cieux et sur la terre. Certes, la promesse d'Allah est vérité. Mais la plupart d'entre eux ne (le) savent pas.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mcdxx{C'est Lui qui donne la vie et qui donne la mort; et c'est vers Lui que vous serez ramenés.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mcdxxi{O gens! Une exhortation vous est venue, de votre Seigneur, une guérison de ce qui est dans les poitrines, un guide et une miséricorde pour les croyants.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mcdxxii{Dis: «[Ceci provient] de la grâce d'Allah et de Sa miséricorde; Voilà de quoi ils devraient se réjouir. C'est bien mieux que tout ce qu'ils amassent».\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mcdxxiii{Que dites-vous de ce qu'Allah a fait descendre pour vous comme subsistance et dont vous avez alors fait des choses licites et des choses interdites? - Dis: «Est-ce Allah qui vous l'a permis? Ou bien forgez vous (des mensonges) contre Allah?»\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mcdxxiv{Et que penseront, au Jour de la Résurrection, ceux qui forgent le mensonge contre Allah? - Certes, Allah est Détenteur de grâce pour les gens, mais la plupart d'entre eux ne sont pas reconnaissants.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mcdxxv{Tu ne te trouveras dans aucune situation, tu ne réciteras aucun passage du Coran, vous n'accomplirez aucun acte sans que Nous soyons témoin au moment où vous l'entreprendrez. Il n'échappe à ton Seigneur ni le poids d'un atome sur terre ou dans le ciel, ni un poids plus petit ou plus grand qui ne soit déjà inscrit dans un livre évident.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mcdxxvi{En vérité, les bien-aimés d'Allah seront à l'abri de toute crainte, et ils ne seront point affligés,\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mcdxxvii{ceux qui croient et qui craignent [Allah].\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mcdxxviii{Il y a pour eux une bonne annonce dans la vie d'ici-bas tout comme dans la vie ultime. - Il n'y aura pas de changement aux paroles d'Allah -. Voilà l'énorme succès!\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mcdxxix{Que ce qu'ils disent ne t'afflige pas. La puissance toute entière appartient à Allah. C'est Lui qui est l'Audient, l'Omniscient.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mcdxxx{C'est à Allah qu'appartient, ce qui est dans les cieux et ce qui est sur la terre. Que suivent donc ceux qui invoquent, en dehors d'Allah, [des divinités] qu'ils Lui associent? Ils ne suivent que la conjecture et ne font que mentir.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mcdxxxi{C'est Lui qui vous a désigné la nuit pour que vous vous y reposiez, et le jour pour vous permettre de voir. Ce sont en vérité des signes pour les gens qui entendent!\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mcdxxxii{Ils disent: «Allah S'est donné un enfant» Gloire et Pureté à Lui! Il est Le Riche par excellence. A Lui appartient tout ce qui est aux cieux et sur la terre; - vous n'avez pour cela aucune preuve. Allez-vous dire contre Allah ce que vous ne savez pas?\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mcdxxxiii{Dis: «En vérité, ceux qui forgent le mensonge contre Allah ne réussiront pas».\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mcdxxxiv{C'est une jouissance (temporaire) dans la vie d'ici-bas; puis ils retourneront vers Nous et Nous leur ferons goûter au dur châtiment, à titre de sanction pour leur mécréance.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mcdxxxv{Raconte-leur l'histoire de Noé, quand il dit à son peuple: «O mon peuple, si mon séjour (parmi vous), et mon rappel des signes d'Allah vous pèsent trop, alors c'est en Allah que je place (entièrement) ma confiance. Concertez-vous avec vos associés, et ne cachez pas vos desseins. Puis, décidez de moi et ne me donnez pas de répit.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mcdxxxvi{Si vous vous détournez, alors je ne vous ai pas demandé de salaire... Mon salaire n'incombe qu'à Allah. Et il m'a été commandé d'être du nombre des soumis».\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mcdxxxvii{Ils le traitèrent de menteur. Nous le sauvâmes, lui et ceux qui étaient avec lui dans l'arche, desquels Nous fîmes les successeurs (sur la terre). Nous noyâmes ceux qui traitaient de mensonge Nos preuves. Regarde comment a été la fin de ceux qui avaient été avertis!\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mcdxxxviii{Puis Nous envoyâmes après lui des messagers à leurs peuples. Ils leur vinrent avec les preuves. Mais (les gens) étaient tels qu'ils ne pouvaient croire à ce qu'auparavant ils avaient traité de mensonge. Ainsi scellons-Nous les cœurs des transgresseurs.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mcdxxxix{Ensuite, Nous envoyâmes après eux Moïse et Aaron, munis de Nos preuves à Pharaon et ses notables. Mais (ces gens) s'enflèrent d'orgueil et ils étaient un peuple criminel.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mcdxl{Et lorsque la vérité leur vint de Notre part, ils dirent: «Voilà certes, une magie manifeste!»\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mcdxli{Moïse dit: «Dites-vous à la Vérité quand elle vous est venue: Est-ce que cela est de la magie? Alors que les magiciens ne réussissent pas...».\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mcdxlii{Ils dirent: «Est-ce pour nous écarter de ce sur quoi nous avons trouvé nos ancêtres que tu es venu à nous, et pour que la grandeur appartienne à vous deux sur la terre? Et nous ne croyons pas en vous!»\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mcdxliii{Et Pharaon dit: «Amenez-moi tout magicien savant!»\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mcdxliv{Puis, lorsque vinrent les magiciens, Moïse leur dit: «Jetez ce que vous avez à jeter».\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mcdxlv{Lorsqu'ils jetèrent, Moïse dit: «Ce que vous avez produit est magie! Allah l'annulera. Car Allah ne fait pas prospérer ce que font les fauteurs de désordre.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mcdxlvi{Et par Ses paroles, Allah fera triompher la Vérité, quelque répulsion qu'en aient les criminels».\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mcdxlvii{Personne ne crut (au message) de Moïse, sauf un groupe de jeunes gens de son peuple, par crainte de représailles de Pharaon et de leurs notables. En vérité, Pharaon fut certes superbe sur terre et il fut du nombre des extravagants.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mcdxlviii{Et Moïse dit: «O mon peuple, si vous croyez en Allah, placez votre confiance en Lui si vous (Lui) êtes soumis».\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mcdxlix{Ils dirent: «En Allah nous plaçons notre confiance. O notre Seigneur, ne fais pas de nous une cible pour les persécutions des injustes.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mcdl{Et délivre-nous, par Ta miséricorde, des gens mécréants».\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mcdli{Et Nous révélâmes à Moïse et à son frère: «Prenez pour votre peuple des maisons en Egypte, faites de vos maisons un lieu de prière et soyez assidus dans la prière. Et fais la bonne annonce aux croyants».\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mcdlii{Et Moïse dit: «O notre Seigneur, Tu as accordé à Pharaon et ses notables des parures et des biens dans la vie présente, et voilà, O notre Seigneur, qu'avec cela ils égarent (les gens loin) de Ton sentier. O notre Seigneur, anéantis leurs biens et endurcis leurs cœurs, afin qu'ils ne croient pas, jusqu'à ce qu'ils aient vu le châtiment douloureux».\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mcdliii{Il dit: «Votre prière est exaucée. Restez tous deux sur le chemin droit, et ne suivez point le sentier de ceux qui ne savent pas».\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mcdliv{Et Nous fîmes traverser la mer aux Enfants d'Israël. Pharaon et ses armées les poursuivirent avec acharnement et inimitié. Puis, quand la noyade l'eut atteint, il dit: «Je crois qu'il n'y a d'autre divinité que Celui en qui ont cru les enfants d'Israël. Et je suis du nombre des soumis».\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mcdlv{[Allah dit]: Maintenant? Alors qu'auparavant tu as désobéi et que tu as été du nombre des corrupteurs!\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mcdlvi{Nous allons aujourd'hui épargner ton corps, afin que tu deviennes un signe à tes successeurs. Cependant beaucoup de gens ne prêtent aucune attention à Nos signes (d'avertissement).\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mcdlvii{Certes, Nous avons établi les Enfants d'Israël dans un endroit honorable, et leur avons attribué comme nourriture de bons aliments. Par la suite, ils n'ont divergé qu'au moment où leur vint la science. Ton Seigneur décidera entre eux, au Jour de la Résurrection sur ce qui les divisait.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mcdlviii{Et si tu es en doute sur ce que Nous avons fait descendre vers toi, interroge alors ceux qui lisent le Livre révélé avant toi. La vérité certes, t'est venue de ton Seigneur: ne sois donc point de ceux qui doutent.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mcdlix{Et ne sois point de ceux qui traitent de mensonge les versets d'Allah. Tu serais alors du nombre des perdants.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mcdlx{Ceux contre qui la parole (la menace) de ton Seigneur se réalisera ne croiront pas,\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mcdlxi{même si tous les signes leur parvenaient, jusqu'à ce qu'ils voient le châtiment douloureux.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mcdlxii{Si seulement il y avait, à part le peuple de Yûnus (Jonas), une cité qui ait cru et à qui sa croyance eut ensuite profité! Lorsqu'ils eurent cru, Nous leur enlevâmes le châtiment d'ignominie dans la vie présente et leur donnâmes jouissance pour un certain temps.\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mcdlxiii{Si ton Seigneur l'avait voulu, tous ceux qui sont sur la terre auraient cru. Est-ce à toi de contraindre les gens à devenir croyants?\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mcdlxiv{Il n'appartient nullement à une âme de croire si ce n'est avec la permission d'Allah. Et Il voue au châtiment ceux qui ne raisonnent pas.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mcdlxv{Dis: «Regardez ce qui est dans les cieux et sur la terre». Mais ni les preuves ni les avertisseurs (prophètes) ne suffisent à des gens qui ne croient pas.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mcdlxvi{Est-ce qu'ils attendent autre chose que des châtiments semblables à ceux des peuples antérieurs? Dis: «Attendez! Moi aussi, j'attends avec vous».\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mcdlxvii{Ensuite, Nous délivrerons Nos messagers et les croyants. C'est ainsi qu'il Nous incombe [en toute justice] de délivrer les croyants.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mcdlxviii{Dis: «O gens! Si vous êtes en doute sur ma religion, moi, je n'adore point ceux que vous adorez en dehors d'Allah; mais j'adore Allah qui vous fera mourir. Et il m'a été commandé d'être du nombre des croyants».\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mcdlxix{Et (il m'a été dit): «Oriente-toi exclusivement sur la religion en pur monothéiste! Et ne sois pas du nombre des Associateurs;\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mcdlxx{et n'invoque pas, en dehors d'Allah, ce qui ne peut te profiter ni te nuire. Et si tu le fais, tu seras alors du nombre des injustes».\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mcdlxxi{Et si Allah fait qu'un mal te touche, nul ne peut l'écarter en dehors de Lui. Et s'Il te veut un bien, nul ne peut repousser Sa grâce. Il en gratifie qui Il veut parmi Ses serviteurs. Et c'est Lui le Pardonneur, le Miséricordieux.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mcdlxxii{Dis: «O gens! Certes la vérité vous est venue de votre Seigneur. Donc, quiconque est dans le bon chemin ne l'est que pour lui-même; et quiconque s'égare, ne s'égare qu'à son propre détriment. Je ne suis nullement un protecteur pour vous.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mcdlxxiii{Et suis ce qui t'est révélé, et sois constant jusqu'à ce qu'Allah rende Son jugement car Il est le meilleur des juges.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mcdlxxiv{\basmalahfr Alif, Lâm, Râ. C'est un Livre dont les versets sont parfaits en style et en sens, émanant d'un Sage, Parfaitement Connaisseur.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mcdlxxv{N'adorez qu'Allah. Moi, je suis pour vous, de Sa part, un avertisseur et un annonciateur.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mcdlxxvi{Demandez pardon à votre Seigneur; ensuite, revenez à Lui. Il vous accordera une belle jouissance jusqu'à un terme fixé, et Il accordera à chaque méritant l'honneur qu'il mérite. Mais si vous tournez le dos, je crains alors pour vous le châtiment d'un grand jour.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mcdlxxvii{C'est à Allah que sera votre retour; et Il est Omnipotent.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mcdlxxviii{Eh quoi! Ils replient leurs poitrines afin de se cacher de Lui. Même lorsqu'ils se couvrent de leurs vêtements, Il sait ce qu'ils cachent et ce qu'ils divulguent car Il connaît certes le contenu des poitrines.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mcdlxxix{Il n'y a point de bête sur terre dont la subsistance n'incombe à Allah qui connaît son gîte et son dépôt; tout est dans un Livre explicite.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mcdlxxx{Et c'est Lui qui a créé les cieux et la terre en six jours, - alors que Son Trône était sur l'eau, - afin d'éprouver lequel de vous agirait le mieux. Et si tu dis: «Vous serez ressuscités après la mort», ceux qui ne croient pas diront: «Ce n'est là qu'une magie évidente».\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mcdlxxxi{Et si Nous retardons pour eux le châtiment jusqu'à une période fixée, ils diront: «Qu'est-ce qui le retient?» - Mais le jour où cela leur viendra, il ne sera pas détourné; d'eux et ce dont ils se moquaient les enveloppera.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mcdlxxxii{Et si Nous faisons goûter à l'homme une grâce de Notre part, et qu'ensuite Nous la lui arrachons, le voilà désespéré et ingrat.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mcdlxxxiii{Et si Nous lui faisons goûter le bonheur, après qu'un malheur l'ait touché, il dira: «Les maux se sont éloignés de moi», et le voilà qui exulte, plein de gloriole.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mcdlxxxiv{sauf ceux qui sont endurants et font de bonnes œuvres. Ceux-là obtiendront pardon et une grosse récompense.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mcdlxxxv{Il se peut que tu négliges une partie de ce qui t'est révélé, et que ta poitrine s'en sente compressée; parce qu'ils disent: «Que n'a-t-on fait descendre sur lui un trésor?» Ou bien: «Que n'est-il venu un Ange en sa compagnie?» - Tu n'es qu'un avertisseur. Et Allah est Le protecteur de toute chose.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mcdlxxxvi{Ou bien ils disent: «Il l'a forgé [le Coran]» - Dis: «Apportez donc dix Sourates semblables à ceci, forgées (par vous). Et appelez qui vous pourrez (pour vous aider), hormis Allah, si vous êtes véridiques».\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mcdlxxxvii{S'ils ne vous répondent pas, sachez alors que c'est par la science d'Allah qu'il est descendu, et qu'il n'y a de divinité que Lui. Etes-vous soumis (à Lui)?\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mcdlxxxviii{Ceux qui veulent la vie présente avec sa parure, Nous les rétribuerons exactement selon leurs actions sur terre, sans que rien leur en soit diminué.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mcdlxxxix{Ceux-là qui n'ont rien, dans l'au-delà, que le Feu. Ce qu'ils auront fait ici-bas sera un échec, et sera vain ce qu'ils auront œuvré.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mcdxc{Est-ce que celui qui se fonde sur une preuve évidente (le Coran) venant de son Seigneur et récitée par un témoin [l'archange Gabriel] de Sa part, cependant qu'avant lui [Muhammad] il y a le livre de Moïse tenant lieu de guide et de miséricorde... [est meilleur ou bien celui qui ne se fonde sur aucune preuve valable?]. Ceux-là y croient; mais quiconque d'entre les factions n'y croit pas, aura le Feu comme rendez-vous. Ne sois donc pas en doute au sujet de ceci (le Coran). Oui, c'est la vérité venant de ton Seigneur; mais la plupart des gens n'y croient pas.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mcdxci{Et quel pire injuste que celui qui forge un mensonge contre Allah? Ceux-là seront présentés à leur Seigneur, et les témoins (les anges) diront: «Voilà ceux qui ont menti contre leur Seigneur». Que la malédiction d'Allah (frappe) les injustes,\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mcdxcii{qui obstruent le sentier d'Allah (aux gens), cherchent à le rendre tortueux et ne croient pas en l'au-delà.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mcdxciii{Ceux-là ne peuvent réduire (Allah) à l'impuissance sur terre! Pas d'alliés pour eux en dehors d'Allah et leur châtiment sera doublé. Ils étaient incapables d'entendre; ils ne voyaient pas non plus.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mcdxciv{Ce sont ceux-là qui ont causé la perte de leurs propres âmes. Et leurs inventions (idoles) se sont éloignées d'eux.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mcdxcv{Ce sont eux, infailliblement, qui dans l'au-delà seront les plus grands perdants.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mcdxcvi{Certes ceux qui croient, font de bonnes œuvres et s'humilient devant leur Seigneur, voilà les gens du Paradis où ils demeureront éternellement.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mcdxcvii{Les deux groupes ressemblent, l'un à l'aveugle et au sourd, l'autre à celui qui voit et qui entend. Les deux sont-ils comparativement égaux? Ne vous souvenez-vous pas?\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mcdxcviii{Nous avons déjà envoyé Noé à son peuple: «Je suis pour vous un avertisseur explicite\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mcdxcix{afin que vous n'adoriez qu'Allah. Je crains pour vous le châtiment d'un jour douloureux».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@md{Les notables de son peuple qui avaient mécru, dirent alors: «Nous ne voyons en toi qu'un homme comme nous; et nous voyons que ce sont seulement les vils parmi nous qui te suivent sans réfléchir; et nous ne voyons en vous aucune supériorité sur nous. Plutôt, nous pensons que vous êtes des menteurs».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mdi{Il dit: «O mon peuple! Que vous en semble? Si je me conforme à une preuve de mon Seigneur, si une Miséricorde, (prophétie) échappant à vos yeux, est venue à moi de Sa part, devrons-nous vous l'imposer alors que vous la répugnez?\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mdii{O mon peuple, je ne vous demande pas de richesse en retour. Mon salaire n'incombe qu'à Allah. Je ne repousserai point ceux qui ont cru, ils auront à rencontrer leur Seigneur. Mais je vous trouve des gens ignorants.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mdiii{O mon peuple, qui me secourra contre (la punition d') Allah si je les repousse? Ne vous souvenez-vous pas?\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mdiv{Et je ne vous dis pas que je détiens les trésors d'Allah, je ne connais pas l'Inconnaissable, et je ne dis pas que je suis un Ange; et je ne dis pas non plus aux gens, que vos yeux méprisent, qu'Allah ne leur accordera aucune faveur; Allah connaît mieux ce qu'il y a dans leurs âmes. [Si je le leur disais], je serais du nombre des injustes.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mdv{Ils dirent: «O Noé, tu as disputé avec nous et multiplié les discussions. Apporte-nous donc ce dont tu nous menaces, si tu es du nombre des véridiques».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mdvi{Il dit: «C'est Allah seul qui vous l'apportera - s'Il veut - et vous ne saurez y échapper.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mdvii{Et mon conseil ne vous profiterait pas, au cas où je voulais vous conseiller, et qu'Allah veuille vous égarer. Il est votre Seigneur, et c'est vers Lui que vous serez ramenés».\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mdviii{Ou bien ils disent: il l'a inventé? Dis: «Si je l'ai inventé, que mon crime retombe sur moi! Et je suis innocent de vos criminelles accusations».\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mdix{Et il fut révélé à Noé: «De ton peuple, il n'y aura plus de croyants que ceux qui ont déjà cru. Ne t'afflige pas de ce qu'ils faisaient.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mdx{Et construis l'arche sous Nos yeux et d'après Notre révélation. Et ne M'interpelle plus au sujet des injustes, car ils vont être noyés».\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mdxi{Et il construisait l'arche. Et chaque fois que des notables de son peuple passaient près de lui, ils se moquaient de lui. Il dit: «Si vous vous moquez de nous, eh bien, nous nous moquerons de vous, comme vous vous moquez [de nous].\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mdxii{Et vous saurez bientôt à qui viendra un châtiment qui l'humiliera, et sur qui s'abattra un châtiment durable!»\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mdxiii{Puis, lorsque Notre commandement vint et que le four se mit à bouillonner [d'eau], Nous dîmes: «Charge [dans l'arche] un couple de chaque espèce ainsi que ta famille - sauf ceux contre qui le décret est déjà prononcé - et ceux qui croient». Or, ceux qui avaient cru avec lui étaient peu nombreux.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mdxiv{Et il dit: «Montez dedans. Que sa course et son mouillage soient au nom d'Allah. Certes mon Seigneur est Pardonneur et Miséricordieux».\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mdxv{Et elle vogua en les emportant au milieu des vagues comme des montagnes. Et Noé appela son fils, qui restait en un lieu écarté (non loin de l'arche): «O mon enfant, monte avec nous et ne reste pas avec les mécréants».\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mdxvi{Il répondit: «Je vais me réfugier vers un mont qui me protègera de l'eau». Et Noé lui dit: «Il n'y a aujourd'hui aucun protecteur contre l'ordre d'Allah. (Tous périront) sauf celui à qui Il fait miséricorde». Et les vagues s'interposèrent entre les deux, et le fils fut alors du nombre des noyés.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mdxvii{Et il fut dit: «O terre, absorbe ton eau! Et toi, ciel, cesse [de pleuvoir]!» L'eau baissa, l'ordre fut exécuté et l'arche s'installa sur le Jûdi, et il fut dit: «Que disparaissent les gens pervers»!\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mdxviii{Et Noé invoqua son Seigneur et dit: «O mon Seigneur, certes mon fils est de ma famille et Ta promesse est vérité. Tu es le plus juste des juges».\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mdxix{Il dit: «O Noé, il n'est pas de ta famille car il a commis un acte infâme. Ne me demande pas ce dont tu n'as aucune connaissance. Je t'exhorte afin que tu ne sois pas du nombre des ignorants».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mdxx{Alors Noé dit: «Seigneur, je cherche Ta protection contre toute demande de ce dont je n'ai aucune connaissance. Et si Tu ne me pardonnes pas et ne me fais pas miséricorde, je serai au nombre des perdants».\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mdxxi{Il fut dit: «O Noé, débarque avec Notre sécurité et Nos bénédictions sur toi et sur des communautés [issues] de ceux qui sont avec toi. Et il y (en) aura des communautés auxquelles Nous accorderons une jouissance temporaire; puis un châtiment douloureux venant de Nous les touchera».\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mdxxii{Voilà quelques nouvelles de l'Inconnaissable que Nous te révélons. Tu ne les savais pas, ni toi ni ton peuple, avant cela. Sois patient. La fin heureuse sera aux pieux.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mdxxiii{Et (Nous avons envoyé) aux 'Aad, leur frère Hûd, qui leur dit: «O mon peuple, adorez Allah. Vous n'avez point de divinité à part Lui. Vous n'êtes que des forgeurs (de mensonges).\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mdxxiv{O mon peuple, je ne vous demande pas de salaire pour cela. Mon salaire n'incombe qu'à Celui qui m'a créé. Ne raisonnez-vous pas?\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mdxxv{O mon peuple, implorez le pardon de votre Seigneur et repentez-vous à Lui pour qu'Il envoie sur vous du ciel des pluies abondantes et qu'Il ajoute force à votre force. Et ne vous détournez pas [de Lui] en devenant coupables».\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mdxxvi{Ils dirent: «O Hûd, tu n'es pas venu à nous avec une preuve, et nous ne sommes pas disposés à abandonner nos divinités sur ta parole, et nous n'avons pas foi en toi.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mdxxvii{Nous dirons plutôt qu'une de nos divinités t'a affligé d'un mal». Il dit: «Je prends Allah à témoin - et vous aussi soyez témoins - qu'en vérité, je désavoue ce que vous associez,\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mdxxviii{en dehors de Lui. Rusez donc tous contre moi et ne me donnez pas de répit.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mdxxix{Je place ma confiance en Allah, mon Seigneur et le vôtre. Il n'y a pas d'être vivant qu'Il ne tienne par son toupet. Mon Seigneur, certes, est sur un droit chemin.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mdxxx{Si vous vous détournez... voilà que je vous ai transmis [le message] que j'étais chargé de vous faire parvenir. Et mon Seigneur vous remplacera par un autre peuple, sans que vous ne Lui nuisiez en rien, car mon Seigneur, est gardien par excellence sur toute chose».\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mdxxxi{Et quand vint Notre Ordre, Nous sauvâmes par une miséricorde de Notre part, Hûd et ceux qui avec lui avaient cru. Et Nous les sauvâmes d'un terrible châtiment.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mdxxxii{Voilà les 'Aad. Ils avaient nié les signes (enseignements) de leur Seigneur, désobéi à Ses messagers et suivi le commandement de tout tyran entêté.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mdxxxiii{Et ils furent poursuivis, ici-bas, d'une malédiction, ainsi qu'au Jour de la Résurrection. En vérité, les 'Aad n'ont pas cru en leur Seigneur. Que s'éloignent (périssent) les 'Aad, peuple de Hûd!\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mdxxxiv{Et (Nous avons envoyé) aux Thamûd, leur frère Sâlih qui dit: «O mon peuple, adorez Allah. Vous n'avez point de divinité en dehors de Lui. De la terre Il vous a créés, et Il vous l'a fait peupler (et exploiter). Implorez donc Son pardon, puis repentez-vous à Lui. Mon Seigneur est bien proche et Il répond toujours (aux appels)».\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mdxxxv{Ils dirent: «O Sâlih, tu étais auparavant un espoir pour nous. Nous interdirais-tu d'adorer ce qu'adoraient nos ancêtres? Cependant, nous voilà bien dans un doute troublant au sujet de ce vers quoi tu nous invites».\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mdxxxvi{Il dit: «O mon peuple! Que vous en semble, si je m'appuie sur une preuve évidente émanant de mon Seigneur et s'Il m'a accordé, de Sa part, une miséricorde, qui donc me protègera contre Allah si je Lui désobéis? Vous ne ferez qu'accroître ma perte.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mdxxxvii{O mon peuple, voici la chamelle d'Allah qu'Il vous a envoyée comme signe. Laissez-la donc paître sur la terre d'Allah, et ne lui faites aucun mal sinon, un châtiment proche vous saisira!»\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mdxxxviii{Ils la tuèrent. Alors, il leur dit: «Jouissez (de vos biens) dans vos demeures pendant trois jours (encore)! Voilà une promesse qui ne sera pas démentie».\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mdxxxix{Puis, lorsque Notre ordre vint, Nous sauvâmes Sâlih et ceux qui avaient cru avec lui, - par une miséricorde venant de Nous - de l'ignominie de ce jour-là. En vérité, c'est ton Seigneur qui est le Fort, le Puissant.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mdxl{Et le Cri saisit les injustes. Et les voilà foudroyés dans leurs demeures,\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mdxli{comme s'ils n'y avaient jamais prospéré. En vérité, les Thamûd n'ont pas cru en leur Seigneur. Que périssent les Thamûd!\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mdxlii{Et Nos émissaires sont, certes, venus à Abraham avec la bonne nouvelle, en disant: «Salâm!». Il dit: «Salâm!», et il ne tarda pas à apporter un veau rôti.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mdxliii{Puis, lorsqu'il vit que leurs mains ne l'approchaient pas, il fut pris de suspicion à leur égard et ressentit de la peur vis-à-vis d'eux. Ils dirent: «N'aie pas peur, nous sommes envoyés au peuple de Lot».\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mdxliv{Sa femme était debout, et elle rit alors; Nous lui annonçâmes donc (la naissance d') Isaac, et après Isaac, Jacob.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mdxlv{Elle dit: «Malheur à moi! Vais-je enfanter alors que je suis vieille et que mon mari, que voici, est un vieillard? C'est là vraiment une chose étrange!»\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mdxlvi{Ils dirent: «T'étonnes-tu de l'ordre d'Allah? Que la miséricorde d'Allah et Ses bénédictions soient sur vous, gens de cette maison! Il est vraiment, digne de louange et de glorification!»\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mdxlvii{Lorsque l'effroi eut quitté Abraham et que la bonne nouvelle l'eut atteint, voilà qu'il discuta avec Nous (en faveur) du peuple de Lot.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mdxlviii{Abraham était, certes, longanime, très implorant et repentant.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mdxlix{O Abraham, renonce à cela; car l'ordre de Ton Seigneur est déjà venu, et un châtiment irrévocable va leur arriver».\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mdl{Et quand Nos émissaires (Anges) vinrent à Lot, il fut chagriné pour eux, et en éprouva une grande gêne. Et il dit: «Voici un jour terrible».\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mdli{Quant à son peuple, ils vinrent à lui, accourant. Auparavant ils commettaient des mauvaises actions. Il dit: «O mon peuple, voici mes filles: elles sont plus pures pour vous. Craignez Allah donc, et ne me déshonorez pas dans mes hôtes. N'y a-t-il pas parmi vous un homme raisonnable?»\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mdlii{Ils dirent: Tu sais très bien que nous n'avons pas de droit sur tes filles. Et en vérité, tu sais bien ce que nous voulons».\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mdliii{Il dit: «[Ah!] si j'avais de la force pour vous résister! ou bien si je trouvais un appui solide!»\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mdliv{Alors [les hôtes] dirent: «O Lot, nous sommes vraiment les émissaires de ton Seigneur. Ils ne pourront jamais t'atteindre. Pars avec ta famille à un moment de la nuit. Et que nul d'entre vous ne se retourne en arrière. Exception faite de ta femme qui sera atteinte par ce qui frappera les autres. Ce qui les menace s'accomplira à l'aube. L'aube n'est-elle pas proche?»\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mdlv{Et, lorsque vint Notre ordre, Nous renversâmes [la cité] de fond en comble, et fîmes pleuvoir sur elle en masse, des pierres d'argile succédant les unes aux autres,\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mdlvi{portant une marque connue de ton Seigneur. Et elles (ces pierres) ne sont pas loin des injustes.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mdlvii{Et (Nous avons envoyé) aux Madyan, leur frère Chuayb qui leur dit: «O mon peuple, adorez Allah; vous n'avez point de divinité en dehors Lui. Et ne diminuez pas les mesures et le poids. Je vous vois dans l'aisance, et je crains pour vous [si vous ne croyez pas] le châtiment d'un jour qui enveloppera tout.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mdlviii{O mon peuple, faites équitablement pleine mesure et plein poids, ne dépréciez pas aux gens leurs valeurs et ne semez pas la corruption sur terre.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mdlix{Ce qui demeure auprès d'Allah est meilleur pour vous si vous êtes croyants! Et je ne suis pas un gardien pour vous».\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mdlx{Ils dirent: «O Chuayb! Est-ce que ta prière te demande de nous faire abandonner ce qu'adoraient nos ancêtres, ou de ne plus faire de nos biens ce que nous voulons? Est-ce toi l'indulgent, le droit?»\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mdlxi{Il dit: «O mon peuple, voyez-vous si je me base sur une preuve évidente émanant de mon Seigneur, et s'Il m'attribue de Sa part une excellente donation?... Je ne veux nullement faire ce que je vous interdis. Je ne veux que la réforme, autant que je le puis. Et ma réussite ne dépend que d'Allah. En Lui je place ma confiance, et c'est vers Lui que je reviens repentant.\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mdlxii{O mon peuple, que votre répugnance et votre hostilité à mon égard ne vous entraînent pas à encourir les mêmes châtiments qui atteignirent le peuple de Noé, le peuple de Hûd, ou le peuple de Sâlih et (l'exemple du) peuple de Lot n'est pas éloigné de vous.\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mdlxiii{Et implorez le pardon de votre Seigneur et repentez-vous à Lui. Mon Seigneur est vraiment Miséricordieux et plein d'amour».\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mdlxiv{Ils dirent: «O Chuayb, nous ne comprenons pas grand chose à ce que tu dis; et vraiment nous te considérons comme un faible parmi nous. Si ce n'est ton clan, nous t'aurions certainement lapidé. Et rien ne nous empêche de t'atteindre».\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mdlxv{Il dit: «O mon peuple, mon clan est-il à vos yeux plus puissant qu'Allah à qui vous tournez ouvertement le dos? Mon Seigneur embrasse (en Sa science) tout ce que vous œuvrez.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mdlxvi{O mon peuple, agissez autant que vous voulez. Moi aussi j'agis. Bientôt, vous saurez sur qui tombera un châtiment qui le déshonorera, et qui de nous est l'imposteur. Et attendez (la conséquence de vos actes)! Moi aussi j'attends avec vous».\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mdlxvii{Lorsque vint Notre ordre, Nous sauvâmes, par une miséricorde de Notre part, Chuayb et ceux qui avaient cru avec lui. Et le Cri terrible saisit les injustes, et ils gisèrent dans leurs demeures,\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mdlxviii{comme s'ils n'y avaient jamais prospéré. Que les Madyan s'éloignent comme les Thamûd se sont éloignés.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mdlxix{Et Nous avions envoyé Moïse, avec Nos miracles et une autorité incontestable,\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mdlxx{à Pharaon et ses notables. Mais ils suivirent l'ordre de Pharaon, bien que l'ordre de Pharaon n'avait rien de sensé.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mdlxxi{Il précédera son peuple, au Jour de la Résurrection. Il les mènera à l'aiguade du Feu. Et quelle détestable aiguade!\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mdlxxii{Et ils sont poursuivis par une malédiction ici-bas et au Jour de la Résurrection. Quel détestable don leur sera donné!\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mdlxxiii{Cela fait partie des récits que Nous te [Muhammad] racontons concernant des cités: les unes sont encore debout, tandis que d'autres (sont complètement) rasées.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mdlxxiv{Nous ne leur avons fait aucun tort. Mais ils se sont fait du tort à eux-mêmes. Leurs divinités, qu'ils invoquaient en dehors d'Allah, ne leur ont servi à rien, quand l'Ordre (le châtiment) de ton Seigneur fut venu; elles n'ont fait qu'accroître leur perte.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mdlxxv{Telle est la rigueur de la prise de ton Seigneur quand Il frappe les cités lorsqu'elles sont injustes. Son châtiment est bien douloureux et bien dur.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mdlxxvi{Il y a bien là un signe pour celui qui craint le châtiment de l'au-delà. C'est un jour où les gens seront rassemblés; et c'est un jour solennel (attesté par tous).\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mdlxxvii{Et Nous ne le retardons que pour un terme bien déterminé.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mdlxxviii{Le jour où cela arrivera, nulle âme ne parlera qu'avec Sa permission (celle d'Allah). Il y aura des damnés et des heureux.\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mdlxxix{Ceux qui sont damnés seront dans le Feu où ils ont des soupirs et des sanglots.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mdlxxx{Pour y demeurer éternellement tant que dureront les cieux et la terre - à moins que ton Seigneur en décide autrement - car ton Seigneur fait absolument tout ce qu'Il veut.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mdlxxxi{Et quant aux bienheureux, ils seront au Paradis, pour y demeurer éternellement tant que dureront les cieux et la terre - à moins que ton Seigneur n'en décide autrement - c'est là un don qui n'est jamais interrompu.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mdlxxxii{Ne sois donc pas en doute au sujet de ce que ceux-là adorent. Ils n'adorent que comme leurs ancêtres adoraient auparavant. Et Nous leur donnerons la totalité de leur part, sans en rien retrancher.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mdlxxxiii{Et Nous avons déjà donné à Moïse le Livre. Il y eut des divergences à son sujet. S'il n'y avait pas un décret préalable de la part de ton Seigneur, tout aurait été décidé entre eux. Et ils sont, à son sujet pleins d'un doute troublant.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mdlxxxiv{Très certainement, ton Seigneur fera leur pleine rétribution à tous pour leurs œuvres... Il est Parfaitement Connaisseur de ce qu'ils font.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mdlxxxv{Demeure sur le droit chemin comme il t'est commandé, ainsi que ceux qui sont revenus [à Allah] avec toi. Et ne commettez pas d'excès. Car vraiment Il observe ce que vous faites.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@mdlxxxvi{Et ne vous penchez pas vers les injustes: sinon le Feu vous atteindrait. Vous n'avez pas d'alliés en dehors d'Allah. Et vous ne serez pas secourus.\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@mdlxxxvii{Et accomplis la Salât aux deux extrémités du jour et à certaines heures de la nuit. Les bonnes œuvres dissipent les mauvaises. Cela est une exhortation pour ceux qui réfléchissent.\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@mdlxxxviii{Et sois patient. Car Allah ne laisse pas perdre la récompense des gens bienfaisants.\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@mdlxxxix{Si seulement il existait, dans les générations d'avant vous, des gens vertueux qui interdisent la corruption sur terre! (Hélas) Il n'y en avait qu'un petit nombre que Nous sauvâmes, alors que les injustes persistaient dans le luxe (exagéré) dans lequel ils vivaient, et ils étaient des criminels.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@mdxc{Et ton Seigneur n'est point tel à détruire injustement des cités dont les habitants sont des réformateurs.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@mdxci{Et si ton Seigneur avait voulu, Il aurait fait des gens une seule communauté. Or, ils ne cessent d'être en désaccord (entre eux,)\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@mdxcii{sauf ceux à qui ton Seigneur a accordé miséricorde. C'est pour cela qu'Il les a créés. Et la parole de ton Seigneur s'accomplit: «Très certainement, Je remplirai l'Enfer de djinns et d'hommes, tous ensemble».\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@mdxciii{Et tout ce que Nous te racontons des récits des messagers, c'est pour en raffermir ton cœur. Et de ceux-ci t'est venue la vérité ainsi qu'une exhortation et un rappel aux croyants.\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@mdxciv{Et dis à ceux qui ne croient pas: «Oeuvrez autant que vous pouvez. Nous aussi, nous œuvrons.\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@mdxcv{Et attendez. Nous aussi nous attendons!»\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@mdxcvi{A Allah appartient l'Inconnaissable des cieux et de la terre, et c'est à Lui que revient l'ordre tout entier. Adore-Le donc et place ta confiance en Lui. Ton Seigneur n'est pas inattentif à ce que vous faites.\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@mdxcvii{\basmalahfr Alif, Lâm, Râ. Tels sont les versets du Livre explicite.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mdxcviii{Nous l'avons fait descendre, un Coran en [langue] arabe, afin que vous raisonniez.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mdxcix{Nous te racontons le meilleur récit, grâce à la révélation que Nous te faisons dans ce Coran même si tu étais auparavant du nombre des inattentifs (à ces récits).\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mdc{Quand Joseph dit à son père: «O mon père, j'ai vu [en songe], onze étoiles, et aussi le soleil et la lune; je les ai vus prosternés devant moi».\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mdci{«O mon fils, dit-il, ne raconte pas ta vision à tes frères car ils monteraient un complot contre toi; le Diable est certainement pour l'homme un ennemi déclaré.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mdcii{Ainsi ton Seigneur te choisira et t'enseignera l'interprétation des rêves, et Il parfera Son bienfait sur toi et sur la famille de Jacob, tout comme Il l'a parfait auparavant sur tes deux ancêtres, Abraham et Isaac, car ton Seigneur est Omniscient et Sage.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mdciii{Il y avait certainement, en Joseph et ses frères, des exhortations pour ceux qui interrogent,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mdciv{quand ceux-ci dirent: «Joseph et son frère sont plus aimés de notre père que nous, alors que nous sommes un groupe bien fort. Notre père est vraiment dans un tort évident.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mdcv{Tuez Joseph ou bien éloignez-le dans n'importe quel pays, afin que le visage de votre père se tourne exclusivement vers vous, et que vous soyez après cela des gens de bien».\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mdcvi{L'un d'eux dit: «Ne tuez pas Joseph, mais jetez-le si vous êtes disposés à agir, au fond du puits afin que quelque caravane le recueille».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mdcvii{Ils dirent: «O notre père, qu'as-tu à ne pas te fier à nous au sujet de Joseph? Nous sommes cependant bien intentionnés à son égard.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mdcviii{Envoie-le demain avec nous faire une promenade et jouer. Et nous veillerons sur lui».\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mdcix{Il dit: «Certes, je m'attristerai que vous l'emmeniez; et je crains que le loup ne le dévore dans un moment où vous ne ferez pas attention à lui».\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mdcx{Ils dirent: «Si le loup le dévore alors que nous sommes nombreux, nous serons vraiment les perdants».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mdcxi{Et lorsqu'ils l'eurent emmené, et se furent mis d'accord pour le jeter dans les profondeurs invisibles du puits, Nous lui révélâmes: «Tu les informeras sûrement de cette affaire sans qu'ils s'en rendent compte».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mdcxii{Et ils vinrent à leur père, le soir, en pleurant.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mdcxiii{Ils dirent: «O notre père, nous sommes allés faire une course, et nous avons laissé Joseph auprès de nos effets; et le loup l'a dévoré. Tu ne nous croiras pas, même si nous disons la vérité».\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mdcxiv{Ils apportèrent sa tunique tachée d'un faux sang. Il dit: «Vos âmes, plutôt, vous ont suggéré quelque chose... [Il ne me reste plus donc] qu'une belle patience! C'est Allah qu'il faut appeler au secours contre ce que vous racontez!»\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mdcxv{Or, vint une caravane. Ils envoyèrent leur chercheur d'eau, qui fit descendre son seau. Il dit: «Bonne nouvelle! Voilà un garçon!» Et ils le dissimulèrent [pour le vendre] telle une marchandise. Allah cependant savait fort bien ce qu'ils faisaient.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mdcxvi{Et ils le vendirent à vil prix: pour quelques dirhams comptés. Ils le considéraient comme indésirable.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mdcxvii{Et celui qui l'acheta était de l'Egypte. Il dit à sa femme: «Accorde lui une généreuse hospitalité. Il se peut qu'il nous soit utile ou que nous l'adoptions comme notre enfant.» Ainsi avons-nous raffermi Joseph dans le pays et nous lui avons appris l'interprétation des rêves. Et Allah est souverain en Son Commandement: mais la plupart des gens ne savent pas.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mdcxviii{Et quand il eut atteint sa maturité Nous lui accordâmes sagesse et savoir. C'est ainsi que nous récompensons les bienfaisants.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mdcxix{Or celle [Zulikha] qui l'avait reçu dans sa maison essaya de le séduire. Et elle ferma bien les portes et dit: «Viens, (je suis prête pour toi!)» - Il dit: «Qu'Allah me protège! C'est mon maître qui m'a accordé un bon asile. Vraiment les injustes ne réussissent pas».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mdcxx{Et, elle le désira. Et il l'aurait désirée n'eût été ce qu'il vit comme preuve évidente de son Seigneur. Ainsi [Nous avons agi] pour écarter de lui le mal et la turpitude. Il était certes un de Nos serviteurs élus.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mdcxxi{Et tous deux coururent vers la porte, et elle lui déchira sa tunique par derrière. Ils trouvèrent le mari [de cette femme] à la porte. Elle dit: «Quelle serait la punition de quiconque a voulu faire du mal à ta famille, sinon la prison, ou un châtiment douloureux?»\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mdcxxii{[Joseph] dit: «C'est elle qui a voulu me séduire». Et un témoin, de la famille de celle-ci témoigna: «Si sa tunique [à lui] est déchirée par devant, alors c'est elle qui dit la vérité, tandis qu'il est du nombre des menteurs.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mdcxxiii{Mais si sa tunique est déchirée par derrière, alors c'est elle qui mentit, tandis qu'il est du nombre des véridiques».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mdcxxiv{Puis, quand il (le mari) vit la tunique déchirée par derrière, il dit: «C'est bien de votre ruse de femmes! Vos ruses sont vraiment énormes!\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mdcxxv{Joseph, ne pense plus à cela! Et toi, (femme), implore le pardon pour ton péché car tu es fautive».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mdcxxvi{Et dans la ville, des femmes dirent: «la femme d'Al-'Azize essaye de séduire son valet! Il l'a vraiment rendue folle d'amour. Nous la trouvons certes dans un égarement évident.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mdcxxvii{Lorsqu'elle eut entendu leur fourberie, elle leur envoya [des invitations,] et prépara pour elles une collation; et elle remit à chacune d'elles un couteau. Puis elle dit: «Sors devant elles, (Joseph!)» - Lorsqu'elles le virent, elles l'admirèrent, se coupèrent les mains et dirent: «A Allah ne plaise! Ce n'est pas un être humain, ce n'est qu'un ange noble!»\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mdcxxviii{Elle dit: «Voilà donc celui à propos duquel vous me blâmiez. J'ai essayé de le séduire mais il s'en défendit fermement. Or, s'il ne fait pas ce que je lui commande, il sera très certainement emprisonné et sera certes parmi les humiliés».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mdcxxix{Il dit: «O mon Seigneur, la prison m'est préférable à ce à quoi elles m'invitent. Et si Tu n'écartes pas de moi leur ruse, je pencherai vers elles et serai du nombre des ignorants» [des pécheurs].\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mdcxxx{Son Seigneur l'exauça donc, et éloigna de lui leur ruse. C'est Lui, vraiment, qui est l'Audient et l'Omniscient.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mdcxxxi{Puis, après qu'ils eurent vu les preuves (de son innocence), il leur sembla qu'ils devaient l'emprisonner pour un temps.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mdcxxxii{Deux valets entrèrent avec lui en prison. L'un d'eux dit: «Je me voyais [en rêve] pressant du raisin...» Et l'autre dit: «Et moi, je me voyais portant sur ma tête du pain dont les oiseaux mangeaient. Apprends-nous l'interprétation (de nos rêves), nous te voyons au nombre des bienfaisants».\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mdcxxxiii{«La nourriture qui vous est attribuée ne vous parviendra point, dit-il, que je ne vous aie avisés de son interprétation [de votre nourriture] avant qu'elle ne vous arrive. Cela fait partie de ce que mon Seigneur m'a enseigné. Certes, j'ai abandonné la religion d'un peuple qui ne croit pas en Allah et qui nie la vie future».\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mdcxxxiv{Et j'ai suivi la religion de mes ancêtres, Abraham, Isaac et Jacob. Il ne nous convient pas d'associer à Allah quoi que ce soit. Ceci est une grâce d'Allah sur nous et sur tout le monde; mais la plupart des gens ne sont pas reconnaissants.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mdcxxxv{O mes deux compagnons de prison! Qui est le meilleur: des Seigneurs éparpillés ou Allah, l'Unique, le Dominateur suprême?\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mdcxxxvi{Vous n'adorez, en dehors de Lui, que des noms que vous avez inventés, vous et vos ancêtres, et à l'appui desquels Allah n'a fait descendre aucune preuve. Le pouvoir n'appartient qu'à Allah. Il vous a commandé de n'adorer que Lui. Telle est la religion droite; mais la plupart des gens ne savent pas.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mdcxxxvii{O mes deux compagnons de prison! L'un de vous donnera du vin à boire à son maître; quant à l'autre, il sera crucifié, et les oiseaux mangeront de sa tête. L'affaire sur laquelle vous me consultez est déjà décidée.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mdcxxxviii{Et il dit à celui des deux dont il pensait qu'il serait délivré: «Parle de moi auprès de ton maître». Mais le Diable fit qu'il oublia de rappeler (le cas de Joseph) à son maître. Joseph resta donc en prison quelques années.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mdcxxxix{Et le roi dit: «En vérité, je voyais (en rêve) sept vaches grasses mangées par sept maigres; et sept épis verts, et autant d'autres, secs. O conseil de notables, donnez-moi une explication de ma vision, si vous savez interpréter le rêve».\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mdcxl{Ils dirent: «C'est un amas de rêves! Et nous ne savons pas interpréter les rêves!»\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mdcxli{Or, celui des deux qui avait été délivré et qui, après quelque temps se rappela, dit: «Je vous en donnerai l'interprétation. Envoyez-moi donc».\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mdcxlii{«O toi, Joseph, le véridique! Eclaire-nous au sujet de sept vaches grasses que mangent sept très maigres, et sept épis verts et autant d'autres, secs, afin que je retourne aux gens et qu'ils sachent [l'interprétation exacte du rêve]».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mdcxliii{Alors [Joseph dit]: «Vous sèmerez pendant sept années consécutives. Tout ce que vous aurez moissonné, laissez-le en épi, sauf le peu que vous consommerez.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mdcxliv{Viendront ensuite sept années de disette qui consommeront tout ce que vous aurez amassé pour elles sauf le peu que vous aurez réservé [comme semence].\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mdcxlv{Puis, viendra après cela une année où les gens seront secourus [par la pluie] et iront au pressoir.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mdcxlvi{Et le roi dit: «Amenez-le moi». Puis, lorsque l'émissaire arriva auprès de lui, [Joseph] dit: «Retourne auprès de ton maître et demande-lui: «Quelle était la raison qui poussa les femmes à se couper les mains? Mon Seigneur connaît bien leur ruse».\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mdcxlvii{Alors, [le roi leur] dit: «Qu'est-ce donc qui vous a poussées à essayer de séduire Joseph?» Elles dirent: «A Allah ne plaise! Nous ne connaissons rien de mauvais contre lui». Et la femme d'Al-'Azize dit: «Maintenant la vérité s'est manifestée. C'est moi qui ai voulu le séduire. Et c'est lui, vraiment, qui est du nombre des véridiques!»\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mdcxlviii{«Cela afin qu'il sache que je ne l'ai pas trahi en son absence, et qu'en vérité Allah ne guide pas la ruse des traîtres.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mdcxlix{Je ne m'innocente cependant pas, car l'âme est très incitatrice au mal, à moins que mon Seigneur, par miséricorde, [ne la préserve du péché]. Mon Seigneur est certes Pardonneur et très Miséricordieux».\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mdcl{Et le roi dit: «Amenez-le moi: je me le réserve pour moi-même». Et lorsqu'il lui eut parlé, il dit: «Tu es dès aujourd'hui près de nous, en une position d'autorité et de confiance».\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mdcli{Et [Joseph] dit: «Assigne-moi les dépôts du territoire: je suis bon gardien et connaisseur».\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mdclii{Ainsi avons-nous affermi (l'autorité de) Joseph dans ce territoire et il s'y installait là où il le voulait. Nous touchons de Notre miséricorde qui Nous voulons et ne faisons pas perdre aux hommes de bien le mérite [de leurs œuvres].\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mdcliii{Et la récompense de l'au-delà est meilleure pour ceux qui ont cru et ont pratiqué la piété.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mdcliv{Et les frères de Joseph vinrent et entrèrent auprès de lui. Il les reconnut, mais eux ne le reconnurent pas.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mdclv{Et quand il leur eut fourni leur provision, il dit: «Amenez-moi un frère que vous avez de votre père. Ne voyez-vous pas que je donne la pleine mesure et que je suis le meilleur des hôtes?\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mdclvi{Et si vous ne me l'amenez pas, alors il n'y aura plus de provision pour vous, chez moi; et vous ne m'approcherez plus».\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mdclvii{Ils dirent: «Nous essayerons de persuader son père. Certes, nous le ferons».\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mdclviii{Et il dit à ses serviteurs: «Remettez leurs marchandises dans leurs sacs: peut-être les reconnaîtront-ils quand ils seront de retour vers leur famille et peut-être qu'ils reviendront».\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mdclix{Et lorsqu'ils revinrent à leur père, ils dirent: «O notre père, il nous sera refusé [à l'avenir] de nous ravitailler [en grain]. Envoie donc avec nous notre frère, afin que nous obtenions des provisions. Nous le surveillerons bien».\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mdclx{Il dit: «Vais-je vous le confier comme, auparavant, je vous ai confié son frère? Mais Allah est le meilleur gardien, et Il est Le plus Miséricordieux des miséricordieux!»\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mdclxi{Et lorsqu'ils ouvrirent leurs bagages, ils trouvèrent qu'on leur avait rendu leurs marchandises. Ils dirent: «O notre père. Que désirons-nous [de plus]? Voici que nos marchandises nous ont été rendues. Et ainsi nous approvisionnerons notre famille, nous veillerons à la sécurité de notre frère et nous nous ajouterons la charge d'un chameau et c'est une charge facile».\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mdclxii{- Il dit: «Jamais je ne l'enverrai avec vous, jusqu'à ce que vous m'apportiez l'engagement formel au nom d'Allah que vous me le ramènerez à moins que vous ne soyez cernés». Lorsqu'ils lui eurent apporté l'engagement, il dit: «Allah est garant de ce que nous disons».\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mdclxiii{Et il dit: «O mes fils, n'entrez pas par une seule porte, mais entrez par portes séparées. Je ne peux cependant vous être d'aucune utilité contre les desseins d'Allah. La décision n'appartient qu'à Allah: en Lui je place ma confiance. Et que ceux qui placent leur confiance la placent en Lui».\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mdclxiv{Etant entrés comme leur père le leur avait commandé [cela] ne leur servit à rien contre (les décrets d') Allah. Ce n'était [au reste] qu'une précaution que Jacob avait jugé [de leur recommander]. Il avait pleine connaissance de ce que Nous lui avions enseigné. Mais la plupart des gens ne savent pas.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mdclxv{Et quand ils furent entrés auprès de Joseph, [celui-ci] retint son frère auprès de lui en disant: «Je suis ton frère. Ne te chagrine donc pas pour ce qu'ils faisaient».\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mdclxvi{Puis, quand il leur eut fourni leurs provisions, il mit la coupe dans le sac de son frère. Ensuite un crieur annonça: «Caravaniers! vous êtes des voleurs».\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mdclxvii{Ils se retournèrent en disant: «Qu'avez-vous perdu?»\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mdclxviii{Ils répondirent: «Nous cherchons la grande coupe du roi. La charge d'un chameau à qui l'apportera et j'en suis garant».\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mdclxix{«Par Allah, dirent-ils, vous savez certes que nous ne sommes pas venus pour semer la corruption sur le territoire et que nous ne sommes pas des voleurs».\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mdclxx{- Quelle sera donc la sanction si vous êtes des menteurs? (dirent-ils).\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mdclxxi{Ils dirent: «La sanction infligée à celui dont les bagages de qui la coupe sera retrouvée est: [qu'il soit livré] lui-même [à titre d'esclave à la victime du vol]. C'est ainsi que nous punissons les malfaiteurs».\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mdclxxii{[Joseph] commença par les sacs des autres avant celui de son frère; puis il la fit sortir du sac de son frère. Ainsi suggérâmes-Nous cet artifice à Joseph. Car il ne pouvait pas se saisir de son frère, selon la justice du roi, à moins qu'Allah ne l'eût voulu. Nous élevons en rang qui Nous voulons. Et au-dessus de tout homme détenant la science il y a un savant [plus docte que lui].\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mdclxxiii{Ils dirent: «S'il a commis un vol, un frère à lui auparavant a volé aussi.» Mais Joseph tint sa pensée secrète, et ne la leur dévoila pas. Il dit [en lui même]: «Votre position est bien pire encore! Et Allah connaît mieux ce que vous décrivez.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mdclxxiv{- Ils dirent. «O Al-'Azize, il a un père très vieux; saisis-toi donc de l'un de nous, à sa place. Nous voyons que tu es vraiment du nombre des gens bienfaisants».\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mdclxxv{- Il dit: «Qu'Allah nous garde de prendre un autre que celui chez qui nous avons trouvé notre bien! Nous serions alors vraiment injustes.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mdclxxvi{Puis, lorsqu'ils eurent perdu tout espoir [de ramener Benyamin] ils se concertèrent en secret. Leur aîné dit: «Ne savez-vous pas que votre père a pris de vous un engagement formel au nom d'Allah, et que déjà vous y avez manqué autrefois à propos de Joseph? Je ne quitterai point le territoire, jusqu'à ce que mon père me le permette ou qu'Allah juge en ma faveur, et Il est le meilleur des juges.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mdclxxvii{Retournez à votre père et dites: «O notre père, ton fils a volé. Et nous n'attestons que ce que nous savons. Et nous n'étions nullement au courant de l'inconnu.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mdclxxviii{Et interroge la ville où nous étions, ainsi que la caravane dans laquelle nous sommes arrivés. Nous disons réellement la vérité.»\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mdclxxix{Alors [Jacob] dit: Vos âmes plutôt vous ont inspiré [d'entreprendre] quelque chose!... Oh! belle patience. Il se peut qu'Allah me les ramènera tous les deux. Car c'est Lui l'Omniscient, le Sage».\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mdclxxx{Et il se détourna d'eux et dit: «Que mon chagrin est grand pour Joseph!» Et ses yeux blanchirent d'affliction. Et il était accablé.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mdclxxxi{- Ils dirent: «Par Allah! Tu ne cesseras pas d'évoquer Joseph, jusqu'à ce que tu t'épuises ou que tu sois parmi les morts».\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mdclxxxii{- Il dit: «Je ne me plains qu'à Allah de mon déchirement et de mon chagrin. Et, je sais de la part d'Allah, ce que vous ne savez pas.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mdclxxxiii{O mes fils! Partez et enquérez-vous de Joseph et de son frère. Et ne désespérez pas de la miséricorde d'Allah. Ce sont seulement les gens mécréants qui désespèrent de la miséricorde d'Allah».\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mdclxxxiv{Et lorsqu'ils s'introduisirent auprès de [Joseph,] ils dirent: «O al-'Azize, la famine nous a touchés, nous et notre famille; et nous venons avec une marchandise sans grande valeur. Donne-nous une pleine mesure, et fais-nous la charité. Certes, Allah récompense les charitables!»\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mdclxxxv{- Il dit: «Savez-vous ce que vous avez fait de Joseph et de son frère alors que vous étiez ignorants? [injustes]».\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mdclxxxvi{- Ils dirent: «Est-ce que tu es... Certes, tu es Joseph!» - Il dit: «Je suis Joseph, et voici mon frère. Certes, Allah nous a favorisés. Quiconque craint et patiente... Et très certainement, Allah ne fait pas perdre la récompense des bienfaisants».\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mdclxxxvii{- Ils dirent: «Par Allah! Vraiment Allah t'a préféré à nous et nous avons été fautifs».\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mdclxxxviii{- Il dit: «Pas de récrimination contre vous aujourd'hui! Qu'Allah vous pardonne. C'est Lui Le plus Miséricordieux des miséricordieux.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mdclxxxix{Emportez ma tunique que voici, et appliquez-la sur le visage de mon père: il recouvrera [aussitôt] la vue. Et amenez-moi toute votre famille».\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mdcxc{- Et dès que la caravane franchit la frontière [de Canâan], leur père dit: «Je décèle, certes, l'odeur de Joseph, même si vous dites que je radote».\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mdcxci{Ils Lui dirent: «Par Allah te voilà bien dans ton ancien égarement».\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mdcxcii{Puis quand arriva le porteur de bonne annonce, il l'appliqua [la tunique] sur le visage de Jacob. Celui-ci recouvra [aussitôt] la vue, et dit: «Ne vous ai-je pas dit que je sais, par Allah, ce que vous ne savez pas?»\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mdcxciii{- Ils dirent: «O notre père, implore pour nous la rémission de nos péchés. Nous étions vraiment fautifs».\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mdcxciv{- Il dit: «J'implorerai pour vous le pardon de mon Seigneur. Car c'est Lui le Pardonneur, le Très Miséricordieux».\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mdcxcv{Lorsqu'ils s'introduisirent auprès de Joseph, celui-ci accueillit ses père et mère, et leur dit: «Entrez en Egypte, en toute sécurité, si Allah le veut!»\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mdcxcvi{Et il éleva ses parents sur le trône, et tous tombèrent devant lui, prosternés. Et il dit: «O mon père, voilà l'interprétation de mon rêve de jadis. Allah l'a bel et bien réalisé... Et Il m'a certainement fait du bien quand Il m'a fait sortir de prison et qu'Il vous a fait venir de la campagne, [du désert], après que le Diable ait suscité la discorde entre mes frères et moi. Mon Seigneur est plein de douceur pour ce qu'Il veut. Et c'est Lui l'Omniscient, le Sage.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mdcxcvii{O mon Seigneur, Tu m'as donné du pouvoir et m'as enseigné l'interprétation des rêves. [C'est Toi Le] Créateur des cieux et de la terre, Tu es mon patron, ici-bas et dans l'au-delà. Fais-moi mourir en parfaite soumission et fais moi rejoindre les vertueux.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mdcxcviii{Ce sont là des récits inconnus que Nous te révélons. Et tu n'étais pas auprès d'eux quand ils se mirent d'accord pour comploter.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mdcxcix{Et la plupart des gens ne sont pas croyants malgré ton désir ardent.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mdcc{Et tu ne leur demandes aucun salaire pour cela. Ce n'est là qu'un rappel adressé à l'univers.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mdcci{Et dans les cieux et sur la terre, que de signes auprès desquels les gens passent, en s'en détournant!\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mdccii{Et la plupart d'entre eux ne croient en Allah, qu'en lui donnant des associés.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mdcciii{Est-ce qu'ils sont sûrs que le châtiment d'Allah ne viendra pas les couvrir ou que l'Heure ne leur viendra pas soudainement, sans qu'ils s'en rendent compte?\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mdcciv{Dis: «Voici ma voie, j'appelle les gens à [la religion] d'Allah, moi et ceux qui me suivent, nous basant sur une preuve évidente. Gloire à Allah! Et je ne suis point du nombre des associateurs.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mdccv{Nous n'avons envoyé avant toi que des hommes originaires des cités, à qui Nous avons fait des révélations. [Ces gens là] n'ont-ils pas parcouru la terre et considéré quelle fut la fin de ceux qui ont vécu avant eux? La demeure de l'au-delà est assurément meilleure pour ceux qui craignent [Allah]. Ne raisonnerez-vous donc pas?\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mdccvi{Quand les messagers faillirent perdre espoir (et que leurs adeptes) eurent pensé qu'ils étaient dupés voilà que vint à eux Notre secours. Et furent sauvés ceux que Nous voulûmes. Mais Notre rigueur ne saurait être détournée des gens criminels.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mdccvii{Dans leurs récits il y a certes une leçon pour les gens doués d'intelligence. Ce n'est point là un récit fabriqué. C'est au contraire la confirmation de ce qui existait déjà avant lui, un exposé détaillé de toute chose, un guide et une miséricorde pour des gens qui croient.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mdccviii{\basmalahfr Alif, Lâm, Mîm, Râ. Voici les versets du Livre; et ce qui t'a été révélé par ton Seigneur est la vérité; mais la plupart des gens ne croient pas.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mdccix{Allah est Celui qui a élevé [bien haut] les cieux sans piliers visibles. Il S'est établi [istawâ] sur le Trône et a soumis le soleil et la lune, chacun poursuivant sa course vers un terme fixé. Il règle l'Ordre [de tout] et expose en détail les signes afin que vous ayez la certitude de la rencontre de votre Seigneur.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mdccx{Et c'est Lui qui a étendu la terre et y a placé montagnes et fleuves. Et de chaque espèce de fruits Il y établit deux éléments de couple. Il fait que la nuit couvre le jour. Voilà bien là des preuves pour des gens qui réfléchissent.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mdccxi{Et sur la terre il y a des parcelles voisines les unes des autres, des jardins [plantés] de vignes, et des céréales et des palmiers, en touffes ou espacés, arrosés de la même eau, cependant Nous rendons supérieurs les uns aux autres quant au goût. Voilà bien là des preuves pour des gens qui raisonnent.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mdccxii{Et si tu dois t'étonner, rien de plus étonnant que leurs dires: «Quand nous seront poussière, reviendrons-nous vraiment à une nouvelle création?» Ceux-là sont ceux qui ne croient pas en leur Seigneur. Et ce sont eux qui auront des jougs à leur cou. Et ce sont eux les gens du Feu, où ils demeureront éternellement.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mdccxiii{Et ils te demandent de hâter [la venue] du malheur plutôt que celle du bonheur. Certes, il s'est produit avant eux des châtiments exemplaires. Ton Seigneur est Détenteur du pardon pour les gens, malgré leurs méfaits. Et ton Seigneur est assurément dur en punition.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mdccxiv{Et ceux qui ont mécru disent: «Pourquoi n'a-t-on pas fait descendre sur celui-ci (Muhammad) un miracle venant de son Seigneur?» Tu n'es qu'un avertisseur, et à chaque peuple un guide.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mdccxv{Allah sait ce que porte chaque femelle, et de combien la période de gestation dans la matrice est écourtée ou prolongée. Et toute chose a auprès de Lui sa mesure.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mdccxvi{Le Connaisseur de ce qui est caché et de ce qui est apparent, Le Grand, Le Sublime.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mdccxvii{Sont égaux pour lui, celui parmi vous qui tient secrète sa parole, et celui qui la divulgue, celui qui se cache la nuit comme celui qui se montre au grand jour.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mdccxviii{Il [l'homme] a par devant lui et derrière lui des Anges qui se relaient et qui veillent sur lui par ordre d'Allah. En vérité, Allah ne modifie point l'état d'un peuple, tant que les [individus qui le composent] ne modifient pas ce qui est en eux-mêmes. Et lorsqu'Allah veut [infliger] un mal à un peuple, nul ne peut le repousser: ils n'ont en dehors de Lui aucun protecteur.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mdccxix{C'est lui qui vous fait voir l'éclair [qui vous inspire] crainte et espoir; et Il crée les nuages lourds.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mdccxx{Le tonnerre Le glorifie par Sa louange, et aussi les Anges, sous l'effet de Sa crainte. Et Il lance les foudres dont Il atteint qui Il veut. Or ils disputent au sujet d'Allah alors qu'Il est redoutable en Sa force.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mdccxxi{A Lui l'appel de la Vérité! Ceux qu'ils invoquent en dehors de Lui ne leur répondent d'aucune façon; semblables à celui qui étend ses deux mains vers l'eau pour la porter à sa bouche, mais qui ne parvient jamais à l'atteindre. L'invocation des mécréants n'est que vanité.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mdccxxii{Et c'est à Allah que se prosternent, bon gré mal gré, tous ceux qui sont dans les cieux et sur la terre, ainsi que leurs ombres, au début et à la fin de la journée.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mdccxxiii{Dis: «Qui est le Seigneur des cieux et de la terre?» Dis: «Allah». Dis: «Et prendrez-vous en dehors de Lui, des maîtres qui ne détiennent pour eux-mêmes ni bien ni mal?» Dis: «Sont-ils égaux, l'aveugle et celui qui voit? Ou sont-elles égales, les ténèbres et la lumière? Ou donnent-ils à Allah des associés qui créent comme Sa création au point que les deux créations se soient confondues à eux? Dis: «Allah est le Créateur de toute chose, et c'est Lui l'Unique, le Dominateur suprême».\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mdccxxiv{Il a fait descendre une eau du ciel à laquelle des vallées servent de lit, selon leur grandeur. Le flot débordé a charrié une écume flottante; et semblable à celle-ci est [l'] écume provenant de ce qu'on porte à fusion, dans le feu pour [fabriquer] des bijoux et des ustensiles. Ainsi Allah représente en parabole la Vérité et le Faux: l'écume [du torrent et du métal fondu] s'en va, au rebut, tandis que [l'eau et les objets] utiles aux Hommes demeurent sur la terre. Ainsi Allah propose des paraboles.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mdccxxv{La meilleure [fin] est pour ceux qui répondent à [l'appel] de leur Seigneur. Et quant à ceux qui ne Lui répondent pas, s'ils avaient tout ce qui est sur la terre, et autant encore, ils l'offriraient en rançon. Ceux-là auront le détestable rendement de compte et l'Enfer sera leur refuge. Quel détestable lit de repos!\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mdccxxvi{Celui qui sait que ce qui t'est révélé de la part de ton Seigneur est la vérité, est-il semblable à l'aveugle? Seuls les gens doués d'intelligence réfléchissent bien,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mdccxxvii{ceux qui remplissent leur engagement envers Allah et ne violent pas le pacte,\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mdccxxviii{qui unissent ce qu'Allah a commandé d'unir, redoutent leur Seigneur et craignent une malheureuse reddition de compte,\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mdccxxix{et qui endurent dans la recherche de l'agrément d'Allah, accomplissent la Salât et dépensent (dans le bien), en secret et en public, de ce que Nous leur avons attribué, et repoussent le mal par le bien. A ceux-là, la bonne demeure finale,\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mdccxxx{les jardins d'Eden, où ils entreront, ainsi que tous ceux de leurs ascendants, conjoints et descendants, qui ont été de bons croyants. De chaque porte, les Anges entreront auprès d'eux:\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mdccxxxi{- «Paix sur vous, pour ce que vous avez enduré!» - Comme est bonne votre demeure finale!»\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mdccxxxii{[Mais] ceux qui violent leur pacte avec Allah après l'avoir engagé, et rompent ce qu'Allah a commandé d'unir et commettent le désordre sur terre, auront la malédiction et la mauvaise demeure.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mdccxxxiii{Allah étend largement Ses dons ou [les] restreint à qui Il veut. Ils se réjouissent de la vie sur terre, mais la vie d'ici-bas ne paraîtra que comme une jouissance éphémère en comparaison de l'au-delà.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mdccxxxiv{Ceux qui ont mécru disent: «Pourquoi n'a-t-on pas descendu sur lui (Muhammad) un miracle venant de son Seigneur?» Dis: «En vérité, Allah égare qui Il veut; et Il guide vers Lui celui qui se repent,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mdccxxxv{ceux qui ont cru, et dont les cœurs se tranquillisent à l'évocation d'Allah». Certes, c'est par l'évocation d'Allah que les cœurs se tranquillisent.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mdccxxxvi{Ceux qui croient et font de bonnes œuvres, auront le plus grand bien et aussi le plus bon retour.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mdccxxxvii{Ainsi Nous t'envoyons dans une communauté - que d'autres communautés ont précédée - pour que tu leur récites ce que Nous te révélons [le Coran], cependant qu'ils ne croient pas au Tout Miséricordieux. Dis: «C'est Lui mon Seigneur. Pas d'autre divinité à part Lui. En Lui je place ma confiance. Et à Lui je me repens».\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mdccxxxviii{S'il y avait un Coran à mettre les montagnes en marche, à fendre la terre ou à faire parler les morts (ce serait celui-ci). C'est plutôt à Allah le commandement tout entier. Les croyants ne savent-ils pas que, si Allah voulait, Il aurait dirigé tous les hommes vers le droit chemin. Cependant, ceux qui ne croient pas ne manqueront pas, pour prix de ce qu'ils font, d'être frappés par un cataclysme, ou [qu'un cataclysme] s'abattra près de leurs demeures jusqu'à ce que vienne la promesse d'Allah. Car Allah, ne manque pas à Sa promesse.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mdccxxxix{On s'est certes moqué des messagers avant toi. Alors, J'ai donné un répit aux mécréants. Ensuite, Je les ai saisis. Et quel fut Mon châtiment!\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mdccxl{Est-ce que Celui qui observe ce que chaque âme acquiert [est semblable aux associés?...] Et pourtant ils donnent des associés à Allah. Dis [leur:] «Nommez-les. Ou essayez-vous de Lui apprendre ce qu'Il ne connaît pas sur la terre? Ou avez-vous été simplement séduits par de faux noms?» En fait, on a embelli aux mécréants leur stratagème et on les a empêchés de prendre le droit chemin. Et quiconque Allah laisse égarer, n'a plus personne pour le guider.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mdccxli{Un châtiment les atteindra dans la vie présente. Le châtiment de l'au-delà sera cependant plus écrasant et ils n'auront nul protecteur contre Allah.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mdccxlii{Tel est le paradis qui a été promis aux pieux: sous lequel coulent les ruisseaux; ses fruits sont perpétuels, ainsi que son ombrage. Voilà la fin de ceux qui pratiquent la piété, tandis que la fin des mécréants sera le Feu.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mdccxliii{Et ceux à qui Nous avons déjà donné le Livre se réjouissent de ce qu'on a fait descendre vers toi. Tandis que certaines factions en rejettent une partie. Dis: «Il m'a seulement été commandé d'adorer Allah et de ne rien Lui associer. C'est à Lui que j'appelle [les gens], Et c'est vers Lui que sera mon retour».\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mdccxliv{Ainsi l'avons-Nous fait descendre (le Coran) [sous forme] de loi en arabe. Et si tu suis leurs passions après ce que tu as reçu comme savoir, il n'y aura pour toi, contre Allah, ni allié ni protecteur.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mdccxlv{Et Nous avons certes envoyé avant toi des messagers, et leur avons donné des épouses et des descendants. Et il n'appartient pas à un Messager d'apporter un miracle, si ce n'est qu'avec la permission d'Allah. Chaque échéance a son terme prescrit.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mdccxlvi{Allah efface ou confirme ce qu'Il veut et l'Ecriture primordiale est auprès de Lui.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mdccxlvii{Que Nous te fassions voir une partie de ce dont Nous les menaçons, ou que Nous te fassions mourir (avant cela), ton devoir est seulement la communication du message, et le règlement de compte sera à Nous.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mdccxlviii{Ne voient-ils pas que Nous frappons la terre et que Nous la réduisons de tous côtés? C'est Allah qui juge et personne ne peut s'opposer à Son jugement, et Il est prompt à régler les comptes.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mdccxlix{Certes ceux d'avant eux ont manigancé (contre leur Messager); le stratagème tout entier appartient à Allah. Il sait ce que chaque âme acquiert. Et les mécréants sauront bientôt à qui appartient la bonne demeure finale.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mdccl{Et ceux qui ne croient pas disent: «Tu n'es pas un Messager». Dis: «Allah suffit, comme témoin entre vous et moi, et ceux qui ont la connaissance du Livre (sont aussi témoins)».\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mdccli{\basmalahfr Alif, Lâm, Râ. (Voici) un livre que nous avons fait descendre sur toi, afin que - par la permission de leur Seigneur - tu fasses sortir les gens des ténèbres vers la lumière, sur la voie du Tout Puissant, du Digne de louange.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mdcclii{Allah, à qui appartient tout ce qui est dans les cieux et sur la terre. Et malheur aux mécréants, pour un dur châtiment [qu'ils subiront].\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mdccliii{Ceux qui préfèrent la vie d'ici-bas à l'au-delà, obstruent [aux gens] le chemin d'Allah et cherchent à le rendre tortueux, ceux-là sont loin dans l'égarement.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mdccliv{Et Nous n'avons envoyé de Messager qu'avec la langue de son peuple, afin de les éclairer. Allah égare qui Il veut et guide qui Il veut. Et, c'est Lui le Tout Puissant, le Sage.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mdcclv{Nous avons certes, envoyé Moïse avec Nos miracles [en lui disant]: «Fais sortir ton peuple des ténèbres vers la lumière, et rappelle-leur les jours d'Allah». [Ses bienfaits]. Dans tout cela il y a des signes pour tout homme plein d'endurance et de reconnaissance.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mdcclvi{(Rappelle-toi) quand Moïse dit à son peuple: «Rappelez-vous le bienfait d'Allah sur vous quand Il vous sauva des gens de Pharaon qui vous infligeaient le pire châtiment. Ils massacraient vos fils et laissaient en vie vos filles. Il y avait là une dure épreuve de la part de votre Seigneur»,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mdcclvii{Et lorsque votre Seigneur proclama: «Si vous êtes reconnaissants, très certainement J'augmenterai [Mes bienfaits] pour vous. Mais si vous êtes ingrats, Mon châtiment sera terrible».\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mdcclviii{Et Moïse dit: «Si vous êtes ingrats, vous ainsi que tous ceux qui sont sur terre, [sachez] qu'Allah Se suffit à Lui-même et qu'Il est digne de louange.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mdcclix{Ne vous est-il pas parvenu le récit de ceux d'avant vous, du peuple de Noé, des `Aad, des Thamud et de ceux qui vécurent après eux, et que seul Allah connaît? Leurs messagers vinrent à eux avec des preuves, mais ils dirent, ramenant leurs mains à leurs bouches: «Nous ne croyons pas [au message] avec lequel vous avez été envoyés et nous sommes, au sujet de ce à quoi vous nous appelez, dans un doute vraiment troublant».\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mdcclx{Leurs messagers dirent: «Y a-t-il un doute au sujet d'Allah, Créateur des cieux et de la terre, qui vous appelle pour vous pardonner une partie de vos péchés et vous donner un délai jusqu'à un terme fixé?» [Les mécréants] répondirent: «Vous n'êtes que des hommes comme nous. Vous voulez nous empêcher de ce que nos ancêtres adoraient. Apportez-nous donc une preuve évidente».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mdcclxi{Leurs messagers leur dirent: «Certes, nous ne sommes que des humains comme vous. Mais Allah favorise qui Il veut parmi Ses serviteurs. Il ne nous appartient de vous apporter quelque preuve, que par la permission d'Allah. Et c'est en Allah que les croyants doivent placer leur confiance.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mdcclxii{Et qu'aurions-nous à ne pas placer notre confiance en Allah, alors qu'Il nous a guidés sur les sentiers [que nous devions suivre]? Nous endurerons sûrement la persécution que vous nous infligez. Et ceux qui ont confiance en Allah s'en remettent entièrement à Lui.»\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mdcclxiii{Et ceux qui ont mécru dirent à leurs messagers: «Nous vous expulserons certainement de notre territoire, à moins que vous ne réintégriez notre religion!» Alors, leur Seigneur leur révéla: «Assurément Nous anéantirons les injustes,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mdcclxiv{et vous établirons dans le pays après eux. Cela est pour celui qui craint Ma présence et craint Ma menace».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mdcclxv{Et ils demandèrent [à Allah] la victoire. Et tout tyran insolent fut déçu.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mdcclxvi{L'Enfer est sa destination et il sera abreuvé d'une eau purulente\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mdcclxvii{qu'il tentera d'avaler à petites gorgées. Mais c'est à peine s'il peut l'avaler. La mort lui viendra de toutes parts, mais il ne mourra pas; et il aura un châtiment terrible.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mdcclxviii{Les œuvres de ceux qui ont mécru en leur Seigneur sont comparables à de la cendre violemment frappée par le vent, dans un jour de tempête. Ils ne tireront aucun profit de ce qu'ils ont acquis. C'est cela l'égarement profond.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mdcclxix{Ne vois-tu pas qu'Allah a créé les cieux et la terre pour une juste raison? S'Il voulait, Il vous ferait disparaître et ferait venir de nouvelles créatures,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mdcclxx{et cela n'est nullement difficile pour Allah.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mdcclxxi{Et tous comparaîtront devant Allah. Puis, les faibles diront à ceux qui s'enflaient d'orgueil: «Nous étions bien vos suiveurs. Pouvez-vous nous être de quelque utilité contre le châtiment d'Allah?» - Alors, les autres diront: «Si Allah nous avait guidés nous vous aurions certainement guidés. Il est indifférent pour nous de nous plaindre ou d'endurer; nous n'avons pas d'échappatoire».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mdcclxxii{Et quand tout sera accompli, le Diable dira: «Certes, Allah vous avait fait une promesse de vérité; tandis que moi, je vous ai fait une promesse que je n'ai pas tenue. Je n'avais aucune autorité sur vous si ce n'est que je vous ai appelés, et que vous m'avez répondu. Ne me faites donc pas de reproches; mais faites-en à vous-mêmes. Je ne vous suis d'aucun secours et vous ne m'êtes d'aucun secours. Je vous renie de m'avoir jadis associé [à Allah]». Certes, un châtiment douloureux attend les injustes [les associateurs].\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mdcclxxiii{Et on fera entrer ceux qui croient et font de bonnes œuvres, dans les jardins sous lesquels coulent les ruisseaux, pour y demeurer éternellement, par permission de leur Seigneur. Et là, leur salutation sera: «Salâm» (Paix).\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mdcclxxiv{N'as-tu pas vu comment Allah propose en parabole une bonne parole pareille à un bel arbre dont la racine est ferme et la ramure s'élançant dans le ciel?\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mdcclxxv{Il donne à tout instant ses fruits, par la grâce de son Seigneur. Allah propose des paraboles à l'intention des gens afin qu'ils s'exhortent.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mdcclxxvi{Et une mauvaise parole est pareille à un mauvais arbre, déraciné de la surface de la terre et qui n'a point de stabilité.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mdcclxxvii{Allah affermit les croyants par une parole ferme, dans la vie présente et dans l'au-delà. Tandis qu'Il égare les injustes. Et Allah fait ce qu'Il veut.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mdcclxxviii{Ne vois-tu point ceux qui troquent les bienfaits d'Allah contre l'ingratitude et établissent leur peuple dans la demeure de la perdition\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mdcclxxix{...l'Enfer, où ils brûleront? Et quel mauvais gîte!\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mdcclxxx{Et ils ont donné à Allah des égaux afin d'égarer (les gens) de Son sentier. - Dis: «Jouissez [de cette vie] car votre destination sera le feu».\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mdcclxxxi{Dis à Mes serviteurs qui ont cru, qu'ils accomplissent la Salât et qu'ils dépensent [dans le bien] en secret et en public de ce que Nous leur avons attribué, avant que vienne le jour où il n'y a ni rachat ni amitié.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mdcclxxxii{Allah, c'est Lui qui a crée les cieux et la terre et qui, du ciel, a fait descendre l'eau; grâce à laquelle Il a produit des fruits pour vous nourrir. Il a soumis à votre service les vaisseaux qui, par Son ordre, voguent sur la mer. Et Il a soumis à votre service les rivières.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mdcclxxxiii{Et pour vous, Il a assujetti le soleil et la lune à une perpétuelle révolution. Et Il vous a assujetti la nuit et le jour.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mdcclxxxiv{Il vous a accordé de tout ce que vous Lui avez demandé. Et si vous comptiez les bienfaits d'Allah, vous ne sauriez les dénombrer. L'homme est vraiment très injuste, très ingrat.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mdcclxxxv{Et (rappelle-toi) quand Abraham dit: «O mon Seigneur, fais de cette cité un lieu sûr, et préserve-moi ainsi que mes enfants de l'adoration des idoles.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mdcclxxxvi{O mon Seigneur, elles (les idoles) ont égaré beaucoup de gens. Quiconque me suit est des miens. Quant à celui qui me désobéit... c'est Toi, le Pardonneur, le Très Miséricordieux!\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mdcclxxxvii{O notre Seigneur, j'ai établi une partie de ma descendance dans une vallée sans agriculture, près de Ta Maison sacrée [la Ka'ba], - ô notre Seigneur - afin qu'ils accomplissent la Salât. Fais donc que se penchent vers eux les cœurs d'une partie des gens. Et nourris-les de fruits. Peut-être seront-ils reconnaissants?\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mdcclxxxviii{O notre Seigneur, Tu sais, vraiment, ce que nous cachons et ce que nous divulguons: - et rien n'échappe à Allah, ni sur terre, ni au ciel! -\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mdcclxxxix{Louange à Allah, qui en dépit de ma vieillesse, m'a donné Ismaël et Isaac. Certes, mon Seigneur entend bien les prières.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mdccxc{O mon Seigneur! Fais que j'accomplisse assidûment la Salât ainsi qu'une partie de ma descendance; exauce ma prière, ô notre Seigneur!\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mdccxci{O notre Seigneur! pardonne-moi, ainsi qu'à mes père et mère et aux croyants, le jour de la reddition des comptes».\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mdccxcii{Et ne pense point qu'Allah soit inattentif à ce que font les injustes. Ils leur accordera un délai jusqu'au jour ou leurs regards se figeront.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mdccxciii{Ils courront [suppliant], levant la tête, les yeux hagards et les cœurs vides.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mdccxciv{Et avertis les gens du jour où le châtiment les atteindra et ceux qui auront été injustes diront: «O notre Seigneur accorde-nous un court délai, nous répondrons à Ton appel et suivrons les messagers». - N'avez-vous pas juré auparavant que vous ne deviez jamais disparaître?\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mdccxcv{Et vous avez habité, les demeures de ceux qui s'étaient fait du tort à eux-mêmes. Il vous est apparu en toute évidence comment Nous les avions traité et Nous vous avons cité les exemples.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mdccxcvi{Ils ont certes comploté. Or leur complot est (inscrit) auprès d'Allah même si leur complot était assez puissant pour faire disparaître les montagnes...\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mdccxcvii{Ne pense point qu'Allah manque à Sa promesse envers Ses messagers. Certes Allah est Tout Puissant et Détenteur du pouvoir de punir,\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mdccxcviii{au jour où la terre sera remplacée par une autre, de même que les cieux et où (les hommes) comparaîtront devant Allah, l'Unique, le Dominateur Suprême.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mdccxcix{Et ce jour-là, tu verras les coupables, enchaînés les uns aux autres,\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mdccc{leurs tuniques seront de goudron et le feu couvrira leurs visages.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mdccci{(Tout cela) afin qu'Allah rétribue chaque âme de ce qu'elle aura acquis. Certes Allah est prompt dans Ses comptes.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mdcccii{Ceci est un message (le Coran) pour les gens afin qu'ils soient avertis, qu'ils sachent qu'Il n'est qu'un Dieu unique, et pour que les doués d'intelligence s'exhortent.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mdccciii{\basmalahfr Alif, Lâm, Râ. Voici les versets du Livre et d'une Lecture explicite.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mdccciv{[Le Jour du Jugement Dernier] les mécréants voudraient avoir été Musulmans [soumis].\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mdcccv{Laisse-les manger, jouir (un temps), et être distraits par l'espoir; car bientôt ils sauront!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mdcccvi{Or Nous ne détruisons aucune cité sans qu'elle n'ait eu [un terme fixé en] une Ecriture connue.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mdcccvii{Nulle communauté ne devance son terme, ni ne le retarde.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mdcccviii{Et ils (les mecquois) disent: «O toi sur qui on a fait descendre le Coran, tu es certainement fou!\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mdcccix{Pourquoi ne nous es-tu pas venu avec les Anges, si tu es du nombre des véridiques?»\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mdcccx{Nous ne faisons descendre les Anges qu'avec la vérité; et alors, il ne leur sera pas accordé de répit [à ces impies].\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mdcccxi{En vérité c'est Nous qui avons fait descendre le Coran, et c'est Nous qui en sommes gardien.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mdcccxii{Et nous avons certes envoyé, avant toi, [des Messagers] parmi les peuples des Anciens.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mdcccxiii{Et pas un Messager ne leur est venu sans qu'ils s'en soient moqués.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mdcccxiv{C'est ainsi que Nous faisons pénétrer (la mécréance) dans les cœurs des coupables.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mdcccxv{Ils ne croiront pas en lui [le Messager ou le Coran] bien que se soit accompli le sort traditionnel des anciens.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mdcccxvi{Et même si Nous ouvrions pour eux une porte du ciel, et qu'ils pussent y monter,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mdcccxvii{ils diraient: «Vraiment nos yeux sont voilés. Mais plutôt, nous sommes des gens ensorcelés».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mdcccxviii{Certes Nous avons placé dans le ciel des constellations et Nous l'avons embelli pour ceux qui regardent.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mdcccxix{Et Nous l'avons protégé contre tout diable banni.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mdcccxx{A moins que l'un d'eux parvienne subrepticement à écouter, une flamme brillante alors le poursuit.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mdcccxxi{Et quant à la terre, Nous l'avons étalée et y avons placé des montagnes (immobiles) et y avons fait pousser toute chose harmonieusement proportionnée.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mdcccxxii{Et Nous y avons placé des vivres pour vous, et (placé aussi pour vous) des êtres que vous ne nourrissez pas.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mdcccxxiii{Et il n'est rien dont Nous n'ayons les réserves et Nous ne le faisons descendre que dans une mesure déterminée.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mdcccxxiv{Et Nous envoyons les vents fécondants; et Nous faisons alors descendre du ciel une eau dont Nous vous abreuvons et que vous n'êtes pas en mesure de conserver.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mdcccxxv{Et c'est bien Nous qui donnons la vie et donnons la mort, et c'est Nous qui sommes l'héritier [de tout].\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mdcccxxvi{Et Nous connaissons certes ceux qui parmi vous ont avancé et Nous connaissons ceux qui tardent encore.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mdcccxxvii{Certes, c'est ton Seigneur qui les rassemblera. Car c'est Lui le Sage, l'Omniscient.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mdcccxxviii{Nous créâmes l'homme d'une argile crissante, extraite d'une boue malléable.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mdcccxxix{Et quant au djinn, Nous l'avions auparavant créé d'un feu d'une chaleur ardente.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mdcccxxx{Et lorsque ton Seigneur dit aux Anges: «Je vais créer un homme d'argile crissante, extraite d'une boue malléable,\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mdcccxxxi{et dès que Je l'aurai harmonieusement formé et lui aurai insufflé Mon souffle de vie, jetez-vous alors, prosternés devant lui».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mdcccxxxii{Alors, les Anges se prosternèrent tous ensemble,\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mdcccxxxiii{excepté Iblis qui refusa d'être avec les prosternés.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mdcccxxxiv{Alors [Allah] dit: «O Iblis, pourquoi n'es-tu pas au nombre des prosternés?»\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mdcccxxxv{Il dit: «Je ne puis me prosterner devant un homme que Tu as créé d'argile crissante, extraite d'une boue malléable».\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mdcccxxxvi{- Et [Allah] dit: «Sors de là [du Paradis], car te voilà banni!\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mdcccxxxvii{Et malédiction sur toi, jusqu'au Jour de la rétribution!»\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mdcccxxxviii{- Il dit: «O mon Seigneur, donne-moi donc un délai jusqu'au jour où ils (les gens) seront ressuscités».\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mdcccxxxix{[Allah] dit: «tu es de ceux à qui ce délai est accordé,\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mdcccxl{jusqu'au jour de l'instant connu» [d'Allah].\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mdcccxli{- Il dit: «O mon Seigneur, parce que Tu m'as induit en erreur, eh bien je leur enjoliverai la vie sur terre et les égarerai tous,\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mdcccxlii{à l'exception, parmi eux, de Tes serviteurs élus.»\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mdcccxliii{- «[Allah] dit: voici une voie droite [qui mène] vers Moi.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mdcccxliv{Sur Mes serviteurs tu n'auras aucune autorité, excepté sur celui qui te suivra parmi les dévoyés.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mdcccxlv{Et l'Enfer sera sûrement leur lieu de rendez-vous à tous.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mdcccxlvi{Il a sept portes; et chaque porte en a sa part déterminée».\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mdcccxlvii{Certes, les pieux seront dans des jardins avec des sources.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mdcccxlviii{«Entrez-y en paix et en sécurité».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mdcccxlix{Et Nous aurons arraché toute rancune de leurs poitrines: et ils se sentiront frères, faisant face les uns aux autres sur des lits.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mdcccl{Nulle fatigue ne les y touchera. Et on ne les en fera pas sortir.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mdcccli{Informe Mes serviteurs que c'est Moi le Pardonneur, le Très Miséricordieux.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mdccclii{et que Mon châtiment est certes le châtiment douloureux.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mdcccliii{Et informe-les au sujet des hôtes d'Abraham\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mdcccliv{Quand ils entrèrent chez lui et dirent: «Salâm» - Il dit: «Nous avons peur de vous».\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mdccclv{Ils dirent: «N'aie pas peur! Nous t'annonçons une bonne nouvelle, [la naissance] d'un garçon plein de savoir».\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mdccclvi{Il dit: «M'annoncez-vous [cette nouvelle] alors que la vieillesse m'a touché? Que m'annoncez-vous donc?»\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mdccclvii{- Ils dirent: «Nous t'annonçons la vérité. Ne sois donc pas de ceux qui désespèrent».\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mdccclviii{- Il dit: «Et qui désespère de la miséricorde de son Seigneur, sinon les égarés?»\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mdccclix{Et il [leur] dit: «Que voulez-vous, ô envoyés d'Allah?»\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mdccclx{- Ils dirent: «En vérité, nous sommes envoyés à des gens criminels,\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mdccclxi{à l'exception de la famille de Lot que nous sauverons tous\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mdccclxii{sauf sa femme.«Nous (Allah) avions déterminé qu'elle sera du nombre des exterminés.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mdccclxiii{Puis lorsque les envoyés vinrent auprès de la famille de Lot\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mdccclxiv{celui-ci dit: «Vous êtes [pour moi] des gens inconnus».\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mdccclxv{- Ils dirent: «Nous sommes plutôt venus à toi en apportant (le châtiment) à propos duquel ils doutaient.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mdccclxvi{Et nous venons à toi avec la vérité. Et nous sommes véridiques.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mdccclxvii{Pars donc avec ta famille en parie de nuit et suis leurs arrières; et que nul d'entre vous ne se retourne. Et allez là où on vous le commande».\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mdccclxviii{Et Nous lui annonçâmes cet ordre: que ces gens-là, au matin, seront anéantis jusqu'au dernier.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mdccclxix{Et les habitants de la ville (Sodome) vinrent [à lui] dans la joie.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mdccclxx{- Il dit: «Ceux-ci sont mes hôtes, ne me déshonorez donc pas.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mdccclxxi{Et craignez Allah. Et ne me couvrez pas d'ignominie.»\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mdccclxxii{Ils dirent: «Ne t'avions-nous pas interdit de [recevoir] du monde?»\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mdccclxxiii{Il dit: «Voici mes filles, si vous voulez faire [quelque chose]!»\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mdccclxxiv{Par ta vie! ils se confondaient dans leur délire.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mdccclxxv{Alors, au lever du soleil le Cri (la catastrophe) les saisit.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mdccclxxvi{Et Nous renversâmes [la ville] de fond en comble et fîmes pleuvoir sur eux des pierres d'argile dure.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mdccclxxvii{Voilà vraiment des preuves, pour ceux qui savent observer!\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mdccclxxviii{Elle [cette ville] se trouvait sur un chemin connu de tous.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mdccclxxix{Voilà vraiment une exhortation pour les croyants!\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mdccclxxx{Et les habitants d'al-Aïka étaient [aussi] des injustes.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mdccclxxxi{Nous Nous sommes donc vengés d'eux. Et ces deux [cités], vraiment, sont sur une route bien évidente [que vous connaissez].\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mdccclxxxii{Certes, les gens d'al-Hijr ont traité de menteurs les messagers.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mdccclxxxiii{Nous leur avons montré Nos miracles, mais ils s'en étaient détournés.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mdccclxxxiv{Et ils taillaient des maisons dans les montagnes, vivant en sécurité.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mdccclxxxv{Puis, au matin, le Cri les saisit.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mdccclxxxvi{Ce qu'ils avaient acquis ne leur a donc point profité.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mdccclxxxvii{Et Nous n'avons créé les cieux et la terre, et ce qui est entre eux, que pour une juste raison. Et l'Heure [sans aucun doute] arrivera! Pardonne-[leur] donc d'un beau pardon.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mdccclxxxviii{Ton Seigneur, c'est Lui vraiment le grand Créateur, l'Omniscient.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mdccclxxxix{Nous t'avons certes donné «les sept versets que l'on répète», ainsi que le Coran sublime.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mdcccxc{Ne regarde surtout pas avec envie les choses dont Nous avons donné jouissance temporaire à certains couples d'entre eux, ne t'afflige pas à leur sujet et abaisse ton aile pour les croyants.\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mdcccxci{Et dis: «Je suis l'avertisseur évident» (d'un châtiment),\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mdcccxcii{De même que Nous avons fait descendre [le châtiment] sur ceux qui ont juré (entre eux),\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mdcccxciii{ceux qui ont fait du Coran des fractions diverses, (pour créer des doutes).\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mdcccxciv{Par ton Seigneur! Nous les interrogerons tous\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mdcccxcv{sur ce qu'ils œuvraient.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mdcccxcvi{Expose donc clairement ce qu'on t'a commandé et détourne-toi des associateurs.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mdcccxcvii{Nous t'avons effectivement défendu vis-à-vis des railleurs.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mdcccxcviii{Ceux qui associent à Allah une autre divinité. Mais ils sauront bientôt.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mdcccxcix{Et Nous savons certes que ta poitrine se serre, à cause de ce qu'ils disent.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mcm{Glorifie donc Ton Seigneur par Sa louange et sois de ceux qui se prosternent;\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mcmi{et adore ton Seigneur jusqu'à ce que te vienne la certitude (la mort).\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mcmii{\basmalahfr L'ordre d'Allah arrive. Ne le hâtez donc pas. Gloire à Lui! Il est au-dessus de ce qu'on Lui associe.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mcmiii{Il fait descendre, par Son ordre, les Anges, avec la révélation sur qui Il veut parmi Ses serviteurs: «Avertissez qu'il n'est d'autre divinité que Moi. Craignez-Moi donc».\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mcmiv{Il a créé les cieux et la terre avec juste raison. Il transcende ce qu'on [Lui] associe.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mcmv{Il a créé l'homme d'une goutte de sperme; et voilà que l'homme devient un disputeur déclaré.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mcmvi{Et les bestiaux, Il les a créés pour vous; vous en retirez des [vêtements] chauds ainsi que d'autres profits. Et vous en mangez aussi.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mcmvii{Ils vous paraissent beaux quand vous les ramenez, le soir, et aussi le matin quand vous les lâchez pour le pâturage.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mcmviii{Et ils portent vos fardeaux vers un pays que vous n'atteindriez qu'avec peine. Vraiment, votre Seigneur est Compatissant et Miséricordieux.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mcmix{Et les chevaux, les mulets et les ânes, pour que vous les montiez, et pour l'apparat. Et Il crée ce que vous ne savez pas.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mcmx{Il appartient à Allah [par Sa grâce, de montrer] le droit chemin car il en est qui s'en détachent. Or, s'Il voulait, Il vous guiderait tous.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mcmxi{C'est Lui qui, du ciel, a fait descendre de l'eau qui vous sert de boisson et grâce à laquelle poussent des plantes dont vous nourrissez vos troupeaux.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mcmxii{D'elle, Il fait pousser pour vous, les cultures, les oliviers, les palmiers, les vignes et aussi toutes sortes de fruits. Voilà bien là une preuve pour des gens qui réfléchissent.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mcmxiii{Pour vous, Il a assujetti la nuit et le jour; le soleil et la lune. Et à Son ordre sont assujetties les étoiles. Voilà bien là des preuves pour des gens qui raisonnent.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mcmxiv{Ce qu'Il a créé pour vous sur la terre a des couleurs diverses. Voilà bien là une preuve pour des gens qui se rappellent.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mcmxv{Et c'est Lui qui a assujetti la mer afin que vous en mangiez une chair fraîche, et que vous en retiriez des parures que vous portez. Et tu vois les bateaux fendre la mer avec bruit, pour que vous partiez en quête de Sa grâce et afin que vous soyez reconnaissants.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mcmxvi{Et Il a implanté des montagnes immobiles dans la terre afin qu'elle ne branle pas en vous emportant avec elle de même que des rivières et des sentiers, pour que vous vous guidiez,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mcmxvii{ainsi que des points de repère. Et au moyen des étoiles [les gens] se guident.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mcmxviii{Celui qui crée est-il semblable à celui qui ne crée rien? Ne vous souvenez-vous pas?\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mcmxix{Et si vous comptez les bienfaits d'Allah, vous ne saurez pas les dénombrer. Car Allah est Pardonneur, et Miséricordieux.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mcmxx{Et Allah sait ce que vous cachez et ce que vous divulguez.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mcmxxi{Et ceux qu'ils invoquent en dehors d'Allah ne créent rien, et ils sont eux-mêmes créés.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mcmxxii{Ils sont morts, et non pas vivants, et ils ne savent pas quand ils seront ressuscités.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mcmxxiii{Votre Dieu est un Dieu unique. Ceux qui ne croient pas en l'au-delà leurs cœurs nient (l'unicité d'Allah) et ils sont remplis d'orgueil.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mcmxxiv{Nul doute qu'Allah sait ce qu'ils cachent et ce qu'ils divulguent. Et assurément Il n'aime pas les orgueilleux.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mcmxxv{Et lorsqu'on leur dit: «Qu'est-ce que votre Seigneur a fait descendre?» Ils disent: «Des légendes anciennes!»\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mcmxxvi{Qu'ils portent donc, au Jour de la Résurrection, tous les fardeaux de leurs propres œuvres ainsi qu'une partie des fardeaux de ceux qu'ils égarent, sans le savoir; combien est mauvais [le fardeau] qu'ils portent!\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mcmxxvii{Ceux qui ont vécu avant eux, certes, ont comploté, mais Allah attaqua les bases mêmes de leur bâtisse. Le toit s'écroula au-dessus d'eux et le châtiment les surprit d'où ils ne l'avaient pas pressenti.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mcmxxviii{Puis, le Jour de la Résurrection, Il les couvrira d'ignominie, et [leur] dira: «Où sont Mes associés pour lesquels vous combattiez?» - Ceux qui ont le savoir diront: «L'ignominie et le malheur tombent aujourd'hui sur les mécréants».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mcmxxix{Ceux à qui les Anges ôtent la vie, alors qu'ils sont injustes envers eux-mêmes, se soumettront humiliés, (et diront): «Nous ne faisions pas de mal!» - «Mais, en fait, Allah sait bien ce que vous faisiez».\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mcmxxx{Entrez donc par les portes de l'Enfer pour y demeurer éternellement. Combien est mauvaise la demeure des orgueilleux!\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mcmxxxi{Et on dira à ceux qui étaient pieux: «Qu'a fait descendre votre Seigneur?» Ils diront: «Un bien». Ceux qui font les bonnes œuvres auront un bien ici-bas; mais la demeure de l'au-delà est certes meilleure. Combien agréable sera la demeure des pieux!\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mcmxxxii{Les jardins du séjour (éternel), où ils entreront et sous lesquels coulent les ruisseaux. Ils auront là ce qu'ils voudront; c'est ainsi qu'Allah récompense les pieux.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mcmxxxiii{Ceux dont les Anges reprennent l'âme - alors qu'ils sont bons - [les Anges leur] disent: «Paix sur vous! Entrez au Paradis, pour ce que vous faisiez».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mcmxxxiv{[Les infidèles] attendent-ils que les Anges leur viennent, ou que survienne l'ordre de ton Seigneur? Ainsi agissaient les gens avant eux. Allah ne les a pas lésés; mais ils faisaient du tort à eux-mêmes.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mcmxxxv{Les méfaits qu'ils accomplissaient les atteindront, et ce dont ils se moquaient les cernera de toutes parts.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mcmxxxvi{Et les associateurs dirent: «Si Allah avait voulu, nous n'aurions pas adoré quoi que ce soit en dehors de Lui, ni nous ni nos ancêtres; et nous n'aurions rien interdit qu'Il n'ait interdit Lui-même». Ainsi agissaient les gens avant eux. N'incombe-t-il aux messagers sinon de transmettre le message en toute clarté?\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mcmxxxvii{Nous avons envoyé dans chaque communauté un Messager, [pour leur dire]: «Adorez Allah et écartez-vous du Tâgût». Alors Allah en guida certains, mais il y en eut qui ont été destinés à l'égarement. Parcourez donc la terre, et regardez quelle fut la fin de ceux qui traitaient [Nos messagers] de menteurs.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mcmxxxviii{Même si tu désirais ardemment qu'ils soient guidés... [Sache] qu'Allah ne guide pas ceux qui s'égarent. Et ils n'auront pas de secoureurs.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mcmxxxix{Et ils jurent par Allah en prononçant leurs serments les plus solennels: «Allah ne ressuscitera pas celui qui meurt». Bien au contraire! C'est une promesse véritable [de Sa part], mais la plupart des gens ne le savent pas.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mcmxl{(Il les ressuscitera) afin qu'Il leur expose clairement ce en quoi ils divergeaient, et pour que ceux qui ont mécru sachent qu'ils ont été des menteurs.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mcmxli{Quand Nous voulons une chose, Notre seule parole est: «Sois». Et, elle est.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mcmxlii{Et ceux qui, pour (la cause d') Allah, ont émigré après avoir subi des injustices, Nous les installerons dans une situation agréable dans la vie d'ici-bas. Et le salaire de la vie dernière sera plus grand encore s'ils savaient.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mcmxliii{Eux qui ont enduré et placé leur confiance en leur Seigneur.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mcmxliv{Nous n'avons envoyé, avant toi, que des hommes auxquels Nous avons fait des révélations. Demandez donc aux gens du rappel si vous ne savez pas.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mcmxlv{(Nous les avons envoyés) avec des preuves évidentes et des livres saints. Et vers toi, Nous avons fait descendre le Coran, pour que tu exposes clairement aux gens ce qu'on a fait descendre pour eux et afin qu'ils réfléchissent.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mcmxlvi{Ceux qui complotaient des méfaits sont-ils à l'abri de ce qu'Allah les engloutisse en terre ou que leur vienne le châtiment d'où ils ne s'attendaient point?\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mcmxlvii{Ou bien qu'Il les saisisse en pleine activité sans qu'ils puissent échapper (au châtiment d'Allah).\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mcmxlviii{Ou bien qu'Il les saisisse en plein effroi? Mais vraiment, votre Seigneur est Compatissant et Miséricordieux.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mcmxlix{N'ont-ils point vu que les ombres de toute chose qu'Allah a créée s'allongent à droite et à gauche, en se prosternant devant Allah, en toute humilité?\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mcml{Et c'est devant Allah que se prosterne tout être vivant dans les cieux, et sur la terre; ainsi que les Anges qui ne s'enflent pas d'orgueil.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mcmli{Ils craignent leur Seigneur, au-dessus d'eux, et font ce qui leur est commandé.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mcmlii{Allah dit: «Ne prenez pas deux divinités. Il n'est qu'un Dieu unique. Donc, ne craignez que Moi».\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mcmliii{C'est à Lui qu'appartient ce qui est dans les cieux et sur la terre; c'est à Lui que l'obéissance perpétuelle est due. Craindriez-vous donc, d'autres qu'Allah?\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mcmliv{Et tout ce que vous avez comme bienfait provient d'Allah. Puis quand le malheur vous touche, c'est Lui que vous implorez à haute voix.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mcmlv{Et une fois qu'Il a dissipé votre malheur, voilà qu'une partie d'entre vous se mettent à donner des associés à leur Seigneur,\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mcmlvi{méconnaissant ainsi ce que Nous leur avons donné. Jouissez donc [pour un temps!] Bientôt vous saurez!\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mcmlvii{Et ils assignent une partie [des biens] que Nous leur avons attribués à [des idoles] qu'ils ne connaissent pas. Par Allah! Vous serez certes interrogés sur ce que vous inventiez.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mcmlviii{Et ils assignent à Allah des filles. Gloire et pureté à Lui! Et à eux-mêmes, cependant, (ils assignent) ce qu'ils désirent (des fils).\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mcmlix{Et lorsqu'on annonce à l'un d'eux une fille, son visage s'assombrit et une rage profonde [l'envahit].\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mcmlx{Il se cache des gens, à cause du malheur qu'on lui a annoncé. Doit-il la garder malgré la honte ou l'enfouira-t-il dans la terre? Combien est mauvais leur jugement!\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mcmlxi{C'est à ceux qui ne croient pas en l'au-delà que revient le mauvais qualificatif (qu'ils ont attribué à Allah). Tandis qu'à Allah [Seul] est le qualificatif suprême. Et c'est Lui le Tout Puissant, le Sage.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mcmlxii{Si Allah s'en prenait aux gens pour leurs méfaits, Il ne laisserait sur cette terre aucun être vivant. Mais Il les renvoie jusqu'à un terme fixé. Puis, quand leur terme vient, ils ne peuvent ni le retarder d'une heure ni l'avancer.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mcmlxiii{Et ils assignent à Allah ce qu'ils détestent [pour eux-mêmes]. Et leurs langues profèrent un mensonge quand ils disent que la plus belle récompense leur sera réservée. C'est le Feu, sans nul doute, qui leur sera réservé et ils y seront envoyés, les premiers.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mcmlxiv{Par Allah! Nous avons effectivement envoyé (des messagers) à des communautés avant toi. Mais le Diable leur enjoliva ce qu'ils faisaient. C'est lui qui est, leur allié, aujourd'hui [dans ce monde]. Et ils auront un châtiment douloureux [dans l'au-delà].\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mcmlxv{Et Nous n'avons fait descendre sur toi le Livre qu'afin que tu leur montres clairement le motif de leur dissension, de même qu'un guide et une miséricorde pour des gens croyants.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mcmlxvi{Allah a fait descendre du ciel une eau avec laquelle Il revivifie la terre après sa mort. Il y a vraiment là une preuve pour des gens qui entendent.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mcmlxvii{Il y a certes un enseignement pour vous dans les bestiaux: Nous vous abreuvons de ce qui est dans leurs ventres, - [un produit] extrait du [mélange] des excréments [intestinaux] et du sang - un lait pur, délicieux pour les buveurs.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mcmlxviii{Des fruits des palmiers et des vignes, vous retirez une boisson enivrante et un aliment excellent. Il y a vraiment là un signe pour des gens qui raisonnent.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mcmlxix{[Et voilà] ce que ton Seigneur révéla aux abeilles: «Prenez des demeures dans les montagnes, les arbres, et les treillages que [les hommes] font.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mcmlxx{Puis mangez de toute espèce de fruits, et suivez les sentiers de votre Seigneur, rendus faciles pour vous. De leur ventre, sort une liqueur, aux couleurs variées, dans laquelle il y a une guérison pour les gens. Il y a vraiment là une preuve pour des gens qui réfléchissent.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mcmlxxi{Allah vous a créés! Puis Il vous fera mourir. Tel parmi vous sera reconduit jusqu'à l'âge le plus vil, de sorte qu'après avoir su, il arrive à ne plus rien savoir. Allah est, certes, Omniscient et Omnipotent.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mcmlxxii{Allah a favorisé les uns d'entre vous par rapport aux autres dans [la répartition] de Ses dons. Ceux qui ont été favorisés ne sont nullement disposés à donner leur portion à ceux qu'ils possèdent de plein droit [esclaves] au point qu'ils y deviennent associés à part égale. Nieront-ils les bienfaits d'Allah?\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mcmlxxiii{Allah vous a fait à partir de vous-mêmes des épouses, et de vos épouses Il vous a donné des enfants et des petits-enfants. Et Il vous a attribué de bonnes choses. Croient-ils donc au faux et nient-ils le bienfait d'Allah?\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mcmlxxiv{Et ils adorent, en dehors d'Allah, ce qui ne peut leur procurer aucune nourriture des cieux et de la terre et qui n'est capable de rien.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mcmlxxv{N'attribuez donc pas à Allah des semblables. Car Allah sait, tandis que vous ne savez pas.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mcmlxxvi{Allah propose en parabole un esclave appartenant [à son maître], dépourvu de tout pouvoir, et un homme à qui Nous avons accordé de Notre part une bonne attribution dont il dépense en secret et en public. [Ces deux hommes] sont-ils égaux? Louange à Allah! Mais la plupart d'entre eux ne savent pas.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mcmlxxvii{Et Allah propose en parabole deux hommes: l'un d'eux est muet, dépourvu de tout pouvoir et totalement à la charge de son maître; Quelque lieu où celui-ci l'envoie, il ne rapporte rien de bon; serait-il l'égal de celui qui ordonne la justice et qui est sur le droit chemin?\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mcmlxxviii{C'est à Allah qu'appartient l'inconnaissable des cieux et de la terre. Et l'ordre [concernant] l'Heure ne sera que comme un clin d'œil ou plus bref encore! Car Allah est, certes, Omnipotent.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mcmlxxix{Et Allah vous a fait sortir des ventres de vos mères, dénués de tout savoir, et vous a donné l'ouïe, les yeux et les cœurs (l'intelligence), afin que vous; soyez reconnaissants.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mcmlxxx{N'ont-ils pas vu les oiseaux assujettis [au vol] dans l'atmosphère du ciel sans que rien ne les retienne en dehors d'Allah? Il y a vraiment là des preuves pour des gens qui croient.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mcmlxxxi{Et Allah vous a fait de vos maisons une habitation, tout comme Il vous a procuré des maisons faites de peaux de bêtes que vous trouvez légères, le jour où vous vous déplacez et le jour où vous vous campez. De leur laine, de leur poil et de leur crin (Il vous a procuré) des effets et des objets dont vous jouissez pour un certain délai.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mcmlxxxii{Et de ce qu'Il a créé, Allah vous a procuré des ombres. Et Il vous a procuré des abris dans les montagnes. Et Il vous a procuré des vêtements qui vous protègent de la chaleur, ainsi que des vêtements [cuirasses, armures] qui vous protègent de votre propre violence. C'est ainsi qu'Allah parachève sur vous Son bienfait, peut-être que vous vous soumettez.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mcmlxxxiii{S'ils se détournent... il ne t'incombe que la communication claire.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mcmlxxxiv{Ils reconnaissent le bienfait d'Allah; puis, ils le renient. Et la plupart d'entre eux sont des ingrats.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mcmlxxxv{(Et rappelle-toi) le jour où de chaque communauté Nous susciterons un témoin, on ne permettra pas aux infidèles (de s'excuser), et on ne leur demandera pas de revenir [sur ce qui a provoqué la colère d'Allah].\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mcmlxxxvi{Et quand les injustes verront le châtiment, on ne leur accordera ni allégement ni répit.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mcmlxxxvii{Quand les associateurs verront ceux qu'ils associaient à Allah, ils diront: «O notre Seigneur, voilà nos divinités que nous invoquions en dehors de Toi». Mais [leurs associés] leur adresseront la parole: «Vous êtes assurément des menteurs».\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mcmlxxxviii{Ils offriront ce jour-là à Allah la soumission, et ce qu'ils avaient inventé sera perdu pour eux.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mcmlxxxix{Ceux qui ne croyaient pas et obstruaient le sentier d'Allah, Nous leur ajouterons châtiment sur châtiment, pour la corruption qu'ils semaient (sur terre).\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mcmxc{Et le jour où dans chaque communauté, Nous susciterons parmi eux-mêmes un témoin contre eux, Et Nous t'emmenerons [Muhammad] comme témoin contre ceux-ci. Et Nous avons fait descendre sur toi le Livre, comme un exposé explicite de toute chose, ainsi qu'un guide, une grâce et une bonne annonce aux Musulmans.\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mcmxci{Certes, Allah commande l'équité, la bienfaisance et l'assistance aux proches. Et Il interdit la turpitude, l'acte répréhensible et la rébellion. Il vous exhorte afin que vous vous souveniez.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mcmxcii{Soyez fidèles au pacte d'Allah après l'avoir contracté et ne violez pas vos serments après les avoir solennellement prêtés et avoir pris Allah comme garant [de votre bonne foi]. Vraiment Allah sait ce que vous faites!\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mcmxciii{Et ne faites pas comme celle qui défaisait brin par brin sa quenouille après l'avoir solidement filée, en prenant vos serments comme un moyen pour vous tromper les uns les autres, du fait que (vous avez trouvé) une communauté plus forte et plus nombreuse que l'autre. Allah ne fait, par là, que vous éprouver. Et, certes, Il vous montrera clairement, au Jour de la Résurrection ce sur quoi vous vous opposiez.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mcmxciv{Si Allah avait voulu, Il aurait certes fait de vous une seule communauté. Mais Il laisse s'égarer qui Il veut et guide qui Il veut. Et vous serez certes, interrogés sur ce que vous faisiez.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mcmxcv{Et ne prenez pas vos serments comme un moyen pour vous tromper les uns les autres, sinon [vos] pas glisseront après avoir été fermes, et vous goûterez le malheur pour avoir barré le sentier d'Allah. Et vous subirez un châtiment terrible.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mcmxcvi{Et ne vendez pas à vil prix le pacte d'Allah. Ce qui se trouve auprès d'Allah est meilleur pour vous, si vous saviez!\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mcmxcvii{Tout ce que vous possédez s'épuisera, tandis que ce qui est auprès d'Allah durera. Et Nous récompenserons ceux qui ont été constants en fonction du meilleur de ce qu'ils faisaient.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mcmxcviii{Quiconque, mâle ou femelle, fait une bonne œuvre tout en étant croyant, Nous lui ferons vivre une bonne vie. Et Nous les récompenserons, certes, en fonction des meilleures de leurs actions.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mcmxcix{Lorsque tu lis le Coran, demande la protection d'Allah contre le Diable banni.\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mm{Il n'a aucun pouvoir sur ceux qui croient et qui placent leur confiance en leur Seigneur.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mmi{Il n'a de pouvoir que sur ceux qui le prennent pour allié et qui deviennent associateurs à cause de lui.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mmii{Quand Nous remplaçons un verset par un autre - et Allah sait mieux ce qu'Il fait descendre - ils disent: «Tu n'es qu'un menteur». Mais la plupart d'entre eux ne savent pas.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mmiii{Dis: «C'est le Saint Esprit [Gabriel] qui l'a fait descendre de la part de ton Seigneur en toute vérité, afin de raffermir [la foi] de ceux qui croient, ainsi qu'un guide et une bonne annonce pour les Musulmans.»\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mmiv{Et Nous savons parfaitement qu'ils disent: «Ce n'est qu'un être humain qui lui enseigne (le Coran)». Or, la langue de celui auquel ils font allusion est étrangère [non arabe], et celle-ci est une langue arabe bien claire.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mmv{Ceux qui ne croient pas aux versets d'Allah, Allah ne les guide pas. Et ils ont un châtiment douloureux.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mmvi{Seuls forgent le mensonge ceux qui ne croient pas aux versets d'Allah; et tels sont les menteurs.\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mmvii{Quiconque a renié Allah après avoir cru... - sauf celui qui y a été contraint alors que son cœur demeure plein de la sérénité de la foi - mais ceux qui ouvrent délibérément leur cœur à la mécréance, ceux-là ont sur eux une colère d'Allah et ils ont un châtiment terrible.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mmviii{Il en est ainsi, parce qu'ils ont aimé la vie présente plus que l'au-delà. Et Allah, vraiment, ne guide pas les gens mécréants.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mmix{Voilà ceux dont Allah a scellé les cœurs, l'ouïe, et les yeux. Ce sont eux les insouciants.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mmx{Et nul doute que dans l'au-delà, ils seront les perdants.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mmxi{Quant à ceux qui ont émigré après avoir subi des épreuves, puis ont lutté et ont enduré, ton Seigneur après cela, est certes Pardonneur et Miséricordieux.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mmxii{(Rappelle-toi) le jour où chaque âme viendra, plaidant pour elle-même, et chaque âme sera pleinement rétribuée pour ce qu'elle aura œuvré sans qu'ils subissent la moindre injustice.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mmxiii{Et Allah propose en parabole une ville: elle était en sécurité, tranquille; sa part de nourriture lui venait de partout en abondance. Puis elle se montra ingrate aux bienfaits d'Allah. Allah lui fit alors goûter la violence de la faim et de la peur [en punition] de ce qu'ils faisaient.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@mmxiv{En effet, un Messager des leurs est venu à eux, mais ils l'ont traité de menteur. Le châtiment, donc, les saisit parce qu'ils étaient injustes.\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@mmxv{Mangez donc de ce qu'Allah vous a attribué de licite et de bon. Et soyez reconnaissants pour les bienfaits d'Allah, si c'est Lui que vous adorez.\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@mmxvi{Il vous a, en effet, interdit (la chair) de la bête morte, le sang, la chair de porc, et la bête sur laquelle un autre nom que celui d'Allah a été invoqué. Mais quiconque en mange sous contrainte, et n'est ni rebelle ni transgresseur, alors Allah est Pardonneur et Miséricordieux.\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@mmxvii{Et ne dites pas, conformément aux mensonges proférés par vos langues: «Ceci est licite, et cela est illicite», pour forger le mensonge contre Allah. Certes, ceux qui forgent le mensonge contre Allah ne réussiront pas.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@mmxviii{Ce sera pour eux une piètre jouissance, mais un douloureux châtiment les attend.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@mmxix{Aux Juifs, Nous avions interdit ce que Nous t'avons déjà relaté. Nous ne leur avons fait aucun tort; mais ils se faisaient du tort à eux-mêmes.\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@mmxx{Puis ton Seigneur envers ceux qui ont commis le mal par ignorance, et se sont par la suite repentis et ont amélioré leur conduite, ton Seigneur, après cela est certes Pardonneur et Miséricordieux.\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@mmxxi{Abraham était un guide ('Umma) parfait. Il était soumis à Allah, voué exclusivement à Lui et il n'était point du nombre des associateurs.\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@mmxxii{Il était reconnaissant pour Ses bienfaits et Allah l'avait élu et guidé vers un droit chemin.\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@mmxxiii{Nous lui avons donné une belle part ici-bas. Et il sera certes dans l'au-delà du nombre des gens de bien.\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@mmxxiv{Puis Nous t'avons révélé: «Suis la religion d'Abraham qui était voué exclusivement à Allah et n'était point du nombre des associateurs».\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@mmxxv{Le Sabbat n'a été imposé qu'à ceux qui divergeaient à son sujet. Au Jour de la Résurrection, ton Seigneur jugera certainement au sujet de ce dont ils divergeaient.\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@mmxxvi{Par la sagesse et la bonne exhortation appelle (les gens) au sentier de ton Seigneur. Et discute avec eux de la meilleure façon. Car c'est ton Seigneur qui connaît le mieux celui qui s'égare de Son sentier et c'est Lui qui connaît le mieux ceux qui sont bien guidés.\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@mmxxvii{Et si vous punissez, infligez [à l'agresseur] une punition égale au tort qu'il vous a fait. Et si vous endurez... cela est certes meilleur pour les endurants.\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@mmxxviii{Endure! Ton endurance [ne viendra] qu'avec (l'aide) d'Allah. Ne t'afflige pas pour eux. Et ne sois pas angoissé à cause de leurs complots.\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@mmxxix{Certes, Allah est avec ceux qui [L'] ont craint avec piété et ceux qui sont bienfaisants.\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@mmxxx{\basmalahfr Gloire et Pureté à Celui qui de nuit, fit voyager Son serviteur [Muhammad], de la Mosquée Al-Harâm à la Mosquée Al-Aqsâ dont Nous avons béni l'alentour, afin de lui faire voir certaines de Nos merveilles. C'est Lui, vraiment, qui est l'Audient, le Clairvoyant.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmxxxi{Et Nous avions donné à Moïse le Livre dont Nous avions fait un guide pour les Enfants d'Israël: «Ne prenez pas de protecteur en dehors de Moi».\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmxxxii{[O vous], les descendants de ceux que Nous avons transportés dans l'arche avec Noé. Celui-ci était vraiment un serviteur fort reconnaissant.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmxxxiii{Nous avions décrété pour les Enfants d'Israël, (et annoncé) dans le Livre: «Par deux fois vous sèmerez la corruption sur terre et vous allez transgresser d'une façon excessive».\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmxxxiv{Lorsque vint l'accomplissement de la première de ces deux [prédictions,] Nous envoyâmes contre vous certains de Nos serviteurs doués d'une force terrible, qui pénétrèrent à l'intérieur des demeures. Et la prédiction fut accomplie.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmxxxv{Ensuite, Nous vous donnâmes la revanche sur eux; et Nous vous renforçâmes en biens et en enfants. Et Nous vous fîmes [un peuple] plus nombreux:\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmxxxvi{«Si vous faites le bien; vous le faites à vous-mêmes; et si vous faites le mal, vous le faites à vous [aussi]». Puis, quand vint la dernière [prédiction,] ce fut pour qu'ils affligent vos visages et entrent dans la Mosquée comme ils y étaient entrés la première fois, et pour qu'ils détruisent complètement ce dont ils se sont emparés.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmxxxvii{Il se peut que votre Seigneur vous fasse miséricorde. Mais si vous récidivez, Nous récidiverons. Et Nous avons assigné l'Enfer comme camp de détention aux infidèles.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmxxxviii{Certes, ce Coran guide vers ce qu'il y a de plus droit, et il annonce aux croyants qui font de bonnes œuvres qu'ils auront une grande récompense,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmxxxix{et à ceux qui ne croient pas en l'au-delà, que Nous leur avons préparé un châtiment douloureux.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmxl{L'homme appelle le mal comme il appelle le bien, car l'homme est très hâtif.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmxli{Nous avons fait de la nuit et du jour deux signes, et Nous avons effacé le signe de la nuit, tandis que Nous avons rendu visible le signe du jour, pour que vous recherchiez des grâces de votre Seigneur, et que vous sachiez le nombre des années et le calcul du temps. Et Nous avons expliqué toute chose d'une manière détaillée.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmxlii{Et au cou de chaque homme, Nous avons attaché son œuvre. Et au Jour de la Résurrection, Nous lui sortirons un écrit qu'il trouvera déroulé:\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmxliii{«Lis ton écrit. Aujourd'hui, tu te suffis d'être ton propre comptable».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmxliv{Quiconque prend le droit chemin ne le prend que pour lui-même; et quiconque s'égare, ne s'égare qu'à son propre détriment. Et nul ne portera le fardeau d'autrui. Et Nous n'avons jamais puni [un peuple] avant de [lui] avoir envoyé un Messager.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmxlv{Et quand Nous voulons détruire une cité, Nous ordonnons à ses gens opulents [d'obéir à Nos prescriptions], mais (au contraire) ils se livrent à la perversité. Alors la Parole prononcée contre elle se réalise, et Nous la détruisons entièrement.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmxlvi{Que de générations avons-nous exterminées, après Noé! Et ton Seigneur suffit qu'Il soit Parfaitement Connaisseur et Clairvoyant sur les péchés de Ses serviteurs.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmxlvii{Quiconque désire [la vie] immédiate, Nous nous hâtons de donner ce que Nous voulons, à qui Nous voulons. Puis, Nous lui assignons l'Enfer où il brûlera méprisé et repoussé.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmxlviii{Et ceux qui recherchent l'au-delà et fournissent les efforts qui y mènent, tout en étant croyants... alors l'effort de ceux-là sera reconnu.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmxlix{Nous accordons abondamment à tous, ceux-ci comme ceux-là, des dons de ton Seigneur. Et les dons de ton Seigneur ne sont refusés [à personne].\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mml{Regarde comment Nous favorisons certains sur d'autres. Et dans l'au-delà, il y a des rangs plus élevés et plus privilégiés.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmli{N'assigne point à Allah d'autre divinité; sinon tu te trouveras méprisé et abandonné.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmlii{Et ton Seigneur a décrété: «N'adorez que Lui; et (marquez) de la bonté envers les père et mère: si l'un d'eux ou tous deux doivent atteindre la vieillesse auprès de toi, alors ne leur dis point: «Fi!» et ne les brusque pas, mais adresse-leur des paroles respectueuses.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmliii{et par miséricorde, abaisse pour eux l'aile de l'humilité, et dis: «O mon Seigneur, fais-leur, à tous deux, miséricorde comme ils m'ont élevé tout petit».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmliv{Votre Seigneur connaît mieux ce qu'il y a dans vos âmes. Si vous êtes bons, Il est certes Pardonneur pour ceux qui Lui reviennent se repentant.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmlv{«Et donne au proche parent ce qui lui est dû ainsi qu'au pauvre et au voyageur (en détresse). Et ne gaspille pas indûment,\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmlvi{car les gaspilleurs sont les frères des diables; et le Diable est très ingrat envers son Seigneur.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmlvii{Si tu t'écartes d'eux à la recherche d'une miséricorde de Ton Seigneur, que tu espères, adresse-leur une parole bienveillante.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmlviii{Ne porte pas ta main enchaînée à ton cou [par avarice], et ne l'étend pas non plus trop largement, sinon tu te trouveras blâmé et chagriné.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmlix{En vérité ton Seigneur étend Ses dons largement à qu'Il veut ou les accorde avec parcimonie. Il est, sur Ses serviteurs, Parfaitement Connaisseur et Clairvoyant.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmlx{Et ne tuez pas vos enfants par crainte de pauvreté; c'est Nous qui attribuons leur subsistance, tout comme à vous. Les tuer, c'est vraiment, un énorme péché.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmlxi{Et n'approchez point la fornication. En vérité, c'est une turpitude et quel mauvais chemin!\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmlxii{Et, sauf en droit, ne tuez point la vie qu'Allah a rendu sacrée. Quiconque est tué injustement, alors Nous avons donné pouvoir à son proche [parent]. Que celui-ci ne commette pas d'excès dans le meurtre, car il est déjà assisté (par la loi).\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmlxiii{Et n'approchez les biens de l'orphelin que de la façon la meilleure, jusqu'à ce qu'il atteigne sa majorité. Et remplissez l'engagement, car on sera interrogé au sujet des engagements.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmlxiv{Et donnez la pleine mesure quand vous mesurez, et pesez avec une balance exacte. C'est mieux [pour vous] et le résultat en sera meilleur.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmlxv{Et ne poursuis pas ce dont tu n'as aucune connaissance. L'ouïe, la vue et le cœur: sur tout cela, en vérité, on sera interrogé.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmlxvi{Et ne foule pas la terre avec orgueil: tu ne sauras jamais fendre la terre et tu ne pourras jamais atteindre la hauteur des montagnes!\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmlxvii{Ce qui est mauvais en tout cela est détesté de ton Seigneur.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmlxviii{Tout cela fait partie de ce que ton Seigneur t'a révélé de la Sagesse. N'assigne donc pas à Allah d'autre divinité, sinon tu seras jeté dans l'Enfer, blâmé et repoussé.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmlxix{Votre Seigneur, aurait-Il réservé exclusivement pour vous des fils, et Lui, aurait-Il pris pour Lui des filles parmi les Anges? Vous prononcez là une parole monstrueuse.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmlxx{Très certainement Nous avons exposé [tout ceci] dans ce Coran afin que [les gens] réfléchissent. Mais cela ne fait qu'augmenter leur répulsion.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmlxxi{Dis: «S'il y avait des divinités avec Lui, comme ils le disent, elles auraient alors cherché un chemin [pour atteindre] le Détenteur du Trône».\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmlxxii{Pureté à Lui! Il est plus haut et infiniment au-dessus de ce qu'ils disent!\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmlxxiii{Les sept cieux et la terre et ceux qui s'y trouvent, célèbrent Sa gloire. Et il n'existe rien qui ne célèbre Sa gloire et Ses louanges. Mais vous ne comprenez pas leur façon de Le glorifier. Certes c'est Lui qui est Indulgent et Pardonneur.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmlxxiv{Et quand tu lis le Coran, Nous plaçons, entre toi et ceux qui ne croient pas en l'au-delà, un voile invisible,\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmlxxv{Nous avons mis des voiles sur leurs cœurs, de sorte qu'ils ne le comprennent pas: et dans leurs oreilles, une lourdeur. Et quand, dans le Coran, tu évoques Ton Seigneur l'Unique, ils tournent le dos par répulsion.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmlxxvi{Nous savons très bien ce qu'ils écoutent. Quand ils t'écoutent et qu'ils chuchotent entre eux, les injustes disent: «Vous ne suivez qu'un homme ensorcelé».\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmlxxvii{Vois ce à quoi ils te comparent! Ils s'égarent donc et sont incapables de trouver un chemin (vers la vérité).\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmlxxviii{Et ils disent: «Quand nous serons ossements et poussière, serons-nous ressuscités en une nouvelle création?»\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmlxxix{Dis: «Soyez pierre ou fer.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmlxxx{ou toute autre créature que vous puissiez concevoir.» Ils diront alors: «Qui donc nous fera revenir?» - Dis: «Celui qui vous a créés la première fois». Ils secoueront vers toi leurs têtes et diront: «Quand cela?» Dis: «Il se peut que ce soit proche.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmlxxxi{Le jour où Il vous appellera, vous Lui répondrez en Le glorifiant. Vous penserez cependant que vous n'êtes restés [sur terre] que peu de temps!»\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmlxxxii{Et dis à Mes serviteurs d'exprimer les meilleures paroles, car le Diable sème la discorde parmi eux. Le Diable est certes, pour l'homme, un ennemi déclaré.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmlxxxiii{Votre Seigneur vous connaît mieux. S'Il veut, Il vous fera miséricorde, et s'Il veut, Il vous châtiera. Et Nous ne t'avons pas envoyé pour que tu sois leur protecteur.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmlxxxiv{Et ton Seigneur est plus Connaisseur de ceux qui sont dans les cieux et sur la terre. Et parmi les prophètes, Nous avons donné à certains plus de faveurs qu'à d'autres. Et à David Nous avons donné le «Zabûr».\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmlxxxv{Dis: «Invoquez ceux que vous prétendez, (être des divinités) en dehors de Lui. Ils ne possèdent ni le moyen de dissiper votre malheur ni de le détourner.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmlxxxvi{Ceux qu'ils invoquent, cherchent [eux-mêmes], à qui mieux, le moyen de se rapprocher le plus de leur Seigneur. Ils espèrent Sa miséricorde et craignent Son châtiment. Le châtiment de ton Seigneur est vraiment redouté.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmlxxxvii{Il n'est point de cité [injuste] que Nous ne fassions périr avant le Jour de la Résurrection, ou que Nous ne punissions d'un dur châtiment. Cela est bien tracé dans le Livre [des décrets immuables].\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmlxxxviii{Rien ne Nous empêche d'envoyer les miracles, si ce n'est que les Anciens les avaient traités de mensonges. Nous avions apporté aux Thamûd la chamelle qui était un [miracle] visible: mais ils lui firent du tort. En outre, Nous n'envoyons de miracles qu'à titre de menace.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmlxxxix{Et lorsque Nous te disions que ton Seigneur cerne tous les gens (par Sa puissance et Son savoir). Quant à la vision que Nous t'avons montrée, Nous ne l'avons faite que pour éprouver les gens, tout comme l'arbre maudit mentionné dans le Coran. Nous les menaçons, mais cela ne fait qu'augmenter leur grande transgression.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmxc{Et lorsque Nous avons dit aux Anges: «Prosternez-vous devant Adam», ils se prosternèrent, à l'exception d'Iblis, qui dit: «Me prosternerai-je devant quelqu'un que Tu as créé d'argile?»\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmxci{Il dit encore: «Vois-Tu? Celui que Tu as honoré au-dessus de moi, si Tu me donnais du répit jusqu'au Jour de la Résurrection, j'éprouverai, certes, sa descendance excepté un petit nombre [parmi eux]».\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmxcii{Et [Allah] dit: «Va-t-en! Quiconque d'entre eux te suivra... votre sanction sera l'Enfer, une ample rétribution.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmxciii{Excite, par ta voix, ceux d'entre eux que tu pourras, rassemble contre eux ta cavalerie et ton infanterie, associe-toi à eux dans leur biens et leurs enfants et fais-leur des promesses». Or, le Diable ne leur fait des promesses qu'en tromperie.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmxciv{Quant à Mes serviteurs, tu n'as aucun pouvoir sur eux». Et ton Seigneur suffit pour les protéger!\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmxcv{Votre Seigneur est Celui qui fait voguer le vaisseau pour vous en mer, afin que vous alliez à la recherche de quelque grâce de Sa part; Certes Il est Miséricordieux envers vous,\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmxcvi{Et quand le mal vous touche en mer, ceux que vous invoquiez en dehors de Lui se perdent. Puis, quand Il vous sauve et vous ramène à terre, vous vous détournez. L'homme reste très ingrat!\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmxcvii{Etes-vous à l'abri de ce qu'Il vous fasse engloutir par un pan de terre, ou qu'Il envoie contre vous un ouragan (avec pluie en pierres) et que vous ne trouverez alors aucun protecteur.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmxcviii{Ou êtes-vous à l'abri de ce qu'Il vous y ramène (en mer) une autre fois, qu'Il déchaîne contre vous un de ces vents à tout casser, puis qu'Il vous fasse noyer à cause de votre mécréance? Et alors vous ne trouverez personne pour vous défendre contre Nous!\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmxcix{Certes, Nous avons honoré les fils d'Adam. Nous les avons transportés sur terre et sur mer, leur avons attribué de bonnes choses comme nourriture, et Nous les avons nettement préférés à plusieurs de Nos créatures.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmc{Le jour où Nous appellerons chaque groupement d'hommes par leur chef, ceux à qui on remettra leur livre dans la main droite liront leur livre (avec plaisir) et ne subiront pas la moindre injustice.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmci{Et quiconque aura été aveugle ici-bas, sera aveugle dans l'au-delà, et sera plus égaré [encore] par rapport à la bonne voie.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmcii{Ils ont failli te détourner de ce que Nous t'avions révélé, [dans l'espoir] qu'à la place de ceci, tu inventes quelque chose d'autre et (l'imputes) à Nous. Et alors, ils t'auraient pris pour ami intime.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmciii{Et si Nous ne t'avions pas raffermi, tu aurais bien failli t'incliner quelque peu vers eux.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmciv{Alors, Nous t'aurions certes fait goûter le double [supplice] de la vie et le double [supplice] de la mort; et ensuite tu n'aurais pas trouvé de secoureur contre Nous.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmcv{En vérité, ils ont failli t'inciter à fuir du pays pour t'en bannir. Mais dans ce cas, ils n'y seraient pas restés longtemps après toi.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmcvi{Telle fut la règle appliquée par Nous à Nos messagers que Nous avons envoyés avant toi. Et tu ne trouveras pas de changement en Notre règle.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmcvii{Accomplis la Salât au déclin du soleil jusqu'à l'obscurité de la nuit, et [fais] aussi la Lecture à l'aube, car la Lecture à l'aube a des témoins.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmcviii{Et de la nuit consacre une partie [avant l'aube] pour des Salât surérogatoires: afin que ton Seigneur te ressuscite en une position de gloire.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmcix{Et dis: «O mon Seigneur, fais que j'entre par une entrée de vérité et que je sorte par une sortie de vérité; et accorde-moi de Ta part, un pouvoir bénéficiant de Ton secours».\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmcx{Et dis: «La Vérité (l'Islam) est venue et l'Erreur a disparu. Car l'Erreur est destinée à disparaître».\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmcxi{Nous faisons descendre du Coran, ce qui est une guérison et une miséricorde pour les croyants. Cependant, cela ne fait qu'accroître la perdition des injustes.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmcxii{Et quand Nous comblons l'homme de bienfaits, il se détourne et se replie sur lui-même; et quand un mal le touche, le voilà profondément désespéré.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmcxiii{Dis: «Chacun agit selon sa méthode, alors que votre Seigneur connaît mieux qui suit la meilleure voie».\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmcxiv{Et ils t'interrogent au sujet de l'âme, - Dis: «L'âme relève de l'Ordre de mon Seigneur». Et on ne vous a donné que peu de connaissance.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmcxv{Si Nous voulons, Nous pouvons certes faire disparaître ce que Nous t'avons révélé; et tu n'y trouverais par la suite aucun défenseur contre Nous.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmcxvi{Si ce n'est par une miséricorde de ton Seigneur, car en vérité Sa grâce sur toi est grande.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmcxvii{Dis: «Même si les hommes et les djinns s'unissaient pour produire quelque chose de semblable à ce Coran, ils ne sauraient produire rien de semblable, même s'ils se soutenaient les uns les autres».\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmcxviii{Et certes, Nous avons déployé pour les gens, dans ce Coran, toutes sortes d'exemples. Mais la plupart des gens s'obstinent à être mécréants.\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmcxix{Et ils dirent: «Nous ne croirons pas en toi, jusqu'à ce que tu aies fait jaillir de terre, pour nous, une source;\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmcxx{ou que tu aies un jardin de palmiers et de vignes, entre lesquels tu feras jaillir des ruisseaux en abondance;\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmcxxi{ou que tu fasses tomber sur nous, comme tu le prétends, le ciel en morceaux; ou que tu fasses venir Allah et les Anges en face de nous;\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmcxxii{ou que tu aies une maison [garnie] d'ornements; ou que tu sois monté au ciel. Encore ne croirons-nous pas à ta montée au ciel, jusqu'à ce que tu fasses descendre sur nous un Livre que nous puissions lire». Dis-[leur]: «Gloire à mon Seigneur! Ne suis-je qu'un être humain-Messager?»\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmcxxiii{Et rien n'empêcha les gens de croire, quand le guide leur est parvenu, si ce n'est qu'ils disaient: «Allah envoie-t-Il un être humain-Messager?»\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mmcxxiv{Dis: «S'il y avait sur terre des Anges marchant tranquillement, Nous aurions certes fait descendre sur eux du ciel un Ange-Messager».\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mmcxxv{Dis: «Allah suffit comme témoin entre vous et moi». Il est, sur Ses serviteurs, Parfaitement Connaisseur et Clairvoyant.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mmcxxvi{Celui qu'Allah guide, c'est lui le bien-guidé et ceux qu'Il égare... tu ne leur trouveras jamais d'alliés en dehors de Lui et au Jour de la Résurrection, Nous les rassemblerons traînés sur leurs visages, aveugles, muets et sourds. L'Enfer sera leur demeure: chaque fois que son feu s'affaiblit, Nous leur accroîtrons la flamme ardente.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mmcxxvii{Telle sera leur sanction parce qu'ils ne croient pas en Nos preuves et disent: «Quand nous serons ossements et poussière, serons-nous ressuscités en une nouvelle création?»\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mmcxxviii{N'ont-ils pas vu qu'Allah qui a créé les cieux et la terre est capable de créer leurs pareils? Il leur a fixé un terme, sur lequel il n'y a aucun doute, mais les injustes s'obstinent dans leur mécréance.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mmcxxix{Dis: «Si c'était vous qui possédiez les trésors de la miséricorde de mon Seigneur, vous lésineriez, certes, de peur de les dépenser. Et l'homme est très avare!\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mmcxxx{Et certes, Nous donnâmes à Moïse neuf miracles évidents. Demande donc aux Enfants d'Israël, lorsqu'il leur vint et que Pharaon lui dit: «O Moïse, je pense que tu es ensorcelé».\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mmcxxxi{Il dit: «Tu sais fort bien que ces choses [les miracles], seul le Seigneur des cieux et de la terre les a fait descendre comme autant de preuves illuminantes; et certes, O Pharaon, je te crois perdu».\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mmcxxxii{[Pharaon] voulut donc les expulser du pays. Alors Nous les noyâmes tous, lui et ceux qui étaient avec lui.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mmcxxxiii{Et après lui, Nous dîmes aux Enfants d'Israël: «Habitez la terre». Puis, lorsque viendra la promesse de la (vie) dernière, Nous vous ferons venir en foule.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mmcxxxiv{Et c'est en toute vérité que Nous l'avons fait descendre (le Coran), et avec la vérité il est descendu, et Nous ne t'avons envoyé qu'en annonciateur et avertisseur.\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mmcxxxv{(Nous avons fait descendre) un Coran que Nous avons fragmenté, pour que tu le lises lentement aux gens. Et Nous l'avons fait descendre graduellement.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mmcxxxvi{Dis: «Croyez-y ou n'y croyez pas. Ceux à qui la connaissance a été donnée avant cela, lorsqu'on le leur récite, tombent, prosternés, le menton contre terre\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mmcxxxvii{et disent: «Gloire à notre Seigneur! La promesse de notre Seigneur est assurément accomplie».\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mmcxxxviii{Et ils tombent sur leur menton, pleurant, et cela augmente leur humilité.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mmcxxxix{Dis: «Invoquez Allah, ou invoquez le Tout Miséricordieux. Quel que soit le nom par lequel vous l'appelez, Il a les plus beaux noms. Et dans ta Salât, ne récite pas à voix haute; et ne l'y abaisse pas trop, mais cherche le juste milieu entre les deux».\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mmcxl{Et dis: «Louange à Allah qui ne S'est jamais attribué d'enfant, qui n'a point d'associé en la royauté et qui n'a jamais eu de protecteur de l'humiliation». Et proclame hautement Sa grandeur.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mmcxli{\basmalahfr Louange à Allah qui a fait descendre sur Son serviteur (Muhammad), le Livre, et n'y a point introduit de tortuosité (ambiguité)!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmcxlii{[Un Livre] d'une parfaite droiture pour avertir d'une sévère punition venant de Sa part et pour annoncer aux croyants qui font de bonnes œuvres qu'il y aura pour eux une belle récompense.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmcxliii{où ils demeureront éternellement,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmcxliv{et pour avertir ceux qui disent: «Allah S'est attribué un enfant.»\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmcxlv{Ni eux ni leurs ancêtres n'en savent rien. Quelle monstrueuse parole que celle qui sort de leurs bouches! Ce qu'ils disent n'est que mensonge.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmcxlvi{Tu vas peut-être te consumer de chagrin parce qu'ils se détournent de toi et ne croient pas en ce discours!\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmcxlvii{Nous avons placé ce qu'il y a sur la terre pour l'embellir, afin d'éprouver (les hommes et afin de savoir) qui d'entre eux sont les meilleurs dans leurs actions.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmcxlviii{Puis, Nous allons sûrement transformer sa surface en un sol aride.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmcxlix{Penses-tu que les gens de la Caverne et d'ar-Raquîm ont constitué une chose extraordinaire d'entre Nos prodiges?\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmcl{Quand les jeunes gens se furent réfugiés dans la caverne, ils dirent: «O notre Seigneur, donne-nous de Ta part une miséricorde; et assure nous la droiture dans tout ce qui nous concerne».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmcli{Alors, Nous avons assourdi leurs oreilles, dans la caverne pendant de nombreuses années.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmclii{Ensuite, Nous les avons ressuscités, afin de savoir lequel des deux groupes saurait le mieux calculer la durée exacte de leur séjour.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmcliii{Nous allons te raconter leur récit en toute vérité. Ce sont des jeunes gens qui croyaient en leur Seigneur; et Nous leur avons accordé les plus grands moyens de se diriger [dans la bonne voie].\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmcliv{Nous avons fortifié leurs cœurs lorsqu'ils s'étaient levés pour dire: «Notre Seigneur est le Seigneur des cieux et de la terre: jamais nous n'invoquerons de divinité en dehors de Lui, sans quoi, nous transgresserions dans nos paroles.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmclv{Voilà que nos concitoyens ont adopté en dehors de Lui des divinités. Que n'apportent-ils sur elles une preuve évidente? Quel pire injuste, donc que celui qui invente un mensonge contre Allah?\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmclvi{Et quand vous vous serez séparés d'eux et de ce qu'ils adorent en dehors d'Allah, réfugiez-vous donc dans la caverne: votre Seigneur répandra de Sa miséricorde sur vous et disposera pour vous un adoucissement à votre sort.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmclvii{Tu aurais vu le soleil, quand il se lève, s'écarter de leur caverne vers la droite, et quand il se couche, passer à leur gauche, tandis qu'eux-mêmes sont là dans une partie spacieuse (de la caverne)... Cela est une des merveilles d'Allah. Celui qu'Allah guide, c'est lui le bien-guidé. Et quiconque Il égare, tu ne trouveras alors pour lui aucun allié pour le mettre sur la bonne voie.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmclviii{Et tu les aurais cru éveillés, alors qu'ils dorment. Et Nous les tournons sur le côté droit et sur le côté gauche, tandis que leur chien est à l'entrée, pattes étendues. Si tu les avais aperçus, certes tu leur aurais tourné le dos en fuyant; et tu aurais été assurément rempli d'effroi devant eux.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmclix{Et c'est ainsi que Nous les ressuscitâmes, afin qu'ils s'interrogent entre eux. L'un parmi eux dit: «Combien de temps avez-vous demeuré là?» Ils dirent: «Nous avons demeuré un jour ou une partie d'un jour». D'autres dirent: «Votre Seigneur sait mieux combien [de temps] vous y avez demeuré. Envoyez donc l'un de vous à la ville avec votre argent que voici, pour qu'il voie quel aliment est le plus pur et qu'il vous en apporte de quoi vous nourrir. Qu'il agisse avec tact; et qu'il ne donne l'éveil à personne sur vous.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmclx{Si jamais ils vous attrapent, ils vous lapideront ou vous feront retourner à leur religion, et vous ne réussirez alors plus jamais».\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmclxi{Et c'est ainsi que Nous fîmes qu'ils furent découverts, afin qu'ils [les gens de la cité] sachent que la promesse d'Allah est vérité et qu'il n'y ait point de doute au sujet de l'Heure. Aussi se disputèrent-ils à leur sujet et déclarèrent-ils: «Construisez sur eux un édifice. Leur Seigneur les connaît mieux». Mais ceux qui l'emportèrent [dans la discussion] dirent: «Elevons sur eux un sanctuaire».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmclxii{Ils diront: «ils étaient trois et le quatrième était leur chien». Et ils diront en conjecturant sur leur mystère qu'ils étaient cinq, le sixième étant leur chien et ils diront: «sept, le huitième étant leur chien». Dis: «Mon Seigneur connaît mieux leur nombre. Il n'en est que peu qui le savent». Ne discute à leur sujet que d'une façon apparente et ne consulte personne en ce qui les concerne.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmclxiii{Et ne dis jamais, à propos d'une chose: «Je la ferai sûrement demain»,\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmclxiv{sans ajouter: «Si Allah le veut», et invoque ton Seigneur quand tu oublies et dis: «Je souhaite que mon Seigneur me guide et me mène plus près de ce qui est correct».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmclxv{Or, ils demeurèrent dans leur caverne trois cents ans et en ajoutèrent neuf (années).\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmclxvi{Dis: «Allah sait mieux combien de temps ils demeurèrent là. A Lui appartient l'Inconnaissable des cieux et de la terre. Comme Il est Voyant et Audient! Ils n'ont aucun allié en dehors de Lui et Il n'associe personne à Son commandement.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmclxvii{Et récite ce qui t'a été révélé du Livre de ton Seigneur. Nul ne peut changer Ses paroles. Et tu ne trouveras, en dehors de Lui, aucun refuge.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmclxviii{Fais preuve de patience [en restant] avec ceux qui invoquent leur Seigneur matin et soir, désirant Sa Face. Et que tes yeux ne se détachent point d'eux, en cherchant (le faux) brillant de la vie sur terre. Et n'obéis pas à celui dont Nous avons rendu le cœur inattentif à Notre Rappel, qui poursuit sa passion et dont le comportement est outrancier.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmclxix{Et dis: «La vérité émane de votre Seigneur». Quiconque le veut, qu'il croie, quiconque le veut qu'il mécroie». Nous avons préparé pour les injustes un Feu dont les flammes les cernent. Et s'ils implorent à boire on les abreuvera d'une eau comme du métal fondu brûlant les visages. Quelle mauvaise boisson et quelle détestable demeure!\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmclxx{Ceux qui croient et font de bonnes œuvres... vraiment Nous ne laissons pas perdre la récompense de celui qui fait le bien.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmclxxi{Voilà ceux qui auront les jardins du séjour (éternel) sous lesquels coulent les ruisseaux. Ils y seront parés de bracelets d'or et se vêtiront d'habits verts de soie fine et de brocart, accoudés sur des divans (bien ornés). Quelle bonne récompense et quelle belle demeure!\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmclxxii{Donne-leur l'exemple de deux hommes: à l'un d'eux Nous avons assigné deux jardins de vignes que Nous avons entourés de palmiers et Nous avons mis entre les deux jardins des champs cultivés.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmclxxiii{Les deux jardins produisaient leur récolte sans jamais manquer. Et Nous avons fait jaillir entre eux un ruisseau.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmclxxiv{Et il avait des fruits et dit alors à son compagnon avec qui il conversait: «Je possède plus de biens que toi, et je suis plus puissant que toi grâce à mon clan».\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmclxxv{Il entra dans son jardin coupable envers lui-même [par sa mécréance]; il dit: «Je ne pense pas que ceci puisse jamais périr,\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmclxxvi{et je ne pense pas que l'Heure viendra. Et si on me ramène vers mon Seigneur, je trouverai certes meilleur lieu de retour que ce jardin.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmclxxvii{Son compagnon lui dit, tout en conversant avec lui: «Serais-tu mécréant envers Celui qui t'a créé de terre, puis de sperme et enfin t'a façonné en homme?\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmclxxviii{Quant à moi, c'est Allah qui est mon Seigneur; et je n'associe personne à mon Seigneur.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmclxxix{En entrant dans ton jardin, que ne dis-tu: «Telle est la volonté (et la grâce) d'Allah! Il n'y a de puissance que par Allah». Si tu me vois moins pourvu que toi en biens et en enfants,\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmclxxx{il se peut que mon Seigneur, bientôt, me donne quelque chose de meilleur que ton jardin, qu'Il envoie sur [ce dernier], du ciel, quelque calamité, et que son sol devienne glissant,\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmclxxxi{ou que son eau tarisse de sorte que tu ne puisses plus la retrouver».\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmclxxxii{Et sa récolte fut détruite et il se mit alors à se tordre les deux mains à cause de ce qu'il y avait dépensé, cependant que ses treilles étaient complètement ravagées. Et il disait: «Que je souhaite n'avoir associé personne à mon Seigneur!»\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmclxxxiii{Il n'eut aucun groupe de gens pour le secourir contre (la punition) d'Allah. Et il ne put se secourir lui-même.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmclxxxiv{En l'occurrence, la souveraine protection appartient à Allah, le Vrai. Il accorde la meilleure récompense et le meilleur résultat.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmclxxxv{Et propose-leur l'exemple de la vie ici-bas. Elle est semblable à une eau que Nous faisons descendre du ciel; la végétation de la terre se mélange à elle. Puis elle devient de l'herbe desséchée que les vents dispersent. Allah est certes Puissant en toutes choses!\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmclxxxvi{Les biens et les enfants sont l'ornement de la vie de ce monde. Cependant, les bonnes œuvres qui persistent ont auprès de ton Seigneur une meilleure récompense et [suscitent] une belle espérance.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmclxxxvii{Le jour où Nous ferons marcher les montagnes et où tu verras la terre nivelée (comme une plaine) et Nous les rassemblerons sans en omettre un seul.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmclxxxviii{Et ils seront présentés en rangs devant ton Seigneur. «Vous voilà venus à Nous comme Nous vous avons créés la première fois. Pourtant vous prétendiez que Nous ne remplirions pas Nos promesses».\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmclxxxix{Et on déposera le livre (de chacun). Alors tu verras les criminels, effrayés à cause de ce qu'il y a dedans, dire: «Malheur à nous, qu'a donc ce livre à n'omettre de mentionner ni péché véniel ni péché capital?» Et ils trouveront devant eux tout ce qu'ils ont œuvré. Et ton Seigneur ne fait du tort à personne.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmcxc{Et lorsque nous dîmes aux Anges: «Prosternez-vous devant Adam», ils se prosternèrent, excepté Iblis [Satan] qui était du nombre des djinns et qui se révolta contre le commandement de son Seigneur. Allez-vous cependant le prendre, ainsi que sa descendance, pour alliés en dehors de Moi, alors qu'ils vous sont ennemis? Quel mauvais échange pour les injustes!\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmcxci{Je ne les ai pas pris comme témoins de la création des cieux et de la terre, ni de la création de leurs propres personnes. Et Je n'ai pas pris comme aides ceux qui égarent.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmcxcii{Et le jour où Il dira: «Appelez ceux que vous prétendiez être Mes associés». Ils les invoqueront; mais eux ne leur répondront pas, Nous aurons placé entre eux une vallée de perdition.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmcxciii{Et les criminels verront le Feu. Ils seront alors convaincus qu'ils y tomberont et n'en trouveront pas d'échappatoire.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmcxciv{Et assurément, Nous avons déployé pour les gens, dans ce Coran, toutes sortes d'exemples. L'homme cependant, est de tous les êtres le plus grand disputeur.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmcxcv{Qu'est-ce qui a donc empêché les gens de croire, lorsque le guide leur est venu, ainsi que de demander pardon à leur Seigneur, si ce n'est qu'ils veulent subir le sort des Anciens, ou se trouver face à face avec le châtiment.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmcxcvi{Et Nous n'envoyons des messagers que pour annoncer la bonne nouvelle et avertir. Et ceux qui ont mécru disputent avec de faux arguments, afin d'infirmer la vérité et prennent en raillerie Mes versets (le Coran) ainsi que ce (châtiment) dont on les a avertis.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmcxcvii{Quel pire injuste que celui à qui on a rappelé les versets de son Seigneur et qui en détourna le dos en oubliant ce que ses deux mains ont commis? Nous avons placé des voiles sur leurs cœurs, de sorte qu'ils ne comprennent pas (le Coran), et mis une lourdeur dans leurs oreilles. Même si tu les appelles vers la bonne voie, jamais ils ne pourront donc se guider.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmcxcviii{Et ton Seigneur est le Pardonneur, le Détenteur de la miséricorde. S'Il s'en prenait à eux pour ce qu'ils ont acquis, Il leur hâterait certes le châtiment. Mais il y a pour eux un terme fixé (pour l'accomplissement des menaces) contre lequel ils ne trouveront aucun refuge.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmcxcix{Et voilà les villes que Nous avons fait périr quand leurs peuples commirent des injustices et Nous avons fixé un rendez-vous pour leur destruction.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmcc{(Rappelle-toi) quand Moïse dit à son valet: «Je n'arrêterai pas avant d'avoir atteint le confluent des deux mers, dussé-je marcher de longues années».\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmcci{Puis, lorsque tous deux eurent atteint le confluent, Ils oublièrent leur poisson qui prit alors librement son chemin dans la mer.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmccii{Puis, lorsque tous deux eurent dépassé [cet endroit,] il dit à son valet: «Apporte-nous notre déjeuner: nous avons rencontré de la fatigue dans notre présent voyage».\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmcciii{[Le valet lui] dit: «Quand nous avons pris refuge près du rocher, vois-tu, j'ai oublié le poisson - le Diable seul m'a fait oublier de (te) le rappeler - et il a curieusement pris son chemin dans la mer».\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmcciv{[Moïse] dit: «Voilà ce que nous cherchions». Puis, ils retournèrent sur leurs pas, suivant leurs traces.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmccv{Ils trouvèrent l'un de Nos serviteurs à qui Nous avions donné une grâce, de Notre part, et à qui Nous avions enseigné une science émanant de Nous.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmccvi{Moïse lui dit: «Puis-je te suivre, à la condition que tu m'apprennes de ce qu'on t'a appris concernant une bonne direction?»\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmccvii{[L'autre] dit: «Vraiment, tu ne pourras jamais être patient avec moi.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmccviii{Comment endurerais-tu sur des choses que tu n'embrasses pas par ta connaissance?»\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmccix{[Moïse] lui dit: «Si Allah veut, tu me trouveras patient; et je ne désobéirai à aucun de tes ordres».\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmccx{«Si tu me suis, dit [l'autre,] ne m'interroge sur rien tant que je ne t'en aurai pas fait mention».\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmccxi{Alors les deux partirent. Et après qu'ils furent montés sur un bateau, l'homme y fit une brèche. [Moïse] lui dit: «Est-ce pour noyer ses occupants que tu l'as ébréché? Tu as commis, certes, une chose monstrueuse!»\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmccxii{[L'autre] répondit: «N'ai-je pas dit que tu ne pourrais pas garder patience en ma compagnie?»\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmccxiii{«Ne t'en prends pas à moi, dit [Moïse,] pour un oubli de ma part; et ne m'impose pas de grande difficulté dans mon affaire».\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmccxiv{Puis ils partirent tous deux; et quand ils eurent rencontré un enfant, [l'homme] le tua. Alors [Moïse] lui dit: «As-tu tué un être innocent, qui n'a tué personne? Tu as commis certes, une chose affreuse!»\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmccxv{[L'autre] lui dit: «Ne t'ai je pas dit que tu ne pourrais pas garder patience en ma compagnie?»\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmccxvi{«Si, après cela, je t'interroge sur quoi que ce soit, dit [Moïse], alors ne m'accompagne plus. Tu seras alors excusé de te séparer de moi».\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmccxvii{Ils partirent donc tous deux; et quand ils furent arrivés à un village habité, ils demandèrent à manger à ses habitants; mais ceux-ci refusèrent de leur donner l'hospitalité. Ensuite, ils y trouvèrent un mur sur le point de s'écrouler. L'homme le redressa. Alors [Moïse] lui dit: «Si tu voulais, tu aurais bien pu réclamer pour cela un salaire».\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmccxviii{«Ceci [marque] la séparation entre toi et moi, dit [l'homme,] Je vais t'apprendre l'interprétation de ce que tu n'as pu supporter avec patience.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmccxix{Pour ce qui est du bateau, il appartenait à des pauvres gens qui travaillaient en mer. Je voulais donc le rendre défectueux, car il y avait derrière eux un roi qui saisissait de force tout bateau.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmccxx{Quant au garçon, ses père et mère étaient des croyants; nous avons craint qu'il ne leur imposât la rébellion et la mécréance.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmccxxi{Nous avons donc voulu que leur Seigneur leur accordât en échange un autre plus pur et plus affectueux.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmccxxii{Et quant au mur, il appartenait à deux garçons orphelins de la ville, et il y avait dessous un trésor à eux; et leur père était un homme vertueux. Ton Seigneur a donc voulu que tous deux atteignent leur maturité et qu'ils extraient, [eux-mêmes] leur trésor, par une miséricorde de ton Seigneur. Je ne l'ai d'ailleurs pas fait de mon propre chef. Voilà l'interprétation de ce que tu n'as pas pu endurer avec patience».\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmccxxiii{Et ils t'interrogent sur Dûl-Qarnayn. Dis: «Je vais vous en citer quelque fait mémorable».\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmccxxiv{Vraiment, Nous avons affermi sa puissance sur terre, et Nous lui avons donné libre voie à toute chose.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmccxxv{Il suivit donc une voie.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmccxxvi{Et quand il eut atteint le Couchant, il trouva que le soleil se couchait dans une source boueuse, et, auprès d'elle il trouva une peuplade [impie]. Nous dîmes: «O Dûl-Qarnayn! ou tu les châties, ou tu uses de bienveillance à leur égard».\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmccxxvii{Il dit: «Quant à celui qui est injuste, nous le châtierons; ensuite il sera ramené vers son Seigneur qui le punira d'un châtiment terrible.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmccxxviii{Et quant à celui qui croit et fait bonne œuvre, il aura, en retour, la plus belle récompense. Et nous lui donnerons des ordres faciles à exécuter».\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmccxxix{Puis, il suivit (une autre) voie.\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmccxxx{Et quand il eut atteint le Levant, il trouva que le soleil se levait sur une peuplade à laquelle Nous n'avions pas donné de voile pour s'en protéger.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmccxxxi{Il en fut ainsi et Nous embrassons de Notre Science ce qu'il détenait.\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmccxxxii{Puis, il suivit (une autre) voie.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmccxxxiii{Et quand il eut atteint un endroit situé entre les Deux Barrières (montagnes), il trouva derrière elles une peuplade qui ne comprenait presque aucun langage.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmccxxxiv{Ils dirent: «O Dûl-Qarnayn, les Yâ jûj et les Mâ jûj commettent du désordre sur terre. Est-ce que nous pourrons t'accorder un tribut pour construire une barrière entre eux et nous?»\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mmccxxxv{Il dit: «Ce que Mon Seigneur m'a conféré vaut mieux (que vos dons). Aidez-moi donc avec votre force et je construirai un remblai entre vous et eux.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mmccxxxvi{Apportez-moi des blocs de fer». Puis, lorsqu'il en eut comblé l'espace entre les deux montagnes, il dit: «Soufflez!» Puis, lorsqu'il l'eut rendu une fournaise, il dit: «Apportez-moi du cuivre fondu, que je le déverse dessus».\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mmccxxxvii{Ainsi, ils ne purent guère l'escalader ni l'ébrécher non plus.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mmccxxxviii{Il dit: «C'est une miséricorde de la part de mon Seigneur. Mais, lorsque la promesse de mon Seigneur viendra, Il le nivellera. Et la promesse de mon Seigneur est vérité».\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mmccxxxix{Nous les laisserons, ce jour-là, déferler comme les flots les uns sur les autres, et on soufflera dans la Trompe et Nous les rassemblerons tous.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mmccxl{Et ce jour-là Nous présenterons de près l'Enfer aux mécréants,\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mmccxli{dont les yeux étaient couverts d'un voile qui les empêchait de penser à Moi, et ils ne pouvaient rien entendre non plus.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mmccxlii{Ceux qui ont mécru, comptent-ils donc pouvoir prendre, pour alliés, Mes serviteurs en dehors de Moi? Nous avons préparé l'Enfer comme résidence pour les mécréants.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mmccxliii{Dis: «Voulez-vous que Nous vous apprenions lesquels sont les plus grands perdants, en œuvres?\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mmccxliv{Ceux dont l'effort, dans la vie présente, s'est égaré, alors qu'ils s'imaginent faire le bien.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mmccxlv{Ceux-là qui ont nié les signes de leur Seigneur, ainsi que Sa rencontre. Leurs actions sont donc vaines». Nous ne leur assignerons pas de poids au Jour de la Résurrection.\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mmccxlvi{C'est que leur rétribution sera l'Enfer, pour avoir mécru et pris en raillerie Mes signes (enseignements) et Mes messagers.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mmccxlvii{Ceux qui croient et font de bonnes œuvres auront pour résidence les Jardins du «Firdaws,» (Paradis),\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mmccxlviii{où ils demeureront éternellement, sans désirer aucun changement.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mmccxlix{Dis: «Si la mer était une encre [pour écrire] les paroles de mon Seigneur, certes la mer s'épuiserait avant que ne soient épuisées les paroles de mon Seigneur, quand même Nous lui apporterions son équivalent comme renfort.»\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mmccl{Dis: «Je suis en fait un être humain comme vous. Il m'a été révélé que votre Dieu est un Dieu unique! Quiconque, donc, espère rencontrer son Seigneur, qu'il fasse de bonnes actions et qu'il n'associe dans son adoration aucun autre à son Seigneur».\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mmccli{\basmalahfr Kâf, Hâ', Yâ', 'Aîn, Sâd.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmcclii{C'est un récit de la miséricorde de ton Seigneur envers Son serviteur Zacharie.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmccliii{Lorsqu'il invoqua son Seigneur d'une invocation secrète,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmccliv{et dit: «O mon Seigneur, mes os sont affaiblis et ma tête s'est enflammée de cheveux blancs. [Cependant], je n'ai jamais été malheureux [déçu] en te priant, ô mon Seigneur.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmcclv{Je crains [le comportement] de mes héritiers, après moi. Et ma propre femme est stérile. Accorde-moi, de Ta part, un descendant\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmcclvi{qui hérite de moi et hérite de la famille de Jacob. Et fais qu'il te soit agréable, ô mon Seigneur».\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmcclvii{«O Zacharie, Nous t'annonçons la bonne nouvelle d'un fils. Son nom sera Yahya [Jean]. Nous ne lui avons pas donné auparavant d'homonyme».\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmcclviii{Et [Zacharie dit]: «O mon Seigneur, comment aurai-je un fils, quand ma femme est stérile et que je suis très avancé en vieillesse?»\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmcclix{[Allah] lui dit: «Ainsi sera-t-il! Ton Seigneur a dit: «Ceci m'est facile. Et avant cela, Je t'ai créé alors que tu n'étais rien».\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmcclx{«O mon Seigneur, dit [Zacharie], accorde-moi un signe». «Ton signe, dit [Allah,] sera que tu ne pourras pas parler aux gens pendant trois nuits tout en étant bien portant.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmcclxi{Il sortit donc du sanctuaire vers son peuple; puis il leur fit signe de prier matin et soir.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmcclxii{... «O Yahya, tiens fermement au Livre (la Thora)!» Nous lui donnâmes la sagesse alors qu'il était enfant,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmcclxiii{ainsi que la tendresse de Notre part et la pureté. Il était pieux,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmcclxiv{et dévoué envers ses père et mère; et ne fut ni violent ni désobéissant.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmcclxv{Que la paix soit sur lui le jour où il naquit, le jour où il mourra, et le jour où il sera ressuscité vivant!\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmcclxvi{Mentionne, dans le Livre (le Coran), Marie, quand elle se retira de sa famille en un lieu vers l'Orient.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmcclxvii{Elle mit entre elle et eux un voile. Nous lui envoyâmes Notre Esprit (Gabriel), qui se présenta à elle sous la forme d'un homme parfait.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmcclxviii{Elle dit: «Je me réfugie contre toi auprès du Tout Miséricordieux. Si tu es pieux, [ne m'approche point].»\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmcclxix{Il dit: «Je suis en fait un Messager de ton Seigneur pour te faire don d'un fils pur».\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmcclxx{Elle dit: «Comment aurais-je un fils, quand aucun homme ne m'a touchée, et que je ne suis pas prostituée?»\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmcclxxi{Il dit: «Ainsi sera-t-il! Cela M'est facile, a dit ton Seigneur! Et Nous ferons de lui un signe pour les gens, et une miséricorde de Notre part. C'est une affaire déjà décidée».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmcclxxii{Elle devint donc enceinte [de l'enfant], et elle se retira avec lui en un lieu éloigné.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmcclxxiii{Puis les douleurs de l'enfantement l'amenèrent au tronc du palmier, et elle dit: «Malheur à moi! Que je fusse morte avant cet instant! Et que je fusse totalement oubliée!»\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmcclxxiv{Alors, il l'appela d'au-dessous d'elle, [lui disant:] «Ne t'afflige pas. Ton Seigneur a placé à tes pieds une source.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmcclxxv{Secoue vers toi le tronc du palmier: il fera tomber sur toi des dattes fraîches et mûres.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmcclxxvi{Mange donc et bois et que ton œil se réjouisse! Si tu vois quelqu'un d'entre les humains, dis [lui:] «Assurément, j'ai voué un jeûne au Tout Miséricordieux: je ne parlerai donc aujourd'hui à aucun être humain».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmcclxxvii{Puis elle vint auprès des siens en le portant [le bébé]. Ils dirent: «O Marie, tu as fait une chose monstrueuse!\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmcclxxviii{«Sœur de Hârûn, ton père n'était pas un homme de mal et ta mère n'était pas une prostituée».\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmcclxxix{Elle fit alors un signe vers lui [le bébé]. Ils dirent: «Comment parlerions-nous à un bébé au berceau?»\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmcclxxx{Mais (le bébé) dit: «Je suis vraiment le serviteur d'Allah. Il m'a donné le Livre et m'a désigné Prophète.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmcclxxxi{Où que je sois, Il m'a rendu béni; et Il m'a recommandé, tant que je vivrai, la prière et la Zakât;\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmcclxxxii{et la bonté envers ma mère. Il ne m'a fait ni violent ni malheureux.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmcclxxxiii{Et que la paix soit sur moi le jour où je naquis, le jour où je mourrai, et le jour où je serai ressuscité vivant.»\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmcclxxxiv{Tel est Issa (Jésus), fils de Marie: parole de vérité, dont ils doutent.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmcclxxxv{Il ne convient pas à Allah de S'attribuer un fils. Gloire et Pureté à Lui! Quand Il décide d'une chose, Il dit seulement: «Sois!» et elle est.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmcclxxxvi{Certes, Allah est mon Seigneur tout comme votre Seigneur. Adorez-le donc. Voilà un droit chemin».\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmcclxxxvii{[par la suite,] les sectes divergèrent entre elles. Alors, malheur aux mécréants lors de la vue d'un jour terrible!\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmcclxxxviii{Comme ils entendront et verront bien le jour où ils viendront à Nous! Mais aujourd'hui, les injustes sont dans un égarement évident.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmcclxxxix{Et avertis-les du jour du Regret, quand tout sera réglé; alors qu'ils sont [dans ce monde] inattentifs et qu'ils ne croient pas.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmccxc{C'est Nous, en vérité, qui hériterons la terre et tout ce qui s'y trouve, et c'est à Nous qu'ils seront ramenés.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmccxci{Et mentionne dans le Livre, Abraham. C'était un très véridique et un Prophète.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmccxcii{Lorsqu'il dit à son père: «O mon père, pourquoi adores-tu ce qui n'entend ni ne voit, et ne te profite en rien?\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmccxciii{O mon père, il m'est venu de la science ce que tu n'as pas reçu; suis-moi, donc, je te guiderai sur une voie droite.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmccxciv{O mon père, n'adore pas le Diable, car le Diable désobéit au Tout Miséricordieux.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmccxcv{O mon père, je crains qu'un châtiment venant du Tout Miséricordieux ne te touche et que tu ne deviennes un allié du Diable».\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmccxcvi{Il dit: «O Abraham, aurais-tu du dédain pour mes divinités? Si tu ne cesses pas, certes je te lapiderai, éloigne-toi de moi pour bien longtemps».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmccxcvii{«Paix sur toi», dit Abraham. «J'implorerai mon Seigneur de te pardonner car Il m'a toujours comblé de Ses bienfaits.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmccxcviii{Je me sépare de vous, ainsi que de ce que vous invoquez, en dehors d'Allah, et j'invoquerai mon Seigneur. J'espère ne pas être malheureux dans mon appel à mon Seigneur».\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmccxcix{Puis, lorsqu'il se fut séparé d'eux et de ce qu'ils adoraient en dehors d'Allah, Nous lui fîmes don d'Isaac et de Jacob; et de chacun Nous fîmes un prophète.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmccc{Et Nous leur donnâmes de par Notre miséricorde, et Nous leur accordâmes un langage sublime de vérité.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmccci{Et mentionne dans le Livre Moïse. C'était vraiment un élu, et c'était un Messager et un prophète.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmcccii{Du côté droit du Mont (Sinaï) Nous l'appelâmes et Nous le fîmes approcher tel un confident.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmccciii{Et par Notre miséricorde, Nous lui donnâmes Aaron son frère comme prophète.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmccciv{Et mentionne Ismaël, dans le Livre. Il était fidèle à ses promesses; et c'était un Messager et un prophète.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmcccv{Et il commandait à sa famille la prière et la Zakât; et il était agréé auprès de son Seigneur.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmcccvi{Et mentionne Idris, dans le Livre. C'était un véridique et un prophète.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmcccvii{Et Nous l'élevâmes à un haut rang.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmcccviii{Voilà ceux qu'Allah a comblés de faveurs, parmi les prophètes, parmi les descendants d'Adam, et aussi parmi ceux que Nous avons transportés en compagnie de Noé, et parmi la descendance d'Abraham et d'Israël, et parmi ceux que Nous avons guidés et choisis. Quand les versets du Tout Miséricordieux leur étaient récités, ils tombaient prosternés en pleurant.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmcccix{Puis leur succédèrent des générations qui délaissèrent la prière et suivirent leurs passions. Ils se trouveront en perdition,\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmcccx{sauf celui qui se repent, croit et fait le bien: ceux-là entreront dans le Paradis et ne seront point lésés,\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmcccxi{aux jardins du séjour (éternel) que le Tout Miséricordieux a promis à Ses serviteurs, [qui ont cru] au mystère. Car Sa promesse arrivera sans nul doute.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmcccxii{On n'y entend nulle parole insignifiante; seulement: «Salâm»; et ils auront là leur nourriture, matin et soir.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmcccxiii{Voilà le Paradis dont Nous ferons hériter ceux de Nos serviteurs qui auront été pieux.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmcccxiv{«Nous ne descendons que sur ordre de ton Seigneur. A Lui tout ce qui est devant nous, tout ce qui est derrière nous et tout ce qui est entre les deux. Ton Seigneur n'oublie rien.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmcccxv{Il est le Seigneur des cieux et de la terre et de tout ce qui est entre eux. Adore-Le donc, et sois constant dans Son adoration. Lui connais-tu un homonyme?»\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmcccxvi{Et l'homme dit: «Une fois mort, me sortira-t-on vivant?»\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmcccxvii{L'homme ne se rappelle-t-il pas qu'avant cela, c'est Nous qui l'avons créé, alors qu'il n'était rien?\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmcccxviii{Par ton Seigneur! Assurément, Nous les rassemblerons, eux et les diables. Puis, Nous les placerons autour de l'Enfer, agenouillés.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmcccxix{Ensuite, Nous arracherons de chaque groupe ceux d'entre eux qui étaient les plus obstinés contre le Tout Miséricordieux.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmcccxx{Puis nous sommes Le meilleur à savoir ceux qui méritent le plus d'y être brûlés.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmcccxxi{Il n'y a personne parmi vous qui ne passera pas par [L'Enfer]: Car [il s'agit là] pour ton Seigneur d'une sentence irrévocable.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmcccxxii{Ensuite, Nous délivrerons ceux qui étaient pieux et Nous y laisserons les injustes agenouillés.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmcccxxiii{Et lorsque Nos versets évidents leur sont récités les mécréants disent à ceux qui croient: «Lequel des deux groupes a la situation la plus confortable et la meilleure compagnie?»\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmcccxxiv{Combien de générations, avant eux, avons-Nous fait périr, qui les surpassaient en biens et en apparence?\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmcccxxv{Dis: «Celui qui est dans l'égarement, que le Tout Miséricordieux prolonge sa vie pour un certain temps, jusqu'à ce qu'ils voient soit le châtiment, soit l'Heure dont ils sont menacés. Alors, ils sauront qui a la pire situation et la troupe la plus faible».\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmcccxxvi{Allah accroît la rectitude de ceux qui suivent le bon chemin, et les bonnes œuvres durables méritent auprès de ton Seigneur une meilleure récompense et une meilleure destination.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmcccxxvii{As-tu vu celui qui ne croit pas à Nos versets et dit: «On me donnera certes des biens et des enfants»?\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmcccxxviii{Est-il au courant de l'Inconnaissable ou a-t-il pris un engagement avec le Tout Miséricordieux?\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmcccxxix{Bien au contraire! Nous enregistrerons ce qu'il dit et accroîtrons son châtiment.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmcccxxx{C'est Nous qui hériterons ce dont il parle, tandis qu'il viendra à Nous, tout seul.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmcccxxxi{Ils ont adopté des divinités en dehors d'Allah pour qu'ils leur soient des protecteurs (contre le châtiment).\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmcccxxxii{Bien au contraire! [ces divinités] renieront leur adoration et seront pour eux des adversaires.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmcccxxxiii{N'as-tu pas vu que Nous avons envoyé contre les mécréants des diables qui les excitent furieusement [à désobéir]?\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmcccxxxiv{Ne te hâte donc pas contre eux: Nous tenons un compte précis de [tous leurs actes].\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmcccxxxv{(Rappelle-toi) le jour où Nous rassemblerons les pieux sur des montures et en grande pompe, auprès du Tout Miséricordieux,\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmcccxxxvi{et pousserons les criminels à l'Enfer comme (un troupeau) à l'abreuvoir,\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmcccxxxvii{ils ne disposeront d'aucune intercession, sauf celui qui aura pris un engagement avec le Tout Miséricordieux.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmcccxxxviii{Et ils ont dit: «Le Tout Miséricordieux S'est attribué un enfant!»\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmcccxxxix{Vous avancez certes là une chose abominable!\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmcccxl{Peu s'en faut que les cieux ne s'entrouvrent à ces mots, que la terre ne se fende et que les montagnes ne s'écroulent,\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmcccxli{du fait qu'ils ont attribué un enfant au Tout Miséricordieux,\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmcccxlii{alors qu'il ne convient nullement au Tout Miséricordieux d'avoir un enfant!\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmcccxliii{Tous ceux qui sont dans les cieux et sur la terre se rendront auprès du Tout Miséricordieux, [sans exception], en serviteurs.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmcccxliv{Il les a certes dénombrés et bien comptés.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mmcccxlv{Et au Jour de la Résurrection, chacun d'eux se rendra seul auprès de Lui.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mmcccxlvi{A ceux qui croient et font de bonnes œuvres, le Tout Miséricordieux accordera Son amour.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mmcccxlvii{Nous l'avons rendu (le Coran) facile [à comprendre] en ta langue, afin que tu annonces par lui la bonne nouvelle aux gens pieux, et que, tu avertisses un peuple irréductible.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mmcccxlviii{Que de générations avant eux avons-Nous fait périr! En retrouves-tu un seul individu? ou en entends-tu le moindre murmure?\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mmcccxlix{\basmalahfr Tâ-Hâ.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmcccl{Nous n'avons point fait descendre sur toi le Coran pour que tu sois malheureux,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmcccli{si ce n'est qu'un Rappel pour celui qui redoute (Allah),\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmccclii{(et comme) une révélation émanant de Celui qui a créé la terre et les cieux sublimes.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmcccliii{Le Tout Miséricordieux S'est établi «Istawâ» sur le Trône.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmcccliv{A Lui appartient ce qui est dans les cieux, sur la terre, ce qui est entre eux et ce qui est sous le sol humide.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmccclv{Et si tu élèves la voix, Il connaît certes les secrets, même les plus cachés.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmccclvi{Allah! Point de divinité que Lui! Il possède les noms les plus beaux.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmccclvii{Le récit de Moïse t'est-il parvenu?\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmccclviii{Lorsqu'il vit du feu, il dit à sa famille: «Restez ici! Je vois du feu de loin; peut-être vous en apporterai-je un tison, ou trouverai-je auprès du feu de quoi me guider».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmccclix{Puis, lorsqu'il y arriva, il fut interpellé: «Moïse!\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmccclx{Je suis ton Seigneur. Enlève tes sandales: car tu es dans la vallée sacrée, Tuwâ.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmccclxi{Moi, Je t'ai choisi. Ecoute donc ce qui va être révélé.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmccclxii{Certes, c'est Moi Allah: point de divinité que Moi. Adore-Moi donc et accomplis la Salât pour te souvenir de Moi.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmccclxiii{L'Heure va certes arriver. Je la cache à peine, pour que chaque âme soit rétribuée selon ses efforts.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmccclxiv{Que celui qui n'y croit pas et qui suit sa propre passion ne t'en détourne pas. Sinon tu périras.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmccclxv{Et qu'est-ce qu'il y a dans ta main droite, ô Moïse?»\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmccclxvi{Il dit: «C'est mon bâton sur lequel je m'appuie, qui me sert à effeuiller (les arbres) pour mes moutons et j'en fais d'autres usages».\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmccclxvii{[Allah lui] dit: «Jette-le, O Moïse».\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmccclxviii{Il le jeta: et le voici un serpent qui rampait.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmccclxix{[Allah] dit: «Saisis-le et ne crains rien: Nous le ramènerons à son premier état.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmccclxx{Et serre ta main sous ton aisselle: elle en sortira blanche sans aucun mal, et ce sera là un autre prodige,\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmccclxxi{afin que Nous te fassions voir de Nos prodiges les plus importants.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmccclxxii{Rends-toi auprès de Pharaon car il a outrepassé toute limite.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmccclxxiii{[Moïse] dit: «Seigneur, ouvre-moi ma poitrine,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmccclxxiv{et facilite ma mission,\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmccclxxv{et dénoue un nœud en ma langue,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmccclxxvi{afin qu'ils comprennent mes paroles,\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmccclxxvii{et assigne-moi un assistant de ma famille:\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmccclxxviii{Aaron, mon frère,\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmccclxxix{accrois par lui ma force!\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmccclxxx{et associe-le à ma mission,\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmccclxxxi{afin que nous Te glorifions beaucoup,\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmccclxxxii{et que nous T'invoquions beaucoup.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmccclxxxiii{Et Toi, certes, Tu es Très Clairvoyant sur nous».\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmccclxxxiv{[Allah] dit: «Ta demande est exaucée, ô Moïse.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmccclxxxv{Et Nous t'avons déjà favorisé une première fois\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmccclxxxvi{lorsque Nous révélâmes à ta mère ce qui fut révélé:\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmccclxxxvii{«Mets-le dans le coffret, puis jette celui-ci dans les flots pour qu'ensuite le fleuve le lance sur la rive; un ennemi à Moi et à lui le prendra». Et J'ai répandu sur toi une affection de Ma part, afin que tu sois élevé sous Mon œil.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmccclxxxviii{Et vœilà que ta sœur (te suivait en) marchant et disait: «Puis-je vous indiquer quelqu'un qui se chargera de lui?» Ainsi, Nous te rapportâmes à ta mère afin que son oil se réjouisse et qu'elle ne s'afflige plus. Tu tuas ensuite un individu; Nous te sauvâmes des craintes qui t'oppressaient; et Nous t'imposâmes plusieurs épreuves. Puis tu demeuras des années durant chez les habitants de Madyan. Ensuite tu es venu, ô Moïse, conformément à un décret.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmccclxxxix{Et je t'ai assigné à Moi-Même.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmcccxc{Pars, toi et ton frère, avec Mes prodiges; et ne négligez pas de M'invoquer.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmcccxci{Allez vers Pharaon: il s'est vraiment rebellé.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmcccxcii{Puis, parlez-lui gentiment. Peut-être se rappellera-t-il ou [Me] craindra-t-il?\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmcccxciii{Ils dirent: «O notre Seigneur, nous craignons qu'il ne nous maltraite indûment, ou qu'il dépasse les limites».\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmcccxciv{Il dit: «Ne craignez rien. Je suis avec vous: J'entends et Je vois.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmcccxcv{Allez donc chez lui; puis, dites-lui: «Nous sommes tous deux, les messagers de ton Seigneur. Envoie donc les Enfants d'Israël en notre compagnie et ne les châtie plus. Nous sommes venus à toi avec une preuve de la part de ton Seigneur. Et que la paix soit sur quiconque suit le droit chemin!\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmcccxcvi{Il nous a été révélé que le châtiment est pour celui qui refuse d'avoir foi et qui tourne le dos».\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmcccxcvii{Alors [Pharaon] dit: «Qui donc est votre Seigneur, ô Moïse?»\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmcccxcviii{«Notre Seigneur, dit Moïse, est Celui qui a donné à chaque chose sa propre nature puis l'a dirigée».\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmcccxcix{«Qu'en est-il donc des générations anciennes?» dit Pharaon.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmcd{Moïse dit: «La connaissance de leur sort est auprès de mon Seigneur, dans un livre. Mon Seigneur [ne commet] ni erreur ni oubli.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmcdi{C'est Lui qui vous a assigné la terre comme berceau et vous y a tracé des chemins; et qui du ciel a fait descendre de l'eau avec laquelle Nous faisons germer des couples de plantes de toutes sortes.»\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmcdii{«Mangez et faites paître votre bétail». Voilà bien là des signes pour les doués d'intelligence.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmcdiii{C'est d'elle (la terre) que Nous vous avons créés, et en elle Nous vous retournerons, et d'elle Nous vous ferons sortir une fois encore.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmcdiv{Certes Nous lui avons montré tous Nos prodiges; mais il les a démentis et a refusé (de croire).\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmcdv{Il dit: «Es-tu venu à nous, ô Moïse, pour nous faire sortir de notre terre par ta magie?\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmcdvi{Nous t'apporterons assurément une magie semblable. Fixe entre nous et toi un rendez-vous auquel ni nous ni toi ne manquerons, dans un lieu convenable».\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmcdvii{Alors Moïse dit: «Votre rendez-vous, c'est le jour de la fête. Et que les gens se rassemblent dans la matinée».\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmcdviii{Pharaon, donc, se retira. Ensuite il rassembla sa ruse puis vint (au rendez-vous).\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmcdix{Moïse leur dit: «Malheur à vous! Ne forgez pas de mensonge contre Allah: sinon par un châtiment Il vous anéantira. Celui qui forge (un mensonge) est perdu».\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmcdx{Là-dessus, ils se mirent à disputer entre eux de leur affaire et tinrent secrètes leurs discussions.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmcdxi{Ils dirent: «Voici deux magiciens qui, par leur magie, veulent vous faire abandonner votre terre et emporter votre doctrine idéale.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmcdxii{Rassemblez donc votre ruse puis venez en rangs serrés. Et celui qui aura le dessus aujourd'hui aura réussi».\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmcdxiii{Ils dirent: «O Moïse, ou tu jettes, [le premier ton bâton] ou que nous soyons les premiers à jeter?»\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmcdxiv{Il dit: «Jetez plutôt». Et voilà que leurs cordes et leurs bâtons lui parurent ramper par l'effet de leur magie.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmcdxv{Moïse ressentit quelque peur en lui-même.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmcdxvi{Nous lui dîmes: «N'aie pas peur, c'est toi qui auras le dessus.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmcdxvii{Jette ce qu'il y a dans ta main droite; cela dévorera ce qu'ils ont fabriqué. Ce qu'ils ont fabriqué n'est qu'une ruse de magicien; et le magicien ne réussit pas, où qu'il soit».\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmcdxviii{Les magiciens se jetèrent prosternés, disant: «Nous avons foi en le Seigneur d'Aaron et de Moïse».\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmcdxix{Alors Pharaon dit: «Avez-vous cru en lui avant que je ne vous y autorise? C'est lui votre chef qui vous a enseigné la magie. Je vous ferai sûrement, couper mains et jambes opposées, et vous ferai crucifier aux troncs des palmiers, et vous saurez, avec certitude, qui de nous est plus fort en châtiment et qui est le plus durable».\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmcdxx{«Par celui qui nous a créés, dirent-ils, nous ne te préférerons jamais à ce qui nous est parvenu comme preuves évidentes. Décrète donc ce que tu as à décréter. Tes décrets ne touchent que cette présente vie.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmcdxxi{Nous croyons en notre Seigneur, afin qu'Il nous pardonne nos fautes ainsi que la magie à laquelle tu nous as contraints». Et Allah est meilleur et éternel.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmcdxxii{Quiconque vient en criminel à son Seigneur, aura certes l'Enfer où il ne meurt ni ne vit.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmcdxxiii{Et quiconque vient auprès de Lui en croyant, après avoir fait de bonnes œuvres, voilà donc ceux qui auront les plus hauts rangs,\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmcdxxiv{les jardins du séjour (éternel), sous lesquels coulent les ruisseaux, où ils demeureront éternellement. Et voilà la récompense de ceux qui se purifient [de la mécréance et des péchés].\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmcdxxv{Nous révélâmes à Moïse: «Pars la nuit, à la tête de Mes serviteurs, puis, trace-leur un passage à sec dans la mer: sans craindre une poursuite et sans éprouver aucune peur».\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmcdxxvi{Pharaon les poursuivit avec ses armées. La mer les submergea bel et bien.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmcdxxvii{Pharaon égara ainsi son peuple et ne le mît pas sur le droit chemin.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmcdxxviii{O Enfants d'Israël, Nous vous avons déjà délivrés de votre ennemi, et Nous vous avons donné rendez-vous sur le flanc droit du Mont. Et Nous avons fait descendre sur vous la manne et les cailles.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmcdxxix{«Mangez des bonnes choses que Nous vous avons attribuées et ne vous montrez pas ingrats, sinon Ma colère s'abattra sur vous: et celui sur qui Ma colère s'abat, va sûrement vers l'abîme.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmcdxxx{Et je suis Grand Pardonneur à celui qui se repent, croit, fait bonne œuvre, puis se met sur le bon chemin».\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmcdxxxi{«Pourquoi Moïse t'es-tu hâté de quitter ton peuple?»\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmcdxxxii{Ils sont là sur mes traces, dit Moïse. Et je me suis hâté vers Toi, Seigneur, afin que Tu sois satisfait.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmcdxxxiii{Allah dit: «Nous avons mis ton peuple à l'épreuve après ton départ. Et le Sâmirî les a égarés».\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmcdxxxiv{Moïse retourna donc vers son peuple, courroucé et chagriné; il dit: «O mon peuple, votre Seigneur ne vous a-t-Il pas déjà fait une belle promesse? L'alliance a-t-elle donc été trop longue pour vous? ou avez-vous désiré que la colère de votre Seigneur s'abatte sur vous, pour avoir trahi votre engagement envers moi?»\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmcdxxxv{Ils dirent: «Ce n'est pas de notre propre gré que nous avons manqué à notre engagement envers toi. Mais nous fûmes chargés de fardeaux d'ornements du peuple (de Pharaon); nous les avons donc jetés (sur le feu) tout comme le Sâmirî les a lancés.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmcdxxxvi{Puis il en a fait sortir pour eux un veau, un corps à mugissement. Et ils ont dit: «C'est votre divinité et la divinité de Moïse; il a donc oublié»!\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmcdxxxvii{Quoi! Ne voyaient-ils pas qu'il [le veau] ne leur rendait aucune parole et qu'il ne possédait aucun moyen de leur nuire ou de leur faire du bien?\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmcdxxxviii{Certes, Aaron leur avait bien dit auparavant: «O mon peuple, vous êtes tombés dans la tentation (à cause du veau). Or, c'est le Tout Miséricordieux qui est vraiment votre Seigneur. Suivez-moi donc et obéissez à mon commandement».\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmcdxxxix{Ils dirent: «Nous continuerons à y être attachés, jusqu'à ce que Moïse retourne vers nous».\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmcdxl{Alors [Moïse] dit: «Qu'est-ce qui t'a empêché, Aaron, quand tu les as vus s'égarer,\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmcdxli{de me suivre? As-tu donc désobéi à mon commandement?»\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmcdxlii{[Aaron] dit: «O fils de ma mère, ne me prends ni par la barbe ni par la tête. Je craignais que tu ne dises: «Tu as divisé les enfants d'Israël et tu n'as pas observé mes ordres».\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mmcdxliii{Alors [Moïse] dit: «Quel a été ton dessein? O Sâmirî?»\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mmcdxliv{Il dit: «J'ai vu ce qu'ils n'ont pas vu: j'ai donc pris une poignée de la trace de l'Envoyé; puis, je l'ai lancée. Voilà ce que mon âme m'a suggéré».\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mmcdxlv{«Va-t-en, dit [Moïse]. Dans la vie, tu auras à dire (à tout le monde): «Ne me touchez pas!» Et il y aura pour toi un rendez-vous que tu ne pourras manquer. Regarde ta divinité que tu as adorée avec assiduité. Nous la brûlerons certes, et ensuite, nous disperserons [sa cendre] dans les flots.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mmcdxlvi{En vérité, votre seul Dieu est Allah en dehors de qui il n'y a point de divinité. De Sa science Il embrasse tout.\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mmcdxlvii{C'est ainsi que Nous te racontons les récits de ce qui s'est passé. C'est bien un rappel de Notre part que Nous t'avons apporté.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mmcdxlviii{Quiconque s'en détourne (de ce Coran), portera au jour de la résurrection un fardeau;\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mmcdxlix{ils resteront éternellement dans cet état, et quel mauvais fardeau pour eux au Jour de la Résurrection,\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mmcdl{Le jour où l'on soufflera dans la Trompe, ce jour-là Nous rassemblerons les criminels tout bleus (de peur)!\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mmcdli{Ils chuchoteront entre eux: «Vous n'êtes restés là que dix [jours]!»\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mmcdlii{Nous connaissons parfaitement ce qu'ils diront lorsque l'un d'entre eux dont la conduite est exemplaire dira: «Vous n'êtes restés qu'un jour».\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mmcdliii{Et ils t'interrogent au sujet des montagnes. Dis: «Mon Seigneur les dispersera comme la poussière,\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mmcdliv{et les laissera comme une plaine dénudée\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mmcdlv{dans laquelle tu ne verras ni tortuosité, ni dépression.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mmcdlvi{Ce jour-là, ils suivront le Convocateur sans tortuosité; et les voix baisseront devant le Tout Miséricordieux. Tu n'entendras alors qu'un chuchotement.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mmcdlvii{Ce jour-là, l'intercession ne profitera qu'à celui auquel le Tout Miséricordieux aura donné Sa permission et dont Il agréera la parole.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mmcdlviii{Il connaît ce qui est devant eux et ce qui est derrière eux, alors qu'eux-mêmes ne Le cernent pas de leur science.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mmcdlix{Et les visages s'humilieront devant Le Vivant, Celui qui subsiste par Lui-même «al-Qayyûm», et malheureux sera celui qui [se présentera devant Lui] chargé d'une iniquité.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mmcdlx{Et quiconque aura fait de bonnes œuvres tout en étant croyant, ne craindra ni injustice ni oppression.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@mmcdlxi{C'est ainsi que nous l'avons fait descendre un Coran en [langue] arabe, et Nous y avons multiplié les menaces, afin qu'ils deviennent pieux ou qu'il les incite à s'exhorter?\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@mmcdlxii{Que soit éxalté Allah, le Vrai Souverain! Ne te hâte pas [de réciter] le Coran avant que ne te soit achevée sa révélation. Et dis: «O mon Seigneur, accroît mes connaissances!»\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@mmcdlxiii{En effet, Nous avons auparavant fait une recommandation à Adam; mais il oublia; et Nous n'avons pas trouvé chez lui de résolution ferme.\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@mmcdlxiv{Et quand Nous dîmes aux Anges: «Prosternez-vous devant Adam», ils se prosternèrent, excepté Iblis qui refusa.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@mmcdlxv{Alors Nous dîmes: «O Adam, celui-là est vraiment un ennemi pour toi et ton épouse. Prenez garde qu'il vous fasse sortir du Paradis, car alors tu seras malheureux.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@mmcdlxvi{Car tu n'y auras pas faim ni ne seras nu,\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@mmcdlxvii{tu n'y auras pas soif ni ne seras frappé par l'ardeur du soleil».\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@mmcdlxviii{Puis le Diable le tenta en disant: «O Adam, t'indiquerai-je l'arbre de l'éternité et un royaume impérissable?»\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@mmcdlxix{Tous deux (Adam et Eve) en mangèrent. Alors leur apparut leur nudité. Ils se mirent à se couvrir avec des feuilles du paradis. Adam désobéit ainsi à son Seigneur et il s'égara.\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@mmcdlxx{Son Seigneur l'a ensuite élu, agréé son repentir et l'a guidé.\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@mmcdlxxi{Il dit: «Descendez d'ici, (Adam et Eve), [Vous serez] tous (avec vos descendants) ennemis les uns des autres. Puis, si jamais un guide vous vient de Ma part, quiconque suit Mon guide ne s'égarera ni ne sera malheureux.\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@mmcdlxxii{Et quiconque se détourne de Mon Rappel, mènera certes, une vie pleine de gêne, et le Jour de la Résurrection Nous l'amènerons aveugle au rassemblement».\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@mmcdlxxiii{Il dira: «O mon Seigneur, pourquoi m'as-Tu amené aveugle alors qu'auparavant je voyais?»\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@mmcdlxxiv{[Allah lui] dira: «De même que Nos Signes (enseignements) t'étaient venus et que tu les as oubliés, ainsi aujourd'hui tu es oublié».\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@mmcdlxxv{Ainsi sanctionnons-nous l'outrancier qui ne croit pas aux révélations de son Seigneur. Et certes, le châtiment de l'au-delà est plus sévère et plus durable.\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@mmcdlxxvi{Cela ne leur a-t-il pas servi de direction, que Nous ayons fait périr avant eux tant de générations dans les demeures desquelles ils marchent maintenant? Voilà bien là des leçons pour les doués d'intelligence!\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@mmcdlxxvii{N'eussent-été un décret préalable de ton Seigneur et aussi un terme déjà fixé, (leur châtiment) aurait été inévitable (et immédiat).\qt@no{(129)}}
\qt@newcmd\qurantrans@fr@mmcdlxxviii{Supporte patiemment ce qu'ils disent et célèbre Sa louange, avant le lever du soleil, avant son coucher et pendant la nuit; et exalte Sa Gloire aux extrémités du jour. Peut-être auras-tu satisfaction:\qt@no{(130)}}
\qt@newcmd\qurantrans@fr@mmcdlxxix{Et ne tends point les yeux vers ce dont Nous avons donné jouissance temporaire à certains groupes d'entre eux, comme décor de la vie présente, afin de les éprouver par cela. Ce qu'Allah fournit (au Paradis) est meilleur et plus durable.\qt@no{(131)}}
\qt@newcmd\qurantrans@fr@mmcdlxxx{Et commande à ta famille la Salât, et fais-la avec persévérance. Nous ne te demandons point de nourriture: c'est à Nous de te nourrir. La bonne fin est réservée à la piété.\qt@no{(132)}}
\qt@newcmd\qurantrans@fr@mmcdlxxxi{Et ils disent: «Pourquoi ne nous apporte-t-il pas un miracle de son Seigneur? La Preuve (le Coran) de ce que contiennent les Ecritures anciennes ne leur est-elle pas venue?\qt@no{(133)}}
\qt@newcmd\qurantrans@fr@mmcdlxxxii{Et si Nous les avions fait périr par un châtiment avant lui [Muhammad], ils auraient certainement dit: «O notre Seigneur, pourquoi ne nous as-Tu pas envoyé de Messager? Nous aurions alors suivi Tes enseignements avant d'avoir été humiliés et jetés dans l'ignominie».\qt@no{(134)}}
\qt@newcmd\qurantrans@fr@mmcdlxxxiii{Dis: «Chacun attend. Attendez donc! Vous saurez bientôt qui sont les gens du droit chemin et qui sont les bien-guidés».\qt@no{(135)}}
\qt@newcmd\qurantrans@fr@mmcdlxxxiv{\basmalahfr [L'échéance] du règlement de leur compte approche pour les hommes, alors que dans leur insouciance ils s'en détournent.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmcdlxxxv{Aucun rappel [de révélation] récente ne leur vient de leur Seigneur, sans qu'ils ne l'entendent en s'amusant,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmcdlxxxvi{leurs cœurs distraits; et les injustes tiennent des conversations secrètes et disent: «Ce n'est là qu'un être humain semblable à vous? Allez-vous donc vous adonner à la magie alors que vous voyez clair?»\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmcdlxxxvii{Il a répondu: «Mon Seigneur sait tout ce qui se dit au ciel et sur la terre; et Il est l'Audient, l'Omniscient».\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmcdlxxxviii{Mais ils dirent: «Voilà plutôt un amas de rêves! Ou bien Il l'a inventé. Ou, c'est plutôt un poète. Qu'il nous apporte donc un signe [identique] à celui dont furent chargés les premiers envoyés».\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmcdlxxxix{Pas une seule cité parmi celles que Nous avons fait périr avant eux n'avait cru [à la vue des miracles]. Ceux-ci croiront-ils donc?\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmcdxc{Nous n'avons envoyé avant toi que des hommes à qui Nous faisions des révélations. Demandez donc aux érudits du Livre, si vous ne savez pas.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmcdxci{Et Nous n'en n'avons pas fait des corps qui ne consommaient pas de nourriture. Et ils n'étaient pas éternels.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmcdxcii{Puis Nous réalisâmes la promesse (qui leur avait été faite). Nous les sauvâmes avec ceux que Nous voulûmes [sauver]. Et Nous fîmes périr les outranciers.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmcdxciii{Nous avons assurément fait descendre vers vous un livre où se trouve votre rappel [ou votre renom]. Ne comprenez-vous donc pas?\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmcdxciv{Et que de cités qui ont commis des injustices, Nous avons brisées; et Nous avons créé d'autres peuples après eux.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmcdxcv{Quand [ces gens] sentirent Notre rigueur ils s'en enfuirent hâtivement.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmcdxcvi{Ne galopez point. Retournez plutôt au grand luxe où vous étiez et dans vos demeures, afin que vous soyez interrogés.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmcdxcvii{Ils dirent: «Malheur à nous! Nous étions vraiment injustes».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmcdxcviii{Telle ne cessa d'être leur lamentation jusqu'à ce que Nous les eûmes moissonnés et éteints.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmcdxcix{Ce n'est pas par jeu que Nous avons créé le ciel et la terre et ce qui est entre eux.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmd{Si Nous avions voulu prendre une distraction, Nous l'aurions prise de Nous-mêmes, si vraiment Nous avions voulu le faire.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmdi{Bien au contraire, Nous lançons contre le faux la vérité qui le subjugue, et le voilà qui disparaît. Et malheur à vous pour ce que vous attribuez [injustement à Allah].\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmdii{A Lui seul appartiennent tous ceux qui sont dans les cieux et sur la terre. Ceux qui sont auprès de Lui [les Anges] ne se considèrent point trop grands pour L'adorer et ne s'en lassent pas.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmdiii{Ils exaltent Sa Gloire nuit et jour et ne s'interrompent point.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmdiv{Ont-ils pris des divinités qui peuvent ressusciter (les morts) de la terre?\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmdv{S'il y avait dans le ciel et la terre des divinités autres qu'Allah, tous deux seraient certes dans le désordre. Gloire, donc à Allah, Seigneur du Trône; Il est au-dessus de ce qu'ils Lui attribuent!\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmdvi{Il n'est pas interrogé sur ce qu'Il fait, mais ce sont eux qui devront rendre compte [de leurs actes].\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmdvii{Ont-ils pris des divinités en dehors de Lui? Dis: «Apportez votre preuve». Ceci est la révélation de ceux qui sont avec moi et de ceux qui étaient avant moi. Mais la plupart d'entre eux ne connaissent pas la vérité et s'en écartent.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmdviii{Et Nous n'avons envoyé avant toi aucun Messager à qui Nous n'ayons révélé: «Point de divinité en dehors de Moi. Adorez-Moi donc».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmdix{Et ils dirent: «Le Tout Miséricordieux s'est donné un enfant». Pureté à Lui! Mais ce sont plutôt des serviteurs honorés.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmdx{Ils ne devancent pas Son Commandement et agissent selon Ses ordres.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmdxi{Il sait ce qui est devant eux et ce qui derrière eux. Et ils n'intercèdent qu'en faveur de ceux qu'Il a agréés [tout en étant] pénétrés de Sa crainte.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmdxii{Et quiconque d'entre eux dirait: «Je suis une divinité en dehors de Lui». Nous le rétribuerons de l'Enfer. C'est ainsi que Nous rétribuons les injustes.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmdxiii{Ceux qui ont mécru, n'ont-ils pas vu que les cieux et la terre formaient une masse compacte? Ensuite Nous les avons séparés et fait de l'eau toute chose vivante. Ne croiront-ils donc pas?\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmdxiv{Et Nous avons placé des montagnes fermes dans la terre, afin qu'elle ne s'ébranle pas en les [entraînant]. Et Nous y avons placé des défilés servant de chemins afin qu'ils se guident.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmdxv{Et Nous avons fait du ciel un toit protégé. Et cependant ils se détournent de ses merveilles.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmdxvi{Et c'est Lui qui a créé la nuit et le jour, le soleil et la lune; chacun voguant dans une orbite.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmdxvii{Et Nous n'avons attribué l'immortalité à nul homme avant toi. Est-ce que si tu meurs, toi, ils seront, eux, éternels?\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmdxviii{Toute âme doit goûter la mort. Nous vous éprouverons par le mal et par le bien [à titre] de tentation. Et c'est à Nous que vous serez ramenés.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmdxix{Quand les mécréants te voient, ils ne te prennent qu'en dérision (disant): «Quoi! Est-ce-là celui qui médit de vos divinités?» Et ils nient [tout] rappel du Tout Miséricordieux.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmdxx{L'homme a été créé prompt dans sa nature. Je vous montrerai Mes signes [la réalisation de Mes menaces]. Ne me hâtez donc pas.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmdxxi{Et ils disent: «A quand cette promesse si vous êtes véridiques?»\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmdxxii{Si [seulement] les mécréants connaissaient le moment où ils ne pourront empêcher le feu de leurs visages ni de leurs dos, et où ils ne seront point secourus.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmdxxiii{Mais non, cela leur viendra subitement et ils seront alors stupéfaits; ils ne pourront pas le repousser et on ne leur donnera pas de répit.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmdxxiv{On s'est moqué de messagers venus avant toi. Et ceux qui se sont moqués d'eux, se virent frapper de toutes parts par l'objet même de leurs moqueries.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmdxxv{Dis: «Qui vous protège la nuit et le jour, contre le [châtiment] du Tout Miséricordieux?» Pourtant ils se détournent du rappel de leur Seigneur.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmdxxvi{Ont-ils donc des divinités en dehors de Nous, qui peuvent les protéger? Mais celles-ci ne peuvent ni se secourir elles-mêmes, ni se faire assister contre Nous.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmdxxvii{Au contraire Nous avons accordé une jouissance [temporaire] à ceux-là comme à leurs ancêtres jusqu'à un âge avancé. Ne voient-ils pas que Nous venons à la terre que Nous réduisons de tous côtés? Seront-ils alors les vainqueurs?\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmdxxviii{Dis: «Je vous avertis par ce qui m'est révélé». Les sourds, cependant, n'entendent pas l'appel quand on les avertit.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmdxxix{Si un souffle du châtiment de ton Seigneur les effleurait, ils diraient alors: «Malheur à nous! Nous étions vraiment injustes».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmdxxx{Au Jour de la Résurrection, Nous placerons les balances exactes. Nulle âme ne sera lésée en rien, fût-ce du poids d'un grain de moutarde que Nous ferons venir. Nous suffisons largement pour dresser les comptes.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmdxxxi{Nous avons déjà apporté à Moïse et Aaron le Livre du discernement (la Thora) ainsi qu'une lumière et un rappel pour les gens pieux,\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmdxxxii{qui craignent leur Seigneur malgré qu'ils ne Le voient pas, et redoutent l'Heure (la fin du monde).\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmdxxxiii{Et ceci [le Coran] est un rappel béni que Nous avons fait descendre. Allez-vous donc le renier?\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmdxxxiv{En effet, Nous avons mis auparavant Abraham sur le droit chemin. Et Nous en avions bonne connaissance.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmdxxxv{Quand il dit à son père et à son peuple: «Que sont ces statues auxquelles vous vous attachez?»\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmdxxxvi{ils dirent: «Nous avons trouvé nos ancêtres les adorant».\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmdxxxvii{Il dit: «Certainement, vous avez été, vous et vos ancêtres, dans un égarement évident».\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmdxxxviii{Ils dirent: «Viens-tu à nous avec la vérité ou plaisantes-tu?»\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmdxxxix{Il dit: «Mais votre Seigneur est plutôt le Seigneur des cieux et de la terre, et c'est Lui qui les a créés. Et je suis un de ceux qui en témoignent.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmdxl{Et par Allah! Je ruserai certes contre vos idoles une fois que vous serez partis».\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmdxli{Il les mit en pièces, hormis [la statue] la plus grande. Peut-être qu'ils reviendraient vers elle.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmdxlii{Ils dirent: «Qui a fait cela à nos divinités? Il est certes parmi les injustes».\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmdxliii{(Certains) dirent: «Nous avons entendu un jeune homme médire d'elles; il s'appelle Abraham».\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmdxliv{Ils dirent: «Amenez-le sous les yeux des gens afin qu'ils puissent témoigner.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmdxlv{(Alors) ils dirent: «Est-ce toi qui as fait cela à nos divinités, Abraham?»\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmdxlvi{Il dit: «C'est la plus grande d'entre elles que voici, qui l'a fait. Demandez-leur donc, si elles peuvent parler».\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmdxlvii{Se ravisant alors, ils se dirent entre eux: «C'est vous qui êtes les vrais injustes».\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmdxlviii{Puis ils firent volte-face et dirent: «Tu sais bien que celles-ci ne parlent pas».\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmdxlix{Il dit: «Adorez-vous donc, en dehors d'Allah, ce qui ne saurait en rien vous être utile ni vous nuire non plus.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmdl{Fi de vous et de ce que vous adorez en dehors d'Allah! Ne raisonnez-vous pas?»\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmdli{Ils dirent: «Brûlez-le. Secourez vos divinités si vous voulez faire quelque chose (pour elles)».\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmdlii{Nous dîmes: «O feu, sois pour Abraham une fraîcheur salutaire».\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmdliii{Ils voulaient ruser contre lui, mais ce sont eux que Nous rendîmes les plus grands perdants.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmdliv{Et Nous le sauvâmes, ainsi que Lot, vers une terre que Nous avions bénie pour tout l'univers.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmdlv{Et Nous lui donnâmes Isaac et, de surcroît Jacob, desquels Nous fîmes des gens de bien.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmdlvi{Nous les fîmes des dirigeants qui guidaient par Notre ordre. Et Nous leur révélâmes de faire le bien, d'accomplir la prière et d'acquitter la Zakât. Et ils étaient Nos adorateurs.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmdlvii{Et Lot! Nous lui avons apporté la capacité de juger et le savoir, et Nous l'avons sauvé de la cité où se commettaient les vices; ces gens étaient vraiment des gens du mal, des pervers.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmdlviii{et Nous l'avons fait entrer en Notre miséricorde. Il était vraiment du nombre des gens de bien.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmdlix{Et Noé, quand auparavant il fit son appel. Nous l'exauçâmes et Nous le sauvâmes, ainsi que sa famille, de la grande angoisse,\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmdlx{et Nous le secourûmes contre le peuple qui traitait Nos prodiges de mensonges. Ils furent vraiment des gens du Mal. Nous les noyâmes donc tous.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmdlxi{Et David, et Salomon, quand ils eurent à juger au sujet d'un champ cultivé où des moutons appartenant à une peuplade étaient allés paître, la nuit. Et Nous étions témoin de leur jugement.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmdlxii{Nous la fîmes comprendre à Salomon. Et à chacun Nous donnâmes la faculté de juger et le savoir. Et Nous asservîmes les montagnes à exalter Notre Gloire en compagnie de David, ainsi que les oiseaux. Et c'est Nous qui sommes le Faiseur.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmdlxiii{Nous lui (David) apprîmes la fabrication des cottes de mailles afin qu'elles vous protègent contre vos violences mutuelles (la guerre). En êtes-vous donc reconnaissants?\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmdlxiv{Et (Nous avons soumis) à Salomon le vent impétueux qui, par son ordre, se dirigea vers la terre que Nous avions bénie. Et Nous sommes à même de tout savoir,\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmdlxv{et parmi les diables il en était qui plongeaient pour lui et faisaient d'autres travaux encore, et Nous les surveillions Nous-mêmes.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmdlxvi{Et Job, quand il implora son Seigneur: «Le mal m'a touché. Mais Toi, tu es le plus miséricordieux des miséricordieux»!\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmdlxvii{Nous l'exauçâmes, enlevâmes le mal qu'il avait, lui rendîmes les siens et autant qu'eux avec eux, par miséricorde de Notre part et en tant que rappel aux adorateurs.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmdlxviii{Et Ismaël, Idris, et Dûl-Kifl! qui étaient tous endurants;\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmdlxix{que Nous fîmes entrer en Notre miséricorde car ils étaient vraiment du nombre des gens de bien.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmdlxx{Et Dû'n-Nûn (Jonas) quand il partit, irrité. Il pensa que Nous N'allions pas l'éprouver. Puis il fit, dans les ténèbres, l'appel que voici: «Pas de divinité à part Toi! Pureté à Toi! J'ai été vraiment du nombre des injustes».\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmdlxxi{Nous l'exauçâmes et le sauvâmes de son angoisse. Et c'est ainsi que Nous sauvons les croyants.\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmdlxxii{Et Zacharie, quand il implora son Seigneur: «Ne me laisse pas seul, Seigneur, alors que Tu es le meilleur des héritiers».\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmdlxxiii{Nous l'exauçâmes, lui donnâmes Yahya et guérîmes son épouse. Ils concouraient au bien et Nous invoquaient par amour et par crainte. Et ils étaient humbles devant Nous.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmdlxxiv{Et celle [la vierge Marie] qui avait préservé sa chasteté! Nous insufflâmes en elle un souffle (de vie) venant de Nous et fîmes d'elle ainsi que de son fils, un signe [miracle] pour l'univers.\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmdlxxv{Certes, cette communauté qui est la vôtre est une communauté unique, et Je suis votre Seigneur. Adorez-Moi donc.\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmdlxxvi{Ils se sont divisés en sectes. Mais tous, retourneront à Nous.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmdlxxvii{Quiconque fait de bonnes œuvres tout en étant croyant, on ne méconnaîtra pas son effort, et Nous le lui inscrivons [à son actif].\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mmdlxxviii{Il est défendu [aux habitants] d'une cité que Nous avons fait périr de revenir [à la vie d'ici-bas]!\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mmdlxxix{Jusqu'à ce que soient relâchés les Yâjûj et les Mâjûj et qu'ils se précipiteront de chaque hauteur;\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mmdlxxx{c'est alors que la vraie promesse s'approchera, tandis que les regards de ceux qui ont mécru se figent: «Malheur à nous! Nous y avons été inattentifs. Bien plus, nous étions des injustes».\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mmdlxxxi{«Vous serez, vous et ce que vous adoriez en dehors d'Allah, le combustible de l'Enfer, vous vous y rendrez tous.\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mmdlxxxii{Si ceux-là étaient vraiment des divinités, ils n'y entreraient pas; et tous y demeureront éternellement.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mmdlxxxiii{Ils y pousseront des gémissements, et n'y entendront rien.\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mmdlxxxiv{En seront écartés, ceux à qui étaient précédemment promises de belles récompenses de Notre part.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mmdlxxxv{Ils n'entendront pas son sifflement et jouiront éternellement de ce que leurs âmes désirent.\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mmdlxxxvi{La grande terreur ne les affligera pas, et les Anges les accueilleront: «voici le jour qui vous a été promis».\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mmdlxxxvii{Le jour où Nous plierons le ciel comme on plie le rouleau des livres. Tout comme Nous avons commencé la première création, ainsi Nous la répéterons; c'est une promesse qui Nous incombe et Nous l'accomplirons!\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mmdlxxxviii{Et Nous avons certes écrit dans le Zabûr, après l'avoir mentionné (dans le Livre céleste), que la terre sera héritée par Mes bons serviteurs».\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mmdlxxxix{Il y a en cela [ces enseignements] une communication à un peuple d'adorateurs!\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mmdxc{Et Nous ne t'avons envoyé qu'en miséricorde pour l'univers.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mmdxci{Dis: «Voilà ce qui m'est révélé: Votre Dieu est un Dieu unique; Etes-vous Soumis?» [décidés à embrasser l'Islam]\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mmdxcii{Si ensuite ils se détournent dis alors: «Je vous ai avertis en toute équité; je ne sais si ce qui vous est promis est proche ou lointain.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mmdxciii{Il connaît ce que vous dites à haute voix et ce que vous cachez.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mmdxciv{Et je ne sais pas; ceci est peut-être une tentation pour vous et une jouissance pour un certain temps»!\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mmdxcv{Il dit: «Seigneur, juge en toute justice! Et Notre Seigneur le Tout Miséricordieux, c'est Lui dont le secours est imploré contre vos assertions».\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@mmdxcvi{\basmalahfr O hommes! Craignez votre Seigneur. Le séisme [qui précédera] l'Heure est une chose terrible.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmdxcvii{Le jour où vous le verrez, toute nourrice oubliera ce qu'elle allaitait, et toute femelle enceinte avortera de ce qu'elle portait. Et tu verras les gens ivres, alors qu'ils ne le sont pas. Mais le châtiment d'Allah est dur.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmdxcviii{Et il y a des gens qui discutent au sujet d'Allah sans aucune science, et qui suivent tout diable rebelle.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmdxcix{Il a été prescrit à l'égard de ce dernier qu'il égarera quiconque le prendra pour maître, et qu'il le guidera vers le châtiment de la fournaise.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmdc{O hommes! Si vous doutez au sujet de la Résurrection, c'est Nous qui vous avons créés de terre, puis d'une goutte de sperme, puis d'une adhérence puis d'un embryon [normalement] formé aussi bien qu'informe pour vous montrer [Notre Omnipotence] et Nous déposerons dans les matrices ce que Nous voulons jusqu'à un terme fixé. Puis Nous vous en sortirons [à l'état] de bébé, pour qu'ensuite vous atteignez votre maturité. Il en est parmi vous qui meurent [jeunes] tandis que d'autres parviennent au plus vil de l'âge si bien qu'ils ne savent plus rien de ce qu'ils connaissaient auparavant. De même tu vois la terre desséchée: dès que Nous y faisons descendre de l'eau elle remue, se gonfle, et fait pousser toutes sortes de splendides couples de végétaux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmdci{Il en est ainsi parce qu'Allah est la vérité; et c'est Lui qui rend la vie aux morts; et c'est Lui qui est Omnipotent.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmdcii{Et que l'Heure arrivera; pas de doute à son sujet, et qu'Allah ressuscitera ceux qui sont dans les tombeaux.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmdciii{Or, il y a des gens qui discutent au sujet d'Allah sans aucune science, ni guide, ni Livre pour les éclairer,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmdciv{affichant une attitude orgueilleuse pour égarer les gens du sentier d'Allah. A lui l'ignominie ici-bas; et Nous Lui ferons goûter le Jour de la Résurrection, le châtiment de la fournaise.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmdcv{Voilà, pour ce que tes deux mains ont préparé (ici-bas)! Cependant, Allah n'est point injuste envers Ses serviteurs.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmdcvi{Il en est parmi les gens qui adorent Allah marginalement. S'il leur arrive un bien, ils s'en tranquillisent, et s'il leur arrive une épreuve, ils détournent leur visage, perdant ainsi (le bien) de l'ici-bas et de l'au-delà. Telle est la perte évidente!\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmdcvii{Ils invoquent en dehors d'Allah, ce qui ne peut ni leur nuire ni leur profiter. Tel est l'égarement profond!\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmdcviii{Ils invoquent ce dont le mal est certainement plus proche que l'utilité. Quel mauvais allié, et quel mauvais compagnon!\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmdcix{Ceux qui croient et font de bonnes œuvres, Allah les fait entrer aux Jardins sous lesquels coulent les ruisseaux, car Allah fait certes ce qu'Il veut.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmdcx{Celui qui pense qu'Allah ne le secourra pas dans l'ici-bas et dans l'au-delà qu'il tende une corde jusqu'au ciel, puis qu'il la coupe, et qu'il voie si sa ruse va faire disparaître ce qui l'enrage.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmdcxi{C'est ainsi que Nous le fîmes descendre (Le Coran) en versets clairs et qu'Allah guide qui Il veut.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmdcxii{Certes, ceux qui ont cru, les Juifs, les Sabéens [les adorateurs des étoiles], les Nazaréens, les Mages et ceux qui donnent à Allah des associés, Allah tranchera entre eux le jour du Jugement, car Allah est certes témoin de toute chose.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmdcxiii{N'as-tu pas vu que c'est devant Allah que se prosternent tous ceux qui sont dans les cieux et tous ceux qui sont sur la terre, le soleil, la lune, les étoiles, les montagnes, les arbres, les animaux, ainsi que beaucoup de gens? Il y en a aussi beaucoup qui méritent le châtiment. Et quiconque Allah avilit n'a personne pour l'honorer, car Allah fait ce qu'il veut.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmdcxiv{Voici deux clans adverses qui disputaient au sujet de leur Seigneur. A ceux qui ne croient pas, on taillera des vêtements de feu, tandis que sur leurs têtes on versera de l'eau bouillante,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmdcxv{qui fera fondre ce qui est dans leurs ventres de même que leurs peaux.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmdcxvi{Et il y aura pour eux des maillets de fer.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmdcxvii{Toutes les fois qu'ils voudront en sortir (pour échapper) à la détresse, on les y remettra et (on leur dira): «Goûtez au châtiment de la Fournaise.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmdcxviii{Certes Allah introduit ceux qui croient et font de bonnes œuvres aux Jardins sous lesquels coulent les ruisseaux. Là, ils seront parés de bracelets d'or, et aussi de perles; et leurs vêtements y seront de soie.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmdcxix{Ils ont été guidés vers la bonne parole et ils ont été guidés vers le chemin Du Digne des louanges.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmdcxx{Mais ceux qui mécroient et qui obstruent le sentier d'Allah et celui de la Mosquée sacrée, que Nous avons établie pour les gens: aussi bien les résidents que ceux de passage... Quiconque cherche à y commettre un sacrilège injustement, Nous lui ferons goûter un châtiment douloureux,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmdcxxi{Et quand Nous indiquâmes pour Abraham le lieu de la Maison (La Kaaba) [en lui disant]: «Ne M'associe rien; et purifie Ma Maison pour ceux qui tournent autour, pour ceux qui s'y tiennent debout et pour ceux qui s'y inclinent et se prosternent».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmdcxxii{Et fais aux gens une annonce pour le Hajj. Ils viendront vers toi, à pied, et aussi sur toute monture, venant de tout chemin éloigné,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmdcxxiii{pour participer aux avantages qui leur ont été accordés et pour invoquer le nom d'Allah aux jours fixés, sur la bête de cheptel qu'Il leur a attribuée, «Mangez-en vous-mêmes et faites-en manger le besogneux misérable.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmdcxxiv{Puis qu'ils mettent fin à leurs interdits (qu'ils nettoient leurs corps), qu'ils remplissent leurs vœux, et qu'ils fassent les circuits autour de l'Antique Maison».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmdcxxv{Voilà [ce qui doit être observé] et quiconque prend en haute considération les limites sacrées d'Allah cela lui sera meilleur auprès de son Seigneur. Le bétail, sauf ce qu'on vous a cité, vous a été rendu licite. Abstenez-vous de la souillure des idoles et abstenez-vous des paroles mensongères.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmdcxxvi{(Soyez) exclusivement [acquis à la religion] d'Allah ne Lui associez rien; car quiconque associe à Allah, c'est comme s'il tombait du haut du ciel et que les oiseaux le happaient, ou que le vent le précipitait dans un abîme très profond.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmdcxxvii{Voilà [ce qui est prescrit]. Et quiconque exalte les injonctions sacrées d'Allah, s'inspire en effet de la piété des cœurs.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmdcxxviii{[De ces bêtes-là] vous tirez des avantages jusqu'à un terme fixé; puis son lieu d'immolation est auprès de l'Antique Maison.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmdcxxix{A chaque communauté, Nous avons assigné un rite sacrificiel, afin qu'ils prononcent le nom d'Allah sur la bête de cheptel qu'Il leur a attribuée. Votre Dieu est certes un Dieu unique. Soumettez-vous donc à Lui. Et fais bonne annonce à ceux qui s'humilient,\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmdcxxx{ceux dont les cœurs frémissent quand le nom d'Allah est mentionné, ceux qui endurent ce qui les atteint et ceux qui accomplissent la Salât et dépensent de ce que Nous leur avons attribué.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmdcxxxi{Nous vous avons désigné les chameaux (et les vaches) bien portants pour certains rites établis par Allah. Il y a en eux pour vous un bien. Prononcez donc sur eux le nom d'Allah, quand ils ont eu la patte attachée, [prêts à être immolés]. Puis, lorsqu'ils gisent sur le flanc, mangez-en, et nourrissez-en le besogneux discret et le mendiant. Ainsi Nous vous les avons assujettis afin que vous soyez reconnaissants.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmdcxxxii{Ni leurs chairs ni leurs sangs n'atteindront Allah, mais ce qui L'atteint de votre part c'est la piété. Ainsi vous les a-t-Il assujettis afin que vous proclamiez la grandeur d'Allah, pour vous avoir mis sur le droit chemin. Et annonce la bonne nouvelle aux bienfaisants.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmdcxxxiii{Allah prend la défense de ceux qui croient. Allah n'aime aucun traître ingrat.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmdcxxxiv{Autorisation est donnée à ceux qui sont attaqués (de se défendre) - parce que vraiment ils sont lésés; et Allah est certes Capable de les secourir -\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmdcxxxv{ceux qui ont été expulsés de leurs demeures, - contre toute justice, simplement parce qu'ils disaient: «Allah est notre Seigneur». - Si Allah ne repoussait pas les gens les uns par les autres, les ermitages seraient démolis, ainsi que les églises, les synagogues et les mosquées où le nom d'Allah est beaucoup invoqué. Allah soutient, certes, ceux qui soutiennent (Sa Religion). Allah est assurément Fort et Puissant,\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmdcxxxvi{ceux qui, si Nous leur donnons la puissance sur terre, accomplissent la Salât, acquittent la Zakât, ordonnent le convenable et interdisent le blâmable. Cependant, l'issue finale de toute chose appartient à Allah.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmdcxxxvii{Et s'ils te traitent de menteur, [sache que] le peuple de Noé, les 'Aad, les Tamûd avant eux, ont aussi crié au mensonge (à l'égard de leurs messagers),\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmdcxxxviii{de même que le peuple d'Abraham, le peuple de Lot.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmdcxxxix{et les gens de Madyan. Et Moïse fut traité de menteur. Puis, J'ai donné un répit aux mécréants; ensuite Je les ai saisis. Et quelle fut Ma réprobation!\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmdcxl{Que de cités, donc, avons-Nous fait périr, parce qu'elles commettaient des tyrannies. Elles sont réduites à des toits écroulés: Que de puits désertés! Que de palais édifiés (et désertés aussi)!\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmdcxli{Que ne voyagent-ils sur la terre afin d'avoir des cœurs pour comprendre, et des oreilles pour entendre? Car ce ne sont pas les yeux qui s'aveuglent, mais, ce sont les cœurs dans les poitrines qui s'aveuglent.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmdcxlii{Et ils te demandent de hâter [l'arrivée] du châtiment. Jamais Allah ne manquera à Sa promesse. Cependant, un jour auprès de ton Seigneur, équivaut à mille ans de ce que vous comptez.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmdcxliii{A combien de cités n'ai-Je pas donné répit alors qu'elles commettaient des tyrannies? Ensuite, Je les ais saisies. Vers Moi est le devenir.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmdcxliv{Dis: «O hommes! Je ne suis pour vous, en vérité, qu'un avertisseur explicite».\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmdcxlv{Ceux donc qui croient et font de bonnes œuvres auront pardon et faveurs généreuses,\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmdcxlvi{tandis que ceux qui s'efforcent à échapper (au châtiment mentionné dans) Nos versets, ceux-là sont les gens de l'Enfer.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmdcxlvii{Nous n'avons envoyé, avant toi, ni Messager ni prophète qui n'ait récité (ce qui lui a été révélé) sans que le Diable n'ait essayé d'intervenir [pour semer le doute dans le cœur des gens au sujet] de sa récitation. Allah abroge ce que le Diable suggère, et Allah renforce Ses versets. Allah est Omniscient et Sage.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmdcxlviii{Afin de faire, de ce que jette le Diable, une tentation pour ceux qui ont une maladie au cœur et ceux qui ont le cœur dur... Les injustes sont certes dans un schisme profond.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmdcxlix{Et afin que ceux à qui le savoir a été donné sachent que (le Coran) est en effet, la Vérité venant de ton Seigneur, qu'ils y croient alors, et que leurs cœurs s'y soumettent en toute humilité. Allah guide certes vers le droit chemin ceux qui croient.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmdcl{Et ceux qui mécroient ne cesseront d'être en doute à son sujet, jusqu'à ce que l'Heure les surprenne à l'improviste ou que les atteigne le châtiment d'un jour terrifiant.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmdcli{La souveraineté ce jour-là appartiendra à Allah qui jugera parmi eux. Ceux qui auront cru et fait de bonnes œuvres seront dans les Jardins du délice,\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmdclii{et quant aux infidèles qui auront traité Nos révélations de mensonges, ils auront un châtiment avilissant!\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmdcliii{Ceux qui émigrent dans le sentier d'Allah et qui sont tués ou meurent, Allah leur accordera certes une belle récompense, car Allah est le meilleur des donateurs.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmdcliv{Il les fera, certes, entrer en un lieu qu'ils agréeront, et Allah est certes Omniscient et Indulgent.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmdclv{Ainsi en est-il. Quiconque châtie de la même façon dont il a été châtié, et qu'ensuite il est victime d'un nouvel outrage, Allah l'aidera, car Allah est certainement Absoluteur et Pardonneur.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmdclvi{C'est ainsi qu'Allah fait pénétrer la nuit dans le jour, et fait pénétrer le jour dans la nuit. Allah est, certes, Audient et Clairvoyant.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmdclvii{C'est ainsi qu'Allah est Lui le Vrai, alors que ce qu'ils invoquent en dehors de Lui est le faux; c'est Allah qui est le Sublime, le Grand.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmdclviii{N'as-tu pas vu qu'Allah fait descendre l'eau du ciel, et la terre devient alors verte? Allah est Plein de bonté et Parfaitement Connaisseur.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmdclix{A Lui appartient ce qui est dans les cieux et sur la terre. Allah est le seul qui se suffit à Lui-Même et qui est Le Digne de louange!\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmdclx{N'as-tu pas vu qu'Allah vous a soumis tout ce qui est sur la terre ainsi que le vaisseau qui vogue sur la mer par Son ordre? Il retient le ciel de tomber sur la terre, sauf quand Il le permettra. Car Allah est Plein de bonté et de miséricorde envers les hommes.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmdclxi{C'est Lui qui vous donne la vie puis vous donne la mort, puis vous fait revivre. Vraiment l'homme est très ingrat!\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmdclxii{A chaque communauté, Nous avons assigné un culte à suivre. Qu'ils ne disputent donc point avec toi l'ordre reçu! Et appelle à ton Seigneur. Tu es certes sur une voie droite.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmdclxiii{Et s'ils discutent avec toi, alors dis: «C'est Allah qui connaît mieux ce que vous faites.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmdclxiv{Allah jugera entre vous, au Jour de la Résurrection, ce en quoi vous divergez».\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmdclxv{Ne sais-tu pas qu'Allah sait ce qu'il y a dans le ciel et sur la terre? Tout cela est dans un Livre, et cela est pour Allah bien facile.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmdclxvi{Et ils adorent en dehors d'Allah, ce en quoi Il n'a fait descendre aucune preuve et ce dont ils n'ont aucune connaissance. Et il n'y aura pas de protecteur pour les injustes.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmdclxvii{Et quand on leur récite Nos versets bien clairs, tu discerneras la réprobation sur les visages de ceux qui ont mécru. Peu s'en faut qu'ils ne se jettent sur ceux qui leur récitent Nos versets. Dis: «Vous informerai-je de quelque chose de plus terrible? - Le Feu: Allah l'a promis à ceux qui ont mécru. Et quel triste devenir!»\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmdclxviii{O hommes! Une parabole vous est proposée, écoutez-la: «Ceux que vous invoquez en dehors d'Allah ne sauraient même pas créer une mouche, quand même ils s'uniraient pour cela. Et si la mouche les dépouillait de quelque chose, ils ne sauraient le lui reprendre. Le solliciteur et le sollicité sont [également] faibles!»\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmdclxix{Ils n'ont pas estimé Allah à sa juste valeur; Allah est certes Fort et Puissant.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmdclxx{Allah choisit des messagers parmi les Anges et parmi les hommes. Allah est Audient et Clairvoyant.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmdclxxi{Il sait ce qui est devant eux et derrière eux. Et c'est vers Allah que tout retournera.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmdclxxii{O vous qui croyez! Inclinez-vous, prosternez-vous, adorez votre Seigneur, et faites le bien. Peut-être réussirez vous!\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmdclxxiii{Et luttez pour Allah avec tout l'effort qu'Il mérite. C'est Lui qui vous a élus; et Il ne vous a imposé aucune gêne dans la religion, celle de votre père Abraham, lequel vous a déjà nommés «Musulmans» avant (ce Livre) et dans ce (Livre), afin que le Messager soit témoin contre vous, et que vous soyez vous-mêmes témoins contre les gens. Accomplissez donc la Salât, acquittez la Zakât et attachez-vous fortement à Allah. C'est Lui votre Maître. Quel Excellent Maître! Et quel Excellent Soutien!\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmdclxxiv{\basmalahfr Bienheureux sont certes les croyants,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmdclxxv{ceux qui sont humbles dans leur Salât,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmdclxxvi{qui se détournent des futilités,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmdclxxvii{qui s'acquittent de la Zakât,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmdclxxviii{et qui préservent leurs sexes [de tout rapport],\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmdclxxix{si ce n'est qu'avec leurs épouses ou les esclaves qu'ils possèdent, car là vraiment, on ne peut les blâmer;\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmdclxxx{alors que ceux qui cherchent au-delà de ces limites sont des transgresseurs;\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmdclxxxi{et qui veillent à la sauvegarde des dépôts confiés à eux et honorent leurs engagements,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmdclxxxii{et qui observent strictement leur Salât.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmdclxxxiii{Ce sont eux les héritiers,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmdclxxxiv{qui hériteront le Paradis pour y demeurer éternellement.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmdclxxxv{Nous avons certes créé l'homme d'un extrait d'argile.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmdclxxxvi{puis Nous en fîmes une goutte de sperme dans un reposoir solide.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmdclxxxvii{Ensuite, Nous avons fait du sperme une adhérence; et de l'adhérence Nous avons créé un embryon; puis, de cet embryon Nous avons créé des os et Nous avons revêtu les os de chair. Ensuite, Nous l'avons transformé en une tout autre création. Gloire à Allah le Meilleur des créateurs!\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmdclxxxviii{Et puis, après cela vous mourrez.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmdclxxxix{Et puis au Jour de la Résurrection vous serez ressuscités.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmdcxc{Nous avons créé, au-dessus de vous, sept cieux. Et Nous ne sommes pas inattentifs à la création.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmdcxci{Et Nous avons fait descendre l'eau du ciel avec mesure. Puis Nous l'avons maintenue dans la terre, cependant que Nous sommes bien Capable de la faire disparaître.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmdcxcii{Avec elle, Nous avons produit pour vous des jardins de palmiers et de vignes, dans lesquels vous avez des fruits abondants et desquels vous mangez,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmdcxciii{ainsi qu'un arbre (l'olivier) qui pousse au Mont Sinaî, en produisant l'huile servant à oindre et où les mangeurs trempent leur pain.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmdcxciv{Vous avez certes dans les bestiaux, un sujet de méditation. Nous vous donnons à boire de ce qu'ils ont dans le ventre, et vous y trouvez également maintes utilités; et vous vous en nourrissez.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmdcxcv{Sur eux ainsi que sur des vaisseaux vous êtes transportés.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmdcxcvi{Nous envoyâmes Noé vers son peuple. Il dit: «O mon peuple, adorez Allah. Vous n'avez pas d'autre divinité en dehors de Lui. Ne [Le] craignez-vous pas?»\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmdcxcvii{Alors les notables de son peuple qui avaient mécru dirent: «Celui-ci n'est qu'un être humain comme vous voulant se distinguer à votre détriment. Si Allah avait voulu, ce sont des Anges qu'Il aurait fait descendre. Jamais nous n'avons entendu cela chez nos ancêtres les plus reculés.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmdcxcviii{Ce n'est en vérité qu'un homme atteint de folie, observez-le donc durant quelque temps.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmdcxcix{Il dit: «Seigneur! Apporte-moi secours parce qu'ils me traitent de menteur».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmdcc{Nous lui révélâmes: «Construis l'arche sous Nos yeux et selon Notre révélation. Et quand Notre commandement viendra et que le four bouillonnera, achemine là-dedans un couple de chaque espèce, ainsi que ta famille, sauf ceux d'entre eux contre qui la parole a déjà été prononcée; et ne t'adresse pas à Moi au sujet des injustes, car ils seront fatalement noyés.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmdcci{Et lorsque tu seras installé, toi et ceux qui sont avec toi, dans l'arche, dis: «Louange à Allah qui nous a sauvés du peuple des injustes».\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmdccii{Et dis: «Seigneur, fais-moi débarquer d'un débarquement béni. Tu es Celui qui procure le meilleur débarquement».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmdcciii{Voilà bien là des signes. Nous sommes certes Celui qui éprouve.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmdcciv{Puis, après eux, Nous avons créé d'autres générations,\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmdccv{Nous envoyâmes parmi elles un Messager [issu] d'elles pour leur dire: «Adorez Allah. Vous n'avez pas d'autre divinité en dehors de Lui. Ne le craignez-vous pas?»\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmdccvi{Les notables de son peuple qui avaient mécru et traité de mensonge la rencontre de l'au-delà, et auxquels Nous avions accordé le luxe dans la vie présente, dirent: «Celui-ci n'est qu'un être humain comme vous, mangeant de ce que vous mangez, et buvant de ce que vous buvez.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmdccvii{Si vous obéissez à un homme comme vous, vous serez alors perdants.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmdccviii{Vous promet-il, quand vous serez morts, et devenus poussière et ossements, que vous serez sortis [de vos sépulcres]?\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmdccix{Loin, loin, ce qu'on vous promet!\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmdccx{Ce n'est là que notre vie présente: nous mourons et nous vivons; et nous ne serons jamais ressuscités.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmdccxi{Ce n'est qu'un homme qui forge un mensonge contre Allah; et nous ne croirons pas en lui».\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmdccxii{Il dit: «Seigneur! Apporte-moi secours parce qu'ils me traitent de menteur».\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmdccxiii{[Allah] dit: «Oui, bientôt ils en viendront aux regrets».\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmdccxiv{Le cri, donc, les saisit en toute justice; puis Nous les rendîmes semblables à des débris emportés par le torrent. Que disparaissent à jamais les injustes!\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmdccxv{Puis après eux Nous avons créé d'autres générations.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmdccxvi{Nulle communauté ne peut avancer ni reculer son terme.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmdccxvii{Ensuite, Nous envoyâmes successivement Nos messagers. Chaque fois qu'un messager se présentait à sa communauté, ils le traitaient de menteur. Et Nous les fîmes succéder les unes aux autres [dans la destruction], et Nous en fîmes des thèmes de récits légendaires. Que disparaissent à jamais les gens qui ne croient pas!\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmdccxviii{Ensuite, Nous envoyâmes Moïse et son frère Aaron avec Nos prodiges et une preuve évidente,\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmdccxix{vers Pharaon et ses notables mais ceux-ci s'enflèrent d'orgueil: ils étaient des gens hautains.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmdccxx{Ils dirent: «Croirons-nous en deux hommes comme nous dont les congénères sont nos esclaves».\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmdccxxi{Ils les traitèrent [tous deux] de menteurs et ils furent donc parmi les anéantis.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmdccxxii{Et Nous avions apporté le Livre à Moïse afin qu'ils se guident.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmdccxxiii{Et Nous fîmes du fils de Marie, ainsi que de sa mère, un prodige; et Nous donnâmes à tous deux asile sur une colline bien stable et dotée d'une source.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmdccxxiv{O Messagers! Mangez de ce qui est permis et agréable et faites du bien. Car Je sais parfaitement ce que vous faites.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmdccxxv{Cette communauté, la vôtre, est une seule communauté, tandis que Je suis votre Seigneur. Craignez-Moi donc».\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmdccxxvi{Mais ils se sont divisés en sectes, chaque secte exultant de ce qu'elle détenait.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmdccxxvii{Laisse-les dans leur égarement pour un certain temps.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmdccxxviii{Pensent-ils que ce que Nous leur accordons, en biens et en enfants,\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmdccxxix{[soit une avance] que Nous Nous empressons de leur faire sur les biens [de la vie future]? Au contraire, ils n'en sont pas conscients.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmdccxxx{Ceux qui, de la crainte de leur Seigneur, sont pénétrés,\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmdccxxxi{qui croient aux versets de leur Seigneur,\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmdccxxxii{qui n'associent rien à leur Seigneur,\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmdccxxxiii{qui donnent ce qu'ils donnent, tandis que leurs cœurs sont pleins de crainte [à la pensée] qu'ils doivent retourner à leur Seigneur.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmdccxxxiv{Ceux-là se précipitent vers les bonnes actions et sont les premiers à les accomplir.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmdccxxxv{Nous n'imposons à personne que selon sa capacité. Et auprès de Nous existe un Livre qui dit la vérité, et ils ne seront pas lésés.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmdccxxxvi{Mais leurs cœurs restent dans l'ignorance à l'égard de cela [le Coran]. [En outre] ils ont d'autres actes (vils) qu'ils accomplissent,\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmdccxxxvii{jusqu'à ce que par le châtiment Nous saisissions les plus aisés parmi eux et voilà qu'ils crient au secours.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmdccxxxviii{«Ne criez pas aujourd'hui. Nul ne vous protègera contre Nous.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmdccxxxix{Mes versets vous étaient récités auparavant; mais vous vous [en] détourniez,\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmdccxl{s'enflant d'orgueil, et vous les dénigriez au cours de vos veillées».\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmdccxli{Ne méditent-ils donc pas sur la parole (le Coran)? Ou est-ce que leur est venu ce qui n'est jamais venu à leurs premiers ancêtres?\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmdccxlii{Ou n'ont-ils pas connu leur Messager, au point de le renier?\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmdccxliii{Ou diront-ils: «Il est fou?» Au contraire, c'est la vérité qu'il leur a apportée. Et la plupart d'entre eux dédaignent la vérité.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmdccxliv{Si la vérité était conforme à leurs passions, les cieux et la terre et ceux qui s'y trouvent seraient, certes, corrompus. Au contraire, Nous leur avons donné leur rappel. Mais ils s'en détournent.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmdccxlv{Ou leur demandes-tu une rétribution? Mais la rétribution de ton Seigneur est meilleure. Et c'est Lui, le Meilleur des pourvoyeurs.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmdccxlvi{Et tu les appelles, certes, vers le droit chemin.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmdccxlvii{Or, ceux qui ne croient pas à l'au-delà sont bien écartés de ce chemin.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmdccxlviii{Si Nous leur faisions miséricorde et écartions d'eux le mal, ils persisteraient certainement dans leur transgression, confus et hésitants.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmdccxlix{Nous les avons certes saisis du châtiment, mais ils ne se sont pas soumis à leur Seigneur; de même qu'ils ne [Le] supplient point,\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmdccl{jusqu'au jour où Nous ouvrirons sur eux une porte au dur châtiment, et voilà qu'ils en seront désespérés.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmdccli{Et c'est Lui qui a créé pour vous l'ouïe, les yeux et les cœurs. Mais vous êtes rarement reconnaissants.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmdcclii{C'est Lui qui vous a répandus sur la terre, et c'est vers Lui que vous serez rassemblés.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmdccliii{Et c'est Lui qui donne la vie et qui donne la mort; et l'alternance de la nuit et du jour dépend de Lui. Ne raisonnerez-vous donc pas?\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmdccliv{Ils ont plutôt tenu les mêmes propos que les anciens.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmdcclv{Ils ont dit: «lorsque nous serons morts et que nous serons poussière et ossements, serons-nous vraiment ressuscités?\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmdcclvi{On nous a promis cela, ainsi qu'à nos ancêtres auparavant; ce ne sont que de vieilles sornettes».\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmdcclvii{Dis: «A qui appartient la terre et ceux qui y sont? si vous savez».\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmdcclviii{Ils diront: «A Allah». Dis: «Ne vous souvenez-vous donc pas?»\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmdcclix{Dis: «Qui est le Seigneur des sept cieux et le Seigneur du Trône sublime?»\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmdcclx{Ils diront: [ils appartiennent] «A Allah». Dis: «Ne craignez-vous donc pas?»\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmdcclxi{Dis: «Qui détient dans sa main la royauté absolue de toute chose, et qui protège et n'a pas besoin d'être protégé? [Dites], si vous le savez!»\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmdcclxii{Ils diront: «Allah». Dis: «Comment donc se fait-il que vous soyez ensorcelés?» [au point de ne pas croire en Lui].\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmdcclxiii{Nous leur avons plutôt apporté la vérité et ils sont assurément des menteurs.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmdcclxiv{Allah ne S'est point attribué d'enfant et il n'existe point de divinité avec Lui; sinon, chaque divinité s'en irait avec ce qu'elle a créé, et certaines seraient supérieures aux autres. (Gloire et pureté) à Allah! Il est Supérieur à tout ce qu'ils décrivent.\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmdcclxv{[Il est] Connaisseur de toute chose visible et invisible! Il est bien au-dessus de ce qu'ils [Lui] associent!\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmdcclxvi{Dis: «Seigneur, si jamais Tu me montres ce qui leur est promis;\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmdcclxvii{alors, Seigneur, ne me place pas parmi les gens injustes.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mmdcclxviii{Nous sommes Capable, certes, de te montrer ce que Nous leur promettons.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mmdcclxix{Repousse le mal par ce qui est meilleur. Nous savons très bien ce qu'ils décrivent.\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mmdcclxx{Et dis: «Seigneur, je cherche Ta protection, contre les incitations des diables.\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mmdcclxxi{et je cherche Ta protection, Seigneur, contre leur présence auprès de moi».\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mmdcclxxii{...Puis, lorsque la mort vient à l'un deux, il dit: «Mon Seigneur! Fais-moi revenir (sur terre),\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mmdcclxxiii{afin que je fasse du bien dans ce que je délaissais». Non, c'est simplement une parole qu'il dit. Derrière eux, cependant, il y a une barrière, jusqu'au jour où ils seront ressuscités».\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mmdcclxxiv{Puis quand on soufflera dans la Trompe, il n'y aura plus de parenté entre eux ce jour là, et ils ne se poseront pas de questions.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mmdcclxxv{Ceux dont la balance est lourde seront les bienheureux;\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mmdcclxxvi{et ceux dont la balance est légère seront ceux qui ont ruiné leurs propres âmes et ils demeureront éternellement dans l'Enfer.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mmdcclxxvii{Le feu brûlera leurs visages et ils auront les lèvres crispées.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mmdcclxxviii{«Mes versets ne vous étaient-ils pas récités et vous les traitiez alors de mensonges?»\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mmdcclxxix{Ils dirent: «Seigneur! Notre malheur nous a vaincus, et nous étions des gens égarés.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mmdcclxxx{Seigneur, fais nous-en sortir! Et si nous récidivons, nous serons alors des injustes».\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mmdcclxxxi{Il dit: «Soyez-y refoulés (humiliés) et ne Me parlez plus».\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mmdcclxxxii{Il y eut un groupe de Mes serviteurs qui dirent: «Seigneur, nous croyons; pardonne-nous donc et fais-nous miséricorde, car Tu es le meilleur des Miséricordieux»\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mmdcclxxxiii{mais vous les avez pris en raillerie jusqu'à oublier de M'invoquer, et vous vous riiez d'eux.\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mmdcclxxxiv{Vraiment, Je les ai récompensés aujourd'hui pour ce qu'ils ont enduré; et ce sont eux les triomphants.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mmdcclxxxv{Il dira: «Combien d'années êtes-vous restés sur terre?»\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@mmdcclxxxvi{Ils diront: «Nous y avons demeuré un jour, ou une partie d'un jour. Interroge donc ceux qui comptent.»\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@mmdcclxxxvii{Il dira: «Vous n'y avez demeuré que peu [de temps], si seulement vous saviez.\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@mmdcclxxxviii{Pensiez-vous que Nous vous avions créés sans but, et que vous ne seriez pas ramenés vers Nous?»\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@mmdcclxxxix{Que soit exalté Allah, le vrai Souverain! Pas de divinité en dehors de Lui, le Seigneur du Trône sublime!\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@mmdccxc{Et quiconque invoque avec Allah une autre divinité, sans avoir la preuve évidente [de son existence], aura à en rendre compte à son Seigneur. En vérité, les mécréants, ne réussiront pas.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@mmdccxci{Et dis: «Seigneur, pardonne et fais miséricorde. C'est Toi le Meilleur des miséricordieux».\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@mmdccxcii{\basmalahfr Voici une Sourate que Nous avons fait descendre et que Nous avons imposée, et Nous y avons fait descendre des versets explicites afin que vous vous souveniez».\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmdccxciii{La fornicatrice et le fornicateur, fouettez-les chacun de cent coups de fouet. Et ne soyez point pris de pitié pour eux dans l'exécution de la loi d'Allah - si vous croyez en Allah et au Jour dernier. Et qu'un groupe de croyants assiste à leur punition.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmdccxciv{Le fornicateur n'épousera qu'une fornicatrice ou une associatrice. Et la fornicatrice ne sera épousée que par un fornicateur ou un associateur; et cela a été interdit aux croyants.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmdccxcv{Et ceux qui lancent des accusations contre des femmes chastes sans produire par la suite quatre témoins, fouettez-les de quatre-vingts coups de fouet, et n'acceptez plus jamais leur témoignage. Et ceux-là sont les pervers,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmdccxcvi{à l'exception de ceux qui, après cela, se repentent et se réforment, car Allah est Pardonneur et Miséricordieux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmdccxcvii{Et quant à ceux qui lancent des accusations contre leurs propres épouses, sans avoir d'autres témoins qu'eux-mêmes, le témoignage de l'un d'eux doit être une quadruple attestation par Allah qu'il est du nombre des véridiques,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmdccxcviii{et la cinquième [attestation] est «que la malédiction d'Allah tombe sur lui s'il est du nombre des menteurs».\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmdccxcix{Et on ne lui infligera pas le châtiment [de la lapidation] si elle atteste quatre fois par Allah qu'il [son mari] est certainement du nombre des menteurs,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmdccc{et la cinquième [attestation] est que la colère d'Allah soit sur elle, s'il était du nombre des véridiques.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmdccci{Et, n'étaient la grâce d'Allah sur vous et Sa miséricorde...! Allah est Grand Accueillant au repentir et Sage!\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmdcccii{Ceux qui sont venus avec la calomnie sont un groupe d'entre vous. Ne pensez pas que c'est un mal pour vous, mais plutôt, c'est un bien pour vous. A chacun d'eux ce qu'il s'est acquis comme péché. Celui d'entre eux qui s'est chargé de la plus grande part aura un énorme châtiment.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmdccciii{Pourquoi, lorsque vous l'avez entendue [cette calomnie], les croyants et les croyantes n'ont-ils pas, en eux-mêmes, conjecturé favorablement, et n'ont-ils pas dit: «C'est une calomnie évidente?»\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmdccciv{Pourquoi n'ont-ils pas produit [à l'appui de leurs accusations] quatre témoins? S'ils ne produisent pas de témoins, alors ce sont eux, auprès d'Allah, les menteurs.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmdcccv{N'eussent-été la grâce d'Allah sur vous et Sa miséricorde ici-bas comme dans l'au-delà, un énorme châtiment vous aurait touchés pour cette (calomnie) dans laquelle vous vous êtes lancés,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmdcccvi{quand vous colportiez la nouvelle avec vos langues et disiez de vos bouches ce dont vous n'aviez aucun savoir; et vous le comptiez comme insignifiant alors qu'auprès d'Allah cela est énorme.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmdcccvii{Et pourquoi, lorsque vous l'entendiez, ne disiez-vous pas: «Nous ne devons pas en parler. Gloire à Toi (ô Allah)! C'est une énorme calomnie»?\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmdcccviii{Allah vous exhorte à ne plus jamais revenir à une chose pareille si vous êtes croyants.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmdcccix{Allah vous expose clairement les versets et Allah est Omniscient et Sage.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmdcccx{Ceux qui aiment que la turpitude se propage parmi les croyants auront un châtiment douloureux, ici-bas comme dans l'au-delà. Allah sait, et vous, vous ne savez pas.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmdcccxi{Et n'eussent été la grâce d'Allah sur vous et Sa miséricorde et (n'eût été) qu'Allah est Compatissant et Miséricordieux...\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmdcccxii{O vous qui avez cru! Ne suivez pas les pas du Diable. Quiconque suit les pas du Diable, [sachez que] celui-ci ordonne la turpitude et le blâmable. Et n'eussent été la grâce d'Allah envers vous et Sa miséricorde, nul d'entre vous n'aurait jamais été pur. Mais Allah purifie qui Il veut. Et Allah est Audient et Omniscient.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmdcccxiii{Et que les détenteurs de richesse et d'aisance parmi vous, ne jurent pas de ne plus faire des dons aux proches, aux pauvres, et à ceux qui émigrent dans le sentier d'Allah. Qu'ils pardonnent et absolvent. N'aimez-vous pas qu'Allah vous pardonne? et Allah est Pardonneur et Miséricordieux!\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmdcccxiv{Ceux qui lancent des accusations contre des femmes vertueuses, chastes [qui ne pensent même pas à commettre la turpitude] et croyantes sont maudits ici-bas comme dans l'au-delà; et ils auront un énorme châtiment,\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmdcccxv{Le jour où leurs langues, leurs mains et leurs pieds témoigneront contre eux de ce qu'ils faisaient.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmdcccxvi{Ce Jour-là, Allah leur donnera leur pleine et vraie rétribution; et ils sauront que c'est Allah qui est le Vrai de toute évidence.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmdcccxvii{Les mauvaises [femmes] aux mauvais [hommes], et les mauvais [hommes] aux mauvaises [femmes]. De même, les bonnes [femmes] aux bons [hommes], et les bons [hommes] aux bonnes [femmes]. Ceux-là sont innocents de ce que les autres disent. Ils ont un pardon et une récompense généreuse.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmdcccxviii{O vous qui croyez! N'entrez pas dans des maisons autres que les vôtres avant de demander la permission [d'une façon délicate] et de saluer leurs habitants. Cela est meilleur pour vous. Peut-être vous souvenez-vous.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmdcccxix{Si vous n'y trouvez personne, alors n'y entrez pas avant que permission vous soit donnée. Et si on vous dit: «Retournez», eh bien, retournez. Cela est plus pur pour vous. Et Allah, de ce que vous faites est Omniscient.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmdcccxx{Nul grief contre vous à entrer dans des maisons inhabitées où se trouve un bien pour vous. Allah sait ce que vous divulguez et ce que vous cachez.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmdcccxxi{Dis aux croyants de baisser leurs regards et de garder leur chasteté. C'est plus pur pour eux. Allah est, certes, Parfaitement Connaisseur de ce qu'ils font.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmdcccxxii{Et dis aux croyantes de baisser leurs regards, de garder leur chasteté, et de ne montrer de leurs atours que ce qui en paraît et qu'elles rabattent leur voile sur leurs poitrines; et qu'elles ne montrent leurs atours qu'à leurs maris, ou à leurs pères, ou aux pères de leurs maris, ou à leurs fils, ou aux fils de leurs maris, ou à leurs frères, ou aux fils de leurs frères, ou aux fils de leurs sœurs, ou aux femmes musulmanes, ou aux esclaves qu'elles possèdent, ou aux domestiques mâles impuissants, ou aux garçons impubères qui ignorent tout des parties cachées des femmes. Et qu'elles ne frappent pas avec leurs pieds de façon que l'on sache ce qu'elles cachent de leurs parures. Et repentez-vous tous devant Allah, ô croyants, afin que vous récoltiez le succès.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmdcccxxiii{Mariez les célibataires d'entre vous et les gens de bien parmi vos esclaves, hommes et femmes. S'ils sont besogneux, Allah les rendra riches par Sa grâce. Car (la grâce d') Allah est immense et Il est Omniscient.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmdcccxxiv{Et que ceux qui n'ont pas de quoi se marier, cherchent à rester chastes jusqu'à ce qu'Allah les enrichisse par Sa grâce. Ceux de vos esclaves qui cherchent un contrat d'affranchissement, concluez ce contrat avec eux si vous reconnaissez du bien en eux; et donnez-leur des biens d'Allah qu'Il vous a accordés. Et dans votre recherche des profits passagers de la vie présente, ne contraignez pas vos femmes esclaves à la prostitution, si elles veulent rester chastes. Si on les y contraint, Allah leur accorde après qu'elles aient été contraintes, Son pardon et Sa miséricorde.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmdcccxxv{Nous avons effectivement fait descendre vers vous des versets clairs, donnant une parabole de ceux qui ont vécu avant vous, et une exhortation pour les pieux!\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmdcccxxvi{Allah est la Lumière des cieux et de la terre. Sa lumière est semblable à une niche où se trouve une lampe. La lampe est dans un (récipient de) cristal et celui-ci ressemble à un astre de grand éclat; son combustible vient d'un arbre béni: un olivier ni oriental ni occidental dont l'huile semble éclairer sans même que le feu la touche. Lumière sur lumière. Allah guide vers Sa lumière qui Il veut. Allah propose aux hommes des paraboles et Allah est Omniscient.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmdcccxxvii{Dans des maisons [des mosquées] qu'Allah a permis que l'on élève, et où Son Nom est invoqué; Le glorifient en elles matin et après-midi,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmdcccxxviii{des hommes que ni le négoce, ni le troc ne distraient de l'invocation d'Allah, de l'accomplissement de la Salât et de l'acquittement de la Zakât, et qui redoutent un Jour où les cœurs seront bouleversés ainsi que les regards.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmdcccxxix{Afin qu'Allah les récompense de la meilleure façon pour ce qu'ils ont fait [de bien]. Et Il leur ajoutera de Sa grâce. Allah attribue à qui Il veut sans compter.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmdcccxxx{Quant à ceux qui ont mécru, leurs actions sont comme un mirage dans une plaine désertique que l'assoiffé prend pour de l'eau. Puis quand il y arrive, il s'aperçoit que ce n'était rien; mais y trouve Allah qui lui règle son compte en entier, car Allah est prompt à compter.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmdcccxxxi{[Les actions des mécréants] sont encore semblables à des ténèbres sur une mer profonde: des vagues la recouvrent, [vagues] au dessus desquelles s'élèvent [d'autres] vagues, sur lesquelles il y a [d'épais] nuages. Ténèbres [entassées] les unes au-dessus des autres. Quand quelqu'un étend la main, il ne la distingue presque pas. Celui qu'Allah prive de lumière n'a aucune lumière.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmdcccxxxii{N'as-tu pas vu qu'Allah est glorifié par tous ceux qui sont dans les cieux et la terre; ainsi que par les oiseaux déployant leurs ailes? Chacun, certes, a appris sa façon de L'adorer et de Le glorifier. Allah sait parfaitement ce qu'ils font.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmdcccxxxiii{C'est à Allah qu'appartient la royauté des cieux et de la terre. Et vers Allah sera le retour final.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmdcccxxxiv{N'as-tu pas vu qu'Allah pousse les nuages? Ensuite Il les réunit et Il en fait un amas, et tu vois la pluie sortir de son sein. Et Il fait descendre du ciel, de la grêle [provenant] des nuages [comparables] à des montagnes. Il en frappe qui Il veut et l'écarte de qui Il veut. Peu s'en faut que l'éclat de son éclair ne ravisse la vue.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmdcccxxxv{Allah fait alterner la nuit et le jour. Il y a là un sujet de réflexion pour ceux qui ont des yeux.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmdcccxxxvi{Et Allah a créé d'eau tout animal. Il y en a qui marche sur le ventre, d'autres marchent sur deux pattes, et d'autres encore marchent sur quatre. Allah crée ce qu'Il veut et Allah est Omnipotent.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmdcccxxxvii{Nous avons certes fait descendre des versets explicites. Et Allah guide qui Il veut vers un droit chemin.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmdcccxxxviii{Et ils disent: «Nous croyons en Allah et au messager et nous obéissons». Puis après cela, une partie d'entre eux fait volte-face. Ce ne sont point ceux-là les croyants.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmdcccxxxix{Et quand on les appelle vers Allah et Son messager pour que celui-ci juge parmi eux, voilà que quelques-uns d'entre eux s'éloignent.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmdcccxl{Mais s'ils ont le droit en leur faveur, ils viennent à lui, soumis.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmdcccxli{Y a-t-il une maladie dans leurs cœurs? ou doutent-ils ? ou craignent-ils qu'Allah les opprime, ainsi que Son messager? Non!... mais ce sont eux les injustes.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmdcccxlii{La seule parole des croyants, quand on les appelle vers Allah et Son messager, pour que celui-ci juge parmi eux, est: «Nous avons entendu et nous avons obéi». Et voilà ceux qui réussissent.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmdcccxliii{Et quiconque obéit à Allah et à Son messager, et craint Allah et Le redoute... alors, voilà ceux qui récoltent le succès.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmdcccxliv{Et ils jurent par Allah en serments solennels que si tu le leur ordonnais, ils sortiraient à coup sûr (au combat). Dis: «Ne jurez donc pas. [Votre] obéissance [verbale] est bien connue. Allah est Parfaitement Connaisseur de ce que vous faites».\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmdcccxlv{Dis: «Obéissez à Allah et obéissez au messager. S'ils se détournent, ...il [le messager] n'est alors responsable que de ce dont il est chargé; et vous assumez ce dont vous êtes chargés. Et si vous lui obéissez, vous serez bien guidés». Et il n'incombe au messager que de transmettre explicitement (son message).\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmdcccxlvi{Allah a promis à ceux d'entre vous qui ont cru et fait les bonnes œuvres qu'Il leur donnerait la succession sur terre comme Il l'a donnée à ceux qui les ont précédés. Il donnerait force et suprématie à leur religion qu'Il a agréée pour eux. Il leur changerait leur ancienne peur en sécurité. Ils M'adorent et ne M'associent rien et celui qui mécroit par la suite, ce sont ceux-là les pervers.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmdcccxlvii{Accomplissez la Salât, acquittez la Zakât et obéissez au messager, afin que vous ayez la miséricorde.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmdcccxlviii{Ne pense point que ceux qui ne croient pas puissent s'opposer à l'autorité d'Allah sur terre. Le Feu sera leur refuge. Quelle mauvaise destination.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmdcccxlix{O vous qui avez-cru! Que les esclaves que vous possédez vous demandent permission avant d'entrer, ainsi que ceux des vôtres qui n'ont pas encore atteint la puberté, à trois moments: avant la Salât de l'aube, à midi quand vous enlevez vos vêtements, ainsi qu'après la Salât de la nuit; trois occasions de vous dévêtir. En dehors de ces moments, nul reproche ni à vous ni à eux d'aller et venir, les uns chez les autres. C'est ainsi qu'Allah vous expose clairement Ses versets, et Allah est Omniscient et Sage.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmdcccl{Et quand les enfants parmi vous atteignent la puberté, qu'ils demandent permission avant d'entrer, comme font leurs aînés. C'est ainsi qu'Allah vous expose clairement Ses versets, et Allah est Omniscient et Sage.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmdcccli{Et quant aux femmes atteintes par la ménopause qui n'espèrent plus le mariage, nul reproche à elles d'enlever leurs vêtements de [sortie], sans cependant exhiber leurs atours et si elle cherchent la chasteté c'est mieux pour elles. Allah est Audient et Omniscient.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmdccclii{Il n'y a pas d'empêchement à l'aveugle, au boiteux, au malade, ainsi qu'à vous-mêmes de manger dans vos maisons, ou dans les maisons de vos pères, ou dans celles de vos mères, ou de vos frères, ou de vos sœurs, ou de vos oncles paternels, ou de vos tantes paternelles ou de vos oncles maternels, ou de vos tantes maternelles, ou dans celles dont vous possédez les clefs, ou chez vos amis. Nul empêchement à vous, non plus, de manger ensemble, ou séparément. Quand donc vous entrez dans des maisons, adressez-vous mutuellement des salutations venant d'Allah, bénies et agréables. C'est ainsi qu'Allah vous expose Ses versets, afin que vous compreniez.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmdcccliii{Les vrais croyants sont ceux qui croient en Allah et en Son messager, et qui, lorsqu'ils sont en sa compagnie pour une affaire d'intérêt général, ne s'en vont pas avant de lui avoir demandé la permission. Ceux qui te demandent cette permission sont ceux qui croient en Allah et en Son messager. Si donc ils te demandent la permission pour une affaire personnelle, donne-la à qui tu veux d'entre eux; et implore le pardon d'Allah pour eux, car Allah est Pardonneur et Miséricordieux.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmdcccliv{Ne considérez pas l'appel du messager comme un appel que vous vous adresseriez les uns aux autres. Allah connaît certes ceux des vôtres qui s'en vont secrètement en s'entrecachant. Que ceux, donc, qui s'opposent à son commandement prennent garde qu'une épreuve ne les atteigne, ou que ne les atteigne un châtiment douloureux.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmdccclv{C'est à Allah, vraiment, qu'appartient tout ce qui est dans les cieux et sur la terre. Il sait parfaitement l'état dans lequel vous êtes, et le Jour où les hommes seront ramenés vers Lui, Il les informera alors de ce qu'ils œuvraient. Allah est Omniscient.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmdccclvi{\basmalahfr Qu'on exalte la Bénédiction de Celui qui a fait descendre le Livre de Discernement sur Son serviteur, afin qu'il soit un avertisseur à l'univers.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmdccclvii{Celui à qui appartient la royauté des cieux et de la terre, qui ne S'est point attribué d'enfant, qui n'a point d'associé en Sa royauté et qui a créé toute chose en lui donnant ses justes proportions.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmdccclviii{Mais ils ont adopté en dehors de Lui des divinités qui, étant elles-mêmes créées, ne créent rien, et qui ne possèdent la faculté de faire ni le mal ni le bien pour elles-mêmes, et qui ne sont maîtresses ni de la mort, ni de la vie, ni de la résurrection.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmdccclix{Les mécréants disent: «Tout ceci n'est qu'un mensonge qu'il (Muhammad) a inventé, et où d'autres gens l'ont aidé». Or, ils commettent là une injustice et un mensonge.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmdccclx{Et ils disent: «Ce sont des contes d'anciens qu'il se fait écrire! On les lui dicte matin et soir!»\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmdccclxi{Dis: «L'a fait descendre Celui qui connaît les secrets dans les cieux et la terre. Et Il est Pardonneur et Miséricordieux.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmdccclxii{Et ils disent: «Qu'est-ce donc que ce Messager qui mange de la nourriture et circule dans les marchés? Que n'a-t-on fait descendre vers lui un Ange qui eût été avertisseur en sa compagnie?\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmdccclxiii{Ou que ne lui a-t-on lancé un trésor? Ou que n'a-t-il un jardin à lui, dont il pourrait manger (les fruits)?» Les injustes disent: «Vous ne suivez qu'un homme ensorcelé».\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmdccclxiv{Vois à quoi ils te comparent! Ils se sont égarés. Ils ne pourront trouver aucun chemin.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmdccclxv{Béni soit Celui qui, s'Il le veut, t'accordera bien mieux que cela: des Jardins sous lesquels coulent les ruisseaux; et Il t'assignera des châteaux.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmdccclxvi{Mais ils ont plutôt qualifié l'Heure de mensonge. Nous avons cependant préparé, pour quiconque qualifie l'Heure de mensonge, une Flamme brûlante.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmdccclxvii{Lorsque de loin elle les voit, ils entendront sa fureur et ses pétillements.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmdccclxviii{Et quand on les y aura jetés, dans un étroit réduit, les mains liées derrière le cou, ils souhaiteront alors leur destruction complète.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmdccclxix{«Aujourd'hui, ne souhaitez pas la destruction une seule fois, mais souhaitez-en plusieurs.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmdccclxx{Dis: «Est-ce mieux ceci? ou bien le Paradis éternel qui a été promis aux pieux, comme récompense et destination dernière?\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmdccclxxi{Ils auront là tout ce qu'ils désireront et une demeure éternelle. C'est une promesse incombant à ton Seigneur.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmdccclxxii{Et le jour où Il les rassemblera, eux et ceux qu'ils adoraient en dehors d'Allah, Il dira: «Est-ce vous qui avez égaré Mes serviteurs que voici, ou ont-ils eux-mêmes perdu le sentier?»\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmdccclxxiii{Ils diront: «Gloire à Toi! Il ne nous convenait nullement de prendre en dehors de Toi des patrons protecteurs mais Tu les as comblés de jouissance ainsi que leurs ancêtres au point qu'ils en ont oublié le livre du rappel [le Coran]. Et ils ont été des gens perdus».\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmdccclxxiv{«Ils vous ont démentis en ce que vous dites. Il n'y aura pour vous ni échappatoire ni secours (possible). Et quiconque des vôtres est injuste, Nous lui ferons goûter un grand châtiment».\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmdccclxxv{Et Nous n'avons envoyé avant toi que des messagers qui mangeaient de la nourriture et circulaient dans les marchés. Et Nous avons fait de certains d'entre vous une épreuve pour les autres -endurerez-vous avec constance? - Et ton Seigneur demeure Clairvoyant.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmdccclxxvi{Et ceux qui n'espèrent pas Nous rencontrer disent: «Si seulement on avait fait descendre sur nous des Anges ou si nous pouvions voir notre Seigneur!» En effet, ils se sont enflés d'orgueil en eux-mêmes, et ont dépassé les limites de l'arrogance.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmdccclxxvii{Le jour où ils verront les Anges, ce ne sera pas une bonne nouvelle, ce jour-là, pour les injustes, ils (les Anges) diront: «Barrage totalement défendu»!\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmdccclxxviii{Nous avons considéré l'œuvre qu'ils ont accomplie et Nous l'avons réduite en poussière éparpillée.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmdccclxxix{Les gens du Paradis seront, ce jour-là, en meilleure demeure et au plus beau lieu de repos.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmdccclxxx{Et le jour où le ciel sera fendu par les nuages et qu'on fera descendre des Anges,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmdccclxxxi{ce jour-là, la vraie royauté appartient au Tout Miséricordieux, et ce sera un Jour difficile aux infidèles.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmdccclxxxii{Le jour où l'injuste se mordra les deux mains et dira: «[Hélas pour moi!] Si seulement j'avais suivi chemin avec le Messager!...\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmdccclxxxiii{Malheur à moi! Hélas! Si seulement je n'avais pas pris «un tel» pour ami!...\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmdccclxxxiv{Il m'a, en effet, égaré loin du rappel [le Coran], après qu'il me soit parvenu». Et le Diable déserte l'homme (après l'avoir tenté).\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmdccclxxxv{Et le Messager dit: «Seigneur, mon peuple a vraiment pris ce Coran pour une chose délaissée!»\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmdccclxxxvi{C'est ainsi que Nous fîmes à chaque prophète un ennemi parmi les criminels. Mais ton Seigneur suffit comme guide et comme soutien.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmdccclxxxvii{Et ceux qui ne croient pas disent: «Pourquoi n'a-t-on pas fait descendre sur lui le Coran en une seule fois?» Nous l'avons révélé ainsi pour raffermir ton cœur. Et Nous l'avons récité soigneusement.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmdccclxxxviii{Ils ne t'apporteront aucune parabole, sans que Nous ne t'apportions la vérité avec la meilleure interprétation.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmdccclxxxix{Ceux qui seront traînés [ensemble] sur leurs visages vers l'Enfer, ceux-là seront dans la pire des situations et les plus égarés hors du chemin droit.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmdcccxc{En effet, Nous avons apporté à Moïse le Livre et lui avons assigné son frère Aaron comme assistant.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmdcccxci{Puis Nous avons dit: «Allez tous deux vers les gens qui ont traité de mensonge Nos preuves». Nous les avons ensuite détruits complètement.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmdcccxcii{Et le peuple de Noé, quand ils eurent démenti les messagers, Nous les noyâmes et en fîmes pour les gens un signe d'avertissement. Et Nous avons préparé pour les injustes un châtiment douloureux.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmdcccxciii{Et les 'Aad, les Thamûd, les gens d'Ar-Rass et de nombreuses générations intermédiaires!\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmdcccxciv{A tous, cependant, Nous avions fait des paraboles et Nous les avions tous anéantis d'une façon brutale.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmdcccxcv{Ils sont passés par la cité sur laquelle est tombée une pluie de malheurs. Ne la voient-ils donc pas? Mais ils n'espèrent pas de résurrection!\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmdcccxcvi{Et quand ils te voient, ils ne te prennent qu'en raillerie: «Est-ce là celui qu'Allah a envoyé comme Messager?\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmdcccxcvii{Peu s'en est fallu qu'il ne nous égare de nos divinités, si ce n'était notre attachement patient à elles!». Cependant, ils sauront quand ils verront le châtiment, qui est le plus égaré en son chemin.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmdcccxcviii{Ne vois-tu pas celui qui a fait de sa passion sa divinité? Est-ce à toi d'être un garant pour lui?\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmdcccxcix{Ou bien penses-tu que la plupart d'entre eux entendent ou comprennent? Ils ne sont en vérité comparables qu'à des bestiaux. Ou plutôt, ils sont plus égarés encore du sentier.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmcm{N'as-tu pas vu comment ton Seigneur étend l'ombre? S'Il avait voulu, certes, Il l'aurait faite immobile. Puis Nous lui fîmes du soleil son indice,\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmcmi{puis Nous la saisissons [pour la ramener] vers Nous avec facilité.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmcmii{Et c'est Lui qui vous fit de la nuit un vêtement, du sommeil un repos et qui fit du jour un retour à la vie active.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmcmiii{Et c'est Lui qui envoya les vents comme une annonce précédant Sa miséricorde. Nous fîmes descendre du ciel une eau pure et purifiante,\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmcmiv{pour faire revivre par elle une contrée morte, et donner à boire aux multiples bestiaux et hommes que Nous avons créés.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmcmv{Nous l'avions répartie entre eux afin qu'ils se rappellent (de Nous). Mais la plupart des gens se refusent à tout sauf à être ingrats.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmcmvi{Or, si Nous avions voulu, Nous aurions certes envoyé dans chaque cité un avertisseur.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmcmvii{N'obéis donc pas aux infidèles; et avec ceci (le Coran), lutte contre eux vigoureusement.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmcmviii{Et c'est Lui qui donne libre cours aux deux mers: l'une douce, rafraîchissante, l'autre salée, amère. Et Il assigne entre les deux une zone intermédiaire et un barrage infranchissable.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmcmix{Et c'est Lui qui de l'eau a créé une espèce humaine qu'Il unit par les liens de la parenté et de l'alliance. Et ton Seigneur demeure Omnipotent.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmcmx{Mais ils adorent en dehors d'Allah, ce qui ne leur profite point, ni ne leur nuit! Et l'infidèle sera toujours l'allié des ennemis de son Seigneur!\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmcmxi{Or, Nous ne t'avons envoyé que comme annonciateur et avertisseur.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmcmxii{Dis: «Je ne vous en demande aucun salaire (pour moi même). Toutefois, celui qui veut suivre un chemin conduisant vers son Seigneur [est libre de dépenser dans la voie d'Allah]».\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmcmxiii{Et place ta confiance en Le Vivant qui ne meurt jamais. Et par Sa louange, glorifie-Le. Il suffit comme Parfait Connaisseur des péchés de Ses serviteurs.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmcmxiv{C'est Lui qui, en six jours, a créé les cieux, la terre et tout ce qui existe entre eux, et le Tout Miséricordieux S'est établi «Istawâ» ensuite sur le Trône. Interroge donc qui est bien informé de Lui.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmcmxv{Et quand on leur dit: «Prosternez-vous devant le Tout Miséricordieux», ils disent: «Qu'est-ce donc que le Tout Miséricordieux? Allons-nous nous prosterner devant ce que tu nous commandes?» - Et cela accroît leur répulsion.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmcmxvi{Que soit béni Celui qui a placé au ciel des constellations et y a placé un luminaire (le soleil) et aussi une lune éclairante!\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmcmxvii{Et c'est Lui qui a assigné une alternance à la nuit et au jour pour quiconque veut y réfléchir ou montrer sa reconnaissance.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmcmxviii{Les serviteurs du Tout Miséricordieux sont ceux qui marchent humblement sur terre, qui, lorsque les ignorants s'adressent à eux, disent: «Paix»,\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmcmxix{qui passent les nuits prosternés et debout devant leur Seigneur;\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmcmxx{qui disent: «Seigneur, écarte de nous le châtiment de l'Enfer». - car son châtiment est permanent.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmcmxxi{Quels mauvais gîte et lieu de séjour!\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmcmxxii{Qui, lorsqu'ils dépensent, ne sont ni prodigues ni avares mais se tiennent au juste milieu.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmcmxxiii{Qui n'invoquent pas d'autre dieu avec Allah et ne tuent pas la vie qu'Allah a rendue sacrée, sauf à bon droit; qui ne commettent pas de fornication - car quiconque fait cela encourra une punition\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmcmxxiv{et le châtiment lui sera doublé, au Jour de la Résurrection, et il y demeurera éternellement couvert d'ignominie;\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmcmxxv{sauf celui qui se repent, croit et accomplit une bonne œuvre; ceux-là Allah changera leurs mauvaises actions en bonnes, et Allah est Pardonneur et Miséricordieux;\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmcmxxvi{et quiconque se repent et accomplit une bonne œuvre c'est vers Allah qu'aboutira son retour.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmcmxxvii{Ceux qui ne donnent pas de faux témoignages; et qui, lorsqu'ils passent auprès d'une frivolité, s'en écartent noblement;\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmcmxxviii{qui lorsque les versets de leur Seigneur leur sont rappelés, ne deviennent ni sourds ni aveugles;\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmcmxxix{et qui disent: «Seigneur, donne-nous, en nos épouses et nos descendants, la joie des yeux, et fais de nous un guide pour les pieux».\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmcmxxx{Ceux-là auront pour récompense un lieu élevé [du Paradis] à cause de leur endurance, et ils y seront accueillis avec le salut et la paix,\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmcmxxxi{pour y demeurer éternellement. Quel beau gîte et lieu de séjour!\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmcmxxxii{Dis: «Mon Seigneur ne se souciera pas de vous sans votre prière; mais vous avez, démenti (le Prophète). Votre [châtiment] sera inévitable et permanent.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmcmxxxiii{\basmalahfr T'â, Sîn, Mim.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmcmxxxiv{Voici les versets du Livre explicite.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmcmxxxv{Il se peut que tu te consumes de chagrin parce qu'ils ne sont pas croyants!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmcmxxxvi{Si Nous voulions, Nous ferions descendre du ciel sur eux un prodige devant lequel leurs nuques resteront courbées.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmcmxxxvii{Aucun nouveau rappel ne leur vient du Tout Miséricordieux sans qu'ils ne l'esquivent.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmcmxxxviii{Et ils ont traité de mensonge [tout ce qui leur vient du Seigneur]. Il leur viendra bientôt des nouvelles de ce dont ils se raillent.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmcmxxxix{N'ont-ils pas observé la terre, combien Nous y avons fait pousser de couples généreux de toutes sortes?\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmcmxl{Voilà bien là une preuve! Et la plupart d'entre eux ne croient pas.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmcmxli{Et ton Seigneur est en vérité Lui le Tout Puissant, le Très Miséricordieux.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmcmxlii{Et lorsque ton Seigneur appela Moïse: «Rends-toi auprès du peuple injuste,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmcmxliii{[auprès du] peuple de Pharaon» ne craindront-ils pas (Allah)?\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmcmxliv{Il dit: «Seigneur, je crains qu'ils ne me traitent de menteur;\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmcmxlv{que ma poitrine ne se serre, et que ma langue ne soit embarrassée: Mande donc Aaron.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmcmxlvi{Ils ont un crime à me reprocher; je crains donc qu'ils ne me tuent».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmcmxlvii{Mais [Allah lui] dit: «Jamais! Allez tous deux avec Nos prodiges, Nous resterons avec vous et Nous écouterons.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmcmxlviii{Rendez-vous donc tous deux auprès de Pharaon, puis dites: «Nous sommes les messagers du Seigneur de l'univers,\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmcmxlix{pour que tu renvoies les Enfants d'Israël avec nous».\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmcml{«Ne t'avons-nous pas, dit Pharaon, élevé chez nous tout enfant? Et n'as-tu pas demeuré parmi nous des années de ta vie?\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmcmli{Puis tu as commis le méfait que tu as fait, en dépit de toute reconnaissance».\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmcmlii{«Je l'ai fait, dit Moïse, alors que j'étais encore du nombre des égarés.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmcmliii{Je me suis donc enfui de vous quand j'ai eu peur de vous: puis, mon Seigneur m'a donné la sagesse et m'a désigné parmi Ses messagers.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmcmliv{Est-ce là un bienfait de ta part [que tu me rappelles] avec reproche, alors que tu as asservi les Enfants d'Israël?»\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmcmlv{«Et qu'est-ce que le Seigneur de l'univers?» dit Pharaon.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmcmlvi{«Le Seigneur des cieux et de la terre et de ce qui existe entre eux, dit [Moïse], si seulement vous pouviez en être convaincus!»\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmcmlvii{[Pharaon] dit à ceux qui l'entouraient: «N'entendez-vous pas?\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmcmlviii{[Moïse] continue: «... Votre Seigneur, et le Seigneur de vos plus anciens ancêtres».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmcmlix{«Vraiment, dit [Pharaon], votre messager qui vous a été envoyé, est un fou».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmcmlx{[Moïse] ajouta: «... Le Seigneur du Levant et du Couchant et de ce qui est entre les deux; si seulement vous compreniez!»\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmcmlxi{«Si tu adoptes, dit [Pharaon], une autre divinité que moi, je te mettrai parmi les prisonniers».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmcmlxii{«Et même si je t'apportais, dit [Moïse], une chose (une preuve) évidente?\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmcmlxiii{«Apporte-la, dit [Pharaon], si tu es du nombre des véridiques».\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmcmlxiv{[Moïse] jeta donc son bâton et le voilà devenu un serpent manifeste.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmcmlxv{Et il tira sa main et voilà qu'elle était blanche (étincelante) à ceux qui regardaient.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmcmlxvi{[Pharaon] dit aux notables autour de lui: «Voilà en vérité un magicien savant.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmcmlxvii{Il veut par sa magie vous expulser de votre terre. Que commandez-vous?»\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmcmlxviii{Ils dirent: «Remets-les à plus tard, [lui] et son frère, et envoie des gens dans les villes, pour rassembler,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmcmlxix{et t'amener tout grand magicien savant».\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmcmlxx{Les magiciens furent donc réunis en rendez-vous au jour convenu.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmcmlxxi{Et il fut dit aux gens: «Est-ce que vous allez vous réunir,\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmcmlxxii{afin que nous suivions les magiciens, si ce sont eux les vainqueurs?»\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmcmlxxiii{Puis, lorsque les magiciens arrivèrent, ils dirent à Pharaon: «Y aura-t-il vraiment une récompense pour nous, si nous sommes les vainqueurs?»\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmcmlxxiv{Il dit: «Oui, bien sûr, vous serez alors parmi mes proches!»\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmcmlxxv{Moïse leur dit: «Jetez ce que vous avez à jeter».\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmcmlxxvi{Ils jetèrent donc leurs cordes et leurs bâtons et dirent: «Par la puissance de Pharaon!... C'est nous qui serons les vainqueurs».\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmcmlxxvii{Puis Moïse jeta son bâton, et voilà qu'il happait ce qu'ils avaient fabriqué.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmcmlxxviii{Alors les magiciens tombèrent prosternés,\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmcmlxxix{disant: «Nous croyons au Seigneur de l'univers,\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmcmlxxx{Le Seigneur de Moïse et d'Aaron».\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmcmlxxxi{[Pharaon] dit: «Avez-vous cru en lui avant que je ne vous le permette? En vérité, c'est lui votre chef, qui vous a enseigné la magie! Eh bien, vous saurez bientôt! Je vous couperai, sûrement, mains et jambes opposées, et vous crucifierai tous».\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmcmlxxxii{Ils disent: «Il n'y a pas de mal! Car c'est vers notre Seigneur que nous retournerons.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmcmlxxxiii{Nous convoitons que notre Seigneur nous pardonne nos fautes pour avoir été les premiers à croire».\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmcmlxxxiv{Et Nous révélâmes à Moïse [ceci]: «Pars de nuit avec Mes serviteurs, car vous serez poursuivis».\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmcmlxxxv{Puis, Pharaon envoya des rassembleurs [dire] dans les villes:\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmcmlxxxvi{«Ce sont, en fait, une bande peu nombreuse,\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmcmlxxxvii{mais ils nous irritent,\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmcmlxxxviii{tandis que nous sommes tous vigilants».\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmcmlxxxix{Ainsi, Nous les fîmes donc sortir des jardins, des sources,\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmcmxc{des trésors et d'un lieu de séjour agréable.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmcmxci{Il en fut ainsi! Et Nous les donnâmes en héritage aux enfants d'Israël.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmcmxcii{Au lever du soleil, ils les poursuivirent.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmcmxciii{Puis, quand les deux partis se virent, les compagnons de Moïse dirent: «Nous allons être rejoints».\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmcmxciv{Il dit: «Jamais, car j'ai avec moi mon Seigneur qui va me guider».\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmcmxcv{Alors Nous révélâmes à Moïse: «Frappe la mer de ton bâton». Elle se fendit alors, et chaque versant fut comme une énorme montagne.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmcmxcvi{Nous fîmes approcher les autres [Pharaon et son peuple].\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmcmxcvii{Et Nous sauvâmes Moïse et tous ceux qui étaient avec lui;\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmcmxcviii{ensuite Nous noyâmes les autres.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmcmxcix{Voilà bien là un prodige, mais la plupart d'entre eux ne croient pas.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmm{Et ton Seigneur, c'est en vérité Lui le Tout Puissant, le Très Miséricordieux.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmi{Et récite-leur la nouvelle d'Abraham:\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmii{Quand il dit à son père et à son peuple: «Qu'adorez-vous?»\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmiii{Ils dirent: «Nous adorons des idoles et nous leurs restons attachés».\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmiv{Il dit: «Vous entendent-elles lorsque vous [les] appelez?\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmv{ou vous profitent-elles? ou vous nuisent-elles?»\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmvi{Ils dirent: «Non! mais nous avons trouvé nos ancêtres agissant ainsi».\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmvii{Il dit: «Que dites-vous de ce que vous adoriez...?\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmviii{Vous et vos vieux ancêtres?\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmix{Ils sont tous pour moi des ennemis sauf le Seigneur de l'univers,\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmx{qui m'a créé, et c'est Lui qui me guide;\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmxi{et c'est Lui qui me nourrit et me donne à boire;\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmmxii{et quand je suis malade, c'est Lui qui me guérit,\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmmxiii{et qui me fera mourir, puis me redonnera la vie,\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmmxiv{et c'est de Lui que je convoite le pardon de mes fautes le Jour de la Rétribution.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmmxv{Seigneur, accorde-moi sagesse (et savoir) et fais-moi rejoindre les gens de bien;\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmmxvi{fais que j'aie une mention honorable sur les langues de la postérité;\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmmxvii{et fais de moi l'un des héritiers du Jardin des délices.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmmxviii{et pardonne à mon père: car il a été du nombre des égarés;\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmmxix{et ne me couvre pas d'ignominie, le jour où l'on sera ressuscité,\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmmxx{le jour où ni les biens, ni les enfants ne seront d'aucune utilité,\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmmxxi{sauf celui qui vient à Allah avec un cœur sain».\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmmxxii{On rapprochera alors le Paradis pour les pieux,\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmmxxiii{et l'on exposera aux errants la Fournaise,\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmmxxiv{et on leur dira: «Où sont ceux que vous adoriez,\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmmxxv{en dehors d'Allah? vous secourent-ils? ou se secourent-ils eux-mêmes?»\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmmxxvi{Ils y seront donc jetés pêle-mêle, et les errants aussi,\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mmmxxvii{ainsi que toutes les légions de Iblis.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mmmxxviii{Ils diront, tout en s'y querellant:\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mmmxxix{«Par Allah! Nous étions certes dans un égarement évident,\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mmmxxx{quand nous faisions de vous les égaux du Seigneur de l'univers.\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mmmxxxi{Ce ne sont que les criminels qui nous ont égarés.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mmmxxxii{Et nous n'avons pas d'intercesseurs,\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mmmxxxiii{ni d'ami chaleureux.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mmmxxxiv{Si un retour nous était possible, alors nous serions parmi les croyants!»\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mmmxxxv{Voilà bien là un signe; cependant, la plupart d'entre eux ne croient pas.\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mmmxxxvi{Et ton Seigneur, c'est Lui vraiment le Puissant, le Très Miséricordieux.\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mmmxxxvii{Le peuple de Noé traita de menteurs les Messagers,\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mmmxxxviii{lorsque Noé, leur frère, (contribule) leur dit: «Ne craindrez-vous pas [Allah]?\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mmmxxxix{Je suis pour vous un messager digne de confiance.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mmmxl{Craignez Allah donc et obéissez-moi.\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mmmxli{Et je ne vous demande pas de salaire pour cela; mon salaire n'incombe qu'au Seigneur de l'univers.\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mmmxlii{Craignez Allah donc, et obéissez-moi».\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mmmxliii{Ils dirent: «Croirons-nous en toi, alors que ce sont les plus vils qui te suivent.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mmmxliv{Il dit: «Je ne sais pas ce que ceux-là faisaient.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@mmmxlv{Leur compte n'incombe qu'à mon Seigneur. Si seulement vous êtes conscients.\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@mmmxlvi{Je ne suis pas celui qui repousse les croyants.\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@mmmxlvii{Je ne suis qu'un avertisseur explicite».\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@mmmxlviii{Ils dirent: «Si tu ne cesses pas, Noé, tu seras certainement du nombre des lapidés!»\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@mmmxlix{Il dit: «O mon Seigneur, mon peuple me traite de menteur.\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@mmml{Tranche donc clairement entre eux et moi; et sauve-moi ainsi que ceux des croyants qui sont avec moi».\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@mmmli{Nous le sauvâmes donc, de même que ceux qui étaient avec lui dans l'arche, pleinement chargée.\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@mmmlii{Et ensuite nous noyâmes le reste (les infidèles).\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@mmmliii{Voilà bien là un signe. Cependant, la plupart d'entre eux ne croient pas.\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@mmmliv{Et Ton Seigneur, c'est lui vraiment le Puissant, le Très Miséricordieux.\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@mmmlv{Les 'Aad traitèrent de menteurs les Envoyés.\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@mmmlvi{Et quand Hûd, leur frère (contribule), leur dit: «Ne craindrez-vous pas [Allah]?»\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@mmmlvii{Je suis pour vous un messager digne de confiance,\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@mmmlviii{Craignez Allah donc et obéissez-moi.\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@mmmlix{Et je ne vous demande pas de salaire pour cela; mon salaire n'incombe qu'au Seigneur de l'univers.\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@mmmlx{Bâtissez-vous par frivolité sur chaque colline un monument?\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@mmmlxi{Et édifiez-vous des châteaux comme si vous deviez demeurer éternellement?\qt@no{(129)}}
\qt@newcmd\qurantrans@fr@mmmlxii{Et quand vous sévissez contre quelqu'un, vous le faites impitoyablement.\qt@no{(130)}}
\qt@newcmd\qurantrans@fr@mmmlxiii{Craignez Allah donc et obéissez-moi.\qt@no{(131)}}
\qt@newcmd\qurantrans@fr@mmmlxiv{Craignez Celui qui vous a pourvus de [toutes les bonnes choses] que vous connaissez,\qt@no{(132)}}
\qt@newcmd\qurantrans@fr@mmmlxv{qui vous a pourvus de bestiaux et d'enfants,\qt@no{(133)}}
\qt@newcmd\qurantrans@fr@mmmlxvi{de jardins et de sources.\qt@no{(134)}}
\qt@newcmd\qurantrans@fr@mmmlxvii{Je crains pour vous le châtiment d'un Jour terrible».\qt@no{(135)}}
\qt@newcmd\qurantrans@fr@mmmlxviii{Ils dirent: «Que tu nous exhortes ou pas, cela nous est parfaitement égal!\qt@no{(136)}}
\qt@newcmd\qurantrans@fr@mmmlxix{Ce ne sont là que des mours des anciens:\qt@no{(137)}}
\qt@newcmd\qurantrans@fr@mmmlxx{Nous ne serons nullement châtiés».\qt@no{(138)}}
\qt@newcmd\qurantrans@fr@mmmlxxi{Ils le traitèrent donc de menteur. Et nous les fîmes périr. Voilà bien là un signe! Cependant, la plupart d'entre eux ne croient pas.\qt@no{(139)}}
\qt@newcmd\qurantrans@fr@mmmlxxii{Et Ton Seigneur, c'est Lui vraiment le Puissant, le Très Miséricordieux.\qt@no{(140)}}
\qt@newcmd\qurantrans@fr@mmmlxxiii{Les Thamûd traitèrent de menteurs les Messagers.\qt@no{(141)}}
\qt@newcmd\qurantrans@fr@mmmlxxiv{Quand Sâlih, leur frère (contribule) leur dit: «Ne craindrez-vous pas [Allah]?»\qt@no{(142)}}
\qt@newcmd\qurantrans@fr@mmmlxxv{Je suis pour vous un messager digne de confiance.\qt@no{(143)}}
\qt@newcmd\qurantrans@fr@mmmlxxvi{Craignez Allah donc et obéissez-moi.\qt@no{(144)}}
\qt@newcmd\qurantrans@fr@mmmlxxvii{Je ne vous demande pas de salaire pour cela, mon salaire n'incombe qu'au Seigneur de l'univers.\qt@no{(145)}}
\qt@newcmd\qurantrans@fr@mmmlxxviii{Vous laissera-t-on en sécurité dans votre présente condition?\qt@no{(146)}}
\qt@newcmd\qurantrans@fr@mmmlxxix{Au milieu de jardins, de sources,\qt@no{(147)}}
\qt@newcmd\qurantrans@fr@mmmlxxx{de cultures et de palmiers aux fruits digestes?\qt@no{(148)}}
\qt@newcmd\qurantrans@fr@mmmlxxxi{Creusez-vous habilement des maisons dans les montagnes?\qt@no{(149)}}
\qt@newcmd\qurantrans@fr@mmmlxxxii{Craignez Allah donc et obéissez-moi.\qt@no{(150)}}
\qt@newcmd\qurantrans@fr@mmmlxxxiii{N'obéissez pas à l'ordre des outranciers,\qt@no{(151)}}
\qt@newcmd\qurantrans@fr@mmmlxxxiv{qui sèment le désordre sur la terre et n'améliorent rien».\qt@no{(152)}}
\qt@newcmd\qurantrans@fr@mmmlxxxv{Ils dirent: «Tu n'es qu'un ensorcelé.\qt@no{(153)}}
\qt@newcmd\qurantrans@fr@mmmlxxxvi{Tu n'es qu'un homme comme nous. Apporte donc un prodige, si tu es du nombre des véridiques».\qt@no{(154)}}
\qt@newcmd\qurantrans@fr@mmmlxxxvii{Il dit: «Voici une chamelle: à elle de boire un jour convenu, et à vous de boire un jour.\qt@no{(155)}}
\qt@newcmd\qurantrans@fr@mmmlxxxviii{Et ne lui infligez aucun mal, sinon le châtiment d'un jour terrible vous saisira».\qt@no{(156)}}
\qt@newcmd\qurantrans@fr@mmmlxxxix{Mais ils la tuèrent. Eh bien, ils eurent à regretter!\qt@no{(157)}}
\qt@newcmd\qurantrans@fr@mmmxc{Le châtiment, en effet, les saisit. Voilà bien là un prodige. Cependant, la plupart d'entre eux ne croient pas.\qt@no{(158)}}
\qt@newcmd\qurantrans@fr@mmmxci{Et ton Seigneur, c'est en vérité Lui le Tout Puissant, le Très Miséricordieux.\qt@no{(159)}}
\qt@newcmd\qurantrans@fr@mmmxcii{Le peuple de Lot traita de menteurs les Messagers,\qt@no{(160)}}
\qt@newcmd\qurantrans@fr@mmmxciii{quand leur frère Lot leur dit: «Ne craindrez-vous pas [Allah]?\qt@no{(161)}}
\qt@newcmd\qurantrans@fr@mmmxciv{Je suis pour vous un messager digne de confiance.\qt@no{(162)}}
\qt@newcmd\qurantrans@fr@mmmxcv{Craignez Allah donc et obéissez-moi.\qt@no{(163)}}
\qt@newcmd\qurantrans@fr@mmmxcvi{Je ne vous demande pas de salaire pour cela; mon salaire n'incombe qu'au Seigneur de l'univers.\qt@no{(164)}}
\qt@newcmd\qurantrans@fr@mmmxcvii{Accomplissez-vous l'acte charnel avec les mâles de ce monde?\qt@no{(165)}}
\qt@newcmd\qurantrans@fr@mmmxcviii{Et délaissez-vous les épouses que votre Seigneur a créées pour vous? Mais vous n'êtes que des gens transgresseurs».\qt@no{(166)}}
\qt@newcmd\qurantrans@fr@mmmxcix{Ils dirent: «Si tu ne cesses pas, Lot, tu seras certainement du nombre des expulsés».\qt@no{(167)}}
\qt@newcmd\qurantrans@fr@mmmc{Il dit: «Je déteste vraiment ce que vous faites.\qt@no{(168)}}
\qt@newcmd\qurantrans@fr@mmmci{Seigneur, sauve-moi ainsi que ma famille de ce qu'ils font».\qt@no{(169)}}
\qt@newcmd\qurantrans@fr@mmmcii{Nous le sauvâmes alors, lui et toute sa famille,\qt@no{(170)}}
\qt@newcmd\qurantrans@fr@mmmciii{sauf une vieille qui fut parmi les exterminés.\qt@no{(171)}}
\qt@newcmd\qurantrans@fr@mmmciv{Puis Nous détruisîmes les autres;\qt@no{(172)}}
\qt@newcmd\qurantrans@fr@mmmcv{et Nous fîmes pleuvoir sur eux une pluie (de pierres). Et quelle pluie fatale pour ceux qui sont avertis!\qt@no{(173)}}
\qt@newcmd\qurantrans@fr@mmmcvi{Voilà bien là un prodige. Cependant, la plupart d'entre eux ne croient pas.\qt@no{(174)}}
\qt@newcmd\qurantrans@fr@mmmcvii{Et ton Seigneur, c'est en vérité Lui le Tout Puissant, le Très Miséricordieux.\qt@no{(175)}}
\qt@newcmd\qurantrans@fr@mmmcviii{Les gens d'Al-Ayka traitèrent de menteurs les Messagers.\qt@no{(176)}}
\qt@newcmd\qurantrans@fr@mmmcix{Lorsque Chuayb leur dit: «Ne craindrez-vous pas [Allah]».\qt@no{(177)}}
\qt@newcmd\qurantrans@fr@mmmcx{Je suis pour vous un messager digne de confiance.\qt@no{(178)}}
\qt@newcmd\qurantrans@fr@mmmcxi{Craignez Allah donc et obéissez-moi,\qt@no{(179)}}
\qt@newcmd\qurantrans@fr@mmmcxii{et je ne vous demande pas de salaire pour cela; mon salaire n'incombe qu'au Seigneur de l'univers.\qt@no{(180)}}
\qt@newcmd\qurantrans@fr@mmmcxiii{Donnez la pleine mesure et n'en faites rien perdre [aux gens].\qt@no{(181)}}
\qt@newcmd\qurantrans@fr@mmmcxiv{et pesez avec une balance exacte.\qt@no{(182)}}
\qt@newcmd\qurantrans@fr@mmmcxv{Ne donnez pas aux gens moins que leur dû; et ne commettez pas de désordre et de corruption sur terre.\qt@no{(183)}}
\qt@newcmd\qurantrans@fr@mmmcxvi{Et craignez Celui qui vous a créés, vous et les anciennes générations».\qt@no{(184)}}
\qt@newcmd\qurantrans@fr@mmmcxvii{Ils dirent: «Tu es certes du nombre des ensorcelés;\qt@no{(185)}}
\qt@newcmd\qurantrans@fr@mmmcxviii{Tu n'es qu'un homme comme nous; et vraiment nous pensons que tu es du nombre des menteurs.\qt@no{(186)}}
\qt@newcmd\qurantrans@fr@mmmcxix{Fais donc tomber sur nous des morceaux du ciel si tu es du nombre des véridiques!»\qt@no{(187)}}
\qt@newcmd\qurantrans@fr@mmmcxx{Il dit: «Mon Seigneur sait mieux ce que vous faites».\qt@no{(188)}}
\qt@newcmd\qurantrans@fr@mmmcxxi{Mais ils le traitèrent de menteur. Alors, le châtiment du jour de l'Ombre les saisit. Ce fut le châtiment d'un jour terrible.\qt@no{(189)}}
\qt@newcmd\qurantrans@fr@mmmcxxii{Voilà bien là un prodige. Cependant, la plupart d'entre eux ne croient pas.\qt@no{(190)}}
\qt@newcmd\qurantrans@fr@mmmcxxiii{Et ton Seigneur, c'est en vérité Lui le Tout Puissant, le Très Miséricordieux.\qt@no{(191)}}
\qt@newcmd\qurantrans@fr@mmmcxxiv{Ce (Coran) ci, c'est le Seigneur de l'univers qui l'a fait descendre,\qt@no{(192)}}
\qt@newcmd\qurantrans@fr@mmmcxxv{et l'Esprit fidèle est descendu avec cela\qt@no{(193)}}
\qt@newcmd\qurantrans@fr@mmmcxxvi{sur ton cœur, pour que tu sois du nombre des avertisseurs,\qt@no{(194)}}
\qt@newcmd\qurantrans@fr@mmmcxxvii{en une langue arabe très claire.\qt@no{(195)}}
\qt@newcmd\qurantrans@fr@mmmcxxviii{Et ceci était déjà mentionné dans les Ecrits des anciens (envoyés).\qt@no{(196)}}
\qt@newcmd\qurantrans@fr@mmmcxxix{N'est-ce pas pour eux un signe, que les savants des Enfants d'Israël le sachent?\qt@no{(197)}}
\qt@newcmd\qurantrans@fr@mmmcxxx{Si Nous l'avions fait descendre sur quelqu'un des non-Arabes,\qt@no{(198)}}
\qt@newcmd\qurantrans@fr@mmmcxxxi{et que celui-ci le leur eut récité, ils n'y auraient pas cru.\qt@no{(199)}}
\qt@newcmd\qurantrans@fr@mmmcxxxii{Ainsi l'avons Nous fait pénétrer [le doute] dans les cœurs des criminels;\qt@no{(200)}}
\qt@newcmd\qurantrans@fr@mmmcxxxiii{mais ils n'y [le Coran] croiront pas avant de voir le châtiment douloureux,\qt@no{(201)}}
\qt@newcmd\qurantrans@fr@mmmcxxxiv{qui viendra sur eux soudain, sans qu'ils s'en rendent compte;\qt@no{(202)}}
\qt@newcmd\qurantrans@fr@mmmcxxxv{alors ils diront: «Est-ce qu'on va nous donner du répit?»\qt@no{(203)}}
\qt@newcmd\qurantrans@fr@mmmcxxxvi{Est-ce qu'ils cherchent à hâter Notre châtiment?\qt@no{(204)}}
\qt@newcmd\qurantrans@fr@mmmcxxxvii{Vois-tu si Nous leur permettions de jouir, des années durant,\qt@no{(205)}}
\qt@newcmd\qurantrans@fr@mmmcxxxviii{et qu'ensuite leur arrive ce dont on les menaçait,\qt@no{(206)}}
\qt@newcmd\qurantrans@fr@mmmcxxxix{les jouissances qu'on leur a permises ne leur serviraient à rien.\qt@no{(207)}}
\qt@newcmd\qurantrans@fr@mmmcxl{Et Nous ne faisons pas périr de cité avant qu'elle n'ait eu des avertisseurs,\qt@no{(208)}}
\qt@newcmd\qurantrans@fr@mmmcxli{[à titre de] rappel, et Nous ne sommes pas injuste.\qt@no{(209)}}
\qt@newcmd\qurantrans@fr@mmmcxlii{Et ce ne sont point les diables qui sont descendus avec ceci (le Coran):\qt@no{(210)}}
\qt@newcmd\qurantrans@fr@mmmcxliii{cela ne leur convient pas; et ils n'auraient pu le faire.\qt@no{(211)}}
\qt@newcmd\qurantrans@fr@mmmcxliv{Car ils sont écartés de toute écoute (du message divin).\qt@no{(212)}}
\qt@newcmd\qurantrans@fr@mmmcxlv{N'invoque donc pas une autre divinité avec Allah, sinon tu seras du nombre des châtiés.\qt@no{(213)}}
\qt@newcmd\qurantrans@fr@mmmcxlvi{Et avertis les gens qui te sont les plus proches.\qt@no{(214)}}
\qt@newcmd\qurantrans@fr@mmmcxlvii{Et abaisse ton aile [sois bienveillant] pour les croyants qui te suivent.\qt@no{(215)}}
\qt@newcmd\qurantrans@fr@mmmcxlviii{Mais s'ils te désobéissent, dis-leur: «Moi, je désavoue ce que vous faites».\qt@no{(216)}}
\qt@newcmd\qurantrans@fr@mmmcxlix{Et place ta confiance dans le Tout Puissant, le Très Miséricordieux,\qt@no{(217)}}
\qt@newcmd\qurantrans@fr@mmmcl{qui te voit quand tu te lèves,\qt@no{(218)}}
\qt@newcmd\qurantrans@fr@mmmcli{et (voit) tes gestes parmi ceux qui se prosternent.\qt@no{(219)}}
\qt@newcmd\qurantrans@fr@mmmclii{C'est Lui vraiment, l'Audient, l'Omniscient.\qt@no{(220)}}
\qt@newcmd\qurantrans@fr@mmmcliii{Vous apprendrai-Je sur qui les diables descendent?\qt@no{(221)}}
\qt@newcmd\qurantrans@fr@mmmcliv{Ils descendent sur tout calomniateur, pécheur.\qt@no{(222)}}
\qt@newcmd\qurantrans@fr@mmmclv{Ils tendent l'oreille... Cependant, la plupart d'entre eux sont menteurs.\qt@no{(223)}}
\qt@newcmd\qurantrans@fr@mmmclvi{Et quant aux poètes, ce sont les égarés qui les suivent.\qt@no{(224)}}
\qt@newcmd\qurantrans@fr@mmmclvii{Ne vois-tu pas qu'ils divaguent dans chaque vallée,\qt@no{(225)}}
\qt@newcmd\qurantrans@fr@mmmclviii{et qu'ils disent ce qu'ils ne font pas?\qt@no{(226)}}
\qt@newcmd\qurantrans@fr@mmmclix{à part ceux qui croient et font de bonnes œuvres, qui invoquent souvent le nom d'Allah et se défendent contre les torts qu'on leur fait. Les injustes verront bientôt le revirement qu'ils [éprouveront]!\qt@no{(227)}}
\qt@newcmd\qurantrans@fr@mmmclx{\basmalahfr T'â, Sîn. Voici les versets du Coran et d'un Livre explicite,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmclxi{un guide et une bonne annonce aux croyants,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmclxii{qui accomplissent la Salât, acquittent la Zakât et croient avec certitude en l'au-delà.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmclxiii{Quant à ceux qui ne croient pas en l'au-delà, Nous embellissons [à leurs yeux] leurs actions, et alors ils deviennent confus et hésitants.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmclxiv{Ce sont eux qui subiront le pire châtiment, tandis qu'ils seront dans l'au-delà les plus grands perdants.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmclxv{Certes, c'est toi qui reçois le Coran, de la part d'un Sage, d'un Savant.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmclxvi{(Rappelle) quand Moïse dit à sa famille: «J'ai aperçu un feu; je vais vous en apporter des nouvelles, ou bien je vous apporterai un tison allumé afin que vous vous réchauffiez».\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmclxvii{Lorsqu'il y arriva, on l'appela, - béni soit Celui qui est dans le feu et Celui qui est tout autour, et gloire à Allah, Seigneur de l'univers.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmclxviii{«O Moïse, c'est Moi, Allah le Tout Puissant, le Sage».\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmclxix{Et: «Jette ton bâton». Quand il le vit remuer comme un serpent, il tourna le dos [pour fuir] sans revenir sur ses pas. «N'aie pas peur, Moïse. Les Messagers n'ont point peur auprès de Moi.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmclxx{Sauf celui qui a commis une injustice puis a remplacé le mal par le bien... alors Je suis Pardonneur et Miséricordieux».\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmclxxi{Et introduis ta main dans l'ouverture de ta tunique. Elle sortira blanche et sans aucun mal - un des neuf prodiges à Pharaon et à son peuple, car ils sont vraiment des gens pervers» -.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmclxxii{Et lorsque Nos prodiges leur parvinrent, clairs et explicites, ils dirent: «C'est là une magie évidente!»\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmclxxiii{Ils les nièrent injustement et orgueilleusement, tandis qu'en eux-mêmes ils y croyaient avec certitude. Regarde donc ce qu'il est advenu des corrupteurs.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmclxxiv{Nous avons effectivement donné à David et à Salomon une science; et ils dirent: «Louange à Allah qui nous a favorisés à beaucoup de Ses serviteurs croyants».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmclxxv{Et Salomon hérita de David et dit: «O hommes! On nous a appris le langage des oiseaux; et on nous a donné part de toutes choses. C'est là vraiment la grâce évidente.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmclxxvi{Et furent rassemblées pour Salomon, ses armées de djinns, d'hommes et d'oiseaux, et furent placées en rangs.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmclxxvii{Quand ils arrivèrent à la Vallée des Fourmis, une fourmi dit: «O fourmis, entrez dans vos demeures, [de peur] que Salomon et ses armées ne vous écrasent [sous leurs pieds] sans s'en rendre compte».\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmclxxviii{Il sourit, amusé par ses propos et dit: «Permets-moi Seigneur, de rendre grâce pour le bienfait dont Tu m'as comblé ainsi que mes père et mère, et que je fasse une bonne œuvre que tu agrées et fais-moi entrer, par Ta miséricorde, parmi Tes serviteurs vertueux».\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmclxxix{Puis il passa en revue les oiseaux et dit: «Pourquoi ne vois-je pas la huppe? est-elle parmi les absents?\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmclxxx{Je la châtierai sévèrement! ou je l'égorgerai! ou bien elle m'apportera un argument explicite».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmclxxxi{Mais elle n'était restée (absente) que peu de temps et dit: «J'ai appris ce que tu n'as point appris; et je te rapporte de Saba' une nouvelle sûre:\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmclxxxii{J'ai trouvé qu'une femme est leur reine, que de toute chose elle a été comblée et qu'elle a un trône magnifique.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmclxxxiii{Je l'ai trouvée, elle et son peuple, se prosternant devant le soleil au lieu d'Allah. Le Diable leur a embelli leurs actions, et les a détournés du droit chemin, et ils ne sont pas bien guidés.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmclxxxiv{Que ne se prosternent-ils devant Allah qui fait sortir ce qui est caché dans les cieux et la terre, et qui sait ce que vous cachez et aussi ce que vous divulguez?\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmclxxxv{Allah! Point de divinité à part Lui, le Seigneur du Trône Immense.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmclxxxvi{Alors, Salomon dit: «Nous allons voir si tu as dis la vérité ou si tu as menti.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmclxxxvii{Pars avec ma lettre que voici; puis lance-la à eux; ensuite tiens-toi à l'écart d'eux pour voir ce que sera leur réponse.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmclxxxviii{La reine dit: «O notables! Une noble lettre m'a été lancée.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmclxxxix{Elle vient de Salomon; et c'est: «Au nom d'Allah, le Tout Miséricordieux, le Très Miséricordieux,\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmcxc{Ne soyez pas hautains avec moi et venez à moi en toute soumission».\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmcxci{Elle dit: «O notables! Conseillez-moi sur cette affaire: je ne déciderai rien sans que vous ne soyez présents (pour me conseiller)».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmcxcii{Ils dirent: «Nous sommes détenteurs d'une force et d'une puissance redoutable. Le commandement cependant t'appartient. Regarde donc ce que tu veux ordonner».\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmcxciii{Elle dit: «En vérité, quand les rois entrent dans une cité ils la corrompent, et font de ses honorables citoyens des humiliés. Et c'est ainsi qu'ils agissent.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmcxciv{Moi, je vais leur envoyer un présent, puis je verrai ce que les envoyés ramèneront».\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmcxcv{Puis, lorsque [la délégation] arriva auprès de Salomon, celui-ci dit: «Est-ce avec des biens que vous voulez m'aider? alors que ce qu'Allah m'a procuré est meilleur que ce qu'Il vous a procuré. Mais c'est vous plutôt qui vous réjouissez de votre cadeau.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmcxcvi{Retourne vers eux. Nous viendrons avec des armées contre lesquelles ils n'auront aucune résistance, et nous les en expulserons tout humiliés et méprisés.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmcxcvii{Il dit: «O notables! Qui de vous m'apportera son trône avant qu'ils ne viennent à moi soumis?»\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmcxcviii{Un djinn redoutable dit: «Je te l'apporterai avant que tu ne te lèves de ta place: pour cela, je suis fort et digne de confiance».\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmcxcix{Quelqu'un qui avait une connaissance du Livre dit: «Je te l'apporterai avant que tu n'aies cligné de l'œil». Quand ensuite, Salomon a vu le trône installé auprès de lui, il dit: «Cela est de la grâce de mon Seigneur, pour m'éprouver si je suis reconnaissant ou si je suis ingrat. Quiconque est reconnaissant c'est dans son propre intérêt qu'il le fait, et quiconque est ingrat... alors mon Seigneur Se suffit à Lui-même et Il est Généreux».\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmcc{Et il dit [encore]: «Rendez-lui son trône méconnaissable, nous verrons alors si elle sera guidée ou si elle est du nombre de ceux qui ne sont pas guidés».\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmcci{Quand elle fut venue on lui dit: «Est-ce que ton trône est ainsi?» Elle dit: «C'est comme s'il l'était». - [Salomon dit]: «Le savoir nous a été donné avant elle; et nous étions déjà soumis».\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmccii{Or, ce qu'elle adorait en dehors d'Allah l'empêchait (d'être croyante) car elle faisait partie d'un peuple mécréant.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmcciii{On lui dit: «Entre dans le palais». Puis, quand elle le vit, elle le prit pour de l'eau profonde et elle se découvrit les jambes. Alors, [Salomon] lui dit: «Ceci est un palais pavé de cristal». - Elle dit: «Seigneur, je me suis fait du tort à moi-même: Je me soumets avec Salomon à Allah, Seigneur de l'univers».\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmcciv{Nous envoyâmes effectivement vers les Thamûd leur frère Sâlih. [qui leur dit]: «Adorez Allah». Et voilà qu'ils se divisèrent en deux groupes qui se disputèrent.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmccv{Il dit: «O mon peuple, pourquoi cherchez-vous à hâter le mal plutôt que le bien? Si seulement vous demandiez pardon à Allah? Peut-être vous serait-il fait miséricorde.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmccvi{Ils dirent: «Nous voyons en toi et en ceux qui sont avec toi, des porteurs de malheur». Il dit: «Votre sort dépend d'Allah. Mais vous êtes plutôt des gens qu'on soumet à la tentation.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmccvii{Et il y avait dans la ville un groupe de neuf individus qui semaient le désordre sur terre et ne faisaient rien de bon.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmccviii{Ils dirent: «Jurons par Allah que nous l'attaquerons de nuit, lui et sa famille. Ensuite nous dirons à celui qui est chargé de le venger: «Nous n'avons pas assisté à l'assassinat de sa famille, et nous sommes sincères».\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmccix{Ils ourdirent une ruse et Nous ourdîmes une ruse sans qu'ils s'en rendent compte.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmccx{Regarde donc ce qu'a été la conséquence de leur stratagème: Nous les fîmes périr, eux et tout leur peuple.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmccxi{Voilà donc leurs maisons désertes à cause de leurs méfaits. C'est bien là un avertissement pour des gens qui savent.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmccxii{Et Nous sauvâmes ceux qui avaient cru et étaient pieux.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmccxiii{[Et rappelle-leur] Lot, quand il dit à son peuple: «Vous livrez-vous à la turpitude [l'homosexualité] alors que vous voyez clair».\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmccxiv{Vous allez aux hommes au lieu de femmes pour assouvir vos désirs? Vous êtes plutôt un peuple ignorant.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmccxv{Puis son peuple n'eut que cette réponse: «Expulsez de votre cité la famille de Lot! Car ce sont des gens qui affectent la pureté.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmccxvi{Nous le sauvâmes ainsi que sa famille, sauf sa femme pour qui Nous avions déterminé qu'elle serait du nombre des exterminés.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmccxvii{Et Nous fîmes pleuvoir sur eux une pluie (de pierres). Et quelle mauvaise pluie que celle des gens prévenus!\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmccxviii{Dis: «Louange à Allah et paix sur Ses serviteurs qu'Il a élus!» Lequel est meilleur: Allah ou bien ce qu'ils Lui associent?\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmccxix{N'est-ce pas Lui qui a créé les cieux et la terre et qui vous a fait descendre du ciel une eau avec laquelle Nous avons fait pousser des jardins pleins de beauté. Vous n'étiez nullement capables de faire pousser leurs arbres. Y a-t-il donc une divinité avec Allah? Non, mais ce sont des gens qui Lui donnent des égaux.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmccxx{N'est-ce pas Lui qui a établi la terre comme lieu de séjour, placé des rivières à travers elle, lui a assigné des montagnes fermes et établi une séparation entre les deux mers, - Y a-t-il donc une divinité avec Allah? Non, mais la plupart d'entre eux ne savent pas.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmccxxi{N'est-ce pas Lui qui répond à l'angoissé quand il L'invoque, et qui enlève le mal, et qui vous fait succéder sur la terre, génération après génération, - Y a-t-il donc une divinité avec Allah? C'est rare que vous vous rappeliez!\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmccxxii{N'est-ce pas Lui qui vous guide dans les ténèbres de la terre et de la mer, et qui envoie les vents, comme une bonne annonce précédent Sa grâce. - Y a-t-il donc une divinité avec Allah? Allah est Très Elevé au-dessus de ce qu'ils [Lui] associent.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmccxxiii{N'est-ce pas Lui qui commence la création, puis la refait, et qui vous nourrit du ciel et de la terre. Y a-t-il donc une divinité avec Allah? Dis: «Apportez votre preuve, si vous êtes véridiques!»\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmccxxiv{Dis: «Nul de ceux qui sont dans les cieux et sur la terre ne connaît l'Inconnaissable, à part Allah». Et ils ne savent pas quand ils seront ressuscités!\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmccxxv{Mais leurs sciences se sont rejointes au sujet de l'autre monde. Ils doutent plutôt là-dessus. Ou plutôt ils sont aveugles à son sujet.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmccxxvi{Et ceux qui ne croient pas disent: «Est-ce que, quand nous serons poussière, nous et nos pères, est-ce que vraiment on nous fera sortir (de nos tombes)?\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmccxxvii{Certes, on nous l'a promis à nous et à nos pères, auparavant. Ce ne sont que des contes d'anciens!»\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmccxxviii{Dis: «Parcourez la terre et voyez ce qu'il est advenu des criminels».\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmccxxix{Et ne t'afflige pas sur eux et ne sois pas angoissé à cause de leur complot.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmccxxx{Et ils disent: «Pour quand cette promesse si vous êtes véridiques?»\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmccxxxi{Dis: «Il se peut qu'une partie de ce que vous cherchez à hâter soit déjà sur vos talons».\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmccxxxii{Certes, ton Seigneur est pourvoyeur de grâce aux hommes, mais la plupart d'entre eux ne sont pas reconnaissants.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmccxxxiii{Certes, ton Seigneur sait ce que cachent leurs poitrines et ce qu'ils divulguent.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmccxxxiv{Et il n'y a rien de caché, dans le ciel et la terre, qui ne soit dans un Livre explicite.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmccxxxv{Ce Coran raconte aux Enfants d'Israël la plupart des sujets sur lesquels ils divergent,\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmccxxxvi{cependant qu'il est pour les croyants un guide et une miséricorde.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmccxxxvii{Ton Seigneur décidera certes entre eux par Son jugement; et Il est le Tout Puissant, le Sage.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmccxxxviii{Place donc ta confiance en Allah, car tu es de toute évidence dans la vérité et le bon droit.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmmccxxxix{Tu ne peux faire entendre les morts ni faire entendre l'appel aux sourds quand ils s'enfuient en tournant le dos.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmmccxl{Et tu ne peux non plus guider les aveugles hors de leur égarement. Tu ne feras entendre que ceux qui croient en Nos versets et se soumettent.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmmccxli{Et quand la Parole tombera sur eux, Nous leur ferons sortir de terre une bête qui leur parlera; les gens n'étaient nullement convaincus de la vérité de Nos signes [ou versets].\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmmccxlii{Et le jour où Nous rassemblerons, de chaque communauté, une foule de ceux qui démentaient Nos révélations, et qu'ils seront placés en rangs.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmmccxliii{puis, quand ils seront arrivés, [Allah] dira: «Avez-vous traité de mensonges Mes signes sans les avoir embrassés de votre savoir? Ou que faisiez-vous donc?»\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmmccxliv{Et la Parole leur tombera dessus à cause de leurs méfaits. Et ils ne pourront rien dire.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmmccxlv{N'ont-ils pas vu qu'en vérité, Nous avons désigné la nuit pour qu'ils y aient du repos, et le jour pour voir? Voilà bien des preuves pour des gens qui croient.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmmccxlvi{Et le jour où l'on soufflera dans la Trompe, tous ceux qui sont dans les cieux et ceux qui sont dans la terre seront effrayés, - sauf ceux qu'Allah a voulu [préserver]! - Et tous viendront à Lui en s'humiliant.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmmccxlvii{Et tu verras les montagnes - tu les crois figées - alors qu'elles passent comme des nuages. Telle est l'œuvre d'Allah qui a tout façonné à la perfection. Il est Parfaitement Connaisseur de ce que vous faites!\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmmccxlviii{Quiconque viendra avec le bien aura bien mieux, et ce jour-là, ils seront à l'abri de tout effroi.\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmmccxlix{Et quiconque viendra avec le mal... alors ils seront culbutés le visage dans le Feu. N'êtes-vous pas uniquement rétribués selon ce que vous œuvriez?»\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmmccl{«Il m'a été seulement commandé d'adorer le Seigneur de cette Ville (la Mecque) qu'Il a sanctifiée, - et à Lui toute chose - et il m'a été commandé d'être du nombre des Musulmans,\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmmccli{et de réciter le Coran». Quiconque se guide, c'est pour lui-même en effet qu'il se guide. Et quiconque s'égare..., alors dis: «Je ne suis que l'un des avertisseurs».\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmmcclii{Dis: «Louange à Allah! Il vous fera voir Ses preuves, et vous les reconnaîtrez». Ton Seigneur n'est pas inattentif à ce que vous faites.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmmccliii{\basmalahfr T'â, Sîn, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmccliv{Voici les versets du Livre explicite.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmcclv{Nous te racontons en toute vérité, de l'histoire de Moïse et de Pharaon, à l'intention des gens qui croient.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmcclvi{Pharaon était hautain sur terre; il répartit en clans ses habitants, afin d'abuser de la faiblesse de l'un d'eux: Il égorgeait leurs fils et laissait vivantes leurs femmes. Il était vraiment parmi les fauteurs de désordre.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmcclvii{Mais Nous voulions favoriser ceux qui avaient été faibles sur terre et en faire des dirigeants et en faire les héritiers,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmcclviii{et les établir puissamment sur terre, et faire voir à Pharaon, à Hâmân, et à leurs soldats, ce dont ils redoutaient.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmcclix{Et Nous révélâmes à la mère de Moïse [ceci]: «Allaite-le. Et quand tu craindras pour lui, jette-le dans le flot. Et n'aie pas peur et ne t'attriste pas: Nous te le rendrons et ferons de lui un Messager».\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmcclx{Les gens de Pharaon le recueillirent, pour qu'il leur soit un ennemi et une source d'affliction! Pharaon, Hâmân et leurs soldats étaient fautifs.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmcclxi{Et la femme de Pharaon dit: «(Cet enfant) réjouira mon œil et le tien! Ne le tuez pas. Il pourrait nous être utile ou le prendrons-nous pour enfant». Et ils ne pressentaient rien.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmcclxii{Et le cœur de la mère de Moïse devint vide. Peu s'en fallut qu'elle ne divulguât tout, si Nous n'avions pas renforcé son cœur pour qu'elle restât du nombre des croyants.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmcclxiii{Elle dit à sa sœur: «Suis-le» elle l'aperçut alors de loin sans qu'ils ne s'en rendent compte.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmcclxiv{Nous lui avions interdit auparavant (le sein) des nourrices. Elle (la sœur de Moïse) dit donc: «Voulez-vous que je vous indique les gens d'une maison qui s'en chargeront pour vous tout en étant bienveillants à son égard?»...\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmcclxv{Ainsi Nous le rendîmes à sa mère, afin que son œil se réjouisse, qu'elle ne s'affligeât pas et qu'elle sût que la promesse d'Allah est vraie. Mais la plupart d'entre eux ne savent pas.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmcclxvi{Et quand il eut atteint sa maturité et sa pleine formation, Nous lui donnâmes la faculté de juger et une science. C'est ainsi que Nous récompensons les bienfaisants.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmcclxvii{Il entra dans la ville à un moment d'inattention de ses habitants; il y trouva deux hommes qui se battaient, l'un était de ses partisans et l'autre de ses adversaires. L'homme de son parti l'appela au secours contre son ennemi. Moïse lui donna un coup de poing qui l'acheva. - [Moïse] dit: «Cela est l'œuvre du Diable. C'est vraiment un ennemi, un égareur évident».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmcclxviii{Il dit: «Seigneur, je me suis fait du tort à moi-même; pardonne-moi». Et Il lui pardonna. C'est Lui vraiment le Pardonneur, le Miséricordieux!\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmcclxix{Il dit: «Seigneur, grâce aux bienfaits dont tu m'as comblé, jamais je ne soutiendrai les criminels».\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmcclxx{Le lendemain matin, il se trouva en ville, craintif et regardant autour de lui, quand voilà que celui qui lui avait demandé secours la veille, l'appelait à grands cris. Moïse lui dit: «Tu es certes un provocateur déclaré».\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmcclxxi{Quand il voulut porter un coup à leur ennemi commun, il (l'Israélite) dit: «O Moïse, veux-tu me tuer comme tu as tué un homme hier? Tu ne veux être qu'un tyran sur terre; et tu ne veux pas être parmi les bienfaiteurs».\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmcclxxii{Et c'est alors qu'un homme vint du bout de la ville en courant et dit: «O Moïse, les notables sont en train de se concerter à ton sujet pour te tuer. Quitte (la ville). C'est le conseil que je te donne».\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmcclxxiii{Il sortit de là, craintif, regardant autour de lui. Il dit: «Seigneur, sauve-moi de [ce] peuple injuste!»\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmcclxxiv{Et lorsqu'il se dirigea vers Madyan, il dit: «Je souhaite que mon Seigneur me guide sur la voie droite».\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmcclxxv{Et quand il fut arrivé au point d'eau de Madyan, il y trouva un attroupement de gens abreuvant [leurs bêtes] et il trouva aussi deux femmes se tenant à l'écart et retenant [leurs bêtes]. Il dit: «Que voulez-vous?» Elles dirent: «Nous n'abreuverons que quand les bergers seront partis; et notre père est fort âgé».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmcclxxvi{Il abreuva [les bêtes] pour elles puis retourna à l'ombre et dit: «Seigneur, j'ai grand besoin du bien que tu feras descendre vers moi».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmcclxxvii{Puis l'une des deux femmes vint à lui, d'une démarche timide, et lui dit: «Mon père t'appelle pour te récompenser pour avoir abreuvé pour nous». Et quand il fut venu auprès de lui et qu'il lui eut raconté son histoire, il (le vieillard) dit: «N'aie aucune crainte: tu as échappé aux gens injustes».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmcclxxviii{L'une d'elles dit: «O mon père, engage-le [à ton service] moyennant salaire, car le meilleur à engager c'est celui qui est fort et digne de confiance».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmcclxxix{Il dit: «Je voudrais te marier à l'une de mes deux filles que voici, à condition que tu travailles à mon service durant huit ans. Si tu achèves dix [années], ce sera de ton bon gré; je ne veux cependant rien t'imposer d'excessif. Tu me trouveras, si Allah le veut, du nombre des gens de bien».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmcclxxx{«C'est (conclu) entre toi et moi, dit [Moïse]. Quel que soit celui des deux termes que je m'assigne, il n'y aura nulle pression sur moi. Et Allah est Garant de ce que nous disons».\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmcclxxxi{Puis, lorsque Moïse eut accompli la période convenue et qu'il se mit en route avec sa famille, il vit un feu du côté du Mont. Il dit à sa famille: «Demeurez ici. J'ai vu du feu. Peut-être vous en apporterai-je une nouvelle ou un tison de feu afin que vous vous réchauffiez».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmcclxxxii{Puis quand il y arriva, on l'appela, du flanc droit de la vallée, dans la place bénie, à partir de l'arbre: «O Moïse! C'est Moi Allah, le Seigneur de l'univers».\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmcclxxxiii{Et: «Jette ton bâton» Puis quand il le vit remuer comme si c'était un serpent, il tourna le dos sans même se retourner. «O Moïse! Approche et n'aie pas peur: tu es du nombre de ceux qui sont en sécurité.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmcclxxxiv{Introduis ta main dans l'ouverture de ta tunique: elle sortira blanche sans aucun mal. Et serre ton bras contre toi pour ne pas avoir peur. Voilà donc deux preuves de ton Seigneur pour Pharaon et ses notables. Ce sont vraiment des gens pervers».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmcclxxxv{«Seigneur, dit [Moïse], j'ai tué un des leurs et je crains qu'ils ne me tuent.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmcclxxxvi{Mais Aaron, mon frère, est plus éloquent que moi. Envoie-le donc avec moi comme auxiliaire, pour déclarer ma véracité: je crains, vraiment, qu'ils ne me traitent de menteur».\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmcclxxxvii{[Allah] dit: «Nous allons, par ton frère, fortifier ton bras, et vous donner des arguments irréfutables; ils ne sauront vous atteindre, grâce à Nos signes [Nos miracles]. Vous deux et ceux qui vous suivront seront les vainqueurs.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmcclxxxviii{Puis, quand Moïse vint à eux avec Nos prodiges évidents, ils dirent: «Ce n'est là que magie inventée. Jamais nous n'avons entendu parler de cela chez nos premiers ancêtres».\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmcclxxxix{Et Moïse dit: «Mon Seigneur connaît mieux qui est venu de Sa part avec la guidée, et à qui appartiendra la Demeure finale. Vraiment, les injustes ne réussiront pas».\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmccxc{Et Pharaon dit: «O notables, je ne connais pas de divinité pour vous, autre que moi. Hâmân, allume-moi du feu sur l'argile puis construis-moi une tour peut-être alors monterai-je jusqu'au Dieu de Moïse. Je pense plutôt qu'il est du nombre des menteurs».\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmccxci{Et il s'enfla d'orgueil sur terre ainsi que ses soldats, sans aucun droit. Et ils pensèrent qu'ils ne seraient pas ramenés vers Nous.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmccxcii{Nous le saisîmes donc, ainsi que ses soldats, et les jetâmes dans le flot. Regarde donc ce qu'il est advenu des injustes!\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmccxciii{Nous fîmes d'eux des dirigeants qui appellent les gens au Feu. Et au Jour de la Résurrection ils ne seront pas secourus.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmccxciv{Nous les fîmes suivre, dans cette vie ici-bas, d'une malédiction. Et au Jour de la Résurrection, ils seront parmi les honnis.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmccxcv{Nous avons en effet, donné le Livre à Moïse, - après avoir fait périr les anciennes générations, - en tant que preuves illuminantes pour les gens, ainsi que guidée et miséricorde afin qu'ils se souviennent.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmccxcvi{Tu n'étais pas sur le versant ouest (du Sinaï), quand Nous avons décrété les commandements à Moïse; tu n'étais pas parmi les témoins.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmccxcvii{Mais Nous avons fait naître des générations dont l'âge s'est prolongé. Et tu n'étais pas [non plus] résident parmi les gens de Madyan leur récitant Nos versets; mais c'est Nous qui envoyons les Messagers.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmccxcviii{Et tu n'étais pas au flanc du Mont Tor quand Nous avons appelé. Mais (tu es venu comme) une miséricorde de ton Seigneur, pour avertir un peuple à qui nul avertisseur avant toi n'est venu, afin qu'ils se souviennent.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmccxcix{Si un malheur les atteignait en rétribution de ce que leurs propres mains avaient préparé, ils diraient: «Seigneur, pourquoi ne nous as-Tu pas envoyé un Messager? Nous aurions alors suivi Tes versets et nous aurions été croyants».\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmccc{Mais quand la vérité leur est venue de Notre part, ils ont dit: «Si seulement il avait reçu la même chose que Moïse! «Est-ce qu'ils n'ont pas nié ce qui auparavant fut apporté à Moïse? Ils dirent: «Deux magies se sont mutuellement soutenues!» Et ils dirent: «Nous n'avons foi en aucune».\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmccci{Dis-leur: «Apportez donc un Livre venant d'Allah qui soit meilleur guide que ces deux-là, et je le suivrai si vous êtes véridiques».\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmcccii{Mais s'ils ne te répondent pas, sache alors que c'est seulement leurs passions qu'ils suivent. Et qui est plus égaré que celui qui suit sa passion sans une guidée d'Allah? Allah vraiment, ne guide pas les gens injustes.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmccciii{Nous leur avons déjà exposé la Parole (le Coran) afin qu'ils se souviennent.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmccciv{Ceux à qui, avant lui [le Coran], Nous avons apporté le Livre, y croient.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmcccv{Et quand on le leur récite, ils disent: «Nous y croyons. Ceci est bien la vérité émanant de notre Seigneur. Déjà avant son arrivée, nous étions Soumis».\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmcccvi{Voilà ceux qui recevront deux fois leur récompense pour leur endurance, pour avoir répondu au mal par le bien, et pour avoir dépensé de ce que Nous leur avons attribué;\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmcccvii{et quand ils entendent des futilités, ils s'en détournent et disent: «A nous nos actions, et à vous les vôtres. Paix sur vous. Nous ne recherchons pas les ignorants».\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmcccviii{Tu [Muhammad] ne diriges pas celui que tu aimes: mais c'est Allah qui guide qui Il veut. Il connaît mieux cependant les bien-guidés.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmcccix{Et ils dirent: «Si nous suivons avec toi la bonne voie, on nous arrachera de notre terre». - Ne les avons-Nous pas établis dans une enceinte sacrée, sûre, vers laquelle des produits de toute sorte sont apportés comme attribution de Notre part? Mais la plupart d'entre eux ne savent pas.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmcccx{Et combien avons-Nous fait périr de cités qui étaient ingrates (alors que leurs habitants vivaient dans l'abondance), et voilà qu'après eux leurs demeures ne sont que très peu habitées, et c'est Nous qui en fûmes l'héritier.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmcccxi{Ton Seigneur ne fait pas périr des cités avant d'avoir envoyé dans leur métropole un Messager pour leur réciter Nos versets. Et Nous ne faisons périr les cités que lorsque leurs habitants sont injustes.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmcccxii{Tout ce qui vous a été donné est la jouissance éphémère de la vie ici-bas et sa parure, alors que ce qui est auprès d'Allah est meilleur et plus durable... Ne comprenez-vous donc pas?\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmcccxiii{Celui à qui Nous avons fait une belle promesse dont il verra l'accomplissement, est-il comparable à celui à qui Nous avons accordé la jouissance de la vie présente et qui sera ensuite le Jour de la Résurrection, de ceux qui comparaîtront (devant Nous).\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmcccxiv{Et le jour où Il les appellera, Il dira: «Où sont ceux que vous prétendiez être Mes associés?»\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmcccxv{Ceux contre qui la Parole se réalisera diront: «Voici, Seigneur, ceux que nous avons séduits. Nous les avons séduits comme nous nous sommes dévoyés nous-mêmes. Nous les désavouons devant Toi: ce n'est pas nous qu'ils adoraient».\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmcccxvi{Et on [leur] dira: «Appelez vos associés». Ils les appelleront, mais ceux-ci ne leur répondront pas. Quand ils verront le châtiment, ils désireront alors avoir suivi le chemin droit (dans la vie d'ici-bas).\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmcccxvii{Et le jour où Il les appellera et qu'Il dira: «Que répondiez-vous aux Messagers?»\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmcccxviii{Ce jour-là, leurs arguments deviendront obscurs et ils ne se poseront point de questions.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmcccxix{Mais celui qui se sera repenti, qui aura cru et fait le bien, il se peut qu'il soit parmi ceux qui réussissent.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmcccxx{Ton Seigneur crée ce qu'Il veut et Il choisit; il ne leur a jamais appartenu de choisir. Gloire à Allah! Il transcende ce qu'ils associent à Lui!\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmcccxxi{Ton Seigneur sait ce que cachent leurs poitrines et ce qu'ils divulguent.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmcccxxii{C'est lui Allah. Pas de divinité à part Lui. A Lui la louange ici-bas comme dans l'au-delà. A Lui appartient le jugement. Et vers Lui vous serez ramenés.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmcccxxiii{Dis: «Que diriez-vous? Si Allah vous assignait la nuit en permanence jusqu'au Jour de la Résurrection, quelle divinité autre qu'Allah pourrait vous apporter une lumière? N'entendez-vous donc pas?»\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmcccxxiv{Dis: «Que diriez-vous? Si Allah vous assignait le jour en permanence jusqu'au Jour de la Résurrection, quelle divinité autre qu'Allah pourrait vous apporter une nuit durant laquelle vous reposeriez? N'observez-vous donc pas?»\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmcccxxv{C'est de par Sa miséricorde qu'Il vous a assigné la nuit et le jour: pour que vous vous y reposiez et cherchiez de Sa grâce, et afin que vous soyez reconnaissants.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmcccxxvi{Et le jour où Il les appellera, Il dira: «Où sont ceux que vous prétendiez être Mes associés?»\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmcccxxvii{Cependant, Nous ferons sortir de chaque communauté un témoin, puis Nous dirons: «Apportez votre preuve décisive». Ils sauront alors que la Vérité est à Allah; et que ce qu'ils avaient inventé les a abandonnés.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmcccxxviii{En vérité, Coré [Karoûn] était du peuple de Moïse mais il était empli de violence envers eux. Nous lui avions donné des trésors dont les clefs pesaient lourd à toute une bande de gens forts. Son peuple lui dit: «Ne te réjouis point. Car Allah n'aime pas les arrogants.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmcccxxix{Et recherche à travers ce qu'Allah t'a donné, la Demeure dernière. Et n'oublie pas ta part en cette vie. Et sois bienfaisant comme Allah a été bienfaisant envers toi. Et ne recherche pas la corruption sur terre. Car Allah n'aime point les corrupteurs».\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmcccxxx{Il dit: «C'est par une science que je possède que ceci m'est venu». Ne savait-il pas qu'avant lui Allah avait fait périr des générations supérieures à lui en force et plus riches en biens? Et les criminels ne seront pas interrogés sur leurs péchés»!\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmcccxxxi{Il sortit à son peuple dans tout son apparat. Ceux qui aimaient la vie présente dirent: «Si seulement nous avions comme ce qui a été donné à Coré. Il a été doté, certes, d'une immense fortune».\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmmcccxxxii{Tandis que ceux auxquels le savoir a été donné dirent: «Malheur à vous! La récompense d'Allah est meilleure pour celui qui croit et fait le bien». Mais elle ne sera reçue que par ceux qui endurent.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmmcccxxxiii{Nous fîmes donc que la terre l'engloutît, lui et sa maison. Aucun clan en dehors d'Allah ne fut là pour le secourir, et il ne pût se secourir lui-même.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmmcccxxxiv{Et ceux qui, la veille, souhaitaient d'être à sa place, se mirent à dire: «Ah! Il est vrai qu'Allah augmente la part de qui Il veut, parmi Ses serviteurs, ou la restreint. Si Allah ne nous avait pas favorisés, Il nous aurait certainement fait engloutir. Ah! Il est vrai que ceux qui ne croient pas ne réussissent pas».\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmmcccxxxv{Cette Demeure dernière, Nous la réservons à ceux qui ne recherchent, ni à s'élever sur terre, ni à y semer la corruption. Cependant, l'heureuse fin appartient aux pieux.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmmcccxxxvi{Quiconque viendra avec le bien, aura meilleur que cela encore; et quiconque viendra avec le mal, (qu'il sache que) ceux qui commettront des méfaits ne seront rétribués que selon ce qu'ils ont commis.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmmcccxxxvii{Celui qui t'a prescrit le Coran te ramènera certainement là où tu (souhaites) retourner. Dis: «Mon Seigneur connaît mieux celui qui a apporté la guidée et celui qui est dans un égarement évident.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmmcccxxxviii{Tu n'espérais nullement que le Livre te serait révélé. Ceci n'a été que par une miséricorde de ton Seigneur. Ne sois donc jamais un soutien pour les infidèles;\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmmcccxxxix{et que ceux-ci ne te détournent point des versets d'Allah une fois qu'on les a fait descendre vers toi. Appelle les gens vers ton Seigneur et ne sois point du nombre des Associateurs.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmmcccxl{Et n'invoque nulle autre divinité avec Allah. Point de divinité à part Lui. Tout doit périr, sauf Son Visage. A Lui appartient le jugement; et vers Lui vous serez ramenés.\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmmcccxli{\basmalahfr Alif, Lâm, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmcccxlii{Est-ce que les gens pensent qu'on les laissera dire: «Nous croyons!» sans les éprouver?\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmcccxliii{Certes, Nous avons éprouvé ceux qui ont vécu avant eux; [Ainsi] Allah connaît ceux qui disent la vérité et ceux qui mentent.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmcccxliv{Ou bien ceux qui commettent des méfaits, comptent-ils pouvoir Nous échapper? Comme leur jugement est mauvais!\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmcccxlv{Celui qui espère rencontrer Allah, le terme fixé par Allah va certainement venir. Et c'est Lui l'Audient, l'Omniscient.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmcccxlvi{Et quiconque lutte, ne lutte que pour lui-même, car Allah peut Se passer de tout l'univers.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmcccxlvii{Et quant à ceux qui croient et font de bonnes œuvres, Nous leur effacerons leurs méfaits, et Nous les rétribuerons de la meilleure récompense pour ce qu'ils auront accompli.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmcccxlviii{Et Nous avons enjoint à l'homme de bien traiter ses père et mère, et «si ceux-ci te forcent à M'associer, ce dont tu n'as aucun savoir, alors ne leur obéis pas». Vers Moi est votre retour, et alors Je vous informerai de ce que vous faisiez.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmcccxlix{Et quant à ceux qui croient et font de bonnes œuvres, Nous les ferons certainement entrer parmi les gens de bien.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmcccl{Parmi les gens il en est qui disent: «Nous croyons en Allah» puis, si on les fait souffrir pour la cause d'Allah, ils considèrent l'épreuve de la part des hommes comme un châtiment d'Allah. Or, s'il vient du secours de ton Seigneur, ils diront certes: «Nous étions avec vous!» Allah n'est-Il pas le meilleur à savoir ce qu'il y a dans les poitrines de tout le monde?\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmcccli{Allah connaît parfaitement les croyants et connaît parfaitement les hypocrites.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmccclii{Et ceux qui ne croient pas disent à ceux qui croient; «Suivez notre sentier, et que nous supportions vos fautes». Mais ils ne supporteront rien de leurs fautes. En vérité ce sont des menteurs.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmcccliii{Et très certainement, ils porteront leurs fardeaux et d'autres fardeaux en plus de leurs propres fardeaux. et ils seront interrogés, le Jour de la Résurrection, sur ce qu'ils inventaient.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmcccliv{Et en effet, Nous avons envoyé Noé vers son peuple. Il demeura parmi eux mille ans moins cinquante années. Puis le déluge les emporta alors qu'ils étaient injustes.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmccclv{Puis Nous le sauvâmes, lui et les gens de l'arche; et Nous en fîmes un avertissement pour l'univers.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmccclvi{Et Abraham, quand il dit à son peuple; «Adorez Allah et craignez-Le: cela vous est bien meilleur si vous saviez».\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmccclvii{Vous n'adorez que des idoles, en dehors d'Allah, et vous forgez un mensonge. Ceux que vous adorez en dehors d'Allah ne possèdent aucun moyen pour vous procurer nourriture; recherchez votre subsistance auprès d'Allah. Adorez-Le et soyez-Lui reconnaissants. C'est à Lui que vous serez ramenés.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmccclviii{Et si vous criez au mensonge, d'autres nations avant vous, ont aussi traité (leurs prophètes) de menteurs. Au Messager, cependant, n'incombe que la transmission claire.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmccclix{Ne voient-ils pas comment Allah commence la création puis la refait? Cela est facile pour Allah.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmccclx{Dis: «Parcourez la terre et voyez comment Il a commencé la création. Puis comment Allah crée la génération ultime. Car Allah est Omnipotent».\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmccclxi{Il châtie qui Il veut et fait miséricorde à qui Il veut; et c'est vers Lui que vous serez ramenés.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmccclxii{Et vous ne pourrez vous opposer à Sa puissance ni sur terre, ni au ciel; et il n'y a pas pour vous, en dehors d'Allah, ni allié ni secoureur.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmccclxiii{Et ceux qui ne croient pas aux versets d'Allah et à Sa rencontre, désespèrent de Ma miséricorde. Et ceux-là auront un châtiment douloureux.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmccclxiv{Son peuple ne fit d'autre réponse que: «tuez-le ou brûlez-le». Mais Allah le sauva du feu. C'est bien là des signes pour des gens qui croient.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmccclxv{Et [Abraham] dit: «En effet, c'est pour cimenter des liens entre vous-mêmes dans la vie présente, que vous avez adopté des idoles, en dehors d'Allah. Ensuite, le Jour de la Résurrection, les uns rejetteront les autres, et les uns maudiront les autres, tandis que vous aurez le Feu pour refuge, n'aurez pas de protecteurs.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmccclxvi{Lot crut en lui. Il dit: «Moi, j'émigre vers mon Seigneur, car c'est Lui le Tout Puissant, le Sage».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmccclxvii{Nous lui donnâmes Isaac et Jacob, et plaçâmes dans sa descendance la prophétie et le Livre. Nous lui accordâmes sa récompense ici-bas, tandis que dans l'au-delà, il sera parmi les gens de bien.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmccclxviii{Et Lot, quand il dit à son peuple: «Vraiment, vous commettez la turpitude où nul dans l'univers ne vous a précédés.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmccclxix{Aurez-vous commerce charnel avec des mâles? Pratiquerez-vous le brigandage? Commettrez-vous le blâmable dans votre assemblée?» Mais son peuple ne fit d'autre réponse que: «Fais que le châtiment d'Allah nous vienne, si tu es du nombre des véridiques».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmccclxx{Il dit: «Seigneur, donne-moi victoire sur ce peuple de corrupteurs!»\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmccclxxi{Et quand Nos Anges apportèrent à Abraham la bonne annonce, ils dirent: «Nous allons anéantir les habitants de cette cité car ses habitants sont injustes».\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmccclxxii{Il dit: «Mais Lot s'y trouve!» Ils dirent: «Nous savons parfaitement qui y habite: nous le sauverons certainement, lui et sa famille, excepté sa femme qui sera parmi ceux qui périront».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmccclxxiii{Et quand Nos Anges vinrent à Lot, il fut affligé pour eux, et se sentit incapable de les protéger. Ils lui dirent: «Ne crains rien et ne t'afflige pas... Nous te sauverons ainsi que ta famille, excepté ta femme qui sera parmi ceux qui périront.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmccclxxiv{Nous ferons tomber du ciel un châtiment sur les habitants de cette cité, pour leur perversité».\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmccclxxv{Et certainement, Nous avons laissé (des ruines de cette cité) un signe (d'avertissement) évident pour des gens qui comprennent.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmccclxxvi{De même, aux Madyan (Nous envoyâmes) leur frère Chuayb qui leur dit: «O mon peuple, adorez Allah et attendez-vous au Jour dernier, et ne semez pas la corruption sur terre».\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmccclxxvii{Mais ils le traitèrent de menteur. Le cataclysme les saisit, et au matin, ils gisaient sans vie dans leurs demeures.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmccclxxviii{De même (Nous anéantîmes) les 'Aad et les Thamûd. - Vous le voyez clairement à travers leurs habitations - Le Diable, cependant, leur avait embelli leurs actions, au point de les repousser loin du Sentier; ils étaient pourtant invités à être clairvoyants.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmccclxxix{De même (Nous détruisîmes) Coré, Pharaon et Hâmân. Alors que Moïse leur apporta des preuves, ils s'enorgueillirent sur terre. Et ils n'ont pas pu [Nous] échapper.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmccclxxx{Nous saisîmes donc chacun pour son péché: Il y en eut sur qui Nous envoyâmes un ouragan; il y en eut que le Cri saisit; il y en eut que Nous fîmes engloutir par la terre; et il y en eut que Nous noyâmes. Cependant, Allah n'est pas tel à leur faire du tort; mais ils ont fait du tort à eux-mêmes.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmccclxxxi{Ceux qui ont pris des protecteurs en dehors d'Allah ressemblent à l'araignée qui s'est donnée maison. Or la maison la plus fragile est celle de l'araignée. Si seulement ils savaient!\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmccclxxxii{Allah connaît toute chose qu'ils invoquent en dehors de Lui. Et c'est Lui le Tout Puissant, le Sage.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmccclxxxiii{Telles sont les paraboles que Nous citons aux gens; cependant, seuls les savants les comprennent.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmccclxxxiv{C'est pour une juste raison qu'Allah a créé les cieux et la terre. Voilà bien là une preuve pour les croyants.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmccclxxxv{Récite ce qui t'est révélé du Livre et accomplis la Salât. En vérité la Salât préserve de la turpitude et du blâmable. Le rappel d'Allah est certes ce qu'il y a de plus grand. Et Allah sait ce que vous faites.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmccclxxxvi{Et ne discutez que de la meilleure façon avec les gens du Livre, sauf ceux d'entre eux qui sont injustes. Et dites: «Nous croyons en ce qu'on a fait descendre vers nous et descendre vers vous, tandis que notre Dieu et votre Dieu est le même, et c'est à Lui que nous nous soumettons».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmccclxxxvii{C'est ainsi que Nous t'avons fait descendre le Livre (le Coran). Ceux à qui Nous avons donné le Livre y croient. Et parmi ceux-ci, il en est qui y croient. Seuls les mécréants renient Nos versets.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmccclxxxviii{Et avant cela, tu ne récitais aucun livre et tu n'en écrivais aucun de ta main droite. Sinon, ceux qui nient la vérité auraient eu des doutes.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmccclxxxix{Il consiste plutôt en des versets évidents, (préservés) dans les poitrines de ceux à qui le savoir a été donné. Et seuls les injustes renient Nos versets.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmcccxc{Et ils dirent: «Pourquoi n'a-t-on pas fait descendre sur lui des prodiges de la part de son Seigneur?» Dis: «Les prodiges sont auprès d'Allah. Moi, je ne suis qu'un avertisseur bien clair».\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmcccxci{Ne leur suffit-il donc point que Nous ayons fait descendre sur toi le Livre et qu'il leur soit récité? Il y a assurément là une miséricorde et un rappel pour des gens qui croient.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmcccxcii{Dis: «Allah suffit comme témoin entre moi et vous». Il sait ce qui est dans les cieux et la terre. Et quant à ceux qui croient au faux et ne croient pas en Allah, ceux-là seront les perdants.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmcccxciii{Et ils te demandent de hâter [la venue] du châtiment. S'il n'y avait pas eu un terme fixé, le châtiment leur serait certes venu. Et assurément, il leur viendra soudain, sans qu'ils en aient conscience.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmcccxciv{Ils te demandent de hâter [la venue] du châtiment, tandis que l'Enfer cerne les mécréants de toutes parts.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmcccxcv{Le jour où le châtiment les enveloppera d'en haut et sous leurs pieds. Il [leur] dira: «Goûtez à ce que vous faisiez!»\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmcccxcvi{O Mes serviteurs qui avaient cru! Ma terre est bien vaste. Adorez-Moi donc!\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmcccxcvii{Toute âme goûtera la mort. Ensuite c'est vers Nous que vous serez ramenés.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmcccxcviii{Et quant à ceux qui croient et accomplissent de bonnes œuvres, Nous les installerons certes à l'étage dans le Paradis sous lequel coulent les ruisseaux, pour y demeurer éternellement. Quelle belle récompense que celle de ceux qui font le bien,\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmcccxcix{qui endurent, et placent leur confiance en leur Seigneur!\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmcd{Que de bêtes ne se chargent point de leur propre nourriture! C'est Allah qui les nourrit ainsi que vous. Et c'est Lui l'Audient, l'Omniscient.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmcdi{Si tu leur demandes: «Qui a créé les cieux et la terre, et assujetti le soleil et la lune?», ils diront très certainement: «Allah». Comment se fait-il qu'ensuite ils se détournent (du chemin droit)?\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmcdii{Allah dispense largement ou restreint Ses dons à qui Il veut parmi Ses serviteurs. Certes, Allah est Omniscient.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmcdiii{Si tu leur demandes: «Qui a fait descendre du ciel une eau avec laquelle Il fit revivre la terre après sa mort?», ils diront très certainement: «Allah». Dis: «Louange à Allah!» Mais la plupart d'entre eux ne raisonnent pas.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmcdiv{Cette vie d'ici-bas n'est qu'amusement et jeu. La Demeure de l'au-delà est assurément la vraie vie. S'ils savaient!\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmcdv{Quand ils montent en bateau, ils invoquent Allah Lui vouant exclusivement leur culte. Une fois qu'Il les a sauvés [des dangers de la mer en les ramenant] sur la terre ferme, voilà qu'ils [Lui] donnent des associés.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmcdvi{Qu'ils nient ce que nous leur avons donné et jouissent des biens de ce monde! Ils sauront bientôt!\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmcdvii{Ne voient-ils pas que vraiment Nous avons fait un sanctuaire sûr [la Mecque], alors que tout autour d'eux on enlève les gens? Croiront-ils donc au faux et nieront-ils les bienfaits d'Allah?\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmcdviii{Et quel pire injuste que celui qui invente un mensonge contre Allah, ou qui dément la Vérité quand elle lui parvient? N'est-ce pas dans l'Enfer une demeure pour les mécréants?\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmcdix{Et quant à ceux qui luttent pour Notre cause, Nous les guiderons certes sur Nos sentiers. Allah est en vérité avec les bienfaisants.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmcdx{\basmalahfr Alif, Lâm, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmcdxi{Les Romains ont été vaincus,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmcdxii{dans le pays voisin, et après leur défaite ils seront les vainqueurs,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmcdxiii{dans quelques années. A Allah appartient le commandement, au début et à la fin, et ce jour-là les Croyants se réjouiront\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmcdxiv{du secours d'Allah. Il secourt qui Il veut et Il est le Tout Puissant, le Tout Miséricordieux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmcdxv{C'est [là] la promesse d'Allah. Allah ne manque jamais à Sa promesse mais la plupart des gens ne savent pas.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmcdxvi{Ils connaissent un aspect de la vie présente, tandis qu'ils sont inattentifs à l'au-delà.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmcdxvii{N'ont-ils pas médité en eux-mêmes? Allah n'a créé les cieux et la terre et ce qui est entre eux, qu'à juste raison et pour un terme fixé. Beaucoup de gens cependant ne croient pas en la rencontre de leur Seigneur.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmcdxviii{N'ont-ils pas parcouru la terre pour voir ce qu'il est advenu de ceux qui ont vécu avant eux? Ceux-là les surpassaient en puissance et avaient labouré et peuplé la terre bien plus qu'ils ne l'ont fait eux-mêmes. Leurs messagers leur vinrent avec des preuves évidentes. Ce n'est pas Allah qui leur fit du tort; mais ils se firent du tort à eux-mêmes.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmcdxix{Puis, mauvaise fut la fin de ceux qui faisaient le mal, ayant traité de mensonges les versets d'Allah et les ayant raillés.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmcdxx{C'est Allah qui commence la création; ensuite Il la refait; puis, vers Lui vous serez ramenés.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmcdxxi{Et le jour où l'Heure arrivera, les criminels seront frappés de désespoir.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmcdxxii{Et ils n'auront point d'intercesseurs parmi ceux qu'ils associaient [à Allah] et ils renieront même leurs divinités.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmcdxxiii{Le jour où l'Heure arrivera, ce jour-là ils se sépareront [les uns des autres].\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmcdxxiv{Ceux qui auront cru et accompli de bonnes œuvres se réjouiront dans un jardin;\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmcdxxv{et quant à ceux qui n'auront pas cru et auront traité de mensonges Nos signes ainsi que la rencontre de l'au-delà, ceux-là seront emmenés au châtiment.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmcdxxvi{Glorifiez Allah donc, soir et matin!\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmcdxxvii{A Lui toute louange dans les cieux et la terre, dans l'après-midi et au milieu de la journée.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmcdxxviii{Du mort, Il fait sortir le vivant, et du vivant, Il fait sortir le mort. Et Il redonne la vie à la terre après sa mort. Et c'est ainsi que l'on vous fera sortir (à la résurrection).\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmcdxxix{Parmi Ses signes: Il vous a créés de terre, - puis, vous voilà des hommes qui se dispersent [dans le monde] -.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmcdxxx{Et parmi Ses signes Il a créé de vous, pour vous, des épouses pour que vous viviez en tranquillité avec elles et Il a mis entre vous de l'affection et de la bonté. Il y a en cela des preuves pour des gens qui réfléchissent.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmcdxxxi{Et parmi Ses signes la création des cieux et de la terre et la variété de vos idiomes et de vos couleurs. Il y a en cela des preuves pour les savants.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmcdxxxii{Et parmi Ses signes votre sommeil la nuit et le jour, et aussi votre quête de Sa grâce. Il y a en cela des preuves pour des gens qui entendent.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmcdxxxiii{Et parmi Ses signes Il vous montre l'éclair avec crainte (de la foudre) et espoir (de la pluie), et fait descendre du ciel une eau avec laquelle Il redonne la vie à la terre après sa mort. Il y a en cela des preuves pour des gens qui raisonnent.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmcdxxxiv{Et parmi Ses signes le ciel et la terre sont maintenus par Son ordre; ensuite lorsqu'Il vous appellera d'un appel, voilà que de la terre vous surgirez.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmcdxxxv{A Lui tous ceux qui sont dans les cieux et la terre: tous Lui sont entièrement soumis.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmcdxxxvi{Et c'est Lui qui commence la création puis la refait; et cela Lui est plus facile. Il a la transcendance absolue dans les cieux et sur la terre. C'est Lui le Tout Puissant, le Sage.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmcdxxxvii{Il vous a cité une parabole de vous-mêmes: Avez-vous associé vos esclaves à ce que Nous vous avons attribué en sorte que vous soyez tous égaux [en droit de propriété] et que vous les craignez [autant] que vous vous craignez mutuellement? C'est ainsi que Nous exposons Nos versets pour des gens qui raisonnent.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmcdxxxviii{Ceux qui ont été injustes ont plutôt suivi leurs propres passions, sans savoir. Qui donc peut guider celui qu'Allah égare? Et ils n'ont pas pour eux, de protecteur.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmcdxxxix{Dirige tout ton être vers la religion exclusivement [pour Allah], telle est la nature qu'Allah a originellement donnée aux hommes - pas de changement à la création d'Allah -. Voilà la religion de droiture; mais la plupart des gens ne savent pas.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmcdxl{Revenez repentants vers Lui; craignez-Le, accomplissez la Salât et ne soyez pas parmi les associateurs,\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmcdxli{parmi ceux qui ont divisé leur religion et sont devenus des sectes, chaque parti exultant de ce qu'il détenait.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmcdxlii{Et quand un mal touche les gens, ils invoquent leur Seigneur en revenant à Lui repentants. Puis s'Il leur fait goûter de Sa part une miséricorde, voilà qu'une partie d'entre eux donnent à leur Seigneur des associés,\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmcdxliii{en sorte qu'ils deviennent ingrats envers ce que Nous leur avons donné. «Et jouissez donc. Vous saurez bientôt».\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmcdxliv{Avons-Nous fait descendre sur eux une autorité (un Livre) telle qu'elle parle de ce qu'ils Lui associaient?\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmcdxlv{Et quand Nous faisons goûter une miséricorde aux gens, ils en exultent. Mais si un malheur les atteint à cause de ce que leurs propres mains ont préparé, voilà qu'ils désespèrent.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmcdxlvi{N'ont-ils pas vu qu'Allah dispense Ses dons ou les restreint à qui Il veut? Il y a en cela des preuves pour des gens qui croient.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmcdxlvii{Donne donc au proche parent son dû, ainsi qu'au pauvre, et au voyageur en détresse. Cela est meilleur pour ceux qui recherchent la face d'Allah (Sa satisfaction); et ce sont eux qui réussissent.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmcdxlviii{Tout ce que vous donnerez à usure pour augmenter vos biens aux dépens des biens d'autrui ne les accroît pas auprès d'Allah, mais ce que vous donnez comme Zakât, tout en cherchant la Face d'Allah (Sa satisfaction)... Ceux-là verront [leurs récompenses] multipliées.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmcdxlix{C'est Allah qui vous a créés et vous a nourris. Ensuite Il vous fera mourir, puis Il vous redonnera vie. Y en a-t-il, parmi vos associés, qui fasse quoi que ce soit de tout cela? Gloire à Lui! Il transcende ce qu'on Lui associe.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmcdl{La corruption est apparue sur la terre et dans la mer à cause de ce que les gens ont accompli de leurs propres mains; afin qu'[Allah] leur fasse goûter une partie de ce qu'ils ont œuvré; peut-être reviendront-ils (vers Allah).\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmcdli{Dis: «Parcourez la terre et regardez ce qu'il est advenu de ceux qui ont vécu avant. La plupart d'entre eux étaient des associateurs».\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmcdlii{Dirige tout ton être vers la religion de droiture, avant que ne vienne d'Allah un jour qu'on ne peut repousser. Ce jour-là [les gens] seront divisés:\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmcdliii{Celui qui aura mécru subira [les conséquences] de son infidélité. Et quiconque aura œuvré en bien... C'est pour eux-mêmes qu'ils préparent (leur avenir),\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmcdliv{afin qu'[Allah] récompense par Sa grâce ceux qui croient et accomplissent les bonnes œuvres. En vérité, Il n'aime pas les infidèles.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmcdlv{Parmi Ses signes, Il envoie les vents comme annonciateurs, pour vous faire goûter de Sa miséricorde et pour que le vaisseau vogue, par Son ordre, et que vous recherchiez de Sa grâce. Peut-être seriez-vous reconnaissants!\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmcdlvi{Nous avons effectivement envoyé avant toi des Messagers vers leurs peuples et ils leur apportèrent les preuves. Nous Nous vengeâmes de ceux qui commirent les crimes [de la négation]; et c'était Notre devoir de secourir les croyants.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmcdlvii{Allah, c'est Lui qui envoie les vents qui soulèvent des nuages; puis Il les étend dans le ciel comme Il veut; et Il les met en morceaux. Tu vois alors la pluie sortir de leurs profondeurs. Puis, lorsqu'Il atteint avec elle qui Il veut parmi Ses serviteurs, les voilà qui se réjouissent,\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmcdlviii{même s'ils étaient auparavant, avant qu'on ne l'ait fait descendre sur eux, désespérés.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmcdlix{Regarde donc les effets de la miséricorde d'Allah comment Il redonne la vie à la terre après sa mort. C'est Lui qui fait revivre les morts et Il est Omnipotent.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmcdlx{Et si Nous envoyons un vent et qu'ils voient jaunir [leur végétation], ils demeurent après cela ingrats (oubliant les bienfaits antérieurs).\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmcdlxi{En vérité, tu ne fais pas entendre les morts; et tu ne fais pas entendre aux sourds l'appel, s'ils s'en vont en tournant le dos.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmcdlxii{Tu n'es pas celui qui guide les aveugles hors de leur égarement. Tu ne fais entendre que ceux qui croient en Nos versets et qui sont alors entièrement soumis [musulmans].\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmcdlxiii{Allah, c'est Lui qui vous a créés faibles; puis après la faiblesse, Il vous donne la force; puis après la force, Il vous réduit à la faiblesse et à la vieillesse: Il crée ce qu'Il veut et c'est Lui l'Omniscient, l'Omnipotent.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmcdlxiv{Et le jour où l'Heure arrivera, les criminels jureront qu'ils n'ont demeuré qu'une heure. C'est ainsi qu'ils ont été détournés (de la vérité);\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmcdlxv{tandis que ceux à qui le savoir et la foi furent donnés diront: «Vous avez demeuré d'après le Décret d'Allah, jusqu'au Jour de la Résurrection, voici le Jour de la Résurrection, - mais vous ne saviez point».\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmcdlxvi{ce jour-là donc, les excuses ne seront pas utiles aux injustes et on ne leur demandera pas à chercher à plaire à [Allah].\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmcdlxvii{Et dans ce Coran, Nous avons certes cité, pour les gens, des exemples de toutes sortes. Et si tu leur apportes un prodige, ceux qui ne croient pas diront: «Certes, vous n'êtes que des imposteurs».\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmcdlxviii{C'est ainsi qu'Allah scelle les cœurs de ceux qui ne savent pas.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmcdlxix{Sois donc patient, car la promesse d'Allah est vérité. Et que ceux qui ne croient pas fermement ne t'ébranlent pas!\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmcdlxx{\basmalahfr Alif, Lâm, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxi{Voici les versets du Livre plein de sagesse,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxii{c'est un guide et une miséricorde aux bienfaisants,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxiii{qui accomplissent la Salât, acquittent la Zakât et qui croient avec certitude en l'au-delà.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxiv{Ceux-là sont sur le chemin droit de leur Seigneur et ce sont eux les bienheureux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxv{Et, parmi les hommes, il est [quelqu'un] qui, dénué de science, achète de plaisants discours pour égarer hors du chemin d'Allah et pour le prendre en raillerie. Ceux-là subiront un châtiment avilissant.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxvi{Et quand on lui récite Nos versets, il tourne le dos avec orgueil, comme s'il ne les avait point entendus, comme s'il y avait un poids dans ses oreilles. Fais-lui donc l'annonce d'un châtiment douloureux.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxvii{Ceux qui croient et accomplissent les bonnes œuvres auront les Jardins des délices,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxviii{pour y demeurer éternellement, - c'est en vérité une promesse d'Allah-. C'est Lui le Puissant, le Sage.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxix{Il a créé les cieux sans piliers que vous puissiez voir; et Il a enfoncé des montagnes fermes dans la terre pour l'empêcher de basculer avec vous; et Il y a propagé des animaux de toute espèce. Et du ciel, Nous avons fait descendre une eau, avec laquelle Nous avons fait pousser des plantes productives par couples de toute espèce.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxx{«Voilà la création d'Allah. Montrez-Moi donc ce qu'ont créé, ceux qui sont en dehors de Lui?» Mais les injustes sont dans un égarement évident.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxxi{Nous avons effectivement donné à Luqmân la sagesse: «Sois reconnaissant à Allah, car quiconque est reconnaissant, n'est reconnaissant que pour soi-même; quant à celui qui est ingrat... En vérité, Allah se dispense de tout, et Il est digne de louange».\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxxii{Et lorsque Luqmân dit à son fils tout en l'exhortant: «O mon fils, ne donne pas d'associé à Allah, car l'association à [Allah] est vraiment une injustice énorme.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxxiii{Nous avons commandé à l'homme [la bienfaisance envers] ses père et mère; sa mère l'a porté [subissant pour lui] peine sur peine: son sevrage a lieu à deux ans. «Sois reconnaissant envers Moi ainsi qu'envers tes parents. Vers Moi est la destination.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxxiv{Et si tous deux te forcent à M'associer ce dont tu n'as aucune connaissance, alors ne leur obéis pas; mais reste avec eux ici-bas de façon convenable. Et suis le sentier de celui qui se tourne vers Moi. Vers Moi, ensuite, est votre retour, et alors Je vous informerai de ce que vous faisiez».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxxv{«O mon enfant, fût-ce le poids d'un grain de moutarde, au fond d'un rocher, ou dans les cieux ou dans la terre, Allah le fera venir. Allah est infiniment Doux et Parfaitement Connaisseur.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxxvi{O mon enfant accomplis la Salât, commande le convenable, interdis le blâmable et endure ce qui t'arrive avec patience. Telle est la résolution à prendre dans toute entreprise!\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxxvii{Et ne détourne pas ton visage des hommes, et ne foule pas la terre avec arrogance: car Allah n'aime pas le présomptueux plein de gloriole.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxxviii{Sois modeste dans ta démarche, et baisse ta voix, car la plus détestée des voix, c'est bien la voix des ânes».\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmcdlxxxix{Ne voyez-vous pas qu'Allah vous a assujetti ce qui est dans les cieux et sur la terre? Et Il vous a comblés de Ses bienfaits apparents et cachés. Et parmi les gens, il y en a qui disputent à propos d'Allah, sans science, ni guidée, ni Livre éclairant.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmcdxc{Et quand on leur dit: «Suivez ce qu'Allah a fait descendre», ils disent: «Nous suivons plutôt ce sur quoi nous avons trouvé nos ancêtres». Est-ce donc même si le Diable les appelait au châtiment de la fournaise!\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmcdxci{Et quiconque soumet son être à Allah, tout en étant bienfaisant, s'accroche réellement à l'anse la plus ferme. La fin de toute chose appartient à Allah.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmcdxcii{Celui qui a mécru, que sa mécréance ne t'afflige pas: vers Nous sera leur retour et Nous les informerons de ce qu'ils faisaient. Allah connaît bien le contenu des poitrines.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmcdxciii{Nous leur donnons de la jouissance pour peu de temps; ensuite Nous les forcerons vers un dur châtiment.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmcdxciv{Si tu leur demandes: «Qui a créé les cieux et la terre?», ils diront, certes: «Allah!» Dis: «Louange à Allah!». Mais la plupart d'entre eux ne savent pas.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmcdxcv{A Allah appartient tout ce qui est dans les cieux et en terre. Allah est Celui qui se suffit à Lui-même, Il est Le Digne de louange!\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmcdxcvi{Quand bien même tous les arbres de la terre se changeraient en calames [plumes pour écrire], quand bien même l'océan serait un océan d'encre où conflueraient sept autres océans, les paroles d'Allah ne s'épuiseraient pas. Car Allah est Puissant et Sage.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmcdxcvii{Votre création et votre résurrection [à tous] sont [aussi faciles à Allah] que s'il s'agissait d'une seule âme. Certes Allah est Audient et Clairvoyant.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmcdxcviii{N'as-tu pas vu qu'Allah fait pénétrer la nuit dans le jour, et qu'il fait pénétrer le jour dans la nuit, et qu'Il a assujetti le soleil et la lune chacun poursuivant sa course jusqu'à un terme fixé? Et Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmcdxcix{Il en est ainsi parce qu'Allah est la Vérité, et que tout ce qu'ils invoquent en dehors de Lui est le Faux, et qu'Allah, c'est Lui le Haut, le Grand.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmd{N'as-tu pas vu que c'est par la grâce d'Allah que le vaisseau vogue dans la mer, afin qu'Il vous fasse voir de Ses merveilles? Il y a en cela des preuves pour tout homme patient et reconnaissant.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmdi{Quand une vague les recouvre comme des ombres, ils invoquent Allah, vouant leur culte exclusivement à Lui; et lorsqu'Il les sauve, en les ramenant vers la terre ferme, certains d'entre eux deviennent réticents; mais, seul le grand traître et le grand ingrat renient Nos signes.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmdii{O hommes! Craignez votre Seigneur et redoutez un jour où le père ne répondra en quoi que ce soit pour son enfant, ni l'enfant pour son père. La promesse d'Allah est vérité. Que la vie présente ne vous trompe donc pas, et que le Trompeur (Satan) ne vous induise pas en erreur sur Allah!\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmdiii{La connaissance de l'Heure est auprès d'Allah; et c'est Lui qui fait tomber la pluie salvatrice; et Il sait ce qu'il y a dans les matrices. Et personne ne sait ce qu'il acquerra demain, et personne ne sait dans quelle terre il mourra. Certes, Allah est Omniscient et Parfaitement Connaisseur.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmdiv{\basmalahfr Alif, Lâm, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmdv{La Révélation du Livre, nul doute là-dessus, émane du Seigneur de l'univers.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmdvi{Diront-ils qu'il (Muhammad) l'a inventé? Ceci est, au contraire, la vérité venant de ton Seigneur pour que tu avertisses un peuple à qui nul avertisseur avant toi n'est venu, afin qu'ils se guident.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmdvii{Allah qui a créé en six jours les cieux et la terre, et ce qui est entre eux. Ensuite Il S'est établi «Istawâ» sur le Trône. Vous n'avez, en dehors de Lui, ni allié ni intercesseur. Ne vous rappelez-vous donc pas?\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmdviii{Du ciel à la terre, Il administre l'affaire, laquelle ensuite monte vers Lui en un jour équivalent à mille ans de votre calcul.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmdix{C'est Lui le Connaisseur [des mondes] inconnus et visibles, le Puissant, le Miséricordieux,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmdx{qui a bien fait tout ce qu'Il a créé. Et Il a commencé la création de l'homme à partir de l'argile,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmdxi{puis Il tira sa descendance d'une goutte d'eau vile [le sperme];\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmdxii{puis Il lui donna sa forme parfaite et lui insuffla de Son Esprit. Et Il vous a assigné l'ouïe, les yeux et le cœur. Que vous êtes peu reconnaissants!\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmdxiii{Et ils disent: «Quand nous serons perdus dans la terre [sous forme de poussière], redeviendrons-nous une création nouvelle?» En outre, ils ne croient pas en la rencontre avec leur Seigneur.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmdxiv{Dis: «L'Ange de la mort qui est chargé de vous, vous fera mourir. Ensuite, vous serez ramenés vers Votre Seigneur».\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmdxv{Si tu voyais alors les criminels [comparaître], têtes basses devant leur Seigneur! «Notre Seigneur, Nous avons vu et entendu, renvoie-nous donc afin que nous puissions faire du bien; nous croyons [maintenant] avec certitude».\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmdxvi{«Si Nous voulions, Nous apporterions à chaque âme sa guidée. Mais la parole venant de Moi doit être réalisée: «J'emplirai l'Enfer de djinns et d'hommes réunis».\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmdxvii{«Goûtez donc! Pour avoir oublié la rencontre de votre jour que voici. Nous aussi Nous vous avons oubliés. Goûtez au châtiment éternel pour ce que vous faisiez».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmdxviii{Seuls croient en Nos versets ceux qui, lorsqu'on les leur rappelle, tombent prosternés et, par des louanges à leur Seigneur, célèbrent Sa gloire et ne s'enflent pas d'orgueil.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmdxix{Ils s'arrachent de leurs lits pour invoquer leur Seigneur, par crainte et espoir; et ils font largesse de ce que Nous leur attribuons.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmdxx{Aucun être ne sait ce qu'on a réservé pour eux comme réjouissance pour les yeux, en récompense de ce qu'ils œuvraient!\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmdxxi{Celui qui est croyant est-il comparable au pervers? (Non), ils ne sont point égaux.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmdxxii{Ceux qui croient et accomplissent les bonnes œuvres, auront leur résidence dans les Jardins du Refuge, en récompense de ce qu'ils œuvraient.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmdxxiii{Et quant à ceux qui auront été pervers, leur refuge sera le Feu: toutes les fois qu'ils voudront en sortir, ils y seront ramenés, et on leur dira: «Goûtez au châtiment du Feu auquel vous refusiez de croire».\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmdxxiv{Nous leur ferons certainement goûter au châtiment ici-bas, avant le grand châtiment afin qu'ils retournent (vers le chemin droit)!\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmdxxv{Qui est plus injuste que celui à qui les versets d'Allah sont rappelés et qui ensuite s'en détourne? Nous nous vengerons certes des criminels.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmdxxvi{Nous avons effectivement donné à Moïse le Livre - ne sois donc pas en doute sur ta rencontre avec lui -, et l'avons assigné comme guide aux Enfants d'Israël.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmdxxvii{Et Nous avons désigné parmi eux des dirigeants qui guidaient (les gens) par Notre ordre aussi longtemps qu'ils enduraient et croyaient fermement en Nos versets.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmdxxviii{Ton Seigneur, c'est Lui qui décidera entre eux, au Jour de la Résurrection, de ce sur quoi ils divergeaient.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmdxxix{N'est-ce pas pour eux une indication le fait qu'avant eux, Nous ayons fait périr tant de générations dans les maisons desquelles ils marchent? Il y a en cela des preuves! N'écouteront-ils donc pas?\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmdxxx{N'ont-ils pas vu que Nous poussons l'eau vers un sol aride, qu'ensuite Nous en faisons sortir une culture que consomment leurs bestiaux et eux-mêmes? Ne voient-ils donc pas,?\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmdxxxi{Et ils disent: «A quand cette victoire, si vous êtes véridiques?»\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmdxxxii{Dis: «Le jour de la Victoire, il sera inutile aux infidèles de croire! Et aucun délai ne leur sera donné».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmdxxxiii{Eloigne-toi d'eux et attends. Eux aussi demeurent dans l'attente.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmdxxxiv{\basmalahfr O Prophète! Crains Allah et n'obéis pas aux infidèles et aux hypocrites, car Allah demeure Omniscient et Sage.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmdxxxv{Et suis ce qui t'est révélé émanant de Ton Seigneur. Car Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmdxxxvi{Et place ta confiance en Allah. Allah te suffit comme protecteur.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmdxxxvii{Allah n'a pas placé à l'homme deux cœurs dans sa poitrine. Il n'a point assimilé à vos mères vos épouses [à qui vous dites en les répudiant]: «Tu es [aussi illicite] pour moi que le dos de ma mère». Il n'a point fait de vos enfants adoptifs vos propres enfants. Ce sont des propos [qui sortent] de votre bouche. Mais Allah dit la vérité et c'est Lui qui met [l'homme] dans la bonne direction.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmdxxxviii{Appelez-les du nom de leurs pères: c'est plus équitable devant Allah. Mais si vous ne connaissez pas leurs pères, alors considérez-les comme vos frères en religion ou vos alliés. Nul blâme sur vous pour ce que vous faites par erreur, mais (vous serez blâmés pour) ce que vos cœurs font délibérément. Allah, cependant, est Pardonneur et Miséricordieux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmdxxxix{Le Prophète a plus de droit sur les croyants qu'ils n'en ont sur eux-mêmes; et ses épouses sont leurs mères. Les liens de consanguinité ont [dans les successions] la priorité [sur les liens] unissant les croyants [de Médine] et les émigrés [de la Mecque] selon le livre d'Allah, à moins que vous ne fassiez un testament convenable en faveur de vos frères en religion. Et cela est inscrit dans le Livre.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmdxl{Lorsque Nous prîmes des prophètes leur engagement, de même que de toi, de Noé, d'Abraham, de Moïse, et de Jésus fils de Marie: et Nous avons pris d'eux un engagement solennel,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmdxli{afin [qu'Allah] interroge les véridiques sur leur sincérité. Et Il a préparé aux infidèles un châtiment douloureux.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmdxlii{O vous qui croyez! Rappelez-vous le bienfait d'Allah sur vous, quand des troupes vous sont venues et que Nous avons envoyé contre elles un vent et des troupes que vous n'avez pas vues. Allah demeure Clairvoyant sur ce que vous faites.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmdxliii{Quand ils vous vinrent d'en haut et d'en bas [de toutes parts], et que les regards étaient troublés, et les cœurs remontaient aux gorges, et vous faisiez sur Allah toutes sortes de suppositions...\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmdxliv{Les croyants furent alors éprouvés et secoués d'une dure secousse.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmdxlv{Et quand les hypocrites et ceux qui ont la maladie [le doute] au cœur disaient: «Allah et Son messager ne nous ont promis que tromperie».\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmdxlvi{De même, un groupe d'entre eux dit: «Gens de Yathrib! Ne demeurez pas ici. Retournez [chez vous]». Un groupe d'entre eux demande au Prophète la permission de partir en disant: «Nos demeures sont sans protection», alors qu'elles ne l'étaient pas: ils ne voulaient que s'enfuir.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmdxlvii{Et si une percée avait été faite sur eux par les flancs de la ville et qu'ensuite on leur avait demandé de renier leur foi, ils auraient accepté certes, et n'auraient guère tardé,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmdxlviii{tandis qu'auparavant ils avaient pris l'engagement envers Allah qu'ils ne tourneraient pas le dos. Et il sera demandé compte de tout engagement vis-à-vis d'Allah.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmdxlix{Dis: «Jamais la fuite ne vous sera utile si c'est la mort (sans combat) ou le meurtre (dans le combat) que vous fuyez; dans ce cas, vous ne jouirez (de la vie) que peu (de temps)».\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmdl{Dis: «Quel est celui qui peut vous protéger d'Allah, s'Il vous veut du mal ou s'Il veut vous accorder une miséricorde?» Et ils ne trouveront pour eux-mêmes en dehors d'Allah, ni allié ni secoureur.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmdli{Certes, Allah connaît ceux d'entre vous qui suscitent des obstacles, ainsi que ceux qui disent à leurs frères: «Venez à nous», tandis qu'ils ne déploient que peu d'ardeur au combat,\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmdlii{avares à votre égard. Puis, quand leur vient la peur, tu les vois te regarder avec des yeux révulsés, comme ceux de quelqu'un qui s'est évanoui par peur de la mort. Une fois la peur passée, ils vous lacèrent avec des langues affilées, alors qu'ils sont chiches à faire le bien. Ceux-là n'ont jamais cru. Allah donc, rend vaines leurs actions. Et cela est facile à Allah.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmdliii{Ils pensent que les coalisés ne sont pas partis. Or si les coalisés revenaient, [ces gens-là] souhaiteraient être des nomades parmi les Bédouins et [se contenteraient] de demander de vos nouvelles. S'ils étaient parmi vous, ils n'auraient combattu que très peu.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmdliv{En effet, vous avez dans le Messager d'Allah un excellent modèle [à suivre], pour quiconque espère en Allah et au Jour dernier et invoque Allah fréquemment.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmdlv{Et quand les croyants virent les coalisés, ils dirent: «Voilà ce qu'Allah et Son messager nous avaient promis; et Allah et Son messager disaient la vérité». Et cela ne fit que croître leur foi et leur soumission.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmdlvi{Il est, parmi les croyants, des hommes qui ont été sincères dans leur engagement envers Allah. Certains d'entre eux ont atteint leur fin, et d'autres attendent encore; et ils n'ont varié aucunement (dans leur engagement);\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmdlvii{afin qu'Allah récompense les véridiques pour leur sincérité, et châtie, s'Il veut, les hypocrites, ou accepte leur repentir. Car Allah est Pardonneur et Miséricordieux.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmdlviii{Et Allah a renvoyé, avec leur rage, les infidèles sans qu'ils n'aient obtenu aucun bien, et Allah a épargné aux croyants le combat. Allah est Fort et Puissant.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmdlix{Et Il a fait descendre de leurs forteresses ceux des gens du Livre qui les avaient soutenus [les coalisés], et Il a jeté l'effroi dans leurs cœurs; un groupe d'entre eux vous tuiez, et un groupe vous faisiez prisonniers.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmdlx{Et Il vous a fait hériter leur terre, leurs demeures, leurs biens, et aussi une terre que vous n'aviez point foulée. Et Allah est Omnipotent.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmdlxi{O Prophète! Dis à tes épouses: «Si c'est la vie présente que vous désirez et sa parure, alors venez! Je vous donnerai [les moyens] d'en jouir et vous libérerai [par un divorce] sans préjudice.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmdlxii{Mais si c'est Allah que vous voulez et Son messager ainsi que la Demeure dernière, Allah a préparé pour les bienfaisantes parmi vous une énorme récompense.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmdlxiii{O femmes du Prophète! Celle d'entre vous qui commettra une turpitude prouvée, le châtiment lui sera doublé par deux fois! Et ceci est facile pour Allah.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmdlxiv{Et celle d'entre vous qui est entièrement soumise à Allah et à Son messager et qui fait le bien, Nous lui accorderons deux fois sa récompense, et Nous avons préparé pour elle une généreuse attribution.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmdlxv{O femmes du Prophète! Vous n'êtes comparables à aucune autre femme. Si vous êtes pieuses, ne soyez pas trop complaisantes dans votre langage, afin que celui dont le cœur est malade [l'hypocrite] ne vous convoite pas. Et tenez un langage décent.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmdlxvi{Restez dans vos foyers; et ne vous exhibez pas à la manière des femmes d'avant l'Islam (Jâhiliyah). Accomplissez la Salât, acquittez la Zakât et obéissez à Allah et à Son messager. Allah ne veut que vous débarrasser de toute souillure, ô gens de la maison [du prophète], et veut vous purifier pleinement.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmdlxvii{Et gardez dans vos mémoires ce qui, dans vos foyers, est récité des versets d'Allah et de la sagesse. Allah est Doux et Parfaitement Connaisseur.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmdlxviii{Les Musulmans et Musulmanes, croyants et croyantes, obéissants et obéissantes, loyaux et loyales, endurants et endurantes, craignants et craignantes, donneurs et donneuses d'aumône, jeûnants et jeûnantes, gardiens de leur chasteté et gardiennes, invocateurs souvent d'Allah et invocatrices: Allah a préparé pour eux un pardon et une énorme récompense.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmdlxix{Il n'appartient pas à un croyant ou à une croyante, une fois qu'Allah et Son messager ont décidé d'une chose d'avoir encore le choix dans leur façon d'agir. Et quiconque désobéit à Allah et à Son messager, s'est égaré certes, d'un égarement évident.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmdlxx{Quand tu disais à celui qu'Allah avait comblé de bienfait, tout comme toi-même l'avais comblé: «Garde pour toi ton épouse et crains Allah», et tu cachais en ton âme ce qu'Allah allait rendre public. Tu craignais les gens, et c'est Allah qui est plus digne de ta crainte. Puis quand Zayd eut cessé toute relation avec elle, Nous te la fîmes épouser, afin qu'il n'y ait aucun empêchement pour les croyants d'épouser les femmes de leurs fils adoptifs, quand ceux-ci cessent toute relation avec elles. Le commandement d'Allah doit être exécuté.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmdlxxi{Nul grief à faire au Prophète en ce qu'Allah lui a imposé, conformément aux lois établies pour ceux qui vécurent antérieurement. Le commandement d'Allah est un décret inéluctable.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmdlxxii{Ceux qui communiquaient les messages d'Allah, Le craignaient et ne redoutaient nul autre qu'Allah. Et Allah suffit pour tenir le compte de tout.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmdlxxiii{Muhammad n'a jamais été le père de l'un de vos hommes, mais le messager d'Allah et le dernier des prophètes. Allah est Omniscient.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmdlxxiv{O vous qui croyez! Evoquez Allah d'une façon abondante,\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmdlxxv{et glorifiez-Le à la pointe et au déclin du jour.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmdlxxvi{C'est lui qui prie sur vous, - ainsi que Ses Anges -, afin qu'Il vous fasse sortir des ténèbres à la lumière; et Il est Miséricordieux envers les croyants.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmdlxxvii{Leur salutation au jour où ils Le rencontreront sera: «Salâm» [paix], et Il leur a préparé une généreuse récompense.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmdlxxviii{O Prophète! Nous t'avons envoyé [pour être] témoin, annonciateur, avertisseur,\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmdlxxix{appelant (les gens) à Allah, par Sa permission; et comme une lampe éclairante.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmdlxxx{Et fais aux croyants la bonne annonce qu'ils recevront d'Allah une grande grâce.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmdlxxxi{Et n'obéis pas aux infidèles et aux hypocrites, ne prête pas attention à leur méchanceté et place ta confiance en Allah et Allah suffit comme protecteur.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmdlxxxii{O vous qui croyez! Quand vous vous mariez avec des croyantes et qu'ensuite vous divorcez d'avec elles avant de les avoir touchées, vous ne pouvez leur imposer un délai d'attente. Donnez-leur jouissance [d'un bien] et libérez-les [par un divorce] sans préjudice.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmdlxxxiii{O Prophète! Nous t'avons rendu licites tes épouses à qui tu as donné leur mahr (dot), ce que tu as possédé légalement parmi les captives [ou esclaves] qu'Allah t'a destinées, les filles de ton oncle paternel, les filles de tes tantes paternelles, les filles de ton oncle maternel, et les filles de tes tantes maternelles, - celles qui avaient émigré en ta compagnie -, ainsi que toute femme croyante si elle fait don de sa personne au Prophète, pourvu que le Prophète consente à se marier avec elle: c'est là un privilège pour toi, à l'exclusion des autres croyants. Nous savons certes, ce que Nous leur avons imposé au sujet de leurs épouses et des esclaves qu'ils possèdent, afin qu'il n'y eût donc point de blâme contre toi. Allah est Pardonneur et Miséricordieux.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmdlxxxiv{Tu fais attendre qui tu veux d'entre elles, et tu héberges chez toi qui tu veux. Puis il ne t'est fait aucun grief si tu invites chez toi l'une de celles que tu avais écartées. Voilà ce qui est le plus propre à les réjouir, à leur éviter tout chagrin et à leur faire accepter de bon cœur ce que tu leur as donné à toutes. Allah sait, cependant, ce qui est en vos cœurs. Et Allah est Omniscient et Indulgent.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmdlxxxv{Il ne t'est plus permis désormais de prendre [d'autres] femmes, ni de changer d'épouses, même si leur beauté te plaît; - à l'exception des esclaves que tu possèdes. Et Allah observe toute chose.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmdlxxxvi{O vous qui croyez! N'entrez pas dans les demeures du Prophète, à moins qu'invitation ne vous soit faite à un repas, sans être là à attendre sa cuisson. Mais lorsqu'on vous appelle, alors, entrez. Puis, quand vous aurez mangé, dispersez-vous, sans chercher à vous rendre familiers pour causer. Cela faisait de la peine au Prophète, mais il se gênait de vous (congédier), alors qu'Allah ne se gêne pas de la vérité. Et si vous leur demandez (à ses femmes) quelque objet, demandez-le leur derrière un rideau: c'est plus pur pour vos cœurs et leurs cœurs; vous ne devez pas faire de la peine au Messager d'Allah, ni jamais vous marier avec ses épouses après lui; ce serait, auprès d'Allah, un énorme péché.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmdlxxxvii{Que vous divulguiez une chose ou que vous la cachiez,... Allah demeure Omniscient.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmdlxxxviii{Nul grief sur elles au sujet de leurs pères, leurs fils, leurs frères, les fils de leurs frères, les fils de leurs sœurs, leurs femmes [de suite] et les esclaves qu'elles possèdent. Et craignez Allah. Car Allah est témoin de toute chose.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmdlxxxix{Certes, Allah et Ses Anges prient sur le Prophète; ô vous qui croyez priez sur lui et adressez [lui] vos salutations.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmdxc{Ceux qui offensent Allah et Son messager, Allah les maudit ici-bas, comme dans l'au-delà et leur prépare un châtiment avilissant.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmdxci{Et ceux qui offensent les croyants et les croyantes sans qu'ils l'aient mérité, se chargent d'une calomnie et d'un péché évident.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmdxcii{O Prophète! Dis à tes épouses, à tes filles, et aux femmes des croyants, de ramener sur elles leurs grands voiles: elles en seront plus vite reconnues et éviteront d'être offensées. Allah est Pardonneur et Miséricordieux.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmdxciii{Certes, si les hypocrites, ceux qui ont la maladie au cœur, et les alarmistes [semeurs de troubles] à Médine ne cessent pas, Nous t'inciterons contre eux, et alors, ils n'y resteront que peu de temps en ton voisinage.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmdxciv{Ce sont des maudits. Où qu'on les trouve, ils seront pris et tués impitoyablement:\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmdxcv{Telle était la loi établie par Allah envers ceux qui ont vécu auparavant et tu ne trouveras pas de changement dans la loi d'Allah.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmdxcvi{Les gens t'interrogent au sujet de l'Heure. Dis: «Sa connaissance est exclusive à Allah». Qu'en sais-tu? Il se peut que l'Heure soit proche.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmdxcvii{Allah a maudit les infidèles et leur a préparé une fournaise,\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmdxcviii{pour qu'ils y demeurent éternellement, sans trouver ni allié ni secoureur.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmdxcix{Le jour où leurs visages seront tournés et retournés dans le Feu, ils diront: «Hélas pour nous! Si seulement nous avions obéi à Allah et obéi au Messager!»\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmdc{Et ils dirent: «Seigneur, nous avons obéi à nos chefs et à nos grands. C'est donc eux qui nous ont égarés du Sentier.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmdci{O notre Seigneur, inflige-leur deux fois le châtiment et maudis les d'une grande malédiction».\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmdcii{O vous qui croyez! Ne soyez pas comme ceux qui ont offensé Moïse. Allah l'a déclaré innocent de leurs accusations, car il était honorable auprès d'Allah.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmdciii{O vous qui croyez! Craignez Allah et parlez avec droiture,\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmdciv{afin qu'Il améliore vos actions et vous pardonne vos péchés. Quiconque obéit à Allah et à Son messager obtient certes une grande réussite.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmdcv{Nous avions proposé aux cieux, à la terre et aux montagnes la responsabilité (de porter les charges de faire le bien et d'éviter le mal). Ils ont refusé de la porter et en ont eu peur, alors que l'homme s'en est chargé; car il est très injuste [envers lui-même] et très ignorant.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmdcvi{[Il en est ainsi] afin qu'Allah châtie les hypocrites, hommes et femmes, et les associateurs et les associatrices et Allah accueille le repentir des croyants et des croyantes. Allah est Pardonneur et Miséricordieux.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmdcvii{\basmalahfr Louange à Allah à qui appartient tout ce qui est dans les cieux et tout ce qui est sur la terre. Et louange à Lui dans l'au-delà. Et c'est Lui le Sage, le Parfaitement Connaisseur.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmdcviii{Il sait ce qui pénètre en terre et ce qui en sort, ce qui descend du ciel et ce qui y remonte. Et c'est Lui le Miséricordieux, le Pardonneur.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmdcix{Ceux qui ne croient pas disent: «L'Heure ne nous viendra pas». Dis: «Par mon Seigneur! Très certainement, elle vous viendra. [Mon Seigneur] le Connaisseur de l'Inconnaissable. Rien ne Lui échappe fût-il du poids d'un atome dans les cieux, comme sur la terre. Et rien n'existe de plus petit ni de plus grand, qui ne soit inscrit dans un Livre explicite,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmdcx{afin qu'Il récompense ceux qui croient et accomplissent les bonnes œuvres. Pour ceux-ci, il y aura un pardon et un don généreux.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmdcxi{Et ceux qui s'efforcent de rendre vains Nos versets, ceux-là auront le châtiment d'un supplice douloureux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmdcxii{Et ceux à qui le savoir a été donné voient que ce qu'on t'a fait descendre de la part de ton Seigneur est la vérité qui guide au chemin du Tout Puissant, du Digne de Louange.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmdcxiii{Et ceux qui ne croient pas dirent: «Voulez-vous que l'on vous montre un homme qui vous prédise que lorsque vous serez complètement désintégrés, vous reparaîtrez, sans nul doute, en une nouvelle création?\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmdcxiv{Invente-t-il un mensonge contre Allah? ou bien est-il fou?» [Non], mais ceux qui ne croient pas en l'au-delà sont voués au châtiment et à l'égarement lointain.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmdcxv{Ne voient-ils donc pas ce qu'il y a comme ciel et comme terre devant et derrière eux? Si Nous voulions, Nous ferions que la terre les engloutisse, ou que des morceaux du ciel tombent sur eux. Il y a en cela une preuve pour tout serviteur repentant.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmdcxvi{Nous avons certes accordé une grâce à David de Notre part. O montagnes et oiseaux, répétez avec lui (les louanges d'Allah). Et pour lui, Nous avons amolli le fer,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmdcxvii{(en lui disant): «Fabrique des cottes de mailles complètes et mesure bien les mailles». Et faites le bien. Je suis Clairvoyant sur ce que vous faites.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmdcxviii{Et à Salomon (Nous avons assujetti) le vent, dont le parcours du matin équivaut à un mois (de marche) et le parcours du soir, un mois aussi. Et pour lui Nous avons fait couler la source de cuivre. Et parmi les djinns il y en a qui travaillaient sous ses ordres, par permission de son Seigneur. Quiconque d'entre eux, cependant, déviait de Notre ordre, Nous lui faisions goûter au châtiment de la fournaise.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmdcxix{Ils exécutaient pour lui ce qu'il voulait: sanctuaires, statues, plateaux comme des bassins, et marmites bien ancrées. - «O famille de David, œuvrez par gratitude», alors qu'il y a eu peu de Mes serviteurs qui sont reconnaissants.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmdcxx{Puis, quand Nous décidâmes sa mort, il n'y eut pour les avertir de sa mort que la «bête de terre», qui rongea sa canne. Puis lorsqu'il s'écroula, il apparut de toute évidence aux djinns que s'ils savaient vraiment l'inconnu, ils ne seraient pas restés dans le supplice humiliant [de la servitude].\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmdcxxi{Il y avait assurément, pour la tribu de Saba' un Signe dans leurs habitat: deux jardins, l'un à droite et l'autre à gauche. «Mangez de ce que votre Seigneur vous a attribué, et soyez-Lui reconnaissants: une bonne contrée et un Seigneur Pardonneur».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmdcxxii{Mais ils se détournèrent. Nous déchaînâmes contre eux l'inondation du Barrage, et leur changeâmes leurs deux jardins en deux jardins aux fruits amers, tamaris et quelques jujubiers.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmdcxxiii{Ainsi les rétribuâmes Nous pour leur mécréance. Saurions-Nous sanctionner un autre que le mécréant?\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmdcxxiv{Et Nous avions placé entre eux et les cités que Nous avions bénies, d'autres cités proéminentes, et Nous avions évalué les étapes de voyage entre elles. «Voyagez entre elles pendant des nuits et des jours, en sécurité».\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmdcxxv{Puis, ils dirent: «Seigneur, allonge les distances entre nos étapes», et ils se firent du tort à eux-mêmes. Nous fîmes d'eux, donc, des sujets de légendes et les désintégrâmes totalement. Il y a en cela des avertissements pour tous grand endurant et grand reconnaissant.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmdcxxvi{Et Satan a très certainement rendu véridique sa conjecture à leur égard. Ils l'ont suivi donc, sauf un groupe parmi les croyants.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmdcxxvii{Et pourtant il n'avait sur eux aucun pouvoir si ce n'est que Nous voulions distinguer celui qui croyait en l'au-delà et celui qui doutait. Ton Seigneur, cependant, assure la sauvegarde de toute chose.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmdcxxviii{Dis: «Invoquez ceux qu'en dehors d'Allah vous prétendez [être des divinités]. Ils ne possèdent même pas le poids d'un atome, ni dans les cieux ni sur la terre. Ils n'ont jamais été associés à leur création et Il n'a personne parmi eux pour Le soutenir».\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmdcxxix{L'intercession auprès de Lui ne profite qu'à celui en faveur duquel Il la permet. Quand ensuite la frayeur se sera éloignée de leurs cœurs, ils diront: «Qu'a dit votre Seigneur?» Ils répondront: «La Vérité; C'est Lui le Sublime, le Grand».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmdcxxx{Dis: «Qui vous nourrit du ciel et de la terre?» Dis: «Allah. C'est nous ou bien vous qui sommes sur une bonne voie, ou dans un égarement manifeste».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmdcxxxi{Dis: «Vous ne serez pas interrogés sur les crimes que nous avons commis, et nous ne serons pas interrogés sur ce que vous faites».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmdcxxxii{Dis: «Notre Seigneur nous réunira, puis Il tranchera entre nous, avec la vérité, car c'est Lui le Grand Juge, l'Omniscient».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmdcxxxiii{Dis: «Montrez-moi ceux que vous Lui avez donnés comme associés. Eh bien, non! C'est plutôt Lui, Allah, le Puissant, le Sage».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmdcxxxiv{Et Nous ne t'avons envoyé qu'en tant qu'annonciateur et avertisseur pour toute l'humanité. Mais la plupart des gens ne savent pas.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmdcxxxv{Et ils disent: «A quand cette promesse, si vous êtes véridiques?»\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmdcxxxvi{Dis: «Le rendez-vous est pour un jour que vous ne saurez retarder d'une heure, ni avancer!»\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmdcxxxvii{Et ceux qui avaient mécru dirent: «Jamais nous ne croirons à ce Coran ni à ce qui l'a précédé». Et si tu pouvais voir quand les injustes seront debout devant leur Seigneur, se renvoyant la parole les uns aux autres! Ceux que l'on considérait comme faibles diront à ceux qui s'enorgueillissaient: «Sans vous, nous aurions certes été croyants».\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmdcxxxviii{Ceux qui s'enorgueillissaient diront à ceux qu'ils considéraient comme faibles: «Est-ce nous qui vous avons repoussés de la bonne direction après qu'elle vous fut venue? Mais vous étiez plutôt des criminels».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmdcxxxix{Et ceux que l'on considérait comme faibles diront à ceux qui s'enorgueillissaient: «C'était votre stratagème, plutôt, nuit et jour, de nous commander de ne pas croire en Allah et de Lui donner des égaux». Et ils cacheront leur regret quand ils verront le châtiment. Nous placerons des carcans aux cous de ceux qui ont mécru: les rétribuerait-on autrement que selon ce qu'ils œuvraient?»\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmdcxl{Et Nous n'avons envoyé aucun avertisseur dans une cité sans que ses gens aisés n'aient dit: «Nous ne croyons pas au message avec lequel vous êtes envoyés».\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmdcxli{Et ils dirent: «Nous avons davantage de richesses et d'enfants et nous ne serons pas châtiés».\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmdcxlii{Dis: «Mon Seigneur dispense avec largesse ou restreint Ses dons à qui Il veut. Mais la plupart des gens ne savent pas».\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmdcxliii{Ni vos biens ni vos enfants ne vous rapprocheront à proximité de Nous. Sauf celui qui croit et œuvre dans le bien. Ceux-là auront une double récompense pour ce qu'ils œuvraient, tandis qu'ils seront en sécurité, aux étages supérieurs (du Paradis).\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmdcxliv{Et quant à ceux qui s'efforcent à rendre Nos versets inefficients, ceux-là seront forcés de se présenter au châtiment.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmdcxlv{Dis: «Mon Seigneur dispense avec largesse ou restreint Ses dons à qui Il veut parmi ses serviteurs. Et toute dépense que vous faites [dans le bien], Il la remplace, et c'est Lui le Meilleur des donateurs».\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmdcxlvi{Et un jour Il les rassemblera tous. Puis Il dira aux Anges: «Est-ce vous que ces gens-là adoraient?»\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmdcxlvii{Ils diront: «Gloire à Toi! Tu es notre Allié en dehors d'eux. Ils adoraient plutôt les djinns, en qui la plupart d'entre eux croyaient.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmdcxlviii{Ce jour-là donc, vous n'aurez aucun moyen pour profiter ou nuire les uns aux autres, tandis que Nous dirons aux injustes: «Goûtez au châtiment du Feu que vous traitiez de mensonge».\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmdcxlix{Et quand Nos versets édifiants leur sont récités, ils disent: Ce n'est là qu'un homme qui veut vous repousser de ce que vos ancêtres adoraient». Et ils disent: «Ceci (Le Coran) n'est qu'un mensonge inventé». Et ceux qui ne croient pas disent de la Vérité quand elle leur vient: «Ce n'est là qu'une magie évidente!»\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmdcl{[Pourtant] Nous ne leur avons pas donné de livres à étudier. Et Nous ne leur avons envoyé avant toi aucun avertisseur.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmdcli{Ceux d'avant eux avaient [aussi] démenti (leurs messagers). [Les Mecquois] n'ont pas atteint le dixième de ce que Nous leur avons donné [en force et en richesse]. Ils traitaient Mes Messagers de menteurs. Et quelle réprobation fut la mienne!\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmdclii{Dis: «Je vous exhorte seulement à une chose: que pour Allah vous vous leviez, par deux ou isolément, et qu'ensuite vous réfléchissiez. Votre compagnon (Muhammad) n'est nullement possédé: il n'est pour vous qu'un avertisseur annonçant un dur châtiment».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmdcliii{Dis: «Ce que je vous demande comme salaire, c'est pour vous-mêmes. Car mon salaire n'incombe qu'à Allah. Il est Témoin de toute chose».\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmdcliv{Dis: «Certes, mon Seigneur lance la Vérité, [à Ses messagers], Il est le Parfait Connaisseur des inconnaissables».\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmdclv{Dis: «La vérité [l'Islam] est venue. Et le Faux [la mécréance] ne peut rien commencer ni renouveler».\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmdclvi{Dis: «Si je m'égare, je ne m'égare qu'à mes dépens; tandis que si je me guide, alors c'est grâce à ce que Mon Seigneur me révèle, car Il est Audient et Proche».\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmdclvii{Si tu les voyais quand ils seront saisis de peur, - pas d'échappatoire pour eux -, et ils seront saisis de près!\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmdclviii{Ils diront alors: «Nous croyons en lui». - Mais comment atteindront-ils la foi de si loin?\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmdclix{alors qu'auparavant ils y avaient effectivement mécru et ils offensent l'inconnu à partir d'un endroit éloigné !\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmdclx{On les empêchera d'atteindre ce qu'ils désirent, comme cela fut fait auparavant avec leurs semblables, car ils se trouvaient dans un doute profond.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmdclxi{\basmalahfr Louange à Allah, Créateur des cieux et de la terre, qui a fait des Anges des messagers dotés de deux, trois ou quatre ailes. Il ajoute à la création ce qu'Il veut, car Allah est Omnipotent.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmdclxii{Ce qu'Allah accorde en miséricorde aux gens, il n'est personne à pouvoir le retenir. Et ce qu'Il retient, il n'est personne à le relâcher après Lui. Et c'est Lui le Puissant, le Sage.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmdclxiii{O hommes! Rappelez-vous le bienfait d'Allah sur vous: existe-t-il en dehors d'Allah, un créateur qui du ciel et de la terre vous attribue votre subsistance? Point de divinité à part Lui! Comment pouvez-vous vous détourner [de cette vérité]?\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmdclxiv{Et s'ils te traitent de menteur, certes on a traité de menteurs des Messagers avant toi. Vers Allah cependant, tout est ramené.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmdclxv{O hommes! La promesse d'Allah est vérité. Ne laissez pas la vie présente vous tromper, et que le grand trompeur (Satan) ne vous trompe pas à propos d'Allah!\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmdclxvi{Le Diable est pour vous un ennemi. Prenez-le donc pour ennemi. Il ne fait qu'appeler ses partisans pour qu'ils soient des gens de la Fournaise.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmdclxvii{Ceux qui ont mécru auront un dur châtiment, tandis que ceux qui croient et accomplissent les bonnes œuvres auront un pardon et une grosse récompense.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmdclxviii{Eh quoi! Celui à qui on a enjolivé sa mauvaise action au point qu'il la voit belle...? - Mais Allah égare qui Il veut, et guide qui Il veut - Que ton âme ne se répande donc pas en regrets pour eux: Allah est Parfaitement Savant de ce qu'ils fabriquent.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmdclxix{Et c'est Allah qui envoie les vents qui soulèvent un nuage que Nous poussons ensuite vers une contrée morte; puis, Nous redonnons la vie à la terre après sa mort. C'est ainsi que se fera la Résurrection!\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmdclxx{Quiconque veut la puissance (qu'il la cherche auprès d'Allah) car la puissance tout entière est à Allah: vers Lui monte la bonne parole, et Il élève haut la bonne action. Et quand à ceux qui complotent de mauvaises actions, ils auront un dur châtiment. Cependant, leur stratagème est voué à l'échec.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmdclxxi{Et Allah vous a créés de terre, puis d'une goutte de sperme, Il vous a ensuite établis en couples. Nulle femelle ne porte ni ne met bas sans qu'Il le sache. Et aucune existence n'est prolongée ou abrégée sans que cela soit consigné dans un livre. Cela est vraiment facile pour Allah.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmdclxxii{Les deux mers ne sont pas identiques: [l'eau de] celle-ci est potable, douce et agréable à boire, et celle-là est salée, amère. Cependant de chacune vous mangez une chair fraîche, et vous extrayez un ornement que vous portez. Et tu vois le vaisseau fendre l'eau avec bruit, pour que vous cherchiez certains [des produits] de Sa grâce. Peut-être serez-vous reconnaissants!\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmdclxxiii{Il fait que la nuit pénètre le jour et que le jour pénètre la nuit. Et Il a soumis le soleil et la lune. Chacun d'eux s'achemine vers un terme fixé. Tel est Allah, votre Seigneur: à Lui appartient la royauté, tandis que ceux que vous invoquez, en dehors de Lui, ne sont même pas maîtres de la pellicule d'un noyau de datte.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmdclxxiv{Si vous les invoquez, ils n'entendent pas votre invocation; et même s'ils entendaient, ils ne sauraient vous répondre. Et le jour du Jugement ils vont nier votre association. Nul ne peut te donner des nouvelles comme Celui qui est parfaitement informé.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmdclxxv{O hommes, vous êtes les indigents ayant besoin d'Allah, et c'est Allah, Lui qui se dispense de tout et Il est Le Digne de louange.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmdclxxvi{S'Il voulait, Il vous ferait disparaître, et ferait surgir une nouvelle création.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmdclxxvii{Et cela n'est point difficile pour Allah.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmdclxxviii{Or, personne ne portera le fardeau d'autrui. Et si une âme surchargée [de péchés] appelle à l'aide, rien de sa charge ne sera supporté par une autre même si c'est un proche parent. Tu n'avertis en fait, que ceux qui craignent leur Seigneur malgré qu'ils ne Le voient pas, et qui accomplissent la Salât. Et quiconque se purifie ne se purifie que pour lui-même, et vers Allah est la destination.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmdclxxix{L'aveugle et celui qui voit ne sont pas semblables,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmdclxxx{ni les ténèbres et la lumière,\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmdclxxxi{ni l'ombre et la chaleur ardente.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmdclxxxii{De même, ne sont pas semblables les vivants et les morts. Allah fait entendre qui Il veut, alors que toi [Muhammad], tu ne peux faire entendre ceux qui sont dans les tombeaux.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmdclxxxiii{Tu n'es qu'un avertisseur.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmdclxxxiv{Nous t'avons envoyé avec la Vérité en tant qu'annonciateur et avertisseur. Il n'est pas une nation qui n'ait déjà eu un avertisseur.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmdclxxxv{Et s'ils te traitent de menteur, eh bien, ceux d'avant eux avaient traité (leurs Messagers) de menteurs, cependant que leurs Messagers leur avaient apporté les preuves, les Ecrits et le Livre illuminant.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmdclxxxvi{Puis J'ai saisi ceux qui ont mécru. Et quelle réprobation fut la Mienne!\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmdclxxxvii{N'as-tu pas vu que, du ciel, Allah fait descendre l'eau? Puis Nous en faisons sortir des fruits de couleurs différentes. Et dans les montagnes, il y a des sillons blancs et rouges, de couleurs différentes, et des roches excessivement noires.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmdclxxxviii{Il y a pareillement des couleurs différentes, parmi les hommes, les animaux, et les bestiaux. Parmi Ses serviteurs, seuls les savants craignent Allah. Allah est, certes, Puissant et Pardonneur.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmdclxxxix{Ceux qui récitent le Livre d'Allah, accomplissent la Salât, et dépensent, en secret et en public de ce que Nous leur avons attribué, espèrent ainsi faire un commerce qui ne périra jamais,\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmdcxc{afin [qu'Allah] les récompense pleinement et leur ajoute de Sa grâce. Il est Pardonneur et Reconnaissant.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmdcxci{Et ce que Nous t'avons révélé du Livre est la Vérité confirmant ce qui l'a précédé. Certes Allah est Parfaitement Connaisseur et Clairvoyant sur Ses serviteurs.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmdcxcii{Ensuite, Nous fîmes héritiers du Livre ceux de Nos serviteurs que Nous avons choisis. Il en est parmi eux qui font du tort à eux-mêmes, d'autres qui se tiennent sur une voie moyenne, et d'autres avec la permission d'Allah devancent [tous les autres] par leurs bonnes actions; telle est la grâce infinie\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmdcxciii{Les jardins d'Eden où ils entreront, parés de bracelets en or ainsi que de perles; et là, leurs vêtements sont de soie.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmdcxciv{Et ils diront: «Louange à Allah qui a écarté de nous l'affliction. Notre Seigneur est certes Pardonneur et Reconnaissant.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmdcxcv{C'est Lui qui nous a installés, par Sa grâce, dans la Demeure de la stabilité, où nulle fatigue, nulle lassitude ne nous touchent».\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmdcxcvi{Et ceux qui ont mécru auront le feu de l'Enfer: on ne les achève pas pour qu'ils meurent; on ne leur allège rien de ses tourments. C'est ainsi que Nous récompensons tout négateur obstiné.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmdcxcvii{Et là, ils hurleront: «Seigneur, fais-nous sortir; nous ferons le bien, contrairement à ce que nous faisions». «Ne vous avons-Nous pas donné une vie assez longue pour que celui qui réfléchit réfléchisse? L'avertisseur, cependant, vous était venu. Et bien, goûtez (votre punition). Car pour les injustes, il n'y a pas de secoureur».\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmdcxcviii{Allah connaît l'Inconnaissable dans les cieux et la terre. Il connaît le contenu des poitrines.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmdcxcix{C'est Lui qui a fait de vous des successeurs sur terre. Quiconque mécroit, sa mécréance retombera sur lui. Leur mécréance n'ajoute aux mécréants qu'opprobre auprès de leur Seigneur. Leur mécréance n'ajoute que perte aux mécréants.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmdcc{Dis: «Voyez-vous vos associés que vous invoquez en dehors d'Allah? Montrez-moi ce qu'ils ont créé de la terre. Ont-ils été associés à la création des cieux? Ou leur avons-Nous apporté un Livre qui contienne des preuves [pour ce qu'ils font?]» Non! Mais ce n'est qu'en tromperie que les injustes se font des promesses les uns aux autres.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmdcci{Allah retient les cieux et la terre pour qu'ils ne s'affaissent pas. Et s'ils s'affaissaient, nul autre après Lui ne pourra les retenir. Il est Indulgent et Pardonneur.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmdccii{Et ils ont juré solennellement par Allah, que si un avertisseur leur venait, ils seraient certes mieux guidés que n'importe quelle autre communauté. Puis, quand un avertisseur (Muhammad) leur est venu, cela n'a fait qu'accroître leur répulsion,\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmdcciii{par orgueil sur terre et par manœuvre perfide. Cependant, la manœuvre perfide n'enveloppe que ses propres auteurs. Attendent-ils donc un autre sort que celui des Anciens? Or, jamais tu ne trouveras de changement dans la règle d'Allah et jamais tu ne trouveras de déviation dans la règle d'Allah.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmdcciv{N'ont-ils donc jamais parcouru la terre pour voir ce qu'il est advenu de ceux qui vécurent avant eux et qui étaient plus puissants qu'eux? Et rien, dans les cieux ni sur terre ne saurait réduire l'autorité d'Allah. Car Il est certes Omniscient, Omnipotent.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmdccv{Et si Allah s'en prenait aux gens pour ce qu'ils acquièrent, Il ne laisserait à la surface [de la terre] aucun être vivant. Mais Il leur donne un délai jusqu'à un terme fixé. Puis quand leur terme viendra... (Il se saisira d'eux) car Allah est Très Clairvoyant sur Ses serviteurs.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmdccvi{\basmalahfr Yâ Sîn.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmdccvii{Par le Coran plein de sagesse.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmdccviii{Tu (Muhammad) es certes du nombre des messagers,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmdccix{sur un chemin droit.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmdccx{C'est une révélation de la part du Tout Puissant, du Très Miséricordieux,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmdccxi{pour que tu avertisses un peuple dont les ancêtres n'ont pas été avertis: ils sont donc insouciants.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmdccxii{En effet, la Parole contre la plupart d'entre eux s'est réalisée: ils ne croiront donc pas.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmdccxiii{Nous mettrons des carcans à leurs cous, et il y en aura jusqu'aux mentons: et voilà qu'ils iront têtes dressées.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmdccxiv{et Nous mettrons une barrière devant eux et une barrière derrière eux; Nous les recouvrirons d'un voile: et voilà qu'ils ne pourront rien voir.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmdccxv{Cela leur est égal que tu les avertisses ou que tu ne les avertisses pas: ils ne croiront jamais.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmdccxvi{Tu avertis seulement celui qui suit le Rappel (le Coran), et craint le Tout Miséricordieux, malgré qu'il ne Le voit pas. Annonce-lui un pardon et une récompense généreuse.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmdccxvii{C'est Nous qui ressuscitons les morts et écrivons ce qu'ils ont fait [pour l'au-delà] ainsi que leurs traces. Et Nous avons dénombré toute chose dans un registre explicite.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmdccxviii{Donne-leur comme exemple les habitants de la cité, quand lui vinrent les envoyés.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmdccxix{Quand Nous leur envoyâmes deux [envoyés] et qu'ils les traitèrent de menteurs. Nous [les] renforçâmes alors par un troisième et ils dirent: «Vraiment, nous sommes envoyés à vous».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmdccxx{Mais ils [les gens] dirent: «Vous n'êtes que des hommes comme nous. Le Tout Miséricordieux n'a rien fait descendre et vous ne faites que mentir».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmdccxxi{Ils [les messagers] dirent: «Notre Seigneur sait qu'en vérité nous sommes envoyés à vous,\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmdccxxii{et il ne nous incombe que de transmettre clairement (notre message)».\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmdccxxiii{Ils dirent: «Nous voyons en vous un mauvais présage. Si vous ne cessez pas, nous vous lapiderons et un douloureux châtiment de notre part vous touchera».\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmdccxxiv{Ils dirent: «Votre mauvais présage est avec vous-mêmes. Est-ce que (c'est ainsi que vous agissez) quand on vous [le] rappelle? Mais vous êtes des gens outranciers!»\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmdccxxv{Et du bout de la ville, un homme vint en toute hâte et dit: «O mon peuple, suivez les messagers:\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmdccxxvi{suivez ceux qui ne vous demandent aucun salaire et qui sont sur la bonne voie.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmdccxxvii{et qu'aurais-je à ne pas adorer Celui qui m'a créé? Et c'est vers Lui que vous serez ramenés.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmdccxxviii{Prendrais-je en dehors de Lui des divinités? Si le Tout Miséricordieux me veut du mal, leur intercession de me servira à rien et ils ne me sauveront pas.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmdccxxix{Je serai alors dans un égarement évident.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmdccxxx{[Mais] je crois en votre Seigneur. Ecoutez-moi donc».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmdccxxxi{Alors, il [lui] fut dit: «Entre au Paradis». Il dit: «Ah si seulement mon peuple savait!\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmdccxxxii{...en raison de quoi mon Seigneur m'a pardonné et mis au nombre des honorés».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmdccxxxiii{Et après lui Nous ne fîmes descendre du ciel aucune armée. Nous ne voulions rien faire descendre sur son peuple.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmdccxxxiv{Ce ne fut qu'un seul Cri et les voilà éteints.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmdccxxxv{Hélas pour les esclaves [les humains]! Jamais il ne leur vient de messager sans qu'ils ne s'en raillent.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmdccxxxvi{Ne voient-ils pas combien de générations avant eux Nous avons fait périr? Lesquelles ne retourneront jamais parmi eux.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmdccxxxvii{Et tous sans exception comparaîtront devant Nous.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmdccxxxviii{Une preuve pour eux est la terre morte, à laquelle Nous redonnons la vie, et d'où Nous faisons sortir des grains dont ils mangent.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmdccxxxix{Nous y avons mis des jardins de palmiers et de vignes et y avons fait jaillir des sources,\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmdccxl{afin qu'ils mangent de Ses fruits et de ce que leurs mains ont produit. Ne seront-ils pas reconnaissants?\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmdccxli{Louange à Celui qui a créé tous les couples de ce que la terre fait pousser, d'eux-mêmes, et de ce qu'ils ne savent pas!\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmdccxlii{Et une preuve pour eux est la nuit. Nous en écorchons le jour et ils sont alors dans les ténèbres.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmdccxliii{et le soleil court vers un gîte qui lui est assigné; telle est la détermination du Tout Puissant, de l'Omniscient.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmdccxliv{Et la lune, Nous lui avons déterminé des phases jusqu'à ce qu'elle devienne comme la palme vieillie.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmdccxlv{Le soleil ne peut rattraper la lune, ni la nuit devancer le jour; et chacun vogue dans une orbite.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmdccxlvi{Et un (autre) signe pour eux est que Nous avons transporté leur descendance sur le bateau chargé;\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmdccxlvii{et Nous leur créâmes des semblables sur lesquels ils montent.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmdccxlviii{Et si Nous le voulons, Nous les noyons; pour eux alors, pas de secoureur et ils ne seront pas sauvés,\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmdccxlix{sauf par une miséricorde de Notre part, et à titre de jouissance pour un temps.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmdccl{Et quand on leur dit: «Craignez ce qu'il y a devant vous et ce qu'il y a derrière vous afin que vous ayez la miséricorde»!...\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmdccli{Or, pas une preuve ne leur vient, parmi les preuves de leur Seigneur sans qu'ils ne s'en détournent.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmdcclii{Et quand on leur dit: «Dépensez de ce qu'Allah vous a attribué», ceux qui ont mécru disent à ceux qui ont cru: «Nourrirons-nous quelqu'un qu'Allah aurait nourri s'Il l'avait voulu? Vous n'êtes que dans un égarement évident».\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmdccliii{Et ils disent: «A quand cette promesse si vous êtes véridiques?»\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmdccliv{Ils n'attendent qu'un seul Cri qui les saisira alors qu'ils seront en train de disputer.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmdcclv{Ils ne pourront donc ni faire de testament, ni retourner chez leurs familles.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmdcclvi{Et on soufflera dans la Trompe, et voilà que, des tombes, ils se précipiteront vers leur Seigneur,\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmdcclvii{en disant: «Malheur à nous! Qui nous a ressuscités de là où nous dormions?» C'est ce que le Tout Miséricordieux avait promis; et les Messagers avaient dit vrai.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmdcclviii{Ce ne sera qu'un seul Cri, et voilà qu'ils seront tous amenés devant Nous.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmdcclix{Ce jour-là, aucune âme ne sera lésée en rien. Et vous ne serez rétribués que selon ce que vous faisiez.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmdcclx{Les gens du Paradis seront, ce jour-là, dans une occupation qui les remplit de bonheur;\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmdcclxi{eux et leurs épouses sont sous des ombrages, accoudés sur les divans.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmdcclxii{Là ils auront des fruits et ils auront ce qu'ils réclameront,\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmdcclxiii{«Salâm» [paix et salut]! Parole de la part d'un Seigneur Très Miséricordieux.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmdcclxiv{«O injustes! Tenez-vous à l'écart ce jour-là!\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmdcclxv{Ne vous ai-Je pas engagés, enfants d'Adam, à ne pas adorer le Diable? Car il est vraiment pour vous un ennemi déclaré,\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmdcclxvi{et [ne vous ai-Je pas engagés] à M'adorer? Voilà un chemin bien droit.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmdcclxvii{Et il a très certainement égaré un grand nombre d'entre vous. Ne raisonniez-vous donc pas?\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmdcclxviii{Voici l'Enfer qu'on vous promettait.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmdcclxix{Brûlez-y aujourd'hui, pour avoir mécru».\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmdcclxx{Ce jour-là, Nous scellerons leurs bouches, tandis que leurs mains Nous parleront et que leurs jambes témoigneront de ce qu'ils avaient accompli.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxi{Et si Nous voulions, Nous effacerions leurs yeux et ils courront vers le chemin. Mais comment alors pourront-ils voir?\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxii{Et si Nous voulions, Nous les métamorphoserions sur place; alors ils ne sauront ni avancer ni revenir.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxiii{A quiconque Nous accordons une longue vie, Nous faisons baisser sa forme. Ne comprendront-ils donc pas?\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxiv{Nous ne lui (à Muhammad) avons pas enseigné la poésie; cela ne lui convient pas non plus. Ceci n'est qu'un rappel et une Lecture [Coran] claire,\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxv{pour qu'il avertisse celui qui est vivant et que la Parole se réalise contre les mécréants.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxvi{Ne voient-ils donc pas que, parmi ce que Nos mains ont fait, Nous leur avons créé des bestiaux dont ils sont propriétaires;\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxvii{et Nous les leur avons soumis: certains leur servent de monture et d'autres de nourriture;\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxviii{et ils en retirent d'autres utilités et des boissons. Ne seront-ils donc pas reconnaissants?\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxix{Et ils adoptèrent des divinités en dehors d'Allah, dans l'espoir d'être secourus...\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxx{Celles-ci ne pourront pas les secourir, elles formeront au contraire une armée dressée contre eux.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxxi{Que leurs paroles ne t'affligent donc pas! Nous savons ce qu'ils cachent et ce qu'ils divulguent.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxxii{L'homme ne voit-il pas que Nous l'avons créé d'une goutte de sperme? Et le voilà [devenu] un adversaire déclaré!\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxxiii{Il cite pour Nous un exemple, tandis qu'il oublie sa propre création; il dit: «Qui va redonner la vie à des ossements une fois réduits en poussière?»\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxxiv{Dis: «Celui qui les a créés une première fois, leur redonnera la vie. Il Se connaît parfaitement à toute création.\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxxv{c'est Lui qui, de l'arbre vert, a fait pour vous du feu, et voilà que de cela vous allumez.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxxvi{Celui qui a créé les cieux et la terre ne sera-t-Il pas capable de créer leur pareil? Oh que si! et Il est le grand Créateur, l'Omniscient.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxxvii{Quand Il veut une chose, Son commandement consiste à dire: «Sois», et c'est.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxxviii{Louange donc, à Celui qui détient en Sa main la royauté sur toute chose! Et c'est vers Lui que vous serez ramenés.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmmdcclxxxix{\basmalahfr Par ceux qui sont rangés en rangs.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmdccxc{Par ceux qui poussent (les nuages) avec force.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmdccxci{Par ceux qui récitent, en rappel:\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmdccxcii{«Votre Dieu est en vérité unique,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmdccxciii{le Seigneur des cieux et de la terre et de ce qui existe entre eux et Seigneur des Levants»\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmdccxciv{Nous avons décoré le ciel le plus proche d'un décor: les étoiles,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmdccxcv{afin de le protéger contre tout diable rebelle.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmdccxcvi{Ils ne pourront être à l'écoute des dignitaires suprêmes [les Anges]; car ils seront harcelés de tout côté,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmdccxcvii{et refoulés. Et ils auront un châtiment perpétuel.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmdccxcviii{Sauf celui qui saisit au vol quelque [information]; il est alors pourchassé par un météore transperçant.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmdccxcix{Demande-leur s'ils sont plus difficiles à créer que ceux que Nous avons créés? Car Nous les avons créés de boue collante!\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmdccc{Mais tu t'étonnes, et ils se moquent!\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmdccci{Et quand on le leur rappelle (le Coran), ils ne se rappellent pas;\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmdcccii{et quand ils voient un prodige, ils cherchent à s'en moquer,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmdccciii{et disent: «Ceci n'est que magie évidente.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmdccciv{Lorsque nous serons morts et que nous deviendrons poussière et ossements, serons-nous ressuscités?\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmdcccv{ainsi que nos premiers ancêtres?»\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmdcccvi{Dis: «Oui! et vous vous humilierez».\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmdcccvii{Il n'y aura qu'un seul Cri, et voilà qu'ils regarderont,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmdcccviii{et ils diront: «Malheur à nous! c'est le jour de la Rétribution».\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmdcccix{«C'est le jour du Jugement que vous traitiez de mensonge».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmdcccx{«Rassemblez les injustes et leurs épouses et tout ce qu'ils adoraient,\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmdcccxi{en dehors d'Allah. Puis conduisez-les au chemin de la Fournaise.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmdcccxii{Et arrêtez-les: car ils doivent être interrogés».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmdcccxiii{«Pourquoi ne vous portez-vous pas secours mutuellement?»\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmdcccxiv{Mais ce jour-là, ils seront complètement soumis,\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmdcccxv{et les uns se tourneront vers les autres s'interrogeant mutuellement;\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmdcccxvi{Ils diront: «C'est vous qui nous forciez (à la mécréance)».\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmdcccxvii{«C'est vous plutôt (diront les chefs) qui ne vouliez pas croire.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmdcccxviii{Et nous n'avions aucun pouvoir sur vous. C'est vous plutôt qui étiez des gens transgresseurs.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmdcccxix{La parole de notre Seigneur s'est donc réalisée contre nous; certes, nous allons goûter [au châtiment].\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmdcccxx{Nous vous avons induits en erreur car, en vérité, nous étions égarés nous-mêmes».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxi{Ce jour-là donc, ils seront tous associés dans le châtiment.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxii{Ainsi traitons-Nous les criminels.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxiii{Quand on leur disait: «Point de divinité à part Allah», ils se gonflaient d'orgueil,\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxiv{et disaient: «Allons-nous abandonner nos divinités pour un poète fou?»\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxv{Il est plutôt venu avec la Vérité et il a confirmé les messagers (précédents).\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxvi{Vous allez certes, goûter au châtiment douloureux.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxvii{Et vous ne serez rétribués que selon ce que vous œuvriez,\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxviii{sauf les serviteurs élus d'Allah,\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxix{Ceux-là auront une rétribution bien connue:\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxx{des fruits, et ils seront honorés,\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxxi{dans les Jardins du délice,\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxxii{sur des lits, face à face.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxxiii{On fera circuler entre eux une coupe d'eau remplie à une source\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxxiv{blanche, savoureuse à boire,\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxxv{Elle n'offusquera point leur raison et ne les enivrera pas.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxxvi{Et Ils auront auprès d'eux des belles aux grands yeux, au regard chaste,\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxxvii{semblables au blanc bien préservé de l'œuf.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxxviii{Puis les uns se tourneront vers les autres s'interrogeant mutuellement.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmdcccxxxix{L'un d'eux dira: «J'avais un compagnon\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmdcccxl{qui disait: «Es-tu vraiment de ceux qui croient?\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmdcccxli{Est-ce que quand nous mourrons et serons poussière et ossements, nous aurons à rendre des comptes?»\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmdcccxlii{Il dira: «Est-ce que vous voudriez regarder d'en haut?»\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmdcccxliii{Alors il regardera d'en haut et il le verra en plein dans la Fournaise,\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmdcccxliv{et dira: «Par Allah! Tu as bien failli causer ma perte!\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmdcccxlv{et sans le bienfait de mon Seigneur, j'aurais certainement été du nombre de ceux qu'on traîne [au supplice].\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmdcccxlvi{N'est-il pas vrai que nous ne mourrons\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmdcccxlvii{que de notre première mort et que nous ne serons pas châtiés?»\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmdcccxlviii{C'est cela, certes, le grand succès.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmdcccxlix{C'est pour une chose pareille que doivent ouvrer ceux qui ouvrent.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmdcccl{Est-ce que ceci est meilleur comme séjour, ou l'arbre de Zaqqûm?\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmdcccli{Nous l'avons assigné en épreuve aux injustes.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmdccclii{C'est un arbre qui sort du fond de la Fournaise.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmdcccliii{Ses fruits sont comme des têtes de diables.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmdcccliv{Ils doivent certainement en manger et ils doivent s'en remplir le ventre.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmdccclv{Ensuite ils auront par-dessus une mixture d'eau bouillante.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmdccclvi{Puis leur retour sera vers la Fournaise.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmdccclvii{C'est qu'ils ont trouvé leurs ancêtres dans l'égarement,\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmdccclviii{et les voilà courant sur leurs traces.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmdccclix{En effet, avant eux, la plupart des anciens se sont égarés.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmdccclx{Et Nous avions certes envoyé parmi eux des avertisseurs.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmdccclxi{Regarde donc ce qu'il est advenu de ceux qui ont été avertis!\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmdccclxii{Exception faite des élus, parmi les serviteurs d'Allah:\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmdccclxiii{Noé, en effet, fit appel à Nous qui sommes le Meilleur Répondeur (qui exauce les prières).\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmdccclxiv{Et Nous le sauvâmes, lui et sa famille, de la grande angoisse,\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmdccclxv{et Nous fîmes de sa descendance les seuls survivants.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmdccclxvi{et Nous avons perpétué son souvenir dans la postérité,\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmdccclxvii{Paix sur Noé dans tout l'univers!\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmmdccclxviii{Ainsi récompensons-Nous les bienfaisants.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmmdccclxix{Il était, certes, un de Nos serviteurs croyants.\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmmdccclxx{Ensuite Nous noyâmes les autres.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxi{Du nombre de ses coreligionnaires, certes, fut Abraham.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxii{Quand il vint à son Seigneur avec un cœur sain.\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxiii{Quand il dit à son père et à son peuple: «Qu'est-ce que vous adorez?»\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxiv{Cherchez-vous dans votre égarement, des divinités en dehors d'Allah?\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxv{Que pensez-vous du Seigneur de l'univers?»\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxvi{Puis, il jeta un regard attentif sur les étoiles,\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxvii{et dit: «Je suis malade».\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxviii{Ils lui tournèrent le dos et s'en allèrent.\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxix{Alors il se glissa vers leurs divinités et dit: «Ne mangez-vous pas?\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxx{Qu'avez-vous à ne pas parler?»\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxxi{Puis il se mit furtivement à les frapper de sa main droite.\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxxii{Alors [les gens] vinrent à lui en courant.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxxiii{Il [leur] dit: «Adorez-vous ce que vous-mêmes sculptez,\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxxiv{alors que c'est Allah qui vous a créés, vous et ce que vous fabriquez?»\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxxv{Ils dirent: «Qu'on lui construise un four et qu'on le lance dans la fournaise!»\qt@no{(97)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxxvi{Ils voulurent lui jouer un mauvais tour; mais ce sont eux que Nous mîmes à bas.\qt@no{(98)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxxvii{Et il dit: «Moi, je pars vers mon Seigneur et Il me guidera.\qt@no{(99)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxxviii{Seigneur, fais-moi don d'une [progéniture] d'entre les vertueux».\qt@no{(100)}}
\qt@newcmd\qurantrans@fr@mmmdccclxxxix{Nous lui fîmes donc la bonne annonce d'un garçon (Ismaël) longanime.\qt@no{(101)}}
\qt@newcmd\qurantrans@fr@mmmdcccxc{Puis quand celui-ci fut en âge de l'accompagner, [Abraham] dit: «O mon fils, je me vois en songe en train de t'immoler. Vois donc ce que tu en penses». (Ismaël) dit: «O mon cher père, fais ce qui t'es commandé: tu me trouveras, s'il plaît à Allah, du nombre des endurants».\qt@no{(102)}}
\qt@newcmd\qurantrans@fr@mmmdcccxci{Puis quand tous deux se furent soumis (à l'ordre d'Allah) et qu'il l'eut jeté sur le front,\qt@no{(103)}}
\qt@newcmd\qurantrans@fr@mmmdcccxcii{voilà que Nous l'appelâmes «Abraham!\qt@no{(104)}}
\qt@newcmd\qurantrans@fr@mmmdcccxciii{Tu as confirmé la vision. C'est ainsi que Nous récompensons les bienfaisants».\qt@no{(105)}}
\qt@newcmd\qurantrans@fr@mmmdcccxciv{C'était là certes, l'épreuve manifeste.\qt@no{(106)}}
\qt@newcmd\qurantrans@fr@mmmdcccxcv{Et Nous le rançonnâmes d'une immolation généreuse.\qt@no{(107)}}
\qt@newcmd\qurantrans@fr@mmmdcccxcvi{Et Nous perpétuâmes son renom dans la postérité:\qt@no{(108)}}
\qt@newcmd\qurantrans@fr@mmmdcccxcvii{«Paix sur Abraham».\qt@no{(109)}}
\qt@newcmd\qurantrans@fr@mmmdcccxcviii{Ainsi récompensons-Nous les bienfaisants;\qt@no{(110)}}
\qt@newcmd\qurantrans@fr@mmmdcccxcix{car il était de Nos serviteurs croyants.\qt@no{(111)}}
\qt@newcmd\qurantrans@fr@mmmcm{Nous lui fîmes la bonne annonce d'Isaac comme prophète d'entre les gens vertueux.\qt@no{(112)}}
\qt@newcmd\qurantrans@fr@mmmcmi{Et Nous le bénîmes ainsi que Isaac. Parmi leurs descendances il y a [l'homme] de bien et celui qui est manifestement injuste envers lui-même.\qt@no{(113)}}
\qt@newcmd\qurantrans@fr@mmmcmii{Et Nous accordâmes certes à Moïse et Aaron des faveurs,\qt@no{(114)}}
\qt@newcmd\qurantrans@fr@mmmcmiii{Et les sauvâmes ainsi que leur peuple, de la grande angoisse,\qt@no{(115)}}
\qt@newcmd\qurantrans@fr@mmmcmiv{et les secourûmes, et ils furent eux les vainqueurs.\qt@no{(116)}}
\qt@newcmd\qurantrans@fr@mmmcmv{Et Nous leur apportâmes le livre explicite\qt@no{(117)}}
\qt@newcmd\qurantrans@fr@mmmcmvi{et les guidâmes vers le droit chemin.\qt@no{(118)}}
\qt@newcmd\qurantrans@fr@mmmcmvii{Et Nous perpétuâmes leur renom dans la postérité:\qt@no{(119)}}
\qt@newcmd\qurantrans@fr@mmmcmviii{«Paix sur Moïse et Aaron»\qt@no{(120)}}
\qt@newcmd\qurantrans@fr@mmmcmix{Ainsi récompensons-Nous les bienfaisants;\qt@no{(121)}}
\qt@newcmd\qurantrans@fr@mmmcmx{car ils étaient du nombre de Nos serviteurs croyants.\qt@no{(122)}}
\qt@newcmd\qurantrans@fr@mmmcmxi{Elie était, certes, du nombre des Messagers.\qt@no{(123)}}
\qt@newcmd\qurantrans@fr@mmmcmxii{Quand il dit à son peuple: «Ne craignez-vous pas [Allah]?»\qt@no{(124)}}
\qt@newcmd\qurantrans@fr@mmmcmxiii{Invoquerez-vous Ball (une idole) et délaisserez-vous le Meilleur des créateurs,\qt@no{(125)}}
\qt@newcmd\qurantrans@fr@mmmcmxiv{Allah, votre Seigneur et le Seigneur de vos plus anciens ancêtres?»\qt@no{(126)}}
\qt@newcmd\qurantrans@fr@mmmcmxv{Ils le traitèrent de menteur. Et bien, ils seront emmenées (au châtiment).\qt@no{(127)}}
\qt@newcmd\qurantrans@fr@mmmcmxvi{Exception faite des serviteurs élus d'Allah.\qt@no{(128)}}
\qt@newcmd\qurantrans@fr@mmmcmxvii{Et Nous perpétuâmes son renom dans la postérité:\qt@no{(129)}}
\qt@newcmd\qurantrans@fr@mmmcmxviii{«Paix sur Elie et ses adeptes».\qt@no{(130)}}
\qt@newcmd\qurantrans@fr@mmmcmxix{Ainsi récompensons-Nous les bienfaisants,\qt@no{(131)}}
\qt@newcmd\qurantrans@fr@mmmcmxx{car il était du nombre de Nos serviteurs croyants.\qt@no{(132)}}
\qt@newcmd\qurantrans@fr@mmmcmxxi{Et Loût était, certes, du nombre des Messagers.\qt@no{(133)}}
\qt@newcmd\qurantrans@fr@mmmcmxxii{Quand Nous le sauvâmes, lui et sa famille, tout entière,\qt@no{(134)}}
\qt@newcmd\qurantrans@fr@mmmcmxxiii{sauf une vieille femme qui devait disparaître avec les autres,\qt@no{(135)}}
\qt@newcmd\qurantrans@fr@mmmcmxxiv{Et Nous détruisîmes les autres\qt@no{(136)}}
\qt@newcmd\qurantrans@fr@mmmcmxxv{Et vous passez certainement auprès d'eux le matin\qt@no{(137)}}
\qt@newcmd\qurantrans@fr@mmmcmxxvi{et la nuit. Ne raisonnez-vous donc pas?\qt@no{(138)}}
\qt@newcmd\qurantrans@fr@mmmcmxxvii{Jonas était certes, du nombre des Messagers.\qt@no{(139)}}
\qt@newcmd\qurantrans@fr@mmmcmxxviii{Quand il s'enfuit vers le bateau comble,\qt@no{(140)}}
\qt@newcmd\qurantrans@fr@mmmcmxxix{Il prit part au tirage au sort qui le désigna pour être jeté [à la mer].\qt@no{(141)}}
\qt@newcmd\qurantrans@fr@mmmcmxxx{Le poisson l'avala alors qu'il était blâmable.\qt@no{(142)}}
\qt@newcmd\qurantrans@fr@mmmcmxxxi{S'il n'avait pas été parmi ceux qui glorifient Allah,\qt@no{(143)}}
\qt@newcmd\qurantrans@fr@mmmcmxxxii{il serait demeuré dans son ventre jusqu'au jour où l'on sera ressuscité.\qt@no{(144)}}
\qt@newcmd\qurantrans@fr@mmmcmxxxiii{Nous le jetâmes sur la terre nue, indisposé qu'il était.\qt@no{(145)}}
\qt@newcmd\qurantrans@fr@mmmcmxxxiv{Et Nous fîmes pousser au-dessus de lui un plant de courge,\qt@no{(146)}}
\qt@newcmd\qurantrans@fr@mmmcmxxxv{et l'envoyâmes ensuite (comme prophète) vers cent mille hommes ou plus.\qt@no{(147)}}
\qt@newcmd\qurantrans@fr@mmmcmxxxvi{Ils crurent, et nous leur donnâmes jouissance de la vie pour un temps.\qt@no{(148)}}
\qt@newcmd\qurantrans@fr@mmmcmxxxvii{Pose-leur donc la question: «Ton Seigneur aurait-Il des filles et eux des fils?\qt@no{(149)}}
\qt@newcmd\qurantrans@fr@mmmcmxxxviii{Ou bien avons-Nous créé des Anges de sexe féminin, et en sont-ils témoins?».\qt@no{(150)}}
\qt@newcmd\qurantrans@fr@mmmcmxxxix{Certes, ils disent dans leur mensonge:\qt@no{(151)}}
\qt@newcmd\qurantrans@fr@mmmcmxl{«Allah a engendré» mais ce sont certainement des menteurs!\qt@no{(152)}}
\qt@newcmd\qurantrans@fr@mmmcmxli{Aurait-Il choisi des filles de préférence à des fils?\qt@no{(153)}}
\qt@newcmd\qurantrans@fr@mmmcmxlii{Qu'avez-vous donc à juger ainsi?\qt@no{(154)}}
\qt@newcmd\qurantrans@fr@mmmcmxliii{Ne réfléchissez-vous donc pas?\qt@no{(155)}}
\qt@newcmd\qurantrans@fr@mmmcmxliv{Ou avez-vous un argument évident?\qt@no{(156)}}
\qt@newcmd\qurantrans@fr@mmmcmxlv{Apportez donc votre Livre si vous êtes véridiques!»\qt@no{(157)}}
\qt@newcmd\qurantrans@fr@mmmcmxlvi{Et ils ont établi entre Lui et les djinns une parenté, alors que les djinns savent bien qu'ils [les mécréants] vont être emmenés (pour le châtiment).\qt@no{(158)}}
\qt@newcmd\qurantrans@fr@mmmcmxlvii{Gloire à Allah. Il est au-dessus de ce qu'ils décrivent!\qt@no{(159)}}
\qt@newcmd\qurantrans@fr@mmmcmxlviii{Exception faite des serviteurs élus d'Allah.\qt@no{(160)}}
\qt@newcmd\qurantrans@fr@mmmcmxlix{En vérité, vous et tout ce que vous adorez,\qt@no{(161)}}
\qt@newcmd\qurantrans@fr@mmmcml{ne pourrez tenter [personne],\qt@no{(162)}}
\qt@newcmd\qurantrans@fr@mmmcmli{excepté celui qui sera brûlé dans la Fournaise.\qt@no{(163)}}
\qt@newcmd\qurantrans@fr@mmmcmlii{Il n'y en a pas un, parmi nous, qui n'ait une place connue;\qt@no{(164)}}
\qt@newcmd\qurantrans@fr@mmmcmliii{nous sommes certes, les rangés en rangs;\qt@no{(165)}}
\qt@newcmd\qurantrans@fr@mmmcmliv{et c'est nous certes, qui célébrons la gloire [d'Allah].\qt@no{(166)}}
\qt@newcmd\qurantrans@fr@mmmcmlv{Même s'ils disaient:\qt@no{(167)}}
\qt@newcmd\qurantrans@fr@mmmcmlvi{«Si nous avions eu un Rappel de [nos] ancêtres,\qt@no{(168)}}
\qt@newcmd\qurantrans@fr@mmmcmlvii{nous aurions été certes les serviteurs élus d'Allah!\qt@no{(169)}}
\qt@newcmd\qurantrans@fr@mmmcmlviii{Ils y ont mécru et ils sauront bientôt.\qt@no{(170)}}
\qt@newcmd\qurantrans@fr@mmmcmlix{En effet, Notre Parole a déjà été donnée à Nos serviteurs, les Messagers,\qt@no{(171)}}
\qt@newcmd\qurantrans@fr@mmmcmlx{que ce sont eux qui seront secourus,\qt@no{(172)}}
\qt@newcmd\qurantrans@fr@mmmcmlxi{et que Nos soldats auront le dessus.\qt@no{(173)}}
\qt@newcmd\qurantrans@fr@mmmcmlxii{Eloigne-toi d'eux, jusqu'à un certain temps;\qt@no{(174)}}
\qt@newcmd\qurantrans@fr@mmmcmlxiii{et observe-les: ils verront bientôt!\qt@no{(175)}}
\qt@newcmd\qurantrans@fr@mmmcmlxiv{Quoi! est-ce Notre châtiment qu'ils cherchent à hâter?\qt@no{(176)}}
\qt@newcmd\qurantrans@fr@mmmcmlxv{Quand il tombera dans leur place, ce sera alors un mauvais matin pour ceux qu'on a avertis!\qt@no{(177)}}
\qt@newcmd\qurantrans@fr@mmmcmlxvi{Et éloigne-toi d'eux jusqu'à un certain temps;\qt@no{(178)}}
\qt@newcmd\qurantrans@fr@mmmcmlxvii{et observe; ils verront bientôt!\qt@no{(179)}}
\qt@newcmd\qurantrans@fr@mmmcmlxviii{Gloire à ton Seigneur, le Seigneur de la puissance. Il est au-dessus de ce qu'ils décrivent!\qt@no{(180)}}
\qt@newcmd\qurantrans@fr@mmmcmlxix{Et paix sur les Messagers,\qt@no{(181)}}
\qt@newcmd\qurantrans@fr@mmmcmlxx{et louange à Allah, Seigneur de l'univers!\qt@no{(182)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxi{\basmalahfr Sâd. Par le Coran, au renom glorieux (dikr)!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxii{Ceux qui ont mécru sont plutôt dans l'orgueil et le schisme!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxiii{Que de générations avant eux avons-Nous fait périr, qui ont crié, hélas, quand il n'était plus temps d'échapper?\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxiv{Et ils (les Mecquois) s'étonnèrent qu'un avertisseur parmi eux leur soit venu, et les infidèles disent: «C'est un magicien et un grand menteur,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxv{Réduira-t-il les divinités à un Seul Dieu? Voilà une chose vraiment étonnante».\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxvi{Et leurs notables partirent en disant: «Allez-vous en, et restez constants à vos dieux: c'est là vraiment une chose souhaitable.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxvii{Nous n'avons pas entendu cela dans la dernière religion (le Christianisme); ce n'est en vérité que pure invention!\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxviii{Quoi! C'est sur lui, parmi nous, qu'on aurait fait descendre le Rappel [le Coran]?» Plutôt ils sont dans le doute au sujet de Mon message. Ou plutôt ils n'ont pas encore goûté à Mon châtiment!\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxix{Ou bien détiennent-ils les trésors de la miséricorde de ton Seigneur, le Puissant, le Dispensateur par excellence.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxx{Ou bien ont-ils le royaume des cieux et de la terre et de ce qui existe entre eux? Eh bien, qu'ils y montent par n'importe quel moyen!\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxxi{Une armée de coalisés qui, ici-même, sera mise en déroute!\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxxii{Avant eux, le peuple de Noé, les Aad et Pharaon l'homme aux pals (ou aux Pyramides),\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxxiii{et les Tamûd, le peuple de Lot, et les gens d'Al-Aykah, (ont tous démenti leurs Messagers). Voilà les coalisés.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxxiv{Il n'en est aucun qui n'ait traité les Messagers de menteurs. Et bien, Ma punition s'est avérée contre eux!\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxxv{Ceux-ci n'attendant qu'un seul Cri, sans répétition.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxxvi{Et ils disent: «Seigneur, hâte-nous notre part avant le jour des Comptes».\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxxvii{Endure ce qu'ils disent; et rappelle-toi David, Notre serviteur, doué de force [dans l'adoration] et plein de repentir [à Allah].\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxxviii{Nous soumîmes les montagnes à glorifier Allah, soir et matin, en sa compagnie,\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmcmlxxxix{de même que les oiseaux assemblés en masse, tous ne faisant qu'obéir à lui [Allah].\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmcmxc{Et Nous renforçâmes son royaume et lui donnâmes la sagesse et la faculté de bien juger.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmcmxci{Et t'est-elle parvenue la nouvelle des disputeurs quand ils grimpèrent au mur du sanctuaire!\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmcmxcii{Quand ils entrèrent auprès de David, il en fut effrayé. Ils dirent: «N'aie pas peur! Nous sommes tous deux en dispute; l'un de nous a fait du tort à l'autre. Juge donc en toute équité entre nous, ne sois pas injuste et guide-nous vers le chemin droit.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmcmxciii{Celui-ci est mon frère: il a quatre-vingt-dix-neuf brebis, tandis que je n'ai qu'une brebis. Il m'a dit: «Confie-la-moi» et dans la conversation, il a beaucoup fait pression sur moi».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmcmxciv{Il [David] dit: «Il a été certes injuste envers toi en demandant de joindre ta brebis à ses brebis». Beaucoup de gens transgressent les droits de leurs associés, sauf ceux qui croient et accomplissent les bonnes œuvres - cependant ils sont bien rares -. Et David pensa alors que Nous l'avions mis à l'épreuve. Il demanda donc pardon à son Seigneur et tomba prosterné et se repentit.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmcmxcv{Nous lui pardonnâmes. Il aura une place proche de Nous et un beau refuge.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmcmxcvi{«O David, Nous avons fait de toi un calife sur la terre. Juge donc en toute équité parmi les gens et ne suis pas la passion: sinon elle t'égarera du sentier d'Allah». Car ceux qui s'égarent du sentier d'Allah auront un dur châtiment pour avoir oublié le Jour des Comptes.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmcmxcvii{Nous n'avons pas créé le ciel et la terre et ce qui existe entre eux en vain. C'est ce que pensent ceux qui ont mécru. Malheur à ceux qui ont mécru pour le feu [qui les attend]!\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmcmxcviii{Traiterons-Nous ceux qui croient et accomplissent les bonnes œuvres comme ceux qui commettent du désordre sur terre? ou traiterons-Nous les pieux comme les pervers?\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmcmxcix{[Voici] un Livre béni que Nous avons fait descendre vers toi, afin qu'ils méditent sur ses versets et que les doués d'intelligence réfléchissent!\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmm{Et à David Nous fîmes don de Salomon, - quel bon serviteur! - Il était plein de repentir.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmi{Quand un après-midi, on lui présenta de magnifiques chevaux de course,\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmii{il dit: «Oui, je me suis complu à aimer les biens (de ce monde) au point [d'oublier] le rappel de mon Seigneur jusqu'à ce que [le soleil] se soit caché derrière son voile.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmiii{Ramenez-les moi.» Alors il se mit à leur couper les pattes et les cous.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmiv{Et Nous avions certes éprouvé Salomon en plaçant sur son siège un corps. Ensuite, il se repentit.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmv{Il dit: «Seigneur, pardonne-moi et fais-moi don d'un royaume tel que nul après moi n'aura de pareil. C'est Toi le grand Dispensateur».\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmvi{Nous lui assujettîmes alors le vent qui, par son ordre, soufflait modérément partout où il voulait.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmvii{De même que les diables, bâtisseurs et plongeurs de toutes sortes.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmviii{Et d'autres encore, accouplés dans des chaînes.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmix{«Voilà Notre don; distribue-le ou retiens-le sans avoir à en rendre compte».\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmx{Et il a une place rapprochée de Nous et un beau refuge.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmxi{Et rappelle-toi Job, Notre serviteur, lorsqu'il appela son Seigneur: «Le Diable m'a infligé détresse et souffrance».\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmxii{Frappe [la terre] de ton pied: voici une eau fraîche pour te laver et voici de quoi boire.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmxiii{Et Nous lui rendîmes sa famille et la fîmes deux fois plus nombreuse, comme une miséricorde de Notre part et comme un rappel pour les gens doués d'intelligence.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmxiv{«Et prends dans ta main un faisceau de brindilles, puis frappe avec cela. Et ne viole pas ton serment». Oui, Nous l'avons trouvé vraiment endurant. Quel bon serviteur! Sans cesse il se repentait.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmxv{Et rappelle-toi Abraham, Isaac et Jacob, Nos serviteurs puissants et clairvoyants.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmxvi{Nous avons fait d'eux l'objet d'une distinction particulière: le rappel de l'au-delà.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmxvii{Ils sont auprès de Nous, certes, parmi les meilleurs élus.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmxviii{Et rappelle-toi Ismaël et Elisée, et Dal Kifl, chacun d'eux parmi les meilleurs.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmxix{Cela est un rappel. C'est aux pieux qu'appartient, en vérité, la meilleure retraite,\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmxx{Les Jardins d'Eden, aux portes ouvertes pour eux,\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmxxi{où, accoudés, ils demanderont des fruits abondants et des boissons.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmxxii{Et auprès d'eux seront les belles au regard chaste, toutes du même âge.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmxxiii{Voilà ce qui vous est promis pour le Jour des Comptes.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmxxiv{Ce sera Notre attribution inépuisable.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmxxv{Voilà! Alors que les rebelles auront certes la pire retraite,\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmxxvi{L'Enfer où ils brûleront. Et quel affreux lit!\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmxxvii{Voilà! Qu'ils y goûtent: eau bouillante et eau purulente,\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmmxxviii{et d'autres punitions du même genre.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmmxxix{Voici un groupe qui entre précipitamment en même temps que vous, nulle bienvenue à eux. Ils vont brûler dans le Feu.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmmxxx{Ils dirent: «Pas de bienvenue pour vous, plutôt. C'est vous qui avez préparé cela pour nous». Quel mauvais lieu de séjour!\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmmxxxi{Ils dirent: «Seigneur, celui qui nous a préparé cela, ajoute-lui un double châtiment dans le Feu».\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmmxxxii{Et ils dirent: «Pourquoi ne voyons-nous pas des gens que nous comptions parmi les malfaiteurs?\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmmxxxiii{Est-ce que nous les avons raillés (à tort) ou échappent-ils à nos regards?»\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmmxxxiv{Telles sont en vérité les querelles des gens du Feu.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmmxxxv{Dis: «Je ne suis qu'un avertisseur. Point de divinité à part Allah, l'Unique, le Dominateur Suprême,\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmmxxxvi{Seigneur des cieux et de la terre et de ce qui existe entre eux, le Puissant, le Grand Pardonneur».\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmmxxxvii{Dis: «Ceci (le Coran) est une grande nouvelle,\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmmxxxviii{mais vous vous en détournez.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmmxxxix{Je n'avais aucune connaissance de la cohorte sublime au moment où elle disputait.\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmmxl{Il m'est seulement révélé que je suis un avertisseur clair».\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmmxli{Quand ton Seigneur dit aux Anges: «Je vais créer d'argile un être humain.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmmxlii{Quand Je l'aurai bien formé et lui aurai insufflé de Mon Esprit, jetez-vous devant lui, prosternés».\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmmxliii{Alors tous les Anges se prosternèrent,\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmmxliv{à l'exception d'Iblîs qui s'enfla d'orgueil et fut du nombre des infidèles.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmmxlv{(Allah) lui dit: «O Iblîs, qui t'a empêché de te prosterner devant ce que J'ai créé de Mes mains? T'enfles-tu d'orgueil ou te considères-tu parmi les hauts placés?»\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmmxlvi{«Je suis meilleur que lui, dit [Iblîs,] Tu m'as créé de feu et tu l'as créé d'argile».\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmmxlvii{(Allah) dit: «Sors d'ici, te voilà banni;\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmmxlviii{et sur toi sera ma malédiction jusqu'au jour de la Rétribution».\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmmxlix{«Seigneur, dit [Iblîs], donne-moi donc un délai, jusqu'au jour où ils seront ressuscités».\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmmml{(Allah) dit: «Tu es de ceux à qui un délai est accordé,\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmmmli{jusqu'au jour de l'Instant bien Connu».\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmmmlii{«Par Ta puissance! dit [Satan]. Je les séduirai assurément tous,\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmmmliii{sauf Tes serviteurs élus parmi eux».\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmmmliv{(Allah) dit: «En vérité, et c'est la vérité que je dis,\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmmmlv{J'emplirai certainement l'Enfer de toi et de tous ceux d'entre eux qui te suivront».\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmmmlvi{Dis: «Pour cela, je ne vous demande aucun salaire; et je ne suis pas un imposteur.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmmmlvii{Ceci [le Coran] n'est qu'un rappel à l'univers.\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmmmlviii{Et certainement vous en aurez des nouvelles bientôt!»\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmmmlix{\basmalahfr La révélation du Livre vient d'Allah, le Puissant, le Sage.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmlx{Nous t'avons fait descendre le Livre en toute vérité. Adore donc Allah en Lui vouant un culte exclusif.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmlxi{C'est à Allah qu'appartient la religion pure. Tandis que ceux qui prennent des protecteurs en dehors de Lui (disent): «Nous ne les adorons que pour qu'ils nous rapprochent davantage d'Allah». En vérité, Allah jugera parmi eux sur ce en quoi ils divergent. Allah ne guide pas celui qui est menteur et grand ingrat.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmlxii{Si Allah avait voulu S'attribuer un enfant, Il aurait certes choisi ce qu'Il eût voulu parmi ce qu'Il crée. Gloire à Lui! C'est Lui Allah, l'Unique, le Dominateur suprême.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmlxiii{Il a créé les cieux et la terre en toute vérité. Il enroule la nuit sur le jour et enroule le jour sur la nuit, et Il a assujetti le soleil et la lune à poursuivre chacun sa course pour un terme fixé. C'est bien Lui le Puissant, le Grand Pardonneur!\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmlxiv{Il vous a créés d'une personne unique et a tiré d'elle son épouse. Et Il a fait descendre [créé] pour vous huit couples de bestiaux. Il vous crée dans les ventres de vos mères, création après création, dans trois ténèbres. Tel est Allah, votre Seigneur! A Lui appartient toute la Royauté. Point de divinité à part Lui. Comment pouvez-vous vous détourner [de son culte]?\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmlxv{Si vous ne croyez pas, Allah se passe largement de vous. De Ses serviteurs cependant, Il n'agrée pas la mécréance. Et si vous êtes reconnaissants, Il l'agrée pour vous. Nul pécheur ne portera les péchés d'autrui. Ensuite, vers votre Seigneur sera votre retour: Il vous informera alors de ce que vous faisiez car Il connaît parfaitement le contenu des poitrines.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmlxvi{Et quand un malheur touche l'homme, il appelle son Seigneur en se tournant vers Lui. Puis quand Il lui accorde de Sa part un bienfait, il oublie la raison pour laquelle il faisait appel, et il assigne à Allah des égaux, afin d'égarer (les gens) de son chemin. Dis «Jouis de ta mécréance un court moment. Tu fais partie des gens du Feu».\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmlxvii{Est-ce que celui qui, aux heures de la nuit, reste en dévotion, prosterné et debout, prenant garde à l'au-delà et espérant la miséricorde de son Seigneur... Dis: «Sont-ils égaux, ceux qui savent et ceux qui ne savent pas?» Seuls les doués d'intelligence se rappellent.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmlxviii{Dis: «O Mes serviteurs qui avez cru! Craignez votre Seigneur». Ceux qui ici-bas font le bien, auront une bonne [récompense]. La terre d'Allah est vaste et les endurants auront leur pleine récompense sans compter.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmlxix{Dis: «Il m'a été ordonné d'adorer Allah en Lui vouant exclusivement le culte,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmlxx{et il m'a été ordonné d'être le premier des Musulmans.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmlxxi{Dis: «Je crains, si je désobéis à mon Seigneur, le châtiment d'un jour terrible».\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmlxxii{Dis: «C'est Allah que j'adore, et Lui voue exclusivement mon culte.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmlxxiii{Adorez donc, en dehors de Lui, qui vous voudrez!» - Dis: «Les perdants sont ceux qui, au Jour de la Résurrection, auront causé la perte de leurs propres âmes et celles de leurs familles». C'est bien cela la perte évidente.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmlxxiv{Au-dessus d'eux ils auront des couches de feu et des couches au-dessous d'eux. Voilà ce dont Allah menace Ses esclaves. «O Mes esclaves, craignez-Moi donc!»\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmlxxv{Et à ceux qui s'écartent des Taghût pour ne pas les adorer, tandis qu'ils reviennent à Allah, à eux la bonne nouvelle! Annonce la bonne nouvelle à Mes serviteurs\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmlxxvi{qui prêtent l'oreille à la Parole, puis suivent ce qu'elle contient de meilleur. Ce sont ceux-là qu'Allah a guidés et ce sont eux les doués d'intelligence!\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmlxxvii{Et bien quoi! Celui contre qui s'avère le décret du châtiment,... est-ce que tu sauves celui qui est dans le Feu?\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmlxxviii{Mais ceux qui auront craint leur Seigneur auront [pour demeure] des étages [au Paradis] au-dessus desquels d'autres étages sont construits et sous lesquels coulent les rivières. Promesse d'Allah! Allah ne manque pas à Sa promesse.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmlxxix{Ne vois-tu pas qu'Allah fait descendre du ciel de l'eau, puis Il l'achemine vers des sources dans la terre; ensuite avec cela, Il fait sortir une culture aux couleurs diverses, laquelle se fane ensuite, de sorte que tu la vois jaunie; ensuite, Il la réduit en miettes. C'est là certainement un rappel aux [gens] doués d'intelligence.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmlxxx{Est-ce que celui dont Allah ouvre la poitrine à l'Islam et qui détient ainsi une lumière venant de Son Seigneur... Malheur donc à ceux dont les cœurs sont endurcis contre le rappel d'Allah. Ceux-là sont dans un égarement évident.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmlxxxi{Allah a fait descendre le plus beau des récits, un Livre dont [certains versets] se ressemblent et se répètent. Les peaux de ceux qui redoutent leur Seigneur frissonnent (à l'entendre); puis leurs peaux et leurs cœurs s'apaisent au rappel d'Allah. Voilà le [Livre] guide d'Allah par lequel Il guide qui Il veut. Mais quiconque Allah égare n'a point de guide.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmlxxxii{Est-ce que celui qui, au Jour de la Résurrection, se sera protégé le visage contre le pire châtiment... Et l'on dira aux injustes: «Goûtez à ce que vous avez acquis».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmlxxxiii{Ceux qui ont vécu avant eux ont démenti (les Messagers), le châtiment leur est venu par où ils ne le pressentaient pas.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmlxxxiv{Allah leur a fait goûter l'ignominie dans la vie présente. Le châtiment de l'au-delà, cependant, est plus grand, si seulement ils savaient!\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmlxxxv{Nous avons, dans ce Coran, cité pour les gens des exemples de toutes sortes afin qu'ils se souviennent.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmlxxxvi{Un Coran [en langue] arabe, dénué de tortuosité, afin qu'ils soient pieux!\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmlxxxvii{Allah a cité comme parabole un homme appartenant à des associés se querellant à son sujet et un [autre] homme appartenant à un seul homme: sont-ils égaux en exemple? Louanges à Allah! Mais la plupart d'entre eux ne savent pas.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmlxxxviii{En vérité tu mourras et ils mourront eux aussi;\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmlxxxix{ensuite, au Jour de la Résurrection, vous vous disputerez auprès de votre Seigneur.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmxc{Quel pire injuste donc, que celui qui ment contre Allah et qui traite de mensonge la vérité quand elle lui vient? N'est-ce pas dans l'Enfer qu'il y a un refuge pour les mécréants?\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmxci{Tandis que celui qui vient avec la vérité et celui qui la confirme, ceux-là sont les pieux.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmxcii{Ils auront tout ce qu'ils désireront auprès de leur Seigneur; voilà la récompense des bienfaisants,\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmxciii{afin qu'Allah leur efface les pires de leurs actions et les récompense selon ce qu'ils auront fait de meilleur.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmxciv{Allah ne suffit-Il pas à Son esclave [comme soutien]? Et ils te font peur avec ce qui est en dehors de Lui. Et quiconque Allah égare n'a point de guide.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmxcv{Quiconque Allah guide, nul ne peut l'égarer. Allah n'est-Il pas Puissant et Détenteur du pouvoir de châtier?\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmxcvi{Si tu leur demandais: «Qui a créé les cieux et la terre?», Ils diraient assurément: «Allah». Dis: «Voyez-vous ceux que vous invoquez en dehors d'Allah; si Allah me voulait du mal, est-ce que [ces divinités] pourraient dissiper Son mal? Ou s'Il me voulait une miséricorde, pourraient-elles retenir Sa miséricorde?» - Dis: «Allah me suffit: c'est en Lui que placent leur confiance ceux qui cherchent un appui».\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmxcvii{Dis: «O mon peuple, agissez selon votre méthode, moi j'agirai [selon la mienne]. Bientôt vous saurez\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmxcviii{sur qui s'abattra un châtiment qui l'avilira; et sur qui se justifiera un châtiment durable».\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmxcix{Nous t'avons fait descendre le Livre, pour les hommes, en toute vérité. Quiconque se guide [le fait] pour son propre bien; et quiconque s'égare, s'égare à son détriment. Tu n'es nullement responsable [de leurs propres affaires].\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmc{Allah reçoit les âmes au moment de leur mort ainsi que celles qui ne meurent pas au cours de leur sommeil. Il retient celles à qui Il a décrété la mort, tandis qu'Il renvoie les autres jusqu'à un terme fixé. Il y a certainement là des preuves pour des gens qui réfléchissent.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmci{Ont-ils adopté, en dehors d'Allah, des intercesseurs? Dis: «Quoi! Même s'ils ne détiennent rien et sont dépourvus de raison?\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmcii{Dis: «L'intercession toute entière appartient à Allah. A Lui la royauté des cieux et de la terre. Puis c'est vers Lui que vous serez ramenés».\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmciii{Et quand Allah est mentionné seul (sans associés), les cœurs de ceux qui ne croient pas en l'au-delà se crispent et quand on mentionne ceux qui sont en dehors de Lui, voilà qu'ils se réjouissent.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmciv{Dis: «O Allah, Créateur des cieux et de la terre, Connaisseur de tout ce que le monde ignore comme de ce qu'il perçoit, c'est Toi qui jugeras entre Tes serviteurs ce sur quoi ils divergeaient».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmcv{Si les injustes possédaient tout ce qui se trouve sur la terre, - et autant encore -, ils l'offriraient comme rançon pour échapper au pire châtiment le Jour de la Résurrection; et leur apparaîtra, de la part d'Allah, ce qu'ils n'avaient jamais imaginé;\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmcvi{et leur apparaîtront les méfaits qu'ils ont commis, et ce dont ils se raillaient les enveloppera.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmcvii{Quand un malheur touche l'homme, il Nous invoque. Quand ensuite Nous lui accordons une faveur de Notre part, il dit: «Je ne la dois qu'à [ma] science». C'est une épreuve, plutôt; mais la plupart d'entre eux ne savent pas.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmcviii{Ainsi parlaient ceux qui vécurent avant eux. Mais ce qu'ils ont acquis ne leur a servi à rien;\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmcix{Ils furent donc atteints par les mauvaises conséquences de leurs acquis. Ceux de ces gens [les Mecquois] qui auront commis l'injustice seront atteints par les mauvaises conséquences de leurs acquis et ils ne pourront s'opposer à la puissance [d'Allah].\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmcx{Ne savent-ils pas qu'Allah attribue Ses dons avec largesse ou les restreint à qui Il veut? Il y a en cela des preuves pour des gens qui croient.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmcxi{Dis: «O Mes serviteurs qui avez commis des excès à votre propre détriment, ne désespérez pas de la miséricorde d'Allah. Car Allah pardonne tous les péchés. Oui, c'est Lui le Pardonneur, le Très Miséricordieux.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmcxii{Et revenez repentant à votre Seigneur, et soumettez-vous à Lui, avant que ne vous vienne le châtiment et vous ne recevez alors aucun secours.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmcxiii{Et suivez la meilleure révélation qui vous est descendue de la part de votre Seigneur, avant que le châtiment ne vous vienne soudain, sans que vous ne [le] pressentiez;\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmcxiv{avant qu'une âme ne dise: «Malheur à moi pour mes manquements envers Allah. Car j'ai été certes, parmi les railleurs»\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmcxv{ou qu'elle ne dise: «Si Allah m'avait guidée, j'aurais été certes, parmi les pieux»\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmmcxvi{ou bien qu'elle ne dise en voyant le châtiment: «Ah! S'il y avait pour moi un retour! Je serais alors parmi les bienfaisants».\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmmcxvii{«Oh que si! Mes versets te sont venus et tu les as traités de mensonge, tu t'es enflé d'orgueil et tu étais parmi les mécréants».\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmmcxviii{Et au Jour de la Résurrection, tu verras les visages de ceux qui mentaient sur Allah, assombris. N'est-ce pas dans l'Enfer qu'il y aura une demeure pour les orgueilleux?\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmmcxix{Et Allah sauvera ceux qui ont été pieux en leur faisant gagner [leur place au Paradis]. Nul mal ne les touchera et ils ne seront point affligés.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmmcxx{Allah est le Créateur de toute chose, et de toute chose Il est Garant.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmmcxxi{Il détient les clefs des cieux et de la terre; et ceux qui ne croient pas aux versets d'Allah, ce sont ceux-là les perdants.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmmcxxii{Dis: «Me commanderez-vous d'adorer autre qu'Allah, O ignorants?»\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmmcxxiii{En effet, il t'a été révélé, ainsi qu'à ceux qui t'ont précédé: «Si tu donnes des associés à Allah, ton œuvre sera certes vaine; et tu seras très certainement du nombre des perdants.\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmmcxxiv{Tout au contraire, adore Allah seul et sois du nombre des reconnaissants».\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmmcxxv{Ils n'ont pas estimé Allah comme Il devrait l'être alors qu'au Jour de la Résurrection, Il fera de la terre entière une poignée, et les cieux seront pliés dans Sa [main] droite. Gloire à Lui! Il est au-dessus de ce qu'ils Lui associent.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmmcxxvi{Et on soufflera dans la Trompe, et voilà que ceux qui seront dans les cieux et ceux qui seront sur la terre seront foudroyés, sauf ceux qu'Allah voudra [épargner]. Puis on y soufflera de nouveau, et les voilà debout à regarder.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmmcxxvii{Et la terre resplendira de la lumière de son Seigneur; le Livre sera déposé et on fera venir les prophètes et les témoins; on décidera parmi eux en toute équité et ils ne seront point lésés;\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmmcxxviii{et chaque âme sera pleinement rétribuée pour ce qu'elle aura œuvré. Il [Allah] connaît mieux ce qu'ils font.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmmcxxix{Et ceux qui avaient mécru seront conduits par groupes à l'Enfer. Puis, quand ils y parviendront, ses portes s'ouvriront et ses gardiens leur diront: «Des messagers [choisis] parmi vous ne vous sont-ils pas venus, vous récitant les versets de votre Seigneur et vous avertissant de la rencontre de votre jour que voici?» Ils diront: si, mais le décret du châtiment s'est avéré juste contre les mécréants.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmmcxxx{«Entrez, [leur] dira-t-on, par les portes de l'Enfer, pour y demeurer éternellement». Qu'il est mauvais le lieu de séjour des orgueilleux!\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmmcxxxi{Et ceux qui avaient craint leur Seigneur seront conduits par groupes au Paradis. Puis, quand ils y parviendront et que ses portes s'ouvriront ses gardiens leur diront: «Salut à vous! vous avez été bons: entrez donc, pour y demeurer éternellement».\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmmcxxxii{Et ils diront: «Louange à Allah qui nous a tenu Sa promesse et nous a fait hériter la terre! Nous allons nous installer dans le Paradis là où nous voulons». Que la récompense de ceux qui font le bien est excellente!\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmmcxxxiii{Et tu verras les Anges faisant cercle autour du Trône, célébrant les louanges de leur Seigneur et Le glorifiant. Et il sera jugé entre eux en toute équité, et l'on dira: «Louange à Allah, Seigneur de l'univers».\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmmcxxxiv{\basmalahfr H'â, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmcxxxv{La révélation du Livre vient d'Allah, le Puissant, l'Omniscient.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmcxxxvi{Le Pardonneur des péchés, l'Accueillant au repentir, le Dur en punition, le Détenteur des faveurs. Point de divinité à part Lui et vers Lui est la destination.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmcxxxvii{Seuls ceux qui ont mécru discutent les versets d'Allah. Que leurs activités dans le pays ne te trompent pas.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmcxxxviii{Avant eux, le peuple de Noé a traité (Son Messager) de menteur, et les coalisés après eux (ont fait de même), et chaque communauté a conçu le dessein de s'emparer de Son Messager. Et ils ont discuté de faux arguments pour rejeter la vérité. Alors Je les ai saisis. Et quelle punition fut la Mienne!\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmcxxxix{Ainsi s'avéra juste la Parole de ton Seigneur contre ceux qui ont mécru: «Ils seront les gens du Feu».\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmcxl{Ceux (les Anges) qui portent le Trône et ceux qui l'entourent célèbrent les louanges de leur Seigneur, croient en Lui et implorent le pardon pour ceux qui croient: «Seigneur! Tu étends sur toute chose Ta miséricorde et Ta science. Pardonne donc à ceux qui se repentent et suivent Ton chemin et protège-les du châtiment de l'Enfer.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmcxli{Seigneur! Fais-les entrer aux jardins d'Eden que Tu leur as promis, ainsi qu'aux vertueux parmi leurs ancêtres, leurs épouses et leurs descendants, car c'est Toi le Puissant, le Sage.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmcxlii{Et préserve-les [du châtiment] des mauvaises actions. Quiconque Tu préserves [du châtiment] des mauvaises actions ce jour-là, Tu lui feras miséricorde». Et c'est là l'énorme succès.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmcxliii{A ceux qui n'auront pas cru on proclamera: «l'aversion d'Allah [envers vous] est plus grande que votre aversion envers vous-mêmes, lorsque vous étiez appelés à la foi et que vous persistiez dans la mécréance».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmcxliv{Ils diront: «Notre Seigneur, Tu nous as fais mourir deux fois et redonné la vie deux fois: nous reconnaissons donc nos péchés. Y a-t-il un moyen d'en sortir?»\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmcxlv{«... Il en est ainsi car lorsqu'Allah était invoqué seul (sans associé), vous ne croyiez pas; et si on Lui donnait des associés, alors vous croyiez. Le jugement appartient à Allah, le Très Haut, le Très Grand».\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmcxlvi{C'est Lui qui vous fait voir Ses preuves, et fait descendre du ciel, pour vous, une subsistance. Seul se rappelle celui qui revient [à Allah].\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmcxlvii{Invoquez Allah donc, en Lui vouant un culte exclusif quelque répulsion qu'en aient les mécréants.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmcxlviii{Il est Celui qui est élevé aux degrés les plus hauts, Possesseur du Trône, Il envoie par son ordre l'Esprit sur celui qu'Il veut parmi Ses serviteurs, afin que celui-ci avertisse du jour de la Rencontre,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmcxlix{le jour où ils comparaîtront sans que rien en eux ne soit caché à Allah. A qui appartient la royauté, aujourd'hui? A Allah, l'Unique, le Dominateur.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmcl{Ce jour-là, chaque âme sera rétribuée selon ce qu'elle aura acquis. Ce jour-là, pas d'injustice, car Allah est prompt dans [Ses] comptes.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmcli{Et avertis-les du jour qui approche, quand les cœurs remonteront aux gorges, terrifiés (ou angoissés). Les injustes n'auront ni ami zélé, ni intercesseur écouté.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmclii{Il (Allah) connaît la trahison des yeux, tout comme ce que les poitrines cachent.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmcliii{Et Allah juge en toute équité, tandis que ceux qu'ils invoquent en dehors de Lui ne jugent rien. En vérité c'est Allah qui est l'Audient, le Clairvoyant.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmcliv{Ne parcourent-ils pas la terre, pour voir ce qu'il est advenu de ceux qui ont vécu avant eux? Ils étaient [pourtant] plus forts qu'eux et ont laissé sur terre bien plus de vestiges. Allah les saisit pour leurs péchés et ils n'eurent point de protecteur contre Allah.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmclv{Ce fut ainsi, parce que leurs Messagers leur avaient apporté les preuves, mais ils se montrèrent mécréants. Allah donc les saisit, car Il est fort et redoutable dans Son châtiment.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmclvi{Nous envoyâmes effectivement Moïse avec Nos signes et une preuve évidente,\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmclvii{vers Pharaon, Hâmân et Coré. Mais ils dirent: «Magicien! Grand menteur!»\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmclviii{Puis, quand il leur eut apporté la vérité venant de Nous, ils dirent: «Tuez les fils de ceux qui ont cru avec lui, et laissez vivre leurs femmes». Et les ruses des mécréants ne vont qu'en pure perte.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmclix{Et Pharaon dit: «Laissez-moi tuer Moïse. Et qu'il appelle son Seigneur! Je crains qu'il ne change votre religion ou qu'il ne fasse apparaître la corruption sur terre».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmclx{Moïse [lui] dit: «Je cherche auprès de mon Seigneur et le vôtre, protection contre tout orgueilleux qui ne croit pas au jour du Compte».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmclxi{Et un homme croyant de la famille de Pharaon, qui dissimulait sa foi dit: «Tuez-vous un homme parce qu'il dit: «Mon Seigneur est Allah?» Alors qu'il est venu à vous avec les preuves évidentes de la part de votre Seigneur. S'il est menteur, son mensonge sera à son détriment; tandis que s'il est véridique, alors une partie de ce dont il vous menace tombera sur vous». Certes, Allah ne guide pas celui qui est outrancier et imposteur!\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmclxii{«O mon peuple, triomphant sur la terre, vous avez la royauté aujourd'hui. Mais qui nous secourra de la rigueur d'Allah si elle nous vient?» Pharaon dit: «Je ne vous indique que ce que je considère bon. Je ne vous guide qu'au sentier de la droiture».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmclxiii{Et celui qui était croyant dit: «O mon peuple, je crains pour vous un jour semblable à celui des coalisés.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmclxiv{Un sort semblable à celui du peuple de Noé, des 'Aad et des Thamûd et de ceux [qui vécurent] après eux». Allah ne veut [faire subir] aucune injustice aux serviteurs.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmclxv{«O mon peuple, je crains pour vous le jour de l'Appel Mutuel,\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmclxvi{Le jour où vous tournerez le dos en déroute, sans qu'il y ait pour vous de protecteur contre Allah». Et quiconque Allah égare, n'a point de guide.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmclxvii{Certes, Joseph vous est venu auparavant avec les preuves évidentes, mais vous n'avez jamais cessé d'avoir des doutes sur ce qu'il vous avait apporté. Mais lorsqu'il mourut, vous dites alors: «Allah n'enverra plus jamais de Messager après lui». Ainsi Allah égare-t-Il celui qui est outrancier et celui qui doute.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmclxviii{Ceux qui discutent les prodiges d'Allah sans qu'aucune preuve ne leur soit venue, [leur action] est grandement haïssable auprès d'Allah et auprès de ceux qui croient. Ainsi Allah scelle-t-Il le cœur de tout orgueilleux tyran.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmclxix{Et Pharaon dit: «O Hâmân, bâtis-moi une tour: peut-être atteindrai-je les voies,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmclxx{les voies des cieux, et apercevrai-je le Dieu de Moïse; mais je pense que celui-ci est menteur». Ainsi la mauvaise action de Pharaon lui parut enjolivée; et il fut détourné du droit chemin; et le stratagème de Pharaon n'est voué qu'à la destruction.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmclxxi{Et celui qui avait cru dit: «O mon peuple, suivez-moi. Je vous guiderai au sentier de la droiture.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmclxxii{O mon peuple, cette vie n'est que jouissance temporaire, alors que l'au-delà est vraiment la demeure de la stabilité.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmclxxiii{Quiconque fait une mauvaise action ne sera rétribué que par son pareil; et quiconque, mâle ou femelle, fait une bonne action tout en étant croyant, alors ceux-là entreront au Paradis pour y recevoir leur subsistance sans compter.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmclxxiv{O mon peuple, mais qu'ai-je à vous appeler au salut, alors que vous m'appelez au Feu?\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmclxxv{Vous m'invitez à nier Allah et à Lui donner des associés dont je n'ai aucun savoir, alors que je vous appelle au Tout Puissant, au Grand Pardonneur.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmclxxvi{Nul doute que ce à quoi vous m'appelez ne peut exaucer une invocation ni ici-bas ni dans l'au-delà. C'est vers Allah qu'est notre retour, et les outranciers sont eux les gens du Feu.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmclxxvii{Bientôt vous vous rappellerez ce que je vous dis; et je confie mon sort à Allah. Allah est, certes, Clairvoyant sur les serviteurs.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmclxxviii{Allah donc le protégea des méfaits de leurs ruses, alors que le pire châtiment cerna les gens de Pharaon:\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmclxxix{le Feu, auquel ils sont exposés matin et soir. Et le jour où l'Heure arrivera (il sera dit): «Faites entrer les gens de Pharaon au plus dur du châtiment».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmclxxx{Et quand ils se disputeront dans le Feu, les faibles diront à ceux qui s'enflaient d'orgueil: «Nous vous avions suivis: pourriez-vous nous préserver d'une partie du feu?»\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmclxxxi{Et ceux qui s'enflaient d'orgueil diront: «En vérité, nous y voilà tous». Allah a déjà rendu son jugement entre les serviteurs.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmclxxxii{Et ceux qui seront dans le Feu diront aux gardiens de l'Enfer: «Priez votre Seigneur de nous alléger un jour de [notre] supplice».\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmclxxxiii{Ils diront: «vos Messagers, ne vous apportaient-ils pas les preuves évidentes?» Ils diront: «Si»! Ils [les gardiens] diront: «Eh bien, priez» ! Et l'invocation des mécréants n'est qu'aberration.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmclxxxiv{Nous secourrons, certes, Nos Messagers et ceux qui croient, dans la vie présente tout comme au jour où les témoins [les Anges gardiens] se dresseront (le Jour du Jugement),\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmclxxxv{au jour où leur excuse ne sera pas utile aux injustes, tandis qu'il y aura pour eux la malédiction et la pire demeure.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmclxxxvi{En effet, Nous avons apporté à Moïse la guidée, et fait hériter aux Enfants d'Israël, le Livre,\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmclxxxvii{une guidée et un rappel aux gens doués d'intelligence.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmclxxxviii{Endure donc, car la promesse d'Allah est vérité, implore le pardon pour ton péché et célèbre la gloire et la louange de ton Seigneur, soir et matin.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmclxxxix{Ceux qui discutent sur les versets d'Allah sans qu'aucune preuve ne leur soit venue, n'ont dans leurs poitrines qu'orgueil. Ils n'atteindront pas leur but. Implore donc la protection d'Allah, car c'est Lui l'Audient, le Clairvoyant.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmcxc{La création des cieux et de la terre est quelque chose de plus grand que la création des gens. Mais la plupart des gens ne savent pas.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmmcxci{L'aveugle et le voyant ne sont pas égaux, et ceux qui croient et accomplissent les bonnes œuvres ne peuvent être comparés à celui qui fait le mal. C'est rare que vous vous rappeliez!\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmmcxcii{En vérité; L'Heure va arriver: pas de doute là-dessus; mais la plupart des gens n'y croient pas.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmmcxciii{Et votre Seigneur dit: «Appelez-Moi, Je vous répondrai. Ceux qui, par orgueil, se refusent à M'adorer entreront bientôt dans l'Enfer, humiliés».\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmmcxciv{Allah est celui qui vous a assigné la nuit pour que vous vous y reposiez, et le jour pour y voir clair. Allah est le Pourvoyeur de grâce aux hommes, mais la plupart des gens ne sont pas reconnaissants.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmmcxcv{Tel est votre Seigneur, Créateur de toute chose. Point de divinité à part Lui. Comment se fait-il que vous vous détourniez (du chemin droit)?\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmmcxcvi{Ainsi ceux qui nient les prodiges d'Allah se détournent-ils [du chemin droit.]\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmmcxcvii{C'est Allah qui vous a assigné la terre comme demeure stable et le ciel comme toit et vous a donné votre forme, - et quelle belle forme Il vous a donnée! - et Il vous a nourris de bonnes choses. Tel est Allah, votre Seigneur; gloire à Allah, Seigneur de l'univers!\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmmcxcviii{C'est Lui le Vivant. Point de divinité à part Lui. Appelez-Le donc, en Lui vouant un culte exclusif. Louange à Allah, Seigneur de l'univers!\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmmcxcix{Dis: «Il m'a été interdit, une fois que les preuves me sont venues de mon Seigneur, d'adorer ceux que vous invoquez en dehors d'Allah, et il m'a été ordonné de me soumettre au Seigneur de l'univers».\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmmcc{C'est Lui qui vous a créés de terre, puis d'une goutte sperme, puis d'une adhérence; puis Il vous fait sortir petit enfant pour qu'ensuite vous atteigniez votre maturité et qu'ensuite vous deveniez vieux, - certains parmi vous meurent plus tôt, - et pour que vous atteigniez un terme fixé, afin que vous raisonniez.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmmcci{C'est Lui qui donne la vie et donne la mort. Puis quand Il décide une affaire, Il n'a qu'à dire: «Sois», et elle est.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmmccii{N'as-tu pas vu comment ceux qui discutent sur les versets d'Allah se laissent détourner?\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmmcciii{Ceux qui traitent de mensonge le Livre (le Coran) et ce avec quoi Nous avons envoyé Nos Messagers; ils sauront bientôt,\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmmcciv{quand, des carcans à leurs cous et avec des chaînes ils seront traînés\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmmccv{dans l'eau bouillante; et qu'ensuite ils brûleront dans le Feu.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmmccvi{Puis on leur dira: «Où sont ceux que vous associez\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmmccvii{à Allah?» «Ils se sont écartés de nous, diront-ils. Ou plutôt, nous n'invoquions rien, auparavant». Ainsi Allah égare-t-Il les mécréants.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmmccviii{Voilà le prix de votre exultation sur terre, sans raison, ainsi que de votre joie immodérée.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmmccix{Franchissez les portes de l'Enfer pour y demeurer éternellement. Qu'il est mauvais le lieu de séjour des orgueilleux!\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmmccx{Endure donc. La promesse d'Allah est vraie. Que Nous te montrions une partie de ce dont Nous les menaçons ou que Nous te fassions mourir (avant cela)... c'est vers Nous qu'ils seront ramenés.\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmmccxi{Certes, Nous avons envoyé avant toi des Messagers. Il en est dont Nous t'avons raconté l'histoire; et il en est dont Nous ne t'avons pas raconté l'histoire. Et il n'appartient pas à un Messager d'apporter un signe [ou verset] si ce n'est avec la permission d'Allah. Lorsque le commandement d'Allah viendra, tout sera décidé en toute justice; et ceux qui profèrent des mensonges sont alors les perdants.\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmmccxii{C'est Allah qui vous a fait les bestiaux pour que vous en montiez et que vous en mangiez,\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmmmccxiii{et vous y avez des profits et afin que vous atteigniez sur eux une chose nécessaire qui vous tenait à cœur. C'est sur eux et sur les vaisseaux que vous êtes transportés.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmmmccxiv{Et Il vous montre Ses merveilles. Quelles merveilles d'Allah niez-vous donc?\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmmmccxv{Ne parcourent-ils donc pas la terre pour voir ce qu'il est advenu de ceux qui étaient avant eux? Ils étaient [pourtant] plus nombreux qu'eux et bien plus puissants et ils [avaient laissé] sur terre beaucoup plus de vestiges. Mais ce qu'ils ont acquis ne leur a servi à rien.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmmmccxvi{Lorsque leurs Messagers leur apportaient les preuves évidentes, ils exultaient des connaissances qu'ils avaient. Et ce dont ils se moquaient les enveloppa.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmmmccxvii{Puis, quand ils virent Notre rigueur ils dirent: «Nous croyons en Allah Seul, et nous renions ce que nous Lui donnions comme associés».\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmmmccxviii{Mais leur croyance, au moment où ils eurent constaté Notre rigueur, ne leur profita point; Telle est la règle d'Allah envers Ses serviteurs dans le passé. Et c'est là que les mécréants se trouvèrent perdants.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmmmccxix{\basmalahfr H'â, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmccxx{[C'est] une Révélation descendue de la part du Tout Miséricordieux, du Très Miséricordieux.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmccxxi{Un Livre dont les versets sont détaillés (et clairement exposés), un Coran [lecture] arabe pour des gens qui savent,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmccxxii{annonciateur [d'une bonne nouvelle] et avertisseur. Mais la plupart d'entre eux se détournent; c'est qu'ils n'entendent pas.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmccxxiii{Et ils dirent: «Nos cœurs sont voilés contre ce à quoi tu nous appelles, nos oreilles sont sourdes. Et entre nous et toi, il y a une cloison. Agis donc de ton côté; nous agissons du nôtre.»\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmccxxiv{Dis: «Je ne suis qu'un homme comme vous. Il m'a été révélé que votre Dieu est un Dieu unique. Cherchez le droit chemin vers Lui et implorez son pardon». Et malheur aux Associateurs\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmccxxv{qui n'acquittent pas la Zakât et ne croient pas en l'au-delà!\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmccxxvi{Ceux qui croient et accomplissent de bonnes œuvres auront une énorme récompense jamais interrompue.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmccxxvii{Dis: «Renierez-vous [l'existence] de celui qui a créé la terre en deux jours et Lui donnerez-vous des égaux? Tel est le Seigneur de l'univers,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmccxxviii{c'est Lui qui a fermement fixé des montagnes au-dessus d'elle, l'a bénie et lui assigna ses ressources alimentaires en quatre jours d'égale durée. [Telle est la réponse] à ceux qui t'interrogent.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmccxxix{Il S'est ensuite adressé au ciel qui était alors fumée et lui dit, ainsi qu'à la terre: «Venez tous deux, bon gré, mal gré». Tous deux dirent: «Nous venons obéissants».\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmccxxx{Il décréta d'en faire sept cieux en deux jours et révéla à chaque ciel sa fonction. Et Nous avons décoré le ciel le plus proche de lampes [étoiles] et l'avons protégé. Tel est l'Ordre établi par le Puissant, l'Omniscient.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmccxxxi{S'ils s'en détournent, alors dis-leur; «Je vous ai avertis d'une foudre semblable à celle qui frappa les 'Aad et les Tamûd».\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmccxxxii{Quand les Messagers leur étaient venus, de devant eux et par derrière, [leur disant]: «N'adorez qu'Allah», ils dirent: «Si notre Seigneur avait voulu, Il aurait certainement fait descendre des Anges. Nous ne croyons donc pas [au message] avec lequel vous avez été envoyés».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmccxxxiii{Quant aux 'Aad, ils s'enflèrent d'orgueil sur terre injustement et dirent: «Qui est plus fort que nous?» Quoi! N'ont-ils pas vu qu'en vérité Allah qui les a créés est plus fort qu'eux? Et ils reniaient Nos signes.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmccxxxiv{Nous déchaînâmes contre eux un vent violent et glacial en des jours néfastes, afin de leur faire goûter le châtiment de l'ignominie dans la vie présente. Le châtiment de l'au-delà cependant est plus ignominieux encore, et ils ne seront pas secourus.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmccxxxv{Et quant aux Tamûd, Nous les guidâmes; mais ils ont préféré l'aveuglement à la guidée. C'est alors qu'ils furent saisis par la foudre du supplice le plus humiliant pour ce qu'ils avaient acquis.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmccxxxvi{Et Nous sauvâmes ceux qui croyaient et craignaient Allah.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmccxxxvii{Et le jour où les ennemis d'Allah seront rassemblés en masse vers le Feu... Puis on les poussera [dans sa direction].\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmccxxxviii{Alors, quand ils y seront, leur ouïe, leurs yeux et leurs peaux témoigneront contre eux de ce qu'ils œuvraient.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmccxxxix{Ils diront à leurs peaux: «Pourquoi avez-vous témoigné contre nous?» Elles diront: «C'est Allah qui nous a fait parler, Lui qui fait parler toute chose. C'est Lui qui vous a créés une première fois et c'est vers Lui que vous serez retournés».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmccxl{Vous ne pouviez vous cacher au point que ni votre ouïe, ni vos yeux et ni vos peaux ne puissent témoigner contre vous. Mais vous pensiez qu'Allah ne savait pas beaucoup de ce que vous faisiez.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmccxli{Et c'est cette pensée que vous avez eue de votre Seigneur, qui vous a ruinés, de sorte que vous êtes devenus du nombre des perdants.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmccxlii{S'ils endurent, le Feu sera leur lieu de séjour; et s'ils cherchent à s'excuser, ils ne seront pas excusés.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmccxliii{Et Nous leur avons destiné des compagnons inséparables [des démons] qui leur ont enjolivé ce qui était devant et derrière eux. Et le décret s'est avéré juste contre eux, comme contre les autres communautés de djinns et d'hommes qui ont vécu avant eux. Ils sont certes perdants!\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmccxliv{Et ceux qui avaient mécru dirent: «Ne prêtez pas l'oreille à ce Coran, et faites du chahut (pendant sa récitation), afin d'avoir le dessus».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmccxlv{Nous ferons certes, goûter à ceux qui ne croient pas un dur châtiment, et les rétribuerons certes [d'une punition] pire que ce [que méritent] leurs méfaits.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmccxlvi{Ainsi, la rétribution des ennemis d'Allah sera le Feu où ils auront une demeure éternelle, comme punition pour avoir nié Nos versets [le Coran].\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmccxlvii{Et les mécréants diront: «Seigneur, fais-nous voir ceux des djinns et des humains qui nous ont égarés, afin que nous les placions tous sous nos pieds, pour qu'ils soient parmi les plus bas».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmccxlviii{Ceux qui disent: «Notre Seigneur est Allah», et qui se tiennent dans le droit chemin, les Anges descendent sur eux. «N'ayez pas peur et ne soyez pas affligés; mais ayez la bonne nouvelle du Paradis qui vous était promis.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmccxlix{Nous sommes vos protecteurs dans la vie présente et dans l'au-delà; et vous y aurez ce que vos âmes désireront et ce que vous réclamerez,\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmccl{un lieu d'accueil de la part d'un Très Grand Pardonneur, d'un Très Miséricordieux».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmccli{Et qui profère plus belles paroles que celui qui appelle à Allah, fait bonne œuvre et dit: «Je suis du nombre des Musulmans?»\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmcclii{La bonne action et la mauvaise ne sont pas pareilles. Repousse (le mal) par ce qui est meilleur; et voilà que celui avec qui tu avais une animosité devient tel un ami chaleureux.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmccliii{Mais (ce privilège) n'est donné qu'à ceux qui endurent et il n'est donné qu'au possesseur d'une grâce infinie.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmccliv{Et si jamais le Diable t'incite (à agir autrement), alors cherche refuge auprès d'Allah; c'est Lui, vraiment l'Audient, l'Omniscient.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmcclv{Parmi Ses merveilles, sont la nuit et le jour, le soleil et la lune: ne vous prosternez ni devant le soleil, ni devant la lune, mais prosternez-vous devant Allah qui les a créés, si c'est Lui que vous adorez.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmcclvi{Mais s'ils s'enflent d'orgueil... ceux qui sont auprès de ton Seigneur [les Anges] Le glorifient, nuit et jour, sans jamais se lasser!\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmcclvii{Et parmi Ses merveilles est que tu vois la terre humiliée (toute nue). Puis aussitôt que Nous faisons descendre l'eau sur elle, elle se soulève et augmente [de volume]. Celui qui lui redonne la vie est certes Celui qui fera revivre les morts, car Il est Omnipotent.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmcclviii{Ceux qui dénaturent le sens de Nos versets (le Coran) ne Nous échappent pas. Celui qui sera jeté au Feu sera-t-il meilleur que celui qui viendra en toute sécurité le Jour de la Résurrection? Faites ce que vous voulez car Il est Clairvoyant sur tout ce que vous faites;\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmcclix{Ceux qui ne croient pas au Rappel [le Coran] quand il leur parvient... alors que c'est un Livre puissant [inattaquable];\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmcclx{Le faux ne l'atteint [d'aucune part], ni par devant ni par derrière: c'est une révélation émanant d'un Sage, Digne de louange.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmcclxi{Il ne t'est dit que ce qui a été dit aux Messagers avant toi. Ton Seigneur est certes Détenteur du pardon et Détenteur aussi d'une punition douloureuse.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmcclxii{Si Nous en avions fait un Coran en une langue autre que l'arabe, ils auraient dit: «Pourquoi ses versets n'ont-ils pas été exposés clairement? quoi? Un [Coran] non-arabe et [un Messager] arabe?» Dis: «Pour ceux qui croient, il est une guidée et une guérison». Et quant à ceux qui ne croient pas, il y a une surdité dans leurs oreilles et ils sont frappés d'aveuglement en ce qui le concerne; ceux-là sont appelés d'un endroit lointain.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmcclxiii{Nous avons effectivement donné à Moïse le Livre. Puis, il y eut controverse là-dessus. Et si ce n'était une parole préalable de ton Seigneur, on aurait certainement tranché entre eux. Ils sont vraiment, à son sujet, dans un doute troublant.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmcclxiv{Quiconque fait une bonne œuvre, c'est pour son bien. Et quiconque fait le mal, il le fait à ses dépens. Ton Seigneur, cependant, n'est point injuste envers les serviteurs.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmcclxv{A Lui revient la connaissance de l'Heure. Aucun fruit ne sort de son enveloppe, aucune femelle ne conçoit ni ne met bas sans qu'Il n'en ait connaissance. Et le jour où Il les appellera: «Où sont Mes associés?», ils diront: «Nous Te déclarons qu'il n'y a point de témoin parmi nous»!\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmcclxvi{Et ce qu'auparavant ils invoquaient les délaissera; et ils réaliseront qu'ils n'ont point d'échappatoire.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmcclxvii{L'homme ne se lasse pas d'implorer le bien. Si le mal le touche, le voilà désespéré, désemparé.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmcclxviii{Et si nous lui faisons goûter une miséricorde de Notre part, après qu'une détresse l'ait touché, il dit certainement: «Cela m'est dû! Et je ne pense pas que l'Heure se lèvera [un jour]. Et si je suis ramené vers mon Seigneur, je trouverai, près de Lui, la plus belle part». Nous informerons ceux qui ont mécru de ce qu'ils ont fait et Nous leur ferons sûrement goûter à un dur châtiment.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmcclxix{Quand Nous comblons de bienfaits l'homme, il s'esquive et s'éloigne. Et quand un malheur le touche, il se livre alors à une longue prière.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmcclxx{Dis: «Voyez-vous? Si ceci (le Coran) émane d'Allah et qu'ensuite vous le reniez; qui se trouvera plus égaré que celui qui s'éloigne dans la dissidence?»\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxi{Nous leur montrerons Nos signes dans l'univers et en eux-mêmes, jusqu'à ce qu'il leur devienne évident que c'est cela (le Coran), la vérité. Ne suffit-il pas que ton Seigneur soit témoin de toute chose?\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxii{Ils sont dans le doute, n'est-ce pas, au sujet de la rencontre de leur Seigneur? C'est Lui certes qui embrasse toute chose (par Sa science et Sa puissance).\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxiii{\basmalahfr H'â, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxiv{Aîn, Sîn, Qâf.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxv{C'est ainsi qu'Allah, le Puissant, le Sage, te fait des révélations, comme à ceux qui ont vécu avant toi.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxvi{A Lui appartient ce qui est dans les cieux et ce qui est sur la terre. Et Il est le Sublime, le Très Grand,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxvii{Peu s'en faut que les cieux ne se fendent depuis leur faîte quand les anges glorifient leur Seigneur, célèbrent Ses louanges et implorent le pardon pour ceux qui sont sur la terre. Allah est certes le Pardonneur, le Très Miséricordieux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxviii{Et quant à ceux qui prennent des protecteurs en dehors de Lui, Allah veille à ce qu'ils font. Et tu n'es pas pour eux un garant.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxix{Et c'est ainsi que Nous t'avons révélé un Coran arabe, afin que tu avertisses la Mère des cités (la Mecque) et ses alentours et que tu avertisses du Jour du rassemblement, - sur lequel il n'y a pas de doute - Un groupe au Paradis et un groupe dans la fournaise ardente.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxx{Et si Allah avait voulu, Il en aurait fait une seule communauté. Mais Il fait entrer qui Il veut dans Sa miséricorde. Et les injustes n'auront ni maître ni secoureur.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxxi{Ont-ils pris des maîtres en dehors de Lui ? C'est Allah qui est le seul Maître et c'est Lui qui redonne la vie aux morts; et c'est Lui qui est Omnipotent.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxxii{Sur toutes vos divergences, le jugement appartient à Allah. Tel est Allah mon Seigneur; en Lui je place ma confiance et c'est à Lui que je retourne [repentant]\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxxiii{...Créateur des cieux et de la terre. Il vous a donné des épouses [issues] de vous-mêmes et des bestiaux par couples; par ce moyen Il vous multiplie. Il n'y a rien qui Lui ressemble; et c'est Lui l'Audient, le Clairvoyant.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxxiv{Il possède les clefs [des trésors] des cieux et de la terre. Il attribue Ses dons avec largesse, ou les restreint à qui Il veut. Certes, Il est Omniscient.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxxv{Il vous a légiféré en matière de religion, ce qu'Il avait enjoint à Noé, ce que Nous t'avons révélé, ainsi que ce que Nous avons enjoint à Abraham, à Moïse et à Jésus: «Etablissez la religion; et n'en faites pas un sujet de divisions». Ce à quoi tu appelles les associateurs leur paraît énorme Allah élit et rapproche de Lui qui Il veut et guide vers Lui celui qui se repent.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxxvi{Ils ne se sont divisés qu'après avoir reçu la science et ceci par rivalité entre eux. Et si ce n'était une parole préalable de ton Seigneur pour un terme fixé, on aurait certainement tranché entre eux. Ceux à qui le Livre a été donné en héritage après eux sont vraiment à son sujet, dans un doute troublant.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxxvii{Appelle donc (les gens) à cela; reste droit comme il t'a été commandé; ne suis pas leurs passions; et dis: «Je crois en tout ce qu'Allah a fait descendre comme Livre, et il m'a été commandé d'être équitable entre vous. Allah est notre Seigneur et votre Seigneur. A nous nos œuvres et à vous vos œuvres. Aucun argument [ne peut trancher] entre nous et vous. Allah nous regroupera tous. Et vers Lui est la destination».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxxviii{Et ceux qui discutent au sujet d'Allah, après qu'il a été répondu à [Son appel], leur argumentation est auprès d'Allah sans valeur. Une colère tombera sur eux et ils auront un dur châtiment.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmcclxxxix{C'est Allah qui a fait descendre le Livre en toute vérité, ainsi que la balance. Et qu'en sais-tu? Peut-être que l'Heure est proche?\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmccxc{Ceux qui n'y croient pas cherchent à la hâter; tandis que ceux qui croient en sont craintifs et savent qu'elle est la pure vérité. Et ceux qui discutent à propos de l'Heure sont dans un égarement lointain.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmccxci{Allah est doux envers Ses serviteurs. Il attribue [Ses biens] à qui Il veut. Et c'est Lui le Fort, le Puissant.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmccxcii{Quiconque désire labourer [le champ] de la vie future, Nous augmenterons pour lui son labour. Quiconque désire labourer [le champ] de la présente vie, Nous lui en accorderons de [ses jouissances]; mais il n'aura pas de part dans l'au-delà.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmccxciii{Ou bien auraient-ils des associés [à Allah] qui auraient établi pour eux des lois religieuses qu'Allah n'a jamais permises? Or, si l'arrêt décisif n'avait pas été prononcé, il aurait été tranché entre eux. Les injustes auront certes un châtiment douloureux.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmccxciv{Tu verras les injustes épouvantés par ce qu'ils ont fait, et le châtiment s'abattra sur eux (inéluctablement). Et ceux qui croient et accomplissent les bonnes œuvres, seront dans les sites fleuris des jardins, ayant ce qu'ils voudront auprès de leur Seigneur. Telle est la grande grâce!\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmccxcv{Telle est la [bonne nouvelle] qu'Allah annonce à ceux de Ses serviteurs qui croient et accomplissent les bonnes œuvres! Dis: «Je ne vous en demande aucun salaire si ce n'est l'affection eu égard à [nos liens] de parenté». Et quiconque accomplit une bonne action, Nous répondons par [une récompense] plus belle encore. Allah est certes Pardonneur et Reconnaissant.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmccxcvi{Ou bien ils disent il a inventé un mensonge contre Allah. Or, si Allah voulait, Il scellerait ton cœur. Par Ses Paroles cependant, Allah efface le faux et confirme le vrai. Il connaît parfaitement le contenu des poitrines.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmccxcvii{Et c'est lui qui agrée de Ses serviteurs le repentir, pardonne les méfaits et sait ce que vous faites,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmccxcviii{et exauce [les vœux] de ceux qui croient et accomplissent les bonnes œuvres et leur accroît Sa faveur, tandis que les mécréants ont un dur châtiment.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmccxcix{Si Allah attribuait Ses dons avec largesse à [tous] Ses serviteurs, ils commettraient des abus sur la terre; mais, Il fait descendre avec mesure ce qu'Il veut. Il connaît parfaitement Ses serviteurs et en est Clairvoyant.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmccc{Et c'est Lui qui fait descendre la pluie après qu'on en a désespéré, et répand Sa miséricorde. Et c'est Lui le Maître, le Digne de louange.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmccci{Parmi Ses preuves est la création des cieux et de la terre et des êtres vivants qu'Il y a disséminés. Il a en outre le pouvoir de les réunir quand Il voudra.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmcccii{Tout malheur qui vous atteint est dû à ce que vos mains ont acquis. Et Il pardonne beaucoup.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmccciii{Vous ne pouvez pas échapper à la puissance d'Allah sur la terre; et vous n'avez en dehors d'Allah, ni maître ni défenseur.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmccciv{Et parmi Ses preuves, sont les vaisseaux à travers la mer, semblables à des montagnes.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmcccv{S'Il veut, Il calme le vent, et les voilà qui restent immobiles à sa surface. Ce sont certainement là des preuves pour tout [homme] endurant et reconnaissant.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmcccvi{Ou bien, Il les détruit en punition de ce qu'ils ont acquis [comme péchés]. Cependant, Il pardonne beaucoup.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmcccvii{Ceux qui disputent à propos de Nos preuves savent bien qu'ils n'ont pas d'échappatoire.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmcccviii{Tout ce qui vous a été donné [comme bien] n'est que jouissance de la vie présente; mais ce qui est auprès d'Allah est meilleur et plus durable pour ceux qui ont cru et qui placent leur confiance en leur Seigneur,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmcccix{qui évitent [de commettre] les péchés les plus graves ainsi que les turpitudes, et qui pardonnent après s'être mis en colère,\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmcccx{qui répondent à l'appel de leur Seigneur, accomplissent la Salât, se consultent entre eux à propos de leurs affaires, dépensent de ce que Nous leur attribuons,\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmcccxi{et qui, atteints par l'injustice, ripostent.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmcccxii{La sanction d'une mauvaise action est une mauvaise action [une peine] identique. Mais quiconque pardonne et réforme, son salaire incombe à Allah. Il n'aime point les injustes!\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmcccxiii{Quant à ceux qui ripostent après avoir été lésés, ...ceux-là pas de voie (recours légal) contre eux;\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmcccxiv{il n'y a de voie [de recours] que contre ceux qui lèsent les gens et commettent des abus, contrairement au droit, sur la terre: ceux-là auront un châtiment douloureux.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmcccxv{Et celui qui endure et pardonne, cela en vérité, fait partie des bonnes dispositions et de la résolution dans les affaires.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmcccxvi{Et quiconque Allah égare n'a aucun protecteur après Lui. Cependant tu verras les injustes dire, en voyant le châtiment: «Y a-t-il un moyen de retourner [sur terre]?»\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmcccxvii{Et tu les verras exposés devant l'Enfer, confondus dans l'avilissement, et regardant d'un œil furtif, tandis que ceux qui ont cru diront: «Les perdants sont certes, ceux qui au Jour de la Résurrection font leur propre perte et celle de leurs familles». Les injustes subiront certes un châtiment permanent.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmcccxviii{Ils n'auront pas de protecteur en dehors d'Allah pour les secourir et quiconque Allah égare n'a plus aucune voie.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmcccxix{Répondez à l'appel de votre Seigneur avant que ne vienne un jour dont Allah ne reportera jamais le terme. Ce jour-là, nul refuge pour vous et vous ne pourrez point nier (vos péchés).\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmcccxx{S'ils se détournent, ...Nous ne t'avons pas envoyé pour assurer leur sauvegarde: tu n'es chargé que de transmettre [le message]. Et lorsque Nous faisons goûter à l'homme une miséricorde venant de Nous, il en exulte; mais si un malheur les atteint pour ce que leurs mains ont perpétré..., l'homme est alors très ingrat!\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxi{A Allah appartient la royauté des cieux et de la terre. Il crée ce qu'Il veut. Il fait don de filles à qui Il veut, et don de garçons à qui Il veut,\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxii{ou bien Il donne à la fois garçons et filles; et Il rend stérile qui Il veut. Il est certes Omniscient et Omnipotent.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxiii{Il n'a pas été donné à un mortel qu'Allah lui parle autrement que par révélation ou de derrière un voile, ou qu'Il [Lui] envoie un messager (Ange) qui révèle, par Sa permission, ce qu'Il [Allah] veut. Il est Sublime et Sage.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxiv{Et c'est ainsi que Nous t'avons révélé un esprit [le Coran] provenant de Notre ordre. Tu n'avais aucune connaissance du Livre ni de la foi; mais Nous en avons fait une lumière par laquelle Nous guidons qui Nous voulons parmi Nos serviteurs. Et en vérité tu guides vers un chemin droit,\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxv{le chemin d'Allah à Qui appartient ce qui est dans les cieux et ce qui est sur la terre. Oui c'est à Allah que s'acheminent toutes les choses.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxvi{\basmalahfr H'â, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxvii{Par le Livre explicite!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxviii{Nous en avons fait un Coran arabe afin que vous raisonniez.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxix{Il est auprès de Nous, dans l'Ecriture-Mère (l'original au ciel), sublime et rempli de sagesse.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxx{Quoi! Allons-Nous vous dispenser du Rappel [le Coran] pour la raison que vous êtes des gens outranciers?\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxxi{Que de prophètes avons-Nous envoyés aux Anciens!\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxxii{et pas un prophète ne leur venait qu'ils ne le tournaient en dérision.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxxiii{Nous avons fait périr de plus redoutables qu'eux! Et on a déjà cité l'exemple des anciens.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxxiv{Et si tu leur demandes: «Qui a créé les cieux et la terre?» Ils diront très certainement: «Le Puissant, l'Omniscient les a créés».\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxxv{Celui qui vous a donné la terre pour berceau et vous y a tracé des sentiers afin que vous vous guidiez;\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxxvi{Celui qui a fait descendre l'eau du ciel avec mesure et avec laquelle Nous ranimons une cité morte [aride]. Ainsi vous serez ressuscités;\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxxvii{Celui qui a créé les couples dans leur totalité et a fait pour vous, des vaisseaux et des bestiaux, des montures,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxxviii{afin que vous vous installiez sur leurs dos, et qu'ensuite, après vous y être installés, vous vous rappeliez le bienfait de votre Seigneur et que vous disiez: «Gloire à Celui qui nous a soumis tout cela alors que nous n'étions pas capables de les dominer.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmcccxxxix{C'est vers notre Seigneur que nous retournerons».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmcccxl{Et ils Lui firent de Ses serviteurs une partie [de Lui-Même]. L'homme est vraiment un ingrat déclaré!\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmcccxli{Ou bien Se serait-Il attribué des filles parmi ce qu'Il crée et accordé à vous par préférence des fils?\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmcccxlii{Or, quand on annonce à l'un d'eux (la naissance) d'une semblable de ce qu'il attribue au Tout Miséricordieux, son visage s'assombrit d'un chagrin profond.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmcccxliii{Quoi! Cet être (la fille) élevé au milieu des parures et qui, dans la dispute, est incapable de se défendre par une argumentation claire et convaincante?\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmcccxliv{Et ils firent des Anges qui sont les serviteurs du Tout Miséricordieux des [êtres] féminins! Etaient-ils témoins de leur création? Leur témoignage sera alors inscrit; et ils seront interrogés.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmcccxlv{Et ils dirent: «Si le Tout Miséricordieux avait voulu, nous ne les aurions pas adorés». Ils n'en ont aucune connaissance; ils ne font que se livrer à des conjectures.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmcccxlvi{Ou bien, leur avions-Nous donné avant lui [le Coran] un Livre auquel ils seraient fermement attachés?\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmcccxlvii{Mais plutôt ils dirent: «Nous avons trouvé nos ancêtres sur une religion, et nous nous guidons sur leurs traces».\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmcccxlviii{Et c'est ainsi que Nous n'avons pas envoyé avant toi d'avertisseur en une cité, sans que ses gens aisés n'aient dit: «Nous avons trouvé nos ancêtres sur une religion et nous suivons leurs traces».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmcccxlix{Il dit: «Même si je viens à vous avec une meilleure direction que celle sur laquelle vous avez trouvé vos ancêtres?» Ils dirent: «Nous ne croyons pas au message avec lequel vous avez été envoyés».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmcccl{Nous Nous vengeâmes d'eux. Regarde ce qu'il est advenu de ceux qui criaient au mensonge.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmcccli{Et lorsqu'Abraham dit à son père et à son peuple: «Je désavoue totalement ce que vous adorez,\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmccclii{à l'exception de Celui qui m'a créé, car c'est Lui en vérité qui me guidera».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmcccliii{Et il en fit une parole qui devait se perpétuer parmi sa descendance. Peut-être reviendront-ils?\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmcccliv{Mais à ces gens ainsi qu'à leurs ancêtres J'ai accordé la jouissance jusqu'à ce que leur vinrent la Vérité (le Coran) et un Messager explicite.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmccclv{Et quand la Vérité leur vint, ils dirent: «C'est de la magie et nous n'y croyons pas».\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmccclvi{Et ils dirent: «Pourquoi n'a-t-on pas fait descendre ce Coran sur un haut personnage de l'une des deux cités?» (la Mecque et Tâ'îf).\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmccclvii{Est-ce eux qui distribuent la miséricorde de ton Seigneur? C'est Nous qui avons réparti entre eux leur subsistance dans la vie présente et qui les avons élevés en grades les uns sur les autres, afin que les uns prennent les autres à leur service. La miséricorde de ton Seigneur vaut mieux, cependant, que ce qu'ils amassent.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmccclviii{Si les hommes ne devaient pas constituer une seule communauté (mécréante), Nous aurions certes pourvu les maisons de ceux qui ne croient pas au Tout Miséricordieux, de toits d'argent avec des escaliers pour y monter;\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmccclix{(Nous aurions pourvu) leurs maisons de portes et de divans où ils s'accouderaient,\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmccclx{ainsi que des ornements. Et tout cela ne serait que jouissance temporaire de la vie d'ici-bas, alors que l'au-delà, auprès de ton Seigneur, est pour les pieux.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmccclxi{Et quiconque s'aveugle (et s'écarte) du rappel du Tout Miséricordieux, Nous lui désignons un diable qui devient son compagnon inséparable.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmccclxii{Ils [Les diables] détournent certes [les hommes] du droit chemin, tandis que ceux-ci s'estiment être bien guidés.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmccclxiii{Lorsque cet [homme] vient à Nous, il dira [à son démon]: «Hélas! Que n'y a-t-il entre toi et moi la distance entre les deux orients [l'Est et l'Ouest]» - Quel mauvais compagnon [que tu es]!\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmccclxiv{Il ne vous profitera point ce jour-là - du moment que vous avez été injustes - que vous soyez associés dans le châtiment.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmccclxv{Est-ce donc toi qui fait entendre les sourds ou qui guide les aveugles et ceux qui sont dans un égarement évident?\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmccclxvi{Soit que Nous t'enlevons [te ferons mourir] et alors Nous Nous vengerons d'eux;\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmccclxvii{ou bien que Nous te ferons voir ce que Nous leur avons promis [le châtiment]; car Nous avons sur eux un pouvoir certain.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmccclxviii{Tiens fermement à ce qui t'a été révélé car tu es sur le droit chemin.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmccclxix{C'est certainement un rappel [le Coran] pour toi et ton peuple. Et vous en serez interrogés.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmccclxx{Et demande à ceux de Nos messagers que Nous avons envoyés avant toi, si Nous avons institué, en dehors du Tout Miséricordieux, des divinités à adorer?\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxi{Nous avons effectivement envoyé Moïse avec Nos miracles, à Pharaon et à ses notables. Il dit: «Je suis le Messager du Seigneur de l'univers».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxii{Puis, lorsqu'il vint à eux avec Nos miracles, voilà qu'ils en rirent.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxiii{Chaque miracle que Nous leur montrions était plus probant que son précédent. Et Nous les saisîmes par le châtiment, peut-être reviendront-ils [vers Nous].\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxiv{Et ils dirent: «O magicien! Implore pour nous ton Seigneur au nom de l'engagement qu'Il a pris envers toi. Nous suivrons le droit chemin».\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxv{Puis quand Nous eûmes écarté d'eux le châtiment, voilà qu'ils violèrent leurs engagements.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxvi{Et Pharaon fit une proclamation à son peuple et dit: «O mon peuple! Le royaume de Misr [l'Egypte] ne m'appartient-il pas ainsi que ces canaux qui coulent à mes pieds? N'observez-vous donc pas?\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxvii{Ne suis-je pas meilleur que ce misérable qui sait à peine s'exprimer?\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxviii{Pourquoi ne lui a-t-on pas lancé des bracelets d'or? Pourquoi les Anges ne l'ont-ils pas accompagné?»\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxix{Ainsi chercha-t-il à étourdir son peuple et ainsi lui obéirent-ils car ils étaient des gens pervers.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxx{Puis lorsqu'ils Nous eurent irrité, Nous Nous vengeâmes d'eux et les noyâmes tous.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxxi{Nous fîmes d'eux un antécédant et un exemple [une leçon] pour la postérité.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxxii{Quand on cite l'exemple du fils de Marie, ton peuple s'en détourne,\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxxiii{en disant: «Nos dieux sont-ils meilleurs, ou bien lui?» Ce n'est que par polémique qu'ils te le citent comme exemple. Ce sont plutôt des gens chicaniers.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxxiv{Il (Jésus) n'était qu'un Serviteur que Nous avions comblé de bienfaits et que Nous avions désigné en exemple aux Enfants d'Israël.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxxv{Si Nous voulions, Nous ferions de vous des Anges qui vous succéderaient sur la terre.\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxxvi{Il sera un signe au sujet de l'Heure. N'en doutez point. Et suivez-moi: voilà un droit chemin.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxxvii{Que le Diable ne vous détourne point! Car il est pour vous un ennemi déclaré.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxxviii{Et quand Jésus apporta les preuves, il dit: «Je suis venu à vous avec la sagesse et pour vous expliquer certains de vos sujets de désaccord. Craignez Allah donc et obéissez-moi.\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmmccclxxxix{Allah est en vérité mon Seigneur et votre Seigneur. Adorez-Le donc. Voilà un droit chemin».\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmmcccxc{Mais les factions divergèrent entre elles. Malheur donc aux injustes du châtiment d'un jour douloureux!\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmmcccxci{Attendent-ils seulement que l'Heure leur vienne à l'improviste, sans qu'ils ne s'en rendent compte?\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmmcccxcii{Les amis, ce jour-là, seront ennemis les uns des autres; excepté les pieux.\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmmcccxciii{«O Mes serviteurs! Vous ne devez avoir aucune crainte aujourd'hui; vous ne serez point affligés,\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmmcccxciv{Ceux qui croient en Nos signes et sont musulmans,\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmmcccxcv{«Entrez au Paradis, vous et vos épouses, vous y serez fêtés».\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmmcccxcvi{On fera circuler parmi eux des plats d'or et des coupes; et il y aura là [pour eux] tout ce que les âmes désirent et ce qui réjouit les yeux;» - et vous y demeurerez éternellement.\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmmcccxcvii{Tel est le Paradis qu'on vous fait hériter pour ce que vous faisiez.\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmmcccxcviii{Il y aura là pour vous beaucoup de fruits dont vous mangerez».\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmmcccxcix{Quant aux criminels, ils demeureront éternellement dans le châtiment de l'Enfer,\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmmcd{qui ne sera jamais interrompu pour eux et où ils seront en désespoir.\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmmcdi{Nous ne leur avons fait aucun tort, mais c'étaient eux les injustes.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmmcdii{et ils crieront: «O Mâlik! Que ton Seigneur nous achève!» Il dira: «En vérité, vous êtes pour y demeurer [éternellement]»!\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmmcdiii{«Certes, Nous vous avions apporté la Vérité; mais la plupart d'entre vous détestaient la Vérité».\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmmcdiv{Ont-ils pris quelque décision [entre eux]? Car c'est Nous qui décidons!\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmmmcdv{Ou bien escomptent-ils que Nous n'entendons pas leur secret ni leurs délibérations? Mais si! Nos Anges prennent note auprès d'eux.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmmmcdvi{Dis: «Si le Tout Miséricordieux avait un enfant, alors je serais le premier à l'adorer».\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmmmcdvii{Gloire au Seigneur des cieux et de la terre, Seigneur du Trône; Il transcende ce qu'ils décrivent.\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmmmcdviii{Laisse-les donc s'enfoncer dans leur fausseté et s'amuser jusqu'à ce qu'ils rencontrent le jour qui leur est promis.\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmmmcdix{C'est Lui qui est Dieu dans le ciel et Dieu sur terre; et c'est Lui le Sage, l'Omniscient!\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmmmcdx{Et béni soit Celui à qui appartient la souveraineté des cieux et de la terre et de ce qui est entre eux. Il détient la science de l'Heure. Et c'est vers Lui que vous serez ramenés.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmmmcdxi{Et ceux qu'ils invoquent en dehors de Lui n'ont aucun pouvoir d'intercession, à l'exception de ceux qui auront témoigné de la vérité en pleine connaissance de cause.\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmmmcdxii{Et si tu leur demandes qui les a créés, ils diront très certainement: «Allah». Comment se fait-il donc qu'ils se détournent?\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmmmcdxiii{Et sa parole (la parole du Prophète à Allah): «Seigneur, ce sont là des gens qui ne croient pas».\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmmmcdxiv{Et bien, éloigne-toi d'eux (pardonne-leur); et dis: «Salut!» Car ils sauront bientôt.\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmmmcdxv{\basmalahfr H'â, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmcdxvi{Par le Livre (le Coran) explicite.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmcdxvii{Nous l'avons fait descendre en une nuit bénie, Nous sommes en vérité Celui qui avertit,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmcdxviii{durant laquelle est décidé tout ordre sage,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmcdxix{c'est là un commandement venant de Nous. C'est Nous qui envoyons [les Messagers],\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmcdxx{à titre de miséricorde de la part de ton Seigneur, car c'est Lui l'Audient, l'Omniscient,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxi{Seigneur des cieux et de la terre et de ce qui est entre eux, si seulement vous pouviez en avoir la conviction.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxii{Point de divinité à part Lui. Il donne la vie et donne la mort, et Il est votre Seigneur et le Seigneur de vos premiers ancêtres.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxiii{Mais ces gens-là, dans le doute, s'amusent.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxiv{Eh bien, attends le jour où le ciel apportera une fumée visible\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxv{qui couvrira les gens. Ce sera un châtiment douloureux.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxvi{«Seigneur, éloigne de nous le châtiment. Car, [à présent] nous croyons».\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxvii{D'où leur vient cette prise de conscience alors qu'un Messager explicite leur est déjà venu,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxviii{Puis ils s'en détournèrent en disant: «C'est un homme instruit [par d'autres], un possédé».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxix{Nous dissiperons le châtiment pour peu de temps; car vous récidiverez.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxx{Le jour où Nous userons de la plus grande violence et Nous Nous vengerons.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxxi{Et avant eux Nous avons déjà éprouvé le peuple de Pharaon, quand un noble Messager leur était venu,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxxii{[leur disant]: «Livrez-moi les serviteurs d'Allah! Je suis pour vous un Messager digne de confiance.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxxiii{Ne vous montrez pas hautains vis-à-vis d'Allah, car je vous apporte une preuve évidente.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxxiv{Et je cherche protection auprès de mon Seigneur et votre Seigneur, pour que vous ne me lapidiez pas.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxxv{Si vous ne voulez pas croire en moi, éloignez-vous de moi».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxxvi{Il invoqua alors son Seigneur: «Ce sont des gens criminels».\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxxvii{«Voyage de nuit avec Mes serviteurs; vous serez poursuivis.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxxviii{Laisse la mer calme; [telle que tu l'as franchie] ce sont, des armées [vouées] à la noyade».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmcdxxxix{Que de jardins et de sources ils laissèrent [derrière eux]\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmcdxl{que de champs et de superbes résidences,\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmcdxli{que de délices au sein desquels ils se réjouissaient.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmcdxlii{Il en fut ainsi et Nous fîmes qu'un autre peuple en hérita.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmcdxliii{Ni le ciel ni la terre ne les pleurèrent et ils n'eurent aucun délai.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmcdxliv{Et certes, Nous sauvâmes les Enfants d'Israël du châtiment avilissant\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmcdxlv{de Pharaon qui était hautain et outrancier.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmcdxlvi{A bon escient Nous les choisîmes parmi tous les peuples de l'univers,\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmcdxlvii{et leur apportâmes des miracles de quoi les mettre manifestement à l'épreuve.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmcdxlviii{Ceux-là (les Mecquois) disent:\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmcdxlix{«Il n'y a pour nous qu'une mort, la première. Et nous ne serons pas ressuscités.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmcdl{Faites donc revenir nos ancêtres, si vous êtes véridiques».\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmcdli{Sont-ils les meilleurs ou le peuple de Tubba' et ceux qui les ont précédés? Nous les avons fait périr parce que vraiment ils étaient criminels.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmcdlii{Ce n'est pas par divertissement que Nous avons créé les cieux et la terre et ce qui est entre eux.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmcdliii{Nous ne les avons créés qu'en toute vérité. Mais la plupart d'entre eux ne savent pas.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmcdliv{En vérité, le Jour de la Décision sera leur rendez-vous à tous,\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmcdlv{le jour où un allié ne sera d'aucune utilité à un [autre] allié; et ils ne seront point secourus non plus,\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmcdlvi{sauf celui à qui Allah fera miséricorde. Car c'est Lui, le Puissant, le Très Miséricordieux.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmcdlvii{Certes l'arbre de Zakkûm\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmcdlviii{sera la nourriture du grand pécheur.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmcdlix{Comme du métal en fusion; il bouillonnera dans les ventres\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmcdlx{comme le bouillonnement de l'eau surchauffée.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxi{Qu'on le saisisse et qu'on l'emporte en plein dans la fournaise;\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxii{qu'on verse ensuite sur sa tête de l'eau bouillante comme châtiment.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxiii{Goûte! Toi [qui prétendait être] le puissant, le noble.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxiv{Voilà ce dont vous doutiez.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxv{Les pieux seront dans une demeure sûre,\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxvi{parmi des jardins et des sources,\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxvii{Ils porteront des vêtements de satin et de brocart et seront placés face à face.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxviii{C'est ainsi! Et Nous leur donnerons pour épouses des houris aux grands yeux.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxix{Ils y demanderont en toute quiétude toutes sortes de fruits.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxx{Ils n'y goûteront pas à la mort sauf leur mort première. Et [Allah] les protègera du châtiment de la Fournaise,\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxi{c'est là une grâce de ton Seigneur. Et c'est là l'énorme succès.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxii{Nous ne l'avons facilité dans ta langue, qu'afin qu'ils se rappellent!\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxiii{Attends donc. Eux aussi attendent.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxiv{\basmalahfr H'â, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxv{La révélation du Livre émane d'Allah, le Puissant, le Sage.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxvi{Il y a certes dans les cieux et la terre des preuves pour les croyants.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxvii{Et dans votre propre création, et dans ce qu'Il dissémine comme animaux, il y a des signes pour des gens qui croient avec certitude.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxviii{De même dans l'alternance de la nuit et du jour, et dans ce qu'Allah fait descendre du ciel comme subsistance [pluie] par laquelle Il redonne la vie à la terre une fois morte, et dans la distribution des vents, il y a des signes pour des gens qui raisonnent.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxix{Voilà les versets d'Allah que Nous te récitons en toute vérité. Alors dans quelle parole croiront-ils après [la parole] d'Allah et après Ses signes?\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxx{Malheur à tout grand imposteur pécheur!\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxxi{Il entend les versets d'Allah qu'on lui récite puis persiste dans son orgueil, comme s'il ne les avait jamais entendus. Annonce-lui donc un châtiment douloureux.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxxii{S'il a connaissance de quelques-uns de Nos versets, il les tourne en dérision. Ceux-là auront un châtiment avilissant:\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxxiii{l'Enfer est à leurs trousses. Ce qu'ils auront acquis ne leur servira à rien, ni ce qu'ils auront pris comme protecteurs, en dehors d'Allah. Ils auront un énorme châtiment.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxxiv{Ceci [le Coran] est un guide. Et ceux qui récusent les versets de leur Seigneur auront le supplice d'un châtiment douloureux.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxxv{Allah c'est Lui qui vous a assujetti la mer, afin que les vaisseaux y voguent, par Son ordre, et que vous alliez en quête de sa grâce afin que vous soyez reconnaissants.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxxvi{Et Il vous a assujetti tout ce qui est dans les cieux et sur la terre, le tout venant de Lui. Il y a là des signes pour des gens qui réfléchissent.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxxvii{Dis à ceux qui ont cru de pardonner à ceux qui n'espèrent pas les jours d'Allah afin qu'Il rétribue [chaque] peuple pour les acquis qu'ils faisaient.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxxviii{Quiconque fait le bien, le fait pour lui-même; et quiconque agit mal, agit contre lui-même. Puis vous serez ramenés vers votre Seigneur,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmcdlxxxix{Nous avons effectivement apporté aux Enfants d'Israël le Livre, la sagesse, la prophétie, et leur avons attribué de bonnes choses, et les préférâmes aux autres humains [leurs contemporains];\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmcdxc{Et Nous leur avons apporté des preuves évidentes de l'Ordre. Ils ne divergèrent qu'après que la science leur fut venue par agressivité entre eux. Ton Seigneur décidera parmi eux, au Jour de la Résurrection, sur ce en quoi ils divergeaient.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmcdxci{Puis Nous t'avons mis sur la voie de l'Ordre [une religion claire et parfaite]. Suis-la donc et ne suis pas les passions de ceux qui ne savent pas.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmcdxcii{Ils ne te seront d'aucune utilité vis-à-vis d'Allah. Les injustes sont vraiment alliés les uns des autres; tandis qu'Allah est le Protecteur des pieux.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmcdxciii{Ceci [le Coran] constitue pour les hommes une source de clarté, un guide et une miséricorde pour des gens qui croient avec certitude.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmcdxciv{Ceux qui commettent des mauvaises actions comptent-ils que Nous allons les traiter comme ceux qui croient et accomplissent les bonnes œuvres, dans leur vie et dans leur mort? Comme ils jugent mal!\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmcdxcv{Et Allah a créé les cieux et la terre en toute vérité et afin que chaque âme soit rétribuée selon ce qu'elle a acquis. Ils ne seront cependant pas lésés.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmcdxcvi{Vois-tu celui qui prend sa passion pour sa propre divinité? Et Allah l'égare sciemment et scelle son ouïe et son cœur et étend un voile sur sa vue. Qui donc peut le guider après Allah? Ne vous rappelez-vous donc pas?\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmcdxcvii{Et ils dirent: «Il n'y a pour nous que la vie d'ici-bas: nous mourons et nous vivons et seul le temps nous fait périr». Ils n'ont de cela aucune connaissance: ils ne font qu'émettre des conjectures.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmcdxcviii{Et quand on leur récite Nos versets bien clairs, leur seul argument est de dire: «Faites revenir nos ancêtres si vous êtes véridiques».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmcdxcix{Dis: «Allah vous donne la vie puis Il vous donne la mort. Ensuite Il vous réunira le Jour de la Résurrection, il n'y a pas de doute à ce sujet, mais la plupart des gens ne savent pas.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmd{A Allah appartient le royaume des cieux et de la terre. Et le jour où l'Heure arrivera, ce jour-là, les imposteurs seront perdus.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmdi{Et tu verras chaque communauté agenouillée. Chaque communauté sera appelée vers son livre. On vous rétribuera aujourd'hui selon ce que vous œuvriez.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmdii{Voilà Notre Livre. Il parle de vous en toute vérité car Nous enregistrions [tout] ce que vous faisiez».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmdiii{Ceux qui ont cru et fait de bonnes œuvres, leur Seigneur les fera entrer dans Sa miséricorde. Voilà le succès évident.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmdiv{Et quant à ceux qui ont mécru [il sera dit]: «Mes versets ne vous étaient-ils pas récités? Mais vous vous enfliez d'orgueil et vous étiez des gens criminels».\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmdv{Et quand on disait: «La promesse d'Allah est vérité; et l'Heure n'est pas l'objet d'un doute», vous disiez: «Nous ne savons pas ce que c'est que l'Heure; et nous ne faisions à son sujet que de simples conjectures et nous ne sommes pas convaincus [qu'elle arrivera].\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmdvi{Et leur apparaîtra [la laideur] de leurs mauvaises actions. Et ce dont ils se moquaient les cernera.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmdvii{Et on leur dira: «Aujourd'hui Nous vous oublions comme vous avez oublié la rencontre de votre jour que voici. Votre refuge est le Feu; et vous n'aurez point de secoureurs.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmdviii{Cela parce que vous preniez en raillerie les versets d'Allah et que la vie d'ici-bas vous trompait». Ce jour-là on ne les en fera pas sortir et on ne les excusera pas non plus.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmdix{Louange à Allah, Seigneur des cieux et Seigneur de la terre: Seigneur de l'univers.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmdx{Et à Lui la grandeur dans les cieux et la terre. Et c'est Lui le Puissant, le Sage.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmdxi{\basmalahfr H'â, Mîm.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmdxii{La révélation du Livre émane d'Allah, le Puissant, le Sage.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmdxiii{Nous n'avons créé les cieux et la terre et ce qui est entre eux qu'en toute vérité et [pour] un terme fixé. Ceux qui ont mécru se détournent de ce dont ils ont été avertis.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmdxiv{Dis: «Que pensez-vous de ceux que vous invoquez en dehors d'Allah? Montrez-moi donc ce qu'ils ont créé de la terre! Ou ont-ils dans les cieux une participation avec Dieu? Apportez-moi un Livre antérieur à celui-ci (le Coran) ou même un vestige d'une science, si vous êtes véridiques».\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmdxv{Et qui est plus égaré que celui qui invoque en dehors d'Allah, et que la vie ne saura lui répondre jusqu'au Jour de la Résurrection? Et elles [leurs divinités] sont indifférentes à leur invocation.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmdxvi{Et quand les gens seront rassemblés [pour le Jugement] elles seront leurs ennemies et nieront leur adoration [pour elles].\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmdxvii{Et quand on leur récite Nos versets bien clairs, ceux qui ont mécru disent à propos de la vérité, une fois venue à eux: «C'est de la magie manifeste».\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmdxviii{Ou bien ils disent: «Il l'a inventé!» Dis: «Si je l'ai inventé alors vous ne pourrez rien pour moi contre [la punition] d'Allah. Il sait parfaitement ce que vous propagez (en calomnies contre le Coran): Allah est suffisant comme témoin entre moi et vous. Et c'est Lui le Pardonneur, le Très Miséricordieux».\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmdxix{Dis: «Je ne suis pas une innovation parmi les messagers; et je ne sais pas ce que l'on fera de moi, ni de vous. Je ne fais que suivre ce qui m'est révélé; et je ne suis qu'un avertisseur clair».\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmdxx{Dis: «Que direz-vous si [cette révélation s'avère] venir d'Allah et que vous n'y croyez pas qu'un témoin parmi les fils d'Israël en atteste la conformité [au Pentateuque] et y croit pendant que vous, vous le repoussez avec orgueil... En vérité Allah ne guide pas les gens injustes!»\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmdxxi{Et ceux qui ont mécru dirent à ceux qui ont cru: «Si ceci était un bien, ils (les pauvres) ne nous y auraient pas devancés». Et comme ils ne se seront pas laissés guider par lui ils diront: «Ce n'est qu'un vieux mensonge!»\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmdxxii{Et avant lui, il y avait le Livre de Moïse, comme guide et comme miséricorde. Et ceci est [un Livre] confirmateur, en langue arabe, pour avertir ceux qui font du tort et pour faire la bonne annonce aux bienfaisants\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmdxxiii{Ceux qui disent: «Notre Seigneur est Allah» et qui ensuite se tiennent sur le droit chemin. Ils ne doivent avoir aucune crainte et ne seront point affligés.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmdxxiv{Ceux-là sont les gens du Paradis où ils demeureront éternellement, en récompense de ce qu'ils faisaient.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmdxxv{Et Nous avons enjoint à l'homme de la bonté envers ses père et mère: sa mère l'a péniblement porté et en a péniblement accouché; et sa gestation et sevrage durent trente mois; puis quand il atteint ses pleines forces et atteint quarante ans, il dit: «O Seigneur! Inspire-moi pour que je rende grâce au bienfait dont Tu m'as comblé ainsi qu'à mes père et mère, et pour que je fasse une bonne œuvre que Tu agrées. Et fais que ma postérité soit de moralité saine. Je me repens à Toi et je suis du nombre des Soumis».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmdxxvi{Ce sont ceux-là dont Nous acceptons le meilleur de ce qu'ils œuvrent et passons sur leurs méfaits, (ils seront) parmi les gens du Paradis, selon la promesse véridique qui leur était faite.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmdxxvii{Quant à celui qui dit à ses père et mère: «Fi de vous deux! Me promettez-vous qu'on me fera sortir de terre alors que des générations avant moi ont passé?» Et les deux, implorant le secours d'Allah, [lui dirent]: «Malheur à toi! Crois. Car la promesse d'Allah est véridique». Mais il (répond): «Ce ne sont que des contes d'Anciens».\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmdxxviii{Ce sont ceux-là qui ont mérité la sentence [prescrite] en même temps que des communautés déjà passées avant eux parmi les djinns et les hommes. Ils étaient réellement perdants.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmdxxix{Et il y a des rangs [de mérite] pour chacun, selon ce qu'ils ont fait afin qu'Allah leur attribue la pleine récompense de leurs œuvres; et ils ne seront point lésés.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmdxxx{Et le jour où ceux qui ont mécru seront présentés au Feu (il leur sera dit): «Vous avez dissipé vos [biens] excellents et vous en avez joui pleinement durant votre vie sur terre: on vous rétribue donc aujourd'hui du châtiment avilissant, pour l'orgueil dont vous vous enfliez injustement sur terre, et pour votre perversité.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmdxxxi{Et rappelle-toi le frère des 'Aad (Hûd) quand il avertit son peuple à Al-Ahqâf - alors qu'avant et après lui, des avertisseurs sont passés - [en disant]: «N'adorez qu'Allah. Je crains pour vous le châtiment d'un jour terrible».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmdxxxii{Ils dirent: «Es-tu venu à nous pour nous détourner de nos divinités? Eh bien, apporte-nous ce que tu nous promets si tu es du nombre des véridiques».\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmdxxxiii{Il dit: «La science n'est qu'auprès d'Allah. Je vous transmets cependant le message avec lequel j'ai été envoyé. Mais je vois que vous êtes des gens ignorants».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmdxxxiv{Puis, voyant un nuage se dirigeant vers leurs vallées ils dirent; «Voici un nuage qui nous apporte de la pluie». Au contraire! c'est cela même que vous cherchiez à hâter: C'est un vent qui contient un châtiment douloureux,\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmdxxxv{détruisant tout, par le commandement de son Seigneur. Puis le lendemain on ne voyait plus que leurs demeures. Ainsi rétribuons-Nous les gens criminels.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmdxxxvi{En effet, Nous les avions consolidés dans des positions que Nous ne vous avons pas données. Et Nous leur avions assigné une ouïe, des yeux et des cœurs, mais ni leur ouïe, ni leurs yeux, ni leurs cœurs ne leur ont profité en quoi que ce soit, parce qu'ils niaient les signes d'Allah. Et ce dont ils se moquaient les cerna.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmdxxxvii{Nous avons assurément fait périr les cités autour de vous; et Nous avons diversifié les signes afin qu'ils reviennent (de leur mécréance).\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmdxxxviii{Pourquoi donc ne les secourent pas, ceux qu'ils avaient pris, en dehors d'Allah, comme divinités pour [soi-disant] les rapprocher de Lui? Ceux-ci, au contraire, les abandonnèrent; telle est leur imposture et voilà ce qu'ils inventaient comme mensonges.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmdxxxix{(Rappelle-toi) lorsque Nous dirigeâmes vers toi une troupe de djinns pour qu'ils écoutent le Coran. Quand ils assistèrent [à sa lecture] ils dirent: «Ecoutez attentivement»... Puis, quand ce fut terminé, ils retournèrent à leur peuple en avertisseurs\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmdxl{Ils dirent: «O notre peuple! Nous venons d'entendre un Livre qui a été descendu après Moïse, confirmant ce qui l'a précédé. Il guide vers la vérité et vers un chemin droit.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmdxli{O notre peuple! Répondez au prédicateur d'Allah et croyez en lui. Il [Allah] vous pardonnera une partie de vos péchés et vous protègera contre un châtiment douloureux.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmdxlii{Et quiconque ne répond pas au prédicateur d'Allah ne saura échapper au pouvoir [d'Allah] sur terre. Et il n'aura pas de protecteurs en dehors de Lui. Ceux-là sont dans un égarement évident.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmdxliii{Ne voient-ils pas qu'Allah qui a créé les cieux et la terre, et qui n'a pas été fatigué par leur création, est capable en vérité de redonner la vie aux morts? Mais si. Il est certes Omnipotent.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmdxliv{Et le jour où seront présentés au Feu ceux qui ont mécru (on leur dira): «Ceci n'est-il pas la vérité?» Ils diront: «Mais si, par notre Seigneur». Il dira: «Eh bien, goûtez le châtiment pour votre mécréance».\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmdxlv{Endure (Muhammad) donc, comme ont enduré les messagers doués de fermeté; et ne te montre pas trop pressé de les voir subir [leur châtiment]. Le jour où ils verront ce qui leur est promis, il leur semblera qu'ils n'étaient restés [sur terre] qu'une heure d'un jour. Voilà une communication. Qui sera donc anéanti sinon les gens pervers?\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmdxlvi{\basmalahfr Ceux qui ont mécru et obstrué le chemin d'Allah, Il a rendu leurs œuvres vaines.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmdxlvii{Et ceux qui ont cru et accompli de bonnes œuvres et ont cru en ce qui a été descendu sur Muhammad - et c'est la vérité venant de leur Seigneur - Il leur efface leurs méfaits et améliore leur condition.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmdxlviii{Il en est ainsi parce que ceux qui ont mécru ont suivi le Faux et que ceux qui ont cru ont suivi la Vérité émanant de leur Seigneur. C'est ainsi qu'Allah propose leurs exemples aux gens.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmdxlix{Lorsque vous rencontrez (au combat) ceux qui ont mécru frappez-en les cous. Puis, quand vous les avez dominés, enchaînez-les solidement. Ensuite, c'est soit la libération gratuite, soit la rançon, jusqu'à ce que la guerre dépose ses fardeaux. Il en est ainsi, car si Allah voulait, Il se vengerait Lui-même contre eux, mais c'est pour vous éprouver les uns par les autres. Et ceux qui seront tués dans le chemin d'Allah, Il ne rendra jamais vaines leurs actions.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmdl{Il les guidera et améliorera leur condition.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmdli{et les fera entrer au Paradis qu'Il leur aura fait connaître.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmdlii{O vous qui croyez! si vous faites triompher (la cause d') Allah, Il vous fera triompher et raffermira vos pas.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmdliii{Et quant à ceux qui ont mécru, il y aura un malheur pour eux, et Il rendra leurs œuvres vaines.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmdliv{C'est parce qu'ils ont de la répulsion pour ce qu'Allah a fait descendre. Il a rendu donc vaines leurs œuvres.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmdlv{N'ont-il pas parcouru la terre pour voir ce qu'il est advenu de leurs prédécesseurs? Allah les a détruits. Pareilles fins sont réservées aux mécréants.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmdlvi{C'est qu'Allah est vraiment le Protecteur de ceux qui ont cru; tandis que les mécréants n'ont pas de protecteur.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmdlvii{Ceux qui croient et accomplissent de bonnes œuvres Allah les fera entrer dans des Jardins sous lesquels coulent les ruisseaux. Et ceux qui mécroient jouissent et mangent comme mangent les bestiaux; et le Feu sera leur lieu de séjour.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmdlviii{Et que de cités, bien plus fortes que ta cité qui t'a expulsé, avons-Nous fait périr, et ils n'eurent point de secoureur.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmdlix{Est-ce que celui qui se base sur une preuve claire venant de son Seigneur est comparable à ceux dont on a embelli les mauvaises actions et qui ont suivi leurs propres passions.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmdlx{Voici la description du Paradis qui a été promis aux pieux: il y aura là des ruisseaux d'une eau jamais malodorante, et des ruisseaux d'un lait au goût inaltérable, et des ruisseaux d'un vin délicieux à boire, ainsi que des ruisseaux d'un miel purifié. Et il y a là, pour eux, des fruits de toutes sortes, ainsi qu'un pardon de la part de leur Seigneur. [Ceux-là] seront-ils pareils à ceux qui s'éternisent dans le Feu et qui sont abreuvés d'une eau bouillante qui leur déchire les entrailles?\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmdlxi{Et il en est parmi eux qui t'écoutent. Une fois sortis de chez toi ils disent à ceux qui ont reçu la science: «Qu'a-t-il dit tout à l'heure?» Ce sont ceux-là dont Allah a scellé les cœurs et qui suivent leurs propres passions.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmdlxii{Quant à ceux qui se mirent sur la bonne voie, Il les guida encore plus et leur inspira leur piété.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmdlxiii{Qu'est-ce qu'ils attendent sinon que l'Heure leur vienne à l'improviste? Or ses signes avant-coureurs sont certes déjà venus. Et comment pourront-ils se rappeler quand elle leur viendra (à l'improviste)?\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmdlxiv{Sache donc qu'en vérité il n'y a point de divinité à part Allah et implore le pardon pour ton péché, ainsi que pour les croyants et les croyantes. Allah connaît vos activités (sur terre) et votre lieu de repos (dans l'au-delà).\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmdlxv{Ceux qui ont cru disent: «Ah! Si une Sourate descendait!» Puis, quand on fait descendre une Sourate explicite et qu'on y mentionne le combat, tu vois ceux qui ont une maladie au cœur te regarder du regard de celui qui s'évanouit devant la mort. Seraient bien préférables pour eux.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmdlxvi{une obéissance et une parole convenable. Puis, quand l'affaire est décidée, il serait mieux pour eux certes, de se montrer sincères vis-à-vis d'Allah.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmdlxvii{Si vous vous détournez, ne risquez-vous pas de semer la corruption sur terre et de rompre vos liens de parenté?\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmdlxviii{Ce sont ceux-là qu'Allah a maudits, a rendus sourds et a rendu leurs yeux aveugles.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmdlxix{Ne méditent-ils pas sur le Coran? Ou y a-t-il des cadenas sur leurs cœurs?\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmdlxx{Ceux qui sont revenus sur leurs pas après que le droit chemin leur a été clairement exposé, le Diable les a séduits et trompés.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxi{C'est parce qu'ils ont dit à ceux qui ont de la répulsion pour la révélation d'Allah: «Nous allons vous obéir dans certaines choses». Allah cependant connaît ce qu'ils cachent.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxii{Qu'adviendra-t-il d'eux quand les Anges les achèveront, frappant leurs faces et leurs dos?\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxiii{Cela parce qu'ils ont suivi ce qui courrouce Allah, et qu'ils ont de la répulsion pour [ce qui attire] Son agrément. Il a donc rendu vaines leurs œuvres.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxiv{Ou bien est-ce que ceux qui ont une maladie au cœur escomptent qu'Allah ne saura jamais faire apparaître leur haine?\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxv{Or, si Nous voulions Nous te les montrerions. Tu les reconnaîtrais certes à leurs traits; et tu les reconnaîtrais très certainement au ton de leur parler. Et Allah connaît bien vos actions.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxvi{Nous vous éprouverons certes afin de distinguer ceux d'entre vous qui luttent [pour la cause d'Allah] et qui endurent, et afin d'éprouver [faire apparaître] vos nouvelles.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxvii{Ceux qui ont mécru et obstrué le chemin d'Allah et se sont mis dans le clan opposé au Messager après que le droit chemin leur fut clairement exposé, ne sauront nuire à Allah en quoi que ce soit. Il rendra vaines leurs œuvres.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxviii{O vous qui avez cru ! Obéissez à Allah, obéissez au Messager, et ne rendez pas vaines vos œuvres.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxix{Ceux qui ont mécru et obstrué le chemin d'Allah puis sont morts tout en étant mécréants, Allah ne leur pardonnera jamais.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxx{Ne faiblissez donc pas et n'appelez pas à la paix alors que vous êtes les plus hauts, qu'Allah est avec vous, et qu'Il ne vous frustrera jamais [du mérite] de vos œuvres.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxxi{La vie présente n'est que jeu et amusement; alors que si vous croyez et craignez, [Allah], Il vous accordera vos récompenses et ne vous demandera pas vos biens.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxxii{S'Il vous les demandait importunément, vous deviendriez avares et Il ferait apparaître vos haines.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxxiii{Vous voilà appelés à faire des dépenses dans le chemin d'Allah. Certains parmi vous se montrent avares. Quiconque cependant est avare, l'est à son détriment. Allah est le Suffisant à Soi-même alors que vous êtes les besogneux. Et si vous vous détournez, Il vous remplacera par un peuple autre que vous, et ils ne seront pas comme vous.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxxiv{\basmalahfr En vérité Nous t'avons accordé une victoire éclatante,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxxv{afin qu'Allah te pardonne tes péchés, passés et futurs, qu'Il parachève sur toi Son bienfait et te guide sur une voie droite;\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxxvi{et qu'Allah te donne un puissant secours.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxxvii{C'est Lui qui a fait descendre la quiétude dans les cœurs des croyants afin qu'ils ajoutent une foi à leur foi. A Allah appartiennent les armées des cieux et de la terre; et Allah est Omniscient et Sage\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxxviii{afin qu'Il fasse entrer les croyants et les croyantes dans des Jardins sous lesquels coulent les ruisseaux où ils demeureront éternellement et afin de leur effacer leurs méfaits. Cela est auprès d'Allah un énorme succès.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmdlxxxix{Et afin qu'Il châtie les hypocrites, hommes et femmes, et les associateurs et les associatrices, qui pensent du mal d'Allah. Qu'un mauvais sort tombe sur eux. Allah est courroucé contre eux, les a maudits, et leur a préparé l'Enfer. Quelle mauvaise destination!\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmdxc{A Allah appartiennent les armées des cieux et de la terre; et Allah est Puissant et Sage.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmdxci{Nous t'avons envoyé en tant que témoin, annonciateur de la bonne nouvelle et avertisseur,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmdxcii{pour que vous croyiez en Allah et en Son messager, que vous l'honoriez, reconnaissiez Sa dignité, et Le glorifiez matin et soir.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmdxciii{Ceux qui te prêtent serment d'allégeance ne font que prêter serment à Allah: la main d'Allah est au-dessus de leurs mains. Quiconque viole le serment ne le viole qu'à son propre détriment; et quiconque remplit son engagement envers Allah, Il lui apportera bientôt une énorme récompense.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmdxciv{Ceux des Bédouins qui ont été laissés en arrière te diront: «Nos biens et nos familles nous ont retenus: implore donc pour nous le pardon». Ils disent avec leurs langues ce qui n'est pas dans leurs cœurs. Dis: «Qui donc peut quelque chose pour vous auprès d'Allah s'Il veut vous faire du mal ou s'Il veut vous faire du bien? Mais Allah est Parfaitement Connaisseur de ce que vous œuvrez.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmdxcv{Vous pensiez plutôt que le Messager et les croyants ne retourneraient jamais plus à leur famille. Et cela vous a été embelli dans vos cœurs; et vous avez eu de mauvaises pensées. Et vous fûtes des gens perdus».\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmdxcvi{Et quiconque ne croit pas en Allah et en Son messager... alors, pour les mécréants, Nous avons préparé une fournaise ardente.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmdxcvii{A Allah appartient la souveraineté des cieux et de la terre. Il pardonne à qui Il veut et châtie qui Il veut. Allah demeure cependant, Pardonneur et Miséricordieux.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmdxcviii{Ceux qui restèrent en arrière diront, quand vous vous dirigez vers le butin pour vous en emparer; «Laissez-nous vous suivre». Ils voudraient changer la parole d'Allah. Dis: «Jamais vous ne nous suivrez: ainsi Allah a déjà annoncé». Mais ils diront: «Vous êtes plutôt envieux à notre égard». Mais ils ne comprenaient en réalité que peu.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmdxcix{Dis à ceux des Bédouins qui restèrent en arrière: «vous serez bientôt appelés contre des gens d'une force redoutable. Vous les combattrez à moins qu'ils n'embrassent l'Islam, si vous obéissez, Allah vous donnera une belle récompense, et si vous vous détournez comme vous vous êtes détournés auparavant, Il vous châtiera d'un châtiment douloureux».\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmdc{Nul grief n'est à faire à l'aveugle, ni au boiteux ni au malade. Et quiconque obéit à Allah et à Son messager, Il le fera entrer dans des Jardins sous lesquels coulent les ruisseaux. Quiconque cependant se détourne, Il le châtiera d'un douloureux châtiment.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmdci{Allah a très certainement agréé les croyants quand ils t'ont prêté le serment d'allégeance sous l'arbre. Il a su ce qu'il y avait dans leurs cœurs, et a fait descendre sur eux la quiétude, et Il les a récompensés par une victoire proche.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmdcii{ainsi qu'un abondant butin qu'ils ramasseront. Allah est Puissant et Sage.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmdciii{Allah vous a promis un abondant butin que vous prendrez et Il a hâté pour vous Celle-ci et repoussé de vous les mains des gens, afin que tout cela soit un signe pour les croyants et qu'Il vous guide dans un droit chemin;\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmdciv{Il vous promet un autre butin que vous ne seriez jamais capables de remporter et qu'Allah a embrassé en Sa puissance, car Allah est Omnipotent.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmdcv{Et si ceux qui ont mécru vous combattent, ils se détourneront, certes; puis ils ne trouveront ni allié ni secoureur.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmdcvi{Telle est la règle d'Allah appliquée aux générations passées. Et tu ne trouveras jamais de changement à la règle d'Allah.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmdcvii{C'est Lui qui, dans la vallée de la Mecque, a écarté leurs mains de vous, de même qu'Il a écarté vos mains d'eux, après vous avoir fait triompher sur eux. Et Allah voit parfaitement ce que vous œuvrez.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmdcviii{Ce sont eux qui ont mécru et qui vous ont obstrué le chemin de la Mosquée Sacrée [et ont empêché] que les offrandes entravées parvinssent à leur lieu d'immolation. S'il n'y avait pas eu des hommes croyants et des femmes croyantes (parmi les Mecquois) que vous ne connaissiez pas et que vous auriez pu piétiner sans le savoir, vous rendant ainsi coupables d'une action répréhensible... [Tout cela s'est fait] pour qu'Allah fasse entrer qui Il veut dans Sa miséricorde. Et s'ils [les croyants] s'étaient signalés, Nous aurions certes châtié d'un châtiment douloureux ceux qui avaient mécru parmi [les Mecquois].\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmdcix{Quand ceux qui ont mécru eurent mis dans leurs cœurs la fureur, [la] fureur de l'ignorance... Puis Allah fit descendre Sa quiétude sur Son Messager ainsi que sur les croyants, et les obligea à une parole de piété, dont ils étaient les plus dignes et les plus proches. Allah est Omniscient.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmdcx{Allah a été véridique en la vision par laquelle Il annonça à Son messager en toute vérité: vous entrerez dans la Mosquée Sacrée si Allah veut, en toute sécurité, ayant rasé vos têtes ou coupé vos cheveux, sans aucune crainte. Il savait donc ce que vous ne saviez pas. Il a placé en deçà de cela (la trêve de Houdaybiya) une victoire proche.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmdcxi{C'est Lui qui a envoyé Son messager avec la guidée et la religion de vérité [l'Islam] pour la faire triompher sur toute autre religion. Allah suffit comme témoin.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmdcxii{Muhammad est le Messager d'Allah. Et ceux qui sont avec lui sont durs envers les mécréants, miséricordieux entre eux. Tu les vois inclinés, prosternés, recherchant d'Allah grâce et agrément. Leurs visages sont marqués par la trace laissée par la prosternation. Telle est leur image dans la Thora. Et l'image que l'on donne d'eux dans l'Evangile est celle d'une semence qui sort sa pousse, puis se raffermit, s'épaissit, et ensuite se dresse sur sa tige, à l'émerveillement des semeurs. [Allah] par eux [les croyants] remplit de dépit les mécréants. Allah promet à ceux d'entre eux qui croient et font de bonnes œuvres, un pardon et une énorme récompense.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmdcxiii{\basmalahfr O vous qui avez cru! Ne devancez pas Allah et Son messager. Et craignez Allah. Allah est Audient et Omniscient.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmdcxiv{O vous qui avez cru! N'élevez pas vos voix au-dessus de la voix du Prophète, et ne haussez pas le ton en lui parlant, comme vous le haussez les uns avec les autres, sinon vos œuvres deviendraient vaines sans que vous vous en rendiez compte.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmdcxv{Ceux qui auprès du Messager d'Allah baissent leurs voix sont ceux dont Allah a éprouvé les cœurs pour la piété. Ils auront un pardon et une énorme récompense.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmdcxvi{Ceux qui t'appellent à haute voix de derrière les appartements, la plupart d'entre eux ne raisonnent pas.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmdcxvii{Et s'ils patientaient jusqu'à ce que tu sortes à eux ce serait certes mieux pour eux. Allah cependant, est Pardonneur et Miséricordieux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmdcxviii{O vous qui avez cru! Si un pervers vous apporte une nouvelle, voyez bien clair [de crainte] que par inadvertance vous ne portiez atteinte à des gens et que vous ne regrettiez par la suite ce que vous avez fait.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmdcxix{Et sachez que le Messager d'Allah est parmi vous. S'il vous obéissait dans maintes affaires, vous seriez en difficultés. Mais Allah vous a fait aimer la foi et l'a embellie dans vos cœurs et vous a fait détester la mécréance, la perversité et la désobéissance. Ceux-là sont les bien dirigés,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmdcxx{c'est là en effet une grâce d'Allah et un bienfait. Allah est Omniscient et Sage.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxi{Et si deux groupes de croyants se combattent, faites la conciliation entre eux. Si l'un d'eux se rebelle contre l'autre, combattez le groupe qui se rebelle, jusqu'à ce qu'il se conforme à l'ordre d'Allah. Puis, s'il s'y conforme, réconciliez-les avec justice et soyez équitables car Allah aime les équitables.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxii{Les croyants ne sont que des frères. Etablissez la concorde entre vos frères, et craignez Allah, afin qu'on vous fasse miséricorde.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxiii{O vous qui avez cru! Qu'un groupe ne se raille pas d'un autre groupe: ceux-ci sont peut-être meilleurs qu'eux. Et que des femmes ne se raillent pas d'autres femmes: celles-ci sont peut-être meilleures qu'elles. Ne vous dénigrez pas et ne vous lancez pas mutuellement des sobriquets (injurieux). Quel vilain mot que «perversion» lorsqu'on a déjà la foi. Et quiconque ne se repent pas... Ceux-là sont les injustes.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxiv{O vous qui avez cru! Evitez de trop conjecturer [sur autrui] car une partie des conjectures est péché. Et n'espionnez pas; et ne médisez pas les uns des autres. L'un de vous aimerait-il manger la chair de son frère mort? (Non!) vous en aurez horreur. Et craignez Allah. Car Allah est Grand Accueillant au repentir, Très Miséricordieux.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxv{O hommes! Nous vous avons créés d'un mâle et d'une femelle, et Nous avons fait de vous des nations et des tribus, pour que vous vous entre-connaissiez. Le plus noble d'entre vous, auprès d'Allah, est le plus pieux. Allah est certes Omniscient et Grand Connaisseur.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxvi{Les Bédouins ont dit: «Nous avons la foi». Dis: «Vous n'avez pas encore la foi. Dites plutôt: Nous nous sommes simplement soumis, car la foi n'a pas encore pénétré dans vos cœurs. Et si vous obéissez à Allah et à Son messager, Il ne vous fera rien perdre de vos œuvres». Allah est Pardonneur et Miséricordieux.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxvii{Les vrais croyants sont seulement ceux qui croient en Allah et en Son messager, qui par la suite ne doutent point et qui luttent avec leurs biens et leurs personnes dans le chemin d'Allah. Ceux-là sont les véridiques.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxviii{Dis: «Est-ce vous qui apprendrez à Allah votre religion, alors qu'Allah sait tout ce qui est dans les cieux et sur la terre?» Et Allah est Omniscient.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxix{Ils te rappellent leur conversion à l'Islam comme si c'était une faveur de leur part. Dis: «Ne me rappelez pas votre conversion à l'Islam comme une faveur. C'est tout au contraire une faveur dont Allah vous a comblés en vous dirigeant vers la foi, si toutefois vous êtes véridiques».\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxx{Allah connaît l'Inconnaissable des cieux et de la terre et Allah est Clairvoyant sur ce que vous faites.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxxi{\basmalahfr Qâf. Par le Coran glorieux!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxxii{Mais ils s'étonnent que l'un des leurs leur vint comme avertisseur; et les mécréants dirent: «Ceci est une chose étonnante.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxxiii{Quoi! Quand nous serons morts et réduits en poussière...? Ce serait revenir de loin!»\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxxiv{Certes, Nous savons ce que la terre rongera d'eux [de leurs corps]; et Nous avons un Livre où tout est conservé.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxxv{Plutôt, ils traitent de mensonge la vérité qui leur est venue: les voilà donc dans une situation confuse.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxxvi{N'ont-ils donc pas observé le ciel au-dessus d'eux, comment Nous l'avons bâti et embelli; et comment il est sans fissures?\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxxvii{Et la terre, Nous l'avons étendue et Nous y avons enfoncé fermement des montagnes et y avons fait pousser toutes sortes de magnifiques couples de [végétaux],\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxxviii{à titre d'appel à la clairvoyance et un rappel pour tout serviteur repentant.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmdcxxxix{Et Nous avons fait descendre du ciel une eau bénie, avec laquelle Nous avons fait pousser des jardins et le grain qu'on moissonne,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmdcxl{ainsi que les hauts palmiers aux régimes superposés,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmdcxli{comme subsistance pour les serviteurs. Et par elle (l'eau) Nous avons redonné la vie à une contrée morte. Ainsi se fera la résurrection.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmdcxlii{Avant eux, le peuple de Noé, les gens d'Ar-Rass et les Thamûd crièrent au mensonge,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmdcxliii{de même que les 'Aad et Pharaon et les frères de Lot,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmdcxliv{et les gens d'Al-Aykah et le peuple de Tubba'. Tous traitèrent les Messagers de menteurs. C'est ainsi que Ma menace se justifia.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmdcxlv{Quoi? Avons-Nous été fatigué par la première création? Mais ils sont dans la confusion [au sujet] d'une création nouvelle.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmdcxlvi{Nous avons effectivement créé l'homme et Nous savons ce que son âme lui suggère et Nous sommes plus près de lui que sa veine jugulaire\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmdcxlvii{quand les deux recueillants, assis à droite et à gauche, recueillent.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmdcxlviii{Il ne prononce pas une parole sans avoir auprès de lui un observateur prêt à l'inscrire.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmdcxlix{L'agonie de la mort fait apparaître la vérité: «Voilà ce dont tu t'écartais».\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmdcl{Et l'on soufflera dans la Trompe: Voilà le jour de la Menace.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmdcli{Alors chaque âme viendra accompagnée d'un conducteur et d'un témoin.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmdclii{«Tu restais indifférent à cela. Et bien, Nous ôtons ton voile; ta vue est perçante aujourd'hui.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmdcliii{Et son compagnon dira: «Voilà ce qui est avec moi, tout prêt».\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmdcliv{«Vous deux, jetez dans l'Enfer tout mécréant endurci et rebelle,\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmdclv{acharné à empêcher le bien, transgresseur, douteur,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmdclvi{celui qui plaçait à côté d'Allah une autre divinité. Jetez-le donc dans le dur châtiment».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmdclvii{Son camarade (le Diable) dira: «Seigneur, ce n'est pas moi qui l'ai fait transgresser; mais il était déjà dans un profond égarement».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmdclviii{Alors [Allah] dira:«Ne vous disputez pas devant moi! Alors que Je vous ai déjà fait part de la menace.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmdclix{Chez Moi, la parole ne change pas; et Je n'opprime nullement les serviteurs».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmdclx{Le jour où Nous dirons à l'Enfer; «Es-tu rempli?» Il dira: «Y en a-t-il encore?»\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmdclxi{Le Paradis sera rapproché à proximité des pieux.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmdclxii{«Voilà ce qui vous a été promis, [ainsi qu'] à tout homme plein de repentir et respectueux [des prescriptions divines]\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmdclxiii{qui redoute le Tout Miséricordieux bien qu'il ne Le voit pas, et qui vient [vers Lui] avec un cœur porté à l'obéissance.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmdclxiv{Entrez-y en toute sécurité,». Voilà le jour de l'éternité!\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmdclxv{Il y aura là pour eux tout ce qu'ils voudront. Et auprès de Nous il y a davantage encore.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmdclxvi{combien avons-Nous fait périr, avant eux, de générations bien plus fortes qu'eux. Ils avaient parcouru les contrées, cherchant [vainement] où fuir.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmdclxvii{Il y a bien là un rappel pour quiconque a un cœur, prête l'oreille tout en étant témoin.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmdclxviii{En effet Nous avons créé les cieux et la terre et ce qui existe entre eux en six jours, sans éprouver la moindre lassitude.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmdclxix{Endure donc ce qu'ils disent; et célèbre la louange de ton Seigneur avant le lever du soleil et avant [son] coucher;\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmdclxx{et célèbre Sa gloire, une partie de la nuit et à la suite des prosternations [prières].\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxi{Et sois à l'écoute, le jour où le Crieur criera d'un endroit proche,\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxii{le jour où ils entendront en toute vérité le Cri. Voilà le Jour de la Résurrection.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxiii{C'est Nous qui donnons la vie et donnons la mort, et vers Nous sera la destination,\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxiv{le jour où la terre se fendra, les [rejetant] précipitamment. Ce sera un rassemblement facile pour Nous.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxv{Nous savons mieux ce qu'ils disent. Tu n'as pas pour mission d'exercer sur eux une contrainte. Rappelle donc, par le Coran celui qui craint Ma menace.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxvi{\basmalahfr Par les vents qui éparpillent!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxvii{Par les porteurs de fardeaux!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxviii{Par les glisseurs agiles!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxix{Par les distributeurs selon un commandement!\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxx{Ce qui vous est promis est certainement vrai.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxxi{Et la Rétribution arrivera inévitablement.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxxii{Par le ciel aux voies parfaitement tracées!\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxxiii{vous divergez sur ce que vous dites.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxxiv{Est détourné de lui quiconque a été détourné de la foi.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxxv{Maudits soient les menteurs,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxxvi{qui sont plongés dans l'insouciance.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxxvii{Ils demandent: «A quand le jour de la Rétribution?»\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxxviii{Le jour où ils seront éprouvés au Feu:\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmdclxxxix{«Goûtez à votre épreuve [punition]; voici ce que vous cherchiez à hâter».\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmdcxc{Les pieux seront dans des Jardins et [parmi] des sources,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmdcxci{recevant ce que leur Seigneur leur aura donné. Car ils ont été auparavant des bienfaisants:\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmdcxcii{ils dormaient peu, la nuit,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmdcxciii{et aux dernières heures de la nuit ils imploraient le pardon [d'Allah];\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmdcxciv{et dans leurs biens, il y avait un droit au mendiant et au déshérité.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmdcxcv{Il y a sur terre des preuves pour ceux qui croient avec certitude;\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmdcxcvi{ainsi qu'en vous-mêmes. N'observez-vous donc pas?\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmdcxcvii{Et il y a dans le ciel votre subsistance et ce qui vous a été promis.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmdcxcviii{Par le Seigneur du ciel et de la terre! Ceci est tout aussi vrai que le fait que vous parliez.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmdcxcix{T'est-il parvenu le récit des visiteurs honorables d'Abraham?\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmdcc{Quand ils entrèrent chez lui et dirent: «Paix!», il [leur] dit: «Paix, visiteurs inconnus».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmdcci{Puis il alla discrètement à sa famille et apporta un veau gras.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmdccii{Ensuite il l'approcha d'eux... «Ne mangez-vous pas?» dit-il.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmdcciii{Il ressentit alors de la peur vis-à-vis d'eux. Ils dirent: «N'aie pas peur». Et ils lui annoncèrent [la naissance] d'un garçon plein de savoir.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmdcciv{Alors sa femme s'avança en criant, se frappa le visage et dit: «Une vieille femme stérile...»\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmdccv{Ils dirent: «Ainsi a dit ton Seigneur. C'est Lui vraiment le Sage, l'Omniscient».\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmdccvi{Alors [Abraham] dit: «Quelle est donc votre mission, ô envoyés?»\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmdccvii{Ils dirent: «Nous avons été envoyés vers des gens criminels,\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmdccviii{pour lancer sur eux des pierres de glaise,\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmdccix{marquées auprès de ton Seigneur à l'intention des outranciers».\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmdccx{Nous en fîmes sortir alors ce qu'il y avait comme croyants,\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmdccxi{mais Nous n'y trouvâmes qu'une seule maison de gens soumis.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmdccxii{Et Nous y laissâmes un signe pour ceux qui redoutent le douloureux châtiment;\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmdccxiii{[Il y a même un signe] en Moïse quand Nous l'envoyâmes, avec une preuve évidente, vers Pharaon.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmdccxiv{Mais [celui-ci] se détourna confiant en sa puissance, et dit: «C'est un magicien ou un possédé!»\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmdccxv{Nous le saisîmes ainsi que ses troupes, puis les jetâmes dans les flots, pour son comportement blâmable.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmdccxvi{De même pour les 'Aad, quand Nous envoyâmes contre eux le vent dévastateur\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmdccxvii{n'épargnant rien sur son passage sans le réduire en poussière.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmdccxviii{De même pour les Thamûd, quand il leur fut dit: «Jouissez jusqu'à un certain temps!»\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmdccxix{Ils défièrent le commandement de leur Seigneur. La foudre les saisit alors qu'ils regardaient.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmdccxx{Ils ne purent ni se mettre debout ni être secourus.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxi{De même, pour le peuple de Noé auparavant. Ils étaient des gens pervers.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxii{Le ciel, Nous l'avons construit par Notre puissance: et Nous l'étendons [constamment] dans l'immensité.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxiii{Et la terre, Nous l'avons étendue. Et de quelle excellente façon Nous l'avons nivelée!\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxiv{Et de toute chose Nous avons créé [deux éléments] de couple. Peut-être vous rappellerez-vous?\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxv{«Fuyez donc vers Allah. Moi, je suis pour vous de Sa part, un avertisseur explicite.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxvi{Ne placez pas avec Allah une autre divinité. Je suis pour vous de Sa part, un avertisseur explicite».\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxvii{Ainsi, aucun Messager n'est venu à leurs prédécesseurs sans qu'ils n'aient dit: «C'est un magicien ou un possédé!»\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxviii{Est-ce qu'ils se sont transmis cette injonction? Ils sont plutôt des gens transgresseurs.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxix{Détourne-toi d'eux, tu ne seras pas blâmé [à leur sujet].\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxx{Et rappelle; car le rappel profite aux croyants.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxxi{Je n'ai créé les djinns et les hommes que pour qu'ils M'adorent.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxxii{Je ne cherche pas d'eux une subsistance; et Je ne veux pas qu'ils me nourrissent.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxxiii{En vérité, c'est Allah qui est le Grand Pourvoyeur, Le Détenteur de la force, l'Inébranlable.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxxiv{Ceux qui ont été injustes auront une part [de tourments] pareille à celle de leurs compagnons. Qu'ils ne soient pas trop pressés.\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxxv{Malheur donc à ceux qui ont mécru à cause du jour dont ils sont menacés!\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxxvi{\basmalahfr Par At-Tûr!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxxvii{Et par un Livre écrit\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxxviii{sur un parchemin déployé!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmdccxxxix{Et par la Maison peuplée!\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmdccxl{Et par la Voûte élevée!\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmdccxli{Et par la Mer portée à ébullition! (au Jour dernier)\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmdccxlii{Le châtiment de ton Seigneur aura lieu inévitablement.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmdccxliii{Nul ne pourra le repousser.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmdccxliv{Le jour où le ciel sera agité d'un tourbillonnement,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmdccxlv{et les montagnes se mettront en marche.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmdccxlvi{Ce jour-là, malheur à ceux qui traitent (les signes d'Allah) de mensonges,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmdccxlvii{ceux qui s'ébattent dans des discours frivoles\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmdccxlviii{le jour où ils seront brutalement poussés au feu de l'Enfer:\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmdccxlix{Voilà le feu que vous traitiez de mensonge.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmdccl{Est-ce que cela est de la magie? Ou bien ne voyez-vous pas clair?\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmdccli{Brûlez dedans! Supportez ou ne supportez pas, ce sera égal pour vous: vous n'êtes rétribués que selon ce que vous faisiez.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmdcclii{Les pieux seront dans des Jardins et dans des délices,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmdccliii{se réjouissant de ce que leur Seigneur leur aura donné, et leur Seigneur les aura protégés du châtiment de la Fournaise.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmdccliv{«En récompense de ce que vous faisiez, mangez et buvez en toute sérénité,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmdcclv{accoudés sur des lits bien rangés», et Nous leur ferons épouser des houris aux grands yeux noirs,\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmdcclvi{Ceux qui auront cru et que leurs descendants auront suivis dans la foi, Nous ferons que leurs descendants les rejoignent. Et Nous ne diminuerons en rien le mérite de leurs œuvres, chacun étant tenu responsable de ce qu'il aura acquis.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmdcclvii{Nous les pourvoirons abondamment des fruits et des viandes qu'ils désireront.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmdcclviii{Là, ils se passeront les uns les autres une coupe qui ne provoquera ni vanité ni incrimination.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmdcclix{Et parmi eux circuleront des garçons à leur service, pareils à des perles bien conservées.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmdcclx{Et ils se tourneront les uns vers les autres s'interrogeant;\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxi{Ils diront: «Nous vivions au milieu des nôtres dans la crainte [d'Allah];\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxii{Puis Allah nous a favorisés et protégés du châtiment du Samûm.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxiii{Antérieurement, nous L'invoquions. C'est Lui certes, le Charitable, le Très Miséricordieux».\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxiv{Rappelle donc et par la grâce de ton Seigneur tu n'es ni un devin ni un possédé.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxv{Ou bien ils disent: «C'est un poète! Attendons pour lui le coup de la mort».\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxvi{Dis: «Attendez! Je suis avec vous parmi ceux qui attendent».\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxvii{Est-ce leur raison qui leur commande cela? Ou sont-ils des gens outranciers?\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxviii{Ou bien ils disent: «Il l'a inventé lui-même?» Non... mais ils ne croient pas.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxix{Eh bien, qu'ils produisent un récit pareil à lui (le Coran), s'ils sont véridiques.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxx{Ont-ils été créé à partir de rien ou sont-ils eux les créateurs?\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxi{Ou ont-ils créé les cieux et la terre? Mais ils n'ont plutôt aucune conviction.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxii{Possèdent-ils les trésors de ton Seigneur? Ou sont-ils eux les maîtres souverains?\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxiii{Ont-ils une échelle d'où ils écoutent? Que celui des leurs qui reste à l'écoute apporte une preuve évidente!\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxiv{[Allah] aurait-Il les filles, tandis que vous, les fils?\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxv{Ou leur demandes-tu un salaire, de sorte qu'ils soient grevés d'une lourde dette?\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxvi{Ou bien détiennent-ils l'Inconnaissable pour le mentionner par écrit?\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxvii{Ou cherchent-ils un stratagème? Mais ce sont ceux qui ont mécru qui sont victimes de leur propre stratagème.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxviii{Ou ont-ils une autre divinité à part Allah? Qu'Allah soit glorifié et purifié de tout ce qu'ils associent!\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxix{Et s'ils voient tomber des fragments du ciel, ils disent: «Ce sont des nuages superposés».\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxx{Laisse-les donc, jusqu'à ce qu'ils rencontrent leur jour où ils seront foudroyés,\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxxi{le jour où leur ruse ne leur servira à rien, où ils ne seront pas secourus.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxxii{Les injustes auront un châtiment préalable. Mais la plupart d'entre eux ne savent pas.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxxiii{Et supporte patiemment la décision de ton Seigneur. Car en vérité, tu es sous Nos yeux. Et célèbre la gloire de ton Seigneur quand tu te lèves;\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxxiv{Glorifie-Le une partie de la nuit et au déclin des étoiles.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxxv{\basmalahfr Par l'étoile à son déclin!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxxvi{Votre compagnon ne s'est pas égaré et n'a pas été induit en erreur\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxxvii{et il ne prononce rien sous l'effet de la passion;\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxxviii{ce n'est rien d'autre qu'une révélation inspirée.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmdcclxxxix{Que lui a enseigné [l'Ange Gabriel] à la force prodigieuse,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmdccxc{doué de sagacité; c'est alors qu'il se montra sous sa forme réelle [angélique],\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmdccxci{alors qu'il se trouvait à l'horizon supérieur.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmdccxcii{Puis il se rapprocha et descendit encore plus bas,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmdccxciii{et fut à deux portées d'arc, ou plus près encore.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmdccxciv{Il révéla à Son serviteur ce qu'Il révéla.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmdccxcv{Le cœur n'a pas menti en ce qu'il a vu.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmdccxcvi{Lui contestez-vous donc ce qu'il voit?\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmdccxcvii{Il l'a pourtant vu, lors d'une autre descente,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmdccxcviii{près de la Sidrat-ul-Muntahâ,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmdccxcix{près d'elle se trouve le jardin de Ma'w?:\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmdccc{au moment où le lotus était couvert de ce qui le couvrait.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmdccci{la vue n'a nullement dévié ni outrepassé la mesure.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmdcccii{Il a bien vu certaines des grandes merveilles de son Seigneur.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmdccciii{Que vous en semble [des divinités], Lât et Uuzzâ\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmdccciv{ainsi que Manât, cette troisième autre?\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmdcccv{Sera-ce à vous le garçon et à Lui la fille?\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmdcccvi{Que voilà donc un partage injuste!\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmdcccvii{Ce ne sont que des noms que vous avez inventés, vous et vos ancêtres. Allah n'a fait descendre aucune preuve à leur sujet. Ils ne suivent que la conjecture et les passions de [leurs] âmes, alors que la guidée leur est venue de leur Seigneur.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmdcccviii{Ou bien l'homme aura-t-il tout ce qu'il désire?\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmdcccix{A Allah appartiennent la vie future et la vie d'ici-bas.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmdcccx{Et que d'Anges dans les cieux dont l'intercession ne sert à rien, sinon qu'après qu'Allah l'aura permis, en faveur de qui Il veut et qu'Il agrée.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxi{Ceux qui ne croient pas en l'au-delà donnent aux Anges des noms de femmes,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxii{alors qu'ils n'en ont aucune science: ils ne suivent que la conjecture, alors que la conjecture ne sert à rien contre la vérité.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxiii{Ecarte-toi donc, de celui qui tourne le dos à Notre rappel et qui ne désire que la vie présente.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxiv{Voilà toute la portée de leur savoir. Certes ton Seigneur connaît parfaitement celui qui s'égare de Son chemin et Il connaît parfaitement qui est bien guidé.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxv{A Allah appartient ce qui est dans les cieux et sur la terre afin qu'Il rétribue ceux qui font le mal selon ce qu'ils œuvrent, et récompense ceux qui font le bien par la meilleure [récompense],\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxvi{ceux qui évitent les plus grands péchés ainsi que les turpitudes et [qui ne commettent] que des fautes légères. Certes, le pardon de Ton Seigneur est immense. C'est Lui qui vous connaît le mieux quand Il vous a produits de terre, et aussi quand vous étiez des embryons dans les ventres de vos mères. Ne vantez pas vous-mêmes votre pureté; c'est Lui qui connaît mieux ceux qui [Le] craignent.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxvii{Vois-tu celui qui s'est détourné,\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxviii{donné peu et a [finalement] cessé de donner?\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxix{Détient-il la science de l'Inconnaissable en sorte qu'il voit?\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxx{Ne lui a-t-on pas annoncé ce qu'il y avait dans les feuilles de Moïse\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxi{et celles d'Abraham qui a tenu parfaitement [sa promesse de transmettre]\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxii{qu'aucune [âme] ne portera le fardeau (le péché) d'autrui,\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxiii{et qu'en vérité, l'homme n'obtient que [le fruit] de ses efforts;\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxiv{et que son effort, en vérité, lui sera présenté (le jour du Jugement).\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxv{Ensuite il en sera récompensé pleinement,\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxvi{et que tout aboutit, en vérité, vers ton Seigneur,\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxvii{et que c'est Lui qui a fait rire et qui a fait pleurer,\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxviii{et que c'est Lui qui a fait mourir et qui a ramené à la vie,\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxix{et que c'est Lui qui a crée les deux éléments de couple, le mâle et la femelle,\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxx{d'une goutte de sperme quand elle est éjaculée\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxxi{et que la seconde création Lui incombe,\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxxii{et c'est Lui qui a enrichi et qui a fait acquérir.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxxiii{Et c'est Lui qui est le Seigneur de Sirius,\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxxiv{et c'est Lui qui a fait périr les anciens 'Aad,\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxxv{ainsi que les Thamûd, et Il fit que rien n'en subsistât,\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxxvi{ainsi que le peuple de Noé antérieurement, car ils étaient encore plus injustes et plus violents,\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxxvii{de même qu'Il anéantit les villes renversées.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxxviii{Et les recouvrit de ce dont Il les recouvrit.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxxxix{Lequel donc des bienfaits de ton Seigneur mets-tu en doute?\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxl{Voici un avertisseur analogue aux avertisseurs anciens:\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxli{l'Imminente (L'heure du Jugement) s'approche.\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxlii{Rien d'autre en dehors d'Allah ne peut la dévoiler.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxliii{Quoi! vous étonnez-vous de ce discours (le Coran)?\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxliv{Et vous [en] riez et n'[en] pleurez point?\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxlv{absorbés [que vous êtes] par votre distraction.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxlvi{Prosternez-vous donc à Allah et adorez-Le.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxlvii{\basmalahfr L'Heure approche et la Lune s'est fendue.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxlviii{Et s'ils voient un prodige, ils s'en détournent et disent: «Une magie persistante».\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxlix{Et ils [le] traitent de mensonge et suivent leurs propres impulsions, or chaque chose arrivera à son terme [et son but].\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmdcccl{Ils ont pourtant reçu comme nouvelles de quoi les empêcher (du mal);\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmdcccli{[Cela est] une sagesse parfaite. Mais les avertissements ne [leur] servent à rien.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmdccclii{Détourne-toi d'eux. Le jour où l'appeleur appellera vers une chose affreuse,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmdcccliii{les regards baissés, ils sortiront des tombes comme des sauterelles éparpillées,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmdcccliv{courant, le cou tendu, vers l'appeleur. Les mécréants diront: «Voilà un jour difficile».\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmdccclv{Avant eux, le peuple de Noé avait crié au mensonge. Ils traitèrent Notre serviteur de menteur et dirent: «C'est un possédé!» et il fut repoussé.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmdccclvi{Il invoqua donc son Seigneur: «Moi, je suis vaincu. Fais triompher (Ta cause)».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmdccclvii{Nous ouvrîmes alors les portes du ciel à une eau torrentielle,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmdccclviii{et fîmes jaillir la terre en sources. Les eaux se rencontrèrent d'après un ordre qui était déjà décrété dans une chose [faite].\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmdccclix{Et Nous le portâmes sur un objet [fait] de planches et de clous [l'arche],\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmdccclx{voguant sous Nos yeux: récompense pour celui qu'on avait renié [Noé].\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxi{Et Nous la laissâmes, comme un signe [d'avertissement]. Y a-t-il quelqu'un pour réfléchir?\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxii{Comment furent Mon châtiment et Mes avertissements?\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxiii{En effet, Nous avons rendu le Coran facile pour la méditation. Y a-t-il quelqu'un pour réfléchir?\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxiv{Les 'Aad ont traité de menteur (leur Messager). Comment furent Mon châtiment et Mes avertissements?\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxv{Nous avons envoyé contre eux un vent violent et glacial, en un jour néfaste et interminable;\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxvi{il arrachait les gens comme des souches de palmiers déracinés.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxvii{Comment furent Mon châtiment et Mes avertissements?\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxviii{En effet, Nous avons rendu le Coran facile pour la méditation. Y a-t-il quelqu'un pour réfléchir?\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxix{Les Thamûd ont traité de mensonges les avertissements.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxx{Ils dirent: «Allons-nous suivre un seul homme (Sâlih) d'entre nous-mêmes? Nous serions alors dans l'égarement et la folie.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxi{Est-ce que le message a été envoyé à Lui à l'exception de nous tous? C'est plutôt un grand menteur, plein de prétention et d'orgueil».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxii{Demain, ils sauront qui est le grand menteur plein de prétention et d'orgueil.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxiii{Nous leur enverrons la chamelle, comme épreuve. Surveille-les donc et sois patient.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxiv{Et informe-les que l'eau sera en partage entre eux [et la chamelle]; chacun boira à son tour.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxv{Puis ils appelèrent leur camarade qui prit [son épée] et [la] tua.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxvi{Comment furent donc Mon châtiment et Mes avertissements?\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxvii{Nous lachâmes sur eux un seul Cri, et voilà qu'ils furent réduits à l'état de paille d'étable.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxviii{Et vraiment, Nous avons rendu le Coran facile pour la méditation. Y a-t-il quelqu'un pour réfléchir?\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxix{Le peuple de Lot traita de mensonges les avertissements.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxx{Nous lachâmes sur eux un ouragan, excepté la famille de Lot que Nous sauvâmes avant l'aube,\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxxi{à titre de bienfait de Notre part: ainsi récompensons-Nous celui qui est reconnaissant.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxxii{Il les avait pourtant avertis de Nos représailles. Mais ils mirent les avertissements en doute.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxxiii{En effet, ils voulaient séduire ses hôtes. Nous aveuglâmes leurs yeux «Goûtez donc Mon châtiment et Mes avertissements».\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxxiv{En effet, au petit matin, un châtiment persistant les surprit.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxxv{Goûtez donc Mon châtiment et Mes avertissements.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxxvi{Et vraiment, Nous avons rendu le Coran facile pour la méditation. Y a-t-il quelqu'un pour réfléchir?\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxxvii{Les avertissements vinrent certes, aux gens de Pharaon.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxxviii{Ils traitèrent de mensonges tous Nos prodiges. Nous les saisîmes donc, de la saisie d'un Puissant Omnipotent.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmdccclxxxix{Vos mécréants sont-ils meilleurs que ceux-là? Ou bien y a-t-il dans les Ecritures une immunité pour vous?\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxc{Ou bien ils disent: «Nous formons un groupe [fort] et nous vaincrons».\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxci{Leur rassemblement sera bientôt mis en déroute, et ils fuiront.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxcii{L'Heure, plutôt, sera leur rendez-vous, et l'Heure sera plus terrible et plus amère.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxciii{Les criminels sont certes, dans l'égarement et la folie.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxciv{Le jour où on les traînera dans le Feu sur leurs visages, (on leur dira): «Goûtez au contact de Saqar [la chaleur brûlante de l'Enfer]».\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxcv{Nous avons créé toute chose avec mesure,\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxcvi{et Notre ordre est une seule [parole]; [il est prompt] comme un clin d'œil.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxcvii{En effet, nous avons fait périr des peuples semblables à vous. Y a-t-il quelqu'un pour s'en souvenir?\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxcviii{Et tout ce qu'ils ont fait est mentionné dans les registres,\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmdcccxcix{et tout fait, petit et grand, est consigné.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmcm{Les pieux seront dans des Jardins et parmi des ruisseaux,\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmcmi{dans un séjour de vérité, auprès d'un Souverain Omnipotent.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmcmii{\basmalahfr Le Tout Miséricordieux.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmcmiii{Il a enseigné le Coran.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmcmiv{Il a créé l'homme.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmcmv{Il lui a appris à s'exprimer clairement.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmcmvi{Le soleil et la lune [évoluent] selon un calcul [minutieux].\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmcmvii{Et l'herbe et les arbres se prosternent.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmcmviii{Et quant au ciel, Il l'a élevé bien haut. Et Il a établi la balance,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmcmix{afin que vous ne transgressiez pas dans la pesée:\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmcmx{Donnez [toujours] le poids exact et ne faussez pas la pesée.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmcmxi{Quant à la terre, Il l'a étendue pour les êtres vivants:\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmcmxii{il s'y trouve des fruits, et aussi les palmiers aux fruits recouverts d'enveloppes,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmcmxiii{tout comme les grains dans leurs balles, et les plantes aromatiques.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmcmxiv{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmcmxv{Il a crée l'homme d'argile sonnante comme la poterie;\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmcmxvi{et Il a créé les djinns de la flamme d'un feu sans fumée.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmcmxvii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmcmxviii{Seigneur des deux Levants et Seigneur des deux Couchants!\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmcmxix{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmcmxx{Il a donné libre cours aux deux mers pour se rencontrer;\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxi{il y a entre elles une barrière qu'elles ne dépassent pas.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxiii{De ces deux [mers] sortent la perle et le corail.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxiv{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxv{A Lui appartiennent les vaisseaux élevés sur la mer comme des montagnes.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxvi{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxvii{Tout ce qui est sur elle [la terre] doit disparaître,\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxviii{[Seule] subsistera La Face [Wajh] de ton Seigneur, plein de majesté et de noblesse.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxix{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxx{Ceux qui sont dans les cieux et la terre L'implorent. Chaque jour, Il accomplit une œuvre nouvelle.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxxi{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxxii{Nous allons bientôt entreprendre votre jugement, ô vous les deux charges [hommes et djinns].\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxxiii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxxiv{O peuple de djinns et d'hommes! Si vous pouvez sortir du domaine des cieux et de la terre, alors faites-le. Mais vous ne pourrez en sortir qu'à l'aide d'un pouvoir [illimité].\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxxv{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxxvi{Il sera lancé contre vous un jet de feu et de fumée [ou de cuivre fondu], et vous ne serez pas secourus.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxxvii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxxviii{Puis quand le ciel se fendra et deviendra alors écarlate comme le cuir rouge.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmcmxxxix{Lequel des bienfaits de votre Seigneur nierez-vous?\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmcmxl{Alors, ni aux hommes ni aux djinns, on ne posera des questions à propos de leurs péchés.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmcmxli{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmcmxlii{On reconnaîtra les criminels à leurs traits. Ils seront donc saisis par les toupets et les pieds.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmcmxliii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmcmxliv{Voilà l'Enfer que les criminels traitaient de mensonge.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmcmxlv{Ils feront le va-et-vient entre lui (l'Enfer) et une eau bouillante extrêmement chaude.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmcmxlvi{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmcmxlvii{Et pour celui qui aura craint de comparaître devant son Seigneur, il y aura deux jardins;\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmcmxlviii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmcmxlix{Aux branches touffues.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmcml{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmcmli{Ils y trouveront deux sources courantes.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmcmlii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmcmliii{Ils contiennent deux espèces de chaque fruit.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmcmliv{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmcmlv{Ils seront accoudés sur des tapis doublés de brocart, et les fruits des deux jardins seront à leur portée (pour être cueillis).\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmcmlvi{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmcmlvii{Ils y trouveront [les houris] aux regards chastes, qu'avant eux aucun homme ou djinn n'aura déflorées.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmcmlviii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmmcmlix{Elles seront [aussi belles] que le rubis et le corail.\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmmcmlx{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxi{Y a-t-il d'autre récompense pour le bien, que le bien?\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxiii{En deçà de ces deux jardins il y aura deux autres jardins.\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxiv{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxv{Ils sont d'un vert sombre.\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxvi{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxvii{Dans lesquelles il y aura deux sources jaillissantes.\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxviii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxix{Ils contiennent des fruits, des palmiers, et des grenadiers.\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxx{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxi{Là, il y aura des vertueuses et des belles.\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxiii{Des houris cloîtrées dans les tentes,\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxiv{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxv{qu'avant eux aucun homme ou djinn n'a déflorées.\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxvi{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxvii{Ils seront accoudés sur des coussins verts et des tapis épais et jolis.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxviii{Lequel donc des bienfaits de votre Seigneur nierez-vous?\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxix{Béni soit le Nom de ton Seigneur, Plein de Majesté et de Munificence!\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxx{\basmalahfr Quand l'événement (le Jugement) arrivera,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxxi{nul ne traitera sa venue de mensonge.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxxii{Il abaissera (les uns), il élèvera (les autres).\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxxiii{Quand la terre sera secouée violemment,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxxiv{et les montagnes seront réduites en miettes,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxxv{et qu'elles deviendront poussière éparpillée\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxxvi{alors vous serez trois catégories:\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxxvii{les gens de la droite - que sont les gens de la droite?\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxxviii{Et les gens de la gauche - que sont les gens de la gauche?\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmcmlxxxix{Les premiers (à suivre les ordres d'Allah sur la terre) ce sont eux qui seront les premiers (dans l'au-delà)\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmcmxc{Ce sont ceux-là les plus rapprochés d'Allah\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmcmxci{dans les Jardins des délices,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmcmxcii{une multitude d'élus parmi les premières [générations],\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmcmxciii{et un petit nombre parmi les dernières [générations],\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmcmxciv{sur des lits ornés [d'or et de pierreries],\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmcmxcv{s'y accoudant et se faisant face.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmcmxcvi{Parmi eux circuleront des garçons éternellement jeunes,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmcmxcvii{avec des coupes, des aiguières et un verre [rempli] d'une liqueur de source\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmcmxcviii{qui ne leur provoquera ni maux de tête ni étourdissement;\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmcmxcix{et des fruits de leur choix,\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmm{et toute chair d'oiseau qu'ils désireront.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmi{Et ils auront des houris aux yeux, grands et beaux,\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmii{pareilles à des perles en coquille\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmiii{en récompense pour ce qu'ils faisaient.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmiv{Ils n'y entendront ni futilité ni blasphème;\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmv{mais seulement les propos: «Salâm! Salâm!»... [Paix! Paix!]\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmvi{Et les gens de la droite; que sont les gens de la droite?\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmvii{[Ils seront parmi] des jujubiers sans épines,\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmviii{et parmi des bananiers aux régimes bien fournis,\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmix{dans une ombre étendue\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmx{[près] d'une eau coulant continuellement,\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmxi{et des fruits abondants\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmxii{ni interrompus ni défendus,\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmxiii{sur des lits surélevés,\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmxiv{C'est Nous qui les avons créées à la perfection,\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmxv{et Nous les avons faites vierges,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmxvi{gracieuses, toutes de même âge,\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmxvii{pour les gens de la droite,\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmxviii{une multitude d'élus parmi les premières [générations],\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmxix{et une multitude d'élus parmi les dernières [générations].\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmxx{Et les gens de la gauche; que sont les gens de la gauche?\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmmxxi{ils seront au milieu d'un souffle brûlant et d'une eau bouillante,\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmmxxii{à l'ombre d'une fumée noire\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmmxxiii{ni fraîche, ni douce.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmmxxiv{Ils vivaient auparavant dans le luxe.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmmxxv{Ils persistaient dans le grand péché [le polythéisme]\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmmxxvi{et disaient: «Quand nous mourrons et serons poussière et ossements, serons-nous ressuscités?\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmmxxvii{ainsi que nos anciens ancêtres?..»\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmmxxviii{Dis: «En vérité les premiers et les derniers\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmmxxix{seront réunis pour le rendez-vous d'un jour connu».\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmmxxx{Et puis, vous, les égarés, qui traitiez (la Résurrection) de mensonge,\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmmxxxi{vous mangerez certainement d'un arbre de Zaqqûm.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmmxxxii{vous vous en remplirez le ventre,\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmmxxxiii{puis vous boirez par-dessus cela de l'eau bouillante,\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmmxxxiv{vous en boirez comme boivent les chameaux assoiffés.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmmxxxv{Voilà le repas d'accueil qui leur sera servi, au jour de la Rétribution.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmmxxxvi{C'est Nous qui vous avons créés. Pourquoi ne croiriez-vous donc pas [à la résurrection]?\qt@no{(57)}}
\qt@newcmd\qurantrans@fr@mmmmmxxxvii{Voyez-vous donc ce que vous éjaculez:\qt@no{(58)}}
\qt@newcmd\qurantrans@fr@mmmmmxxxviii{est-ce vous qui le créez ou [en] sommes Nous le Créateur?\qt@no{(59)}}
\qt@newcmd\qurantrans@fr@mmmmmxxxix{Nous avons prédéterminé la mort parmi vous. Nous ne serons point empêchés\qt@no{(60)}}
\qt@newcmd\qurantrans@fr@mmmmmxl{de vous remplacer par vos semblables, et vous faire renaître dans [un état] que vous ne savez pas.\qt@no{(61)}}
\qt@newcmd\qurantrans@fr@mmmmmxli{Vous avez connu la première création. Ne vous rappelez-vous donc pas?\qt@no{(62)}}
\qt@newcmd\qurantrans@fr@mmmmmxlii{Voyez-vous donc ce que vous labourez?\qt@no{(63)}}
\qt@newcmd\qurantrans@fr@mmmmmxliii{Est-ce vous qui le cultivez? ou [en] sommes Nous le cultivateur?\qt@no{(64)}}
\qt@newcmd\qurantrans@fr@mmmmmxliv{Si Nous voulions, Nous le réduirions en débris. Et vous ne cesseriez pas de vous étonner et [de crier]:\qt@no{(65)}}
\qt@newcmd\qurantrans@fr@mmmmmxlv{«Nous voilà endettés!\qt@no{(66)}}
\qt@newcmd\qurantrans@fr@mmmmmxlvi{ou plutôt, exposés aux privations».\qt@no{(67)}}
\qt@newcmd\qurantrans@fr@mmmmmxlvii{Voyez-vous donc l'eau que vous buvez?\qt@no{(68)}}
\qt@newcmd\qurantrans@fr@mmmmmxlviii{Est-ce vous qui l'avez fait descendre du nuage? ou [en] sommes Nous le descendeur?\qt@no{(69)}}
\qt@newcmd\qurantrans@fr@mmmmmxlix{Si Nous voulions, Nous la rendrions salée. Pourquoi n'êtes-vous donc pas reconnaissants?\qt@no{(70)}}
\qt@newcmd\qurantrans@fr@mmmmml{Voyez-vous donc le feu que vous obtenez par frottement?\qt@no{(71)}}
\qt@newcmd\qurantrans@fr@mmmmmli{Est-ce vous qui avez créé son arbre ou [en] sommes Nous le Créateur?\qt@no{(72)}}
\qt@newcmd\qurantrans@fr@mmmmmlii{Nous en avons fait un rappel (de l'Enfer), et un élément utile pour ceux qui en ont besoin.\qt@no{(73)}}
\qt@newcmd\qurantrans@fr@mmmmmliii{Glorifie donc le nom de ton Seigneur, le Très Grand!\qt@no{(74)}}
\qt@newcmd\qurantrans@fr@mmmmmliv{Non!.. Je jure par les positions des étoiles (dans le firmament).\qt@no{(75)}}
\qt@newcmd\qurantrans@fr@mmmmmlv{Et c'est vraiment un serment solennel, si vous saviez.\qt@no{(76)}}
\qt@newcmd\qurantrans@fr@mmmmmlvi{Et c'est certainement un Coran noble,\qt@no{(77)}}
\qt@newcmd\qurantrans@fr@mmmmmlvii{dans un Livre bien gardé\qt@no{(78)}}
\qt@newcmd\qurantrans@fr@mmmmmlviii{que seuls les purifiés touchent;\qt@no{(79)}}
\qt@newcmd\qurantrans@fr@mmmmmlix{C'est une révélation de la part du Seigneur de l'Univers.\qt@no{(80)}}
\qt@newcmd\qurantrans@fr@mmmmmlx{Est-ce ce discours-là que vous traitez de mensonge?\qt@no{(81)}}
\qt@newcmd\qurantrans@fr@mmmmmlxi{Et est-ce pour vous [une façon d'être reconnaissant] à votre subsistance que de traiter (le Coran) de mensonge?\qt@no{(82)}}
\qt@newcmd\qurantrans@fr@mmmmmlxii{Lorsque le souffle de la vie remonte à la gorge (d'un moribond),\qt@no{(83)}}
\qt@newcmd\qurantrans@fr@mmmmmlxiii{et qu'à ce moment là vous regardez,\qt@no{(84)}}
\qt@newcmd\qurantrans@fr@mmmmmlxiv{et que Nous sommes plus proche de lui que vous [qui l'entourez] mais vous ne [le] voyez point.\qt@no{(85)}}
\qt@newcmd\qurantrans@fr@mmmmmlxv{Pourquoi donc, si vous croyez que vous n'avez pas de compte à rendre,\qt@no{(86)}}
\qt@newcmd\qurantrans@fr@mmmmmlxvi{ne la faites-vous pas revenir [cette âme], si vous êtes véridiques?\qt@no{(87)}}
\qt@newcmd\qurantrans@fr@mmmmmlxvii{Si celui-ci est du nombre des rapprochés (d'Allah),\qt@no{(88)}}
\qt@newcmd\qurantrans@fr@mmmmmlxviii{alors (il aura) du repos, de la grâce et un Jardin de délices.\qt@no{(89)}}
\qt@newcmd\qurantrans@fr@mmmmmlxix{Et s'il est du nombre des gens de la droite,\qt@no{(90)}}
\qt@newcmd\qurantrans@fr@mmmmmlxx{il sera [accueilli par ces mots]: «Paix à toi» de la part des gens de la droite.\qt@no{(91)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxi{Et s'il est de ceux qui avaient traité de mensonge (la résurrection) et s'étaient égarés,\qt@no{(92)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxii{alors, il sera installé dans une eau bouillante,\qt@no{(93)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxiii{et il brûlera dans la Fournaise.\qt@no{(94)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxiv{C'est cela la pleine certitude.\qt@no{(95)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxv{Glorifie donc le nom de ton Seigneur, le Très Grand!\qt@no{(96)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxvi{\basmalahfr Tout ce qui est dans les cieux et la terre glorifie Allah. Et c'est Lui le Puissant, le Sage.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxvii{A Lui appartient la souveraineté des cieux et de la terre. Il fait vivre et il fait mourir, et Il est Omnipotent.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxviii{C'est Lui le Premier et le Dernier, l'Apparent et le Caché et Il est Omniscient.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxix{C'est Lui qui a créé les cieux et la terre en six jours puis Il S'est établi sur le Trône; Il sait ce qui pénètre dans la terre et ce qui en sort, et ce qui descend du ciel et ce qui y monte, et Il est avec vous où que vous soyez. Et Allah observe parfaitement ce que vous faites.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxx{A Lui appartient la souveraineté des cieux et de la terre. Et à Allah tout est ramené.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxxi{Il fait pénétrer la nuit dans le jour et fait pénétrer le jour dans la nuit, et Il sait parfaitement le contenu des poitrines.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxxii{Croyez en Allah et en Son Messager, et dépensez de ce dont Il vous a donné la lieutenance. Ceux d'entre vous qui croient et dépensent [pour la cause d'Allah] auront une grande récompense.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxxiii{Et qu'avez-vous à ne pas croire en Allah, alors que le Messager vous appelle à croire en votre Seigneur? Et [Allah] a déjà pris [acte] de votre engagement si vous êtes [sincères] dans votre foi.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxxiv{C'est Lui qui fait descendre sur Son serviteur des versets clairs, afin qu'il vous fasse sortir des ténèbres à la lumière; et assurément Allah est Compatissant envers vous, et Très Miséricordieux.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxxv{Et qu'avez-vous à ne pas dépenser dans le chemin d'Allah, alors que c'est à Allah que revient l'héritage des cieux et de la terre? On ne peut comparer cependant celui d'entre vous qui a donné ses biens et combattu avant la conquête... ces derniers sont plus hauts en hiérarchie que ceux qui ont dépensé et ont combattu après. Or, à chacun, Allah a promis la plus belle récompense, et Allah est Grand Connaisseur de ce que vous faites.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxxvi{Quiconque fait à Allah un prêt sincère, Allah le lui multiplie, et il aura une généreuse récompense.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxxvii{Le jour où tu verras les croyants et les croyantes, leur lumière courant devant eux et à leur droite; (on leur dira): «Voici une bonne nouvelle pour vous, aujourd'hui: des Jardins sous lesquels coulent les ruisseaux pour y demeurer éternellement». Tel est l'énorme succès.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxxviii{Le jour où les hypocrites, hommes et femmes, diront à ceux qui croient: «Attendez que nous empruntions [un peu] de votre lumière». Il sera dit: «Revenez en arrière, et cherchez de la lumière». C'est alors qu'on éleva entre eux une muraille ayant une porte dont l'intérieur contient la miséricorde, et dont la face apparente a devant elle le châtiment [l'Enfer].\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmlxxxix{«N'étions-nous pas avec vous?» leur crieront-ils. «Oui, répondront [les autres] mais vous vous êtes laissés tenter, vous avez comploté (contre les croyants) et vous avez douté et de vains espoirs vous ont trompés, jusqu'à ce que vînt l'ordre d'Allah. Et le séducteur [le diable] vous a trompés au sujet d'Allah.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmxc{Aujourd'hui donc, on n'acceptera de rançon ni de vous ni de ceux qui ont mécru. Votre asile est le Feu: c'est lui qui est votre compagnon inséparable. Et quelle mauvaise destination!\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmxci{Le moment n'est-il pas venu pour ceux qui ont cru, que leurs cœurs s'humilient à l'évocation d'Allah et devant ce qui est descendu de la vérité [le Coran]? Et de ne point être pareils à ceux qui ont reçu le Livre avant eux. Ceux-ci trouvèrent le temps assez long et leurs cœurs s'endurcirent, et beaucoup d'entre eux sont pervers.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmxcii{Sachez qu'Allah redonne la vie à la terre une fois morte. Certes, Nous vous avons exposé les preuves clairement afin que vous raisonniez.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmxciii{Ceux et celles qui font la charité et qui ont fait à Allah un prêt sincère, cela leur sera multiplié et ils auront une généreuse récompense.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmxciv{Ceux qui ont cru en Allah et en Ses messagers ceux-là sont les grands véridiques et les témoins auprès d'Allah. Ils auront leur récompense et leur lumière, tandis que ceux qui ont mécru et traité de mensonges Nos signes, ceux-là seront les gens de la Fournaise.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmxcv{Sachez que la vie présente n'est que jeu, amusement, vaine parure, une course à l'orgueil entre vous et une rivalité dans l'acquisition des richesses et des enfants. Elle est en cela pareille à une pluie: la végétation qui en vient émerveille les cultivateurs, puis elle se fane et tu la vois donc jaunie; ensuite elle devient des débris. Et dans l'au-delà, il y a un dur châtiment, et aussi pardon et agrément d'Allah. Et la vie présente n'est que jouissance trompeuse.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmxcvi{Hâtez-vous vers un pardon de votre Seigneur ainsi qu'un Paradis aussi large que le ciel et la terre, préparé pour ceux qui ont cru en Allah et en Ses Messagers. Telle est la grâce d'Allah qu'Il donne à qui Il veut. Et Allah est le Détenteur de l'énorme grâce.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmxcvii{Nul malheur n'atteint la terre ni vos personnes, qui ne soit enregistré dans un Livre avant que Nous ne l'ayons créé; et cela est certes facile à Allah,\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmxcviii{afin que vous ne vous tourmentiez pas au sujet de ce qui vous a échappé, ni n'exultiez pour ce qu'Il vous a donné. Et Allah n'aime point tout présomptueux plein de gloriole.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmxcix{Ceux qui sont avares et ordonnent aux gens l'avarice. Et quiconque se détourne... Allah Se suffit alors à Lui-même et Il est Digne de louange.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmc{Nous avons effectivement envoyé Nos Messagers avec des preuves évidentes, et fait descendre avec eux le Livre et la balance, afin que les gens établissent la justice. Et Nous avons fait descendre le fer, dans lequel il y a une force redoutable, aussi bien que des utilités pour les gens, et pour qu'Allah reconnaisse qui, dans l'Invisible, défendra Sa cause et celle de Ses Messagers. Certes, Allah est Fort et Puissant.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmci{Nous avons effectivement envoyé Noé et Abraham et accordé à leur descendance la prophétie et le Livre. Certains d'entre eux furent bien-guidés, tandis que beaucoup d'entre eux furent pervers.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmcii{Ensuite, sur leurs traces, Nous avons fait suivre Nos [autres] messagers, et Nous les avons fait suivre de Jésus fils de Marie et lui avons apporté l'Evangile, et mis dans les cœurs de ceux qui le suivirent douceur et mansuétude. Le monachisme qu'ils inventèrent, Nous ne le leur avons nullement prescrit. [Ils devaient] seulement rechercher l'agrément d'Allah. Mais ils ne l'observèrent pas (ce monachisme) comme il se devait. Nous avons donné leur récompense à ceux d'entre eux qui crurent. Mais beaucoup d'entre eux furent des pervers.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmciii{O Vous qui avez cru! Craignez Allah et croyez en Son messager pour qu'Il vous accorde deux parts de Sa miséricorde, et qu'Il vous assigne une lumière à l'aide de laquelle vous marcherez, et qu'Il vous pardonne, car Allah est Pardonneur et Très Miséricordieux.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmciv{Cela afin que les gens du Livre sachent qu'ils ne peuvent en rien disposer de la grâce d'Allah et que la grâce est dans la main d'Allah. Il la donne à qui Il veut, et Allah est le Détenteur de la grâce immense.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmcv{\basmalahfr Allah a bien entendu la parole de celle qui discutait avec toi à propos de son époux et se plaignait à Allah. Et Allah entendait votre conversation, car Allah est Audient et Clairvoyant.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcvi{Ceux d'entre vous qui répudient leurs femmes, en déclarant qu'elles sont pour eux comme le dos de leurs mères. alors qu'elles ne sont nullement leurs mères, car ils n'ont pour mères que celles qui les ont enfantés. Ils prononcent certes une parole blâmable et mensongère. Allah cependant est Indulgent et Pardonneur.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcvii{Ceux qui comparent leurs femmes au dos de leurs mères puis reviennent sur ce qu'ils ont dit, doivent affranchir un esclave avant d'avoir aucun contact [conjugal] avec leur femme. C'est ce dont on vous exhorte. Et Allah est Parfaitement Connaisseur de ce que vous faites\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcviii{Mais celui qui n'en trouve pas les moyens doit jeûner alors deux mois consécutifs avant d'avoir aucun contact [conjugal] avec sa femme. Mais s'il ne peut le faire non plus, alors qu'il nourrisse soixante pauvres. Cela, pour que vous croyiez en Allah et en Son messager. Voilà les limites imposées par Allah. Et les mécréants auront un châtiment douloureux.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcix{Ceux qui s'opposent à Allah et à Son messager seront culbutés comme furent culbutés leurs devanciers. Nous avons déjà fait descendre des preuves explicites, et les mécréants auront un châtiment avilissant,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcx{le jour où Allah les ressuscitera tous, puis les informera de ce qu'ils ont fait Allah l'a dénombré et ils l'auront oublié. Allah est témoin de toute chose.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcxi{Ne vois-tu pas qu'Allah sait ce qui est dans les cieux et sur la terre? Pas de conversation secrète entre trois sans qu'Il ne soit leur quatrième, ni entre cinq sans qu'Il n'y ne soit leur sixième, ni moins ni plus que cela sans qu'Il ne soit avec eux, là où ils se trouvent. Ensuite, Il les informera au Jour de la Résurrection, de ce qu'ils faisaient, car Allah est Omniscient.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcxii{Ne vois-tu pas ceux à qui les conversations secrètes ont été interdites? Puis, ils retournent à ce qui leur a été interdit, et se concertent pour pécher, transgresser et désobéir au Messager. Et quand ils viennent à toi, ils te saluent d'une façon dont Allah ne t'a pas salué, et disent en eux-mêmes: «Pourquoi Allah ne nous châtie pas pour ce que nous disons?» L'Enfer leur suffira, où ils brûleront. Et quelle mauvaise destination!\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcxiii{O vous qui avez cru! Quand vous tenez des conversations secrètes, ne vous concertez pas pour pécher, transgresser et désobéir au Messager, mais concertez-vous dans la bonté et la piété. Et craignez Allah vers qui vous serez rassemblés.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcxiv{La conversation secrète n'est que [l'œuvre] du Diable pour attrister ceux qui ont cru. Mais il ne peut leur nuire en rien sans la permission d'Allah. Et c'est en Allah que les croyants doivent placer leur confiance.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcxv{O vous qui avez cru! Quand on vous dit: «Faites place [aux autres] dans les assemblées», alors faites place. Allah vous ménagera une place (au Paradis). Et quand on vous dit de vous lever, levez-vous. Allah élèvera en degrés ceux d'entre vous qui auront cru et ceux qui auront reçu le savoir. Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcxvi{O vous qui avez cru! Quand vous avez un entretien confidentiel avec le Messager, faites précéder d'une aumône votre entretien: cela est meilleur pour vous et plus pur. Mais si vous n'en trouvez pas les moyens alors Allah est Pardonneur et très Miséricordieux!\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcxvii{Appréhendez-vous de faire précéder d'aumônes votre entretien? Mais, si vous ne l'avez pas fait et qu'Allah a accueilli votre repentir, alors accomplissez la Salât, acquittez la Zakât, et obéissez à Allah et à Son messager. Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcxviii{N'as-tu pas vu ceux qui ont pris pour alliés des gens contre qui Allah S'est courroucé? Ils ne sont ni des vôtres, ni des leurs; et ils jurent mensongèrement, alors qu'ils savent.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcxix{Allah leur a préparé un dur châtiment. Ce qu'ils faisaient alors était très mauvais.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcxx{Prenant leurs serments comme boucliers, ils obstruent le chemin d'Allah. Ils auront donc un châtiment avilissant.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxi{Ni leurs biens, ni leurs enfants ne leur seront d'aucune utilité contre la [punition] d'Allah. Ce sont les gens du Feu où ils demeureront éternellement.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxii{Le jour où Allah les ressuscitera tous, ils Lui jureront alors comme ils vous jurent à vous-mêmes, pensant s'appuyer sur quelque chose de solide. Mais ce sont eux les menteurs.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxiii{Le Diable les a dominés et leur a fait oublier le rappel d'Allah. Ceux-là sont le parti du Diable et c'est le parti du Diable qui sont assurément les perdants.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxiv{Ceux qui s'opposent à Allah et à Son messager seront parmi les plus humiliés.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxv{Allah a prescrit: «Assurément, Je triompherai, Moi ainsi que Mes Messagers». En vérité Allah est Fort et Puissant.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxvi{Tu n'en trouveras pas, parmi les gens qui croient en Allah et au Jour dernier, qui prennent pour amis ceux qui s'opposent à Allah et à Son Messager, fussent-ils leurs pères, leurs fils, leurs frères ou les gens de leur tribu. Il a prescrit la foi dans leurs cœurs et Il les a aidés de Son secours. Il les fera entrer dans des Jardins sous lesquels coulent les ruisseaux, où ils demeureront éternellement. Allah les agrée et ils L'agréent. Ceux-là sont le parti d'Allah. Le parti d'Allah est celui de ceux qui réussissent.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxvii{\basmalahfr Ce qui est dans les cieux et ce qui est sur la terre glorifient Allah, et Il est le Puissant, le Sage.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxviii{C'est Lui qui a expulsé de leurs maisons, ceux parmi les gens du Livre qui ne croyaient pas, lors du premier exode. Vous ne pensiez pas qu'ils partiraient, et ils pensaient qu'en vérité leurs forteresses les défendraient contre Allah. Mais Allah est venu à eux par où ils ne s'attendaient point, et a lancé la terreur dans leurs cœurs. Ils démolissaient leurs maisons de leurs propres mains, autant que des mains des croyants. Tirez-en une leçon, ô vous qui êtes doués de clairvoyance.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxix{Et si Allah n'avait pas prescrit contre eux l'expatriation, Il les aurait certainement châtiés ici-bas; et dans l'au-delà ils auront le châtiment du feu.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxx{Il en est ainsi parce qu'ils se sont dressés contre Allah et Son messager. Et quiconque se dresse contre Allah... alors, vraiment Allah est dur en punition.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxxi{Tout palmier que vous avez coupé ou que vous avez laissé debout sur ses racines, c'est avec la permission d'Allah et afin qu'Il couvre ainsi d'ignominie les pervers.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxxii{Le butin provenant de leurs biens et qu'Allah a accordé sans combat à Son Messager, vous n'y aviez engagé ni chevaux, ni chameaux; mais Allah, donne à Ses messagers la domination sur qui Il veut et Allah est Omnipotent.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxxiii{Le butin provenant [des biens] des habitants des cités, qu'Allah a accordé sans combat à Son Messager, appartient à Allah, au Messager, aux proches parents, aux orphelins, aux pauvres et au voyageur en détresse, afin que cela ne circule pas parmi les seuls riches d'entre vous. Prenez ce que le Messager vous donne; et ce qu'il vous interdit, abstenez-vous en; et craignez Allah car Allah est dur en punition.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxxiv{[Il appartient aussi] aux émigrés besogneux qui ont été expulsés de leurs demeures et de leurs biens, tandis qu'ils recherchaient une grâce et un agrément d'Allah, et qu'ils portaient secours à (la cause d') Allah et à Son Messager. Ceux-là sont les véridiques.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxxv{Il [appartient également] à ceux qui, avant eux, se sont installés dans le pays et dans la foi, qui aiment ceux qui émigrent vers eux, et ne ressentent dans leurs cœurs aucune envie pour ce que [ces immigrés] ont reçu, et qui [les] préfèrent à eux-mêmes, même s'il y a pénurie chez eux. Quiconque se prémunit contre sa propre avarice, ceux-là sont ceux qui réussissent.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxxvi{Et [il appartient également] à ceux qui sont venus après eux en disant: «Seigneur, pardonne-nous, ainsi qu'à nos frères qui nous ont précédés dans la foi; et ne mets dans nos cœurs aucune rancœur pour ceux qui ont cru. Seigneur, Tu es Compatissant et Très Miséricordieux».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxxvii{N'as-tu pas vu les hypocrites disant à leurs confrères qui ont mécru parmi les gens du Livre: «Si vous êtes chassés, nous partirons certes avec vous et nous n'obéirons jamais à personne contre vous; et si vous êtes attaqués, nous vous secourrons certes». Et Allah atteste qu'en vérité ils sont des menteurs.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxxviii{S'ils sont chassés, ils ne partiront pas avec eux; et s'ils sont attaqués, ils ne les secourront pas; et même s'ils allaient à leur secours, ils tourneraient sûrement le dos; puis ils ne seront point secourus.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcxxxix{Vous jetez dans leurs cœurs plus de terreur qu'Allah. C'est qu'ils sont des gens qui ne comprennent pas.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcxl{Tous ne vous combattront que retranchés dans des cités fortifiées ou de derrière des murailles. Leurs dissensions internes sont extrêmes. Tu les croirait unis, alors que leurs cœurs sont divisés. C'est qu'ils sont des gens qui ne raisonnent pas.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcxli{Ils sont semblables à ceux qui, peu de temps avant eux, ont goûté la conséquence de leur comportement et ils auront un châtiment douloureux;\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcxlii{ils sont semblables au Diable quand il dit à l'homme: «Sois incrédule». Puis quand il a mécru, il dit: «Je te désavoue car je redoute Allah, le Seigneur de l'Univers».\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcxliii{Ils eurent pour destinée d'être tous deux dans le Feu pour y demeurer éternellement. Telle est la rétribution des injustes.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcxliv{O vous qui avez cru! Craignez Allah. Que chaque âme voit bien ce qu'elle a avancé pour demain. Et craignez Allah, car Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcxlv{Et ne soyez pas comme ceux qui ont oublié Allah; [Allah] leur a fait alors oublier leurs propres personnes; ceux-là sont les pervers.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcxlvi{Ne seront pas égaux les gens du Feu et les gens du Paradis. Les gens du Paradis sont eux les gagnants.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcxlvii{Si Nous avions fait descendre ce Coran sur une montagne, tu l'aurais vu s'humilier et se fendre par crainte d'Allah. Et ces paraboles Nous les citons aux gens afin qu'ils réfléchissent.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcxlviii{C'est Lui Allah. Nulle divinité autre que Lui, le Connaisseur de l'Invisible tout comme du visible. C'est Lui, le Tout Miséricordieux, le Très Miséricordieux.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcxlix{C'est Lui, Allah. Nulle divinité autre que Lui; Le Souverain, Le Pur, L'Apaisant, Le Rassurant, Le Prédominant, Le Tout Puissant, Le Contraignant, L'Orgueilleux. Gloire à Allah! Il transcende ce qu'ils Lui associent.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmcl{C'est Lui Allah, le Créateur, Celui qui donne un commencement à toute chose, le Formateur. A Lui les plus beaux noms. Tout ce qui est dans les cieux et la terre Le glorifie. Et c'est Lui le Puissant, le Sage.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmcli{\basmalahfr O vous qui avez cru! Ne prenez pas pour alliés Mon ennemi et le vôtre, leur offrant l'amitié, alors qu'ils ont nié ce qui vous est parvenu de la vérité. Ils expulsent le Messager et vous-mêmes parce que vous croyez en Allah, votre Seigneur. Si vous êtes sortis pour lutter dans Mon chemin et pour rechercher Mon agrément, leur témoignerez-vous secrètement de l'amitié, alors que Je connais parfaitement ce que vous cachez et ce que vous divulguez? Et quiconque d'entre vous le fait s'égare de la droiture du sentier.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmclii{S'ils vous dominent, ils seront des ennemis pour vous et étendront en mal leurs mains et leurs langues vers vous; et ils aimeraient que vous deveniez mécréants.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcliii{Ni vos proches parents ni vos enfants ne vous seront d'aucune utilité le Jour de la Résurrection, Il [Allah] décidera entre vous, et Allah est Clairvoyant sur ce que vous faites.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcliv{Certes, vous avez eu un bel exemple [à suivre] en Abraham et en ceux qui étaient avec lui, quand ils dirent à leur peuple: «Nous vous désavouons, vous et ce que vous adorez en dehors d'Allah. Nous vous renions. Entre vous et nous, l'inimitié et la haine sont à jamais déclarées jusqu'à ce que vous croyiez en Allah, seul». Exception faite de la parole d'Abraham [adressée] à son père: «J'implorerai certes, le pardon [d'Allah] en ta faveur bien que je ne puisse rien pour toi auprès d'Allah». «Seigneur, c'est en Toi que nous mettons notre confiance et à Toi nous revenons [repentants]. Et vers Toi est le Devenir.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmclv{Seigneur, ne fais pas de nous [un sujet] de tentation pour ceux qui ont mécru; et pardonne-nous, Seigneur, car c'est Toi le Puissant, le Sage».\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmclvi{Vous avez certes eu en eux un bel exemple [à suivre], pour celui qui espère en Allah et en le Jour dernier; mais quiconque se détourne... alors Allah Se suffit à Lui-même et est Digne de louange.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmclvii{Il se peut qu'Allah établisse de l'amitié entre vous et ceux d'entre eux dont vous avez été les ennemis. Et Allah est Omnipotent et Allah est Pardonneur et Très Miséricordieux.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmclviii{Allah ne vous défend pas d'être bienfaisants et équitables envers ceux qui ne vous ont pas combattus pour la religion et ne vous ont pas chassés de vos demeures. Car Allah aime les équitables.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmclix{Allah vous défend seulement de prendre pour alliés ceux qui vous ont combattus pour la religion, chassés de vos demeures et ont aidé à votre expulsion. Et ceux qui les prennent pour alliés sont les injustes.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmclx{O vous qui avez cru! Quand les croyantes viennent à vous en émigrées, éprouvez-les; Allah connaît mieux leur foi; si vous constatez qu'elles sont croyantes, ne les renvoyez pas aux mécréants. Elles ne sont pas licites [en tant qu'épouses] pour eux, et eux non plus ne sont pas licites [en tant qu'époux] pour elles. Et rendez-leur ce qu'ils ont dépensé (comme mahr). Il ne vous sera fait aucun grief en vous mariant avec elles quand vous leur aurez donné leur mahr. Et ne gardez pas de liens conjugaux avec les mécréantes. Réclamez ce que vous avez dépensé et que (les mécréants) aussi réclament ce qu'ils ont dépensé. Tel est le jugement d'Allah par lequel Il juge entre vous, et Allah est Omniscient et Sage.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmclxi{Et si quelqu'une de vos épouses s'échappe vers les mécréants, et que vous fassiez des représailles, restituez à ceux dont les épouses sont parties autant que ce qu'ils avaient dépensé. Craignez Allah en qui vous croyez.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmclxii{O Prophète! Quand les croyantes viennent te prêter serment d'allégeance, [et en jurent] qu'elles n'associeront rien à Allah, qu'elles ne voleront pas, qu'elles ne se livreront pas à l'adultère, qu'elles ne tueront pas leurs propres enfants, qu'elles ne commettront aucune infamie ni avec leurs mains ni avec leurs pieds et qu'elles ne désobéiront pas en ce qui est convenable, alors reçois leur serment d'allégeance, et implore d'Allah le pardon pour elles. Allah est certes, Pardonneur et Très Miséricordieux.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmclxiii{O vous qui avez cru! Ne prenez pas pour alliés des gens contre lesquels Allah est courroucé et qui désespèrent de l'au-delà, tout comme les mécréants désespèrent des gens des tombeaux.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmclxiv{\basmalahfr Ce qui est dans les cieux et ce qui est sur la terre glorifient Allah, et Il est le Puissant, le Sage.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmclxv{O vous qui avez cru! Pourquoi dites-vous ce que vous ne faites pas?\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmclxvi{C'est une grande abomination auprès d'Allah que de dire ce que vous ne faites pas.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmclxvii{Allah aime ceux qui combattent dans Son chemin en rang serré pareils à un édifice renforcé.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmclxviii{Et quand Moïse dit à son peuple: «O mon peuple! Pourquoi me maltraitez-vous alors que vous savez que je suis vraiment le Messager d'Allah [envoyé] à vous?» Puis quand ils dévièrent, Allah fit dévier leurs cœurs, car Allah ne guide pas les gens pervers.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmclxix{Et quand Jésus fils de Marie dit: «O Enfants d'Israël, je suis vraiment le Messager d'Allah [envoyé] à vous, confirmateur de ce qui, dans la Thora, est antérieur à moi, et annonciateur d'un Messager à venir après moi, dont le nom sera «Ahmad». Puis quand celui-ci vint à eux avec des preuves évidentes, ils dirent: «C'est là une magie manifeste».\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmclxx{Et qui est plus injuste que celui qui invente un mensonge contre Allah, alors qu'il est appelé à l'Islam? Et Allah ne guide pas les gens injustes.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxi{Ils veulent éteindre de leurs bouches la lumière d'Allah, alors qu'Allah parachèvera Sa lumière en dépit de l'aversion des mécréants.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxii{C'est Lui qui a envoyé Son messager avec la guidée et la Religion de Vérité, pour la placer au-dessus de toute autre religion, en dépit de l'aversion des associateurs.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxiii{O vous qui avez cru! vous indiquerai-je un commerce qui vous sauvera d'un châtiment douloureux?\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxiv{Vous croyez en Allah et en Son messager et vous combattez avec vos biens et vos personnes dans le chemin d'Allah, et cela vous est bien meilleur, si vous saviez!\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxv{Il vous pardonnera vos péchés et vous fera entrer dans des Jardins sous lesquels coulent les ruisseaux, et dans des demeures agréables dans les jardins d'Eden. Voilà l'énorme succès\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxvi{et Il vous accordera d'autres choses encore que vous aimez bien: un secours [venant] d'Allah et une victoire prochaine. Et annonce la bonne nouvelle aux croyants.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxvii{O vous qui avez cru! Soyez les alliés d'Allah, à l'instar de ce que Jésus fils de Marie a dit aux apôtres: «Qui sont mes alliés (pour la cause) d'Allah?» - Les apôtres dirent: «Nous sommes les alliés d'Allah». Un groupe des Enfants d'Israël crut, tandis qu'un groupe nia. Nous aidâmes donc ceux qui crurent contre leur ennemi, et ils triomphèrent.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxviii{\basmalahfr Ce qui est dans les cieux et ce qui est sur la terre glorifient Allah, le Souverain, le Pur, le Puissant, le Sage.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxix{C'est Lui qui a envoyé à des gens sans Livre (les Arabes) un Messager des leurs qui leur récite Ses versets, les purifie et leur enseigne le Livre et la Sagesse, bien qu'ils étaient auparavant dans un égarement évident,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxx{ainsi qu'à d'autres parmi ceux qui ne les ont pas encore rejoints. C'est Lui le Puissant, le Sage.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxxi{Telle est la grâce d'Allah qu'Il donne à qui Il veut. Et Allah est le Détenteur de l'énorme grâce.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxxii{Ceux qui ont été chargés de la Thora mais qui ne l'ont pas appliquée sont pareils à l'âne qui porte des livres. Quel mauvais exemple que celui de ceux qui traitent de mensonges les versets d'Allah et Allah ne guide pas les gens injustes.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxxiii{Dis: «O vous qui pratiquez le judaïsme! Si vous prétendez être les bien-aimés d'Allah à l'exclusion des autres, souhaitez, donc la mort, si vous êtes véridiques».\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxxiv{Or, ils ne la souhaiteront jamais, à cause de ce que leurs mains ont préparé. Allah cependant connaît bien les injustes.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxxv{Dis: «La mort que vous fuyez va certes vous rencontrer. Ensuite vous serez ramenés à Celui qui connaît parfaitement le monde Invisible et le monde visible et qui vous informera alors de ce que vous faisiez».\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxxvi{O vous qui avez cru! Quand on appelle à la Salât du jour du Vendredi, accourez à l'invocation d'Allah et laissez tout négoce. Cela est bien meilleur pour vous, si vous saviez!\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxxvii{Puis quand la Salât est achevée, dispersez-vous sur terre et recherchez [quelque effet] de la grâce d'Allah, et invoquez beaucoup Allah afin que vous réussissiez.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxxviii{Quand ils entrevoient quelque commerce ou quelque divertissement, ils s'y dispersent et te laissent debout. Dis: «Ce qui est auprès d'Allah est bien meilleur que le divertissement et le commerce, et Allah est le Meilleur des pourvoyeurs».\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmclxxxix{\basmalahfr Quand les hypocrites viennent à toi, ils disent: «Nous attestons que tu es certes le Messager d'Allah» Allah sait que tu es vraiment Son messager; et Allah atteste que les hypocrites sont assurément des menteurs.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcxc{Ils prennent leurs serments pour bouclier et obstruent le chemin d'Allah. Quelles mauvaises choses que ce qu'ils faisaient!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcxci{C'est parce qu'en vérité ils ont cru, puis rejeté la foi. Leurs cœurs donc, ont été scellés, de sorte qu'ils ne comprennent rien.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcxcii{Et quand tu les vois, leurs corps t'émerveillent; et s'ils parlent tu écoutes leur parole. Ils sont comme des bûches appuyées (contre des murs) et ils pensent que chaque cri est dirigé contre eux. L'ennemi c'est eux. Prends y garde. Qu'Allah les extermine! Comme les voilà détournés (du droit chemin).\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcxciii{Et quand on leur dit: «Venez que le Messager d'Allah implore le pardon pour vous», ils détournent leurs têtes, et tu les vois se détourner tandis qu'ils s'enflent d'orgueil.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcxciv{C'est égal, pour eux, que tu implores le pardon pour eux ou que tu ne le fasses pas: Allah ne leur pardonnera jamais, car Allah ne guide pas les gens pervers.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcxcv{Ce sont eux qui disent: «Ne dépensez point pour ceux qui sont auprès du Messager d'Allah, afin qu'ils se dispersent». Et c'est à Allah qu'appartiennent les trésors des cieux et de la terre, mais les hypocrites ne comprennent pas.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcxcvi{Ils disent: «Si nous retournons à Médine, le plus puissant en fera assurément sortir le plus humble». Or c'est à Allah qu'est la puissance ainsi qu'à Son messager et aux croyants. Mais les hypocrites ne le savent pas.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcxcvii{O vous qui avez cru! Que ni vos biens ni vos enfants ne vous distraient du rappel d'Allah. Et quiconque fait cela... alors ceux-là seront les perdants.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcxcviii{Et dépensez de ce que Nous vous avons octroyé avant que la mort ne vienne à l'un de vous et qu'il dise alors: «Seigneur! si seulement Tu m'accordais un court délai: je ferais l'aumône et serais parmi les gens de bien».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcxcix{Allah cependant n'accorde jamais de délai à une âme dont le terme est arrivé. Et Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcc{\basmalahfr Ce qui est dans les cieux et ce qui est sur la terre glorifient Allah. A Lui la royauté et à Lui les louanges. Et Il est Omnipotent.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcci{C'est Lui qui vous a créés. Parmi vous [il y a] mécréant et croyant. Allah observe parfaitement ce que vous faites.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmccii{Il a créé les cieux et la terre en toute vérité et vous a donné votre forme et quelle belle forme Il vous a donnée! Et vers Lui est le devenir.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcciii{Il sait ce qui est dans les cieux et la terre, et Il sait ce que vous cachez ainsi que ce que vous divulguez. Et Allah connaît bien le contenu des poitrines.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcciv{Ne vous est-elle pas parvenue, la nouvelle de ceux qui auparavant ont mécru et qui ont goûté la conséquence néfaste de leur acte; ils auront en outre un châtiment douloureux.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmccv{Il en est ainsi parce que leurs messagers leur venaient avec des preuves évidentes, et qu'ils ont dit: «Sont-ce des hommes qui nous guideront?» Ils mécrurent alors et se détournèrent et Allah Se passa [d'eux] et Allah Se suffit à Lui-même et Il est Digne de louange.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmccvi{Ceux qui ont mécru prétendent qu'ils ne seront point ressuscités. Dis: «Mais si! Par mon Seigneur! Vous serez très certainement ressuscités; puis vous serez certes informés de ce que vous faisiez. Et cela est facile pour Allah».\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmccvii{Croyez en Allah donc et en Son messager, ainsi qu'en la Lumière [le Coran] que Nous avons fait descendre. Et Allah est Parfaitement Connaisseur de ce que vous faites.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmccviii{Le jour où Il vous réunira pour le jour du Rassemblement, ce sera le jour de la grande perte. Et celui qui croit en Allah et accomplit les bonnes œuvres, Il lui effacera ses mauvaises actions et le fera entrer dans des Jardins sous lesquels coulent les ruisseaux où ils demeureront éternellement. Voilà l'énorme succès!\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmccix{Et ceux qui ont mécru et traité de mensonges Nos versets, ceux-là sont les gens du Feu où ils demeureront éternellement. Et quelle mauvaise destination!\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmccx{Nul malheur n'atteint [l'homme] que par la permission d'Allah. Et quiconque croit en Allah, [Allah] guide son cœur. Allah est Omniscient.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmccxi{Obéissez à Allah et obéissez au Messager et si vous vous détournez... il n'incombe à Notre messager que de transmettre en clair (son message).\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmccxii{Allah nulle autre divinité que Lui! Et c'est à Allah que les croyants [doivent] s'en remettre.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmccxiii{O vous qui avez cru, vous avez de vos épouses et de vos enfants un ennemi [une tentation]. Prenez-y garde donc. Mais si vous [les] excusez, passez sur [leurs] fautes et [leur] pardonnez, sachez qu'Allah est Pardonneur, Très Miséricordieux.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmccxiv{Vos biens et vos enfants ne sont qu'une tentation, alors qu'auprès d'Allah est une énorme récompense.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmccxv{Craignez Allah, donc autant que vous pouvez, écoutez, obéissez et faites largesses. Ce sera un bien pour vous. Et quiconque a été protégé contre sa propre avidité... ceux-là sont ceux qui réussissent.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmccxvi{Si vous faites à Allah un prêt sincère, Il le multipliera pour vous et vous pardonnera. Allah cependant est très Reconnaissant et Indulgent.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmccxvii{Il est le Connaisseur du monde Invisible et visible, et Il est le Puissant, le Sage.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmccxviii{\basmalahfr O Prophète! Quand vous répudiez les femmes, répudiez-les conformément à leur période d'attente prescrite; et comptez la période; et craignez Allah votre Seigneur. Ne les faites pas sortir de leurs maisons, et qu'elles n'en sortent pas, à moins qu'elles n'aient commis une turpitude prouvée. Telles sont les lois d'Allah. Quiconque cependant transgresse les lois d'Allah, se fait du tort à lui-même. Tu ne sais pas si d'ici là Allah ne suscitera pas quelque chose de nouveau!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmccxix{Puis quand elles atteignent le terme prescrit, retenez-les de façon convenable, ou séparez-vous d'elles de façon convenable; et prenez deux hommes intègres parmi vous comme témoins. Et acquittez-vous du témoignage envers Allah. Voilà ce à quoi est exhorté celui qui croit en Allah et au Jour dernier. Et quiconque craint Allah, Il Lui donnera une issue favorable,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmccxx{et lui accordera Ses dons par [des moyens] sur lesquels il ne comptait pas. Et quiconque place sa confiance en Allah, Il [Allah] lui suffit. Allah atteint ce qu'Il Se propose, et Allah a assigné une mesure à chaque chose.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxi{Si vous avez des doutes à propos (de la période d'attente) de vos femmes qui n'espèrent plus avoir de règles, leur délai est de trois mois. De même pour celles qui n'ont pas encore de règles. Et quant à celles qui sont enceintes, leur période d'attente se terminera à leur accouchement. Quiconque craint Allah cependant, Il lui facilite les choses.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxii{Tel est le commandement d'Allah qu'Il a fait descendre vers vous. Quiconque craint Allah cependant, Il lui efface ses fautes et lui accorde une grosse récompense.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxiii{Et faites que ces femmes habitent où vous habitez, et suivant vos moyens. Et ne cherchez pas à leur nuire en les contraignant à vivre à l'étroit. Et si elles sont enceintes, pourvoyez à leurs besoins jusqu'à ce qu'elles aient accouché. Puis, si elles allaitent [l'enfant né] de vous, donnez-leur leurs salaires. Et concertez vous [à ce sujet] de façon convenable. Et si vous rencontrez des difficultés réciproques, alors, une autre allaitera pour lui.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxiv{Que celui qui est aisé dépense de sa fortune; et que celui dont les biens sont restreints dépense selon ce qu'Allah lui a accordé. Allah n'impose à personne que selon ce qu'Il lui a donné, et Allah fera succéder l'aisance à la gêne.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxv{Que de cités ont refusé avec insolence le commandement de leur Seigneur et de Ses messagers! Nous leur en demandâmes compte avec sévérité, et les châtiâmes d'un châtiment inouï.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxvi{Elles goûtèrent donc la conséquence de leur comportement. Et le résultat final de leurs actions fut [leur] perdition.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxvii{Allah a préparé pour eux un dur châtiment. Craignez Allah donc, ô vous qui êtes doués d'intelligence, vous qui avez la foi. Certes, Allah a fait descendre vers vous un rappel,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxviii{un Messager qui vous récite les versets d'Allah comme preuves claires, afin de faire sortir ceux qui croient et accomplissent les bonnes œuvres des ténèbres à la lumière. Et quiconque croit en Allah et fait le bien, Il le fait entrer aux Jardins sous lesquels coulent les ruisseaux, pour y demeurer éternellement. Allah lui a fait une belle attribution.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxix{Allah qui a créé sept cieux et autant de terres. Entre eux [Son] commandement descend, afin que vous sachiez qu'Allah est en vérité Omnipotent et qu'Allah a embrassé toute chose de [Son] savoir.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxx{\basmalahfr O Prophète! Pourquoi, en recherchant l'agrément de tes femmes, t'interdis-tu ce qu'Allah t'a rendu licite? Et Allah est Pardonneur, Très Miséricordieux.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxxi{Allah vous a prescrit certes, de vous libérer de vos serments. Allah est votre Maître; et c'est Lui l'Omniscient, le Sage.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxxii{Lorsque le Prophète confia un secret à l'une de ses épouses et qu'elle l'eut divulgué et qu'Allah l'en eut informé, celui-ci en fit connaître une partie et passa sur une partie. Puis, quand il l'en eut informée elle dit: «Qui t'en a donné nouvelle?» Il dit: «C'est l'Omniscient, le Parfaitement Connaisseur qui m'en a avisé».\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxxiii{Si vous vous repentez à Allah c'est que vos cœurs ont fléchi. Mais si vous vous soutenez l'une l'autre contre le Prophète, alors ses alliés seront Allah, Gabriel et les vertueux d'entre les croyants, et les Anges sont par surcroît [son] soutien.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxxiv{S'Il vous répudie, il se peut que son Seigneur lui donne en échange des épouses meilleures que vous, musulmanes, croyantes, obéissantes, repentantes, adoratrices, jeûneuses, déjà mariées ou vierges.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxxv{O vous qui avez cru! Préservez vos personnes et vos familles, d'un Feu dont le combustible sera les gens et les pierres, surveillé par des Anges rudes, durs, ne désobéissant jamais à Allah en ce qu'Il leur commande, et faisant strictement ce qu'on leur ordonne.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxxvi{O vous qui avez mécru! Ne vous excusez pas aujourd'hui. Vous ne serez rétribués que selon ce que vous œuvriez.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxxvii{O vous qui avez cru! Repentez-vous à Allah d'un repentir sincère. Il se peut que votre Seigneur vous efface vos fautes et qu'Il vous fasse entrer dans des Jardins sous lesquels coulent les ruisseaux, le jour où Allah épargnera l'ignominie au Prophète et à ceux qui croient avec lui. Leur lumière courra devant eux et à leur droite; ils diront: «Seigneur, parfais-nous notre lumière et pardonne-nous. Car Tu es Omnipotent».\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxxviii{O Prophète! Mène la lutte contre les mécréants et les hypocrites et sois rude à leur égard. Leur refuge sera l'Enfer, et quelle mauvaise destination!\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmccxxxix{Allah a cité en parabole pour ceux qui ont mécru la femme de Noé et la femme de Lot. Elles étaient sous l'autorité de deux vertueux de Nos serviteurs. Toutes deux les trahirent et ils ne furent d'aucune aide pour [ces deux femmes] vis-à-vis d'Allah. Et il [leur] fut dit: «Entrez au Feu toutes les deux, avec ceux qui y entrent»,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmccxl{et Allah a cité en parabole pour ceux qui croient, la femme de Pharaon, quand elle dit «Seigneur, construis-moi auprès de Toi une maison dans le Paradis, et sauve-moi de Pharaon et de son œuvre; et sauve-moi des gens injustes».\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmccxli{De même, Marie, la fille d''Imran qui avait préservé sa virginité; Nous y insufflâmes alors de Notre Esprit. Elle avait déclaré véridiques les paroles de son Seigneur ainsi que Ses Livres: elle fut parmi les dévoués.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmccxlii{\basmalahfr Béni soit celui dans la main de qui est la royauté, et Il est Omnipotent.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmccxliii{Celui qui a créé la mort et la vie afin de vous éprouver (et de savoir) qui de vous est le meilleur en œuvre, et c'est Lui le Puissant, le Pardonneur.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmccxliv{Celui qui a créé sept cieux superposés sans que tu voies de disproportion en la création du Tout Miséricordieux. Ramène [sur elle] le regard. Y vois-tu une brèche quelconque?\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmccxlv{Puis, retourne ton regard à deux fois: le regard te reviendra humilié et frustré.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmccxlvi{Nous avons effectivement embelli le ciel le plus proche avec des lampes [des étoiles] dont Nous avons fait des projectiles pour lapider les diables et Nous leur avons préparé le châtiment de la Fournaise.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmccxlvii{Ceux qui ont mécru à leur Seigneur auront le châtiment de l'Enfer. Et quelle mauvaise destination!\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmccxlviii{Quand ils y seront jetés, ils lui entendront un gémissement, tandis qu'il bouillonne.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmccxlix{Peu s'en faut que, de rage, il n'éclate. Toutes les fois qu'un groupe y est jeté, ses gardiens leur demandent: «Quoi! ne vous est-il pas venu d'avertisseur?»\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmccl{Ils dirent: «Mais si! un avertisseur nous était venu certes, mais nous avons crié au mensonge et avons dit: Allah n'a rien fait descendre: vous n'êtes que dans un grand égarement».\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmccli{Et ils dirent: «Si nous avions écouté ou raisonné, nous ne serions pas parmi les gens de la Fournaise».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcclii{Ils ont reconnu leur péché. Que les gens de la Fournaise soient anéantis à jamais.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmccliii{Ceux qui redoutent leur Seigneur bien qu'ils ne L'aient jamais vu auront un pardon et une grande récompense.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmccliv{Que vous cachiez votre parole ou la divulguiez Il connaît bien le contenu des poitrines.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcclv{Ne connaît-Il pas ce qu'Il a créé alors que c'est Lui le Compatissant, le Parfaitement Connaisseur.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcclvi{C'est Lui qui vous a soumis la terre: parcourez donc ses grandes étendues. Mangez de ce qu'Il vous fournit. Vers Lui est la Résurrection.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcclvii{Etes-vous à l'abri que Celui qui est au ciel vous enfouisse en la terre? Et voici qu'elle tremble!\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcclviii{Ou êtes-vous à l'abri que Celui qui est au ciel envoie contre vous un ouragan de pierres? Vous saurez ainsi quel fut Mon avertissement.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcclix{En effet, ceux d'avant eux avaient crié au mensonge. Quelle fut alors Ma réprobation!\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcclx{N'ont-ils pas vu les oiseaux au-dessus d'eux, déployant et repliant leurs ailes tour à tour? Seul le Tout Miséricordieux les soutient. Car Il est sur toute chose, Clairvoyant.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxi{Quel est celui qui constituerait pour vous une armée [capable] de vous secourir, en dehors du Tout Miséricordieux? En vérité les mécréants sont dans l'illusion complète.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxii{Ou quel est celui qui vous donnera votre subsistance s'Il s'arrête de fournir Son attribution? Mais ils persistent dans leur insolence et dans leur répulsion.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxiii{Qui est donc mieux guidé? Celui qui marche face contre terre ou celui qui marche redressé sur un chemin droit.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxiv{Dis: «C'est Lui qui vous a créés et vous a donné l'ouïe, les yeux et les cœurs». Mais vous êtes rarement reconnaissants!\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxv{Dis: «C'est Lui qui vous a répandus sur la terre, et c'est vers Lui que vous serez rassemblés».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxvi{Et ils disent: «A quand cette promesse si vous êtes véridiques?»\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxvii{Dis: «Allah seul [en] a la connaissance. Et moi je ne suis qu'un avertisseur clair».\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxviii{Puis, quand ils verront (le châtiment) de près, les visages de ceux qui ont mécru seront affligés. Et il leur sera dit: «Voilà ce que vous réclamiez».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxix{Dis: «Que vous en semble? Qu'Allah me fasse périr ainsi que ceux qui sont avec moi ou qu'Il nous fasse miséricorde, qui protégera alors les mécréants d'un châtiment douloureux?»\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxx{Dis: «C'est Lui, le Tout Miséricordieux. Nous croyons en Lui et c'est en Lui que nous plaçons notre confiance. Vous saurez bientôt qui est dans un égarement évident».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxi{Dis: «Que vous en semble? Si votre eau était absorbée au plus profond de la terre, qui donc vous apporterait de l'eau de source?»\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxii{\basmalahfr Nûn. Par la plume et ce qu'ils écrivent!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxiii{Tu (Muhammad) n'es pas, par la grâce de ton Seigneur, un possédé.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxiv{Et il y aura pour toi certes, une récompense jamais interrompue.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxv{Et tu es certes, d'une moralité éminente.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxvi{Tu verras et ils verront\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxvii{qui d'entre vous a perdu la raison.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxviii{C'est ton Seigneur qui connaît mieux ceux qui s'égarent de Son chemin, et Il connaît mieux ceux qui suivent la bonne voie.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxix{N'obéis pas à ceux qui crient au mensonge,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxx{Ils aimeraient bien que tu transiges avec eux afin qu'ils transigent avec toi.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxxi{Et n'obéis à aucun grand jureur, méprisable,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxxii{grand diffamateur, grand colporteur de médisance,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxxiii{grand empêcheur du bien, transgresseur, grand pécheur,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxxiv{au cœur dur, et en plus de cela bâtard.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxxv{Même s'il est doté de richesses et (de nombreux) enfants.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxxvi{Quand Nos versets lui sont récités, il dit: «Des contes d'anciens».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxxvii{Nous le marquerons sur le museau [nez].\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxxviii{Nous les avons éprouvés comme Nous avons éprouvé les propriétaires du verger qui avaient juré d'en faire la récolte au matin,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcclxxxix{sans dire: «Si Allah le veut».\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmccxc{Une calamité de la part de ton Seigneur tomba dessus pendant qu'ils dormaient,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmccxci{et le matin, ce fut comme si tout avait été rasé.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmccxcii{Le [lendemain] matin, ils s'appelèrent les uns les autres:\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmccxciii{«Partez tôt à votre champ si vous voulez le récolter».\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmccxciv{Ils allèrent donc, tout en parlant entre eux à voix basse:\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmccxcv{«Ne laissez aucun pauvre y entrer aujourd'hui».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmccxcvi{Ils partirent de bonne heure décidés à user d'avarice [envers les pauvres], convaincus que cela était en leur pouvoir.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmccxcvii{Puis, quand ils le virent [le jardin], ils dirent: «vraiment, nous avons perdu notre chemin.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmccxcviii{Ou plutôt nous sommes frustrés».\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmccxcix{Le plus juste d'entre eux dit: «Ne vous avais-je pas dit: Si seulement vous avez rendu gloire à Allah!»\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmccc{Ils dirent: «Gloire à notre Seigneur! Oui, nous avons été des injustes».\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmccci{Puis ils s'adressèrent les uns aux autres, se faisant des reproches.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmcccii{Ils dirent: «Malheur à nous! Nous avons été des rebelles.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmccciii{Nous souhaitons que notre Seigneur nous le remplace par quelque chose de meilleur. Nous désirons nous rapprocher de notre Seigneur».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmccciv{Tel fut le châtiment; et le châtiment de l'au-delà est plus grand encore, si seulement ils savaient!\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmcccv{Les pieux auront auprès de leur Seigneur les Jardins du délice.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmcccvi{Traiterons-Nous les soumis [à Allah] à la manière des criminels?\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmcccvii{Qu'avez-vous? Comment jugez-vous?\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmcccviii{Ou bien avez-vous un Livre dans lequel vous apprenez\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmcccix{qu'en vérité vous obtiendrez tout ce que vous désirez?\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmcccx{Ou bien est-ce que vous avez obtenu de Nous des serments valables jusqu'au Jour de la Résurrection, Nous engageant à vous donner ce que vous décidez?\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxi{Demande-leur qui d'entre eux en est garant?\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxii{Ou encore, est-ce qu'ils ont des associés? Eh bien, qu'ils fassent venir leurs associés s'ils sont véridiques!\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxiii{Le jour où ils affronteront les horreurs [du Jugement] et où ils seront appelés à la Prosternation mais ils ne le pourront pas.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxiv{Leurs regards seront abaissés, et l'avilissement les couvrira. Or, ils étaient appelés à la Prosternation au temps où ils étaient sains et saufs!...\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxv{Laisse-Moi donc avec quiconque traite de mensonge ce discours; Nous allons les mener graduellement par où ils ne savent pas!\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxvi{Et Je leur accorde un délai, car Mon stratagème est sûr!\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxvii{Ou bien est-ce que tu leur demandes un salaire, les accablant ainsi d'une lourde dette?\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxviii{Ou savent-ils l'Inconnaissable et c'est de là qu'ils écrivent [leurs mensonges]?\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxix{Endure avec patience la sentence de ton Seigneur, et ne sois pas comme l'homme au Poisson [Jonas] qui appela (Allah) dans sa grande angoisse.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxx{Si un bienfait de son Seigneur ne l'avait pas atteint, il aurait été rejeté honni sur une terre déserte,\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxi{Puis son Seigneur l'élut et le désigna au nombre des gens de bien.\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxii{Peu s'en faut que ceux qui mécroient ne te transpercent par leurs regards, quand ils entendent le Coran, ils disent: «Il est certes fou!»\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxiii{Et ce n'est qu'un Rappel, adressé aux mondes!\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxiv{\basmalahfr L'inévitable [l'Heure qui montre la vérité]\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxv{Qu'est-ce que l'inévitable?\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxvi{Et qui te dira ce que c'est que l'inévitable?\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxvii{Les Thamûd et les 'Aad avaient traité de mensonge le cataclysme.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxviii{Quant aux Thamûd, ils furent détruits par le [bruit] excessivement fort.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxix{Et quant aux 'Aad, ils furent détruits par un vent mugissant et furieux\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxx{qu'[Allah] déchaîna contre eux pendant sept nuits et huit jours consécutifs; tu voyais alors les gens renversés par terre comme des souches de palmiers évidées.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxxi{En vois-tu le moindre vestige?\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxxii{Pharaon et ceux qui vécurent avant lui ainsi que les Villes renversées, commirent des fautes.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxxiii{Ils désobéirent au Messager de leur Seigneur. Celui-ci donc, les saisit d'une façon irrésistible.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxxiv{C'est Nous qui, quand l'eau déborda, vous avons chargés sur l'Arche\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxxv{afin d'en faire pour vous un rappel que toute oreille fidèle conserve.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxxvi{Puis, quand d'un seul souffle, on soufflera dans la Trompe,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxxvii{et que la terre et les montagnes seront soulevées puis tassées d'un seul coup;\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxxviii{ce jour-là alors, l'Evénement se produira,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxxxix{et le ciel se fendra et sera fragile, ce jour-là.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxl{Et sur ses côtés [se tiendront] les Anges, tandis que huit, ce jour-là, porteront au-dessus d'eux le Trône de ton Seigneur.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxli{Ce jour-là vous serez exposés; et rien de vous ne sera caché.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxlii{Quant à celui à qui on aura remis le Livre en sa main droite, il dira: «Tenez! lisez mon livre.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxliii{J'étais sûr d'y trouver mon compte».\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxliv{Il jouira d'une vie agréable:\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxlv{dans un Jardin haut placé\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxlvi{dont les fruits sont à portée de la main.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxlvii{«Mangez et buvez agréablement pour ce que vous avez avancé dans les jours passés».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxlviii{Quant à celui à qui on aura remis le Livre en sa main gauche, il dira: «Hélas pour moi! J'aurai souhaité qu'on ne m'ait pas remis mon livre,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxlix{et ne pas avoir connu mon compte...\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmcccl{Hélas, comme j'aurai souhaité que [ma première mort] fût la définitive.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmcccli{Ma fortune ne m'a servi à rien.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmccclii{Mon autorité est anéantie et m'a quitté!»\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmcccliii{«Saisissez-le! Puis, mettez-lui un carcan;\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmcccliv{ensuite, brûlez-le dans la Fournaise;\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmccclv{puis, liez-le avec une chaîne de soixante-dix coudées,\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmccclvi{car il ne croyait pas en Allah, le Très Grand.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmccclvii{et n'incitait pas à nourrir le pauvre.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmccclviii{Il n'a pour lui ici, aujourd'hui, point d'ami chaleureux [pour le protéger],\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmccclix{ni d'autre nourriture que du pus,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmccclx{que seuls les fautifs mangeront».\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxi{Mais non... Je jure par ce que vous voyez,\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxii{ainsi que par ce que vous ne voyez pas,\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxiii{que ceci [le Coran] est la parole d'un noble Messager,\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxiv{et que ce n'est pas la parole d'un poète; mais vous ne croyez que très peu,\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxv{ni la parole d'un devin, mais vous vous rappelez bien peu.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxvi{C'est une révélation du Seigneur de l'Univers.\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxvii{Et s'il avait forgé quelques paroles qu'ils Nous avait attribuées,\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxviii{Nous l'aurions saisi de la main droite,\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxix{ensuite, Nous lui aurions tranché l'aorte.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxx{Et nul d'entre vous n'aurait pu lui servir de rempart.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxi{C'est en vérité un rappel pour les pieux.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxii{Et Nous savons qu'il y a parmi vous qui le traitent de menteur;\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxiii{mais en vérité, ce sera un sujet de regret pour les mécréants,\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxiv{c'est là la véritable certitude.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxv{Glorifie donc le nom de ton Seigneur, le Très Grand!\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxvi{\basmalahfr Un demandeur a réclamé un châtiment inéluctable,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxvii{pour les mécréants, que nul ne pourrait repousser,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxviii{et qui vient d'Allah, le Maître des voies d'ascension.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxix{Les Anges ainsi que l'Esprit montent vers Lui en un jour dont la durée est de cinquante mille ans.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxx{Supporte donc, d'une belle patience.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxxi{Ils le (le châtiment) voient bien loin,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxxii{alors que Nous le voyons bien proche,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxxiii{le jour où le ciel sera comme du métal en fusion\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxxiv{et les montagnes comme de la laine,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxxv{où nul ami dévoué ne s'enquerra d'un ami,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxxvi{bien qu'ils se voient l'un l'autre. Le criminel aimerait pouvoir se racheter du châtiment de ce jour, en livrant ses enfants,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxxvii{sa compagne, son frère,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxxviii{même son clan qui lui donnait asile,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmccclxxxix{et tout ce qui est sur la terre, tout, qui pourrait le sauver.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxc{Mais rien [ne le sauvera]. [L'Enfer] est un brasier\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxci{arrachant brutalement la peau du crâne.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxcii{Il appellera celui qui tournait le dos et s'en allait,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxciii{amassait et thésaurisait.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxciv{Oui, l'homme a été créé instable [très inquiet];\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxcv{quand le malheur le touche, il est abattu;\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxcvi{et quand le bonheur le touche, il est grand refuseur.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxcvii{Sauf ceux qui pratiquent la Salât\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxcviii{qui sont assidus à leurs Salâts,\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmcccxcix{et sur les biens desquels il y a un droit bien déterminé [la Zakât]\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmcd{pour le mendiant et le déshérité;\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmcdi{et qui déclarent véridique le Jour de la Rétribution,\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmcdii{et ceux qui craignent le châtiment de leur Seigneur\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmcdiii{car vraiment, il n'y a nulle assurance contre le châtiment de leur Seigneur;\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmcdiv{et qui se maintiennent dans la chasteté\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmcdv{et n'ont de rapports qu'avec leurs épouses ou les esclaves qu'ils possèdent car dans ce cas, ils ne sont pas blâmables,\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmcdvi{mais ceux qui cherchent [leur plaisir] en dehors de cela, sont des transgresseurs;\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmcdvii{et qui gardent les dépôts confiés à eux, et respectent leurs engagements scrupuleusement;\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmcdviii{et qui témoignent de la stricte vérité,\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmcdix{et qui sont réguliers dans leur Salât.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmcdx{Ceux-là seront honorés dans des Jardins.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxi{Qu'ont donc, ceux qui ont mécru, à courir vers toi, le cou tendu,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxii{de droite et de gauche, [venant] par bandes?\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxiii{Chacun d'eux convoite-t-il qu'on le laisse entrer au Jardin des délices?\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxiv{Mais non! Nous les avons créés de ce qu'ils savent.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxv{Eh Non!... Je jure par le Seigneur des Levants et des Couchants que Nous sommes Capable\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxvi{de les remplacer par de meilleurs qu'eux, et nul ne peut nous en empêcher.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxvii{Laisse-les donc s'enfoncer (dans leur mécréance) et se divertir jusqu'à ce qu'ils rencontrent leur jour dont on les menaçait,\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxviii{le jour où ils sortiront des tombes, rapides comme s'ils couraient vers des pierres dressées;\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxix{leurs yeux seront abaissés, l'avilissement les couvrira. C'est cela le jour dont on les menaçait!\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxx{\basmalahfr Nous avons envoyé Noé vers son peuple: «Avertis ton peuple, avant que leur vienne un châtiment douloureux».\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxi{Il [leur] dit: «O mon peuple, je suis vraiment pour vous, un avertisseur clair,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxii{Adorez Allah, craignez-Le et obéissez-moi,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxiii{pour qu'Il vous pardonne vos péchés et qu'Il vous donne un délai jusqu'à un terme fixé. Mais quand vient le terme fixé par Allah, il ne saurait être différé si vous saviez!»\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxiv{Il dit: «Seigneur! J'ai appelé mon peuple, nuit et jour.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxv{Mais mon appel n'a fait qu'accroître leur fuite.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxvi{Et chaque fois que je les ai appelés pour que Tu leur pardonnes, ils ont mis leurs doigts dans leurs oreilles. se sont enveloppés de leurs vêtements, se sont entêtés et se sont montrés extrêmement orgueilleux.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxvii{Ensuite, je les ai appelés ouvertement.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxviii{Puis, je leur ai fait des proclamations publiques, et des confidences en secret.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxix{J'ai donc dit: «Implorez le pardon de votre Seigneur, car Il est grand Pardonneur,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxx{pour qu'Il vous envoie du ciel, des pluies abondantes,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxxi{et qu'Il vous accorde beaucoup de biens et d'enfants, et vous donne des jardins et vous donne des rivières.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxxii{Qu'avez-vous à ne pas vénérer Allah comme il se doit,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxxiii{alors qu'Il vous a créés par phases successives?\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxxiv{N'avez-vous pas vu comment Allah a créé sept cieux superposés\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxxv{et y a fait de la lune une lumière et du soleil une lampe?\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxxvi{Et c'est Allah qui, de la terre, vous a fait croître comme des plantes,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxxvii{puis Il vous y fera retourner et vous en fera sortir véritablement.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxxviii{Et c'est Allah qui vous a fait de la terre un tapis,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxxxix{pour que vous vous acheminiez par ses voies spacieuses».\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxl{Noé dit: «Seigneur, ils m'ont désobéi et ils ont suivi celui dont les biens et les enfants n'ont fait qu'accroître la perte.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxli{Ils ont ourdi un immense stratagème,\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxlii{et ils ont dit: «N'abandonnez jamais vos divinités et n'abandonnez jamais Wadd, Suwâ, Yaghhû, Ya'ûq et Nasr'.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxliii{Elles [les idoles] ont déjà égaré plusieurs. Ne fais (Seigneur) croître les injustes qu'en égarement.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxliv{A cause de leurs fautes, ils ont été noyés, puis on les a fait entrer au Feu, et ils n'ont pas trouvé en dehors d'Allah, de secoureurs».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxlv{Et Noé dit: «Seigneur, ne laisse sur la terre aucun infidèle.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxlvi{Si Tu les laisses [en vie], ils égareront Tes serviteurs et n'engendreront que des pécheurs infidèles.\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxlvii{Seigneur! Pardonne-moi, et à mes père et mère et à celui qui entre dans ma demeure croyant, ainsi qu'aux croyants et croyantes; et ne fais croître les injustes qu'en perdition».\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxlviii{\basmalahfr Dis: «Il m'a été révélé qu'un groupe de djinns prêtèrent l'oreille, puis dirent: «Nous avons certes entendu une Lecture [le Coran] merveilleuse,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxlix{qui guide vers la droiture. Nous y avons cru, et nous n'associerons jamais personne à notre Seigneur.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcdl{En vérité notre Seigneur - que Sa grandeur soit exaltée - ne S'est donné ni compagne, ni enfant!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcdli{Notre insensé [Iblis] disait des extravagances contre Allah.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlii{Et nous pensions que ni les humains ni les djinns ne sauraient jamais proférer de mensonge contre Allah.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcdliii{Or, il y avait parmi les humains, des mâles qui cherchaient protection auprès des mâles parmi les djinns mais cela ne fit qu'accroître leur détresse.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcdliv{Et ils avaient pensé comme vous avez pensé qu'Allah ne ressusciterait jamais personne.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlv{Nous avions frôlé le ciel et nous l'avions trouvé plein d'une forte garde et de bolides.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlvi{Nous y prenions place pour écouter. Mais quiconque prête l'oreille maintenant, trouve contre lui un bolide aux aguets.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlvii{Nous ne savons pas si on veut du mal aux habitants de la terre ou si leur Seigneur veut les mettre sur le droit chemin.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlviii{Il y a parmi nous des vertueux et [d'autres] qui le sont moins: nous étions divisés en différentes sectes.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlix{Nous pensions bien que nous ne saurions jamais réduire Allah à l'impuissance sur la terre et que nous ne saurions jamais le réduire à l'impuissance en nous enfuyant.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlx{Et lorsque nous avons entendu le guide [le Coran], nous y avons cru, et quiconque croit en son Seigneur ne craint alors ni diminution de récompense ni oppression.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxi{Il y a parmi nous les Musulmans, et il y en a les injustes [qui ont dévié]. Et ceux qui se sont convertis à l'Islam sont ceux qui ont cherché la droiture.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxii{Et quant aux injustes, ils formeront le combustible de l'Enfer.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxiii{Et s'ils se maintenaient dans la bonne direction, Nous les aurions abreuvés, certes d'une eau abondante,\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxiv{afin de les y éprouver. Et quiconque se détourne du rappel de son Seigneur, Il l'achemine vers un châtiment sans cesse croissant.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxv{Les mosquées sont consacrées à Allah: n'invoquez donc personne avec Allah.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxvi{Et quand le serviteur d'Allah s'est mis debout pour L'invoquer, ils faillirent se ruer en masse sur lui.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxvii{Dis: «Je n'invoque que mon Seigneur et ne Lui associe personne».\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxviii{Dis: «Je ne possède aucun moyen pour vous faire du mal, ni pour vous mettre sur le chemin droit».\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxix{Dis: «Vraiment, personne ne saura me protéger contre Allah; et jamais je ne trouverai de refuge en dehors de Lui.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxx{[Je ne puis que transmettre] une communication et des messages [émanant] d'Allah. Et quiconque désobéit à Allah et à Son Messager aura le feu de l'Enfer pour y demeurer éternellement.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxi{Puis, quand ils verront ce dont on les menaçait, ils sauront lesquels ont les secours les plus faibles et [lesquels] sont les moins nombreux.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxii{Dis: «Je ne sais pas si ce dont vous êtes menacés est proche, ou bien, si mon Seigneur va lui assigner un délai.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxiii{[C'est Lui] qui connaît le mystère. Il ne dévoile Son mystère à personne,\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxiv{sauf à celui qu'Il agrée comme Messager et qu'Il fait précéder et suivre de gardiens vigilants,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxv{afin qu'Il sache s'ils ont bien transmis les messages de leur Seigneur. Il cerne (de Son savoir) ce qui est avec eux, et dénombre exactement toute chose.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxvi{\basmalahfr O toi, l'enveloppé [dans tes vêtements]!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxvii{Lève-toi [pour prier], toute la nuit, excepté une petite partie;\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxviii{Sa moitié, ou un peu moins;\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxix{ou un peu plus. Et récite le Coran, lentement et clairement.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxx{Nous allons te révéler des paroles lourdes (très importantes).\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxxi{La prière pendant la nuit est plus efficace et plus propice pour la récitation.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxxii{Tu as, dans la journée, à vaquer à de longues occupations.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxxiii{Et rappelle-toi le nom de ton Seigneur et consacre-toi totalement à Lui,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxxiv{le Seigneur du Levant et du Couchant. Il n'y a point de divinité à part Lui. Prends-Le donc comme Protecteur.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxxv{Et endure ce qu'ils disent; et écarte-toi d'eux d'une façon convenable.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxxvi{Et laisse-moi avec ceux qui crient au mensonge et qui vivent dans l'aisance; et accorde-leur un court répit:\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxxvii{Nous avons [pour eux] lourdes chaînes et Enfer,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxxviii{et nourriture à faire suffoquer, et châtiment douloureux.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcdlxxxix{Le jour où la terre et les montagnes trembleront, tandis que les montagnes deviendront comme une dune de sable dispersée.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxc{Nous vous avons envoyé un Messager pour être témoin contre vous, de même que Nous avions envoyé un Messager à Pharaon.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxci{Pharaon désobéit alors au Messager. Nous le saisîmes donc rudement.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxcii{Comment vous préserverez-vous, si vous mécroyez, d'un jour qui rendra les enfants comme des vieillards aux cheveux blancs?\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxciii{[et] durant lequel le ciel se fendra. Sa promesse s'accomplira sans doute.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxciv{Ceci est un rappel. Que celui qui veut prenne une voie [menant] à son Seigneur.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxcv{Ton Seigneur sait, certes, que tu (Muhammad) te tiens debout moins de deux tiers de la nuit, ou sa moitié, ou son tiers. De même qu'une partie de ceux qui sont avec toi. Allah détermine la nuit et le jour. Il sait que vous ne saurez jamais passer toute la nuit en prière. Il a usé envers vous avec indulgence. Récitez donc ce qui [vous] est possible du Coran. Il sait qu'il y aura parmi vous des malades, et d'autres qui voyageront sur la terre, en quête de la grâce d'Allah, et d'autres encore qui combattront dans le chemin d'Allah. Récite-en donc ce qui [vous] sera possible. Accomplissez la Salât, acquittez la Zakât, et faites à Allah un prêt sincère. Tout bien que vous vous préparez, vous le retrouverez auprès d'Allah, meilleur et plus grand en fait de récompense. Et implorez le pardon d'Allah. Car Allah est Pardonneur et Très Miséricordieux.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxcvi{\basmalahfr O, toi (Muhammad)! Le revêtu d'un manteau!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxcvii{Lève-toi et avertis.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxcviii{Et de ton Seigneur, célèbre la grandeur.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcdxcix{Et tes vêtements, purifie-les.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmd{Et de tout péché, écarte-toi.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdi{Et ne donne pas dans le but de recevoir davantage.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdii{Et pour ton Seigneur, endure.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdiii{Quand on sonnera du Clairon,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdiv{alors, ce jour-là sera un jour difficile,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdv{pas facile pour les mécréants.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdvi{Laisse-Moi avec celui que J'ai créé seul,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdvii{et à qui J'ai donné des biens étendus,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdviii{et des enfants qui lui tiennent toujours compagnie,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdix{pour qui aussi J'ai aplani toutes difficultés\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdx{Cependant, il convoite [de Moi] que Je lui donne davantage.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdxi{Pas du tout! Car il reniait nos versets (le Coran) avec entêtement.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdxii{Je vais le contraindre à gravir une pente.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdxiii{Il a réfléchi. Et il a décidé.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdxiv{Qu'il périsse! Comme il a décidé!\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdxv{Encore une fois, qu'il périsse; comme il a décidé!\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmdxvi{Ensuite, il a regardé.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmdxvii{Et il s'est renfrogné et a durci son visage.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmdxviii{Ensuite il a tourné le dos et s'est enflé d'orgueil\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmdxix{Puis il a dit: «Ceci (le Coran) n'est que magie apprise\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmdxx{ce n'est là que la parole d'un humain».\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxi{Je vais le brûler dans le Feu intense (Saqar).\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxii{Et qui te dira ce qu'est Saqar?\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxiii{Il ne laisse rien et n'épargne rien;\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxiv{Il brûle la peau et la noircit.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxv{Ils sont dix neuf à y veiller.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxvi{Nous n'avons assigné comme gardiens du Feu que des Anges. Cependant, Nous n'en avons fixé le nombre que pour éprouver les mécréants, et aussi afin que ceux à qui le Livre a été apporté soient convaincus, et que croisse la foi de ceux qui croient, et que ceux à qui le Livre a été apporté et les croyants n'aient point de doute; et pour que ceux qui ont au cœur quelque maladie ainsi que les mécréants disent: «Qu'a donc voulu Allah par cette parabole?» C'est ainsi qu'Allah égare qui Il veut et guide qui Il veut. Nul ne connaît les armées de ton Seigneur, à part Lui. Et ce n'est là qu'un rappel pour les humains.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxvii{Non!... Par la lune!\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxviii{Et par la nuit quand elle se retire!\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxix{Et par l'aurore quand elle se découvre!\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxx{[Saqar] est l'un des plus grands [malheurs]\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxxi{un avertissement, pour les humains.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxxii{Pour qui d'entre vous, veut avancer ou reculer.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxxiii{Toute âme est l'otage de ce qu'elle a acquis.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxxiv{Sauf les gens de la droite (les élus):\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxxv{dans des Jardins, ils s'interrogeront\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxxvi{au sujet des criminels:\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxxvii{«Qu'est-ce qui vous a acheminés à Saqar?»\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxxviii{Ils diront: «Nous n'étions pas de ceux qui faisaient la Salât,\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmmdxxxix{et nous ne nourrissions pas le pauvre,\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmmdxl{et nous nous associions à ceux qui tenaient des conversations futiles,\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmmdxli{et nous traitions de mensonge le jour de la Rétribution,\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmmdxlii{jusqu'à ce que nous vînt la vérité évidente [la mort]».\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmmdxliii{Ne leur profitera point donc, l'intercession des intercesseurs.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmmdxliv{Qu'ont-ils à se détourner du Rappel?\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmmdxlv{Ils sont comme des onagres épouvantés,\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmmdxlvi{s'enfuyant devant un lion.\qt@no{(51)}}
\qt@newcmd\qurantrans@fr@mmmmmdxlvii{Chacun d'eux voudrait plutôt qu'on lui apporte des feuilles tout étalées.\qt@no{(52)}}
\qt@newcmd\qurantrans@fr@mmmmmdxlviii{Ah! Non! C'est plutôt qu'ils ne craignent pas l'au-delà.\qt@no{(53)}}
\qt@newcmd\qurantrans@fr@mmmmmdxlix{Ah! Non! Ceci est vraiment un Rappel.\qt@no{(54)}}
\qt@newcmd\qurantrans@fr@mmmmmdl{Quiconque veut, qu'il se le rappelle.\qt@no{(55)}}
\qt@newcmd\qurantrans@fr@mmmmmdli{Mais ils ne se rappelleront que si Allah veut. C'est Lui qui est Le plus digne d'être craint; et c'est Lui qui détient le pardon.\qt@no{(56)}}
\qt@newcmd\qurantrans@fr@mmmmmdlii{\basmalahfr Non!... Je jure par le Jour de la Résurrection!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdliii{Mais non!, Je jure par l'âme qui ne cesse de se blâmer.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdliv{L'homme, pense-t-il que Nous ne réunirons jamais ses os?\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdlv{Mais si! Nous sommes Capable de remettre à leur place les extrémités de ses doigts.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdlvi{L'homme voudrait plutôt continuer à vivre en libertin.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdlvii{Il interroge: «A quand, le Jour de la Résurrection?»\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdlviii{Lorsque la vue sera éblouie,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdlix{et que la lune s'éclipsera,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdlx{et que le soleil et la lune seront réunis,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxi{l'homme, ce jour-là, dira: «Où fuir?»\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxii{Non! Point de refuge!\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxiii{Vers ton Seigneur sera, ce jour-là, le retour.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxiv{L'homme sera informé ce jour-là de ce qu'il aura avancé et de ce qu'il aura remis à plus tard.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxv{Mais l'homme sera un témoin perspicace contre lui-même,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxvi{quand même il présenterait ses excuses.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxvii{Ne remue pas ta langue pour hâter sa récitation:\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxviii{Son rassemblement (dans ton cœur et sa fixation dans ta mémoire) Nous incombent, ainsi que la façon de le réciter.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxix{Quand donc Nous le récitons, suis sa récitation.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxx{A Nous, ensuite incombera son explication.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxi{Mais vous aimez plutôt [la vie] éphémère,\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxii{et vous délaissez l'au-delà.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxiii{Ce jour-là, il y aura des visages resplendissants\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxiv{qui regarderont leur Seigneur;\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxv{et il y aura ce jour-là, des visages assombris,\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxvi{qui s'attendent à subir une catastrophe.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxvii{Mais non! Quand [l'âme] en arrive aux clavicules\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxviii{et qu'on dit: «Qui est exorciseur?»\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxix{et qu'il [l'agonisant] est convaincu que c'est la séparation (la mort),\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxx{et que la jambe s'enlace à la jambe,\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxxi{c'est vers ton Seigneur, ce jour-là que tu seras conduit.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxxii{Mais il n'a ni cru, ni fait la Salât;\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxxiii{par contre, il a démenti et tourné le dos,\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxxiv{puis il s'en est allé vers sa famille, marchant avec orgueil.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxxv{«Malheur à toi, malheur!»\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxxvi{Et encore malheur à toi, malheur!\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxxvii{L'homme pense-t-il qu'on le laissera sans obligation à observer?\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxxviii{N'était-il pas une goutte de sperme éjaculé?\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmdlxxxix{Et ensuite une adhérence Puis [Allah] l'a créée et formée harmonieusement;\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmdxc{puis en a fait alors les deux éléments de couple: le mâle et la femelle?\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmdxci{Celui-là [Allah] n'est-Il pas capable de faire revivre les morts?\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmdxcii{\basmalahfr S'est-il écoulé pour l'homme un laps de temps durant lequel il n'était même pas une chose mentionnable?\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdxciii{En effet, Nous avons créé l'homme d'une goutte de sperme mélangé [aux composantes diverses] pour le mettre à l'épreuve. [C'est pourquoi] Nous l'avons fait entendant et voyant.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdxciv{Nous l'avons guidé dans le chemin, - qu'il soit reconnaissant ou ingrat -\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdxcv{Nous avons préparé pour les infidèles des chaînes, des carcans et une fournaise ardente.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdxcvi{Les vertueux boiront d'une coupe dont le mélange sera de camphre,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdxcvii{d'une source de laquelle boiront les serviteurs d'Allah et ils la feront jaillir en abondance.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdxcviii{Ils accomplissent leurs vœux et ils redoutent un jour dont le mal s'étendra partout.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdxcix{et offrent la nourriture, malgré son amour, au pauvre, à l'orphelin et au prisonnier,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdc{(disant): «C'est pour le visage d'Allah que nous vous nourrissons: nous ne voulons de vous ni récompense ni gratitude.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdci{Nous redoutons, de notre Seigneur, un jour terrible et catastrophique».\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdcii{Allah les protègera donc du mal de ce jour-là, et leur fera rencontrer la splendeur et la joie,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdciii{et les rétribuera pour ce qu'ils auront enduré, en leur donnant le Paradis et des [vêtements] de soie,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdciv{ils y seront accoudés sur des divans, n'y voyant ni soleil ni froid glacial.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdcv{Ses ombrages les couvriront de près, et ses fruits inclinés bien bas [à portée de leurs mains].\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdcvi{Et l'on fera circuler parmi eux des récipients d'argent et des coupes cristallines,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdcvii{en cristal d'argent, dont le contenu a été savamment dosé.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdcviii{Et là, ils seront abreuvés d'une coupe dont le mélange sera de gingembre,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdcix{puisé là-dedans à une source qui s'appelle Salsabîl.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdcx{Et parmi eux, circuleront des garçons éternellement jeunes. Quand tu les verras, tu les prendras pour des perles éparpillées.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxi{Et quand tu regarderas là-bas, tu verras un délice et un vaste royaume.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxii{Ils porteront des vêtements verts de satin et de brocart. Et ils seront parés de bracelets d'argent. Et leur Seigneur les abreuvera d'une boisson très pure.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxiii{Cela sera pour vous une récompense, et votre effort sera reconnu.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxiv{En vérité c'est Nous qui avons fait descendre sur toi le Coran graduellement.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxv{Endure donc ce que ton Seigneur a décrété, et n'obéis ni au pécheur, parmi eux, ni au grand mécréant.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxvi{Et invoque le nom de ton Seigneur, matin et après-midi;\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxvii{et prosterne-toi devant Lui une partie de la nuit; et glorifie-Le de longues [heures] pendant la nuit.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxviii{Ces gens-là aiment [la vie] éphémère (la vie sur terre) et laissent derrière eux un jour bien lourd [le Jour du Jugement].\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxix{C'est Nous qui les avons créés et avons fortifié leur constitution. Quand Nous voulons, cependant, Nous les remplaçons [facilement] par leurs semblables.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxx{Ceci est un rappel. Que celui qui veut prenne donc le chemin vers son Seigneur!\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxi{Cependant, vous ne saurez vouloir, à moins qu'Allah veuille. Et Allah est Omniscient et Sage.\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxii{Il fait entrer qui Il veut dans Sa miséricorde. Et quant aux injustes, Il leur a préparé un châtiment douloureux.\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxiii{\basmalahfr Par ceux qu'on envoie en rafales,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxiv{et qui soufflent en tempête!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxv{Et qui dispersent largement [dans toutes les directions].\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxvi{Par ceux qui séparent nettement (le bien et le mal),\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxvii{et lancent un rappel\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxviii{en guise d'excuse ou d'avertissement!\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxix{Ce qui vous est promis est inéluctable.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxx{Quand donc les étoiles seront effacées,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxxi{et que le ciel sera fendu,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxxii{et que les montagnes seront pulvérisées,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxxiii{et que le moment (pour la réunion) des Messagers a été fixé!...\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxxiv{A quel jour tout cela a-t-il été renvoyé?\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxxv{Au Jour de la Décision. [le Jugement]!\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxxvi{Et qui te dira ce qu'est le Jour de la Décision?\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxxvii{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxxviii{N'avons-nous pas fait périr les premières [générations]?\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxxxix{Puis ne les avons-Nous pas fait suivre par les derniers?\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxl{C'est ainsi que Nous agissons avec les criminels.\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxli{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxlii{Ne vous avons-Nous pas créés d'une eau vile\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxliii{que Nous avons placée dans un reposoir sûr,\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxliv{pour une durée connue?\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxlv{Nous l'avons décrété ainsi et Nous décrétons [tout] de façon parfaite.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxlvi{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxlvii{N'avons-Nous pas fait de la terre un endroit les contenant tous,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxlviii{les vivants ainsi que les morts?\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxlix{Et n'y avons-Nous pas placé fermement de hautes montagnes? Et ne vous avons-Nous pas abreuvés d'eau douce?\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmdcl{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmdcli{Allez vers ce que vous traitiez alors de mensonge!\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmdclii{Allez vers une ombre [fumée de l'Enfer] à trois branches;\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmdcliii{qui n'est ni ombreuse ni capable de protéger contre la flamme;\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmdcliv{car [le feu] jette des étincelles volumineuses comme des châteaux,\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmdclv{et qu'on prendrait pour des chameaux jaunes.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmdclvi{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmdclvii{Ce sera le jour où ils ne [peuvent] pas parler,\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmdclviii{et point ne leur sera donné permission de s'excuser.\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmdclix{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmdclx{C'est le Jour de la Décision [Jugement], où nous vous réunirons ainsi que les anciens.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxi{Si vous disposez d'une ruse, rusez donc contre Moi.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxii{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxiii{Les pieux seront parmi des ombrages et des sources\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxiv{De même que des fruits selon leurs désirs.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxv{«Mangez et buvez agréablement, pour ce que vous faisiez».\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxvi{C'est ainsi que Nous récompensons les bienfaisants.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxvii{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxviii{«Mangez et jouissez un peu (ici-bas); vous êtes certes des criminels».\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxix{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(47)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxx{Et quand on leur dit: «Inclinez-vous, ils ne s'inclinent pas.\qt@no{(48)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxi{Malheur, ce jour-là, à ceux qui criaient au mensonge.\qt@no{(49)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxii{Après cela, en quelle parole croiront-ils donc?\qt@no{(50)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxiii{\basmalahfr Sur quoi s'interrogent-ils mutuellement?\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxiv{Sur la grande nouvelle,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxv{à propos de laquelle ils divergent.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxvi{Eh bien non! Ils sauront bientôt.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxvii{Encore une fois, non! Ils sauront bientôt.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxviii{N'avons-Nous pas fait de la terre une couche?\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxix{et (placé) les montagnes comme des piquets?\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxx{Nous vous avons créés en couples,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxxi{et désigné votre sommeil pour votre repos,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxxii{et fait de la nuit un vêtement,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxxiii{et assigné le jour pour les affaires de la vie,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxxiv{et construit au-dessus de vous sept (cieux) renforcés,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxxv{et [y] avons placé une lampe (le soleil) très ardente,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxxvi{et fait descendre des nuées une eau abondante\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxxvii{pour faire pousser par elle grains et plantes\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxxviii{et jardins luxuriants.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdclxxxix{Le Jour de la Décision [du Jugement] a son terme fixé.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxc{Le jour où l'on soufflera dans la Trompe, vous viendrez par troupes,\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxci{et le ciel sera ouvert et [présentera] des portes,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxcii{et les montagnes seront mises en marche et deviendront un mirage.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxciii{L'Enfer demeure aux aguets,\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxciv{refuge pour les transgresseurs.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxcv{Ils y demeureront pendant des siècles successifs.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxcvi{Ils n'y goûteront ni fraîcheur ni breuvage,\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxcvii{Hormis une eau bouillante et un pus\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxcviii{comme rétribution équitable.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmdcxcix{Car ils ne s'attendaient pas à rendre compte,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmdcc{et traitaient de mensonges, continuellement, Nos versets,\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmdcci{alors que Nous avons dénombré toutes choses en écrit.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmdccii{Goûtez-donc. Nous n'augmenterons pour vous que le châtiment!\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmdcciii{Pour les pieux ce sera une réussite:\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmdcciv{jardins et vignes,\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmdccv{et des (belles) aux seins arrondis, d'une égale jeunesse,\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmdccvi{et coupes débordantes.\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmdccvii{Ils n'y entendront ni futilités ni mensonges.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmdccviii{A titre de récompense de ton Seigneur et à titre de don abondant\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmdccix{du Seigneur des cieux et de la terre et de ce qui existe entre eux, le Tout Miséricordieux; ils n'osent nullement Lui adresser la parole.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmdccx{Le jour où l'Esprit et les Anges se dresseront en rangs, nul ne saura parler, sauf celui à qui le Tout Miséricordieux aura accordé la permission, et qui dira la vérité.\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxi{Ce jour-là est inéluctable. Que celui qui veut prenne donc refuge auprès de son Seigneur.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxii{Nous vous avons avertis d'un châtiment bien proche, le jour où l'homme verra ce que ses deux mains ont préparé; et l'infidèle dira: «Hélas pour moi! Comme j'aurais aimé n'être que poussière».\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxiii{\basmalahfr Par ceux qui arrachent violemment!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxiv{Et par ceux qui recueillent avec douceur!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxv{Et par ceux qui voguent librement,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxvi{puis s'élancent à toute vitesse,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxvii{et règlent les affaires!\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxviii{Le jour où [la terre] tremblera [au premier son du clairon]\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxix{immédiatement suivi du deuxième.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxx{Ce jour-là, il y aura des cœurs qui seront agités d'effroi,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxi{et leurs regards se baisseront.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxii{Ils disent: «Quoi! Serons-nous ramenés à notre vie première,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxiii{quand nous serons ossements pourris?»\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxiv{Ils disent: «ce sera alors un retour ruineux!»\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxv{Il n'y aura qu'une sommation,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxvi{et voilà qu'ils seront sur la terre (ressuscités).\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxvii{Le récit de Moïse t'est-il parvenu?\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxviii{Quand son Seigneur l'appela, dans Towâ, la vallée sanctifiée:\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxix{«Va vers Pharaon. Vraiment, il s'est rebellé!»\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxx{Puis dis-lui: «Voudrais-tu te purifier?\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxxi{et que je te guide vers ton Seigneur afin que tu Le craignes?»\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxxii{Il lui fit voir le très grand miracle.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxxiii{Mais il le qualifia de mensonge et désobéit;\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxxiv{Ensuite, il tourna le dos, s'en alla précipitamment,\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxxv{rassembla [les gens] et leur fit une proclamation,\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxxvi{et dit: «C'est moi votre Seigneur, le très haut».\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxxvii{Alors Allah le saisit de la punition exemplaire de l'au-delà et de celle d'ici-bas.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxxviii{Il y a certes là un sujet de réflexion pour celui qui craint.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxxxix{Etes-vous plus durs à créer? ou le ciel, qu'Il a pourtant construit?\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxl{Il a élevé bien haut sa voûte, puis l'a parfaitement ordonné;\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxli{Il a assombri sa nuit et fait luire son jour.\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxlii{Et quant à la terre, après cela, Il l'a étendue:\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxliii{Il a fait sortir d'elle son eau et son pâturage,\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxliv{et quant aux montagnes, Il les a ancrées,\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxlv{pour votre jouissance, vous et vos bestiaux.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxlvi{Puis quand viendra le grand cataclysme,\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxlvii{le jour où l'homme se rappellera à quoi il s'est efforcé,\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxlviii{l'Enfer sera pleinement visible à celui qui regardera...\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxlix{Quant à celui qui aura dépassé les limites\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmdccl{et aura préféré la vie présente,\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmdccli{alors, l'Enfer sera son refuge...\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclii{Et pour celui qui aura redouté de comparaître devant son Seigneur, et préservé son âme de la passion,\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmdccliii{le Paradis sera alors son refuge.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmmdccliv{Ils t'interrogent au sujet de l'Heure: «Quand va-t-elle jeter l'ancre?»\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclv{Quelle [science] en as-tu pour le leur dire?\qt@no{(43)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclvi{Son terme n'est connu que de ton Seigneur.\qt@no{(44)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclvii{Tu n'es que l'avertisseur de celui qui la redoute.\qt@no{(45)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclviii{Le jour où ils la verront, il leur semblera n'avoir demeuré qu'un soir ou un matin.\qt@no{(46)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclix{\basmalahfr Il s'est renfrogné et il s'est détourné\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclx{parce que l'aveugle est venu à lui.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxi{Qui te dit: peut-être [cherche]-t-il à se purifier?\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxii{ou à se rappeler en sorte que le rappel lui profite?\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxiii{Quant à celui qui se complaît dans sa suffisance (pour sa richesse)\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxiv{tu vas avec empressement à sa rencontre.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxv{Or, que t'importe qu'il ne se purifie pas».\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxvi{Et quant à celui qui vient à toi avec empressement\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxvii{tout en ayant la crainte,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxviii{tu ne t'en soucies pas.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxix{N'agis plus ainsi! Vraiment ceci est un rappel -\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxx{quiconque veut, donc, s'en rappelle -\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxi{consigné dans des feuilles honorées,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxii{élevées, purifiées,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxiii{entre les mains d'ambassadeurs\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxiv{nobles, obéissants.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxv{Que périsse l'homme! Qu'il est ingrat!\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxvi{De quoi [Allah] l'a-t-Il créé?\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxvii{D'une goutte de sperme, Il le crée et détermine (son destin):\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxviii{puis Il lui facilite le chemin;\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxix{puis Il lui donne la mort et le met au tombeau;\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxx{puis Il le ressuscitera quand Il voudra.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxxi{Eh bien non! [L'homme] n'accomplit pas ce qu'Il lui commande.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxxii{Que l'homme considère donc sa nourriture:\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxxiii{C'est Nous qui versons l'eau abondante,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxxiv{puis Nous fendons la terre par fissures\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxxv{et y faisons pousser grains,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxxvi{vignobles et légumes,\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxxvii{oliviers et palmiers,\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxxviii{jardins touffus,\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmdcclxxxix{fruits et herbages,\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxc{pour votre jouissance vous et vos bestiaux.\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxci{Puis quand viendra le Fracas,\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxcii{le jour où l'homme s'enfuira de son frère,\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxciii{de sa mère, de son père,\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxciv{de sa compagne et de ses enfants,\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxcv{car chacun d'eux, ce jour-là, aura son propre cas pour l'occuper.\qt@no{(37)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxcvi{Ce jour-là, il y aura des visages rayonnants,\qt@no{(38)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxcvii{riants et réjouis.\qt@no{(39)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxcviii{De même qu'il y aura, ce jour-là, des visages couverts de poussière,\qt@no{(40)}}
\qt@newcmd\qurantrans@fr@mmmmmdccxcix{recouverts de ténèbres.\qt@no{(41)}}
\qt@newcmd\qurantrans@fr@mmmmmdccc{Voilà les infidèles, les libertins.\qt@no{(42)}}
\qt@newcmd\qurantrans@fr@mmmmmdccci{\basmalahfr Quand le soleil sera obscurci,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccii{et que les étoiles deviendront ternes,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdccciii{et les montagnes mises en marche,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdccciv{et les chamelles à terme, négligées,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccv{et les bêtes farouches, rassemblées,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccvi{et les mers allumées,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccvii{et les âmes accouplées\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccviii{et qu'on demandera à la fillette enterrée vivante\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccix{pour quel péché elle a été tuée.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccx{Et quand les feuilles seront déployées,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxi{et le ciel écorché\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxii{et la fournaise attisée,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxiii{et le Paradis rapproché,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxiv{chaque âme saura ce qu'elle a présenté.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxv{Non!... Je jure par les planètes qui gravitent\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxvi{qui courent et disparaissent\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxvii{par la nuit quand elle survient!\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxviii{et par l'aube quand elle exhale son souffle!\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxix{Ceci [le Coran] est la parole d'un noble Messager,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxx{doué d'une grande force, et ayant un rang élevé auprès du Maître du Trône,\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxi{obéi, là-haut, et digne de confiance.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxii{Votre compagnon (Muhammad) n'est nullement fou;\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxiii{il l'a effectivement vu (Gabriel), au clair horizon\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxiv{et il ne garde pas avarement pour lui-même ce qui lui a été révélé.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxv{Et ceci [le Coran] n'est point la parole d'un diable banni.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxvi{Où allez-vous donc?\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxvii{Ceci n'est qu'un rappel pour l'univers,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxviii{pour celui d'entre vous qui veut suivre le chemin droit.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxix{Mais vous ne pouvez vouloir, que si Allah veut, [Lui], le Seigneur de l'Univers ;\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxx{\basmalahfr Quand le ciel se rompra,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxxi{et que les étoiles se disperseront,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxxii{et que les mers confondront leurs eaux,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxxiii{et que les tombeaux seront bouleversés,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxxiv{toute âme saura alors ce qu'elle a accompli et ce qu'elle a remis de faire à plus tard.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxxv{O homme! Qu'est-ce qui t'a trompé au sujet de ton Seigneur, le Noble,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxxvi{qui t'a créé, puis modelé et constitué harmonieusement?\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxxvii{Il t'a façonné dans la forme qu'Il a voulue.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxxviii{Non...! [malgré tout] vous traitez la Rétribution de mensonge;\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxxxix{alors que veillent sur vous des gardiens,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxl{de nobles scribes,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxli{qui savent ce que vous faites.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxlii{Les bons seront, certes, dans un [jardin] de délice,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxliii{et les libertins seront, certes, dans une fournaise\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxliv{où ils brûleront, le jour de la Rétribution\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxlv{incapables de s'en échapper.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxlvi{Et qui te dira ce qu'est le jour de la Rétribution?\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxlvii{Encore une fois, qui te dira ce qu'est le jour de la Rétribution?\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxlviii{Le jour où aucune âme ne pourra rien en faveur d'une autre âme. Et ce jour-là, le commandement sera à Allah.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxlix{\basmalahfr Malheur aux fraudeurs\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccl{qui, lorsqu'ils font mesurer pour eux-mêmes exigent la pleine mesure,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccli{et qui lorsqu'eux-mêmes mesurent ou pèsent pour les autres, [leur] causent perte.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclii{Ceux-là ne pensent-ils pas qu'ils seront ressuscités,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccliii{en un jour terrible,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccliv{le jour où les gens se tiendront debout devant le Seigneur de l'Univers?\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclv{Non...! Mais en vérité le livre des libertins sera dans le Sijjîn -\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclvi{et qui te dira ce qu'est le Sijjîn? -\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclvii{Un livre déjà cacheté (achevé).\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclviii{Malheur, ce jour-là, aux négateurs,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclix{qui démentent le jour de la Rétribution.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclx{Or, ne le dément que tout transgresseur, pécheur:\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxi{qui, lorsque Nos versets lui sont récités, dit: «[Ce sont] des contes d'anciens!»\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxii{Pas du tout, mais ce qu'ils ont accompli couvre leurs cœurs.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxiii{Qu'ils prennent garde! En vérité ce jour-là un voile les empêchera de voir leur Seigneur,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxiv{ensuite, ils brûleront certes, dans la Fournaise;\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxv{on [leur] dira alors: «Voilà ce que vous traitiez de mensonge!»\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxvi{Qu'ils prennent garde! Le livre des bons sera dans l'Illiyûn -\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxvii{et qui te dira ce qu'est l'Illiyûn? -\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxviii{un livre cacheté!\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxix{Les rapprochés [d'Allah: les Anges] en témoignent.\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxx{Les bons seront dans [un Jardin] de délice,\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxi{sur les divans, ils regardent.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxii{Tu reconnaîtras sur leurs visages, l'éclat de la félicité.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxiii{On leur sert à boire un nectar pur, cacheté,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxiv{laissant un arrière-goût de musc. Que ceux qui la convoitent entrent en compétition [pour l'acquérir]\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxv{Il est mélangé à la boisson de Tasnîm,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxvi{source dont les rapprochés boivent.\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxvii{Les criminels riaient de ceux qui croyaient,\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxviii{et, passant près d'eux, ils se faisaient des œillades,\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxix{et, retournant dans leurs familles, ils retournaient en plaisantant,\qt@no{(31)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxx{et les voyant, ils disaient: «Ce sont vraiment ceux-là les égarés».\qt@no{(32)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxxi{Or, ils n'ont pas été envoyés pour être leurs gardiens.\qt@no{(33)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxxii{Aujourd'hui, donc, ce sont ceux qui ont cru qui rient des infidèles\qt@no{(34)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxxiii{sur les divans, ils regardent.\qt@no{(35)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxxiv{Est-ce que les infidèles ont eu la récompense de ce qu'ils faisaient?\qt@no{(36)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxxv{\basmalahfr Quand le ciel se déchirera\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxxvi{et obéira à son Seigneur - et fera ce qu'il doit faire -\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxxvii{et que la terre sera nivelée,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxxviii{et qu'elle rejettera ce qui est en son sein (les morts) et se videra,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmdccclxxxix{et qu'elle obéira à son Seigneur - et fera ce qu'elle doit faire -\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxc{O homme! Toi qui t'efforces vers ton Seigneur sans relâche, tu Le rencontreras alors.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxci{Celui qui recevra son livre en sa main droite,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxcii{sera soumis à un jugement facile,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxciii{et retournera réjoui auprès de sa famille\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxciv{Quant à celui qui recevra son livre derrière son dos,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxcv{il invoquera la destruction sur lui-même,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxcvi{et il brûlera dans un feu ardent.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxcvii{Car il était tout joyeux parmi les siens,\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxcviii{et il pensait que jamais il ne ressusciterait\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmdcccxcix{Mais si! Certes, son Seigneur l'observait parfaitement.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcm{Non!... Je jure par le crépuscule,\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcmi{et par la nuit et ce qu'elle enveloppe,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcmii{et par la lune quand elle devient pleine lune!\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcmiii{Vous passerez, certes, par des états successifs!\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcmiv{Qu'ont-ils à ne pas croire?\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcmv{et à ne pas se prosterner quand le Coran leur est lu?\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcmvi{Mais ceux qui ne croient pas, le traitent plutôt de mensonge.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcmvii{Or, Allah sait bien ce qu'ils dissimulent.\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmcmviii{Annonce-leur donc un châtiment douloureux.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmcmix{Sauf ceux qui croient et accomplissent les bonnes œuvres: à eux une récompense jamais interrompue.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmcmx{\basmalahfr Par le ciel aux constellations!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxi{et par le jour promis!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxii{et par le témoin et ce dont on témoigne!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxiii{Périssent les gens de l'Uhdûd,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxiv{par le feu plein de combustible,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxv{cependant qu'ils étaient assis tout autour,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxvi{ils étaient ainsi témoins de ce qu'ils faisaient des croyants,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxvii{à qui ils ne leur reprochaient que d'avoir cru en Allah, le Puissant, le Digne de louange,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxviii{Auquel appartient la royauté des cieux et de la terre. Allah est témoin de toute chose.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxix{Ceux qui font subir des épreuves aux croyants et aux croyantes, puis ne se repentent pas, auront le châtiment de l'Enfer et le supplice du feu.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxx{Ceux qui croient et accomplissent les bonnes œuvres auront des Jardins sous lesquels coulent les ruisseaux. Cela est le grand succès.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxi{La riposte de ton Seigneur est redoutable.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxii{C'est Lui, certes, qui commence (la création) et la refait.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxiii{Et c'est Lui le Pardonneur, le Tout-Affectueux,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxiv{Le Maître du Trône, le Tout-Glorieux,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxv{Il réalise parfaitement tout ce qu'Il veut.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxvi{T'est-il parvenu le récit des armées,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxvii{de Pharaon, et de Thamûd?\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxviii{Mais ceux qui ne croient pas persistent à démentir,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxix{alors qu'Allah, derrière eux, les cerne de toutes parts.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxx{Mais c'est plutôt un Coran glorifié\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxxi{préservé sur une Tablette (auprès d'Allah).\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxxii{\basmalahfr Par le ciel et par l'astre nocturne\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxxiii{Et qui te dira ce qu'est l'astre nocturne?\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxxiv{C'est l'étoile vivement brillante.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxxv{Il n'est pas d'âme qui n'ait sur elle un gardien.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxxvi{Que l'homme considère donc de quoi il a été créé.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxxvii{Il a été créé d'une giclée d'eau\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxxviii{sortie d'entre les lombes et les côtes.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxxxix{Allah est certes capable de le ressusciter.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxl{Le jour où les cœurs dévoileront leurs secrets,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxli{Il n'aura alors ni force ni secoureur.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxlii{Par le ciel qui fait revenir la pluie!\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxliii{et par la terre qui se fend!\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxliv{Ceci [le Coran] est certes, une parole décisive [qui tranche entre le vrai et le faux],\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxlv{et non point une plaisanterie frivole!\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxlvi{Ils se servent d'une ruse,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxlvii{et Moi aussi Je me sers de Mon plan.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxlviii{Accorde (ô Prophète) donc un délai aux infidèles: accorde-leur un court délai.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxlix{\basmalahfr Glorifie le nom de ton Seigneur, le Très Haut,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcml{Celui Qui a créé et agencé harmonieusement,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcmli{qui a décrété et guidé,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlii{et qui a fait pousser le pâturage,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcmliii{et en a fait ensuite un foin sombre.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcmliv{Nous te ferons réciter (le Coran), de sorte que tu n'oublieras\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlv{que ce qu'Allah veut. Car, Il connaît ce qui paraît au grand jour ainsi que ce qui est caché.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlvi{Nous te mettrons sur la voie la plus facile.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlvii{Rappelle, donc, où le Rappel doit être utile.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlviii{Quiconque craint (Allah) s'[en] rappellera,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlix{et s'en écartera le grand malheureux,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlx{qui brûlera dans le plus grand Feu,\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxi{où il ne mourra ni ne vivra.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxii{Réussit, certes, celui qui se purifie,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxiii{et se rappelle le nom de son Seigneur, puis célèbre la Salât.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxiv{Mais, vous préférez plutôt la vie présente,\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxv{alors que l'au-delà est meilleur et plus durable.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxvi{Ceci se trouve, certes, dans les Feuilles anciennes,\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxvii{les Feuilles d'Abraham et de Moïse.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxviii{\basmalahfr T'est-il parvenu le récit de l'enveloppante?\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxix{Ce jour-là, il y aura des visages humiliés,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxx{préoccupés, harassés.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxi{Ils brûleront dans un Feu ardent,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxii{et seront abreuvés d'une source bouillante.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxiii{Il n'y aura pour eux d'autre nourriture que des plantes épineuses [darî'],\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxiv{qui n'engraisse, ni n'apaise la faim.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxv{Ce jour-là, il y aura des visages épanouis,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxvi{contents de leurs efforts,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxvii{dans un haut Jardin,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxviii{où ils n'entendent aucune futilité.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxix{Là, il y aura une source coulante.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxx{Là, des divans élevés\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxxi{et des coupes posées\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxxii{et des coussins rangés\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxxiii{et des tapis étalés.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxxiv{Ne considèrent-ils donc pas les chameaux, comment ils ont été créés,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxxv{et le ciel comment il est élevé,\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxxvi{et les montagnes comment elles sont dressées\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxxvii{et la terre comment elle est nivelée?\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxxviii{Eh bien, rappelle! Tu n'es qu'un rappeleur,\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmcmlxxxix{et tu n'es pas un dominateur sur eux.\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxc{Sauf celui qui tourne le dos et ne croit pas,\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxci{alors Allah le châtiera du plus grand châtiment.\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxcii{Vers Nous est leur retour.\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxciii{Ensuite, c'est à Nous de leur demander compte.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxciv{\basmalahfr Par l'Aube!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxcv{Et par les dix nuits!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxcvi{Par le pair et l'impair!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxcvii{Et par la nuit quand elle s'écoule!\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxcviii{N'est-ce pas là un serment, pour un doué d'intelligence?\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmcmxcix{N'as-tu pas vu comment ton Seigneur a agi avec les 'Aad\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmm{[avec] Iram, [la cité] à la colonne remarquable,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmi{dont jamais pareille ne fut construite parmi les villes?\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmii{et avec les Thamûd qui taillaient le rocher dans la vallée?\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmmiii{ainsi qu'avec Pharaon, l'homme aux épieux?\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmmiv{Tous, étaient des gens qui transgressaient dans [leurs] pays,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmmv{et y avaient commis beaucoup de désordre.\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmmvi{Donc, ton Seigneur déversa sur eux un fouet du châtiment.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmmvii{Car ton Seigneur demeure aux aguets.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmmviii{Quant à l'homme, lorsque son Seigneur l'éprouve en l'honorant et en le comblant de bienfaits, il dit: «Mon Seigneur m'a honoré».\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmmix{Mais par contre, quand Il l'éprouve en lui restreignant sa subsistance, il dit: «Mon Seigneur m'a avili».\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmmx{Mais non! C'est vous plutôt, qui n'êtes pas généreux envers les orphelins;\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmmxi{qui ne vous incitez pas mutuellement à nourrir le pauvre,\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmmxii{qui dévorez l'héritage avec une avidité vorace,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmmxiii{et aimez les richesses d'un amour sans bornes.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmmxiv{Prenez garde! Quand la terre sera complètement pulvérisée,\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmmxv{et que ton Seigneur viendra ainsi que les Anges, rang par rang,\qt@no{(22)}}
\qt@newcmd\qurantrans@fr@mmmmmmxvi{et que ce jour-là, on amènera l'Enfer; ce jour-là, l'homme se rappellera. Mais à quoi lui servira de se souvenir?\qt@no{(23)}}
\qt@newcmd\qurantrans@fr@mmmmmmxvii{Il dira: «Hélas! Que n'ai-je fait du bien pour ma vie future!\qt@no{(24)}}
\qt@newcmd\qurantrans@fr@mmmmmmxviii{Ce jour-là donc, nul ne saura châtier comme Lui châtie,\qt@no{(25)}}
\qt@newcmd\qurantrans@fr@mmmmmmxix{et nul ne saura garrotter comme Lui garrotte.\qt@no{(26)}}
\qt@newcmd\qurantrans@fr@mmmmmmxx{«O toi, âme apaisée,\qt@no{(27)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxi{retourne vers ton Seigneur, satisfaite et agréée;\qt@no{(28)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxii{entre donc parmi Mes serviteurs,\qt@no{(29)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxiii{et entre dans Mon Paradis».\qt@no{(30)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxiv{\basmalahfr Non!... Je jure par cette Cité!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxv{et toi, tu es un résident dans cette cité -\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxvi{Et par le père et ce qu'il engendre!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxvii{Nous avons, certes, créé l'homme pour une vie de lutte.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxviii{Pense-t-il que personne ne pourra rien contre lui?\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxix{Il dit: «J'ai gaspillé beaucoup de biens».\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxx{Pense-t-il que nul ne l'a vu?\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxxi{Ne lui avons Nous pas assigné deux yeux,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxxii{et une langue et deux lèvres?\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxxiii{Ne l'avons-Nous pas guidé aux deux voies.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxxiv{Or, il ne s'engage pas dans la voie difficile!\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxxv{Et qui te dira ce qu'est la voie difficile?\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxxvi{C'est délier un joug [affranchir un esclave],\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxxvii{ou nourrir, en un jour de famine,\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxxviii{un orphelin proche parent\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmmxxxix{ou un pauvre dans le dénuement.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmmxl{Et c'est être, en outre, de ceux qui croient et s'enjoignent mutuellement l'endurance, et s'enjoignent mutuellement la miséricorde.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmmxli{Ceux-là sont les gens de la droite;\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmmxlii{alors que ceux qui ne croient pas en Nos versets sont les gens de la gauche.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmmxliii{Le Feu se refermera sur eux.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmmxliv{\basmalahfr Par le soleil et par sa clarté!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmxlv{Et par la lune quand elle le suit!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmxlvi{Et par le jour quand il l'éclaire!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmxlvii{Et par la nuit quand elle l'enveloppe!\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmxlviii{Et par le ciel et Celui qui l'a construit!\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmxlix{Et par la terre et Celui qui l'a étendue!\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmml{Et par l'âme et Celui qui l'a harmonieusement façonnée;\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmli{et lui a alors inspiré son immoralité, de même que sa piété!\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmlii{A réussi, certes, celui qui la purifie.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmmliii{Et est perdu, certes, celui qui la corrompt.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmmliv{Les Thamûd, par leur transgression, ont crié au mensonge,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmmlv{lorsque le plus misérable d'entre eux se leva (pour tuer la chamelle)\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmmlvi{Le Messager d'Allah leur avait dit: «La chamelle d'Allah! Laissez-la boire.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmmlvii{Mais, ils le traitèrent de menteur, et la tuèrent. Leur Seigneur les détruisit donc, pour leur péché et étendit Son châtiment sur tous.\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmmlviii{Et Allah n'a aucune crainte des conséquences.\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmmlix{\basmalahfr Par la nuit quand elle enveloppe tout!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmlx{Par le jour quand il éclaire!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxi{Et par ce qu'Il a créé, mâle et femelle!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxii{Vos efforts sont divergents.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxiii{Celui qui donne et craint (Allah)\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxiv{et déclare véridique la plus belle récompense\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxv{Nous lui faciliterons la voie au plus grand bonheur.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxvi{Et quant à celui qui est avare, se dispense (de l'adoration d'Allah),\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxvii{et traite de mensonge la plus belle récompense,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxviii{Nous lui faciliterons la voie à la plus grande difficulté,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxix{et à rien ne lui serviront ses richesses quand il sera jeté (au Feu).\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxx{C'est à Nous, certes, de guider;\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxi{à Nous appartient, certes, la vie dernière et la vie présente.\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxii{Je vous ai donc avertis d'un Feu qui flambe\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxiii{où ne brûlera que le damné,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxiv{qui dément et tourne le dos;\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxv{alors qu'en sera écarté le pieux,\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxvi{qui donne ses biens pour se purifier\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxvii{et auprès de qui personne ne profite d'un bienfait intéressé,\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxviii{mais seulement pour la recherche de La Face de son Seigneur le Très Haut.\qt@no{(20)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxix{Et certes, il sera bientôt satisfait!\qt@no{(21)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxx{\basmalahfr Par le Jour Montant!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxxi{Et par la nuit quand elle couvre tout!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxxii{Ton Seigneur ne t'a ni abandonné, ni détesté.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxxiii{La vie dernière t'est, certes, meilleure que la vie présente.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxxiv{Ton Seigneur t'accordera certes [Ses faveurs], et alors tu seras satisfait.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxxv{Ne t'a-t-Il pas trouvé orphelin? Alors Il t'a accueilli!\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxxvi{Ne t'a-t-Il pas trouvé égaré? Alors Il t'a guidé.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxxvii{Ne t'a-t-Il pas trouvé pauvre? Alors Il t'a enrichi.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxxviii{Quant à l'orphelin, donc, ne le maltraite pas.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmmlxxxix{Quant au demandeur, ne le repousse pas.\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmmxc{Et quant au bienfait de ton Seigneur, proclame-le.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmmxci{\basmalahfr N'avons-Nous pas ouvert pour toi ta poitrine?\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmxcii{Et ne t'avons-Nous pas déchargé du fardeau\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmxciii{qui accablait ton dos?\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmxciv{Et exalté pour toi ta renommée?\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmxcv{A côté de la difficulté est, certes, une facilité!\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmxcvi{A côté de la difficulté est, certes, une facilité!\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmxcvii{Quand tu te libères, donc, lève-toi,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmxcviii{et à ton Seigneur aspire.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmxcix{\basmalahfr Par le figuier et l'olivier!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmc{Et par le Mont Sînîn!\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmci{Et par cette Cité sûre!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmcii{Nous avons certes créé l'homme dans la forme la plus parfaite.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmciii{Ensuite, Nous l'avons ramené au niveau le plus bas,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmciv{sauf ceux qui croient et accomplissent les bonnes œuvres: ceux-là auront une récompense jamais interrompue.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmcv{Après cela, qu'est-ce qui te fait traiter la rétribution de mensonge?\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmcvi{Allah n'est-Il pas le plus sage des Juges?\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmcvii{\basmalahfr Lis, au nom de ton Seigneur qui a créé,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmcviii{qui a créé l'homme d'une adhérence.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmcix{Lis! Ton Seigneur est le Très Noble,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmcx{qui a enseigné par la plume [le calame],\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxi{a enseigné à l'homme ce qu'il ne savait pas.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxii{Prenez-garde! Vraiment l'homme devient rebelle,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxiii{dès qu'il estime qu'il peut se suffire à lui-même (à cause de sa richesse).\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxiv{Mais, c'est vers ton Seigneur qu'est le retour.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxv{As-tu vu celui qui interdit\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxvi{à un serviteur d'Allah [Muhammad] de célébrer la Salât?\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxvii{Vois-tu s'il est sur la bonne voie,\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxviii{ou s'il ordonne la piété?\qt@no{(12)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxix{Vois-tu s'il dément et tourne le dos?\qt@no{(13)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxx{Ne sait-il pas que vraiment Allah voit?\qt@no{(14)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxi{Mais non! S'il ne cesse pas, Nous le saisirons certes, par le toupet,\qt@no{(15)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxii{le toupet d'un menteur, d'un pécheur.\qt@no{(16)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxiii{Qu'il appelle donc son assemblée.\qt@no{(17)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxiv{Nous appellerons les gardiens [de l'Enfer].\qt@no{(18)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxv{Non! Ne lui obéis pas; mais prosterne-toi et rapproche-toi.\qt@no{(19)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxvi{\basmalahfr Nous l'avons certes, fait descendre (le Coran) pendant la nuit d'Al-Qadr.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxvii{Et qui te dira ce qu'est la nuit d'Al-Qadr?\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxviii{La nuit d'Al-Qadr est meilleure que mille mois.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxix{Durant celle-ci descendent les Anges ainsi que l'Esprit, par permission de leur Seigneur pour tout ordre.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxx{Elle est paix et salut jusqu'à l'apparition de l'aube.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxxi{\basmalahfr Les infidèles parmi les gens du Livre, ainsi que les Associateurs, ne cesseront pas de mécroire jusqu'à ce que leur vienne la Preuve évidente:\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxxii{un Messager, de la part d'Allah, qui leur récite des feuilles purifiées,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxxiii{dans lesquelles se trouvent des prescriptions d'une rectitude parfaite.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxxiv{Et ceux à qui le Livre a été donné ne se sont divisés qu'après que la preuve leur fut venue.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxxv{Il ne leur a été commandé, cependant, que d'adorer Allah, Lui vouant un culte exclusif, d'accomplir la Salât et d'acquitter la Zakât. Et voilà la religion de droiture.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxxvi{Les infidèles parmi les gens du Livre, ainsi que les Associateurs iront au feu de l'Enfer, pour y demeurer éternellement. De toute la création, ce sont eux les pires.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxxvii{Quant à ceux qui croient et accomplissent les bonnes œuvres, ce sont les meilleurs de toute la création.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxxviii{Leur récompense auprès d'Allah sera les Jardins de séjour, sous lesquels coulent les ruisseaux, pour y demeurer éternellement. Allah les agrée et ils L'agréent. Telle sera [la récompense] de celui qui craint son Seigneur.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxxxix{\basmalahfr Quand la terre tremblera d'un violent tremblement,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxl{et que la terre fera sortir ses fardeaux,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxli{et que l'homme dira: «Qu'a-t-elle?»\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxlii{ce jour-là, elle contera son histoire,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxliii{selon ce que ton Seigneur lui aura révélé [ordonné].\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxliv{Ce jour-là, les gens sortiront séparément pour que leur soient montrées leurs œuvres.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxlv{Quiconque fait un bien fût-ce du poids d'un atome, le verra,\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxlvi{et quiconque fait un mal fût-ce du poids d'un atome, le verra.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxlvii{\basmalahfr Par les coursiers qui halètent,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxlviii{qui font jaillir des étincelles,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxlix{qui attaquent au matin,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmcl{et font ainsi voler la poussière,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmcli{et pénètrent au centre de la troupe ennemie.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmclii{L'homme est, certes, ingrat envers son Seigneur;\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmcliii{et pourtant, il est certes, témoin de cela;\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmcliv{et pour l'amour des richesses il est certes ardent.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmclv{Ne sait-il donc pas que lorsque ce qui est dans les tombes sera bouleversé,\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmmclvi{et que sera dévoilé ce qui est dans les poitrines,\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmmclvii{ce jour-là, certes, leur Seigneur sera Parfaitement Connaisseur d'eux?\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmmclviii{\basmalahfr Le fracas!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmclix{Qu'est-ce que le fracas?\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmclx{Et qui te dira ce qu'est le fracas?\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxi{C'est le jour où les gens seront comme des papillons éparpillés,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxii{et les montagnes comme de la laine cardée;\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxiii{quant à celui dont la balance sera lourde\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxiv{il sera dans une vie agréable;\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxv{et quant à celui dont la balance sera légère,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxvi{sa mère [destination] est un abîme très profond.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxvii{Et qui te dira ce que c'est?\qt@no{(10)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxviii{C'est un Feu ardent.\qt@no{(11)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxix{\basmalahfr La course aux richesses vous distrait,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxx{jusqu'à ce que vous visitiez les tombes.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxi{Mais non! Vous saurez bientôt!\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxii{(Encore une fois)! Vous saurez bientôt!\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxiii{Sûrement! Si vous saviez de science certaine.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxiv{Vous verrez, certes, la Fournaise.\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxv{Puis, vous la verrez certes, avec l'œil de la certitude.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxvi{Puis, assurément, vous serez interrogés, ce jour-là, sur les délices.\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxvii{\basmalahfr Par le Temps!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxviii{L'homme est certes, en perdition,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxix{sauf ceux qui croient et accomplissent les bonnes œuvres, s'enjoignent mutuellement la vérité et s'enjoignent mutuellement l'endurance.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxx{\basmalahfr Malheur à tout calomniateur diffamateur,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxxi{qui amasse une fortune et la compte,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxxii{pensant que sa fortune l'immortalisera.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxxiii{Mais non! Il sera certes, jeté dans la Hutamah.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxxiv{Et qui te dira ce qu'est la Hutamah?\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxxv{Le Feu attisé d'Allah\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxxvi{qui monte jusqu'aux cœurs.\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxxvii{Il se refermera sur eux,\qt@no{(8)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxxviii{en colonnes (de flammes) étendues.\qt@no{(9)}}
\qt@newcmd\qurantrans@fr@mmmmmmclxxxix{\basmalahfr N'as-tu pas vu comment ton Seigneur a agi envers les gens de l'Eléphant?\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxc{N'a-t-Il pas rendu leur ruse complètement vaine?\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxci{et envoyé sur eux des oiseaux par volées\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxcii{qui leur lançaient des pierres d'argile?\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxciii{Et Il les a rendus semblables à une paille mâchée.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxciv{\basmalahfr A cause du pacte des Coraïch,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxcv{De leur pacte [concernant] les voyages d'hiver et d'été.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxcvi{Qu'ils adorent donc le Seigneur de cette Maison [la Ka'ba],\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxcvii{qui les a nourris contre la faim et rassurés de la crainte!\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxcviii{\basmalahfr Vois-tu celui qui traite de mensonge la Rétribution?\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmcxcix{C'est bien lui qui repousse l'orphelin,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmcc{et qui n'encourage point à nourrir le pauvre.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmcci{Malheur donc, à ceux qui prient\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmccii{tout en négligeant (et retardant) leur Salât,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmcciii{qui sont pleins d'ostentation,\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmcciv{et refusent l'ustensile (à celui qui en a besoin).\qt@no{(7)}}
\qt@newcmd\qurantrans@fr@mmmmmmccv{\basmalahfr Nous t'avons certes, accordé l'Abondance.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmccvi{Accomplis la Salât pour ton Seigneur et sacrifie.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmccvii{Celui qui te hait sera certes, sans postérité.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmccviii{\basmalahfr Dis: «O vous les infidèles!\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmccix{Je n'adore pas ce que vous adorez.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmccx{Et vous n'êtes pas adorateurs de ce que j'adore.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxi{Je ne suis pas adorateur de ce que vous adorez.\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxii{Et vous n'êtes pas adorateurs de ce que j'adore.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxiii{A vous votre religion, et à moi ma religion».\qt@no{(6)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxiv{\basmalahfr Lorsque vient le secours d'Allah ainsi que la victoire,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxv{et que tu vois les gens entrer en foule dans la religion d'Allah,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxvi{alors, par la louange, célèbre la gloire de ton Seigneur et implore Son pardon. Car c'est Lui le grand Accueillant au repentir.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxvii{\basmalahfr Que périssent les deux mains d'Abû-Lahab et que lui-même périsse.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxviii{Sa fortune ne lui sert à rien, ni ce qu'il a acquis.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxix{Il sera brûlé dans un Feu plein de flammes,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxx{de même sa femme, la porteuse de bois,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxi{à son cou, une corde de fibres.\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxii{\basmalahfr Dis: «Il est Allah, Unique.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxiii{Allah, Le Seul à être imploré pour ce que nous désirons.\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxiv{Il n'a jamais engendré, n'a pas été engendré non plus.\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxv{Et nul n'est égal à Lui».\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxvi{\basmalahfr Dis: «Je cherche protection auprès du Seigneur de l'aube naissante,\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxvii{contre le mal des êtres qu'Il a créés,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxviii{contre le mal de l'obscurité quand elle s'approfondit,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxix{contre le mal de celles qui soufflent [les sorcières] sur les nœuds,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxx{et contre le mal de l'envieux quand il envie».\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxxi{\basmalahfr Dis: «Je cherche protection auprès du Seigneur des hommes.\qt@no{(1)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxxii{Le Souverain des hommes,\qt@no{(2)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxxiii{Dieu des hommes,\qt@no{(3)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxxiv{contre le mal du mauvais conseiller, furtif,\qt@no{(4)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxxv{qui souffle le mal dans les poitrines des hommes,\qt@no{(5)}}
\qt@newcmd\qurantrans@fr@mmmmmmccxxxvi{qu'il (le conseiller) soit un djinn, ou un être humain».\qt@no{(6)}}
