\qt@newcmd\qurantrans@ur@i{اللہ کے نام سے جو رحمان و رحیم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ii{تعریف اللہ ہی کے لیے ہے جو تمام کائنات کا رب ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@iii{رحمان اور رحیم ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@iv{روز جزا کا مالک ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@v{ہم تیری ہی عبادت کرتے ہیں اور تجھی سے مدد مانگتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@vi{ہمیں سیدھا راستہ دکھا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@vii{اُن لوگوں کا راستہ جن پر تو نے انعام فرمایا، جو معتوب نہیں ہوئے، جو بھٹکے ہوئے نہیں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@viii{\basmalahur الف لام میم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ix{یہ اللہ کی کتاب ہے، اس میں کوئی شک نہیں ہدایت ہے اُن پرہیز گار لوگوں کے لیے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@x{جو غیب پر ایمان لاتے ہیں، نماز قائم کرتے ہیں، جو رزق ہم نے اُن کو دیا ہے، اُس میں سے خرچ کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@xi{جو کتاب تم پر نازل کی گئی ہے (یعنی قرآن) اور جو کتابیں تم سے پہلے نازل کی گئی تھیں ان سب پر ایمان لاتے ہیں اور آخرت پر یقین رکھتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@xii{ایسے لوگ اپنے رب کی طرف سے راہ راست پر ہیں اور وہی فلاح پانے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@xiii{جن لوگوں نے (اِن باتوں کو تسلیم کرنے سے) انکار کر دیا، اُن کے لیے یکساں ہے، خواہ تم انہیں خبردار کرو یا نہ کرو، بہرحال وہ ماننے والے نہیں ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@xiv{اللہ نے ان کے دلوں اور ان کے کانوں پر مہر لگا دی ہے اور ان کی آنکھوں پر پردہ پڑ گیا ہے وہ سخت سزا کے مستحق ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@xv{بعض لوگ ایسے بھی ہیں جو کہتے ہیں کہ ہم اللہ پر اور آخرت کے دن پر ایمان لائے ہیں، حالانکہ در حقیقت وہ مومن نہیں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@xvi{وہ اللہ اور ایمان لانے والوں کے ساتھ دھوکہ بازی کر رہے ہیں، مگر دراصل وہ خود اپنے آپ ہی کو دھوکے میں ڈال رہے ہیں اور انہیں اس کا شعور نہیں ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@xvii{ان کے دلوں میں ایک بیماری ہے جسے اللہ نے اور زیادہ بڑھا دیا، اور جو جھوٹ وہ بولتے ہیں، اس کی پاداش میں ان کے لیے درد ناک سزا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@xviii{جب کبھی ان سے کہا گیا کہ زمین پر فساد برپا نہ کرو تو انہوں نے یہی کہا کہ ہم تو اصلاح کرنے والے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@xix{خبردار! حقیقت میں یہی لوگ مفسد ہیں مگر انہیں شعور نہیں ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@xx{اور جب ان سے کہا گیا جس طرح دوسرے لوگ ایمان لائے ہیں اسی طرح تم بھی ایمان لاؤ تو انہوں نے یہی جواب دیا ``کیا ہم بیوقوفوں کی طرح ایمان لائیں؟" خبردار! حقیقت میں تو یہ خود بیوقوف ہیں، مگر یہ جانتے نہیں ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@xxi{جب یہ اہل ایمان سے ملتے ہیں، تو کہتے ہیں کہ ہم ایمان لائے ہیں اور جب علیحدگی میں اپنے شیطانوں سے ملتے ہیں، تو کہتے ہیں کہ اصل میں تو ہم تمہارے ساتھ ہیں اور ان لوگوں سے محض مذاق کر رہے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@xxii{اللہ ان سے مذاق کر رہا ہے، وہ ان کی رسی دراز کیے جاتا ہے، اور یہ اپنی سرکشی میں اندھوں کی طرح بھٹکتے چلے جاتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@xxiii{یہ وہ لوگ ہیں جنہوں نے ہدایت کے بدلے گمراہی خرید لی ہے، مگر یہ سودا ان کے لیے نفع بخش نہیں ہے اور یہ ہرگز صحیح راستے پر نہیں ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@xxiv{اِن کی مثال ایسی ہے جیسے ایک شخص نے آگ روشن کی اور جب اُس نے سارے ماحول کو روشن کر دیا تو اللہ نے اِن کا نور بصارت سلب کر لیا اور انہیں اس حال میں چھوڑ دیا کہ تاریکیوں میں انہیں کچھ نظر نہیں آتا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@xxv{یہ بہرے ہیں، گونگے ہیں، اندھے ہیں، یہ اب نہ پلٹیں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@xxvi{یا پھر ان کی مثال یوں سمجھو کہ آسمان سے زور کی بارش ہو رہی ہے اور اس کے ساتھ اندھیری گھٹا اور کڑک چمک بھی ہے، یہ بجلی کے کڑاکے سن کر اپنی جانوں کے خوف سے کانوں میں انگلیاں ٹھو نسے لیتے ہیں اور اللہ اِن منکرین حق کو ہر طرف سے گھیرے میں لیے ہوئے ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@xxvii{چمک سے ان کی حالت یہ ہو رہی ہے کہ گویا عنقریب بجلی اِن کی بصارت اُچک لے جائے گی جب ذرا کچھ روشنی انہیں محسوس ہوتی ہے تو اِس میں کچھ دور چل لیتے ہیں اور جب ان پر اندھیرا چھا جاتا ہے تو کھڑ ے ہو جاتے ہیں اللہ چاہتا تو ان کی سماعت اور بصارت بالکل ہی سَلب کر لیتا، یقیناً وہ ہر چیز پر قادر ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@xxviii{لوگو! بندگی اختیار کرو اپنے اُس رب کی جو تمہارا اور تم سے پہلے جو لوگ ہو گزرے ہیں اُن سب کا خالق ہے، تمہارے بچنے کی توقع اِسی صورت ہوسکتی ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@xxix{وہی تو ہے جِس نے تمہارے لیے زمین کا فرش بچھایا، آسمان کی چھت بنائی، اوپر سے پانی برسایا اور اس کے ذریعے سے ہر طرح کی پیداوار نکال کر تمہارے لیے رزق بہم پہنچایا پس جب تم یہ جانتے ہو تو دوسروں کو اللہ کا مد مقابل نہ ٹھیراؤ\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@xxx{اور اگر تمہیں اِس امر میں شک ہے کہ یہ کتا ب جو ہم نے اپنے بندے پر اتاری ہے، یہ ہماری ہے یا نہیں، تواس کے مانند ایک ہی سورت بنا لاؤ، اپنے سارے ہم نواؤں کو بلا لو، ایک اللہ کو چھوڑ کر باقی جس جس کی چاہو، مدد لے لو، اگر تم سچے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@xxxi{تو یہ کام کر کے دکھاؤ، لیکن اگر تم نے ایسا نہ کیا اور یقیناً کبھی نہیں کرسکتے، تو ڈرو اس آگ سے جس کا ایندھن بنیں گے انسان اور پتھر، جو مہیا کی گئی ہے منکرین حق کے لیے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@xxxii{اور اے پیغمبرؐ، جو لوگ اس کتاب پر ایمان لے آئیں اور (اس کے مطابق) اپنے عمل درست کر لیں، انہیں خوش خبری دے دو کہ اُن کے لیے ایسے باغ ہیں، جن کے نیچے نہریں بہتی ہوں گی ان باغوں کے پھل صورت میں دنیا کے پھلوں سے ملتے جلتے ہونگے جب کوئی پھل انہیں کھانے کو دیا جائے گا، تو وہ کہیں گے کہ ایسے ہی پھل اس سے پہلے دنیا میں ہم کو دیے جاتے تھے ان کے لیے وہاں پاکیزہ بیویاں ہونگی، اور وہ وہاں ہمیشہ رہیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@xxxiii{ہاں، اللہ اس سے ہرگز نہیں شرماتا کہ مچھر یا اس سے بھی حقیر تر کسی چیز کی تمثیلیں دے جو لوگ حق بات کو قبول کرنے والے ہیں، وہ انہی تمثیلوں کو دیکھ کر جان لیتے ہیں کہ یہ حق ہے جو ان کے رب ہی کی طرف سے آیا ہے، اور جو ماننے والے نہیں ہیں، وہ انہیں سن کر کہنے لگتے ہیں کہ ایسی تمثیلوں سے اللہ کو کیا سروکار؟ اس طرح اللہ ایک ہی بات سے بہتوں کو گمراہی میں مبتلا کر دیتا ہے اور بہتوں کو راہ راست دکھا دیتا ہے اور گمراہی میں وہ انہی کو مبتلا کرتا ہے، جو فاسق ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@xxxiv{اللہ کے عہد کو مضبوط باندھ لینے کے بعد توڑ دیتے ہیں اللہ نے جسے جوڑنے کا حکم دیا ہے اُسے کاٹتے ہیں، اور زمین میں فساد برپا کرتے ہیں حقیقت میں یہی لوگ نقصان اٹھانے والے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@xxxv{تم اللہ کے ساتھ کفر کا رویہ کیسے اختیار کرتے ہو حالانکہ تم بے جان تھے، اس نے تم کو زندگی عطا کی، پھر وہی تمھاری جان سلب کرے گا، پھر وہی تمہیں دوبارہ زندگی عطا کرے گا، پھر اسی کی طرف تمہیں پلٹ کر جانا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@xxxvi{وہی تو ہے، جس نے تمہارے لیے زمین کی ساری چیزیں پید ا کیں، پھر اوپر کی طرف توجہ فرمائی اور سات آسمان استوار کیے اور وہ ہر چیز کا علم رکھنے والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@xxxvii{پھر ذرا اس وقت کا تصور کرو جب تمہارے رب نے فرشتوں سے کہا تھا کہ ``میں زمین میں ایک خلیفہ بنانے والا ہوں" انہوں نے عرض کیا: ``کیا آپ زمین میں کسی ایسے کو مقر ر کرنے والے ہیں، جو اس کے انتظام کو بگاڑ دے گا اور خونریزیاں کرے گا آپ کی حمد و ثنا کے ساتھ تسبیح اور آپ کے لیے تقدیس تو ہم کر ہی رہے ہیں" فرمایا: ``میں جانتا ہوں جو کچھ تم نہیں جانتے"\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@xxxviii{اس کے بعد اللہ نے آدمؑ کو ساری چیزوں کے نام سکھائے، پھر انہیں فرشتوں کے سامنے پیش کیا اور فرمایا ``اگر تمہارا خیال صحیح ہے (کہ کسی خلیفہ کے تقرر سے انتظام بگڑ جائے گا) تو ذرا ان چیزوں کے نام بتاؤ"\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@xxxix{انہوں نے عرض کیا: ``نقص سے پاک تو آپ ہی کی ذات ہے، ہم تو بس اتنا ہی علم رکھتے ہیں، جتنا آپ نے ہم کو دے دیا ہے حقیقت میں سب کچھ جاننے اور سمجھنے والا آپ کے سوا کوئی نہیں"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@xl{پھر اللہ نے آدمؑ سے کہا: ``تم اِنہیں اِن چیزوں کے نام بتاؤ" جب اس نے ان کو اُن سب کے نام بتا دیے، تو اللہ نے فرمایا: ``میں نے تم سے کہا نہ تھا کہ میں آسمانوں اور زمین کی وہ ساری حقیقتیں جانتا ہوں جو تم سے مخفی ہیں، جو کچھ تم ظاہر کرتے ہو، وہ بھی مجھے معلوم ہے اور جو کچھ تم چھپاتے ہو، اسے بھی میں جانتا ہوں"\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@xli{پھر جب ہم نے فرشتوں کو حکم دیا کہ آدمؑ کے آگے جھک جاؤ، تو سب جھک گئے، مگر ابلیس نے انکار کیا وہ اپنی بڑائی کے گھمنڈ میں پڑ گیا اور نافرمانوں میں شامل ہو گیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@xlii{پھر ہم نے آدمؑ سے کہا کہ ``تم اور تمہاری بیوی، دونوں جنت میں رہو اور یہاں بفراغت جو چاہو کھاؤ، مگر اس درخت کا رُخ نہ کرنا، ورنہ ظالموں میں شمار ہو گے"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@xliii{آخر کار شیطان نے ان دونوں کو اس درخت کی ترغیب دے کر ہمارے حکم کی پیروی سے ہٹا دیا اور انہیں اُس حالت سے نکلوا کر چھوڑا، جس میں وہ تھے ہم نے حکم دیا کہ، ``اب تم سب یہاں سے اتر جاؤ، تم ایک دوسرے کے دشمن ہو اور تمہیں ایک خاص وقت تک زمین ٹھیرنا اور وہیں گزر بسر کرنا ہے"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@xliv{اس وقت آدمؑ نے اپنے رب سے چند کلمات سیکھ کر توبہ کی، جس کو اس کے رب نے قبول کر لیا، کیونکہ وہ بڑا معاف کرنے والا اور رحم فرمانے والا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@xlv{ہم نے کہا کہ، ``تم سب یہاں سے اتر جاؤ پھر جو میری طرف سے کوئی ہدایت تمہارے پاس پہنچے، تو جو لوگ میر ی ہدایت کی پیروی کریں گے، ان کے لیے کسی خوف اور رنج کا موقع نہ ہوگا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@xlvi{اور جو اس کو قبول کرنے سے انکار کریں گے اور ہماری آیات کو جھٹلائیں گے، وہ آگ میں جانے والے لوگ ہیں، جہاں وہ ہمیشہ رہیں گے"\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@xlvii{اے بنی اسرائیل! ذرا خیال کرو میری اس نعمت کا جو میں نے تم کو عطا کی تھی، میرے ساتھ تمھارا جو عہد تھا اُسے تم پورا کرو، تو میرا جو عہد تمہارے ساتھ تھا اُسے میں پورا کروں گا اور مجھ ہی سے تم ڈرو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@xlviii{اور میں نے جو کتاب بھیجی ہے اس پر ایمان لاؤ یہ اُس کتاب کی تائید میں ہے جو تمہارے پاس پہلے سے موجود تھی، لہٰذا سب سے پہلے تم ہی اس کے منکر نہ بن جاؤ تھوڑی قیمت پر میری آیات کو نہ بیچ ڈالو او ر میرے غضب سے بچو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@xlix{باطل کا رنگ چڑھا کر حق کو مشتبہ نہ بناؤ اور نہ جانتے بوجھتے حق کو چھپانے کی کوشش کرو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@l{نماز قائم کرو، زکوٰۃ دو اور جو لوگ میرے آگے جھک رہے ہیں اُن کے ساتھ تم بھی جھک جاؤ\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@li{تم دوسروں کو تو نیکی کا راستہ اختیار کرنے کے لیے کہتے ہو، مگر اپنے آپ کو بھول جاتے ہو؟ حالانکہ تم کتاب کی تلاوت کرتے ہو کیا تم عقل سے بالکل ہی کام نہیں لیتے؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@lii{صبر اور نماز سے مدد لو، بیشک نماز ایک سخت مشکل کام ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@liii{مگر ان فرماں بردار بندوں کے لیے مشکل نہیں ہے جو سمجھتے ہیں کہ آخر کار انہیں اپنے رب سے ملنا اور اسی کی طرف پلٹ کر جانا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@liv{اے بنی اسرائیل! یاد کرو میری اُس نعمت کو، جس سے میں نے تمہیں نوازا تھا اور اس بات کو کہ میں نے تمہیں دنیا کی ساری قوموں پر فضیلت عطا کی تھی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@lv{اور ڈرو اُس دن سے جب کوئی کسی کے ذرا کام نہ آئے گا، نہ کسی کی طرف سے سفارش قبول ہوگی، نہ کسی کو فدیہ لے کر چھوڑا جائے گا، اور نہ مجرموں کو کہیں سے مدد مل سکے گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@lvi{یاد کرو وہ وقت، جب ہم نے تم کو فرعونیوں کی غلامی سے نجات بخشی اُنہوں نے تمہیں سخت عذاب میں مبتلا کر رکھا تھا، تمہارے لڑکوں کو ذبح کرتے تھے اور تمہاری لڑکیوں کو زندہ رہنے دیتے تھے اور اس حالت میں تمہارے رب کی طرف سے تمہاری بڑی آزمائش تھی\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@lvii{یاد کرو وہ وقت، جب ہم نے سمندر پھاڑ کر تمہارے لیے راستہ بنایا، پھر اس میں سے تمہیں بخیریت گزروا دیا، پھر وہیں تمہاری آنکھوں کے سامنے فرعونوں کو غرقاب کیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@lviii{یاد کرو، جب ہم نے موسیٰؑ کو چالیس شبانہ روز کی قرارداد پر بلایا، تو اس کے پیچھے تم بچھڑے کو اپنا معبود بنا بیٹھے اُس وقت تم نے بڑی زیادتی کی تھی\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@lix{مگر اس پر بھی ہم نے تمہیں معاف کر دیا کہ شاید اب تم شکر گزار بنو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@lx{یاد کرو کہ (ٹھیک اس وقت جب تم یہ ظلم کر رہے تھے) ہم نے موسیٰؑ کو کتاب اور فرقان عطا کی تاکہ تم اس کے ذریعے سے سیدھا راستہ پاسکو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@lxi{یاد کرو جب موسیٰؑ (یہ نعمت لیتے ہوئے پلٹا، تو اُس) نے اپنی قوم سے کہا کہ ``لوگو، تم نے بچھڑے کو معبود بنا کر اپنے اوپر سخت ظلم کیا ہے، لہٰذا تم لوگ اپنے خالق کے حضور توبہ کرو اور اپنی جانوں کو ہلاک کرو، اسی میں تمہارے خالق کے نزدیک تمہاری بہتری ہے" اُس وقت تمہارے خالق نے تمہاری توبہ قبول کر لی کہ وہ بڑا معاف کرنے والا اور رحم فرمانے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@lxii{یاد کرو جب تم نے موسیٰؑ سے کہا تھا کہ ہم تمہارے کہنے کا ہرگز یقین نہ کریں گے، جب تک کہ اپنی آنکھوں سے علانیہ خدا کو (تم سے کلام کرتے) نہ دیکھ لیں اس وقت تمہارے دیکھتے دیکھتے ایک زبردست صاعقے نے تم کو آ لیا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@lxiii{تم بے جان ہو کر گر چکے تھے، مگر پھر ہم نے تم کو جِلا اٹھایا، شاید کہ اس احسان کے بعد تم شکر گزار بن جاؤ\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@lxiv{ہم نے تم پر ابر کا سایہ کیا، من وسلویٰ کی غذا تمہارے لیے فراہم کی اور تم سے کہا کہ جو پاک چیزیں ہم نے تمہیں بخشی ہیں، اُنہیں کھاؤ، مگر تمہارے اسلاف نے جو کچھ کیا، وہ ہم پر ظلم نہ تھا، بلکہ انہوں نے آپ اپنے ہی اوپر ظلم کیا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@lxv{پھر یاد کرو جب ہم نے کہا تھا کہ، ``یہ بستی جو تمہارے سامنے ہے، اس میں داخل ہو جاؤ، اس کی پیداوار جس طرح چاہو، مزے سے کھاؤ، مگر بستی کے دروازے میں سجدہ ریز ہوتے ہو ئے داخل ہونا اور کہتے جانا حطۃ حطۃ، ہم تمہاری خطاؤں سے در گزر کریں گے اور نیکو کاروں کو مزید فضل و کرم سے نوازیں گے"\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@lxvi{مگر جو بات کہی گئی تھی، ظالموں نے اُسے بدل کر کچھ اور کر دیا آخر کار ہم نے ظلم کرنے والوں پر آسمان سے عذاب نازل کیا یہ سزا تھی ان نافرمانیوں کی، جو وہ کر رہے تھے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@lxvii{یاد کرو، جب موسیٰؑ نے اپنی قوم کے لیے پانی کی دعا کی تو ہم نے کہا کہ فلاں چٹان پر اپنا عصا مارو چنانچہ اس سے بارہ چشمے پھوٹ نکلے اور ہر قبیلے نے جان لیا کہ کونسی جگہ اس کے پانی لینے کی ہے اُس وقت یہ ہدایت کر دی گئی تھی کہ اللہ کا دیا ہوا رزق کھاؤ پیو، اور زمین میں فساد نہ پھیلاتے پھرو\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@lxviii{یاد کرو، جب تم نے کہا تھا کہ، ``اے موسیٰؑ، ہم ایک ہی طرح کے کھانے پر صبر نہیں کرسکتے اپنے رب سے دعا کرو کہ ہمارے لیے زمین کی پیداوار ساگ، ترکاری، کھیرا، ککڑی، گیہوں، لہسن، پیاز، دال وغیرہ پیدا کرے" تو موسیٰؑ نے کہا: ``کیا ایک بہتر چیز کے بجائے تم ادنیٰ درجے کی چیزیں لینا چاہتے ہو؟ اچھا، کسی شہری آبادی میں جا رہو جو کچھ تم مانگتے ہو، وہاں مل جائے گا" آخر کار نوبت یہاں تک پہنچی کہ ذلت و خواری اور پستی و بد حالی اُن پر مسلط ہو گئی اور وہ اللہ کے غضب میں گھر گئے یہ نتیجہ تھا اس کا کہ وہ اللہ کی آیات سے کفر کرنے لگے اور پیغمبروں کو ناحق قتل کرنے لگے یہ نتیجہ تھا ان کی نافرمانیوں کا اور اس بات کا کہ وہ حدود شرع سے نکل نکل جاتے تھے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@lxix{یقین جانو کہ نبی عربی کو ماننے والے ہوں یا یہودی، عیسائی ہوں یا صابی، جو بھی اللہ اور روزِ آخر پر ایمان لائے گا اور نیک عمل کرے گا، اُس کا اجر اس کے رب کے پاس ہے اور اس کے لیے کسی خوف اور رنج کا موقع نہیں ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@lxx{یاد کرو وہ وقت، جب ہم نے طُور کو تم پر اٹھا کر تم سے پختہ عہد لیا تھا اور کہا تھا کہ ``جو کتاب ہم تمہیں دے رہے ہیں اسے مضبوطی کے ساتھ تھامنا اور جو احکام و ہدایات اس میں درج ہیں انہیں یاد رکھنا اسی ذریعے سے توقع کی جاسکتی ہے کہ تم تقویٰ کی روش پر چل سکو گے"\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@lxxi{مگر اس کے بعد تم اپنے عہد سے پھِر گئے اس پر بھی اللہ کے فضل اور اس کی رحمت نے تمہارا ساتھ نہ چھوڑا، ورنہ تم کبھی کے تباہ ہو چکے ہوتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@lxxii{پھر تمہیں اپنی قوم کے اُن لوگوں کا قصہ تو معلوم ہی ہے جنہوں نے سبت کا قانون توڑا تھا ہم نے انہیں کہہ دیا کہ بندر بن جاؤ اور اس حال میں رہو کہ ہر طرف سے تم پر دھتکار پھٹکار پڑے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@lxxiii{اس طرح ہم نے اُن کے انجام کو اُس زمانے کے لوگوں اور بعد کی آنے والی نسلوں کے لیے عبرت اور ڈرنے والوں کے لیے نصیحت بنا کر چھوڑا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@lxxiv{پھر وہ واقعہ یاد کرو، جب موسیٰؑ نے اپنے قوم سے کہا کہ، اللہ تمہیں ایک گائے ذبح کرنے کا حکم دیتا ہے کہنے لگے کیا تم ہم سے مذاق کرتے ہو؟ موسیٰؑ نے کہا، میں اس سے خدا کی پناہ مانگتا ہوں کہ جاہلوں کی سی باتیں کروں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@lxxv{بولے اچھا، اپنے رب سے درخواست کرو کہ وہ ہمیں گائے کی کچھ تفصیل بتائے موسیٰؑ نے کہا، اللہ کا ارشاد ہے کہ وہ ایسی گائے ہونی چاہیے جو نہ بوڑھی ہو نہ بچھیا، بلکہ اوسط عمر کی ہو لہٰذا جو حکم دیا جاتا ہے اس کی تعمیل کرو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@lxxvi{پھر کہنے لگے اپنے رب سے یہ اور پوچھ دو کہ اُس کا رنگ کیسا ہو موسیٰؑ نے کہا وہ فرماتا ہے زرد رنگ کی گائے ہونی چاہیے، جس کا رنگ ایسا شوخ ہو کہ دیکھنے والوں کا جی خوش ہو جائے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@lxxvii{پھر بولے اپنے رب سے صاف صاف پوچھ کر بتاؤ کیسی گائے مطلوب ہے، ہمیں اس کی تعین میں اشتباہ ہو گیا ہے اللہ نے چاہا، تو ہم اس کا پتہ پالیں گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@lxxviii{موسیٰؑ نے جواب دیا: اللہ کہتا ہے کہ وہ ایسی گائے ہے جس سے خدمت نہیں لی جاتی، نہ زمین جوتتی ہے نہ پانی کھینچتی ہے، صحیح سالم اور بے داغ ہے، اس پر وہ پکار اٹھے کہ ہاں، اب تم نے ٹھیک پتہ بتایا ہے پھر انہوں نے اسے ذبح کیا، ورنہ وہ ایسا کرتے معلوم نہ ہوتے تھے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@lxxix{اور تمہیں یاد ہے وہ واقعہ جب تم نے ایک شخص کی جان لی تھی، پھر اس کے بارے میں جھگڑنے اور ایک دوسرے پر قتل کا الزام تھوپنے لگے تھے اور اللہ نے فیصلہ کر لیا تھا کہ جو کچھ تم چھپاتے ہو، اسے کھول کر رکھ دے گا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@lxxx{اُس وقت ہم نے حکم دیا کہ مقتول کی لاش کو اس کے ایک حصے سے ضرب لگاؤ دیکھو اس طرح اللہ مُردوں کو زندگی بخشتا ہے اور تمہیں اپنی نشانیاں دکھاتا ہے تاکہ تم سمجھو\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@lxxxi{مگر ایسی نشانیاں دیکھنے کے بعد بھی آخر کار تمہارے دل سخت ہوگئے، پتھروں کی طرف سخت، بلکہ سختی میں کچھ ان سے بھی بڑھے ہوئے، کیونکہ پتھروں میں سے تو کوئی ایسا بھی ہوتا ہے جس میں سے چشمے پھوٹ بہتے ہیں، کوئی پھٹتا ہے اور اس میں سے پانی نکل آتا ہے اور کوئی خدا کے خوف سے لرز کر گر بھی پڑتا ہے اللہ تمہارے کرتوتوں سے بے خبر نہیں ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@lxxxii{اے مسلمانو! اب کیا اِن لوگوں سے تم یہ توقع رکھتے ہو کہ تمہاری دعوت پر ایمان لے آئیں گے؟ حالانکہ ان میں سے ایک گروہ کا شیوہ یہ رہا ہے کہ اللہ کا کلام سنا اور پھر خوب سمجھ بوجھ کر دانستہ اس میں تحریف کی\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@lxxxiii{(محمد رسول اللہﷺ پر) ایمان لانے والوں سے ملتے ہیں تو کہتے ہیں کہ ہم بھی انہیں مانتے ہیں، اور جب آپس میں ایک دوسرے سے تخلیے کی بات چیت ہوتی ہے تو کہتے ہیں کہ بے وقوف ہوگئے ہو؟ اِن لوگوں کو وہ باتیں بتاتے ہو جو اللہ نے تم پر کھولی ہیں تاکہ تمہارے رب کے پاس تمہارے مقابلے میں انہیں حُجتّ؟ میں پیش کریں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@lxxxiv{اور کیا یہ جانتے نہیں ہیں کہ جو کچھ یہ چھپاتے ہیں اور جو کچھ ظاہر کرتے ہیں، اللہ کو سب باتوں کی خبر ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@lxxxv{ان میں ایک دوسرا گروہ امّیوں کا ہے، جو کتاب کا تو علم رکھتے نہیں، بس اپنی بے بنیاد امیدوں اور آرزوؤں کو لیے بیٹھے ہیں اور محض وہم و گمان پر چلے جا رہے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@lxxxvi{پس ہلاکت اور تباہی ہے اُن لوگوں کے لیے جو اپنے ہاتھوں سے شرع کا نوشتہ لکھتے ہیں، پھر لوگوں سے کہتے ہیں کہ یہ اللہ کے پاس سے آیا ہوا ہے تاکہ اس کے معاوضے میں تھوڑا سا فائدہ حاصل کر لیں ان کے ہاتھوں کا لکھا بھی ان کے لیے تباہی کا سامان ہے اور ان کی یہ کمائی بھی ان کے لیے موجب ہلاکت\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@lxxxvii{وہ کہتے ہیں کہ دوزخ کی آگ ہمیں ہرگز چھونے والی نہیں اِلّا یہ کہ چند روز کی سز ا مل جائے تو مل جائے اِن سے پوچھو، کیا تم نے اللہ سے کوئی عہد لے لیا ہے، جس کی خلاف ورزی وہ نہیں کرسکتا؟ یا بات یہ ہے کہ تم اللہ کے ذمے ڈال کر ایسی باتیں کہہ دیتے ہو جن کے متعلق تمہیں علم نہیں ہے کہ اُس نے ان کا ذمہ لیا ہے؟ آخر تمہیں دوزخ کی آگ کیوں نہ چھوئے گی؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@lxxxviii{جو بھی بدی کمائے گا اور اپنی خطا کاری کے چکر میں پڑا رہے گا، وہ دوزخی ہے او ر دوزخ ہی میں وہ ہمیشہ رہے گا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@lxxxix{اور جو لوگ ایمان لائیں گے اور نیک عمل کریں گے وہی جنتی ہیں اور جنت میں وہ ہمیشہ رہیں گے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@xc{یاد کرو، اسرائیل کی اولاد سے ہم نے پختہ عہد لیا تھا کہ اللہ کے سوا کسی کی عبادت نہ کرنا، ماں باپ کے ساتھ، رشتے داروں کے ساتھ، یتیموں اور مسکینوں کے ساتھ نیک سلوک کرنا، لوگوں سے بھلی بات کہنا، نماز قائم کرنا اور زکوٰۃ دینا، مگر تھوڑے آدمیوں کے سو ا تم سب اس عہد سے پھر گئے اور اب تک پھر ے ہوئے ہو\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@xci{پھر ذرا یاد کرو، ہم نے تم سے مضبوط عہد لیا تھا کہ آپس میں ایک دوسرے کا خون نہ بہانا اور نہ ایک دوسرے کو گھر سے بے گھر کرنا تم نے اس کا اقرار کیا تھا، تم خود اس پر گواہ ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@xcii{مگر آج وہی تم ہو کہ اپنے بھائی بندوں کو قتل کرتے ہو، اپنی برادری کے کچھ لوگوں کو بے خانماں کر دیتے ہو، ظلم و زیادتی کے ساتھ ان کے خلاف جتھے بندیاں کرتے ہو، اور جب وہ لڑائی میں پکڑے ہوئے تمہارے پاس آتے ہیں، تو ان کی رہائی کے لیے فدیہ کا لین دین کرتے ہو، حالانکہ انہیں ان کے گھروں سے نکالنا ہی سرے سے تم پر حرام تھا تو کیا تم کتاب کے ایک حصے پر ایمان لاتے ہو اور دوسرے حصے کے ساتھ کفر کرتے ہو پھر تم میں سے جو لوگ ایسا کریں، ان کی سزا اس کے سوا اور کیا ہے کہ دنیا کی زندگی میں ذلیل و خوار ہو کر رہیں اور آخرت میں شدید ترین عذاب کی طرف پھیر دیے جائیں؟ اللہ ان حرکات سے بے خبر نہیں ہے، جو تم کر رہے ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@xciii{یہ وہ لوگ ہیں جنہوں نے آخرت بیچ کر دنیا کی زندگی خرید لی ہے، لہٰذا نہ اِن کی سزا میں کوئی تخفیف ہوگی اور نہ انہیں کوئی مدد پہنچ سکے گی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@xciv{ہم نے موسیٰؑ کو کتاب دی، اس کے بعد پے در پے رسول بھیجے، آخر کار عیسیٰؑ ابن مریمؑ کو روشن نشانیاں دے کر بھیجا اور روح پاک سے اس کی مدد کی پھر یہ تمہارا کیا ڈھنگ ہے کہ جب بھی کوئی رسول تمہاری خواہشات نفس کے خلاف کوئی چیز لے کر تمہارے پاس آیا، تو تم نے اس کے مقابلے میں سرکشی ہی کی، کسی کو جھٹلایا اور کسی کو قتل کر ڈالا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@xcv{وہ کہتے ہیں، ہمارے دل محفوظ ہیں نہیں، اصل بات یہ ہے کہ ان کے کفر کی وجہ سے ان پر اللہ کی پھٹکار پڑی ہے، اس لیے وہ کم ہی ایمان لاتے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@xcvi{اور اب جو ایک کتاب اللہ کی طرف سے ان کے پاس آئی ہے، اس کے ساتھ ان کا کیا برتاؤ ہے؟ باوجود یہ کہ وہ اس کتاب کی تصدیق کرتی ہے جو ان کے پاس پہلے سے موجو د تھی، باوجود یہ کہ اس کی آمد سے پہلے وہ خود کفار کے مقابلے میں فتح و نصرت کی دعائیں مانگا کرتے تھے، مگر جب وہ چیز آ گئی، جسے وہ پہچان بھی گئے تو، انہوں نے اسے ماننے سے انکار کر دیا خدا کی لعنت اِن منکرین پر\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@xcvii{کیسا برا ذریعہ ہے جس سے یہ اپنے نفس کی تسلی حاصل کرتے ہیں کہ جو ہدایت اللہ نے نازل کی ہے، اس کو قبول کرنے سے صرف اِس ضد کی بنا پر انکار کر رہے ہیں کہ اللہ نے اپنے فضل (وحی و رسالت) سے اپنے جس بندے کو خود چاہا، نواز دیا! لہٰذا اب یہ غضب بالائے غضب کے مستحق ہوگئے ہیں اور ایسے کافروں کے لیے سخت آمیز سزا مقرر ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@xcviii{جب اُن سے کہا جاتا ہے کہ جو کچھ اللہ نے نازل کیا ہے اس پر ایمان لاؤ، تو وہ کہتے ہیں ``ہم تو صرف اُس چیز پر ایمان لاتے ہیں، جو ہمارے ہاں (یعنی نسل اسرائیل) میں اتری ہے" اس دائرے کے باہر جو کچھ آیا ہے، اسے ماننے سے وہ انکار کرتے ہیں، حالانکہ وہ حق ہے اور اُس تعلیم کی تصدیق و تائید کر رہا ہے جو ان کے ہاں پہلے سے موجود تھی اچھا، ان سے کہو: اگر تم اس تعلیم ہی پر ایمان رکھنے والے ہو جو تمہارے ہاں آئی تھی، تو اس سے پہلے اللہ کے اُن پیغمبروں کو (جو خود بنی اسرائیل میں پیدا ہوئے تھے) کیوں قتل کرتے رہے؟\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@xcix{تمہارے پاس موسیٰؑ کیسی کیسی روشن نشانیوں کے ساتھ آیا پھر بھی تم ایسے ظالم تھے کہ اس کے پیٹھ موڑتے ہی بچھڑے کو معبود بنا بیٹھے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@c{پھر ذرا اُس میثاق کو یاد کرو، جو طُور کو تمہارے اوپر اٹھا کر ہم نے تم سے لیا تھا ہم نے تاکید کی تھی کہ جو ہدایات ہم دے رہے ہیں، ان کی سختی کے ساتھ پابندی کرو اور کان لگا کر سنو تمہارے اسلاف نے کہا کہ ہم نے سن لیا، مگر مانیں گے نہیں اور ان کی باطل پرستی کا یہ حال تھا کہ دلوں میں ان کے بچھڑا ہی بسا ہوا تھا کہو: اگر تم مومن ہو، تو عجیب ایمان ہے، جو ایسی بری حرکات کا تمہیں حکم دیتا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ci{اِن سے کہو کہ اگر واقعی اللہ کے نزدیک آخرت کا گھر تمام انسانوں کو چھوڑ کر صرف تمہارے ہی لیے مخصوص ہے، تب تو تمہیں چاہیے کہ موت کی تمنا کرو، اگر تم اپنے اس خیال میں سچے ہو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@cii{یقین جانو کہ یہ کبھی اس کی تمنا نہ کریں گے، اس لیے کہ اپنے ہاتھوں جو کچھ کما کر انہوں نے وہاں بھیجا ہے، اس کا اقتضا یہی ہے (کہ یہ وہاں جانے کی تمنا نہ کریں) اللہ ان ظالموں کے حال سے خوب واقف ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ciii{تم انہیں سب سے بڑھ کر جینے کا حریص پاؤ گے حتیٰ کہ یہ اس معاملے میں مشرکوں سے بھی بڑھے ہوئے ہیں ان میں سے ایک ایک شخص یہ چاہتا ہے کہ کسی طرح ہزار برس جیے، حالانکہ لمبی عمر بہرحال اُسے عذاب سے تو دور نہیں پھینک سکتی جیسے کچھ اعمال یہ کر رہے ہیں، اللہ تو انہیں دیکھ ہی رہا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@civ{اِن سے کہو کہ جو کوئی جبریل سے عداوت رکھتا ہو، اسے معلوم ہونا چاہیے کہ جبریل نے اللہ کے اِذن سے یہ قرآن تمہارے قلب پر نازل کیا ہے، جو پہلے آئی ہوئی کتابوں کی تصدیق و تائید کرتا ہے اور ایمان لانے والوں کے لیے ہدایت اور کامیابی کی بشارت بن کر آیا ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cv{(اگر جبریل سے ان کی عداوت کا سبب یہی ہے، تو کہہ دو کہ) جو اللہ اور اس کے فرشتوں اور اس کے رسولوں اور جبریل اور میکائیل کے دشمن ہیں، اللہ ان کافروں کا دشمن ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cvi{ہم نے تمہاری طرف ایسی آیات نازل کی ہیں جو صاف صاف حق کا اظہار کر نے والی ہیں اور ان کی پیروی سے صرف وہی لوگ انکار کرتے ہیں، جو فاسق ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cvii{کیا ہمیشہ ایسا ہی نہیں ہوتا رہا ہے کہ جب انہوں نے کوئی عہد کیا، تو ان میں سے ایک نہ ایک گروہ نے اسے ضرور ہی بالا ئے طاق رکھ دیا؟ بلکہ ان میں سے اکثر ایسے ہی ہیں، جو سچے دل سے ایمان نہیں لاتے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cviii{اور جب ان کے پاس اللہ کی طرف سے کوئی رسول اس کتاب کی تصدیق و تائید کرتا ہوا آیا جو ان کے ہاں پہلے سے موجود تھی، تو اِن اہل کتاب میں سے ایک گروہ نے کتاب اللہ کو اس طرح پس پشت ڈالا، گویا کہ وہ کچھ جانتے ہی نہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cix{اور لگے اُن چیزوں کی پیروی کرنے، جو شیا طین، سلیمانؑ کی سلطنت کا نام لے کر پیش کیا کرتے تھے، حالانکہ سلیمانؑ نے کبھی کفر نہیں کیا، کفر کے مرتکب تو وہ شیاطین تھے جو لوگوں کو جادو گری کی تعلیم دیتے تھے وہ پیچھے پڑے اُس چیز کے جو بابل میں دو فرشتوں، ہاروت و ماروت پر نازل کی گئی تھی، حالانکہ وہ (فرشتے) جب بھی کسی کو اس کی تعلیم دیتے تھے، تو پہلے صاف طور پر متنبہ کر دیا کرتے تھے کہ ``دیکھ، ہم محض ایک آزمائش ہیں، تو کفر میں مبتلا نہ ہو" پھر بھی یہ لوگ اُن سے وہ چیز سیکھتے تھے، جس سے شوہر اور بیوی میں جدائی ڈال دیں ظاہر تھا کہ اذنِ الٰہی کے بغیر وہ اس ذریعے سے کسی کو بھی ضرر نہ پہنچا سکتے تھے، مگراس کے باوجود وہ ایسی چیز سیکھتے تھے جو خود ان کے لیے نفع بخش نہیں، بلکہ نقصان د ہ تھی اور انہیں خوب معلوم تھا کہ جو اس چیز کا خریدار بنا، اس کے لیے آخرت میں کوئی حصہ نہیں کتنی بری متاع تھی جس کے بدلے انہوں نے اپنی جانوں کو بیچ ڈالا، کاش انہیں معلوم ہوتا!\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cx{اگر وہ ایمان اور تقویٰ اختیار کرتے، تو اللہ کے ہاں اس کا جو بدلہ ملتا، وہ ان کے لیے زیادہ بہتر تھا، کاش اُنہیں خبر ہوتی\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cxi{اے لوگو جو ایمان لائے ہو: رَاعِناَ نہ کہا کرو، بلکہ اُنظرنَا کہو اور توجہ سے بات کو سنو، یہ کافر تو عذاب الیم کے مستحق ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cxii{یہ لوگ جنہوں نے دعوت حق کو قبول کرنے سے انکار کر دیا ہے، خواہ اہل کتاب میں سے ہوں یا مشرک ہوں، ہرگز یہ پسند نہیں کرتے کہ تمہارے رب کی طرف سے تم پر کوئی بھلائی نازل ہو، مگر اللہ جس کو چاہتا ہے، اپنی رحمت کے لیے چن لیتا ہے اور وہ بڑا فضل فرمانے والا ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cxiii{ہم اپنی جس آیت کو منسوخ کر دیتے ہیں یا بُھلا دیتے ہیں، اس کی جگہ اس سے بہتر لے آتے ہیں یا کم از کم ویسی ہی کیا تم جانتے نہیں ہو کہ اللہ ہر چیز پر قدرت رکھتا ہے؟\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cxiv{کیا تمہیں خبر نہیں ہے کہ زمیں اور آسمان کی فرمانروائی اللہ ہی کے لیے ہے اور اس کے سوا کوئی تمہاری خبر گیری کرنے اور تمہاری مدد کرنے والا نہیں ہے؟\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cxv{پھر کیا تم اپنے رسول سے اس قسم کے سوالات اور مطالبہ کرنا چاہتے ہو، جیسے اس سے پہلے موسیٰؑ سے کیے جا چکے ہیں؟ حالانکہ جس شخص نے ایمان کی روش کو کفر کی روش سے بدل لیا وہ راہ راست سے بھٹک گیا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cxvi{اہل کتاب میں سے اکثر لوگ یہ چاہتے ہیں کہ کسی طرح تمہیں ایمان سے پھیر کر پھر کفر کی طرف پلٹا لے جائیں اگرچہ حق ان پر ظاہر ہو چکا ہے، مگر اپنے نفس کے حسد کی بنا پر تمہارے لیے ان کی یہ خواہش ہے اس کے جواب میں تم عفو و در گزر سے کام لو یہاں تک کہ اللہ خود ہی اپنا فیصلہ نافذ کر دے مطمئن رہو کہ اللہ تعالیٰ ہر چیز پر قدرت رکھتا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cxvii{نماز قائم کرو اور زکوٰۃ دو تم اپنی عاقبت کے لیے جو بھلائی کما کر آگے بھیجو گے، اللہ کے ہاں اسے موجود پاؤ گے جو کچھ تم کرتے ہو، وہ سب اللہ کی نظر میں ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cxviii{ان کا کہنا ہے کہ کوئی شخص جنت میں نہ جائے گا جب تک کہ وہ یہودی نہ ہو (یا عیسائیوں کے خیال کے مطابق) عیسائی نہ ہو یہ ان کی تمنائیں ہیں ان سے کہو، اپنی دلیل پیش کرو، اگر تم اپنے دعوے میں سچے ہو\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cxix{دراصل نہ تمہاری کچھ خصوصیت ہے، نہ کسی اور کی حق یہ ہے کہ جو بھی اپنی ہستی کو اللہ کی اطاعت میں سونپ دے اور عملاً نیک روش پر چلے، اس کے لیے اس کے رب کے پاس اُس کا اجر ہے اور ایسے لوگوں کے لیے کسی خوف یا رنج کا کوئی موقع نہیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cxx{یہودی کہتے ہیں: عیسائیوں کے پاس کچھ نہیں عیسائی کہتے ہیں: یہودیوں کے پاس کچھ نہیں حالانکہ دونوں ہی کتاب پڑھتے ہیں اور اسی قسم کے دعوے ان لوگوں کے بھی ہیں، جن کے پاس کتاب کا علم نہیں ہے یہ اختلافات جن میں یہ لوگ مبتلا ہیں، ان کا فیصلہ اللہ قیامت کے روز کر دے گا\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cxxi{اوراس شخص سے بڑھ کر ظالم کون ہوگا جو اللہ کے معبدوں میں اس کے نام کی یاد سے روکے اور ان کی ویرانی کے درپے ہو؟ ایسے لوگ اس قابل ہیں کہ ان کی عبادت گاہوں میں قدم نہ رکھیں اور اگر وہاں جائیں بھی، تو ڈرتے ہوئے جائیں ان کے لیے تو دنیا میں رسوائی ہے اور آخرت میں عذاب عظیم\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cxxii{مشرق اور مغرب سب اللہ کے ہیں جس طرف بھی تم رخ کرو گے، اسی طرف اللہ کا رخ ہے اللہ بڑی وسعت والا اور سب کچھ جاننے والا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cxxiii{ان کا قول ہے کہ اللہ نے کسی کو بیٹا بنایا ہے اللہ پاک ہے ان باتوں سے اصل حقیقت یہ ہے کہ زمین اور آسمانوں کی تمام موجودات اس کی ملک ہیں، سب کے سب اس کے مطیع فرمان ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cxxiv{وہ آسمانوں اور زمین کا موجد ہے اور جس بات کا وہ فیصلہ کرتا ہے، اس کے لیے بس یہ حکم دیتا ہے کہ ``ہو جا" اور وہ ہو جاتی ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cxxv{نادان کہتے ہیں کہ اللہ خود ہم سے بات کیوں نہیں کرتا یا کوئی نشانی ہمارے پاس کیوں نہیں آتی؟ ایسی ہی باتیں اِن سے پہلے لوگ بھی کیا کرتے تھے اِن سب (اگلے پچھلے گمراہوں) کی ذہنیتیں ایک جیسی ہیں یقین لانے والوں کے لیے تو ہم نشانیاں صاف صاف نمایاں کر چکے ہیں\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cxxvi{(اس سے بڑھ کر نشانی کیا ہوگی کہ) ہم نے تم کو علم حق کے ساتھ خوش خبری دینے والا ور ڈرانے والا بنا کر بھیجا اب جو لوگ جہنم سے رشتہ جوڑ چکے ہیں، ان کی طرف سے تم ذمہ دار و جواب دہ نہیں ہو\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cxxvii{یہودی اور عیسائی تم سے ہرگز راضی نہ ہوں گے، جب تک تم ان کے طریقے پر نہ چلنے لگو صاف کہہ دوکہ راستہ بس وہی ہے، جو اللہ نے بتایا ہے ورنہ اگراُس علم کے بعد، جو تمہارے پاس آ چکا ہے، تم نے اُن کی خواہشات کی پیروی کی، تو اللہ کی پکڑ سے بچانے والا کوئی دوست اور مدد گار تمہارے لیے نہیں ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cxxviii{جن لوگوں کو ہم نے کتاب دی ہے، وہ اُسے اس طرح پڑھتے ہیں جیسا کہ پڑھنے کا حق ہے وہ اس پر سچے دل سے ایمان لاتے ہیں اور جواس کے ساتھ کفر کا رویہ اختیار کریں، وہی اصل میں نقصان اٹھانے والے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cxxix{اے بنی اسرائیل! یاد کرو میری وہ نعمت، جس سے میں نے تمہیں نواز ا تھا، اور یہ کہ میں نے تمہیں دنیا کی تمام قوموں پر فضیلت دی تھی\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cxxx{اور ڈرو اُس دن سے، جب کوئی کسی کے ذرا کام نہ آئے گا، نہ کسی سے فدیہ قبول کیا جائے گا، نہ کوئی سفارش ہی آدمی کو فائدہ دے گی، اور نہ مجرموں کو کہیں سے کوئی مدد پہنچ سکے گی\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cxxxi{یاد کرو کہ جب ابراہیمؑ کو اس کے رب نے چند باتوں میں آزما یا اور وہ اُن سب میں پورا اتر گیا، تو اس نے کہا: ``میں تجھے سب لوگوں کا پیشوا بنانے والا ہوں" ابراہیمؑ نے عرض کیا: ``اور کیا میری اولاد سے بھی یہی وعدہ ہے؟" اس نے جواب دیا: ``میرا وعدہ ظالموں سے متعلق نہیں ہے"\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cxxxii{اور یہ کہ ہم نے اس گھر (کعبے) کو لوگوں کے لیے مرکز اور امن کی جگہ قرار دیا تھا اور لوگوں کو حکم دیا تھا کہ ابراہیمؑ جہاں عبادت کے لیے کھڑا ہوتا ہے اس مقام کو مستقل جائے نماز بنا لو اور ابراہیمؑ اور ا سماعیل کو تاکید کی تھی کہ میرے گھر کو طواف اور اعتکاف اور رکوع اور سجدہ کرنے والوں کے لیے پاک رکھو\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cxxxiii{اور یہ کہ ابراہیمؑ نے دعا کی: ``اے میرے رب، اس شہر کو امن کا شہر بنا دے، اور اس کے باشندوں میں جو اللہ اور آخرت کو مانیں، انہیں ہر قسم کے پھلو ں کا رزق دے" جواب میں اس کے رب نے فرمایا: ``اور جو نہ مانے گا، دنیا کی چند روزہ زندگی کا سامان تومیں اُسے بھی دوں گا مگر آخرکار اُسے عذاب جہنم کی طرف گھسیٹوں گا، اور وہ بد ترین ٹھکانا ہے"\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cxxxiv{اور یاد کرو ابراہیمؑ اور اسمٰعیلؑ جب اس گھر کی دیواریں اٹھا رہے تھے، تو دعا کرتے جاتے تھے: ``اے ہمارے رب، ہم سے یہ خدمت قبول فرما لے، تو سب کی سننے اور سب کچھ جاننے والا ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cxxxv{اے رب، ہم دونوں کو اپنا مسلم (مُطیع فرمان) بنا، ہماری نسل سے ایک ایسی قوم اٹھا، جو تیری مسلم ہو، ہمیں اپنی عبادت کے طریقے بتا، اور ہماری کوتاہیوں سے در گزر فرما، تو بڑا معاف کرنے والا اور رحم فرمانے والا ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cxxxvi{اور اے رب، ان لوگوں میں خود انہیں کی قوم سے ایک ایسا رسول اٹھا ئیو، جو انہیں تیری آیات سنائے، ان کو کتاب اور حکمت کی تعلیم دے اور ان کی زندگیاں سنوارے تو بڑا مقتدر اور حکیم ہے"\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cxxxvii{اب کون ہے، جو ابراہیمؑ کے طریقے سے نفرت کرے؟ جس نے خود اپنے آپ کو حماقت و جہالت میں مبتلا کر لیا ہو، اس کے سو ا کون یہ حرکت کرسکتا ہے؟ ابراہیمؑ تو وہ شخص ہے، جس کو ہم نے دنیا میں اپنے کام کے لیے چُن لیا تھا اور آخرت میں اس کا شمار صالحین میں ہوگا\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cxxxviii{اس کا حال یہ تھا کہ جب اس کے رب نے اس سے کہا: ``مسلم ہو جا"، تو اس نے فوراً کہا: ``میں مالک کائنات کا ``مسلم" ہو گیا"\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cxxxix{اسی طریقے پر چلنے کی ہدایت اس نے اپنی اولاد کو کی تھی اور اسی کی وصیت یعقوبؑ اپنی اولاد کو کر گیا اس نے کہا تھا کہ: ``میرے بچو! اللہ نے تمہارے لیے یہی دین پسند کیا ہے لہٰذا مرتے دم تک مسلم ہی رہنا"\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cxl{پھر کیا تم اس وقت موجود تھے، جب یعقوبؑ اس دنیا سے رخصت ہو رہا تھا؟اس نے مرتے وقت اپنے بچوں سے پوچھا: ``بچو! میرے بعد تم کس کی بندگی کرو گے؟" ان سب نے جواب دیا: ``ہم اسی ایک خدا کی بندگی کریں گے جسے آپ نے اور آپ کے بزرگوں ابراہیمؑ، اسماعیلؑ اور اسحاقؑ نے خدا مانا ہے اور ہم اُسی کے مسلم ہیں"\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cxli{وہ کچھ لوگ تھے، جو گزر گئے جو کچھ انہوں نے کمایا، وہ اُن کے لیے ہے اور جو کچھ تم کماؤ گے، وہ تمہارے لیے ہے تم سے یہ نہ پوچھا جائے گا کہ وہ کیا کرتے تھے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cxlii{یہودی کہتے ہیں: یہودی ہو تو راہ راست پاؤ گے عیسائی کہتے ہیں: عیسائی ہو، تو ہدایت ملے گی اِن سے کہو: ``نہیں، بلکہ سب کو چھوڑ کر ابراہیمؑ کا طریقہ اور ابراہیمؑ مشر کو ں میں سے نہ تھا"\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cxliii{مسلمانو! کہو کہ: ``ہم ایمان لائے اللہ پر اور اس ہدایت پر جو ہماری طرف نازل ہوئی ہے اور جو ابراہیمؑ، اسماعیلؑ، اسحاقؑ، یعقوبؑ اور اولاد یعقوبؑ کی طرف نازل ہوئی تھی اور جو موسیٰؑ اور عیسیٰؑ اور دوسرے تمام پیغمبروں کو اُن کے رب کی طرف سے دی گئی تھی ہم ان کے درمیان کوئی تفریق نہیں کرتے اور ہم اللہ کے مسلم ہیں"\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cxliv{پھر اگر وہ اُسی طرح ایمان لائیں، جس طرح تم لائے ہو، تو ہدایت پر ہیں، اور اگراس سے منہ پھیریں، تو کھلی بات ہے کہ وہ ہٹ دھرمی میں پڑ گئے ہیں لہٰذا اطمینان رکھو کہ اُن کے مقابلے میں اللہ تمہاری حمایت کے لیے کافی ہے وہ سب کچھ سنتا اور جانتا ہے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cxlv{کہو: ``اللہ کا رنگ اختیار کرو اس کے رنگ سے اچھا اور کس کا رنگ ہوگا؟ اور ہم اُسی کی بندگی کرنے والے لوگ ہیں"\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cxlvi{اے نبیؐ! اِن سے کہو: ``کیا تم اللہ کے بارے میں ہم سے جھگڑتے ہو؟حالانکہ وہی ہمارا رب بھی ہے اور تمہارا رب بھی ہمارے اعمال ہمارے لیے ہیں، تمہارے اعمال تمہارے لیے، اور ہم اللہ ہی کے لیے اپنی بندگی کو خالص کر چکے ہیں\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cxlvii{یا پھر کیا تما را کہنا یہ ہے کہ ابراہیمؑ، اسماعیلؑ، اسحاقؑ، یعقوبؑ اور اولاد یعقوبؑ سب کے سب یہودی تھے یا نصرانی تھے؟ کہو: ``تم زیادہ جانتے ہو یا اللہ؟ اُس شخص سے بڑا ظالم اور کون ہوگا جس کے ذمے اللہ کی طرف سے ایک گواہی ہو اور وہ اُسے چھپائے؟ تمہاری حرکات سے اللہ غافل تو نہیں ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cxlviii{وہ کچھ لوگ تھے، جو گزر چکے اُن کی کمائی اُن کے لیے تھی اور تمہاری کمائی تمہارے لیے تم سے اُن کے اعمال کے متعلق سوال نہیں ہوگا"\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cxlix{نادان لوگ ضرور کہیں گے : اِنہیں کیا ہوا کہ پہلے یہ جس قبلے کی طرف رخ کر کے نماز پڑھتے تھے، اس سے یکایک پھر گئے؟ اے نبی، ان سے کہو: ``مشرق اور مغرب سب اللہ کے ہیں اللہ جسے چاہتا ہے، سیدھی راہ دکھا دیتا ہے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cl{اور اِسی طرح تو ہم نے تمہیں ایک ``امت وسط" بنایا ہے تاکہ تم دنیا کے لوگوں پر گواہ ہو اور رسول تم پر گواہ ہو پہلے جس طرف تم رخ کرتے تھے، اس کو تو ہم نے صرف یہ دیکھنے کے لیے قبلہ مقرر کیا تھا کہ کون رسول کی پیروی کرتا ہے اور کون الٹا پھر جاتا ہے یہ معاملہ تھا تو بڑا سخت، مگر اُن لوگوں کے لیے کچھ بھی سخت نہ ثابت ہوا، جو اللہ کی ہدایت سے فیض یاب تھے اللہ تمہارے اس ایمان کو ہرگز ضائع نہ کرے گا، یقین جانو کہ وہ لوگوں کے حق میں نہایت شفیق و رحیم ہے\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cli{یہ تمہارے منہ کا بار بار آسمان کی طرف اٹھنا ہم دیکھ رہے ہیں لو، ہم اُسی قبلے کی طرف تمہیں پھیرے دیتے ہیں، جسے تم پسند کرتے ہو مسجد حرام کی طرف رُخ پھیر دو اب جہاں کہیں تم ہو، اُسی کی طرف منہ کر کے نماز پڑھا کرو یہ لوگ جںہیں کتاب دی گئی تھی، خو ب جانتے ہیں کہ (تحویل قبلہ کا) یہ حکم ان کے رب ہی کی طرف سے ہے اور بر حق ہے، مگرا س کے باوجود جو کچھ یہ کر رہے ہیں، اللہ اس سے غافل نہیں ہے\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@clii{تم ان اہل کتاب کے پاس خواہ کوئی نشانی لے آؤ، ممکن نہیں کہ یہ تمہارے قبلے کی پیروی کرنے لگیں، اور نہ تمہارے لیے یہ ممکن ہے کہ ان کے قبلے کی پیروی کرو، اور ان میں سے کوئی گروہ بھی دوسرے کے قبلے کی پیروی کے لیے تیار نہیں ہے، او ر اگر تم نے اس علم کے بعد جو تمہارے پاس آ چکا ہے، ان کی خواہشات کی پیروی کی، تو یقیناً تمہارا شمار ظالموں میں ہوگا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cliii{جن لوگوں کو ہم نے کتاب دی ہے، وہ اِس مقام کو (جسے قبلہ بنایا گیا ہے) ایسا پہچانتے ہیں، جیسا اپنی اولاد کو پہچانتے ہیں مگر ان میں سے ایک گروہ جانتے بوجھتے حق کو چھپا رہا ہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cliv{یہ قطعی ایک امر حق ہے تمہارے رب کی طرف سے، لہٰذا اس کے متعلق تم ہرگز کسی شک میں نہ پڑو\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@clv{ہر ایک کے لیے ایک رُخ ہے، جس کی طرف وہ مڑتا ہے پس بھلا ئیوں کی طرف سبقت کرو جہاں بھی تم ہو گے، اللہ تمہیں پا لے گا اُس کی قدرت سے کوئی چیز باہر نہیں\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@clvi{تمہارا گزر جس مقام سے بھی ہو، وہیں اپنا رُخ (نماز کے وقت) مسجد حرام کی طرف پھیر دو، کیونکہ یہ تمہارے رب کا بالکل حق فیصلہ ہے اور اللہ تم لوگوں کے اعمال سے بے خبر نہیں ہے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@clvii{اور جہاں سے بھی تمہارا گزر ہو، اپنا رُخ مسجد حرام کی طرف پھیرا کرو، اور جہاں بھی تم ہو، اُسی کی طرف منہ کر کے نما ز پڑھو تاکہ لوگوں کو تمہارے خلاف کوئی حجت نہ ملے ہاں جو ظالم ہیں، اُن کی زبان کسی حال میں بند نہ ہوگی تو اُن سے تم نہ ڈرو، بلکہ مجھ سے ڈرو اور اس لیے کہ میں تم پر اپنی نعمت پوری کر دوں اور اس توقع پر کہ میرے اس حکم کی پیروی سے تم اسی طرح فلاح کا راستہ پاؤ گے\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@clviii{جس طرح (تمہیں اِس چیز سے فلاح نصیب ہوئی کہ) میں نے تمہارے درمیان خود تم میں سے ایک رسول بھیجا، جو تمہیں میری آیات سناتا ہے، تمہاری زندگیوں کو سنوارتا ہے، تمہیں کتاب اور حکمت کی تعلیم دیتا ہے، اور تمہیں وہ باتیں سکھاتا ہے، جو تم نہ جانتے تھے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@clix{لہٰذا تم مجھے یاد رکھو، میں تمہیں یاد رکھوں گا اور میرا شکر ادا کرو، کفران نعمت نہ کرو\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@clx{اے لوگو جو ایمان لائے ہو، صبر اور نماز سے مدد لو اللہ صبر کرنے والوں کے ساتھ ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@clxi{اور جو لوگ اللہ کی راہ میں مارے جائیں، انہیں مُردہ نہ کہو، ایسے لوگ تو حقیقت میں زندہ ہیں، مگر تمہیں ان کی زندگی کا شعور نہیں ہوتا\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@clxii{اور ہم ضرور تمہیں خوف و خطر، فاقہ کشی، جان و مال کے نقصانات اور آمدنیوں کے گھاٹے میں مبتلا کر کے تمہاری آزمائش کریں گے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@clxiii{اِن حالات میں جو لوگ صبر کریں اور جب کوئی مصیبت پڑے، تو کہیں کہ: ``ہم اللہ ہی کے ہیں اور اللہ ہی کی طرف ہمیں پلٹ کر جانا ہے"\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@clxiv{انہیں خوش خبری دے دو ان پر ان کے رب کی طرف سے بڑی عنایات ہوں گی، اُس کی رحمت اُن پر سایہ کرے گی اور ایسے ہی لوگ راست رَو ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@clxv{یقیناً صفا اور مَروہ، اللہ کی نشانیوں میں سے ہیں لہٰذا جو شخص بیت اللہ کا حج یا عمرہ کرے، اس کے لیے کوئی گناہ کی بات نہیں کہ وہ اِن دونوں پہاڑیوں کے درمیان سعی کر لے اور جو برضا و رغبت کوئی بھلائی کا کام کرے گا، اللہ کو اس کا علم ہے او ر وہ اس کی قدر کرنے والا ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@clxvi{جو لوگ ہماری نازل کی ہوئی روشن تعلیمات اور ہدایات کو چھپاتے ہیں، درآں حالیکہ ہم انہیں سب انسانوں کی رہنمائی کے لیے اپنی کتاب میں بیان کر چکے ہیں، یقین جانو کہ اللہ بھی ان پر لعنت کرتا ہے اور تمام لعنت کرنے والے بھی اُن پر لعنت بھیجتے ہیں\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@clxvii{البتہ جو اس روش سے باز آ جائیں اور اپنے طرز عمل کی اصلاح کر لیں اور جو کچھ چھپاتے تھے، اُسے بیان کرنے لگیں، اُن کو میں معاف کر دوں گا اور میں بڑا در گزر کرنے والا اور رحم کرنے والا ہوں\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@clxviii{جن لوگوں نے کفر کا رویہ اختیار کیا اور کفر کی حالت ہی میں جان دی، ان پر اللہ اور فرشتوں اور تمام انسانوں کی لعنت ہے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@clxix{اسی لعنت زدگی کی حالت میں وہ ہمیشہ رہیں گے، نہ اُن کی سز امیں تخفیف ہوگی اور نہ انہیں پھر کوئی دوسری مہلت دی جائے گی\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@clxx{تمہارا خدا ایک ہی خدا ہے، اُس رحمان اور رحیم کے سوا کوئی اور خدا نہیں ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@clxxi{(اِس حقیقت کو پہچاننے کے لیے اگر کوئی نشانی اور علامت درکا رہے تو) جو لوگ عقل سے کام لیتے ہیں اُن کے لیے آسمانوں اور زمین کی ساخت میں، رات اور دن کے پیہم ایک دوسرے کے بعد آنے میں، اُن کشتیوں میں جوا نسان کے نفع کی چیزیں لیے ہوئے دریاؤں اور سمندروں میں چلتی پھرتی ہیں، بارش کے اُس پانی میں جسے اللہ اوپر سے برساتا ہے پھر اس کے ذریعے سے زمین کو زندگی بخشتا ہے اور اپنے اِسی انتظام کی بدولت زمین میں ہر قسم کی جان دار مخلوق پھیلاتا ہے، ہواؤں کی گردش میں، اور اُن بادلوں میں جو آسمان اور زمین کے درمیان تابع فرمان بنا کر رکھے گئے ہیں، بے شمار نشانیاں ہیں\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@clxxii{(مگر وحدت خداوندی پر دلالت کرنے والے اِن کھلے کھلے آثار کے ہوتے ہوئے بھی) کچھ لوگ ایسے ہیں جو اللہ کے سوا دوسروں کو اس کا ہمسر اور مدمقابل بناتے ہیں اور اُن کے ایسے گرویدہ ہیں جیسے اللہ کے ساتھ گرویدگی ہونی چاہیے حالانکہ ایمان رکھنے والے لوگ سب سے بڑھ کر اللہ کو محبوب رکھتے ہیں کاش، جو کچھ عذاب کو سامنے دیکھ کر انہیں سُوجھنے والا ہے وہ آج ہی اِن ظالموں کو سوجھ جائے کہ ساری طاقتیں اور سارے اختیارات اللہ ہی کے قبضے میں ہیں اور یہ کہ اللہ سزا دینے میں بھی بہت سخت ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@clxxiii{جب وہ سزا دے گا اس وقت کیفیت یہ ہوگی کہ وہی پیشوا اور رہنما، جن کی دنیا میں پیروی کی گئی تھی، اپنے پیروؤں سے بے تعلقی ظاہر کریں گے، مگر سزا پا کر رہیں گے اور ان کے سارے اسباب و وسائل کا سلسلہ کٹ جائے گا\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@clxxiv{اور وہ لوگ جو دنیا میں اُن کی پیروی کرتے تھے، کہیں گے کہ کاش ہم کو پھر ایک موقع دیا جاتا تو جس طرح آج یہ ہم سے بیزاری ظاہر کر رہے ہیں، ہم اِن سے بیزار ہو کر دکھا دیتے یوں اللہ اِن لوگوں کے وہ اعمال جو یہ دنیا میں کر رہے ہیں، ان کے سامنے اِس طرح لائے گا کہ یہ حسرتوں اور پشیمانیوں کے ساتھ ہاتھ ملتے رہیں گے مگر آگ سے نکلنے کی کوئی راہ نہ پائیں گے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@clxxv{لوگو! زمین میں جو حلال اور پاک چیزیں ہیں انہیں کھاؤ اور شیطان کے بتائے ہوئے راستوں پر نہ چلو وہ تمہارا کھلا دشمن ہے\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@clxxvi{تمہیں بدی اور فحش کا حکم دیتا ہے اور یہ سکھاتا ہے کہ تم اللہ کے نام پر وہ باتیں کہو جن کے متعلق تمہیں علم نہیں ہے کہ وہ اللہ نے فرمائی ہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@clxxvii{ان سے جب کہا جاتا ہے کہ اللہ نے جو احکام نازل کیے ہیں اُن کی پیروی کرو تو جواب دیتے ہیں کہ ہم تو اسی طریقے کی پیروی کریں گے جس پر ہم نے اپنے باپ دادا کو پایا ہے اچھا اگر ان کے باپ دادا نے عقل سے کچھ بھی کام نہ لیا ہو اور راہ راست نہ پائی ہو تو کیا پھر بھی یہ انہیں کی پیروی کیے چلے جائیں گے؟\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@clxxviii{یہ لوگ جنہوں نے خدا کے بتائے ہوئے طریقے پر چلنے سے انکار کر دیا ہے اِن کی حالت بالکل ایسی ہے جیسے چرواہا جانوروں کو پکارتا ہے اور وہ ہانک پکار کی صدا کے سوا کچھ نہیں سنتے یہ بہرے ہیں، گونگے ہیں، اندھے ہیں، اس لیے کوئی بات ان کی سمجھ میں نہیں آتی\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@clxxix{اے لوگو جو ایمان لائے ہو، اگر تم حقیقت میں اللہ کی بندگی کرنے والے ہو تو جو پاک چیزیں ہم نے تمہیں بخشی ہیں اُنہیں بے تکلف کھاؤ اور اللہ کا شکر ادا کرو\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@clxxx{اللہ کی طرف سے اگر کوئی پابندی تم پر ہے تو وہ یہ ہے کہ مُردار نہ کھاؤ، خون سے اور سور کے گوشت سے پرہیز کرو اور کوئی چیز نہ کھاؤ جس پر اللہ کے سوا کسی اور کا نام لیا گیا ہو ہاں جو شخص مجبوری کی حالت میں ہو اور وہ ان میں سے کوئی چیز کھا لے بغیر اس کے کہ وہ قانون شکنی کا ارادہ رکھتا ہو یا ضرورت کی حد سے تجاوز کر ے، تو اس پر کچھ گناہ نہیں، اللہ بخشنے والا اور رحم کرنے والا ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@clxxxi{حق یہ ہے کہ جو لوگ اُن احکام کو چھپاتے ہیں جو اللہ نے اپنی کتاب میں ناز ل کیے ہیں اور تھوڑے سے دُنیوی فائدوں پرا نہیں بھینٹ چڑھاتے ہیں، وہ دراصل اپنے پیٹ آگ سے بھر رہے ہیں قیامت کے روز اللہ ہرگز ان سے بات نہ کرے گا، نہ اُنہیں پاکیزہ ٹھیرائے گا، اور اُن کے لیے دردناک سزا ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@clxxxii{یہ وہ لوگ ہیں جنہوں نے ہدایت کے بدلے ضلالت خریدی اور مغفرت کے بدلے عذاب مول لے لیا کیسا عجیب ہے ان کا حوصلہ کہ جہنم کا عذاب برداشت کرنے کے لیے تیار ہیں\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@clxxxiii{یہ سب کچھ اس وجہ سے ہوا کہ اللہ نے تو ٹھیک ٹھیک حق کے مطابق کتاب نازل کی تھی مگر جن لوگوں نے کتاب میں اختلاف نکالے وہ اپنے جھگڑوں میں حق سے بہت دور نکل گئے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@clxxxiv{نیکی یہ نہیں ہے کہ تم نے اپنے چہرے مشرق کی طرف کر لیے یا مغرب کی طرف، بلکہ نیکی یہ ہے کہ آدمی اللہ کو اور یوم آخر اور ملائکہ کو اور اللہ کی نازل کی ہوئی کتاب اور اس کے پیغمبروں کو دل سے مانے اور اللہ کی محبت میں اپنا دل پسند مال رشتے داروں اور یتیموں پر، مسکینوں او رمسافروں پر، مدد کے لیے ہاتھ پھیلانے والوں پر اور غلامو ں کی رہائی پر خرچ کرے، نماز قائم کرے اور زکوٰۃ دے اور نیک وہ لوگ ہیں کہ جب عہد کریں تو اُسے وفا کریں، اور تنگی و مصیبت کے وقت میں اور حق و باطل کی جنگ میں صبر کریں یہ ہیں راستباز لوگ اور یہی لوگ متقی ہیں\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@clxxxv{ا ے لوگو جو ایمان لائے ہو، تمہارے لیے قتل کے مقدموں میں قصاص کا حکم لکھ دیا گیا ہے آزاد آدمی نے قتل کیا ہو تو اس آزاد ہی سے بدلہ لیا جائے، غلام قاتل ہو تو وہ غلام ہی قتل کیا جائے، اور عورت اِس جرم کی مرتکب ہو توا س عورت ہی سے قصاص لیا جائے ہاں اگر کسی قاتل کے ساتھ اس کا بھائی کچھ نرمی کرنے کے لیے تیار ہو، تو معروف طریقے کے مطابق خوں بہا کا تصفیہ ہونا چاہیے اور قاتل کو لازم ہے کہ راستی کے ساتھ خوں بہا ادا کرے یہ تمہارے رب کی طرف سے تخفیف اور رحمت ہے اس پر بھی جو زیادتی کرے، اس کے لیے دردناک سزا ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@clxxxvi{عقل و خرد رکھنے والو! تمہارے لیے قصاص میں زندگی ہے اُمید ہے کہ تم اس قانون کی خلاف ورزی سے پرہیز کرو گے\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@clxxxvii{تم پر فرض کیا گیا ہے کہ جب تم میں سے کسی کی موت کا وقت آئے اور وہ اپنے پیچھے مال چھوڑ رہا ہو، تو والدین اور رشتہ داروں کے لیے معروف طریقے سے وصیت کرے یہ حق ہے متقی لوگوں پر\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@clxxxviii{پھر جنہوں نے وصیت سنی اور بعد میں اُسے بدل ڈالا، توا س کا گناہ ان بدلنے والوں پر ہوگا اللہ سب کچھ سنتا اور جانتا ہے\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@clxxxix{البتہ جس کو یہ اندیشہ ہو کہ وصیت کرنے والے نے نادانستہ یا قصداً حق تلفی کی ہے، اور پھر معاملے سے تعلق رکھنے والوں کے درمیان وہ اصلاح کرے، تو اس پر کچھ گناہ نہیں ہے، اللہ بخشنے والا اور رحم فرمانے والا ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cxc{اے لوگو جو ایمان لائے ہو، تم پر روزے فرض کر دیے گئے، جس طرح تم سے پہلے انبیا کے پیروؤں پر فرض کیے گئے تھے اس سے توقع ہے کہ تم میں تقویٰ کی صفت پیدا ہوگی\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cxci{چند مقرر دنوں کے روزے ہیں اگر تم میں سے کوئی بیمار ہو، یا سفر پر ہو تو دوسرے دنوں میں اتنی ہی تعداد پوری کر لے اور جو لوگ روزہ رکھنے کی قدرت رکھتے ہوں (پھر نہ رکھیں) تو وہ فدیہ دیں ایک روزے کا فدیہ ایک مسکین کو کھانا کھلانا ہے اور جو اپنی خوشی سے کچھ زیادہ بھلائی کرے تو یہ اسی کے لیے بہتر ہے لیکن اگر تم سمجھو، تو تمہارے حق میں اچھا یہی ہے کہ روزہ رکھو\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cxcii{رمضان وہ مہینہ ہے، جس میں قرآن نازل کیا گیا جو انسانوں کے لیے سراسر ہدایت ہے اور ایسی واضح تعلیمات پر مشتمل ہے، جو راہ راست دکھانے والی اور حق و باطل کا فرق کھول کر رکھ دینے والی ہیں لہٰذا اب سے جو شخص اس مہینے کو پائے، اُس کو لازم ہے کہ اِس پورے مہینے کے روزے رکھے اور جو کوئی مریض ہو یا سفر پر ہو، تو وہ دوسرے دنوں میں روزوں کی تعداد پوری کرے اللہ تمہارے ساتھ نرمی کرنا چاہتا ہے، سختی کرنا نہیں چاہتا اس لیے یہ طریقہ تمہیں بتایا جا رہا ہے تاکہ تم روزوں کی تعداد پوری کرسکو اور جس ہدایت سے اللہ نے تمہیں سرفراز کیا ہے، اُس پر اللہ کی کبریا ئی کا اظہار و اعتراف کرو اور شکر گزار بنو\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cxciii{اور اے نبیؐ، میرے بندے اگر تم سے میرے متعلق پوچھیں، تو اُنہیں بتا دو کہ میں ان سے قریب ہی ہوں پکارنے والا جب مجھے پکارتا ہے، میں اُس کی پکار سنتا اور جواب دیتا ہوں لہٰذا انہیں چاہیے کہ میری دعوت پر لبیک کہیں اور مجھ پر ایمان لائیں یہ بات تم اُنہیں سنا دو، شاید کہ وہ راہ راست پالیں\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cxciv{تمہارے لیے روزوں کے زمانے میں راتوں کو اپنی بیویوں کے پاس جانا حلال کر دیا گیا ہے وہ تمہارے لیے لباس ہیں اور تم اُن کے لیے اللہ کو معلوم ہو گیا کہ تم لوگ چپکے چپکے اپنے آپ سے خیانت کر رہے تھے، مگر اُ س نے تمہارا قصور معاف کر دیا اور تم سے درگزر فرمایا اب تم اپنی بیویوں کے ساتھ شب باشی کرو اور جو لطف اللہ نے تمہارے لیے جائز کر دیا ہے، اُسے حاصل کرو نیز راتوں کو کھاؤ پیو یہاں تک کہ تم کو سیاہی شب کی دھاری سے سپیدۂ صبح کی دھاری نمایاں نظر آ جائے تب یہ سب کام چھوڑ کر رات تک اپنا روزہ پورا کرو اور جب تم مسجدوں میں معتکف ہو، تو بیویوں سے مباشرت نہ کرو یہ اللہ کی باندھی ہوئی حدیں ہیں، ان کے قریب نہ پھٹکنا اِس طرح اللہ اپنے احکام لوگوں کے لیے بصراحت بیان کرتا ہے، توقع ہے کہ وہ غلط رویے سے بچیں گے\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cxcv{اور تم لوگ نہ تو آپس میں ایک دوسرے کے مال ناروا طریقہ سے کھاؤ اور نہ حاکموں کے آگے ان کو اس غرض کے لیے پیش کرو کہ تمہیں دوسروں کے مال کا کوئی حصہ قصداً ظالمانہ طریقے سے کھانے کا موقع مل جائے\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cxcvi{لوگ تم سے چاند کی گھٹتی بڑھتی صورتوں کے متعلق پوچھتے ہیں کہو: یہ لوگوں کے لیے تاریخوں کی تعین کی اور حج کی علامتیں ہیں نیز ان سے کہو: یہ کوئی نیکی کا کام نہیں ہے کہ اپنے گھروں میں پیچھے کی طرف داخل ہوتے ہو نیکی تو اصل میں یہ ہے کہ آدمی اللہ کی ناراضی سے بچے لہٰذا تم اپنے گھروں میں دروازے ہی سے آیا کرو البتہ اللہ سے ڈرتے رہو شاید کہ تمہیں فلاح نصیب ہو جائے\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cxcvii{اور تم اللہ کی راہ میں اُن لوگوں سے لڑو، جو تم سے لڑتے ہیں، مگر زیادتی نہ کرو کہ اللہ زیادتی کرنے والوں کو پسند نہیں کرتا\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cxcviii{ان سے لڑو جہاں بھی تمہارا اُن سے مقابلہ پیش آئے اور انہیں نکالو جہاں سے انہوں نے تم کو نکالا ہے، اس لیے کہ قتل اگرچہ برا ہے، مگر فتنہ اس سے بھی زیادہ برا ہے اور مسجد حرام کے قریب جب تک وہ تم سے نہ لڑیں، تم بھی نہ لڑو، مگر جب وہ وہاں لڑنے سے نہ چُوکیں، تو تم بھی بے تکلف انہیں مارو کہ ایسے کافروں کی یہی سزا ہے\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cxcix{پھر اگر وہ باز آ جائیں، تو جان لو کہ اللہ معاف کرنے والا اور رحم فرمانے والا ہے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cc{تم ان سے لڑتے رہو یہاں تک کہ فتنہ باقی نہ رہے اور دین اللہ کے لیے ہو جائے پھر اگر وہ باز آ جائیں، تو سمجھ لو کہ ظالموں کے سوا اور کسی پر دست درازی روا نہیں\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cci{ماہ حرام کا بدلہ حرام ہی ہے اور تمام حرمتوں کا لحاظ برابری کے ساتھ ہوگا لہٰذا جوتم پر دست درازی کرے، تم بھی اسی طرح اس پر دست درازی کرو البتہ اللہ سے ڈرتے رہو اور جان رکھو کہ اللہ انہیں لوگوں کے ساتھ ہے، جو اس کی حدود توڑنے سے پرہیز کرتے ہیں\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@ccii{اللہ کی راہ میں خرچ کرو اور اپنے ہاتھوں اپنے آپ کو ہلاکت میں نہ ڈالو احسان کا طریقہ اختیار کرو کہ اللہ محسنو ں کو پسند کرتا ہے\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cciii{اللہ کی خوشنودی کے لیے جب حج اور عمرے کی نیت کرو، تو اُسے پورا کرو اور اگر کہیں گھر جاؤ تو جو قربانی میسر آئے، اللہ کی جناب میں پیش کرو اور اپنے سر نہ مونڈو جب تک کہ قربانی اپنی جگہ نہ پہنچ جائے مگر جو شخص مریض ہو یا جس کے سر میں کوئی تکلیف ہو اور اس بنا پر اپنا سر منڈوا لے، تو اُسے چاہیے کہ فدیے کے طور پر روزے رکھے یا صدقہ دے یا قربانی کرے پھر اگر تمہیں امن نصیب ہو جائے (اور تم حج سے پہلے مکے پہنچ جاؤ)، تو جو شخص تم میں سے حج کا زمانہ آنے تک عمرے کا فائدہ اٹھائے، وہ حسب مقدور قربانی دے، اور ا گر قربانی میسر نہ ہو، تو تین روزے حج کے زمانے میں اور سات گھر پہنچ کر، اِس طرح پورے دس روزے رکھ لے یہ رعایت اُن لوگوں کے لیے ہے، جن کے گھر بار مسجد حرام کے قریب نہ ہوں اللہ کے اِن احکام کی خلاف ورزی سے بچو اور خوب جان لو کہ اللہ سخت سزا دینے والا ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cciv{حج کے مہینے سب کو معلوم ہیں جو شخص ان مقرر مہینوں میں حج کی نیت کرے، اُسے خبردار رہنا چاہیے کہ حج کے دوران اس سے کوئی شہوانی فعل، کوئی بد عملی، کوئی لڑائی جھگڑے کی بات سرزد نہ ہو اور جو نیک کام تم کرو گے، وہ اللہ کے علم میں ہوگا سفر حج کے لیے زاد راہ ساتھ لے جاؤ، اور سب سے بہتر زاد راہ پرہیزگاری ہے پس اے ہوش مندو! میر ی نا فرمانی سے پرہیز کرو\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@ccv{اور اگر حج کے ساتھ ساتھ اپنے رب کا فضل بھی تلاش کرتے جاؤ، تو اس میں کوئی مضائقہ نہں پھر جب عرفات سے چلو، تو مشعر حرام (مزدلفہ) کے پاس ٹھیر کر اللہ کو یاد کرو اور اُس طرح یاد کرو، جس کی ہدایت اس نے تمہیں دی ہے، ورنہ اس سے پہلے تم لوگ بھٹکے ہوئے تھے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@ccvi{پھر جہاں سے سب لوگ پلٹتے ہیں وہیں سے تم بھی پلٹو اور اللہ سے معافی چاہو، یقیناً وہ معاف کرنے والا اور رحم فرمانے والا ہے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@ccvii{پھر جب اپنے حج کے ارکان ادا کر چکو، تو جس طرح پہلے اپنے آبا و اجداد کا ذکر کرتے تھے، اُس طرح اب اللہ کا ذکر کرو، بلکہ اس سے بھی بڑھ کر (مگر اللہ کو یاد کرنے والے لوگوں میں بھی بہت فرق ہے) اُن میں سے کوئی تو ایسا ہے، جو کہتا ہے کہ اے ہمارے رب، ہمیں دنیا ہی میں سب کچھ دیدے ایسے شخص کے لیے آخرت میں کوئی حصہ نہیں\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@ccviii{اور کوئی کہتا ہے کہ اے ہمارے رب! ہمیں دنیا میں بھی بھلائی دے اور آخرت میں بھی بھلائی اور آگ کے عذاب سے ہمیں بچا\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@ccix{ایسے لوگ اپنی کمائی کے مطابق (دونوں جگہ) حصہ پائیں گے اور اللہ کو حساب چکاتے کچھ دیر نہیں لگتی\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@ccx{یہ گنتی کے چند روز ہیں، جو تمہیں اللہ کی یاد میں بسر کرنے چاہییں پھر جو کوئی جلدی کر کے دو ہی دن میں واپس ہو گیا تو کوئی حرج نہیں، اور جو کچھ دیر زیادہ ٹھیر کر پلٹا تو بھی کوئی حرج نہیں بشر طیکہ یہ دن اس نے تقویٰ کے ساتھ بسر کیے ہو اللہ کی نافرمانی سے بچو اور خوب جان رکھو کہ ایک روز اس کے حضور میں تمہاری پیشی ہونے والی ہے\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@ccxi{انسانوں میں کوئی تو ایسا ہے، جس کی باتیں دنیا کی زندگی میں تمہیں بہت بھلی معلوم ہوتی ہیں، اور اپنی نیک نیتی پر وہ بار بار خد ا کو گواہ ٹھیرا تا ہے، مگر حقیقت میں وہ بد ترین دشمن حق ہوتا ہے\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@ccxii{جب اُسے اقتدار حاصل ہو جاتا ہے، تو زمین میں اُس کی ساری دوڑ دھوپ اس لیے ہوتی ہے کہ فساد پھیلائے، کھیتوں کو غارت کرے اور نسل انسانی کو تباہ کرے حالاں کہ اللہ (جسے وہ گواہ بنا رہا تھا) فساد کو ہرگز پسند نہیں کرتا\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@ccxiii{اور جب اس سے کہا جاتا ہے کہ اللہ سے ڈر، تو اپنے وقار کا خیال اُس کو گناہ پر جما دیتا ہے ایسے شخص کے لیے تو بس جہنم ہی کافی ہے اور وہ بہت برا ٹھکانا ہے\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@ccxiv{دوسری طرف انسانوں ہی میں کوئی ایسا بھی ہے، جو رضا ئے الٰہی کی طلب میں اپنی جان کھپا دیتا ہے اور ایسے بندوں پر اللہ بہت مہربان ہے\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@ccxv{اے ایمان لانے والو! تم پورے کے پورے اسلام میں آ جاؤ اور شیطان کی پیروی نہ کرو کہ وہ تمہارا کھلا دشمن ہے\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@ccxvi{جو صاف صاف ہدایات تمہارے پا س آ چکی ہیں، اگر ان کو پا لینے کے بعد پھر تم نے لغز ش کھائی، تو خوب جان رکھو کہ اللہ سب پر غالب اور حکیم و دانا ہے\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@ccxvii{(اِن ساری نصیحتوں اور ہدایتوں کے بعد بھی لوگ سیدھے نہ ہوں، تو) کیا اب وہ اِس کے منتظر ہیں کہ اللہ بادلوں کا چتر لگائے فرشتوں کے پرے سا تھ لیے خود سامنے آ موجود ہو اور فیصلہ ہی کر ڈالا جائے؟ آخر کار سارے معاملات پیش تو اللہ ہی کے حضور ہونے والے ہیں\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@ccxviii{بنی اسرائیل سے پوچھو: کیسی کھلی کھلی نشانیاں ہم نے اُنہیں دکھائی ہیں (اور پھر یہ بھی انہیں سے پوچھ لو کہ) اللہ کی نعمت پانے کے بعد جو قوم اس کو شقاوت سے بدلتی ہے اُسے اللہ کیسی سخت سزادیتا ہے\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@ccxix{جن لوگوں نے کفر کی راہ اختیار کی ہے، اُن کے لیے دنیا کی زندگی بڑی محبوب و دل پسند بنا دی گئی ہے ایسے لوگ ایمان کی راہ اختیار کرنے والوں کا مذاق اڑاتے ہیں، مگر قیامت کے روز پرہیز گار لوگ ہی اُن کے مقابلے میں عالی مقام ہوں گے رہا دنیا کا رزق، تو اللہ کو اختیار ہے، جسے چاہے بے حساب دے\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@ccxx{ابتدا میں سب لوگ ایک ہی طریقہ پر تھے (پھر یہ حالت باقی نہ رہی اور اختلافات رونما ہوئے) تب اللہ نے نبی بھیجے جو راست روی پر بشارت دینے والے اور کج روی کے نتائج سے ڈرانے والے تھے، اور اُن کے ساتھ کتاب بر حق نازل کی تاکہ حق کے بارے میں لوگوں کے درمیان جو اختلافات رونما ہوگئے تھے، ان کا فیصلہ کرے (اور ان اختلافات کے رونما ہونے کی وجہ یہ نہ تھی کہ ابتدا میں لوگوں کو حق بتایا نہیں گیا تھا نہیں،) اختلاف اُن لوگوں نے کیا، جنہیں حق کا عمل دیا چکا تھا اُنہوں نے روشن ہدایات پا لینے کے بعد محض اس کے لیے حق کو چھوڑ کر مختلف طریقے نکالے کہ وہ آپس میں زیادتی کرنا چاہتے تھے پس جو لوگ انبیا پر ایمان لے آئے، انہیں اللہ نے اپنے اذن سے اُس حق کا راستہ دکھا دیا، جس میں لوگوں نے اختلاف کیا تھا اللہ جسے چاہتا ہے، راہ راست دکھا دیتا ہے\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@ccxxi{پھر کیا تم لوگوں نے یہ سمجھ رکھا ہے کہ یونہی جنت کا داخلہ تمہیں مل جائے گا، حالانکہ ابھی تم پر وہ سب کچھ نہیں گزرا ہے، جو تم سے پہلے ایمان لانے والوں پر گزر چکا ہے؟ اُن پر سختیاں گزریں، مصیبتیں آئیں، ہلا مارے گئے، حتیٰ کہ وقت کارسول اور اس کے ساتھی اہل ایمان چیخ اٹھے کہ اللہ کی مدد کب آئے گی اُس وقت انہیں تسلی دی گئی کہ ہاں اللہ کی مدد قریب ہے\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@ccxxii{لوگ پوچھتے ہیں کہ ہم کیا خرچ کریں؟ جواب دو کہ جو مال بھی تم خرچ کرو اپنے والدین پر، رشتے داروں پر، یتیموں اور مسکینوں اور مسافروں پر خرچ کرو اور جو بھلائی بھی تم کرو گے، اللہ اس سے باخبر ہوگا\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@ccxxiii{تمہیں جنگ کا حکم دیا گیا ہے اور وہ تمہیں ناگوار ہے ہوسکتا ہے کہ ایک چیز تمہیں ناگوار ہو اور وہی تمہارے لیے بہتر ہو اور ہوسکتا ہے کہ ایک چیز تمہیں پسند ہو اور وہی تمہارے لیے بری ہو اللہ جانتا ہے، تم نہیں جانتے\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@ccxxiv{لوگ پوچھتے ہیں ماہ حرام میں لڑنا کیسا ہے؟ کہو: اِس میں لڑ نا بہت برا ہے، مگر راہ خدا سے لوگوں کو روکنا اور اللہ سے کفر کرنا اور مسجد حرام کا راستہ خدا پرستوں پر بند کرنا اور حرم کے رہنے والوں کو وہاں سے نکالنا اللہ کے نزدیک اِس سے بھی زیادہ برا ہے اور فتنہ خونریزی سے شدید تر ہے وہ تو تم سے لڑے ہی جائیں گے حتیٰ کہ اگر اُن کا بس چلے، تو تمہیں اِس دین سے پھرا لے جائیں (اور یہ خوب سمجھ لو کہ) تم میں سے جو کوئی اس دین سے پھرے گا اور کفر کی حالت میں جان دے گا، اس کے اعمال دنیا اور آخرت دونوں میں ضائع ہو جائیں گے ایسے سب لوگ جہنمی ہیں اور ہمیشہ جہنم ہی میں رہیں گے\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@ccxxv{بخلا ف اِس کے جو لوگ ایمان لائے ہیں اور جنہوں نے خدا کی راہ میں اپنا گھر بار چھوڑا اور جہاد کیا ہے، وہ رحمت الٰہی کے جائز امیدوار ہیں اور اللہ ان کی لغزشوں کو معاف کرنے والا اور اپنی رحمت سے انہیں نوازنے والا ہے\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@ccxxvi{پوچھتے ہیں: شراب اور جوئے کا کیا حکم ہے؟ کہو: ان دونوں چیزوں میں بڑی خرابی ہے اگرچہ ان میں لوگوں کے لیے کچھ منافع بھی ہیں، مگر ان کا گناہ اُن کے فائدے سے بہت زیادہ ہے پوچھتے ہیں: ہم راہ خدا میں کیا خرچ کریں؟ کہو: جو کچھ تمہاری ضرورت سے زیادہ ہو اس طرح اللہ تمہارے لیے صاف صاف احکام بیان کرتا ہے، شاید کہ تم دنیا اور آخرت دونوں کی فکر کرو\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@ccxxvii{پوچھتے ہیں: یتیموں کے ساتھ کیا معاملہ کیا جائے؟ کہو: جس طرز عمل میں ان کے لیے بھلائی ہو، وہی اختیار کرنا بہتر ہے اگر تم اپنا اور اُن کا خرچ اور رہنا سہنا مشترک رکھو، تو اس میں کوئی مضائقہ نہیں آخر وہ تمہارے بھائی بند ہی تو ہیں برائی کرنے والے اور بھلائی کرنے والے، دونوں کا حال اللہ پر روشن ہے اللہ چاہتا تو اس معاملے میں تم پر سختی کرتا، مگر وہ صاحب اختیار ہونے کے ساتھ صاحب حکمت بھی ہے\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@ccxxviii{تم مشرک عورتوں سے ہرگز نکاح نہ کرنا، جب تک کہ وہ ایمان نہ لے آئیں ایک مومن لونڈی مشرک شریف زادی سے بہتر ہے، اگرچہ وہ تمہیں بہت پسند ہو اور اپنی عورتوں کے نکاح مشرک مردوں سے کبھی نہ کرنا، جب تک کہ وہ ایمان نہ لے آئیں ایک مومن غلام مشرک شریف سے بہتر ہے اگرچہ وہ تمہیں بہت پسند ہو یہ لوگ تمہیں آگ کی طرف بلاتے ہیں اور اللہ اپنے اذن سے تم کو جنت اور مغفرت کی طرف بلاتا ہے، اور وہ اپنے احکام واضح طور پر لوگوں کے سامنے بیان کرتا ہے، توقع ہے کہ وہ سبق لیں گے اور نصیحت قبول کریں گے\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@ccxxix{پوچھتے ہیں: حیض کا کیا حکم ہے؟ کہو: وہ ایک گندگی کی حالت ہے اس میں عورتوں سے الگ رہو اور ان کے قریب نہ جاؤ، جب تک کہ وہ پاک صاف نہ ہو جائیں پھر جب وہ پاک ہو جائیں، تو اُن کے پاس جاؤ اُس طرح جیسا کہ اللہ نے تم کو حکم دیا ہے اللہ اُن لوگوں کو پسند کرتا ہے، جو بدی سے باز رہیں اور پاکیزگی اختیار کریں\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@ccxxx{تمہاری عورتیں تمہاری کھیتیاں ہیں تمہیں اختیار ہے، جس طرح چاہو، اپنی کھیتی میں جاؤ، مگر اپنے مستقبل کی فکر کرو اور اللہ کی ناراضی سے بچو خوب جان لو کہ تمہیں ایک دن اُس سے ملنا ہے اور اے نبیؐ! جو تمہاری ہدایات کو مان لیں انہیں فلاح و سعادت کا مثردہ سنا دو\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@ccxxxi{اللہ کے نام کو ایسی قسمیں کھانے کے لیے استعمال نہ کرو، جن سے مقصود نیکی اور تقویٰ اور بند گان خدا کی بھلائی کے کاموں سے باز رہنا ہو اللہ تمہاری ساری باتیں سن رہا ہے اور سب کچھ جانتا ہے\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@ccxxxii{جو بے معنی قسمیں تم بلا ارادہ کھا لیا کرتے ہو، اُن پر اللہ گرفت نہیں کرتا، مگر جو قسمیں تم سچے دل سے کھاتے ہو، اُن کی باز پرس وہ ضرور کرے گا اللہ بہت در گزر کرنے والا اور بردبار ہے\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@ccxxxiii{جو لوگ اپنی عورتوں سے تعلق نہ رکھنے کی قسم کھا بیٹھے ہیں، اُن کے لیے چار مہینے کی مہلت ہے اگر انہوں نے رجوع کر لیا، تو اللہ معاف کرنے والا اور رحیم ہے\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@ccxxxiv{اور اگر اُنہوں نے طلاق ہی کی ٹھان لی ہو تو جانے رہیں کہ اللہ سب کچھ سنتا اور جانتا ہے\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@ccxxxv{جن عورتوں کو طلاق دی گئی ہو، وہ تین مرتبہ ایام ماہواری آنے تک اپنے آپ کو روکے رکھیں اور اُن کے لیے یہ جائز نہیں ہے کہ اللہ نے اُن کے رحم میں جو کچھ خلق فرمایا ہو، اُسے چھپائیں اُنہیں ہرگز ایسا نہ کرنا چاہیے، اگر وہ اللہ اور روز آخر پر ایمان رکھتی ہیں اُن کے شوہر تعلقات درست کر لینے پر آمادہ ہوں، تو وہ اِس عدت کے دوران اُنہیں پھر اپنی زوجیت میں واپس لے لینے کے حق دار ہیں عورتوں کے لیے بھی معروف طریقے پر ویسے ہی حقوق ہیں، جیسے مردوں کے حقوق اُن پر ہیں البتہ مردوں کو اُن پر ایک درجہ حاصل ہے اور سب پر اللہ غالب اقتدار رکھنے والا اور حکیم و دانا موجود ہے\qt@no{(228)}}%
\qt@newcmd\qurantrans@ur@ccxxxvi{طلاق دو بار ہے پھر یا تو سیدھی طرح عورت کو روک لیا جائے یا بھلے طریقے سے اس کو رخصت کر دیا جائے اور رخصت کر تے ہوئے ایسا کرنا تمہارے لیے جائز نہیں ہے کہ جو کچھ تم انہیں دے چکے ہو، اُس میں سے کچھ واپس لے لو البتہ یہ صورت مستثنیٰ ہے کہ زوجین کو اللہ کے حدود پر قائم نہ رہ سکنے کا اندیشہ ہو ایسی صورت میں اگر تمہیں یہ خوف ہو کہ وہ دونوں حدود الٰہی پر قائم نہ رہیں گے، تو اُن دونوں کے درمیان یہ معاملہ ہو جانے میں مضائقہ نہیں کہ عورت اپنے شوہر کو کچھ معاوضہ دے کر علیحدگی حاصل کر لے یہ اللہ کے مقرر کردہ حدود ہیں، اِن سے تجاوز نہ کرو اور جو لوگ حدود الٰہی سے تجاوز کریں، وہی ظالم ہیں\qt@no{(229)}}%
\qt@newcmd\qurantrans@ur@ccxxxvii{پھر اگر (دو بارہ طلاق دینے کے بعد شوہر نے عورت کو تیسری بار) طلاق دے دی تو وہ عورت پھر اس کے لیے حلال نہ ہوگی، الّا یہ کہ اس کا نکاح کسی دوسرے شخص سے ہو اور وہ اسے طلاق دیدے تب اگر پہلا شوہر اور یہ عورت دونوں یہ خیال کریں کہ حدود الٰہی پر قائم رہیں گے، تو ان کے لیے ایک دوسرے کی طرف رجو ع کر لینے میں کوئی مضائقہ نہیں یہ اللہ کی مقرر کردہ حدیں ہیں، جنہیں وہ اُن لوگوں کی ہدایت کے لیے واضح کر رہا ہے، جو (اس کی حدود کو توڑنے کا انجام) جانتے ہیں\qt@no{(230)}}%
\qt@newcmd\qurantrans@ur@ccxxxviii{اور جب تم عورتوں کو طلاق دے دو اور ان کی عدت پوری ہونے کو آ جائے، تو یا بھلے طریقے سے انہیں روک لو یا بھلے طریقے سے رخصت کر دو محض ستانے کی خاطر انہیں نہ روکے رکھنا یہ زیادتی ہوگی اور جو ایسا کرے گا، وہ در حقیقت آپ اپنے ہی اوپر ظلم کرے گا اللہ کی آیات کا کھیل نہ بناؤ بھول نہ جاؤ کہ اللہ نے کس نعمت عظمیٰ سے تمہیں سرفراز کیا ہے وہ تمہیں نصیحت کرتا ہے کہ جو کتاب اور حکمت اُس نے تم پر نازل کی ہے، اس کا احترام ملحوظ رکھو اللہ سے ڈرو اور خوب جان لو کہ اللہ کو ہر بات کی خبر ہے\qt@no{(231)}}%
\qt@newcmd\qurantrans@ur@ccxxxix{جب تم اپنی عورتوں کو طلاق دے چکو اور وہ اپنی عدت پوری کر لیں، تو پھر اس میں مانع نہ ہو کہ وہ اپنے زیر تجویز شوہروں سے نکاح کر لیں، جب کہ وہ معروف طریقے سے باہم مناکحت پر راضی ہوں تمہیں نصیحت کی جاتی ہے کہ ایسی حرکت ہرگز نہ کرنا، اگر تم اللہ اور روز آخر پر ایمان لانے والے ہو تمہارے لیے شائستہ اور پاکیزہ طریقہ یہی ہے کہ اس سے باز رہو اللہ جانتا ہے، تم نہیں جانتے\qt@no{(232)}}%
\qt@newcmd\qurantrans@ur@ccxl{جو باپ چاہتے ہوں کہ ان کی اولا د پوری مدت رضاعت تک دودھ پیے، تو مائیں اپنے بچوں کو کامل دو سال دودھ پلائیں اِس صورت میں بچے کے باپ کو معروف طریقے سے انہیں کھانا کپڑا دینا ہوگا مگر کسی پر اس کی وسعت سے بڑھ کر بار نہ ڈالنا چاہیے نہ تو ماں کو اِس وجہ سے تکلیف میں ڈالا جائے کہ بچہ اس کا ہے، اور نہ باپ ہی کو اس وجہ سے تنگ کیا جائے کہ بچہ اس کا ہے دودھ پلانے والی کا یہ حق جیسا بچے کے باپ پر ہے ویسا ہی اس کے وارث پر بھی ہے لیکن اگر فریقین باہمی رضامندی اور مشورے سے دودھ چھڑانا چاہیں، تو ایسا کرنے میں کوئی مضائقہ نہیں اور اگر تمہارا خیال اپنی اولاد کو کسی غیر عورت سے دودھ پلوانے کا ہو، تو اس میں بھی کوئی حرج نہیں بشر طیکہ اس کا جو کچھ معاوضہ طے کرو، وہ معروف طریقے پر ادا کر دو اللہ سے ڈرو اور جان رکھو کہ جو کچھ تم کرتے ہو، سب اللہ کی نظر میں ہے\qt@no{(233)}}%
\qt@newcmd\qurantrans@ur@ccxli{تم میں سے جو لوگ مر جائیں، اُن کے پیچھے اگر اُن کی بیویاں زندہ ہوں، تو وہ اپنے آپ کو چار مہینے، دس دن روکے رکھیں پھر جب ان کی عدت پوری ہو جائے، تو انہیں اختیار ہے، اپنی ذات کے معاملے میں معروف طریقے سے جو چاہیں، کریں تم پر اس کی کوئی ذمہ داری نہیں اللہ تم سب کے اعمال سے باخبر ہے\qt@no{(234)}}%
\qt@newcmd\qurantrans@ur@ccxlii{زمانہ عدت میں خواہ تم اُن بیوہ عورتوں کے ساتھ منگنی کا ارادہ اشارے کنایے میں ظاہر کر دو، خواہ دل میں چھپائے رکھو، دونوں صورتوں میں کوئی مضائقہ نہیں اللہ جانتا ہے کہ اُن کا خیال تو تمہارے دل میں آئے گا ہی مگر دیکھو! خفیہ عہد و پیمان نہ کرنا اگر کوئی بات کرنی ہے، تو معرف طریقے سے کرو اور عقد نکاح باندھنے کا فیصلہ اُس وقت تک نہ کرو، جب تک کہ عدت پوری نہ ہو جائے خوب سمجھ لو کہ اللہ تمہارے دلوں کا حال تک جانتا ہے لہٰذا اس سے ڈرو اور یہ بھی جان لو کہ اللہ بردبار ہے، چھوٹی چھوٹی باتوں سے درگزر فرماتا ہے\qt@no{(235)}}%
\qt@newcmd\qurantrans@ur@ccxliii{تم پر کچھ گنا ہ نہیں، اگر اپنی تم عورتوں کو طلاق دے دو قبل اس کے کہ ہاتھ لگانے کی نوبت آئے یا مہر مقرر ہو اس صورت میں اُنہیں کچھ نہ کچھ دینا ضرور چاہیے خوش حال آدمی اپنی مقدرت کے مطابق اور غریب اپنی مقدرت کے مطابق معروف طریقہ سے دے یہ حق ہے نیک آدمیوں پر\qt@no{(236)}}%
\qt@newcmd\qurantrans@ur@ccxliv{اور اگر تم نے ہاتھ لگانے سے پہلے طلاق دی ہے، لیکن مہر مقرر کیا جا چکا ہو، تو اس صورت میں نصف مہر دینا ہوگا یہ اور بات ہے کہ عورت نرمی برتے (اور مہر نہ لے) یا وہ مرد، جس کے اختیار میں عقد نکاح ہے، نرمی سے کام لے (اور پورا مہر دیدے)، اور تم (یعنی مرد) نرمی سے کام لو، تو یہ تقویٰ سے زیادہ مناسبت رکھتا ہے آپس کے معاملات میں فیاضی کو نہ بھولو تمہارے اعمال کو اللہ دیکھ رہا ہے\qt@no{(237)}}%
\qt@newcmd\qurantrans@ur@ccxlv{اپنی نمازوں کی نگہداشت رکھو، خصوصاً ایسی نماز کی جو محاسن صلوٰۃ کی جا مع ہو اللہ کے آگے اس طرح کھڑے ہو، جیسے فر ماں بردار غلام کھڑ ے ہوتے ہیں\qt@no{(238)}}%
\qt@newcmd\qurantrans@ur@ccxlvi{بدامنی کی حالت ہو، تو خواہ پیدل ہو، خواہ سوار، جس طرح ممکن ہو، نماز پڑھو اور جب امن میسر آجائے، تو اللہ کو اُس طریقے سے یاد کرو، جو اُس نے تمہیں سکھا دیا ہے، جس سے تم پہلے نا واقف تھے\qt@no{(239)}}%
\qt@newcmd\qurantrans@ur@ccxlvii{تم میں سے جو لوگوں وفات پائیں اور پیچھے بیویاں چھوڑ رہے ہوں، اُن کو چاہیے کہ اپنی بیویوں کے حق میں یہ وصیت کر جائیں کہ ایک سال تک ان کو نان و نفقہ دیا جائے اور وہ گھر سے نہ نکالی جائیں پھر اگر وہ خود نکل جائیں، تو اپنی ذات کے معاملے میں معروف طریقے سے وہ جو کچھ بھی کریں، اس کی کوئی ذمہ داری تم پر نہیں ہے اللہ سب پر غالب اقتدار رکھنے والا اور حکیم و دانا ہے\qt@no{(240)}}%
\qt@newcmd\qurantrans@ur@ccxlviii{اِسی طرح جن عورتوں کو طلاق دی گئی ہو، انہیں بھی مناسب طور پر کچھ نہ کچھ دے کر رخصت کیا جائے یہ حق ہے متقی لوگوں پر\qt@no{(241)}}%
\qt@newcmd\qurantrans@ur@ccxlix{اِس طرح اللہ اپنے احکام تمہیں صاف صاف بتاتا ہے امید ہے کہ تم سمجھ بوجھ کر کام کرو گے\qt@no{(242)}}%
\qt@newcmd\qurantrans@ur@ccl{تم نے اُن لوگوں کے حال پر بھی کچھ غور کیا، جو موت کے ڈر سے اپنے گھر بار چھوڑ کر نکلے تھے اور ہزاروں کی تعداد میں تھے؟ اللہ نے اُن سے فرمایا: مر جاؤ پھر اُس نے اُن کو دوبارہ زندگی بخشی حقیقت یہ ہے کہ اللہ انسان پر بڑا فضل فرمانے والا ہے مگر اکثر لوگ شکر ادا نہیں کرتے\qt@no{(243)}}%
\qt@newcmd\qurantrans@ur@ccli{مسلمانو! اللہ کی راہ میں جنگ کرو اور خوب جان رکھو کہ اللہ سننے والا اور جاننے والا ہے\qt@no{(244)}}%
\qt@newcmd\qurantrans@ur@cclii{تم میں کون ہے جو اللہ کو قرض حسن دے تاکہ اللہ اُسے کئی گنا بڑھا چڑھا کر واپس کرے؟ گھٹانا بھی اللہ کے اختیار میں ہے اور بڑھانا بھی، اور اُسی کی طرف تمہیں پلٹ کر جانا ہے\qt@no{(245)}}%
\qt@newcmd\qurantrans@ur@ccliii{پھر تم نے اُس معاملے پر بھی غور کیا، جو موسیٰؑ کے بعد سرداران بنی اسرائیل کو پیش آیا تھا؟ اُنہوں نے اپنے نبی سے کہا: ہمارے لیے ایک بادشاہ مقرر کر دو تاکہ ہم اللہ کی راہ میں جنگ کریں نبی نے پوچھا: کہیں ایسا تو نہ ہوگا کہ تم کو لڑائی کا حکم دیا جائے اور پھر تم نہ لڑو وہ کہنے لگے : بھلا یہ کیسے ہو سکتا ہے کہ ہم راہ خدا میں نہ لڑیں، جبکہ ہمیں اپنے گھروں سے نکال دیا گیا ہے اور ہمارے بال بچے ہم سے جدا کر دیے گئے ہیں مگر جب ان کو جنگ کا حکم دیا گیا، تو ایک قلیل تعداد کے سوا وہ سب پیٹھ موڑ گئے، اور اللہ ان میں سے ایک ایک ظالم کو جانتا ہے\qt@no{(246)}}%
\qt@newcmd\qurantrans@ur@ccliv{اُن کے نبی نے ان سے کہا کہ اللہ نے طالوت کو تمہارے لیے بادشاہ مقرر کیا ہے یہ سن کر وہ بولے : ``ہم پر بادشاہ بننے کا وہ کیسے حقدار ہو گیا؟ اُس کے مقابلے میں بادشاہی کے ہم زیادہ مستحق ہیں وہ تو کوئی بڑا ما ل دار آدمی نہیں ہے" نبی نے جواب دیا: ``اللہ نے تمہارے مقابلے میں اسی کو منتخب کیا ہے اور اس کو دماغی و جسمانی دونوں قسم کی اہلیتیں فراوانی کے ساتھ عطا فرمائی ہیں اور اللہ کو اختیار ہے کہ اپنا ملک جسے چاہے دے، اللہ بڑی وسعت رکھتا ہے اور سب کچھ اُس کے علم میں ہے"\qt@no{(247)}}%
\qt@newcmd\qurantrans@ur@cclv{اس کے ساتھ اُن کے نبی نے اُن کو یہ بھی بتایا کہ ``خدا کی طرف سے اُس کے بادشاہ مقرر ہونے کی علامت یہ ہے کہ اس کے عہد میں وہ صندوق تمہیں واپس مل جائے گا، جس میں تمہارے رب کی طرف سے تمہارے لیے سکون قلب کا سامان ہے، جس میں آل موسیٰؑ اور آل ہارون کے چھوڑے ہوئے تبرکات ہیں، اور جس کو اس وقت فرشتے سنبھالے ہوئے ہیں اگر تم مومن ہو، تو یہ تمہارے لیے بہت بڑی نشانی ہے\qt@no{(248)}}%
\qt@newcmd\qurantrans@ur@cclvi{پھر جب طالوت لشکر لے کر چلا، تو اُس نے کہا: ``ایک دریا پر اللہ کی طرف سے تمہاری آزمائش ہونے والی ہے جواس کا پانی پیے گا، وہ میرا ساتھی نہیں میرا ساتھی صرف وہ ہے جو اس سے پیاس نہ بجھائے، ہاں ایک آدھ چلو کوئی پی لے، تو پی لے" مگر ایک گروہ قلیل کے سوا وہ سب اس دریا سے سیراب ہوئے پھر جب طالوت اور اس کے ساتھی مسلمان دریا پار کر کے آگے بڑھے، تو اُنہوں نے طالوت سے کہہ دیا کہ آج ہم میں جالوت اور اس کے لشکروں کا مقابلہ کرنے کی طاقت نہیں ہے لیکن جو لوگ یہ سمجھتے تھے کہ انہیں ایک دن اللہ سے ملنا ہے، انہوں نے کہا: ``بارہا ایسا ہوا ہے کہ ایک قلیل گروہ اللہ کے اذن سے ایک بڑے گروہ پر غالب آگیا ہے اللہ صبر کرنے والوں کا ساتھی ہے"\qt@no{(249)}}%
\qt@newcmd\qurantrans@ur@cclvii{اور جب وہ جالوت اور اس کے لشکروں کے مقابلہ پر نکلے، تو انہوں نے دعا کی: ``اے ہمارے رب ہم پر صبر کا فیضان کر، ہمارے قدم جما دے اور اس کافر گروہ پر ہمیں فتح نصیب کر"\qt@no{(250)}}%
\qt@newcmd\qurantrans@ur@cclviii{آخر کا ر اللہ کے اذن سے اُنہوں نے کافروں کو مار بھگایا اور داؤدؑ نے جالوت کو قتل کر دیا اور اللہ نے اسے سلطنت اور حکمت سے نوازا اور جن جن چیزوں کا چاہا، اس کو علم دیا اگر اس طرح اللہ انسانوں کے ایک گروہ کو دوسرے گروہ کے ذریعے ہٹاتا نہ رہتا، تو زمین کا نظام بگڑ جاتا، لیکن دنیا کے لوگوں پر اللہ کا بڑا فضل ہے (کہ وہ اِس طرح دفع فساد کا انتظام کرتا رہتا ہے)\qt@no{(251)}}%
\qt@newcmd\qurantrans@ur@cclix{یہ اللہ کی آیات ہیں، جو ہم ٹھیک ٹھیک تم کو سنا رہے ہیں اور تم یقیناً ان لوگوں میں سے ہو، جو رسول بنا کر بھیجے گئے ہیں\qt@no{(252)}}%
\qt@newcmd\qurantrans@ur@cclx{یہ رسول (جو ہماری طرف سے انسانوں کی ہدایت پر مامور ہوئے) ہم نے ان کو ایک دوسرے سے بڑھ چڑھ کر مرتبے عطا کیے ان میں کوئی ایسا تھا جس سے خدا خود ہم کلام ہوا، کسی کو اس نے دوسری حیثیتوں سے بلند درجے دیے، اور آخر میں عیسیٰ ابن مریمؑ کو روشن نشانیاں عطا کیں اور روح پاک سے اس کی مدد کی اگر اللہ چاہتا، تو ممکن نہ تھا کہ اِن رسولوں کے بعد جو لوگ روشن نشانیاں دیکھ چکے تھے، وہ آپس میں لڑتے مگر (اللہ کی مشیت یہ نہ تھی کہ وہ لوگوں کو جبراً اختلاف سے روکے، اس وجہ سے) انہوں نے باہم اختلاف کیا، پھر کوئی ایمان لایا اور کسی نے کفر کی راہ اختیار کی ہاں، اللہ چاہتا، تو وہ ہرگز نہ لڑتے، مگر اللہ جو چاہتا ہے کرتا ہے\qt@no{(253)}}%
\qt@newcmd\qurantrans@ur@cclxi{اے لوگو جو ایمان لائے ہو، جو کچھ مال متاع ہم نے تم کو بخشا ہے، اس میں سے خرچ کرو، قبل اس کے کہ وہ دن آئے، جس میں نہ خریدو فروخت ہوگی، نہ دوستی کام آئے گی اور نہ سفارش چلے گی اور ظالم اصل میں وہی ہیں، جو کفر کی روش اختیار کرتے ہیں\qt@no{(254)}}%
\qt@newcmd\qurantrans@ur@cclxii{اللہ، وہ زندہ جاوید ہستی، جو تمام کائنات کو سنبھالے ہوئے ہے، اُس کے سوا کوئی خدا نہیں ہے وہ نہ سوتا ہے اور نہ اُسے اونگھ لگتی ہے زمین اور آسمانوں میں جو کچھ ہے، اُسی کا ہے کون ہے جو اُس کی جناب میں اُس کی اجازت کے بغیر سفارش کر سکے؟ جو کچھ بندوں کے سامنے ہے اسے بھی وہ جانتا ہے اور جو کچھ اُن سے اوجھل ہے، اس سے بھی وہ واقف ہے اور اُس کی معلومات میں سے کوئی چیز اُن کی گرفت ادراک میں نہیں آسکتی الّا یہ کہ کسی چیز کا علم وہ خود ہی اُن کو دینا چاہے اُس کی حکومت آسمانوں اور زمین پر چھائی ہوئی ہے اور اُن کی نگہبانی اس کے لیے کوئی تھکا دینے والا کام نہیں ہے بس وہی ایک بزرگ و برتر ذات ہے\qt@no{(255)}}%
\qt@newcmd\qurantrans@ur@cclxiii{دین کے معاملے میں کوئی زور زبردستی نہیں ہے صحیح بات غلط خیالات سے ا لگ چھانٹ کر رکھ دی گئی ہے اب جو کوئی طاغوت کا انکار کر کے اللہ پر ایمان لے آیا، اُس نے ایک ایسا مضبوط سہارا تھام لیا، جو کبھی ٹوٹنے والا نہیں، اور اللہ (جس کا سہارا اس نے لیا ہے) سب کچھ سننے اور جاننے والا ہے\qt@no{(256)}}%
\qt@newcmd\qurantrans@ur@cclxiv{جو لوگ ایمان لاتے ہیں، اُن کا حامی و مددگار اللہ ہے اور وہ ان کو تاریکیوں سے روشنی میں نکال لاتا ہے اور جو لوگ کفر کی راہ اختیار کرتے ہیں، اُن کے حامی و مدد گار طاغوت ہیں اور وہ انہیں روشنی سے تاریکیوں کی طرف کھینچ لے جاتے ہیں یہ آگ میں جانے والے لوگ ہیں، جہاں یہ ہمیشہ رہیں گے\qt@no{(257)}}%
\qt@newcmd\qurantrans@ur@cclxv{کیا تم نے اُس شخص کے حال پر غور نہیں کیا، جس نے ابراہیمؑ سے جھگڑا کیا تھا؟ جھگڑا اِس بات پر کہ ابراہیمؑ کا رب کون ہے، اور اس بنا پر کہ اس شخص کو اللہ نے حکومت دے رکھی تھی جب ابراہیمؑ نے کہا کہ ``میرا رب وہ ہے، جس کے اختیار میں زندگی اور موت ہے، تو اُس نے جواب دیا: ``زندگی اور موت میرے اختیار میں ہے"ابراہیمؑ نے کہا: ``اچھا، اللہ سورج کو مشرق سے نکالتا ہے، تو ذرا اُسے مغرب سے نکال لا" یہ سن کر وہ منکر حق ششدر رہ گیا، مگر اللہ ظالموں کو راہ راست نہیں دکھایا کرتا\qt@no{(258)}}%
\qt@newcmd\qurantrans@ur@cclxvi{یا پھر مثال کے طور پر اُس شخص کو دیکھو، جس کا گزر ایک ایسی بستی پر ہوا، جو اپنی چھتوں پر اوندھی گری پڑی تھی اُس نے کہا: ``یہ آبادی، جو ہلاک ہو چکی ہے، اسے اللہ کس طرح دوبارہ زندگی بخشے گا؟" اس پر اللہ نے اس کی روح قبض کر لی اور وہ سوبرس تک مُردہ پڑا رہا پھر اللہ نے اسے دوبارہ زندگی بخشی اور اس سے پوچھا: ``بتاؤ، کتنی مدت پڑے رہے ہو؟" اُس نے کہا: ``ایک دن یا چند گھنٹے رہا ہوں گا" فرمایا: ``تم پر سو برس اِسی حالت میں گزر چکے ہیں اب ذرا اپنے کھانے اور پانی کو دیکھو کہ اس میں ذرا تغیر نہیں آیا ہے دوسری طرف ذرا اپنے گدھے کو بھی دیکھو (کہ اِس کا پنجر تک بوسید ہ ہو رہا ہے) اور یہ ہم نے اس لیے کیا ہے کہ ہم تمہیں لوگوں کے لیے ایک نشانی بنا دینا چاہتے ہیں پھر دیکھو کہ ہڈیوں کے اِس پنجر کو ہم کس طرح اٹھا کر گوشت پوست اس پر چڑھاتے ہیں" اس طرح جب حقیقت اس کے سامنے بالکل نمایاں ہو گئی، تو اس نے کہا: ``میں جانتا ہوں کہ اللہ ہر چیز پر قدرت رکھتا ہے"\qt@no{(259)}}%
\qt@newcmd\qurantrans@ur@cclxvii{اور وہ واقعہ بھی پیش نظر رہے، جب ابراہیمؑ نے کہا تھا کہ: ``میرے مالک، مجھے دکھا دے، تو مُردوں کو کیسے زندہ کرتا ہے" فرمایا: ``کیا تو ایمان نہیں رکھتا؟" اُس نے عرض کیا ``ایمان تو رکھتا ہوں، مگر دل کا اطمینان درکار ہے" فرمایا: ``اچھا تو چار پرندے لے اور ان کو اپنے سے مانوس کر لے پھر ان کا ایک ایک جز ایک ایک پہاڑ پر رکھ دے پھر ان کو پکار، وہ تیرے پاس دوڑے چلے آئیں گے خوب جان لے کہ اللہ نہایت با اقتدار اور حکیم ہے"\qt@no{(260)}}%
\qt@newcmd\qurantrans@ur@cclxviii{جو لوگ اپنے مال اللہ کی راہ میں صرف کرتے ہیں، اُن کے خرچ کی مثال ایسی ہے، جیسے ایک دانہ بویا جائے اور اس سے سات بالیں نکلیں اور ہر بال میں سو دانے ہوں اِسی طرح اللہ جس کے عمل کو چاہتا ہے، افزونی عطا فرماتا ہے وہ فراخ دست بھی ہے اور علیم بھی\qt@no{(261)}}%
\qt@newcmd\qurantrans@ur@cclxix{جو لوگ اپنے مال اللہ کی راہ میں خرچ کرتے ہیں اور خرچ کر کے پھر احسان جتاتے، نہ دکھ دیتے ہیں، اُن کا اجر اُن کے رب کے پاس ہے اور ان کے لیے کسی رنج اور خوف کا موقع نہیں\qt@no{(262)}}%
\qt@newcmd\qurantrans@ur@cclxx{ایک میٹھا بول اور کسی ناگوار بات پر ذرا سی چشم پوشی اُس خیرات سے بہتر ہے، جس کے پیچھے دکھ ہو اللہ بے نیاز ہے اور بردباری اُس کی صفت ہے\qt@no{(263)}}%
\qt@newcmd\qurantrans@ur@cclxxi{اے ایمان لانے والو! اپنے صدقات کو احسان جتا کر اور دکھ دے کر اُس شخص کی طرح خاک میں نہ ملا دو، جو اپنا مال محض لوگوں کے دکھانے کو خرچ کرتا ہے اور نہ اللہ پر ایما ن رکھتا ہے، نہ آخرت پر اُس کے خرچ کی مثال ایسی ہے، جیسے ایک چٹان تھی، جس پر مٹی کی تہہ جمی ہوئی تھی اس پر جب زور کا مینہ برسا، تو ساری مٹی بہہ گئی اور صاف چٹان کی چٹان رہ گئی ایسے لوگ اپنے نزدیک خیرات کر کے جو نیکی کماتے ہیں، اس سے کچھ بھی اُن کے ہاتھ نہیں آتا، اور کافروں کو سیدھی راہ دکھانا اللہ کا دستور نہیں ہے\qt@no{(264)}}%
\qt@newcmd\qurantrans@ur@cclxxii{بخلا ف اِس کے جو لو گ اپنے مال محض اللہ کی رضا جوئی کے لیے دل کے پورے ثبات و قرار کے ساتھ خرچ کرتے ہیں، ان کے خرچ کی مثال ایسی ہے، جیسے کسی سطح مرتفع پر ایک باغ ہو اگر زور کی بار ش ہو جائے تو دو گنا پھل لائے، اور اگر زور کی بارش نہ بھی ہو تو ایک ہلکی پھوار ہی اُس کے لیے کافی ہو جائے تم جو کچھ کرتے ہو، سب اللہ کی نظر میں ہے\qt@no{(265)}}%
\qt@newcmd\qurantrans@ur@cclxxiii{کیا تم میں سے کوئی یہ پسند کرتا ہے کہ اس کے پاس ایک ہرا بھرا باغ ہو، نہروں سے سیراب، کھجوروں اور انگوروں اور ہرقسم کے پھلوں سے لدا ہوا، اور وہ عین اُس وقت ایک تیز بگولے کی زد میں آ کر جھلس جائے، جبکہ وہ خود بوڑھا ہو اور اس کے کم سن بچے ابھی کسی لائق نہ ہوں؟ اس طرح اللہ اپنی باتیں تمہارے سامنے بیان کرتا ہے، شاید کہ تم غور و فکر کرو\qt@no{(266)}}%
\qt@newcmd\qurantrans@ur@cclxxiv{اے لوگو جو ایمان لائے ہو، جو مال تم نے کمائے ہیں اور جو کچھ ہم نے زمین سے تمہارے لیے نکالا ہے، اُس سے بہتر حصہ راہ خدا میں خرچ کرو ایسا نہ ہو کہ اس کی راہ میں دینے کے لیے بری سے بری چیز چھانٹنے کی کوشش کرنے لگو، حالانکہ وہی چیز اگر کوئی تمہیں دے، تو تم ہرگز اُسے لینا گوارا نہ کرو گے الّا یہ کہ اس کو قبول کرنے میں تم اغماض برت جاؤ تمہیں جان لینا چاہیے کہ اللہ بے نیاز ہے اور بہترین صفات سے متصف ہے\qt@no{(267)}}%
\qt@newcmd\qurantrans@ur@cclxxv{شیطان تمہیں مفلسی سے ڈراتا ہے اور شرمناک طرز عمل اختیار کرنے کی ترغیب دیتا ہے، مگر اللہ تمہیں اپنی بخشش اور فضل کی امید دلاتا ہے اللہ بڑا فراخ دست اور دانا ہے\qt@no{(268)}}%
\qt@newcmd\qurantrans@ur@cclxxvi{جس کو چاہتا ہے حکمت عطا کرتا ہے، اور جس کو حکمت ملی، اُسے حقیقت میں بڑی دولت مل گئی اِن باتوں سے صرف وہی لوگ سبق لیتے ہیں، جو دانشمند ہیں\qt@no{(269)}}%
\qt@newcmd\qurantrans@ur@cclxxvii{تم نے جو کچھ بھی خرچ کیا ہو اور جو نذر بھی مانی ہو، اللہ کو اُس کا علم ہے، اور ظالموں کا کوئی مددگار نہیں\qt@no{(270)}}%
\qt@newcmd\qurantrans@ur@cclxxviii{اگر اپنے صدقات علانیہ دو، تو یہ بھی اچھا ہے، لیکن اگر چھپا کر حاجت مندوں کو دو، تو یہ تمہارے حق میں زیادہ بہتر ہے تمہاری بہت سی برائیاں اِس طرز عمل سے محو ہو جاتی ہیں اور جو کچھ تم کرتے ہوئے اللہ کو بہر حال اُس کی خبر ہے\qt@no{(271)}}%
\qt@newcmd\qurantrans@ur@cclxxix{لوگوں کو ہدایت بخش دینے کی ذمے داری تم پر نہیں ہے ہدایت تو اللہ ہی جسے چاہتا ہے بخشتا ہے اور خیرات میں جو مال تم خرچ کرتے ہو وہ تمہارے اپنے لیے بھلا ہے آخر تم اسی لیے تو خرچ کرتے ہو کہ اللہ کی رضا حاصل ہو تو جو کچھ مال تم خیرات میں خرچ کرو گے، اس کا پورا پورا اجر تمہیں دیا جائے گا اور تمہاری حق تلفی ہرگز نہ ہوگی\qt@no{(272)}}%
\qt@newcmd\qurantrans@ur@cclxxx{خاص طور پر مدد کے مستحق وہ تنگ دست لوگ ہیں جو اللہ کے کام میں ایسے گھر گئے ہیں کہ اپنی ذاتی کسب معاش کے لیے زمین میں کوئی دوڑ دھوپ نہیں کرسکتے ان کی خود داری دیکھ کر ناواقف آدمی گمان کرتا ہے کہ یہ خوش حال ہیں تم ان کے چہروں سے ان کی اندرونی حالت پہچان سکتے ہو مگر وہ ایسے لوگ نہیں ہیں کہ لوگوں کے پیچھے پڑ کر کچھ مانگیں اُن کی اعانت میں جو کچھ مال تم خرچ کرو گے وہ اللہ سے پوشیدہ نہ رہے گا\qt@no{(273)}}%
\qt@newcmd\qurantrans@ur@cclxxxi{جو لو گ اپنے مال شب و روز کھلے اور چھپے خرچ کرتے ہیں ان کا اجر ان کے رب کے پاس ہے اور اُن کے لیے کسی خوف اور رنج کا مقام نہیں\qt@no{(274)}}%
\qt@newcmd\qurantrans@ur@cclxxxii{مگر جو لوگ سود کھاتے ہیں، اُ ن کا حال اُس شخص کا سا ہوتا ہے، جسے شیطان نے چھو کر باؤلا کر دیا ہو اور اس حالت میں اُن کے مبتلا ہونے کی وجہ یہ ہے کہ وہ کہتے ہیں: ``تجارت بھی تو آخر سود ہی جیسی چیز ہے"، حالانکہ اللہ نے تجارت کو حلال کیا ہے اور سود کو حرام لہٰذا جس شخص کو اس کے رب کی طرف سے یہ نصیحت پہنچے اور آئندہ کے لیے وہ سود خوری سے باز آ جائے، تو جو کچھ وہ پہلے کھا چکا، سو کھا چکا، اس کا معاملہ اللہ کے حوالے ہے اور جو اِس حکم کے بعد پھر اسی حرکت کا اعادہ کرے، وہ جہنمی ہے، جہاں وہ ہمیشہ رہے گا\qt@no{(275)}}%
\qt@newcmd\qurantrans@ur@cclxxxiii{اللہ سود کا مٹھ مار دیتا ہے اور صدقات کو نشو و نما دیتا ہے اور اللہ کسی ناشکرے بد عمل انسان کو پسند نہیں کرتا\qt@no{(276)}}%
\qt@newcmd\qurantrans@ur@cclxxxiv{ہاں، جو لوگ ایمان لے آئیں اور نیک عمل کریں اور نماز قائم کریں اور زکوٰۃ دیں، اُن کا اجر بے شک ان کے رب کے پاس ہے اور ان کے لیے کسی خوف اور رنج کا موقع نہیں\qt@no{(277)}}%
\qt@newcmd\qurantrans@ur@cclxxxv{اے لوگو جو ایمان لائے ہو، خدا سے ڈرو اور جو کچھ تمہارا سود لوگوں پر باقی رہ گیا ہے، اسے چھوڑ دو، اگر واقعی تم ایمان لائے ہو\qt@no{(278)}}%
\qt@newcmd\qurantrans@ur@cclxxxvi{لیکن اگر تم نے ایسا نہ کیا، تو آگاہ ہو جاؤ کہ اللہ اور اسکے رسول کی طرف سے تمہارے خلاف اعلان جنگ ہے اب بھی توبہ کر لو (اور سود چھوڑ دو) تو اپنا اصل سرمایہ لینے کے تم حق دار ہو نہ تم ظلم کرو، نہ تم پر ظلم کیا جائے\qt@no{(279)}}%
\qt@newcmd\qurantrans@ur@cclxxxvii{تمہارا قرض دار تنگ دست ہو، تو ہاتھ کھلنے تک اُسے مہلت دو، اور جو صدقہ کر دو، تو یہ تمہارے لیے زیادہ بہتر ہے، اگر تم سمجھو\qt@no{(280)}}%
\qt@newcmd\qurantrans@ur@cclxxxviii{اس دن کی رسوائی و مصیبت سے بچو، جبکہ تم اللہ کی طرف واپس ہو گے، وہاں ہر شخص کو اس کی کمائی ہوئی نیکی یا بدی کا پورا پورا بدلہ مل جائے گا اور کسی پر ظلم ہرگز نہ ہوگا\qt@no{(281)}}%
\qt@newcmd\qurantrans@ur@cclxxxix{اے لوگو جو ایمان لائے ہو، جب کسی مقرر مدت کے لیے تم آپس میں قرض کا لین دین کرو، تو اسے لکھ لیا کرو فریقین کے درمیان انصاف کے ساتھ ایک شخص دستاویز تحریر کرے جسے اللہ نے لکھنے پڑھنے کی قابلیت بخشی ہو، اسے لکھنے سے انکار نہ کرنا چاہیے وہ لکھے اور املا وہ شخص کرائے جس پر حق آتا ہے (یعنی قرض لینے والا)، اور اُسے اللہ، اپنے رب سے ڈرنا چاہیے کہ جو معاملہ طے ہوا ہو اس میں کوئی کمی بیشی نہ کرے لیکن اگر قرض لینے والا خود نادان یا ضعیف ہو، املا نہ کرا سکتا ہو، تواس کا ولی انصاف کے ساتھ املا کرائے پھر اپنے مردوں سے دو آدمیوں کی اس پر گواہی کرا لو اور اگر دو مرد نہ ہوں تو ایک مرد اور دو عورتیں ہوں تاکہ ایک بھول جائے، تو دوسری اسے یاد دلا دے یہ گواہ ایسے لوگوں میں سے ہونے چاہییں، جن کی گواہی تمہارے درمیان مقبول ہو گواہوں کو جب گواہ بننے کے لیے کہا جائے، تو انہیں انکار نہ کرنا چاہیے معاملہ خواہ چھوٹا ہو یا بڑا، میعاد کی تعین کے ساتھ اس کی دستاویز لکھوا لینے میں تساہل نہ کرو اللہ کے نزدیک یہ طریقہ تمہارے لیے زیادہ مبنی بر انصاف ہے، اس سے شہادت قائم ہونے میں زیادہ سہولت ہوتی ہے، اور تمہارے شکوک و شبہات میں مبتلا ہونے کا امکان کم رہ جاتا ہے ہاں جو تجارتی لین دین دست بدست تم لوگ آپس میں کرتے ہو، اس کو نہ لکھا جائے تو کوئی حرج نہیں، مگر تجارتی معاملے طے کرتے وقت گواہ کر لیا کرو کاتب اور گواہ کو ستایا نہ جائے ایسا کرو گے، تو گناہ کا ارتکاب کرو گے اللہ کے غضب سے بچو وہ تم کو صحیح طریق عمل کی تعلیم دیتا ہے اور اسے ہر چیز کا علم ہے\qt@no{(282)}}%
\qt@newcmd\qurantrans@ur@ccxc{اگر تم سفر کی حالت میں ہو اور دستاویز لکھنے کے لیے کوئی کاتب نہ ملے، تو رہن بالقبض پر معاملہ کرو اگر تم میں سے کوئی شخص دوسرے پر بھروسہ کر کے اس کے ساتھ کوئی معاملہ کرے، تو جس پر بھروسہ کیا گیا ہے، اسے چاہیے کہ امانت ادا کرے اور اللہ، اپنے رب سے ڈرے اور شہادت ہرگز نہ چھپاؤ جو شہادت چھپاتا ہے، اس کا دل گناہ میں آلودہ ہے اور اللہ تمہارے اعمال سے بے خبر نہیں ہے\qt@no{(283)}}%
\qt@newcmd\qurantrans@ur@ccxci{آسمانوں اور زمین میں جو کچھ ہے، سب اللہ کا ہے تم اپنے دل کی باتیں خواہ ظاہر کرو یا چھپاؤ اللہ بہرحال ان کا حساب تم سے لے لے گا پھر اسے اختیار ہے، جسے چاہے، معاف کر دے اور جسے چاہے، سزا دے وہ ہر چیز پر قدرت رکھتا ہے\qt@no{(284)}}%
\qt@newcmd\qurantrans@ur@ccxcii{رسول اُس ہدایت پر ایمان لایا ہے جو اس کے رب کی طرف سے اس پر نازل ہوئی ہے اور جو لوگ اِس رسول کے ماننے والے ہیں، انہوں نے بھی اس ہدایت کو دل سے تسلیم کر لیا ہے یہ سب اللہ اور اس کے فرشتوں اوراس کی کتابوں اور اس کے رسولوں کو مانتے ہیں اور ان کا قول یہ ہے کہ: ``ہم اللہ کے رسولوں کو ایک دوسرے سے الگ نہیں کرتے، ہم نے حکم سنا اور اطاعت قبول کی مالک! ہم تجھ سے خطا بخشی کے طالب ہیں اور ہمیں تیری ہی طرف پلٹنا ہے"\qt@no{(285)}}%
\qt@newcmd\qurantrans@ur@ccxciii{اللہ کسی متنفس پر اُس کی مقدرت سے بڑھ کر ذمہ داری کا بوجھ نہیں ڈالتا ہر شخص نے جو نیکی کمائی ہے، اس کا پھل اسی کے لیے ہے اور جو بدی سمیٹی ہے، اس کا وبال اسی پر ہے (ایمان لانے والو! تم یوں دعا کیا کرو) اے ہمارے رب! ہم سے بھول چوک میں جو قصور ہو جائیں، ان پر گرفت نہ کر مالک! ہم پر وہ بوجھ نہ ڈال، جو تو نے ہم سے پہلے لوگوں پر ڈالے تھے پروردگار! جس بار کو اٹھانے کی طاقت ہم میں نہیں ہے، وہ ہم پر نہ رکھ، ہمارے ساتھ نرمی کر، ہم سے در گزر فرما، ہم پر رحم کر، تو ہمارا مولیٰ ہے، کافروں کے مقابلے میں ہماری مدد کر\qt@no{(286)}}%
\qt@newcmd\qurantrans@ur@ccxciv{\basmalahur الف لام میم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ccxcv{اللہ، وہ زندہ جاوید ہستی، جو نظام کائنات کو سنبھالے ہوئے ہے، حقیقت میں اُس کے سوا کوئی خدا نہیں ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@ccxcvi{اُس نے تم پر یہ کتاب نازل کی ہے، جو حق لے کر آئی ہے اور اُن کتابوں کی تصدیق کر رہی ہے جو پہلے سے آئی ہوئی تھیں اس سے پہلے وہ انسانوں کی ہدایت کے لیے تورات اور انجیل نازل کر چکا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@ccxcvii{اور اس نے وہ کسوٹی اتاری ہے (جو حق اور باطل کا فرق د کھانے والی ہے) اب جو لوگ اللہ کے فرامین کو قبول کرنے سے انکار کریں، ان کو یقیناً سخت سزا ملے گی اللہ بے پناہ طاقت کا مالک ہے اور برائی کا بدلہ دینے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@ccxcviii{زمین اور آسمان کی کوئی چیز اللہ سے پوشیدہ نہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@ccxcix{وہی تو ہے جو تمہاری ماؤں کے پیٹ میں تمہاری صورتیں، جیسی چاہتا ہے، بناتا ہے اُس زبردست حکمت والے کے سوا کوئی اور خدا نہیں ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@ccc{وہی خدا ہے، جس نے یہ کتاب تم پر نازل کی ہے اِس کتاب میں دو طرح کی آیات ہیں: ایک محکمات، جو کتاب کی اصل بنیاد ہیں اور دوسری متشابہات جن لوگوں کے دلو ں میں ٹیڑھ ہے، وہ فتنے کی تلاش میں ہمیشہ متشابہات ہی کے پیچھے پڑے رہتے ہیں اور اُن کو معنی پہنانے کی کوشش کیا کرتے ہیں، حالانکہ ان کا حقیقی مفہوم اللہ کے سوا کوئی نہیں جانتا بخلا ف اِس کے جو لوگ علم میں پختہ کار ہیں، وہ کہتے ہیں کہ ``ہمارا اُن پر ایمان ہے، یہ سب ہمارے رب ہی کی طرف سے ہیں" اور سچ یہ ہے کہ کسی چیز سے صحیح سبق صرف دانشمند لوگ ہی حاصل کرتے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@ccci{وہ اللہ سے دعا کرتے رہتے ہیں کہ: ``پروردگار! جب تو ہمیں سیدھے رستہ پر لگا چکا ہے، تو پھر کہیں ہمارے دلوں کو کجی میں مبتلا نہ کر دیجیو ہمیں اپنے خزانہ فیض سے رحمت عطا کر کہ تو ہی فیاض حقیقی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cccii{پروردگار! تو یقیناً سب لوگوں کو ایک روز جمع کرنے والا ہے، جس کے آنے میں کوئی شبہ نہیں تو ہرگز اپنے وعدے سے ٹلنے والا نہیں ہے"\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@ccciii{جن لوگوں نے کفر کا رویہ اختیار کیا ہے، انہیں اللہ کے مقابلے میں نہ اُن کا مال کچھ کام دے گا، نہ اولاد وہ دوزخ کا ایندھن بن کر رہیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@ccciv{اُن کا انجام ویسا ہی ہوگا، جیسا فرعون کے ساتھیوں اور اُن سے پہلے کے نافرمانوں کا ہو چکا ہے کہ اُنہوں نے آیات الٰہی کو جھٹلایا، نتیجہ یہ ہوا کہ اللہ نے ان کے گناہوں پر انہیں پکڑ لیا اور حق یہ ہے کہ اللہ سخت سزا دینے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cccv{پس اے محمدؐ! جن لوگوں نے تمہاری دعوت کو قبول کرنے سے انکار کر دیا ہے، اُن سے کہہ دو کہ قریب ہے وہ وقت، جب تم مغلوب ہو جاؤ گے اور جہنم کی طرف ہانکے جاؤ گے اور جہنم بڑا ہی برا ٹھکانا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cccvi{تمہارے لیے اُن دو گروہوں میں ایک نشان عبرت تھا، جو (بدر میں) ایک دوسرے سے نبرد آزما ہوئے ایک گروہ اللہ کی راہ میں لڑ رہا تھا اور دوسرا گروہ کافر تھا دیکھنے والے بچشم سر دیکھ رہے تھے کہ کافر گروہ مومن گروہ سے دو چند ہے مگر (نتیجے نے ثابت کر دیا کہ) اللہ اپنی فتح و نصرت سے جس کو چاہتا ہے، مدد دیتا ہے دیدۂ بینا رکھنے والوں کے لیے اس میں بڑا سبق پوشیدہ ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cccvii{لوگوں کے لیے مرغوبات نفس، عورتیں، اولا د، سونے چاندی کے ڈھیر، چیدہ گھوڑے، مویشی او ر زرعی زمینیں بڑی خوش آئند بنا دی گئی ہیں، مگر یہ سب دنیا کی چند روزہ زندگی کے سامان ہیں حقیقت میں جو بہتر ٹھکانا ہے، وہ تو اللہ کے پاس ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cccviii{کہو: میں تمہیں بتاؤں کہ ان سے زیادہ اچھی چیز کیا ہے؟ جو لوگ تقویٰ کی روش اختیار کریں، اُن کے لیے ان کے رب کے پا س باغ ہیں، جن کے نیچے نہریں بہتی ہوں گی، وہاں انہیں ہمیشگی کی زندگی حاصل ہوگی، پاکیزہ بیویاں ان کی رفیق ہوں گی اور اللہ کی رضا سے وہ سرفراز ہوں گے اللہ اپنے بندوں کے رویے پر گہری نظر رکھتا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cccix{یہ وہ لوگ ہیں، جو کہتے ہیں کہ ``مالک! ہم ایمان لائے، ہماری خطاؤں سے در گزر فرما اور ہمیں آتش دوزخ سے بچا لے"\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cccx{یہ لوگ صبر کرنے والے ہیں، راستباز ہیں، فرمانبردار اور فیاض ہیں اور رات کی آخری گھڑیوں میں اللہ سے مغفرت کی دعائیں مانگا کرتے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cccxi{اللہ نے خود شہادت دی ہے کہ اس کے سوا کوئی خدا نہیں ہے، او ر (یہی شہادت) فرشتوں اور سب اہل علم نے بھی دی ہے وہ انصاف پر قائم ہے اُس زبردست حکیم کے سوا فی الواقع کوئی خدا نہیں ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cccxii{اللہ کے نزدیک دین صرف اسلام ہے اس دین سے ہٹ کر جو مختلف طریقے اُن لوگوں نے اختیار کیے، جنہیں کتاب دی گئی تھی، اُن کے اِس طرز عمل کی کوئی وجہ اس کے سوا نہ تھی کہ انہوں نے علم آ جانے کے بعد آپس میں ایک دوسرے پر زیادتی کرنے کے لیے ایسا کیا اور جو کوئی اللہ کے احکام و ہدایات کی اطاعت سے انکار کر دے، اللہ کو اس سے حساب لیتے کچھ دیر نہیں لگتی ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cccxiii{اب اگر یہ لوگ تم سے جھگڑا کریں، توا ن سے کہو: ``میں نے اور میرے پیروؤں نے تو اللہ کے آگے سر تسلیم خم کر دیا ہے" پھر اہل کتاب اور غیر اہل کتاب دونوں سے پوچھو: ``کیا تم نے بھی اس کی اطاعت و بندگی قبول کی؟" اگر کی تو وہ راہ راست پا گئے، اور اگر اس سے منہ موڑا تو تم پر صرف پیغام پہنچا دینے کی ذمہ داری تھی آگے اللہ خود اپنے بندوں کے معاملات دیکھنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cccxiv{جو لوگ اللہ کے احکام و ہدایات کو ماننے سے انکار کرتے ہیں اور اس کے پیغمبروں کو ناحق قتل کرتے ہیں اور ایسے لوگوں کی جان کے درپے ہو جاتے ہیں، جو خلق خدا میں عدل و راستی کا حکم دینے کے لیے اٹھیں، ان کو درد ناک سزا کی خوش خبری سنا دو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cccxv{یہ وہ لوگ ہیں جن کے اعمال دنیا اور آخرت دونوں میں ضائع ہوگئے، اور ان کا مددگار کوئی نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cccxvi{تم نے دیکھا نہیں جن لوگوں کو کتاب کے علم میں سے کچھ حصہ ملا ہے، اُن کا حال کیا ہے؟اُنہیں جب کتاب الٰہی کی طرف بلایا جاتا ہے تاکہ وہ اُن کے درمیان فیصلہ کرے، تو ان میں سے ایک فریق اس سے پہلو تہی کرتا ہے اور اس فیصلے کی طرف آنے سے منہ پھیر جاتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cccxvii{ان کا یہ طرز عمل اس وجہ سے ہے کہ وہ کہتے ہیں ``آتش دوزخ تو ہمیں مس تک نہ کرے گی اور اگر دوزخ کی سزا ہم کو ملے گی بھی تو بس چند روز" اُن کے خود ساختہ عقیدوں نے اُن کو اپنے دین کے معاملے میں بڑی غلط فہمیوں میں ڈال رکھا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cccxviii{مگر کیا بنے گی اُن پر جب ہم انہیں اُس روز جمع کریں گے جس کا آنا یقینی ہے؟ اس روز ہر شخص کو اس کی کمائی کا بدلہ پورا پورا دے دیا جائیگا اور کسی پر ظلم نہ ہوگا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cccxix{کہو! خدایا! مُلک کے مالک! تو جسے چاہے، حکومت دے اور جسے چاہے، چھین لے جسے چاہے، عزت بخشے اور جس کو چاہے، ذلیل کر دے بھلائی تیرے اختیار میں ہے بیشک تو ہر چیز پر قادر ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cccxx{رات کو دن میں پروتا ہوا لے آتا ہے اور دن کو رات میں جاندار میں سے بے جان کو نکالتا ہے اور بے جان میں سے جاندار کو اور جسے چاہتا ہے، بے حساب رزق دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cccxxi{مومنین اہل ایمان کو چھوڑ کر کافروں کو اپنا رفیق اور دوست ہرگز نہ بنائیں جو ایسا کرے گا اس کا اللہ سے کوئی تعلق نہیں ہاں یہ معاف ہے کہ تم ان کے ظلم سے بچنے کے لیے بظاہر ایسا طرز عمل اختیار کر جاؤ مگر اللہ تمہیں اپنے آپ سے ڈراتا ہے اور تمہیں اسی کی طرف پلٹ کر جانا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cccxxii{اے نبیؐ! لوگوں کو خبردار کر دو کہ تمہارے دلوں میں جو کچھ ہے، اُسے خواہ تم چھپاؤ یا ظاہر کرو، اللہ بہرحال اسے جانتا ہے، زمین و آسمان کی کوئی چیز اس کے علم سے باہر نہیں ہے اور اُس کا اقتدار ہر چیز پر حاوی ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cccxxiii{وہ دن آنے والا ہے، جب ہر نفس اپنے کیے کا پھل حاضر پائے گا خواہ اُس نے بھلائی کی ہو یا برائی اس روز آدمی یہ تمنا کرے گا کہ کاش ابھی یہ دن اس سے بہت دور ہوتا! اللہ تمہیں اپنے آپ سے ڈراتا ہے اور وہ اپنے بندوں کا نہایت خیر خواہ ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cccxxiv{اے نبیؐ! لوگوں سے کہہ دو کہ، ``اگر تم حقیقت میں اللہ سے محبت رکھتے ہو، تو میر ی پیروی اختیار کرو، اللہ تم سے محبت کرے گا اور تمہاری خطاؤں سے درگزر فرمائے گا وہ بڑا معاف کرنے والا اور رحیم ہے"\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cccxxv{اُن سے کہو کہ ``اللہ اور رسول کی اطاعت قبول کر لو" پھر تم اگر وہ تمہاری دعوت قبول نہ کریں، تو یقیناً یہ ممکن نہیں ہے کہ اللہ ایسے لوگوں سے محبت کرے، جو اس کی اور اس کے رسول کی اطاعت سے انکار کرتے ہوں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cccxxvi{اللہ نے آدمؑ اور نوحؑ اور آل ابراہیم اور آل عمران کو تمام دنیا والوں پر ترجیح دے کر (اپنی رسالت کے لیے) منتخب کیا تھا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cccxxvii{یہ ایک سلسلے کے لوگ تھے، جو ایک دوسرے کی نسل سے پیدا ہوئے تھے اللہ سب کچھ سنتا اور جانتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cccxxviii{(وہ اُس وقت سن رہا تھا) جب عمران کی عورت کہہ رہی تھی کہ، ``میرے پروردگار! میں اس بچے کو جو میرے پیٹ میں ہے تیری نذر کرتی ہوں، وہ تیرے ہی کام کے لیے وقف ہوگا میری اس پیشکش کو قبول فرما تو سننے اور جاننے والا ہے"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cccxxix{پھر جب وہ بچی اس کے ہاں پیدا ہوئی تو اس نے کہا ``مالک! میرے ہاں تو لڑکی پیدا ہو گئی ہے حالانکہ جو کچھ اس نے جنا تھا، اللہ کو اس کی خبر تھی اور لڑکا لڑ کی کی طرح نہیں ہوتا خیر، میں نے اس کا نام مریمؑ رکھ دیا ہے اور میں اسے اور اس کی آئندہ نسل کو شیطان مردود کے فتنے سے تیری پناہ میں دیتی ہوں"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cccxxx{آخرکار اس کے رب نے اس لڑکی کو بخوشی قبول فرما لیا، اُسے بڑی اچھی لڑکی بنا کر اٹھایا اور زکریاؑ کوا س کا سرپرست بنا دیا زکریاؑ جب کبھی اس کے پاس محراب میں جاتا تو اس کے پاس کچھ نہ کچھ کھانے پینے کا سامان پاتا پوچھتا مریمؑ! یہ تیرے پا س کہاں سے آیا؟ وہ جواب دیتی اللہ کے پاس سے آیا ہے، اللہ جسے چاہتا ہے بے حساب دیتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cccxxxi{یہ حال دیکھ کر زکریاؑ نے اپنے رب کو پکارا ``پروردگار! اپنی قدرت سے مجھے نیک اولاد عطا کر تو ہی دعا سننے والا ہے"\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cccxxxii{جواب میں فرشتوں نے آواز دی، جب کہ وہ محراب میں کھڑا نماز پڑھ رہا تھا، کہ ``اللہ تجھے یحییٰؑ کی خوش خبری دیتا ہے وہ اللہ کی طرف سے ایک فرمان کی تصدیق کرنے و الا بن کر آئے گا اس میں سرداری و بزرگی کی شان ہوگی کمال درجہ کا ضابط ہوگا نبوت سے سرفراز ہوگا اور صالحین میں شمار کیا جائے گا"\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cccxxxiii{زکریاؑ نے کہا، ``پروردگار! بھلا میرے ہاں لڑکا کہاں سے ہوگا، میں تو بوڑھا ہو چکا ہوں اور میری بیوی بانجھ ہے" جواب ملا، ``ایسا ہی ہوگا، اللہ جو چاہتا ہے کرتا ہے"\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cccxxxiv{عرض کیا ``مالک! پھر کوئی نشانی میرے لیے مقرر فرما دے" کہا، ``نشانی یہ ہے کہ تم تین دن تک لوگوں سے اشارہ کے سوا کوئی بات چیت نہ کرو گے (یا نہ کرسکو گے) اِس دوران میں اپنے رب کو بہت یاد کرنا اور صبح و شام اس کی تسبیح کرتے رہنا"\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cccxxxv{پھر وہ وقت آیا جب مریمؑ سے فرشتوں نے آکر کہا، ``اے مریمؑ! اللہ نے تجھے برگزیدہ کیا اور پاکیزگی عطا کی اور تمام دنیا کی عورتوں پر تجھ کو ترجیح دے کر اپنی خدمت کے لیے چن لیا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cccxxxvi{اے مریمؑ! اپنے رب کی تابع فرمان بن کر رہ، اس کے آگے سر بسجود ہو، اور جو بندے اس کے حضور جھکنے والے ہیں ان کے ساتھ تو بھی جھک جا"\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cccxxxvii{اے محمدؐ! یہ غیب کی خبریں ہیں جو ہم تم کو وحی کے ذریعہ سے بتا رہے ہیں، ورنہ تم اُس وقت وہاں موجود نہ تھے جب ہیکل کے خادم یہ فیصلہ کرنے کے لیے کہ مریمؑ کا سر پرست کون ہو اپنے اپنے قلم پھینک رہے تھے، اور نہ تم اُس وقت حاضر تھے، جب اُن کے درمیان جھگڑا برپا تھا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cccxxxviii{اور جب فرشتوں نے کہا، ``اے مریمؑ! اللہ تجھے اپنے ایک فرمان کی خوش خبری دیتا ہے اُس کا نام مسیح عیسیٰ ابن مریم ہوگا، دنیا اور آخرت میں معزز ہوگا، اللہ کے مقرب بندوں میں شمار کیا جائے گا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@cccxxxix{لوگوں سے گہوارے میں بھی کلام کرے گا اور بڑی عمر کو پہنچ کر بھی، اور وہ ایک مرد صالح ہوگا"\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@cccxl{یہ سن کر مریمؑ بولی، ``پروردگار! میرے ہاں بچہ کہاں سے ہوگا، مجھے تو کسی شخص نے ہاتھ تک نہیں لگایا" جواب ملا، ``ایسا ہی ہوگا، اللہ جو چاہتا ہے پیدا کرتا ہے وہ جب کسی کام کے کرنے کا فیصلہ فرماتا ہے تو بس کہتا ہے کہ ہو جا اور وہ ہو جاتا ہے"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@cccxli{(فرشتوں نے پھر سلسلئہ کلام میں کہا) ``اور اللہ اُسے کتاب اور حکمت کی تعلیم دے گا، تورات اور انجیل کا علم سکھائے گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@cccxlii{اور بنی اسرائیل کی طرف اپنا رسول مقرر کرے گا" (اور جب وہ بحیثیت رسول بنی اسرائیل کے پاس آیا تو اس نے کہا) ``میں تمہارے رب کی طرف سے تمہارے پاس نشانی لے کر آیا ہوں میں تمہارے سامنے مٹی سے پرندے کی صورت میں ایک مجسمہ بناتا ہوں اور اس میں پھونک مارتا ہوں، وہ اللہ کے حکم سے پرندہ بن جاتا ہے میں اللہ کے حکم سے مادر زاد اندھے اور کوڑھی کو اچھا کرتا ہوں اور مُردے کو زندہ کرتا ہوں میں تمہیں بتاتا ہوں کہ تم کیا کھاتے ہو اور کیا اپنے گھروں میں ذخیرہ کر کے رکھتے ہو اس میں تمہارے لیے کافی نشانی ہے اگر تم ایمان لانے والے ہو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@cccxliii{اور میں اُس تعلیم و ہدایت کی تصدیق کرنے والا بن کر آیا ہوں جو تورات میں سے اِس وقت میرے زمانہ میں موجود ہے اوراس لیے آیا ہوں کہ تمہارے لیے بعض اُن چیزوں کو حلال کر دوں جو تم پر حرام کر دی گئی ہیں دیکھو، میں تمہارے رب کی طرف سے تمہارے پاس نشانی لے کر آیا ہوں، لہٰذا اللہ سے ڈرو اور میر ی اطاعت کرو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@cccxliv{اللہ میرا رب بھی ہے او ر تمہارا رب بھی، لہٰذا تم اُسی کی بندگی اختیار کرو، یہی سیدھا راستہ ہے"\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@cccxlv{جب عیسیٰؑ نے محسوس کیا کہ بنی اسرائیل کفر و انکار پر آمادہ ہیں تو اس نے کہا ``کون اللہ کی راہ میں میرا مدد گار ہوتا ہے؟" حواریوں نے جواب دیا، ``ہم اللہ کے مددگار ہیں، ہم اللہ پر ایمان لائے، گواہ رہو کہ ہم مسلم (اللہ کے آگے سر اطاعت جھکا دینے والے) ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@cccxlvi{مالک! جو فرمان تو نے نازل کیا ہے ہم نے اسے مان لیا اور رسول کی پیروی قبول کی، ہمارا نام گواہی دینے والوں میں لکھ لے"\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@cccxlvii{پھر بنی اسرائیل (مسیح کے خلاف) خفیہ تدبیریں کرنے لگے جواب میں اللہ نے بھی اپنی خفیہ تدبیر کی اور ایسی تدبیروں میں اللہ سب سے بڑھ کر ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@cccxlviii{(وہ اللہ کی خفیہ تدبیر ہی تھی) جب اُس نے کہا کہ، ``اے عیسیٰؑ! اب میں تجھے واپس لے لوں گا اور تجھ کو اپنی طرف اٹھا لوں گا اور جنہوں نے تیرا انکار کیا ہے اُن سے (یعنی ان کی معیت سے اور ان کے گندے ماحول میں ان کے ساتھ رہنے سے) تجھے پاک کر دوں گا اور تیری پیروی کرنے والوں کو قیامت تک ان لوگوں پر بالادست رکھوں گا جنہوں نے تیرا انکار کیا ہے پھر تم سب کو آخر میرے پاس آنا ہے، اُس وقت میں اُن باتوں کا فیصلہ کر دوں گا جن میں تمہارے درمیان اختلاف ہوا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@cccxlix{جن لوگوں نے کفر و انکار کی روش اختیار کی ہے انہیں دنیا اور آخرت دونوں میں سخت سزا دوں گا اور وہ کوئی مددگار نہ پائیں گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@cccl{اور جنہوں نے ایمان اور نیک عملی کا رویہ اختیار کیا ہے انہیں اُن کے اجر پورے پورے دے دیے جائیں گے اور خوب جان لے کہ ظالموں سے اللہ ہرگز محبت نہیں کرتا"\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@cccli{یہ آیات اور حکمت سے لبریز تذکرے ہیں جو ہم تمہیں سنا رہے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@ccclii{اللہ کے نزدیک عیسیٰؑ کی مثال آدمؑ کی سی ہے کہ اللہ نے اسے مٹی سے پیدا کیا اور حکم دیا کہ ہو جا اور وہ ہو گیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@cccliii{یہ اصل حقیقت ہے جو تمہارے رب کی طرف سے بتائی جا رہی ہے اور تم ان لوگوں میں شامل نہ ہو جو اس میں شک کرتے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@cccliv{یہ علم آ جانے کے بعد اب کوئی اس معاملہ میں تم سے جھگڑا کرے تو اے محمدؐ! اس سے کہو، ``آؤ ہم اور تم خود بھی آ جائیں اور اپنے اپنے بال بچوں کو بھی لے آئیں اور خد ا سے دعا کریں کہ جو جھوٹا ہو اُس پر خدا کی لعنت ہو"\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@ccclv{یہ بالکل صحیح واقعات ہیں، اور حقیقت یہ ہے کہ اللہ کے سوا کوئی خداوند نہیں ہے، اور وہ اللہ ہی کی ہستی ہے جس کی طاقت سب سے بالا اور جس کی حکمت نظام عالم میں کار فرما ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@ccclvi{پس اگر یہ لوگ (اِس شرط پر مقابلہ میں آنے سے) منہ موڑیں تو (اُن کا مفسد ہونا صاف کھل جائے گا) اور اللہ تو مفسدوں کے حال سے واقف ہی ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@ccclvii{کہو، ``اے اہل کتاب! آؤ ایک ایسی بات کی طرف جو ہمارے اور تمہارے درمیان یکساں ہے یہ کہ ہم اللہ کے سوا کسی کی بندگی نہ کریں، اس کے ساتھ کسی کو شریک نہ ٹھیرائیں، اور ہم میں سے کوئی اللہ کے سوا کسی کو اپنا رب نہ بنا لے" اس دعوت کو قبول کرنے سے اگر وہ منہ موڑیں تو صاف کہہ دو کہ گواہ رہو، ہم تو مسلم (صرف خدا کی بندگی و اطاعت کرنے والے) ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@ccclviii{اے اہل کتاب! تم ابراہیمؑ کے بارے میں ہم سے کیوں جھگڑا کرتے ہو؟ تورات اور انجیل تو ابراہیمؑ کے بعد ہی نازل ہوئی ہیں پھر کیا تم اتنی بات بھی نہیں سمجھتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@ccclix{تم لوگ جن چیزوں کا علم رکھتے ہو اُن میں تو خوب بحثیں کر چکے، اب ان معاملات میں کیوں بحث کرنے چلے ہو جن کا تمہارے پاس کچھ بھی علم نہیں اللہ جانتا ہے، تم نہیں جانتے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@ccclx{ابراہیمؑ نہ یہودی تھا نہ عیسائی، بلکہ وہ ایک مسلم یکسو تھا اور وہ ہرگز مشرکوں میں سے نہ تھا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@ccclxi{ابراہیمؑ سے نسبت رکھنے کا سب سے زیادہ حق اگر کسی کو پہنچتا ہے تو اُن لوگوں کو پہنچتا ہے جنہوں نے اس کی پیروی کی اور اب یہ نبی اور اس کے ماننے والے اِس نسبت کے زیادہ حق دار ہیں اللہ صرف اُنہی کا حامی و مددگار ہے جو ایمان رکھتے ہوں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@ccclxii{(اے ایمان لانے والو) اہل کتاب میں سے ایک گروہ چاہتا ہے کہ کسی طرح تمہیں راہ راست سے ہٹا دے، حالانکہ در حقیقت وہ اپنے سوا کسی کو گمرا ہی میں نہیں ڈال رہے ہیں مگر انہیں اس کا شعور نہیں ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@ccclxiii{اے اہل کتاب! کیوں اللہ کی آیات کا انکار کرتے ہو حالانکہ تم خود ان کا مشاہدہ کر رہے ہو؟\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@ccclxiv{اے اہل کتاب! کیوں حق کو باطل کا رنگ چڑھا کر مشتبہ بناتے ہو؟ کیوں جانتے بوجھتے حق کو چھپاتے ہو؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@ccclxv{اہل کتاب میں سے ایک گروہ کہتا ہے کہ اس نبی کے ماننے والوں پر جو کچھ نازل ہوا ہے اس پر صبح ایمان لاؤ اور شام کو اس سے انکار کر دو، شاید اس ترکیب سے یہ لوگ اپنے ایمان سے پھر جائیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@ccclxvi{نیز یہ لوگ آپس میں کہتے ہیں کہ اپنے مذہب والے کے سوا کسی کی بات نہ مانو اے نبیؐ! ان سے کہہ دو کہ، ``اصل میں ہدایت تو اللہ کی ہدایت ہے اور یہ اُسی کی دین ہے کہ کسی کو وہی کچھ دے دیا جائے جو کبھی تم کو دیا گیا تھا، یا یہ کہ دوسروں کو تمہارے رب کے حضور پیش کرنے کے لیے تمہارے خلاف قوی حجت مل جائے" اے نبیؐ! ان سے کہو کہ، ``فضل و شرف اللہ کے اختیار میں ہے، جسے چاہے عطا فرمائے وہ وسیع النظر ہے اور سب کچھ جانتا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@ccclxvii{اپنی رحمت کے لیے جس کو چاہتا ہے مخصوص کر لیتا ہے اور اس کا فضل بہت بڑا ہے"\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@ccclxviii{اہل کتاب میں کوئی تو ایسا ہے کہ اگر تم اس کے اعتماد پر مال و دولت کا ایک ڈھیر بھی دے دو تو وہ تمہارا مال تمہیں ادا کر دے گا، اور کسی کا حال یہ ہے کہ اگر تم ایک دینار کے معاملہ میں بھی اس پر بھروسہ کرو تو وہ ادا نہ کرے گا الّا یہ کہ تم اس کے سر پر سوار ہو جاؤ اُن کی اس اخلاقی حالت کا سبب یہ ہے کہ وہ کہتے ہیں، ``امیوں (غیر یہودی لوگوں) کے معاملہ میں ہم پر کوئی مواخذہ نہیں ہے" اور یہ بات وہ محض جھوٹ گھڑ کر اللہ کی طرف منسوب کرتے ہیں، حالانکہ انہیں معلوم ہے کہ اللہ نے ایسی کوئی بات نہیں فرمائی ہے آخر کیوں اُن سے باز پرس نہ ہوگی؟\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@ccclxix{جو بھی اپنے عہد کو پورا کرے گا اور برائی سے بچ کر رہے گا وہ اللہ کا محبوب بنے گا، کیونکہ پرہیز گار لوگ اللہ کو پسند ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@ccclxx{رہے وہ لوگ جو اللہ کے عہد اور اپنی قسموں کو تھوڑی قیمت پر بیچ ڈالتے ہیں، تو ان کے لیے آخرت میں کوئی حصہ نہیں، اللہ قیامت کے روز نہ اُن سے بات کرے گا نہ اُن کی طرف دیکھے گا اور نہ انہیں پاک کرے گا، بلکہ اُن کے لیے تو سخت دردناک سزا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@ccclxxi{اُن میں کچھ لوگ ایسے ہیں جو کتاب پڑھتے ہوئے اس طرح زبان کا الٹ پھیر کرتے ہیں کہ تم سمجھو جو کچھ وہ پڑھ رہے ہیں وہ کتاب ہی کی عبارت ہے، حالانکہ وہ کتاب کی عبارت نہیں ہوتی، وہ کہتے ہیں کہ یہ جو کچھ ہم پڑھ رہے ہیں یہ خدا کی طرف سے ہے، حالانکہ وہ خدا کی طرف سے نہیں ہوتا، وہ جان بوجھ کر جھوٹ بات اللہ کی طرف منسوب کر دیتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@ccclxxii{کسی انسان کا یہ کام نہیں ہے کہ اللہ تو اس کو کتاب اور حکم اور نبوت عطا فرمائے اور وہ لوگوں سے کہے کہ اللہ کے بجائے تم میرے بندے بن جاؤ وہ تو یہی کہے گا کہ سچے ربانی بنو جیسا کہ اس کتاب کی تعلیم کا تقاضا ہے جسے تم پڑھتے اور پڑھاتے ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@ccclxxiii{وہ تم سے ہرگز یہ نہ کہے گا کہ فرشتوں کو یا پیغمبروں کو اپنا رب بنا لو کیا یہ ممکن ہے کہ ایک نبی تمہیں کفر کا حکم دے جب کہ تم مسلم ہو؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@ccclxxiv{یاد کرو، اللہ نے پیغمبروں سے عہد لیا تھا کہ، ``آج ہم نے تمہیں کتاب اور حکمت و دانش سے نوازا ہے، کل اگر کوئی دوسرا رسول تمہارے پاس اُسی تعلیم کی تصدیق کرتا ہوا آئے جو پہلے سے تمہارے پاس موجود ہے، تو تم کو اس پر ایمان لانا ہوگا اور اس کی مدد کرنی ہوگی" یہ ارشاد فرما کر اللہ نے پوچھا، ``کیا تم اِس کا اقرار کرتے ہو اور اس پر میری طرف سے عہد کی بھاری ذمہ داری اٹھاتے ہو؟" اُنہوں نے کہا ہاں ہم اقرار کرتے ہیں اللہ نے فرمایا، ``اچھا تو گواہ رہو اور میں بھی تمہارے ساتھ گواہ ہوں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@ccclxxv{اس کے بعد جو اپنے عہد سے پھر جائے وہی فاسق ہے"\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@ccclxxvi{اب کیا یہ لوگ اللہ کی اطاعت کا طریقہ (دین اللہ) چھوڑ کر کوئی اور طریقہ چاہتے ہیں؟ حالانکہ آسمان و زمین کی ساری چیزیں چار و نا چار اللہ ہی کی تابع فرمان (مسلم) ہیں اور اُسی کی طرف سب کو پلٹنا ہے؟\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@ccclxxvii{اے نبیؐ! کہو کہ ``ہم اللہ کو مانتے ہیں، اُس تعلیم کو مانتے ہیں جو ہم پر نازل کی گئی ہے، اُن تعلیمات کو بھی مانتے ہیں جو ابراہیمؑ، اسماعیلؑ، اسحاقؑ، یعقوبؑ اور اولاد یعقوبؑ پر نازل ہوئی تھیں اور اُن ہدایات پر بھی ایمان رکھتے ہیں جو موسیٰؑ اور عیسیٰؑ اور دوسرے پیغمبروں کو اُن کے رب کی طرف سے دی گئیں ہم ان کے درمیان فرق نہیں کرتے اور ہم اللہ کے تابع فرمان (مسلم) ہیں"\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@ccclxxviii{اس فرماں برداری (اسلام) کے سوا جو شخص کوئی اور طریقہ اختیار کرنا چاہے اس کا وہ طریقہ ہرگز قبول نہ کیا جائے گا اور آخرت میں وہ ناکام و نامراد رہے گا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@ccclxxix{کیسے ہوسکتا ہے کہ اللہ اُن لوگوں کو ہدایت بخشے جنہوں نے نعمت ایمان پا لینے کے بعد پھر کفر اختیار کیا حالانکہ وہ خود اس بات پر گواہی دے چکے ہیں کہ یہ رسول حق پر ہے اور ان کے پاس روشن نشانیاں بھی آ چکی ہیں اللہ ظالموں کو تو ہدایت نہیں دیا کرتا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@ccclxxx{ان کے ظلم کا صحیح بدلہ یہی ہے کہ ان پر اللہ اور فرشتوں اور تمام انسانوں کی پھٹکار ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@ccclxxxi{اِسی حالت میں وہ ہمیشہ رہیں گے، نہ ان کی سزا میں تخفیف ہوگی اور نہ انہیں مہلت دی جائے گی\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@ccclxxxii{البتہ وہ لوگ بچ جائیں گے جو اِس کے بعد توبہ کر کے اپنے طرز عمل کی اصلاح کر لیں، اللہ بخشنے والا اور رحم فرمانے والا ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiii{مگر جن لوگوں نے ایمان لانے کے بعد کفر اختیار کیا، پھر اپنے کفر میں بڑھتے چلے گئے ان کی توبہ بھی قبول نہ ہوگی، ایسے لوگ تو پکے گمراہ ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiv{یقین رکھو، جن لوگوں نے کفر اختیار کیا اور کفر ہی کی حالت میں جان دی اُن میں سے کوئی اگر اپنے آپ کو سزا سے بچانے کے لیے روئے زمین بھر کر بھی سونا فدیہ میں دے تو اُسے قبول نہ کیا جائے گا ایسے لوگوں کے لیے دردناک سزا تیار ہے اور و ہ اپنا کوئی مددگار نہ پائیں گے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@ccclxxxv{تم نیکی کو نہیں پہنچ سکتے جب تک کہ اپنی وہ چیزیں (خدا کی راہ میں) خرچ نہ کرو جنہیں تم عزیز رکھتے ہو، اور جو کچھ تم خرچ کرو گے اللہ اس سے بے خبر نہ ہوگا\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvi{کھانے کی یہ ساری چیزیں (جو شریعت محمدیؐ میں حلال ہیں) بنی اسرائیل کے لیے بھی حلال تھیں، البتہ بعض چیزیں ایسی تھیں جنہیں توراۃ کے نازل کیے جانے سے پہلے اسرائیل نے خود اپنے اوپر حرام کر لیا تھا ان سے کہو، اگر تم (ا پنے اعتراض میں) سچے ہو تو لاؤ توراۃ اور پیش کرو اس کی کوئی عبارت\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvii{اس کے بعد بھی جولو گ اپنی جھوٹی گھڑی ہوئی باتیں اللہ کی طرف منسوب کرتے رہیں و ہی در حقیقت ظالم ہیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@ccclxxxviii{کہو، اللہ نے جو کچھ فرمایا ہے سچ فرمایا ہے، تم کو یکسو ہو کر ابراہیمؑ کے طریقہ کی پیروی کرنی چاہیے، اور ابراہیمؑ شرک کرنے والوں میں سے نہ تھا\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ccclxxxix{بے شک سب سے پہلی عبادت گاہ جو انسانوں کے لیے تعمیر ہوئی وہ وہی ہے جو مکہ میں واقع ہے اس کو خیر و برکت دی گئی تھی اور تمام جہان والوں کے لیے مرکز ہدایت بنایا گیا تھا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@cccxc{اس میں کھلی ہوئی نشانیاں ہیں، ابراہیمؑ کا مقام عبادت ہے، اوراس کا حال یہ ہے کہ جو اِس میں داخل ہوا مامون ہو گیا لوگوں پر اللہ کا یہ حق ہے کہ جو اس گھر تک پہنچنے کی استطاعت رکھتا ہو وہ اس کا حج کرے، اور جو کوئی اس حکم کی پیروی سے انکار کرے تو اسے معلوم ہو جانا چاہیے کہ اللہ تمام د نیا والوں سے بے نیاز ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cccxci{کہو، اے اہل کتاب! تم کیوں اللہ کی باتیں ماننے سے انکار کرتے ہو؟ جو حرکتیں تم کر رہے ہو اللہ سب کچھ دیکھ رہا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cccxcii{کہو، اے اہل کتاب! یہ تمہاری کیا روش ہے کہ جو اللہ کی بات مانتا ہے اُسے بھی تم اللہ کے راستہ سے روکتے ہو اور چاہتے ہو کہ وہ ٹیڑھی راہ چلے، حالانکہ تم خود (اس کے راہ راست ہونے پر) گواہ ہو تمہاری حرکتوں سے اللہ غافل نہیں ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cccxciii{اے لوگو جو ایمان لائے ہو، اگر تم نے اِن اہل کتاب میں سے ایک گروہ کی بات مانی تو یہ تمہیں ایمان سے پھر کفر کی طرف پھیر لے جائیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cccxciv{تمہارے لیے کفر کی طرف جانے کا اب کیا موقع باقی ہے جب کہ تم کو اللہ کی آیات سنائی جا رہی ہیں اور تمہارے درمیان اس کا رسولؐ موجود ہے؟ جو اللہ کا دامن مضبوطی کے ساتھ تھامے گا وہ ضرور راہ راست پالے گا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cccxcv{اے لوگو جو ایمان لائے ہو، اللہ سے ڈرو جیسا کہ اس سے ڈرنے کا حق ہے تم کو موت نہ آئے مگر اس حال میں کہ تم مسلم ہو\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cccxcvi{سب مل کر اللہ کی رسی کو مضبوط پکڑ لو اور تفرقہ میں نہ پڑو اللہ کے اُس احسان کو یاد رکھو جو اس نے تم پر کیا ہے تم ایک دوسرے کے دشمن تھے، اُس نے تمہارے دل جوڑ دیے اور اس کے فضل و کرم سے تم بھائی بھائی بن گئے تم آگ سے بھرے ہوئے ایک گڑھے کے کنارے کھڑے تھے، اللہ نے تم کو اس سے بچا لیا اس طرح اللہ اپنی نشانیاں تمہارے سامنے روشن کرتا ہے شاید کہ اِن علامتوں سے تمہیں اپنی فلاح کا سیدھا راستہ نظر آ جائے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cccxcvii{تم میں کچھ لوگ تو ایسے ضرور ہی رہنے چاہییں جو نیکی کی طرف بلائیں، بھلائی کا حکم دیں، اور برائیوں سے روکتے رہیں جو لوگ یہ کام کریں گے وہی فلاح پائیں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cccxcviii{کہیں تم اُن لوگوں کی طرح نہ ہو جانا جو فرقوں میں بٹ گئے اور کھلی کھلی واضح ہدایات پانے کے بعد پھر اختلافات میں مبتلا ہوئے جنہوں نے یہ روش اختیار کی وہ اُس روزسخت سزا پائیں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cccxcix{جبکہ کچھ لوگ سرخ رو ہوں گے اور کچھ لوگوں کا منہ کالا ہوگا، جن کا منہ کالا ہوگا (ان سے کہا جائے گا کہ) نعمت ایمان پانے کے بعد بھی تم نے کافرانہ رویہ اختیار کیا؟ اچھا تو اب اِس کفران نعمت کے صلہ میں عذاب کا مزہ چکھو\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cd{رہے وہ لوگ جن کے چہرے روشن ہوں گے تو اُن کو اللہ کے دامن رحمت میں جگہ ملے گی اور ہمیشہ وہ اسی حالت میں رہیں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cdi{یہ اللہ کے ارشادات ہیں جو ہم تمہیں ٹھیک ٹھیک سنارہے ہیں کیونکہ اللہ دنیا والوں پر ظلم کرنے کا کوئی ارادہ نہیں رکھتا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cdii{زمین و آسمان کی ساری چیزوں کا مالک اللہ ہے اور سارے معاملات اللہ ہی کے حضور پیش ہوتے ہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cdiii{اب دنیا میں وہ بہترین گروہ تم ہو جسے انسانوں کی ہدایت و اصلاح کے لیے میدان میں لایا گیا ہے تم نیکی کا حکم دیتے ہو، بدی سے روکتے ہو اور اللہ پر ایمان رکھتے ہو یہ اہل کتاب ایمان لاتے تو انہی کے حق میں بہتر تھا اگرچہ ان میں کچھ لوگ ایمان دار بھی پائے جاتے ہیں مگر اِن کے بیشتر افراد نافرمان ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cdiv{یہ تمہارا کچھ بگاڑ نہیں سکتے، زیادہ سے زیادہ بس کچھ ستا سکتے ہیں اگر یہ تم سے لڑیں گے تو مقابلہ میں پیٹھ دکھائیں گے، پھر ایسے بے بس ہوں گے کہ کہیں سے اِن کو مدد نہ ملے گی\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cdv{یہ جہاں بھی پائے گئے اِن پر ذلت کی مار ہی پڑی، کہیں اللہ کے ذمہ یا انسانوں کے ذمہ میں پناہ مل گئی تو یہ اور بات ہے یہ اللہ کے غضب میں گھر چکے ہیں، ان پر محتاجی و مغلوبی مسلط کر دی گئی ہے، اور یہ سب کچھ صرف اس وجہ سے ہوا ہے کہ یہ اللہ کی آیات سے کفر کرتے رہے اور انہوں نے پیغمبروں کو ناحق قتل کیا یہ ان کی نافرمانیوں اور زیادتیوں کا انجام ہے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cdvi{مگر سارے اہل کتاب یکساں نہیں ہیں ان میں کچھ لوگ ایسے بھی ہیں جو راہ راست پر قائم ہیں، راتوں کو اللہ کی آیات پڑھتے ہیں اور اسکے آگے سجدہ ریز ہوتے ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cdvii{اللہ اور روز آخرت پر ایمان رکھتے ہیں، نیکی کا حکم دیتے ہیں، برائیوں سے روکتے ہیں اور بھلائی کے کاموں میں سرگرم رہتے ہیں یہ صالح لوگ ہیں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cdviii{اور جو نیکی بھی یہ کریں گے اس کی نا قدری نہ کی جائے گی، اللہ پرہیزگار لوگوں کو خوب جانتا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cdix{رہے وہ لوگ جنہوں نے کفر کا رویہ اختیار کیا تو اللہ کے مقابلہ میں ان کو نہ ان کا مال کچھ کام دے گا نہ اولاد، وہ تو آگ میں جانے والے لوگ ہیں اور آگ ہی میں ہمیشہ رہیں گے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cdx{جو کچھ وہ اپنی اس دنیا کی زندگی میں خرچ کر رہے ہیں اُس کی مثال اُس ہوا کی سی ہے جس میں پالا ہو اور وہ اُن لوگوں کی کھیتی پر چلے جنہوں نے اپنے اوپر ظلم کیا ہے اور اسے برباد کر کے رکھ دے اللہ نے ان پر ظلم نہیں کیا در حقیقت یہ خود اپنے اوپر ظلم کر رہے ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cdxi{اے لوگو جو ایمان لائے ہو، اپنی جماعت کے لوگوں کے سوا دوسروں کو اپنا راز دار نہ بناؤ وہ تمہاری خرابی کے کسی موقع سے فائدہ اٹھانے میں نہیں چوکتے تمہیں جس چیز سے نقصان پہنچے وہی ان کو محبوب ہے ان کے دل کا بغض ان کے منہ سے نکلا پڑتا ہے اور جو کچھ وہ اپنے سینوں میں چھپائے ہوئے ہیں وہ اس سے شدید تر ہے ہم نے تمہیں صاف صاف ہدایات دے دی ہیں، اگر تم عقل رکھتے ہو (تو ان سے تعلق رکھنے میں احتیاط برتو گے)\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cdxii{تم ان سے محبت رکھتے ہو مگر وہ تم سے محبت نہیں رکھتے حالانکہ تم تمام کتب آسمانی کو مانتے ہو جب وہ تم سے ملتے ہیں تو کہتے ہیں کہ ہم نے بھی (تمہارے رسول اور تمہاری کتاب کو) مان لیا ہے، مگر جب جدا ہوتے ہیں تو تمہارے خلاف ان کے غیظ و غضب کا یہ حال ہوتا ہے کہ اپنی انگلیاں چبانے لگتے ہیں ان سے کہہ دو کہ اپنے غصہ میں آپ جل مرو اللہ دلوں کے چھپے ہوئے راز تک جانتا ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cdxiii{تمہارا بھلا ہوتا ہے تو ان کو برا معلوم ہوتا ہے، اور تم پر کوئی مصیبت آتی ہے تو یہ خوش ہوتے ہیں مگر ان کی کوئی تدبیر تمہارے خلاف کارگر نہیں ہوسکتی بشرطیکہ تم صبر سے کام لو اور اللہ سے ڈر کر کام کرتے رہو جو کچھ یہ کر رہے ہیں اللہ اُس پر حاوی ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cdxiv{(اے پیغمبرؐ! مسلمانوں کے سامنے اُس موقع کا ذکر کرو) جب تم صبح سویرے اپنے گھر سے نکلے تھے اور (احد کے میدان میں) مسلمانوں کو جنگ کے لیے جا بجا مامور کر رہے تھے اللہ ساری باتیں سنتا ہے اور وہ نہایت باخبر ہے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cdxv{یاد کرو جب تم میں سے دو گروہ بزدلی د کھانے پر آمادہ ہوگئے تھے، حالانکہ اللہ ان کی مدد پر موجود تھا اور مومنوں کو اللہ ہی پر بھروسہ رکھنا چاہیے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cdxvi{آخر اس سے پہلے جنگ بدر میں اللہ تمہاری مدد کر چکا تھا حالانکہ اس وقت تم بہت کمزور تھے لہٰذا تم کو چاہیے کہ اللہ کی ناشکر ی سے بچو، امید ہے کہ اب تم شکر گزار بنو گے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cdxvii{یاد کرو جب تم مومنوں سے کہہ رہے تھے، ``کیا تمہارے لیے یہ بات کافی نہیں کہ اللہ تین ہزار فرشتے اتار کر تمہاری مدد کرے؟"\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cdxviii{بے شک، اگر تم صبر کرو اور خدا سے ڈرتے ہوئے کام کرو تو جس آن دشمن تمہارے اوپر چڑھ کر آئیں گے اُسی آن تمہارا رب (تین ہزار نہیں) پانچ ہزار صاحب نشان فرشتوں سے تمہاری مدد کرے گا\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cdxix{یہ بات اللہ نے تمہیں اس لیے بتا دی ہے کہ تم خوش ہو جاؤ اور تمہارے دل مطمئن ہو جائیں فتح و نصرت جو کچھ بھی ہے اللہ کی طرف سے ہے جو بڑی قوت والا اور دانا و بینا ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cdxx{(اور یہ مدد وہ تمہیں اس لیے دے گا) تاکہ کفر کی راہ چلنے والوں کا ایک بازو کاٹ دے، یا ان کو ایسی ذلیل شکست دے کہ وہ نامرادی کے ساتھ پسپا ہو جائیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cdxxi{(اے پیغمبرؐ) فیصلہ کے اختیارات میں تمہارا کوئی حصہ نہیں، اللہ کو اختیار ہے چاہے انہیں معاف کرے، چاہے سزا دے کیونکہ وہ ظالم ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cdxxii{زمین اور آسمانوں میں جو کچھ ہے اس کا مالک اللہ ہے، جس کو چاہے بخش دے اور جس کو چاہے عذاب دے، و ہ معاف کرنے والا اور رحیم ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cdxxiii{اے لوگو جو ایمان لائے ہو، یہ بڑھتا اور چڑھتا سود کھانا چھوڑ دو اور اللہ سے ڈرو، امید ہے کہ فلاح پاؤ گے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cdxxiv{اُس آگ سے بچو جو کافروں کے لیے مہیا کی گئی ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cdxxv{اور اللہ اور رسول کا حکم مان لو، توقع ہے کہ تم پر رحم کیا جائے گا\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cdxxvi{دوڑ کر چلو اُ س راہ پر جو تمہارے رب کی بخشش اور اُس جنت کی طرف جاتی ہے جس کی وسعت زمین اور آسمانوں جیسی ہے، اور وہ اُن خدا ترس لوگوں کے لیے مہیا کی گئی\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cdxxvii{جو ہر حال میں اپنے مال خرچ کرتے ہیں خواہ بد حال ہوں یا خوش حال، جو غصے کو پی جاتے ہیں اور دوسروں کے قصور معاف کر دیتے ہیں ایسے نیک لوگ اللہ کو بہت پسند ہیں\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cdxxviii{اور جن کا حال یہ ہے کہ اگر کبھی کوئی فحش کام ان سے سرزد ہو جاتا ہے یا کسی گناہ کا ارتکاب کر کے وہ اپنے اوپر ظلم کر بیٹھتے ہیں تو معاً اللہ انہیں یاد آ جاتا ہے اور اس سے وہ اپنے قصوروں کی معافی چاہتے ہیں کیونکہ اللہ کے سوا اور کون ہے جو گناہ معاف کرسکتا ہو او ر وہ دیدہ و دانستہ اپنے کیے پر اصرار نہیں کرتے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cdxxix{ایسے لوگوں کی جزا ان کے رب کے پاس یہ ہے کہ وہ ان کو معاف کر دے گا اور ایسے باغوں میں انہیں داخل کرے گا جن کے نیچے نہریں بہتی ہونگی اور وہاں وہ ہمیشہ رہیں گے کیسا اچھا بدلہ ہے نیک عمل کرنے والوں کے لیے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cdxxx{تم سے پہلے بہت سے دور گزر چکے ہیں، زمین میں چل پھر کر دیکھ لو کہ اُن لوگوں کا کیا انجام ہوا جنہوں نے (اللہ کے احکام و ہدایات کو) جھٹلایا\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cdxxxi{یہ لوگوں کے لیے ایک صاف اور صریح تنبیہ ہے اور جو اللہ سے ڈرتے ہوں اُن کے لیے ہدایت اور نصیحت\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cdxxxii{دل شکستہ نہ ہو، غم نہ کرو، تم ہی غالب رہو گے اگر تم مومن ہو\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cdxxxiii{ا ِس وقت اگر تمھیں چوٹ لگی ہے تو اس سے پہلے ایسی ہی چوٹ تمہارے مخالف فریق کو بھی لگ چکی ہے یہ تو زمانہ کے نشیب و فراز ہیں جنہیں ہم لوگوں کے درمیان گردش دیتے رہتے ہیں تم پر یہ وقت ا س لیے لایا گیا کہ اللہ دیکھنا چاہتا تھا کہ تم میں سچے مومن کون ہیں، اور ان لوگوں کو چھانٹ لینا چاہتا تھا جو واقعی (راستی کے) گواہ ہوں کیونکہ ظالم لوگ اللہ کو پسند نہیں ہیں\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cdxxxiv{اور وہ اس آزمائش کے ذریعہ سے مومنوں کو الگ چھانٹ کر کافروں کی سرکوبی کر دینا چاہتا تھا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cdxxxv{کیا تم نے یہ سمجھ رکھا ہے کہ یونہی جنت میں چلے جاؤ گے حالانکہ ابھی اللہ نے یہ تو دیکھا ہی نہیں کہ تم میں کون وہ لوگ ہیں جو اس کی راہ میں جانیں لڑانے والے اور اس کی خاطر صبر کرنے والے ہیں\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cdxxxvi{تم تو موت کی تمنائیں کر رہے تھے! مگر یہ اُس وقت کی بات تھی جب موت سامنے نہ آئی تھی، لو اب وہ تمہارے سامنے آ گئی اور تم نے اُسے آنکھوں دیکھ لیا\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cdxxxvii{محمدؐ اس کے سوا کچھ نہیں کہ بس ایک رسول ہیں، اُن سے پہلے اور رسول بھی گزر چکے ہیں، پھر کیا اگر وہ مر جائیں یا قتل کر دیے جائیں تو تم لوگ الٹے پاؤں پھر جاؤ گے؟ یاد رکھو! جو الٹا پھرے گا وہ اللہ کا کچھ نقصان نہ کرے گا، البتہ جو اللہ کے شکر گزار بندے بن کر رہیں گے انہیں وہ اس کی جزا دے گا\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cdxxxviii{کوئی ذی روح اللہ کے اذن کے بغیر نہیں مرسکتا موت کا وقت تو لکھا ہوا ہے جو شخص ثواب دنیا کے ارادہ سے کام کرے گا اس کو ہم دنیا ہی میں سے دیں گے، اور جو ثواب آخرت کے ارادہ سے کام کرے گا وہ آخرت کا ثواب پائے گا اور شکر کرنے والوں کو ہم اُن کی جزا ضرور عطا کریں گے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cdxxxix{اِس سے پہلے کتنے ہی نبی ایسے گزر چکے ہیں جن کے ساتھ مل کر بہت سے خدا پرستوں نے جنگ کی اللہ کی راہ میں جو مصیبتیں اُن پر پڑیں ان سے وہ دل شکستہ نہیں ہوئے، انہوں نے کمزوری نہیں دکھائی، وہ (باطل کے آگے) سرنگوں نہیں ہوئے ایسے ہی صابروں کو اللہ پسند کرتا ہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cdxl{ان کی دعا بس یہ تھی کہ، ``اے ہمارے رب! ہماری غلطیوں اور کوتاہیوں سے درگزر فرما، ہمارے کام میں تیرے حدود سے جو کچھ تجاوز ہو گیا ہو اُسے معاف کر دے، ہمارے قدم جما دے اور کافروں کے مقابلہ میں ہماری مدد کر"\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cdxli{آخرکار اللہ نے ان کو دنیا کا ثواب بھی دیا اور اس سے بہتر ثواب آخرت بھی عطا کیا اللہ کو ایسے ہی نیک عمل لوگ پسند ہیں\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cdxlii{اے لوگو جو ایمان لائے ہو، اگر تم اُن لوگوں کے اشاروں پر چلو گے جنہوں نے کفر کی راہ اختیار کی ہے تو وہ تم کو الٹا پھیر لے جائیں گے اور تم نامراد ہو جاؤ گے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cdxliii{(اُن کی باتیں غلط ہیں) حقیقت یہ ہے کہ اللہ تمہارا حامی و مددگار ہے اور وہ بہترین مدد کرنے والا ہے\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cdxliv{عنقریب وہ وقت آنے والا ہے جب ہم منکرین حق کے دلوں میں رعب بٹھا دیں گے، اس لیے کہ اُنہوں نے اللہ کے ساتھ اُن کو خدائی میں شریک ٹھیرایا ہے جن کے شریک ہونے پر اللہ نے کوئی سند نازل نہیں کی اُن کا آخری ٹھکانا جہنم ہے اور بہت ہی بری ہے وہ قیام گاہ جو اُن ظالموں کو نصیب ہوگی\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cdxlv{اللہ نے (تائید و نصرت کا) جو وعدہ تم سے کیا تھا وہ تو اُس نے پورا کر دیا ابتدا میں اُس کے حکم سے تم ہی اُن کو قتل کر رہے تھے مگر جب تم نے کمزوری دکھائی اور اپنے کام میں باہم اختلاف کیا، اور جونہی کہ وہ چیز اللہ نے تمہیں دکھائی جس کی محبت میں تم گرفتار تھے (یعنی مال غنیمت) تم اپنے سردار کے حکم کی خلاف ورزی کر بیٹھے اس لیے کہ تم میں سے کچھ لوگ دنیا کے طالب تھے اور کچھ آخرت کی خواہش رکھتے تھے تب اللہ نے تمہیں کافروں کے مقابلہ میں پسپا کر دیا تاکہ تمہاری آزمائش کرے اور حق یہ ہے کہ اللہ نے پھر بھی تمہیں معاف ہی کر دیا کیونکہ مومنوں پر اللہ بڑی نظر عنایت رکھتا ہے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cdxlvi{یاد کرو جب تم بھاگے چلے جا رہے تھے، کسی کی طرف پلٹ کر دیکھنے تک کا ہوش تمہیں نہ تھا، اور رسولؐ تمہارے پیچھے تم کو پکار رہا تھا اُس وقت تمہاری اس روش کا بدلہ اللہ نے تمہیں یہ دیا کہ تم کو رنج پر رنج دیے تاکہ آئندہ کے لیے تمہیں یہ سبق ملے کہ جو کچھ تمہارے ہاتھ سے جائے یا جو مصیبت تم پر نازل ہو اس پر ملول نہ ہو اللہ تمہارے سب اعمال سے باخبر ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cdxlvii{اس غم کے بعد پھر اللہ نے تم میں سے کچھ لوگوں پر ایسی اطمینان کی سی حالت طاری کر دی کہ وہ اونگھنے لگے مگر ایک دوسرا گروہ، جس کے لیے ساری اہمیت بس اپنے مفاد ہی کی تھی، اللہ کے متعلق طرح طرح کے جاہلانہ گمان کرنے لگا جو سراسر خلاف حق تھے یہ لوگ اب کہتے ہیں کہ، ``اس کام کے چلانے میں ہمارا بھی کوئی حصہ ہے؟" ان سے کہو ``(کسی کا کوئی حصہ نہیں) اِس کام کے سارے اختیارات اللہ کے ہاتھ میں ہیں" دراصل یہ لوگ اپنے دلوں میں جو بات چھپائے ہوئے ہیں اُسے تم پر ظاہر نہیں کرتے ان کا اصل مطلب یہ ہے کہ، ``اگر (قیادت کے) اختیارات میں ہمارا کچھ حصہ ہوتا تو یہاں ہم نہ مارے جاتے" ان سے کہہ دو کہ، ``اگر تم اپنے گھروں میں بھی ہوتے تو جن لوگوں کی موت لکھی ہوئی تھی وہ خود اپنی قتل گاہوں کی طرف نکل آتے" اور یہ معاملہ جو پیش آیا، یہ تو اس لیے تھا کہ جو کچھ تمہارے سینوں میں پوشیدہ ہے اللہ اُسے آزما لے اور جو کھوٹ تمہارے دلوں میں ہے اُسے چھانٹ دے، اللہ دلوں کا حال خوب جانتا ہے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cdxlviii{تم میں سے جو لوگ مقابلہ کے دن پیٹھ پھیر گئے تھے اُن کی ا ِس لغزش کا سبب یہ تھا کہ ان کی بعض کمزوریوں کی وجہ سے شیطان نے اُن کے قدم ڈگمگا دیے تھے اللہ نے انہیں معاف کر دیا، اللہ بہت درگزر کرنے والا اور بردبار ہے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cdxlix{اے لوگو جو ایمان لائے ہو، کافروں کی سی باتیں نہ کرو جن کے عزیز و اقارب اگر کبھی سفر پر جاتے ہیں یا جنگ میں شریک ہوتے ہیں (اور وہاں کسی حادثہ سے دو چار ہو جاتے ہیں) تو وہ کہتے ہیں کہ اگر وہ ہمارے پاس ہوتے تو نہ مارے جاتے اور نہ قتل ہوتے اللہ اس قسم کی باتوں کو ان کے دلوں میں حسرت و اندوہ کا سبب بنا دیتا ہے، ورنہ دراصل مارنے اور جِلانے والا تو اللہ ہی ہے اور تمہاری حرکات پر وہی نگراں ہے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cdl{اگر تم اللہ کی راہ میں مارے جاؤ یا مر جاؤ تو اللہ کی جو رحمت اور بخشش تمہارے حصہ میں آئے گی وہ اُن ساری چیزوں سے زیادہ بہتر ہے جنہیں یہ لوگ جمع کرتے ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cdli{اور خواہ تم مرو یا مارے جاؤ بہر حال تم سب کو سمٹ کر جانا اللہ ہی کی طرف ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cdlii{(اے پیغمبرؐ) یہ اللہ کی بڑی رحمت ہے کہ تم اِن لوگوں کے لیے بہت نرم مزاج واقع ہوئے ہو ورنہ اگر کہیں تم تند خو اور سنگ دل ہوتے تو یہ سب تمہارے گردو پیش سے چھٹ جاتے اِن کے قصور معاف کر دو، اِن کے حق میں دعا ئے مغفرت کرو، اور دین کے کام میں ان کو بھی شریک مشورہ رکھو، پھر جب تمہارا عزم کسی رائے پر مستحکم ہو جائے تو اللہ پر بھروسہ کرو، اللہ کو وہ لوگ پسند ہیں جو اُسی کے بھروسے پر کام کرتے ہیں\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cdliii{اللہ تمہاری مدد پر ہو تو کوئی طاقت تم پر غالب آنے والی نہیں، اور وہ تمہیں چھوڑ دے، تو اس کے بعد کون ہے جو تمہاری مدد کرسکتا ہو؟ پس جو سچے مومن ہیں ان کو اللہ ہی پر بھروسہ رکھنا چاہیے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cdliv{کسی نبی کا یہ کام نہیں ہوسکتا کہ وہ خیانت کر جائے اور جو کوئی خیانت کرے تو وہ اپنی خیانت سمیت قیامت کے روز حاضر ہو جائے گا، پھر ہر متنفس کو اس کی کمائی کا پورا پورا بدلہ مل جائے گا اور کسی پر کچھ ظلم نہ ہوگا\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cdlv{بھلا یہ کیسے ہوسکتا ہے کہ جو شخص ہمیشہ اللہ کی رضا پر چلنے والا ہو وہ اُس شخص کے سے کام کرے جو اللہ کے غضب میں گھر گیا ہو اور جس کا آخری ٹھکانا جہنم ہو جو بدترین ٹھکانا ہے؟\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cdlvi{اللہ کے نزدیک دونوں قسم کے آدمیوں میں بدرجہا فرق ہے اور اللہ سب کے اعمال پر نظر رکھتا ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cdlvii{درحقیقت اہل ایمان پر تو اللہ نے یہ بہت بڑا احسان کیا ہے کہ اُن کے درمیان خود انہی میں سے ایک ایسا پیغمبر اٹھایا جو اس کی آیات انہیں سناتا ہے، اُن کی زندگیوں کو سنوارتا ہے اور اُن کو کتاب اور دانائی کی تعلیم دیتا ہے، حالانکہ اس سے پہلے یہی لوگ صریح گمراہیوں میں پڑے ہوئے تھے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cdlviii{اور یہ تمہارا کیا حال ہے کہ جب تم پر مصیبت آ پڑی تو تم کہنے لگے یہ کہاں سے آئی؟ حالانکہ (جنگ بدر میں) اس سے د و گنی مصیبت تمہارے ہاتھوں (فریق مخالف پر) پڑ چکی ہے اے نبیؐ! اِن سے کہو، یہ مصیبت تمہاری اپنی لائی ہوئی ہے، اللہ ہر چیز پر قادر ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cdlix{جو نقصان لڑائی کے دن تمہیں پہنچا وہ اللہ کے اذن سے تھا اور اس لیے تھا کہ اللہ دیکھ لے تم میں سے مومن کون ہیں\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@cdlx{اور منافق کون، وہ منافق کہ جب اُن سے کہا گیا آؤ، اللہ کی راہ میں جنگ کرو یا کم از کم (اپنے شہر کی) مدافعت ہی کرو، تو کہنے لگے اگر ہمیں علم ہوتا کہ آج جنگ ہوگی تو ہم ضرور ساتھ چلتے یہ بات جب وہ کہہ رہے تھے اُس وقت وہ ایمان کی نسبت کفر سے زیادہ قریب تھے وہ اپنی زبانوں سے وہ باتیں کہتے ہیں جو ان کے دلوں میں نہیں ہوتیں، اور جو کچھ وہ دلوں میں چھپاتے ہیں اللہ اسے خوب جانتا ہے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@cdlxi{یہ وہی لوگ ہیں جو خود تو بیٹھے رہے او ران کے جو بھائی بند لڑنے گئے اور مارے گئے ان کے متعلق انہوں نے کہہ دیا کہ ا گروہ ہماری بات مان لیتے تو نہ مارے جاتے ان سے کہو اگر تم اپنے قول میں سچے ہو تو خود تمہاری موت جب آئے اُسے ٹال کر دکھا دینا\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@cdlxii{جو لوگ اللہ کی راہ میں قتل ہوئے ہیں انہیں مردہ نہ سمجھو، وہ تو حقیقت میں زندہ ہیں، اپنے رب کے پاس رزق پا رہے ہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@cdlxiii{جو کچھ اللہ نے اپنے فضل سے انہیں دیا ہے اُس پر خوش و خرم ہیں، اور مطمئن ہیں کہ جو اہل ایمان انکے پیچھے دنیا میں رہ گئے ہیں اور ابھی وہاں نہیں پہنچے ہیں ان کے لیے بھی کسی خوف اور رنج کا موقع نہیں ہے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@cdlxiv{وہ اللہ کے انعام اور اس کے فضل پر شاداں و فرحاں ہیں اور ان کو معلوم ہو چکا ہے کہ اللہ مومنوں کے اجر کو ضائع نہیں کرتا\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@cdlxv{جن لوگوں نے زخم کھانے کے بعد بھی اللہ اور رسول کی پکار پر لبیک کہا اُن میں جو اشخاص نیکوکار اور پرہیز گار ہیں اُن کے لیے بڑا اجر ہے\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@cdlxvi{اور وہ جن سے لوگوں نے کہا کہ، ``تماررے خلاف بڑی فوجیں جمع ہوئی ہیں، اُن سے ڈرو"، تو یہ سن کر ان کا ایمان اور بڑھ گیا اور اُنہوں نے جواب دیا کہ ہمارے لیے اللہ کافی ہے اور وہی بہترین کارسا ز ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@cdlxvii{آخر کار وہ اللہ تعالیٰ کی نعمت اور فضل کے ساتھ پلٹ آئے، ان کو کسی قسم کا ضرر بھی نہ پہنچا اور اللہ کی رضا پر چلنے کا شرف بھی انہیں حاصل ہو گیا، اللہ بڑا فضل فرمانے والا ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@cdlxviii{اب تمہیں معلوم ہو گیا کہ وہ دراصل شیطان تھا جو اپنے دوستوں سے خواہ مخواہ ڈرا رہا تھا لہٰذا آئندہ تم انسانوں سے نہ ڈرنا، مجھ سے ڈرنا اگر تم حقیقت میں صاحب ایمان ہو\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@cdlxix{(اے پیغمبرؐ) جو لوگ آج کفر کی راہ میں بڑی دوڑ دھوپ کر رہے ہیں ان کی سرگرمیاں تمہیں آزردہ نہ کریں، یہ اللہ کا کچھ بھی نہ بگاڑ سکیں گے اللہ کا ارادہ یہ ہے کہ اُن کے لیے آخرت میں کوئی حصہ نہ رکھے، اور بالآخر ان کو سخت سزا ملنے والی ہے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@cdlxx{جو لوگ ایمان کو چھوڑ کر کفر کے خریدار بنے ہیں وہ یقیناً اللہ کا کوئی نقصان نہیں کر رہے ہیں، اُن کے لیے درد ناک عذاب تیار ہے\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@cdlxxi{یہ ڈھیل جو ہم انہیں دیے جاتے ہیں اس کو یہ کافر اپنے حق میں بہتری نہ سمجھیں، ہم تو انہیں اس لیے ڈھیل دے رہے ہیں کہ یہ خوب بار گناہ سمیٹ لیں، پھر اُن کے لیے سخت ذلیل کرنے والی سزا ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@cdlxxii{اللہ مومنوں کو اس حالت میں ہرگز نہ رہنے دے گا جس میں تم اس وقت پائے جاتے ہو وہ پاک لوگوں کو ناپاک لوگوں سے الگ کر کے رہے گا مگر اللہ کا یہ طریقہ نہیں ہے کہ تم کو غیب پر مطلع کر دے غیب کی باتیں بتانے کے لیے تو وہ اپنے رسولوں میں جس کو چاہتا ہے منتخب کر لیتا ہے لہٰذا (امور غیب کے بارے میں) اللہ اور اس کے رسول پر ایمان رکھو اگر تم ایمان اور خدا ترسی کی روش پر چلو گے تو تم کو بڑا اجر ملے گا\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@cdlxxiii{جن لوگوں کو اللہ نے اپنے فضل سے نوازا ہے اور پھر وہ بخل سے کام لیتے ہیں وہ اس خیال میں نہ رہیں کہ یہ بخیلی ان کے لیے اچھی ہے نہیں، یہ ان کے حق میں نہایت بری ہے جو کچھ وہ اپنی کنجوسی سے جمع کر رہے ہیں وہی قیامت کے روز ان کے گلے کا طوق بن جائے گا زمین اور آسمانوں کی میراث اللہ ہی کے لیے ہے اور تم جو کچھ کرتے ہو اللہ اس سے باخبر ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@cdlxxiv{اللہ نے اُن لوگوں کا قول سنا جو کہتے ہیں کہ اللہ فقیر ہے اور ہم غنی ہیں ان کی یہ باتیں بھی ہم لکھ لیں گے، اور اس سے پہلے جو وہ پیغمبروں کو ناحق قتل کرتے رہے ہیں وہ بھی ان کے نامہ اعمال میں ثبت ہے (جب فیصلہ کا وقت آئے گا اُس وقت) ہم ان سے کہیں گے کہ لو، اب عذاب جہنم کا مزا چکھو\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@cdlxxv{یہ تمہارے اپنے ہاتھوں کی کمائی ہے، اللہ اپنے بندوں کے لیے ظالم نہیں ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cdlxxvi{جو لوگ کہتے ہیں ``اللہ نے ہم کو ہدایت کر دی ہے کہ ہم کسی کو رسول تسلیم نہ کریں جب تک وہ ہمارے سامنے ایسی قربانی نہ کرے جسے (غیب سے آکر) آگ کھا لے ``، اُن سے کہو، ``تمہارے پاس مجھ سے پہلے بہت سے رسول آ چکے ہیں جو بہت سی روشن نشانیاں لائے تھے اور وہ نشانی بھی لائے تھے جس کا تم ذکر کرتے ہو، پھر اگر (ایمان لانے کے لیے یہ شرط پیش کرنے میں) تم سچے ہو تو اُن رسولوں کو تم نے کیوں قتل کیا؟"\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cdlxxvii{اب اے محمدؐ! اگر یہ لوگ تمہیں جھٹلاتے ہیں تو بہت سے رسول تم سے پہلے جھٹلائے جا چکے ہیں جو کھلی کھلی نشانیاں اور صحیفے اور روشنی بخشنے والی کتابیں لائے تھے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cdlxxviii{آخر کار ہر شخص کو مرنا ہے اور تم سب اپنے اپنے پورے اجر قیامت کے روز پانے والے ہو کامیاب دراصل وہ ہے جو وہاں آتش دوزخ سے بچ جائے اور جنت میں داخل کر دیا جائے رہی یہ دنیا، تو یہ محض ایک ظاہر فریب چیز ہے\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cdlxxix{مسلمانو! تمہیں مال اور جان دونوں کی آزمائشیں پیش آ کر رہیں گی، اور تم اہل کتاب اور مشرکین سے بہت سی تکلیف دہ باتیں سنو گے اگر ان سب حالات میں تم صبر اور خدا ترسی کی روش پر قائم رہو تو یہ بڑے حوصلہ کا کام ہے\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cdlxxx{اِن اہل کتاب کو وہ عہد بھی یاد دلاؤ جو اللہ نے ان سے لیا تھا کہ تمہیں کتاب کی تعلیمات کو لوگوں میں پھیلانا ہوگا، انہیں پوشیدہ رکھنا نہیں ہوگا مگر انہوں نے کتاب کو پس پشت ڈال دیا اور تھوڑی قیمت پر اُسے بیچ ڈالا کتنا برا کاروبار ہے جو یہ کر رہے ہیں\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cdlxxxi{تم اُن لوگوں کو عذاب سے محفوظ نہ سمجھو جو اپنے کرتوتوں پر خوش ہیں اور چاہتے ہیں کہ ایسے کاموں کی تعریف اُنہیں حاصل ہو جو فی الواقع انہوں نے نہیں کیے ہیں حقیقت میں ان کے لیے درد ناک سزا تیار ہے\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cdlxxxii{زمین اور آسمان کا مالک اللہ ہے اور اس کی قدرت سب پر حاوی ہے\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiii{زمین اور آسمانوں کی پیدائش میں اور رات اور دن کے باری باری سے آنے میں اُن ہوش مند لوگوں کے لیے بہت نشانیاں ہیں\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiv{جو اٹھتے، بیٹھتے اور لیٹتے، ہر حال میں خدا کو یاد کرتے ہیں اور آسمان و زمین کی ساخت میں غور و فکر کرتے ہیں (وہ بے اختیار بو ل اٹھتے ہیں) ``پروردگار! یہ سب کچھ تو نے فضول اور بے مقصد نہیں بنایا ہے، تو پاک ہے اس سے کہ عبث کام کرے پس اے رب! ہمیں دوزخ کے عذاب سے بچا لے\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cdlxxxv{تو نے جسے دوزخ میں ڈالا اسے در حقیقت بڑی ذلت و رسوائی میں ڈال دیا، اور پھر ایسے ظالموں کا کوئی مدد گار نہ ہوگا\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvi{مالک! ہم نے ایک پکارنے والے کو سنا جو ایمان کی طرف بلاتا تھا اور کہتا تھا کہ اپنے رب کو مانو ہم نے اس کی دعوت قبول کر لی، پس اے ہمارے آقا! جو قصور ہم سے ہوئے ہیں ان سے درگزر فرما، جو برائیاں ہم میں ہیں انہیں دور کر دے اور ہمارا خاتمہ نیک لوگوں کے ساتھ کر\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvii{خداوندا! جو وعدے تو نے اپنے رسولوں کے ذریعہ سے کیے ہیں اُن کو ہمارے ساتھ پورا کر اور قیامت کے دن ہمیں رسوائی میں نہ ڈال، بے شک تو اپنے وعدے کے خلاف کرنے والا نہیں ہے"\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@cdlxxxviii{جواب میں ان کے رب نے فرمایا، ``میں تم میں سے کسی کا عمل ضائع کرنے والا نہیں ہوں خواہ مرد ہو یا عورت، تم سب ایک دوسرے کے ہم جنس ہو لہٰذا جن لوگوں نے میری خاطر اپنے وطن چھوڑے اور جو میر ی راہ میں اپنے گھروں سے نکالے گئے اور ستائے گئے اور میرے لیے لڑے اور مارے گئے اُن کے سب قصور میں معاف کر دوں گا اور انہیں ایسے باغوں میں داخل کروں گا جن کے نیچے نہریں بہتی ہوں گی یہ اُن کی جزا ہے اللہ کے ہاں اور بہترین جزا اللہ ہی کے پاس ہے"\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cdlxxxix{اے نبیؐ! دنیا کے ملکوں میں خدا کے نافرمان لوگوں کی چلت پھرت تمہیں کسی دھوکے میں نہ ڈالے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cdxc{یہ محض چند روزہ زندگی کا تھوڑا سا لطف ہے، پھر یہ سب جہنم میں جائیں گے جو بدترین جائے قرار ہے\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@cdxci{برعکس اس کے جو لوگ اپنے رب سے ڈرتے ہوئے زندگی بسر کرتے ہیں ان کے لیے ایسے باغ ہیں جن کے نیچے نہریں بہتی ہیں، ان باغوں میں وہ ہمیشہ رہیں گے، اللہ کی طرف سے یہ سامان ضیافت ہے ان کے لیے، اور جو کچھ اللہ کے پاس ہے نیک لوگوں کے لیے وہی سب سے بہتر ہے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@cdxcii{اہل کتاب میں بھی کچھ لوگ ایسے ہیں جو اللہ کو مانتے ہیں، اس کتاب پر ایمان لاتے ہیں جو تمہاری طرف بھیجی گئی ہے اوراُس کتاب پربھی ایمان رکھتے ہیں جو اس سے پہلے خود ان کی طرف بھیجی گئی تھی، اللہ کے آگے جھکے ہوئے ہیں، اور اللہ کی آیات کو تھوڑی سی قیمت پر بیچ نہیں دیتے ان کا اجر ان کے رب کے پاس ہے اور اللہ حساب چکانے میں دیر نہیں لگاتا\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@cdxciii{اے لوگو جو ایمان لائے ہو، صبر سے کام لو، باطل پرستوں کے مقابلہ میں پا مردی دکھاؤ، حق کی خدمت کے لیے کمر بستہ رہو، اور اللہ سے ڈرتے رہو، امید ہے کہ فلاح پاؤ گے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@cdxciv{\basmalahur لوگو! اپنے رب سے ڈرو جس نے تم کو ایک جان سے پیدا کیا اور اُسی جان سے اس کا جوڑا بنایا اور ان دونوں سے بہت مرد و عورت دنیا میں پھیلا دیے اُس خدا سے ڈرو جس کا واسطہ دے کر تم ایک دوسرے سے اپنے حق مانگتے ہو، اور رشتہ و قرابت کے تعلقات کو بگاڑنے سے پرہیز کرو یقین جانو کہ اللہ تم پر نگرانی کر رہا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cdxcv{یتیموں کے مال اُن کو واپس دو، اچھے مال کو برے مال سے نہ بدل لو، اور اُن کے مال اپنے مال کے ساتھ ملا کر نہ کھا جاؤ، یہ بہت بڑا گناہ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cdxcvi{اور اگر تم یتیموں کے ساتھ بے انصافی کرنے سے ڈرتے ہو تو جو عورتیں تم کو پسند آئیں اُن میں سے دو دو، تین تین، چار چار سے نکاح کرلو لیکن اگر تمہیں اندیشہ ہو کہ اُن کے ساتھ عدل نہ کر سکو گے تو پھر ایک ہی بیوی کرو یا اُن عورتوں کو زوجیت میں لاؤ جو تمہارے قبضہ میں آئی ہیں، بے انصافی سے بچنے کے لیے یہ زیادہ قرین صواب ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cdxcvii{اور عورتوں کے مہر خوش دلی کے ساتھ (فرض جانتے ہوئے) ادا کرو، البتہ اگر وہ خود اپنی خوشی سے مہر کا کوئی حصہ تمہیں معاف کر دیں تو اُسے تم مزے سے کھا سکتے ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cdxcviii{اور اپنے وہ مال جنہیں اللہ نے تمہارے لیے قیام زندگی کا ذریعہ بنایا ہے، نادان لوگوں کے حوالہ نہ کرو، البتہ انہیں کھانے اور پہننے کے لیے دو اور انہیں نیک ہدایت کرو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cdxcix{اور یتیموں کی آزمائش کرتے رہو یہاں تک کہ وہ نکاح کے قابل عمر کو پہنچ جائیں پھر اگر تم اُن کے اندر اہلیت پاؤ تو اُن کے مال اُن کے حوالے کر دو ایسا کبھی نہ کرنا کہ حد انصاف سے تجاوز کر کے اِس خوف سے اُن کے مال جلدی جلدی کھا جاؤ کہ وہ بڑے ہو کر اپنے حق کا مطالبہ کریں گے یتیم کا جو سرپرست مال دار ہو وہ پرہیز گاری سے کام لے اور جو غریب ہو وہ معروف طریقہ سے کھائے پھر جب اُن کے مال اُن کے حوالے کرنے لگو تو لوگوں کو اس پر گواہ بنا لو، اور حساب لینے کے لیے اللہ کافی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@d{مردوں کے لیے اُس مال میں حصہ ہے جو ماں باپ اور رشتہ داروں نے چھوڑا ہو، اور عورتوں کے لیے بھی اُس مال میں حصہ ہے جو ماں باپ اور رشتہ داروں نے چھوڑا ہو، خواہ تھوڑا ہو یا بہت، اور یہ حصہ (اللہ کی طرف سے) مقرر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@di{اور جب تقسیم کے موقع پر کنبہ کے لوگ اور یتیم اور مسکین آئیں تو اس مال میں سے ان کو بھی کچھ دو اور اُن کے ساتھ بھلے مانسوں کی سی بات کرو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dii{لوگوں کو اس بات کا خیال کر کے ڈرنا چاہیے کہ اگر وہ خود اپنے پیچھے بے بس اولاد چھوڑتے تو مرتے وقت انہیں اپنے بچوں کے حق میں کیسے کچھ اندیشے لاحق ہوتے پس چاہیے کہ وہ خدا کا خوف کریں اور راستی کی بات کریں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@diii{جو لوگ ظلم کے ساتھ یتیموں کے مال کھاتے ہیں در حقیقت وہ اپنے پیٹ آگ سے بھرتے ہیں اور وہ ضرور جہنم کی بھڑکتی ہوئی آگ میں جھونکے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@div{تمہاری اولاد کے بارے میں اللہ تمہیں ہدایت کرتا ہے کہ: مرد کا حصہ دو عورتوں کے برابر ہے، اگر (میت کی وارث) دو سے زائد لڑکیاں ہوں تو انہیں ترکے کا دو تہائی دیا جائے، اور اگر ایک ہی لڑکی وارث ہو تو آدھا ترکہ اس کا ہے اگر میت صاحب اولاد ہو تواس کے والدین میں سے ہر ایک کو ترکے کا چھٹا حصہ ملنا چاہیے اور اگر وہ صاحب اولاد نہ ہو اور والدین ہی اس کے وارث ہو ں تو ماں کو تیسرا حصہ دیا جائے اور اگر میت کے بھائی بہن بھی ہوں تو ماں چھٹے حصہ کی حق دار ہوگی (یہ سب حصے اُس وقت نکالے جائیں) جبکہ وصیت جو میت نے کی ہو پوری کر دی جائے اور قرض جو اُس پر ہو ادا کر دیا جائے تم نہیں جانتے کہ تمہارے ماں باپ اور تمہاری اولاد میں سے کون بلحاظ نفع تم سے قریب تر ہے یہ حصے اللہ نے مقرر کر دیے ہیں، اور اللہ یقیناً سب حقیقتوں سے واقف اور ساری مصلحتوں کا جاننے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dv{اور تمہاری بیویوں نے جو کچھ چھوڑا ہو اس کا آدھا حصہ تمہیں ملے گا اگر وہ بے اولاد ہوں، ورنہ اولاد ہونے کی صورت میں ترکہ کا ایک چوتھائی حصہ تمہارا ہے جبکہ وصیت جو انہوں ں نے کی ہو پوری کر دی جائے، اور قرض جو اُنہوں نے چھوڑا ہو ادا کر دیا جائے اور وہ تمہارے ترکہ میں سے چوتھائی کی حق دار ہوں گی اگر تم بے اولاد ہو، ورنہ صاحب اولاد ہونے کی صورت میں اُن کا حصہ آٹھواں ہوگا، بعد اس کے کہ جو وصیت تم نے کی ہو وہ پوری کر دی جائے اور جو قرض تم نے چھوڑا ہو وہ ادا کر دیا جائے اور اگر وہ مرد یا عورت (جس کی میراث تقسیم طلب ہے) بے اولاد بھی ہو اور اس کے ماں باپ بھی زندہ نہ ہوں، مگر اس کا ایک بھائی یا ایک بہن موجود ہو تو بھائی اور بہن ہر ایک کو چھٹا حصہ ملے گا، اور بھائی بہن ایک سے زیادہ ہوں تو کل ترکہ کے ایک تہائی میں وہ سب شریک ہوں گے، جبکہ وصیت جو کی گئی ہو پوری کر دی جائے، اور قرض جو میت نے چھوڑا ہو ادا کر دیا جائے، بشر طیکہ وہ ضرر رساں نہ ہو یہ حکم ہے اللہ کی طرف سے اور اللہ دانا و بینا اور نرم خو ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dvi{یہ اللہ کی مقرر کی ہوئی حدیں ہیں جو اللہ اور اُس کے رسول کی اطاعت کرے گا اُسے اللہ ایسے باغوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی اور ان باغوں میں وہ ہمیشہ رہے گا اور یہی بڑی کامیابی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dvii{اور جو اللہ اور اُس کے رسول کی نافرمانی کرے گا اور اس کی مقرر کی ہوئی حدوں سے تجاوز کر جائے گا اُسے اللہ آگ میں ڈالے گا جس میں وہ ہمیشہ رہے گا اور اس کے لیے رسوا کن سزا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dviii{تمہاری عورتوں میں سے جو بد کاری کی مرتکب ہوں اُن پر اپنے میں سے چار آدمیوں کی گواہی لو، اور اگر چار آدمی گواہی دے دیں تو ان کو گھروں میں بند رکھو یہاں تک کہ انہیں موت آ جائے یا اللہ اُن کے لیے کوئی راستہ نکال دے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dix{اور تم میں سے جو اس فعل کا ارتکاب کریں اُن دونوں کو تکلیف دو، پھر اگر وہ توبہ کریں اور اپنی اصلاح کر لیں تو انہیں چھوڑ دو کہ اللہ بہت توبہ قبول کرنے والا اور رحم فرمانے والا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dx{ہاں یہ جان لو کہ اللہ پر توبہ کی قبولیت کا حق اُنہی لوگوں کے لیے ہے جو نادانی کی وجہ سے کوئی برا فعل کر گزرتے ہیں اور اس کے بعد جلدی ہی توبہ کر لیتے ہیں ایسے لوگوں پر اللہ اپنی نظر عنایت سے پھر متوجہ ہو جاتا ہے اور اللہ ساری باتوں کی خبر رکھنے والا اور حکیم و دانا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dxi{مگر توبہ اُن لوگوں کے لیے نہیں ہے جو برے کام کیے چلے جاتے ہیں یہاں تک کہ جب ان میں سے کسی کی موت وقت آ جاتا ہے اُس وقت وہ کہتا ہے کہ اب میں نے توبہ کی، اور اسی طرح توبہ اُن کے لیے بھی نہیں ہے جو مرتے دم تک کافر رہیں ا یسے لوگوں کے لیے تو ہم نے درد ناک سزا تیار کر رکھی ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dxii{اے لوگو جو ایمان لائے ہو، تمہارے لیے یہ حلال نہیں ہے کہ زبردستی عورتوں کے وارث بن بیٹھو اور نہ یہ حلال ہے کہ انہیں تنگ کر کے اُس مہر کا کچھ حصہ اڑا لینے کی کوشش کرو جو تم انہیں دے چکے ہو ہاں اگر وہ کسی صریح بد چلنی کی مرتکب ہو ں (تو ضرور تمہیں تنگ کرنے کا حق ہے) ان کے ساتھ بھلے طریقہ سے زندگی بسر کرو اگر وہ تمہیں ناپسند ہوں تو ہو سکتا ہے کہ ایک چیز تمہیں پسند نہ ہو مگر اللہ نے اُسی میں بہت کچھ بھلائی رکھ دی ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dxiii{اور اگر تم ایک بیوی کی جگہ دوسری بیوی لے آنے کا ارادہ ہی کر لو تو خواہ تم نے اُسے ڈھیر سا مال ہی کیوں نہ دیا ہو، اس میں سے کچھ واپس نہ لینا کیا تم اُسے بہتان لگا کر اور صریح ظلم کر کے واپس لو گے؟\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dxiv{اور آخر تم اُسے کس طرح لے لو گے جب کہ تم ایک دوسرے سے لطف اندو ز ہو چکے ہو اور وہ تم سے پختہ عہد لے چکی ہیں؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dxv{اور جن عورتوں سے تمہارے باپ نکاح کر چکے ہوں اُن سے ہرگز نکاح نہ کرو، مگر جو پہلے ہو چکا سو ہو چکا در حقیقت یہ ایک بے حیائی کا فعل ہے، ناپسندیدہ ہے اور برا چلن ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dxvi{تم پر حرام کی گئیں تمہاری مائیں، بیٹیاں، بہنیں، پھوپھیاں، خالائیں، بھتیجیاں، بھانجیاں، اور تمہاری وہ مائیں جنہوں نے تم کو دودھ پلایا ہو، اور تمہاری دودھ شریک بہنیں، اور تمہاری بیویوں کی مائیں، اور تمہاری بیویوں کی لڑکیاں جنہوں نے تمہاری گودوں میں پرورش پائی ہے اُن بیویوں کی لڑکیاں جن سے تمہارا تعلق زن و شو ہو چکا ہو ورنہ اگر (صرف نکاح ہوا ہو اور) تعلق زن و شو نہ ہوا ہو تو (ا نہیں چھوڑ کر ان کی لڑکیوں سے نکاح کر لینے میں) تم پر کوئی مواخذہ نہیں ہے اور تمہارے اُن بیٹوں کی بیویاں جو تمہاری صلب سے ہوں اور یہ بھی تم پر حرام کیا گیا ہے کہ ایک نکاح میں دو بہنوں کو جمع کرو، مگر جو پہلے ہو گیا سو ہو گیا، اللہ بخشنے والا اور رحم کرنے والا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dxvii{اور وہ عورتیں بھی تم پر حرام ہیں جو کسی دوسرے کے نکاح میں ہوں (محصنات) البتہ ایسی عورتیں اس سے مستثنیٰ ہیں جو (جنگ میں) تمہارے ہاتھ آئیں یہ اللہ کا قانون ہے جس کی پابندی تم پر لازم کر دی گئی ہے اِن کے ماسوا جتنی عورتیں ہیں انہیں اپنے اموال کے ذریعہ سے حاصل کرنا تمہارے لیے حلال کر دیا گیا ہے، بشر طیکہ حصار نکاح میں اُن کو محفوظ کرو، نہ یہ کہ آزاد شہوت رانی کرنے لگو پھر جو ازدواجی زندگی کا لطف تم ان سے اٹھاؤ اس کے بدلے اُن کے مہر بطور فرض ادا کرو، البتہ مہر کی قرارداد ہو جانے کے بعد آپس کی رضامندی سے تمہارے درمیان اگر کوئی سمجھوتہ ہو جائے تو اس میں کوئی حرج نہیں، اللہ علیم اور دانا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dxviii{اور جو شخص تم میں سے اتنی مقدرت نہ رکھتا ہو کہ خاندانی مسلمان عورتوں (محصنات) سے نکاح کر سکے اسے چاہیے کہ تمہاری اُن لونڈیوں میں سے کسی کے ساتھ نکاح کر لے جو تمہارے قبضہ میں ہوں اور مومنہ ہوں اللہ تمہارے ایمانوں کا حال خوب جانتا ہے، تم سب ایک ہی گروہ کے لوگ ہو، لہٰذا اُن کے سرپرستوں کی اجازت سے اُن کے ساتھ نکاح کر لو اور معروف طریقہ سے اُن کے مہر ادا کر دو، تاکہ وہ حصار نکاح میں محفوظ (محصنات) ہو کر رہیں، آزاد شہوت رانی کرتی پھریں اور نہ چوری چھپے آشنائیاں کریں پھر جب وہ حصار نکاح میں محفوظ ہو جائیں اور اس کے بعد کسی بد چلنی کی مرتکب ہوں تو ان پر اُس سز ا کی بہ نسبت آدھی سزا ہے جو خاندانی عورتوں (محصنات) کے لیے مقرر ہے یہ سہولت تم میں سے اُن لوگوں کے لیے پیدا کی گئی ہے جن کو شادی نہ کرنے سے بند تقویٰ کے ٹوٹ جانے کا اندیشہ ہو لیکن اگر تم صبر کرو تو یہ تمہارے لیے بہتر ہے، اور اللہ بخشنے والا اور رحم فرمانے والا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dxix{اللہ چاہتا ہے کہ تم پر اُن طریقوں کو واضح کرے اور اُنہی طریقوں پر تمہیں چلائے جن کی پیروی تم سے پہلے گزرے ہوئے صلحا٫ کرتے تھے وہ اپنی رحمت کے ساتھ تمہاری طرف متوجہ ہونے کا ارادہ رکھتا ہے، اور وہ علیم بھی ہے اور دانا بھی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dxx{ہاں، اللہ تو تم پر رحمت کے ساتھ توجہ کرنا چاہتا ہے مگر جو لوگ خود اپنی خواہشات نفس کی پیروی کر رہے ہیں وہ چاہتے ہیں کہ تم راہ راست سے ہٹ کر دور نکل جاؤ\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dxxi{اللہ تم پر سے پابندیوں کو ہلکا کرنا چاہتا ہے کیونکہ انسان کمزور پیدا کیا گیا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dxxii{اے لوگو جو ایمان لائے ہو، آپس میں ایک دوسرے کے مال باطل طریقوں سے نہ کھاؤ، لین دین ہونا چاہیے آپس کی رضامندی سے اور اپنے آپ کو قتل نہ کرو یقین مانو کہ اللہ تمہارے اوپر مہربان ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dxxiii{جو شخص ظلم و زیادتی کے ساتھ ایسا کرے گا اُس کو ہم ضرور آگ میں جھونکیں گے اور یہ اللہ کے لیے کوئی مشکل کام نہیں ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dxxiv{اگر تم اُن بڑے بڑے گناہوں سے پرہیز کرتے رہو جن سے تمہیں منع کیا جا رہا ہے تو تمہاری چھوٹی موٹی برائیوں کو ہم تمہارے حساب سے ساقط کر دیں گے اور تم کو عزت کی جگہ داخل کریں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dxxv{اور جو کچھ اللہ نے تم میں سے کسی کو دوسروں کے مقابلہ میں زیادہ دیا ہے اس کی تمنا نہ کرو جو کچھ مَردوں نے کمایا ہے اُس کے مطابق ان کا حصہ ہے اور جو کچھ عورتوں نے کمایا ہے اس کے مطابق اُن کا حصہ ہاں اللہ سے اس کے فضل کی دعا مانگتے رہو، یقیناً اللہ ہر چیز کا علم رکھتا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dxxvi{اور ہم نے ہر اُس ترکے کے حق دار مقرر کر دیے ہیں جو والدین اور رشتہ دار چھوڑیں اب رہے وہ لوگ جن سے تمہارے عہد و پیمان ہوں تو ان کا حصہ انہیں دو، یقیناً اللہ ہر چیز پر نگراں ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dxxvii{مرد عورتوں پر قوام ہیں، اس بنا پر کہ اللہ نے اُن میں سے ایک کو دوسرے پر فضیلت دی ہے، اور اس بنا پر کہ مرد اپنے مال خرچ کرتے ہیں پس جو صالح عورتیں ہیں وہ اطاعت شعار ہوتی ہیں اور مردوں کے پیچھے اللہ کی حفاظت و نگرانی میں اُن کے حقوق کی حفاظت کرتی ہیں اور جن عورتوں سے تمہیں سرکشی کا اندیشہ ہو انہیں سمجھاؤ، خواب گاہوں میں اُن سے علیحدہ رہو اور مارو، پھر اگر تم وہ تمہاری مطیع ہو جائیں تو خواہ مخواہ ان پر دست درازی کے لیے بہانے تلاش نہ کرو، یقین رکھو کہ اوپر اللہ موجود ہے جو بڑا اور بالا تر ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dxxviii{اور اگر تم لوگوں کو کہیں میاں اور بیوی کے تعلقات بگڑ جانے کا اندیشہ ہو تو ایک حَکم مرد کے رشتہ داروں میں سے اور ایک عورت کے رشتہ داروں میں سے مقرر کرو، وہ دونوں اصلاح کرنا چاہیں گے تو اللہ اُن کے درمیان موافقت کی صورت نکال دے گا، اللہ سب کچھ جانتا ہے اور باخبر ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dxxix{اور تم سب اللہ کی بندگی کرو، اُس کے ساتھ کسی کو شریک نہ بناؤ، ماں باپ کے ساتھ نیک برتاؤ کرو، قرابت داروں اور یتیموں اور مسکینوں کے ساتھ حسن سلوک سے پیش آؤ، اور پڑوسی رشتہ دار سے، اجنبی ہمسایہ سے، پہلو کے ساتھی اور مسافر سے، اور اُن لونڈی غلاموں سے جو تمہارے قبضہ میں ہوں، احسان کا معاملہ رکھو، یقین جانو اللہ کسی ایسے شخص کو پسند نہیں کرتا جو اپنے پندار میں مغرور ہو اور اپنی بڑائی پر فخر کر ے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dxxx{اور ایسے لوگ بھی اللہ کو پسند نہیں ہیں جو کنجوسی کرتے ہیں اور دوسروں کو بھی کنجوسی کی ہدایت کرتے ہیں اور جو کچھ اللہ نے اپنے فضل سے انہیں دیا ہے اسے چھپاتے ہیں ایسے کافر نعمت لوگوں کے لیے ہم نے رسوا کن عذاب مہیا کر رکھا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dxxxi{اور وہ لوگ بھی اللہ کو ناپسند ہیں جو اپنے مال محض لوگوں کو دکھانے کیلیے خرچ کرتے ہیں اور در حقیقت نہ اللہ پر ایمان رکھتے ہیں نہ روز آخر پر سچ یہ ہے کہ شیطان جس کا رفیق ہوا اُسے بہت ہی بری رفاقت میسر آئی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dxxxii{آخر اِن لوگوں پر کیا آفت آ جاتی اگر یہ اللہ اور روز آخر پر ایمان رکھتے اور جو کچھ اللہ نے دیا ہے اس میں سے خرچ کرتے اگر یہ ایسا کرتے تو اللہ سے ان کی نیکی کا حال چھپا نہ رہ جاتا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dxxxiii{اللہ کسی پر ذرہ برابر بھی ظلم نہیں کرتا اگر کوئی ایک نیکی کرے تو اللہ اُسے دو چند کرتا ہے اور پھر اپنی طرف سے بڑا اجر عطا فرماتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dxxxiv{پھر سوچو کہ اُس وقت یہ کیا کریں گے جب ہم ہر امت میں سے ایک گواہ لائیں گے اور اِن لوگوں پر تمہیں (یعنی محمد ﷺ کو) گواہ کی حیثیت سے کھڑا کریں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dxxxv{اُس وقت وہ سب لوگ جنہوں نے رسولؐ کی بات نہ مانی اور اس کی نافرمانی کرتے رہے، تمنا کریں گے کہ کاش زمین پھٹ جائے اور وہ اس میں سما جائیں وہاں یہ اپنی کوئی بات اللہ سے نہ چھپا سکیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dxxxvi{اے لوگو جو ایمان لائے ہو، جب تم نشے کی حالت میں ہو تو نماز کے قریب نہ جاؤ نماز اُس وقت پڑھنی چاہیے، جب تم جانو کہ کیا کہہ رہے ہو اور اسی طرح جنابت کی حالت میں بھی نماز کے قریب نہ جاؤ جب تک کہ غسل نہ کر لو، الا یہ کہ راستہ سے گزرتے ہو اور اگر کبھی ایسا ہو کہ تم بیمار ہو، یا سفر میں ہو، یا تم میں سے کوئی شخص رفع حاجت کر کے آئے، یا تم نے عورتوں سے لمس کیا ہو، اور پھر پانی نہ ملے تو پاک مٹی سے کام لو اور اس سے اپنے چہروں اور ہاتھوں پر مسح کر لو، بے شک اللہ نرمی سے کام لینے والا اور بخشش فرمانے والا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dxxxvii{تم نے اُن لوگوں کو بھی دیکھا جنہیں کتاب کے علم کا کچھ حصہ دیا گیا ہے؟ وہ خود ضلالت کے خریدار بنے ہوئے ہیں اور چاہتے ہیں کہ تم بھی راہ گم کر دو\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dxxxviii{اللہ تمہارے دشمنوں کو خوب جانتا ہے اور تمہاری حمایت و مدد گاری کے لیے اللہ ہی کافی ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dxxxix{جو لوگ یہودی بن گئے ہیں اُن میں کچھ لوگ ہیں جو الفاظ کو اُن کے محل سے پھیر دیتے ہیں اور دین حق کے خلاف نیش زنی کرنے کے لیے اپنی زبانوں کو توڑ موڑ کر کہتے ہیں سَمِعنَا وَ عَصَینَا اور اِسمَع غَیر مُسمَع اور رَاعِنَا حالانکہ اگر وہ کہتے سَمِعنَا وَ اَطَعنَا، اور اِسمَع اور اُنظُرنَا تو یہ انہی کے لیے بہتر تھا اور زیادہ راستبازی کا طریقہ تھا مگر ان پر تو ان کی باطل پرستی کی بدولت اللہ کی پھٹکار پڑی ہوئی ہے اس لیے وہ کم ہی ایمان لاتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dxl{اے وہ لوگو جنہیں کتاب دی گئی تھی! مان لو اُس کتاب کو جو ہم نے اب نازل کی ہے اور جو اُس کتاب کی تصدیق و تائید کرتی ہے جو تمہارے پاس پہلے سے موجود تھی اس پر ایمان لے آؤ قبل اس کے کہ ہم چہر ے بگاڑ کر پیچھے پھیر دیں یا ان کو اسی طرح لعنت زدہ کر دیں جس طرح سبت والوں کے ساتھ ہم نے کیا تھا، اور یاد رکھو کہ اللہ کا حکم نافذ ہو کر رہتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dxli{اللہ بس شرک ہی کو معاف نہیں کرتا، اِس کے ماسوا دوسرے جس قدر گناہ ہیں وہ جس کے لیے چاہتا ہے معاف کر دیتا ہے اللہ کے ساتھ جس نے کسی اور کو شریک ٹھیرایا اُس نے تو بہت ہی بڑا جھوٹ تصنیف کیا اور بڑے سخت گناہ کی بات کی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dxlii{تم نے اُن لوگوں کو بھی دیکھا جو بہت اپنی پاکیز گی نفس کا دم بھرتے ہیں؟ حالانکہ پاکیزگی تو اللہ ہی جسے چاہتا ہے عطا کرتا ہے، اور (انہیں جو پاکیزگی نہیں ملتی تو در حقیقت) ان پر ذرہ برابر بھی ظلم نہیں کیا جاتا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dxliii{دیکھو تو سہی، یہ اللہ پر بھی جھوٹے افترا گھڑنے سے نہیں چوکتے اور ان کے صریحاً گناہ گا ر ہونے کے لیے یہی ایک گناہ کافی ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dxliv{کیا تم نے اُن لوگوں کو نہیں دیکھا جنہیں کتاب کے علم میں سے کچھ حصہ دیا گیا ہے اور اُن کا حال یہ ہے کہ جِبت اور طاغوت کو مانتے ہیں اور کافروں کے متعلق کہتے ہیں کہ ایمان لانے والوں سے تو یہی زیادہ صحیح راستے پر ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dxlv{ایسے ہی لوگ ہیں جن پر اللہ نے لعنت کی ہے اور جس پر اللہ لعنت کر دے پھر تم اُس کا کوئی مدد گار نہیں پاؤ گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dxlvi{کیا حکومت میں اُن کا کوئی حصہ ہے؟ اگر ایسا ہوتا تو یہ دوسروں کو ایک پھوٹی کوڑی تک نہ دیتے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dxlvii{پھر کیا یہ دوسروں سے اس لیے حسد کرتے ہیں کہ اللہ نے انہیں اپنے فضل سے نواز دیا؟ اگر یہ بات ہے تو انہیں معلوم ہو کہ ہم نے تو ابراہیمؑ کی اولاد کو کتاب اور حکمت عطا کی اور ملک عظیم بخش دیا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dxlviii{مگر ان میں سے کوئی اس پر ایمان لایا اور کوئی اس سے منہ موڑ گیا، اور منہ موڑ نے والوں کے لیے تو بس جہنم کی بھڑکتی ہوئی آگ ہی کافی ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dxlix{جن لوگوں نے ہماری آیات کو ماننے سے انکار کر دیا ہے انہیں بالیقین ہم آگ میں جھونکیں گے اور جب ان کے بدن کی کھال گل جائے گی تو اس کی جگہ دوسری کھال پیدا کر دیں گے تاکہ وہ خوب عذاب کا مزہ چکھیں، اللہ بڑی قدرت رکھتا ہے اور اپنے فیصلوں کو عمل میں لانے کی حکمت خوب جانتا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dl{اور جن لوگوں نے ہماری آیات کو مان لیا اور نیک عمل کیے اُن کو ہم ایسے باغوں میں داخل کریں گے جن کے نیچے نہریں بہتی ہوں گی، جہاں وہ ہمیشہ ہمیشہ رہیں گے اور اُن کو پاکیزہ بیویاں ملیں گی اور انہیں ہم گھنی چھاؤں میں رکھیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dli{مسلمانو! اللہ تمہیں حکم دیتا ہے کہ امانتیں اہل امانت کے سپرد کرو، اور جب لوگوں کے درمیان فیصلہ کرو تو عدل کے ساتھ کرو، اللہ تم کو نہایت عمدہ نصیحت کرتا ہے اور یقیناً اللہ سب کچھ سنتا اور دیکھتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dlii{اے لوگو جو ایمان لائے ہوئے، اطاعت کرو اللہ کی اور اطاعت کرو رسول کی اور اُن لوگوں کی جو تم میں سے صاحب امر ہوں، پھر اگر تمہارے درمیان کسی معاملہ میں نزاع ہو جائے تو اسے اللہ اور رسول کی طرف پھیر دو اگر تم واقعی اللہ اور روز آخر پر ایمان رکھتے ہو یہی ایک صحیح طریق کار ہے اور انجام کے اعتبار سے بھی بہتر ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dliii{اے نبیؐ! تم نے دیکھا نہیں اُن لوگوں کو جو دعویٰ تو کرتے ہیں کہ ہم ایمان لائے ہیں اُس کتاب پر جو تمہاری طرف نازل کی گئی ہے اور ان کتابوں پر جو تم سے پہلے نازل کی گئی تھیں، مگر چاہتے یہ ہیں کہ اپنے معاملات کا فیصلہ کرانے کے لیے طاغوت کی طرف رجوع کریں، حالانکہ انہیں طاغوت سے کفر کرنے کا حکم دیا گیا تھا شیطان انہیں بھٹکا کر راہ راست سے بہت دور لے جانا چاہتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dliv{اور جب ان سے کہا جاتا ہے کہ آؤ اُس چیز کی طرف جو اللہ نے نازل کی ہے اور آؤ رسول کی طرف تو ان منافقوں کو تم دیکھتے ہو کہ یہ تمہاری طرف آنے سے کتراتے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dlv{پھر اس وقت کیا ہوتا ہے جب اِن کے اپنے ہاتھوں کی لائی ہوئی مصیبت ان پر آ پڑتی ہے؟ اُس وقت یہ تمہارے پاس قسمیں کھاتے ہوئے آتے ہیں اور کہتے ہیں کہ خدا کی قسم ہم تو صرف بھلائی چاہتے تھے اور ہماری نیت تو یہ تھی کہ فریقین میں کسی طرح موافقت ہو جائے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dlvi{اللہ جانتا ہے جو کچھ ان کے دلوں میں ہے، ان سے تعرض مت کرو، انہیں سمجھاؤ اور ایسی نصیحت کرو جو ان کے دلوں میں اتر جائے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dlvii{(انہیں بتاؤ کہ) ہم نے جو رسول بھی بھیجا ہے اس لیے بھیجا ہے کہ اذن خداوندی کی بنا پر اس کی اطاعت کی جائے اگر انہوں نے یہ طریقہ اختیار کیا ہوتا کہ جب یہ اپنے نفس پر ظلم کر بیٹھے تھے تو تمہارے پاس آ جاتے اور اللہ سے معافی مانگتے، اور رسول بھی ان کے لیے معافی کی درخواست کرتا، تو یقیناً اللہ کو بخشنے والا اور رحم کرنے والا پاتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dlviii{نہیں، اے محمدؐ، تمہارے رب کی قسم یہ کبھی مومن نہیں ہوسکتے جب تک کہ اپنے باہمی اختلافات میں یہ تم کو فیصلہ کرنے والا نہ مان لیں، پھر جو کچھ تم فیصلہ کرو اس پر اپنے دلوں میں بھی کوئی تنگی نہ محسوس کریں، بلکہ سر بسر تسلیم کر لیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dlix{اگر ہم نے انہیں حکم دیا ہوتا کہ اپنے آپ کو ہلاک کر دو یا اپنے گھروں سے نکل جاؤ تو ان میں سے کم ہی آدمی اس پر عمل کرتے حالانکہ جو نصیحت انہیں کی جاتی ہے، اگر یہ اس پر عمل کرتے تو یہ ان کے لیے زیادہ بہتری اور زیادہ ثابت قدمی کا موجب ہوتا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dlx{اور جب یہ ایسا کرتے تو ہم انہیں اپنی طرف سے بہت بڑا اجر دیتے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dlxi{اور انہیں سیدھا راستہ دکھا دیتے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dlxii{جو اللہ اور رسول کی اطاعت کرے گا وہ ان لوگوں کے ساتھ ہوگا جن پر اللہ نے انعام فرمایا ہے یعنی انبیا٫ اور صدیقین اور شہدا٫ اور صالحین کیسے اچھے ہیں یہ رفیق جو کسی کو میسر آئیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dlxiii{یہ حقیقی فضل ہے جو اللہ کی طرف سے ملتا ہے اور حقیقت جاننے کے لیے بس اللہ ہی کا علم کافی ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dlxiv{اے لوگو جو ایمان لائے ہو، مقابلہ کے لیے ہر وقت تیار رہو، پھر جیسا موقع ہو الگ الگ دستوں کی شکل میں نکلو یا اکٹھے ہو کر\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dlxv{ہاں، تم میں کوئی آدمی ایسا بھی ہے جو لڑائی سے جی چراتا ہے، ا گر تم پر کوئی مصیبت آئے تو کہتا ہے کہ اللہ نے مجھ پر بڑا فضل کیا کہ میں اِن لوگوں کے ساتھ نہ گیا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dlxvi{اور اگر اللہ کی طرف سے تم پر فضل ہو تو کہتا ہے اور اس طرح کہتا ہے کہ گویا تمہارے اور اس کے درمیان محبت کا تو کوئی تعلق تھا ہی نہیں کہ کاش میں بھی ان کے ساتھ ہوتا تو بڑا کام بن جاتا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dlxvii{(ایسے لوگوں کو معلوم ہو کہ) اللہ کی راہ میں لڑنا چاہیے اُن لوگوں کو جو آخرت کے بدلے دنیا کی زندگی کو فروخت کر دیں، پھر جو اللہ کی راہ میں لڑے گا اور مارا جائے گا یا غالب رہے گا اُسے ضرور ہم اجر عظیم عطا کریں گے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dlxviii{آخر کیا وجہ ہے کہ تم اللہ کی راہ میں اُن بے بس مردوں، عورتوں اور بچوں کی خاطر نہ لڑو جو کمزور پاکر دبا لیے گئے ہیں اور فریاد کر رہے ہیں کہ خدایا ہم کو اس بستی سے نکال جس کے باشندے ظالم ہیں اور اپنی طرف سے ہمارا کوئی حامی و مدد گار پیدا کر دے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dlxix{جن لوگوں نے ایمان کا راستہ اختیار کیا ہے، وہ اللہ کی راہ میں لڑتے ہیں اور جنہوں نے کفر کا راستہ اختیار کیا ہے، و ہ طاغوت کی راہ میں لڑتے ہیں، پس شیطان کے ساتھیوں سے لڑو اور یقین جانو کہ شیطان کی چالیں حقیقت میں نہایت کمزور ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dlxx{تم نے اُن لوگوں کو بھی دیکھا جن سے کہا گیا تھا کہ اپنے ہاتھ روکے رکھو اور نماز قائم کرو اور زکوٰۃ دو؟ اب جو انہیں لڑائی کا حکم دیا گیا تو ان میں سے ایک فریق کا حال یہ ہے کہ لوگوں سے ایسا ڈر رہے ہیں جیسا خدا سے ڈرنا چاہیے یا کچھ اس سے بھی بڑھ کر کہتے ہیں خدایا! یہ ہم پر لڑائی کا حکم کیوں لکھ دیا؟ کیوں نہ ہمیں ابھی کچھ اور مہلت دی؟ ان سے کہو، دنیا کا سرمایہ زندگی تھوڑا ہے، اور آخرت ایک خدا ترس انسان کے لیے زیادہ بہتر ہے، اور تم پر ظلم ایک شمہ برابر بھی نہ کیا جائے گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dlxxi{رہی موت، تو جہاں بھی تم ہو وہ بہرحال تمہیں آکر رہے گی خواہ تم کیسی ہی مضبوط عمارتوں میں ہو اگر انہیں کوئی فائدہ پہنچتا ہے تو کہتے ہیں یہ اللہ کی طرف سے ہے، اور اگر کوئی نقصان پہنچتا ہے تو کہتے ہیں یہ تمہاری بدولت ہے کہو، سب کچھ اللہ ہی کی طرف سے ہے آخر ان لوگوں کو کیا ہو گیا ہے کہ کوئی بات ان کی سمجھ میں نہیں آتی\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dlxxii{اے انسان! تجھے جو بھلائی بھی حاصل ہوتی ہے اللہ کی عنایت سے ہوتی ہے، اور جو مصیبت تجھ پر آتی ہے وہ تیرے اپنے کسب و عمل کی بدولت ہے اے محمدؐ! ہم نے تم کو لوگوں کے لیے رسول بنا کر بھیجا ہے اوراس پر خدا کی گواہی کافی ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dlxxiii{جس نے رسول کی اطاعت کی اس نے دراصل خدا کی اطاعت کی اور جو منہ موڑ گیا، تو بہرحال ہم نے تمہیں ان لوگوں پر پاسبان بنا کر تو نہیں بھیجا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dlxxiv{وہ منہ پر کہتے ہیں کہ ہم مطیع فرمان ہیں مگر جب تمہارے پاس سے نکلتے ہیں تو ان میں سے ایک گروہ راتوں کو جمع ہو کر تمہاری باتوں کے خلاف مشورے کرتا ہے اللہ ان کی یہ ساری سرگوشیاں لکھ رہا ہے تم ان کی پروا نہ کرو اور اللہ پر بھروسہ رکھو، وہی بھروسہ کے لیے کافی ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dlxxv{کیا یہ لوگ قرآن پر غور نہیں کرتے؟ اگر یہ اللہ کے سوا کسی اور کی طرف سے ہوتا تو اِس میں بہت کچھ اختلاف بیانی پائی جاتی\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dlxxvi{یہ لوگ جہاں کوئی اطمینان بخش یا خوفناک خبر سن پاتے ہیں اُسے لے کر پھیلا دیتے ہیں، حالانکہ اگر یہ اُسے رسول اور اپنی جماعت کے ذمہ دار اصحاب تک پہنچائیں تو وہ ایسے لوگوں کے علم میں آ جائے جو اِن کے درمیان اس بات کی صلاحیت رکھتے ہیں کہ اس سے صحیح نتیجہ اخذ کرسکیں تم لوگوں پر اللہ کی مہربانی اور رحمت نہ ہوتی تو (تمہاری کمزوریاں ایسی تھیں کہ) معدودے چند کے سوا تم سب شیطان کے پیچھے لگ گئے ہوتے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dlxxvii{پس اے نبیؐ! تم اللہ کی راہ میں لڑو، تم اپنی ذات کے سوا کسی اور کے لیے ذمہ دار نہیں ہو البتہ اہل ایما ن کو لڑنے کے لیے اکساؤ، بعید نہیں کہ اللہ کافروں کا زور توڑ دے، اللہ کا زور سب سے زیادہ زبردست اور اس کی سزا سب سے زیادہ سخت ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dlxxviii{جو بھلائی کی سفارش کریگا وہ اس میں سے حصہ پائے گا اور جو برائی کی سفارش کرے گا وہ اس میں سے حصہ پائے گا، اور اللہ ہر چیز پر نظر رکھنے والا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dlxxix{اور جب کوئی احترام کے ساتھ تمہیں سلام کرے تو اس کو اس سے بہتر طریقہ کے ساتھ جواب دو یا کم از کم اُسی طرح، اللہ ہر چیز کا حساب لینے والا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dlxxx{اللہ وہ ہے جس کے سوا کوئی خدا نہیں ہے، وہ تم سب کو اُس قیامت کے دن جمع کرے گا جس کے آنے میں کوئی شبہہ نہیں، اور اللہ کی بات سے بڑھ کر سچی بات اور کس کی ہوسکتی ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dlxxxi{پھر یہ تمہیں کیا ہو گیا ہے کہ منافقین کے بارے میں تمہارے درمیان دو رائیں پائی جاتی ہیں، حالانکہ جو برائیاں اُنہوں نے کمائی ہیں اُن کی بدولت اللہ انہیں الٹا پھیر چکا ہے کیا تم چاہتے ہو کہ جسے اللہ نے ہدایت نہیں بخشی اُسے تم ہدایت بخش دو؟ حالانکہ جس کو اللہ نے راستہ سے ہٹا دیا اُس کے لیے تم کوئی راستہ نہیں پاسکتے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dlxxxii{وہ تو یہ چاہتے ہیں کہ جس طرح وہ خود کافر ہیں اسی طرح تم بھی کافر ہو جاؤ تاکہ تم اور وہ سب یکساں ہو جائیں لہٰذا ان میں سے کسی کو اپنا دوست نہ بناؤ جب تک کہ وہ اللہ کی راہ میں ہجرت کر کے نہ آ جائیں، اور اگر وہ ہجرت سے باز رہیں تو جہاں پاؤ انہیں پکڑو اور قتل کرو اور ان میں سے کسی کو اپنا دوست اور مددگار نہ بناؤ\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dlxxxiii{البتہ و ہ منافق اس حکم سے مستثنیٰ ہیں جو کسی ایسی قوم سے جا ملیں جس کے ساتھ تمہارا معاہدہ ہے اسی طرح وہ منافق بھی مستثنیٰ ہیں جو تمہارے پاس آتے ہیں اور لڑائی سے دل برداشتہ ہیں، نہ تم سے لڑنا چاہتے ہیں نہ اپنی قوم سے اللہ چاہتا تو ان کو تم پر مسلط کر دیتا اور وہ بھی تم سے لڑتے لہٰذا اگر وہ تم سے کنارہ کش ہو جائیں اور لڑنے سے باز رہیں اور تمہاری طرف صلح و آشتی کا ہاتھ بڑھائیں تو اللہ نے تمہارے لیے ان پر دست درازی کی کوئی سبیل نہیں رکھی ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dlxxxiv{ایک اور قسم کے منافق تمہیں ایسے ملیں گے جو چاہتے ہیں کہ تم سے بھی امن میں رہیں اور اپنی قوم سے بھی، مگر جب کبھی فتنہ کا موقع پائیں گے اس میں کود پڑیں گے ایسے لوگ اگر تمہارے مقابلہ سے باز نہ رہیں اور صلح و سلامتی تمہارے آگے پیش نہ کریں اور اپنے ہاتھ نہ روکیں تو جہاں وہ ملیں انہیں پکڑو اور مارو، ان پر ہاتھ اٹھانے کے لیے ہم نے تمہیں کھلی حجت دے دی ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dlxxxv{کسی مومن کا یہ کام نہیں ہے کہ دوسرے مومن کو قتل کرے، الا یہ کہ اُس سے چوک ہو جائے، اور جو شخص کسی مومن کو غلطی سے قتل کر دے تو اس کا کفارہ یہ ہے کہ ایک مومن کو غلامی سے آزاد کرے اور مقتول کے وارثوں کو خونبہا دے، الا یہ کہ وہ خونبہا معاف کر دیں لیکن اگر وہ مسلمان مقتول کسی ایسی قوم سے تھا جس سے تمہاری دشمنی ہو تو اس کا کفارہ ایک مومن غلام آزاد کرنا ہے اور اگر وہ کسی ایسی غیرمسلم قوم کا فرد تھا جس سے تمہارا معاہدہ ہو تو اس کے وارثوں کو خون بہا دیا جائے گا اور ایک مومن غلام کو آزاد کرنا ہوگا پھر جو غلام نہ پائے وہ پے در پے دو مہینے کے روزے رکھے یہ اِس گناہ پر اللہ سے توبہ کرنے کا طریقہ ہے اور اللہ علیم و دانا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dlxxxvi{رہا وہ شخص جو کسی مومن کو جان بوجھ کر قتل کرے تو اُس کی جزا جہنم ہے جس میں وہ ہمیشہ رہے گا اس پر اللہ کا غضب اور اُس کی لعنت ہے اور اللہ نے اس کے لیے سخت عذاب مہیا کر رکھا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dlxxxvii{اے لوگو جو ایما ن لائے ہو، جب تم اللہ کی راہ میں جہاد کے لیے نکلو تو دوست دشمن میں تمیز کرو اور جو تمہاری طرف سلام سے تقدیم کرے اُسے فوراً نہ کہہ دو کہ تو مومن نہیں ہے اگر تم دنیوی فائدہ چاہتے ہو تو اللہ کے پاس تمہارے لیے بہت سے اموال غنیمت ہیں آخر اسی حالت میں تم خود بھی تو اس سے پہلے مبتلا رہ چکے ہو، پھر اللہ نے تم پر احسان کیا، لہٰذا تحقیق سے کام لو، جو کچھ تم کرتے ہو اللہ اُس سے باخبر ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dlxxxviii{مسلمانوں میں سے وہ لوگ جو کسی معذوری کے بغیر گھر بیٹھے رہتے ہیں اور وہ جو اللہ کی راہ میں جان و مال سے جہاد کرتے ہیں، دونوں کی حیثیت یکساں نہیں ہے اللہ نے بیٹھنے والوں کی بہ نسبت جان و مال سے جہاد کرنے والوں کا درجہ بڑا رکھا ہے اگرچہ ہر ایک کے لیے اللہ نے بھلائی ہی کا وعدہ فرمایا ہے، مگر اُس کے ہاں مجاہدوں کی خدمات کا معاوضہ بیٹھنے والوں سے بہت زیادہ ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dlxxxix{اُن کے لیے اللہ کی طرف سے بڑے درجے ہیں اور مغفرت اور رحمت ہے، اور اللہ بڑا معاف کرنے والا اور رحم فرمانے والا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dxc{جو لوگ اپنے نفس پر ظلم کر رہے تھے اُن کی روحیں جب فرشتوں نے قبض کیں تو ان سے پوچھا کہ یہ تم کس حال میں مبتلا تھے؟ انہوں نے جواب دیا کہ ہم زمین میں کمزور و مجبور تھے فرشتوں نے کہا، کیا خدا کی زمین وسیع نہ تھی کہ تم اس میں ہجرت کرتے؟ یہ وہ لوگ ہیں جن کا ٹھکانا جہنم ہے اور بڑا ہی برا ٹھکانا ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dxci{ہاں جو مرد، عورتیں اور بچے واقعی بے بس ہیں اور نکلنے کا کوئی راستہ اور ذریعہ نہیں پاتے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dxcii{بعید نہیں کہ اللہ انہیں معاف کر دے، اللہ بڑا معاف کرنے والا اور درگزر فرمانے والا ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dxciii{جو کوئی اللہ کی راہ میں ہجرت کرے گا وہ زمین میں پناہ لینے کے لیے بہت جگہ اوربسر اوقات کے لیے بڑی گنجائش پائے گا، اور جو اپنے گھر سے اللہ اور رسول کی طرف ہجرت کے لیے نکلے، پھر راستہ ہی میں اُسے موت آ جائے اُس کا اجر اللہ کے ذمے واجب ہو گیا، اللہ بہت بخشش فرمانے والا اور رحیم ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dxciv{اور جب تم لوگ سفر کے لیے نکلو تو کوئی مضائقہ نہیں اگر نماز میں اختصار کر دو (خصوصاً) جبکہ تمہیں اندیشہ ہو کہ کافر تمہیں ستائیں گے کیونکہ وہ کھلم کھلا تمہاری دشمنی پر تلے ہوئے ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dxcv{اور اے نبیؐ! جب تم مسلمانوں کے درمیان ہو اور (حالت جنگ میں) انہیں نماز پڑھانے کھڑے ہو تو چاہیے کہ ان میں سے ایک گروہ تمہارے ساتھ کھڑا ہو اور اسلحہ لیے رہے، پھر جب وہ سجدہ کر لے تو پیچھے چلا جائے اور دوسرا گروہ جس نے ابھی نماز نہیں پڑھی ہے آکر تمہارے ساتھ پڑھے اور وہ بھی چوکنا رہے اور اپنے اسلحہ لیے رہے، کیوں کہ کفار اِس تاک میں ہیں کہ تم اپنے ہتھیاروں اور اپنے سامان کی طرف سے ذرا غافل ہو تو وہ تم پر یکبارگی ٹوٹ پڑیں البتہ اگر تم بارش کی وجہ سے تکلیف محسوس کرو یا بیمار ہو تو اسلحہ رکھ دینے میں کوئی مضائقہ نہیں، مگر پھر بھی چوکنے رہو یقین رکھو کہ اللہ نے کافروں کے لیے رسوا کن عذاب مہیا کر رکھا ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dxcvi{پھر جب نماز سے فارغ ہو جاؤ تو کھڑے اور بیٹھے اور لیٹے، ہر حال میں اللہ کو یاد کرتے رہو اور جب اطمینان نصیب ہو جائے تو پوری نماز پڑھو نما ز در حقیقت ایسا فرض ہے جو پابندی وقت کے ساتھ اہل ایمان پر لازم کیا گیا ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dxcvii{اِس گروہ کے تعاقب میں کمزوری نہ دکھاؤ اگر تم تکلیف اٹھا رہے ہو تو تمہاری طرح وہ بھی تکلیف اٹھا رہے ہیں اور تم اللہ سے اُس چیز کے امیدوار ہو جس کے وہ امیدوار نہیں ہیں اللہ سب کچھ جانتا ہے اور وہ حکیم و دانا ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dxcviii{اے نبیؐ! ہم نے یہ کتاب حق کے ساتھ تمہاری طرف نازل کی ہے تاکہ جو راہ راست اللہ نے تمہیں دکھائی ہے اس کے مطابق لوگوں کے درمیان فیصلہ کرو تم بد دیانت لوگوں کی طرف سے جھگڑنے والے نہ بنو\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dxcix{اور اللہ سے در گزر کی درخواست کرو، وہ بڑا درگزر فرمانے والا اور رحیم ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dc{جو لو گ اپنے نفس سے خیانت کرتے ہیں تم اُن کی حمایت نہ کرو اللہ کو ایسا شخص پسند نہیں ہے جو خیانت کار اور معصیت پیشہ ہو\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dci{یہ لو گ انسانوں سے اپنی حرکات چھپا سکتے ہیں مگر خدا سے نہیں چھپا سکتے وہ تواُس وقت بھی اُن کے ساتھ ہوتا ہے جب یہ راتوں کو چھپ کر اُس کی مرضی کے خلاف مشورے کرتے ہیں اِن کے سارے اعمال پر اللہ محیط ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcii{ہاں! تم لوگوں نے اِن مجرموں کی طرف سے دنیا کی زندگی میں تو جھگڑا کر لیا، مگر قیامت کے روز ان کی طرف سے کون جھگڑا کرے گا؟آخر وہاں کون اِن کا وکیل ہوگا؟\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dciii{اگر کوئی شخص برا فعل کر گزرے یا اپنے نفس پر ظلم کر جائے اور اس کے بعد اللہ سے درگزر کی درخواست کرے تو اللہ کو درگزر کرنے والا اور رحیم پائے گا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dciv{مگر جو برائی کما لے تو اس کی یہ کمائی اُسی کے لیے وبال ہوگی، اللہ کو سب باتوں کی خبر ہے اور وہ حکیم و دانا ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcv{پھر جس نے کوئی خطا یا گناہ کر کے اس کا الزام کسی بے گناہ پر تھوپ دیا اُس نے تو بڑے بہتان اور صریح گناہ کا بار سمیٹ لیا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcvi{اے نبیؐ! اگر اللہ کا فضل تم پر نہ ہوتا اور اس کی رحمت تمہارے شامل حال نہ ہوتی تو ان میں سے ایک گروہ نے تو تمہیں غلط فہمی میں مبتلا کرنے کا فیصلہ کر ہی لیا تھا، حالاں کہ در حقیقت وہ خود اپنے سوا کسی کو غلط فہمی میں مبتلا نہیں کر رہے تھے اور تمہارا کوئی نقصان نہ کرسکتے تھے اللہ نے تم پر کتاب اور حکمت نازل کی ہے اور تم کو وہ کچھ بتایا ہے جو تمہیں معلوم نہ تھا اور اس کا فضل تم پر بہت ہے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcvii{لوگوں کی خفیہ سرگوشیوں میں اکثر و بیشتر کوئی بھلائی نہیں ہوتی ہاں اگر کوئی پوشیدہ طور پر صدقہ و خیرات کی تلقین کرے یا کسی نیک کام کے لیے یا لوگوں کے معاملات میں اصلاح کرنے کے لیے کسی سے کچھ کہے تو یہ البتہ بھلی بات ہے، اور جو کوئی اللہ کی رضا جوئی کے لیے ایسا کرے گا اُسے ہم بڑا اجر عطا کریں گے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcviii{مگر جو شخص رسول کی مخالفت پر کمر بستہ ہو اور اہل ایمان کی روش کے سوا کسی اور روش پر چلے، درآں حالیکہ اس پر راہ راست واضح ہو چکی ہو، تو اُس کو ہم اُسی طرف چلائیں گے جدھر وہ خود پھر گیا اور اسے جہنم میں جھونکیں گے جو بد ترین جائے قرار ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcix{اللہ کے ہاں بس شرک ہی کی بخشش نہیں ہے، اس کے سوا اور سب کچھ معاف ہوسکتا ہے جسے وہ معاف کرنا چاہے جس نے اللہ کے ساتھ کسی کو شریک ٹھیرایا وہ تو گمراہی میں بہت دور نکل گیا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcx{وہ اللہ کو چھوڑ کر دیویوں کو معبود بناتے ہیں وہ اُس باغی شیطان کو معبود بناتے ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcxi{جس کو اللہ نے لعنت زدہ کیا ہے (وہ اُس شیطان کی اطاعت کر رہے ہیں) جس نے اللہ سے کہا تھا کہ ``میں تیرے بندوں سے ایک مقرر حصہ لے کر رہوں گا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcxii{میں انہیں بہکاؤں گا، میں انہیں آرزوؤں میں الجھاؤں گا، میں انہیں حکم دوں گا اور وہ میرے حکم سے جانوروں کے کان پھاڑیں گے اور میں انہیں حکم دوں گا اور وہ میرے حکم سے خدائی ساخت میں رد و بدل کریں گے" اس شیطان کوجس نے اللہ کے بجائے اپنا ولی و سرپرست بنا لیا وہ صریح نقصان میں پڑ گیا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcxiii{وہ اِن لوگوں سے وعدہ کرتا ہے اور انہیں امیدیں دلاتا ہے، مگر شیطان کے سارے وعدے بجز فریب کے اور کچھ نہیں ہیں\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dcxiv{اِن لوگوں کا ٹھکانا جہنم ہے جس سے خلاصی کی کوئی صورت یہ نہ پائیں گے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@dcxv{رہے وہ لوگ جو ایمان لے آئیں اور نیک عمل کریں، توا نہیں ہم ایسے باغوں میں داخل کریں گے جن کے نیچے نہریں بہتی ہوں گی اور وہ وہاں ہمیشہ ہمیشہ رہیں گے یہ اللہ کا سچا وعدہ ہے اور اللہ سے بڑھ کر کون اپنی بات میں سچا ہوگا\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@dcxvi{انجام کار نہ تمہاری آرزوؤں پر موقوف ہے نہ اہل کتاب کی آرزوؤں پر جو بھی برائی کرے گا اس کا پھل پائے گا اور اللہ کے مقابلہ میں اپنے لیے کوئی حامی و مدد گار نہ پاسکے گا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@dcxvii{اور جو نیک عمل کرے گا، خواہ مرد ہو یا عورت، بشر طیکہ ہو وہ مومن، تو ایسے ہی لوگ جنت میں داخل ہوں گے اور اُن کی ذرہ برابر حق تلفی نہ ہونے پائے گی\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@dcxviii{اُس شخص سے بہتر اور کس کا طریق زندگی ہوسکتا ہے جس نے اللہ کے آگے سر تسلیم خم کر دیا اور اپنا رویہ نیک رکھا اور یکسو ہو کر ابراہیمؑ کے طریقے کی پیروی کی، اُس ابراہیمؑ کے طریقے کی جسے اللہ نے اپنا دوست بنا لیا تھا\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@dcxix{آسمانوں اور زمین میں جو کچھ ہے اللہ کا ہے اور اللہ ہر چیز پر محیط ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@dcxx{لو گ تم سے عورتوں کے معاملہ میں فتویٰ پوچھتے ہیں کہو اللہ تمہیں اُن کے معاملہ میں فتویٰ دیتا ہے، اور ساتھ ہی وہ احکام بھی یاد دلاتا ہے جو پہلے سے تم کو اس کتاب میں سنائے جا رہے ہیں یعنی وہ احکام جو اُن یتیم لڑکیوں کے متعلق ہیں جن کے حق تم ادا نہیں کرتے اور جن کے نکاح کرنے سے تم باز رہتے ہو (یا لالچ کی بنا پر تم خود ان سے نکاح کر لینا چاہتے ہو)، او ر وہ احکام جو اُن بچوں کے متعلق ہیں جو بیچارے کوئی زور نہیں رکھتے اللہ تمہیں ہدایت کرتا ہے کہ یتیموں کے ساتھ انصاف پر قائم رہو، اور جو بھلائی تم کرو گے وہ اللہ کے علم سے چھپی نہ رہ جائے گی\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@dcxxi{جب کسی عورت کو اپنے شوہر سے بدسلوکی یا بے رخی کا خطر ہ ہو تو کوئی مضائقہ نہیں اگر میاں اور بیوی (کچھ حقوق کی کمی بیشی پر) آپس میں صلح کر لیں صلح بہر حال بہتر ہے نفس تنگ دلی کے طرف جلدی مائل ہو جاتے ہیں، لیکن اگر تم لوگ احسان سے پیش آؤ اور خدا ترسی سے کام لو تو یقین رکھو کہ اللہ تمہارے اس طرز عمل سے بے خبر نہ ہوگا\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@dcxxii{بیویوں کے درمیان پورا پورا عدل کرنا تمہارے بس میں نہیں ہے تم چاہو بھی تو اس پر قادر نہیں ہوسکتے لہٰذا (قانون الٰہی کا منشا پورا کرنے کے لیے یہ کافی ہے کہ) ایک بیوی کی طرف اِس طرح نہ جھک جاؤ کہ دوسری کو ادھر لٹکتا چھوڑ دو اگر تم اپنا طرز عمل درست رکھو اور اللہ سے ڈرتے رہو تو اللہ چشم پوشی کرنے والا اور رحم فرمانے والا ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@dcxxiii{لیکن اگر زوجین ایک دوسرے سے الگ ہی ہو جائیں تو اللہ اپنی وسیع قدرت سے ہر ایک کو دوسرے کی محتاجی سے بے نیاز کر دے گا اللہ کا دامن بہت کشادہ ہے اور وہ دانا و بینا ہے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@dcxxiv{آسمانوں اور زمین میں جو کچھ ہے سب اللہ ہی کا ہے تم سے پہلے جن کو ہم نے کتاب دی تھی انہیں بھی یہی ہدایت کی تھی اور اب تم کو بھی یہی ہدایت کرتے ہیں کہ خدا سے ڈرتے ہوئے کام کرو لیکن اگر تم نہیں مانتے تو نہ مانو، آسمان و زمین کی ساری چیزوں کا مالک اللہ ہی ہے اور وہ بے نیاز ہے، ہر تعریف کا مستحق\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@dcxxv{ہاں اللہ ہی مالک ہے ان سب چیزوں کاجو آسمانوں میں ہیں اور جو زمین میں ہیں، اور کار سازی کے لیے بس و ہی کافی ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@dcxxvi{اگر وہ چاہے تو تم لوگوں کو ہٹا کر تمہاری جگہ دوسروں کو لے آئے، اور وہ اِس کی پوری قدرت رکھتا ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@dcxxvii{جو شخص محض ثواب دنیا کا طالب ہو اُسے معلوم ہونا چاہیے کہ اللہ کے پاس ثواب دنیا بھی ہے اور ثواب آخرت بھی، اور اللہ سمیع و بصیر ہے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@dcxxviii{اے لوگو جو ایمان لائے ہو، انصاف کے علمبردار اور خدا واسطے کے گواہ بنو اگرچہ تمہارے انصاف اور تمہاری گواہی کی زد خود تمہاری اپنی ذات پر یا تمہارے والدین اور رشتہ داروں پر ہی کیوں نہ پڑتی ہو فریق معاملہ خواہ مالدار ہو یا غریب، اللہ تم سے زیادہ اُن کا خیر خواہ ہے لہٰذا اپنی خواہش نفس کی پیروی میں عدل سے باز نہ رہو اور اگر تم نے لگی لپٹی بات کہی یا سچائی سے پہلو بچایا تو جان رکھو کہ جو کچھ تم کرتے ہو اللہ کو اس کی خبر ہے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@dcxxix{اے لوگو جو ایمان لائے ہو، ایمان لاؤ اللہ پر اور اس کے رسول پر اور اس کتاب پر جو اللہ نے اپنے رسول پر نازل کی ہے اور ہر اُس کتاب پر جو اس سے پہلے وہ نازل کر چکا ہے جس نے اللہ اور اس کے ملائکہ اور اس کی کتابوں اور اس کے رسولوں اور روز آخرت سے کفر کیا وہ گمراہی میں بھٹک کر بہت دور نکل گیا\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@dcxxx{رہے وہ لوگ جو ایمان لائے، پھر کفر کیا، پھر ایمان لائے، پھر کفر کیا، پھر اپنے کفر میں بڑھتے چلے گئے، تو اللہ ہرگز ان کو معاف نہ کرے گا اور نہ کبھی اُن کو راہ راست دکھائے گا\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@dcxxxi{اور جو منافق اہل ایمان کو چھوڑ کر کافروں کو اپنا رفیق بناتے ہیں انہیں یہ مثردہ سنا دو کہ اُن کے لیے دردناک سزا تیار ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@dcxxxii{کیا یہ لوگ عزت کی طلب میں اُن کے پاس جاتے ہیں؟ حالانکہ عزت تو ساری کی ساری اللہ ہی کے لیے ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@dcxxxiii{اللہ اِس کتاب میں تم کو پہلے ہی حکم دے چکا ہے کہ جہاں تم سنو کہ اللہ کی آیات کے خلاف کفر بکا جا رہا ہے اور ا ن کا مذاق اڑایا جا رہا ہے وہاں نہ بیٹھو جب تک کہ لوگ کسی دوسری بات میں نہ لگ جائیں اب اگر تم ایسا کرتے ہو تو تم بھی انہی کی طرح ہو یقین جانو کہ اللہ منافقوں اور کافروں کو جہنم میں ایک جگہ جمع کرنے والا ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@dcxxxiv{یہ منافق تمہارے معاملہ میں انتظار کر رہے ہیں (کہ اونٹ کس کروٹ بیٹھتا ہے) اگر اللہ کی طرف سے فتح تمہاری ہوئی تو آ کر کہیں گے کہ کیا ہم تمہارے ساتھ نہ تھے؟ ا گر کافروں کا پلہ بھاری رہا تو اُن سے کہیں گے کہ کیا ہم تمہارے خلاف لڑنے پر قادر نہ تھے اور پھر بھی ہم نے تم کو مسلمانوں سے بچایا؟ بس اللہ ہی تمہارے اور ان کے معاملہ کا فیصلہ قیامت کے روز کرے گا اور (اس فیصلہ میں) اللہ نے کافروں کے لیے مسلمانوں پر غالب آنے کی ہرگز کوئی سبیل نہیں رکھی ہے\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@dcxxxv{یہ منافق اللہ کے ساتھ دھوکہ بازی کر رہے ہیں حالانکہ در حقیقت اللہ ہی نے انہیں دھوکہ میں ڈال رکھا ہے جب یہ نماز کے لیے اٹھتے ہں تو کسمساتے ہوئے محض لوگوں کو دکھانے کی خاطر اٹھتے ہیں اور خدا کو کم ہی یاد کرتے ہیں\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@dcxxxvi{کفر و ایمان کے درمیان ڈانوا ڈول ہیں نہ پورے اِس طرف ہیں نہ پورے اُس طرف جسے اللہ نے بھٹکا دیا ہو اس کے لیے تم کوئی راستہ نہیں پاسکتے\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@dcxxxvii{اے لوگو جو ایمان لائے ہو، مومنوں کو چھوڑ کر کافروں کو اپنا رفیق نہ بناؤ کیا تم چاہتے ہو کہ اللہ کو اپنے خلاف صریح حجت دے دو؟\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@dcxxxviii{یقین جانو کہ منافق جہنم کے سب سے نیچے طبقے میں جائیں گے اور تم کسی کو اُن کا مدد گار نہ پاؤ گے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@dcxxxix{البتہ جو اُن میں سے تائب ہو جائیں او ر اپنے طرز عمل کی اصلاح کر لیں اور اللہ کا دامن تھام لیں اور اپنے دین کو اللہ کے لیے خالص کر دیں، ایسے لوگ مومنوں کے ساتھ ہیں اور اللہ مومنوں کو ضرور اجر عظیم عطا فرمائے گا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@dcxl{آخر اللہ کو کیا پڑی ہے کہ تمہیں خواہ مخواہ سزا دے اگر تم شکر گزار بندے بنے رہو اور ایمان کی روش پر چلو اللہ بڑا قدر دان ہے اور سب کے حال سے واقف ہے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@dcxli{اللہ اس کو پسند نہیں کرتا کہ آدمی بد گوئی پر زبان کھولے، الا یہ کہ کسی پر ظلم کیا گیا ہو، اور اللہ سب کچھ سننے اور جاننے والا ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@dcxlii{(مظلوم ہونے کی صورت میں اگر چہ تم پر بد گوئی کا حق ہے) لیکن اگر تم ظاہر و باطن میں بھلائی ہی کیے جاؤ، یا کم از کم برائی سے در گزر کرو، تو اللہ کی صفت بھی یہی ہے کہ وہ بڑا معاف کرنے والا ہے حالانکہ سزا دینے پر پوری قدرت رکھتا ہے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@dcxliii{جو لوگ اللہ اور اس کے رسولوں سے کفر کرتے ہیں، اور چاہتے ہیں کہ اللہ اور اس کے رسولوں کے درمیان تفریق کریں، اور کہتے ہیں کہ ہم کسی کو مانیں گے اور کسی کو نہ مانیں گے، اور کفر و ایمان کے بیچ میں ایک راہ نکالنے کا ارادہ رکھتے ہیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@dcxliv{وہ سب پکے کافر ہیں اور ایسے کافروں کے لیے ہم نے وہ سزا مہیا کر رکھی ہے جو انہیں ذلیل و خوار کر دینے والی ہوگی\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@dcxlv{بخلاف اس کے جو لوگ اللہ اور ا س کے تمام رسولوں کو مانیں، اور اُن کے درمیان تفریق نہ کریں، اُن کو ہم ضرور اُن کے اجر عطا کریں گے، اور اللہ بڑا درگزر فرمانے والا اور رحم کرنے والا ہے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@dcxlvi{یہ اہل کتاب اگر آج تم سے مطالبہ کر رہے ہیں کہ تم آسمان سے کوئی تحریر اُن پر نازل کراؤ تو اِس سے بڑھ چڑھ کر مجرمانہ مطالبے یہ پہلے موسیٰؑ سے کر چکے ہیں اُس سے تو اِنہوں نے کہا تھا کہ ہمیں خدا کو علانیہ دکھا دو اور اِسی سرکشی کی وجہ سے یکایک اِن پر بجلی ٹوٹ پڑی تھی پھر انہوں نے بچھڑے کو اپنا معبود بنا لیا، حالانکہ یہ کھلی کھلی نشانیاں دیکھ چکے تھے اس پر بھی ہم نے اِن سے درگزر کیا ہم نے موسیٰؑ کو صریح فرمان عطا کیا\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@dcxlvii{اور اِن لوگوں پر طور کو اٹھا کر اِن سے (اُس فرمان کی اطاعت کا) عہد لیا ہم نے اِن کو حکم دیا کہ دروازے میں سجدہ ریز ہوتے ہوئے داخل ہوں ہم نے اِن سے کہا کہ سبت کا قانون نہ توڑو اوراس پر اِن سے پختہ عہد لیا\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@dcxlviii{آخر کا ر اِن کی عہد شکنی کی وجہ سے، اور اس وجہ سے کہ انہوں نے اللہ کی آیات کو جھٹلایا، اور متعدد پیغمبروں کو نا حق قتل کیا، اور یہاں تک کہا کہ ہمارے دل غلافوں میں محفوظ ہیں حالانکہ در حقیقت اِن کی باطل پرستی کے سبب سے اللہ نے اِن کے دلوں پر ٹھپہ لگا دیا ہے اور اسی وجہ سے یہ بہت کم ایمان لاتے ہیں\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@dcxlix{پھر اپنے کفر میں اتنے بڑھے کہ مریم پر سخت بہتان لگایا\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@dcl{اور خود کہا کہ ہم نے مسیح، عیسیٰ ابن مریم، رسول اللہ کو قتل کر دیا ہے حالانکہ فی الواقع انہوں نے نہ اس کو قتل کیا نہ صلیب پر چڑھایا بلکہ معاملہ ان کے لیے مشتبہ کر دیا گیا اور جن لوگوں نے اس کے بارے میں اختلاف کیا ہے وہ بھی دراصل شک میں مبتلا ہیں، ان کے پاس اس معاملہ میں کوئی علم نہیں ہے، محض گمان ہی کی پیروی ہے انہوں نے مسیح کو یقین کے ساتھ قتل نہیں کیا\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@dcli{بلکہ اللہ نے اس کو اپنی طرف اٹھا لیا، اللہ زبردست طاقت رکھنے والا اور حکیم ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@dclii{اور اہل کتاب میں سے کوئی ایسا نہ ہوگا جو اُس کی موت سے پہلے اس پر ایمان نہ لے آئے گا اور قیامت کے روز وہ ان پر گواہی دے گا\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@dcliii{غرض اِن یہودی بن جانے والوں کے اِسی ظالمانہ رویہ کی بنا پر، اور اس بنا پر کہ یہ بکثرت اللہ کے راستے سے روکتے ہیں\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@dcliv{اور سود لیتے ہیں جس سے انہیں منع کیا گیا تھا، اور لوگوں کے مال ناجائز طریقوں سے کھاتے ہیں، ہم نے بہت سی وہ پاک چیزیں ان پر حرام کر دیں جو پہلے ان کے لیے حلال تھیں، اور جو لوگ اِن میں سے کافر ہیں ان کے لیے ہم نے درد ناک عذاب تیار کر رکھا ہے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@dclv{مگر ان میں جو لوگ پختہ علم رکھنے والے ہیں اور ایماندار ہیں وہ سب اُس تعلیم پر ایمان لاتے ہیں جو تمہاری طرف نازل کی گئی ہے اور جو تم سے پہلے نازل کی گئی تھی اِس طرح کے ایمان لانے والے اور نماز و زکوٰۃ کی پابندی کرنے والے اور اللہ اور روز آخر پر سچا عقیدہ رکھنے والے لوگوں کو ہم ضرور اجر عظیم عطا کریں گے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@dclvi{اے محمدؐ! ہم نے تمہاری طرف اُسی طرح وحی بھیجی ہے جس طرح نوحؑ اور اس کے بعد کے پیغمبروں کی طرف بھیجی تھی ہم نے ابراہیمؑ، اسماعیلؑ، اسحاقؑ، یعقوبؑ اور اولاد یعقوبؑ، عیسیٰؑ، ایوبؑ، یونسؑ، ہارونؑ اور سلیمانؑ کی طرف وحی بھیجی ہم نے داؤدؑ کو زبور دی\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@dclvii{ہم نے اُن رسولوں پر بھی وحی نازل کی جن کا ذکر ہم اِس سے پہلے تم سے کر چکے ہیں اور اُن رسولوں پر بھی جن کا ذکر تم سے نہیں کیا ہم نے موسیٰؑ سے اِس طرح گفتگو کی جس طرح گفتگو کی جاتی ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@dclviii{یہ سارے رسول خوش خبری دینے والے اور ڈرانے والے بنا کر بھیجے گئے تھے تاکہ اُن کو مبعوث کردینے کے بعد لوگوں کے پاس اللہ کے مقابلہ میں کوئی حجت نہ رہے اور اللہ بہرحال غالب رہنے والا اور حکیم و دانا ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@dclix{(لوگ نہیں مانتے تو نہ مانیں) مگر اللہ گواہی دیتا ہے کہ جو کچھ اُس نے تم پر نازل کیا ہے اپنے علم سے نازل کیا ہے، اور اِس پر ملائکہ بھی گواہ ہیں اگرچہ اللہ کا گواہ ہونا بالکل کفایت کرتا ہے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@dclx{جو لوگ اِس کو ماننے سے خود انکار کرتے ہیں اور دوسروں کو خدا کے راستہ سے روکتے ہیں وہ یقیناً گمرا ہی میں حق سے بہت دور نکل گئے ہیں\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@dclxi{ا ِس طرح جن لوگوں نے کفر و بغاوت کا طریقہ اختیار کیا اور ظلم وستم پر اتر آئے اللہ ان کو ہرگز معاف نہ کرے گا اور انہیں کوئی راستہ،\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@dclxii{بجز جہنم کے راستہ کے نہ دکھائے گا جس میں وہ ہمیشہ رہیں گے اللہ کے لیے یہ کوئی مشکل کام نہیں ہے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@dclxiii{لوگو! یہ رسول تمہارے پاس تمہارے رب کی طرف سے حق لے کر آگیا ہے، ایمان لے آؤ، تمہارے ہی لیے بہتر ہے، اور اگر انکار کرتے ہو تو جان لو کہ آسمانوں اور زمین میں جو کچھ ہے سب اللہ کا ہے اور اللہ علیم بھی ہے اور حکیم بھی\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@dclxiv{اے اہل کتاب! اپنے دین میں غلو نہ کرو اور اللہ کی طرف حق کے سوا کوئی بات منسوب نہ کرو مسیح عیسیٰ ابن مریم اس کے سوا کچھ نہ تھا کہ اللہ کا ایک رسول تھا اور ایک فرمان تھا جو اللہ نے مریم کی طرف بھیجا اور ایک روح تھی اللہ کی طرف سے (جس نے مریم کے رحم میں بچہ کی شکل اختیار کی) پس تم اللہ اور اُ س کے رسولوں پر ایمان لاؤ اور نہ کہو کہ ``تین" ہیں باز آ جاؤ، یہ تمہارے ہی لیے بہتر ہے اللہ تو بس ایک ہی خدا ہے وہ بالا تر ہے اس سے کہ کوئی اس کا بیٹا ہو زمین اور آسمانوں کی ساری چیزیں اس کی مِلک ہیں، اور ان کی کفالت و خبر گیری کے لیے بس وہی کافی ہے\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@dclxv{مسیح نے کبھی اس بات کو عار نہیں سمجھا کہ وہ اللہ کا بندہ ہو، اور نہ مقرب ترین فرشتے اِس کو اپنے لیے عار سمجھتے ہیں اگر کوئی اللہ کی بندگی کو اپنے لیے عار سمجھتا ہے اور تکبر کرتا ہے تو ایک وقت آئے گا جب اللہ سب کو گھیر کر اپنے سامنے حاضر کرے گا\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@dclxvi{اُس وقت وہ لوگ جنہوں نے ایمان لا کر نیک طرز عمل اختیار کیا ہے اپنے اجر پورے پورے پائیں گے اور اللہ اپنے فضل سے ان کو مزید اجر عطا فرمائے گا، اور جن لوگوں نے بندگی کو عار سمجھا اور تکبر کیا ہے اُن کو اللہ دردناک سزا دے گا اور اللہ کے سوا جن جن کی سرپرستی و مددگاری پر وہ بھروسہ رکھتے ہیں ان میں سے کسی کو بھی وہ وہاں نہ پائیں گے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@dclxvii{لوگو! تمہارے رب کی طرف سے تمہارے پاس دلیل روشن آ گئی ہے اور ہم نے تمہاری طرف ایسی روشنی بھیج دی ہے جو تمہیں صاف صاف راستہ دکھانے والی ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@dclxviii{اب جو لوگ اللہ کی بات مان لیں گے اور اس کی پناہ ڈھونڈیں گے ان کو اللہ اپنی رحمت اور اپنے فضل و کرم کے دامن میں لے لے گا اور اپنی طرف آنے کا سیدھا راستہ ان کو دکھا دے گا\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@dclxix{لوگ تم سے کلالہ کے معاملہ میں فتویٰ پوچھتے ہیں کہو اللہ تمہیں فتویٰ دیتا ہے اگر کوئی شخص بے اولاد مر جائے اور اس کی ایک بہن ہو تو وہ اس کے ترکہ میں سے نصف پائے گی، اور اگر بہن بے اولاد مرے تو بھائی اس کا وارث ہوگا اگر میت کی وارث دو بہنیں ہوں تو وہ ترکے میں سے دو تہائی کی حقدار ہوں گی، اور اگر کئی بھائی بہنیں ہوں تو عورتوں کا اکہرا اور مردوں کا دوہرا حصہ ہوگا اللہ تمہارے لیے احکام کی توضیح کرتا ہے تاکہ تم بھٹکتے نہ پھرو اور اللہ ہر چیز کا علم رکھتا ہے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@dclxx{\basmalahur اے لوگو جو ایمان لائے ہو، بندشوں کی پوری پابندی کرو تمہارے لیے مویشی کی قسم کے سب جانور حلال کیے گئے، سوائے اُن کے جو آگے چل کر تم کو بتائے جائیں گے لیکن احرام کی حالت میں شکار کو اپنے لیے حلال نہ کر لو، بے شک اللہ جو چاہتا ہے حکم دیتا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dclxxi{اے لوگو جو ایمان لائے ہو، خد ا پرستی کی نشانیوں کو بے حرمت نہ کرو نہ حرام مہینوں میں سے کسی کو حلال کر لو، نہ قربانی کے جانوروں پر دست درازی کرو، نہ اُن جانوروں پر ہاتھ ڈالو جن کی گردنوں میں نذر خداوندی کی علامت کے طور پر پٹے پڑے ہوئے ہوں، نہ اُن لوگوں کو چھیڑو جو اپنے رب کے فضل اور اس کی خوشنودی کی تلاش میں مکان محترم (کعبہ) کی طرف جا رہے ہوں ہاں جب احرام کی حالت ختم ہو جائے تو شکار تم کرسکتے ہو اور دیکھو، ایک گروہ نے جو تمہارے لیے مسجد حرام کا راستہ بند کر دیا ہے تواس پر تمہارا غصہ تمہیں اتنا مشتعل نہ کر دے کہ تم بھی ان کے مقابلہ میں ناروا زیادتیاں کرنے لگو نہیں! جو کام نیکی اور خدا ترسی کے ہیں ان میں سب سے تعاون کرو اور جو گناہ اور زیادتی کے کام ہیں ان میں کسی سے تعاون نہ کرو اللہ سے ڈرو، اس کی سز ا بہت سخت ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dclxxii{تم پر حرام کیا گیا مُردار، خون، سُور کا گوشت، وہ جانور جو خدا کے سوا کسی اور کے نام پر ذبح کیا گیا ہو، وہ جو گھلا گھٹ کر، یا چوٹ کھا کر، یا بلندی سے گر کر، یا ٹکر کھا کر مرا ہو، یا جسے کسی درندے نے پھاڑا ہو سوائے اس کے جسے تم نے زندہ پاکر ذبح کر لیا اور وہ جو کسی آستا نے پر ذبح کیا گیا ہو نیز یہ بھی تمہارے لیے ناجائز ہے کہ پانسوں کے ذریعہ سے اپنی قسمت معلوم کرو یہ سب افعال فسق ہیں آج کافروں کو تمہارے دین کی طرف سے پوری مایوسی ہو چکی ہے لہٰذا تم اُن سے نہ ڈرو بلکہ مجھ سے ڈرو آج میں نے تمہارے دین کو تمہارے لیے مکمل کر دیا ہے اور اپنی نعمت تم پر تمام کر دی ہے اور تمہارے لیے اسلام کو تمہارے دین کی حیثیت سے قبول کر لیا ہے (لہٰذا حرام و حلال کی جو قیود تم پر عائد کر دی گئی ہیں اُن کی پابند ی کرو) البتہ جو شخص بھوک سے مجبور ہو کر اُن میں سے کوئی چیز کھا لے، بغیر اس کے کہ گناہ کی طرف اس کا میلان ہو تو بیشک اللہ معاف کرنے والا اور رحم فرمانے والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dclxxiii{لوگ پوچھتے ہیں کہ ان کے لیے کیا حلال کیا گیا ہے، کہو تمہارے لیے ساری پاک چیزیں حلال کر دی گئی ہیں اور جن شکاری جانوروں کو تم نے سدھایا ہو جن کو خدا کے دیے ہوئے علم کی بنا پر تم شکار کی تعلیم دیا کرتے ہو وہ جس جانور کو تمہارے لیے پکڑ رکھیں اس کو بھی تم کھاسکتے ہو، البتہ اس پر اللہ کا نام لے لو اور اللہ کا قانون توڑنے سے ڈرو، اللہ کو حساب لیتے کچھ دیر نہیں لگتی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dclxxiv{آج تمہارے لیے ساری پاک چیزیں حلال کر دی گئی ہیں اہل کتاب کا کھانا تمہارے لیے حلال ہے اور تمہارا کھانا اُن کے لیے اور محفوظ عورتیں بھی تمہارے لیے حلال ہیں خواہ وہ اہل ایمان کے گروہ سے ہوں یا اُن قوموں میں سے جن کو تم سے پہلے کتاب دی گئی تھی، بشر طیکہ تم اُن کے مہر ادا کر کے نکاح میں اُن کے محافظ بنو، نہ یہ کہ آزاد شہوت رانی کرنے لگو یا چوری چھپے آشنائیاں کرو اور جو کسی نے ایمان کی روش پر چلنے سے انکار کیا تو اس کا سارا کارنامہ زندگی ضائع ہو جائے گا اور وہ آخرت میں دیوالیہ ہوگا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dclxxv{اے لوگو جو ایمان لائے ہو، جب تم نماز کے لیے اٹھو تو چاہیے کہ اپنے منہ اور ہاتھ کہنیوں تک دھو لو، سروں پر ہاتھ پھیر لو اور پاؤں ٹخنوں تک دھو لیا کرو اگر جنابت کی حالت میں ہو تو نہا کر پاک ہو جاؤ اگر بیمار ہو یا سفر کی حالت میں ہو یا تم میں سے کوئی شخص رفع حاجت کر کے آئے یا تم نے عورتوں کو ہاتھ لگایا ہو، اور پانی نہ ملے، تو پاک مٹی سے کام لو، بس اُس پر ہاتھ مار کر اپنے منہ اور ہاتھوں پر پھیر لیا کرو اللہ تم پر زندگی کو تنگ نہیں کرنا چاہتا، مگر وہ چاہتا ہے کہ تمہیں پاک کرے اور اپنی نعمت تم پر تمام کر دے، شاید کہ تم شکر گزار بنو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dclxxvi{اللہ نے تم کو جو نعمت عطا کی ہے اس کا خیال رکھو اور اُس پختہ عہد و پیمان کو نہ بھولو جو اُس نے تم سے لیا ہے، یعنی تمہارا یہ قول کہ، ``ہم نے سنا اور اطاعت قبول کی" اللہ سے ڈرو، اللہ دلوں کے راز تک جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dclxxvii{اے لوگو جو ایمان لائے ہو! اللہ کی خاطر راستی پر قائم رہنے والے اور انصاف کی گواہی دینے والے بنو کسی گروہ کی دشمنی تم کو اتنا مشتعل نہ کر دے کہ انصاف سے پھر جاؤ عدل کرو، یہ خدا ترسی سے زیادہ مناسبت رکھتا ہے اللہ سے ڈر کر کام کرتے رہو، جو کچھ تم کرتے ہو اللہ اُس سے پوری طرح باخبر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dclxxviii{جو لوگ ایمان لائیں اور نیک عمل کریں، اللہ نے ان سے وعدہ کیا ہے کہ ان کی خطاؤں سے درگزر کیا جائے گا اور انہیں بڑا اجر ملے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dclxxix{رہے وہ لوگ جو کفر کریں اور اللہ کی آیات کو جھٹلائیں، تو وہ دوزخ میں جانے والے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dclxxx{اے لوگو جو ایمان لائے ہو، اللہ کے اُس احسان کو یاد کرو جو اُس نے (ابھی حال میں) تم پر کیا ہے، جبکہ ایک گروہ نے تم پر دست درازی کا ارادہ کر لیا تھا مگر اللہ نے اُن کے ہاتھ تم پر اٹھنے سے روک دیے اللہ سے ڈر کر کام کرتے رہو، ایمان رکھنے والوں کو اللہ ہی پر بھروسہ کرنا چاہیے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dclxxxi{اللہ نے بنی اسرائیل سے پختہ عہد لیا تھا اور ان میں بارہ نقیب مقرر کیے تھے اور ان سے کہا تھا کہ ``میں تمہارے ساتھ ہوں، اگر تم نے نماز قائم رکھی اور زکوٰۃ دی اور میرے رسولوں کو مانا اور ان کی مدد کی اور اپنے خدا کو اچھا قرض دیتے رہے تو یقین رکھو کہ میں تمہاری برائیاں تم سے زائل کر دوں گا اور تم کو ایسے باغوں میں داخل کروں گا جن کے نیچے نہریں بہتی ہوں گی، مگراس کے بعد جس نے تم میں سے کفر کی روش اختیار کی تو در حقیقت اُس نے سوا٫ السبیل گم کر دی"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dclxxxii{پھر یہ اُن کا اپنے عہد کو توڑ ڈالنا تھا جس کی وجہ سے ہم نے ان کو اپنی رحمت سے دور پھینک دیا اور ان کے دل سخت کر دیے اب ان کا حال یہ ہے کہ الفاظ کا الٹ پھیر کر کے بات کو کہیں سے کہیں لے جاتے ہیں، جو تعلیم انہیں دی گئی تھی اُس کا بڑا حصہ بھول چکے ہیں، اور آئے دن تمہیں ان کی کسی نہ کسی خیانت کا پتہ چلتا رہتا ہے ان میں سے بہت کم لوگ اس عیب سے بچے ہوئے ہیں (پس جب یہ اِس حال کو پہنچ چکے ہیں تو جو شرارتیں بھی یہ کریں وہ ان سے عین متوقع ہیں) لہٰذا انہیں معاف کرو اور ان کی حرکات سے چشم پوشی کرتے رہو، اللہ اُن لوگوں کو پسند کرتا ہے جو احسان کی روش رکھتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dclxxxiii{اِسی طرح ہم نے اُن لوگوں سے بھی پختہ عہد لیا تھا جنہوں نے کہا تھا کہ ہم ``نصاریٰ" ہیں، مگر ان کو بھی جو سبق یاد کرایا گیا تھا اس کا ایک بڑا حصہ اُنہوں نے فراموش کر دیا آخر کار ہم نے ان کے درمیان قیامت تک کے لیے دشمنی اور آپس کے بغض و عناد کا بیج بو دیا، اور ضرور ایک وقت آئے گا جب اللہ انہیں بتائے گا کہ وہ دنیا میں کیا بناتے رہے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dclxxxiv{اے اہل کتاب! ہمارا رسول تمہارے پاس آ گیا ہے جو کتاب الٰہی کی بہت سی اُن باتوں کو تمہارے سامنے کھول رہا ہے جن پر تم پردہ ڈالا کرتے تھے، اور بہت سی باتوں سے درگزر بھی کر جاتا ہے تمہارے پاس اللہ کی طرف سے روشنی آ گئی ہے اور ایک ایسی حق نما کتاب\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dclxxxv{جس کے ذریعہ سے اللہ تعالیٰ اُن لوگوں کو جو اس کی رضا کے طالب ہیں سلامتی کے طریقے بتاتا ہے اور اپنے اذن سے اُن کو اندھیروں سے نکال کر اجالے کی طرف لاتا ہے اور راہ راست کی طرف ان کی رہنمائی کرتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dclxxxvi{یقیناً کفر کیا اُن لوگوں نے جنہوں نے کہا مسیح ابن مریم ہی خدا ہے اے محمدؐ! ان سے کہو کہ اگر خدا مسیح ابن مریم کو اور اس کی ماں اور تمام زمین والوں کو ہلاک کر دینا چاہے تو کس کی مجال ہے کہ اُس کو اِس ارادے سے باز رکھ سکے؟ اللہ تو زمین اور آسمانوں کا اور اُن سب چیزوں کا مالک ہے جو زمین اور آسمانوں کے درمیان پائی جاتی ہیں، جو کچھ چاہتا ہے پیدا کرتا ہے اور اس کی قدرت ہر چیز پر حاوی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dclxxxvii{یہود اور نصاریٰ کہتے ہیں کہ ہم اللہ کے بیٹے اور اس کے چہیتے ہیں ان سے پوچھو، پھر وہ تمہارے گناہوں پر تمہیں سزا کیوں دیتا ہے؟ در حقیقت تم بھی ویسے ہی انسان ہو جیسے اور انسان خدا نے پیدا کیے ہیں وہ جسے چاہتا ہے معاف کرتا ہے اور جسے چاہتا ہے سزا دیتا ہے زمین اور آسمان اور ان کی ساری موجودات اس کی مِلک ہیں، اور اسی کی طرف سب کو جانا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dclxxxviii{اے اہل کتاب! ہمارا یہ رسول ایسے وقت تمہارے پاس آیا ہے اور دین کی واضح تعلیم تمہیں دے رہا ہے جبکہ رسولوں کی آمد کا سلسلہ ایک مدت سے بند تھا، تاکہ تم یہ نہ کہہ سکو کہ ہمارے پاس کوئی بشارت دینے والا اور ڈرانے والا نہیں آیا سو دیکھو! اب وہ بشارت دینے اور ڈرانے والا آ گیا اور اللہ ہر چیز پر قادر ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dclxxxix{یاد کرو جب موسیٰؑ نے اپنی قوم سے کہا تھا کہ ``اے میری قوم کے لوگو! اللہ کی اُس نعمت کا خیال کرو جو اس نے تمہیں عطا کی تھی اُس نے تم میں نبی پیدا کیے، تم کو فرماں روا بنایا، اور تم کو وہ کچھ دیا جو دنیا میں کسی کو نہ دیا تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcxc{اے برادران قوم! اس مقدس سرزمین میں داخل ہو جاؤ جو اللہ نے تمہارے لیے لکھ دی ہے، پیچھے نہ ہٹو ورنہ ناکام و نامراد پلٹو گے"\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcxci{انہوں نے جواب دیا ``اے موسیٰؑ! وہاں تو بڑے زبردست لوگ رہتے ہیں، ہم وہاں ہرگز نہ جائیں گے جب تک وہ وہاں سے نکل نہ جائیں ہاں اگر وہ نکل گئے تو ہم داخل ہونے کے لیے تیار ہیں"\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcxcii{اُن ڈرنے والوں میں دو شخص ایسے بھی تھے جن کو اللہ نے اپنی نعمت سے نوازا تھا اُنہوں نے کہا کہ ``ان جباروں کے مقابلہ میں دروازے کے اندر گھس جاؤ، جب تم اندر پہنچ جاؤ گے تو تم ہی غالب رہو گے اللہ پر بھروسہ رکھو اگر تم مومن ہو"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcxciii{لیکن اُنہوں نے پھر یہی کہا کہ ``اے موسیٰؑ! ہم تو وہاں کبھی نہ جائیں گے جب تک وہ وہاں موجود ہیں بس تم اور تمہارا رب، دونوں جاؤ اور لڑو، ہم یہاں بیٹھے ہیں"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcxciv{اس پر موسیٰؑ نے کہا ``اے میرے رب، میرے اختیار میں کوئی نہیں مگر یا میری اپنی ذات یا میرا بھائی، پس تو ہمیں اِن نافرمان لوگوں سے الگ کر دے"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcxcv{اللہ نے جواب دیا ``اچھا تو وہ ملک چالیس سال تک اِن پر حرام ہے، یہ زمین میں مارے مارے پھریں گے، اِن نافرمانوں کی حالت پر ہرگز ترس نہ کھاؤ"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcxcvi{اور ذرا انہیں آدمؑ کے دو بیٹوں کا قصہ بھی بے کم و کاست سنا دو جب اُن دونوں نے قربانی کی تو ان میں سے ایک کی قربانی قبول کی گئی اور دوسرے کی نہ کی گئی اُس نے کہا ``میں تجھے مار ڈالوں گا" اس نے جواب دیا ``اللہ تو متقیوں ہی کی نذریں قبول کرتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcxcvii{اگر تو مجھے قتل کرنے کے لیے ہاتھ اٹھائے گا تو میں تجھے قتل کرنے کے لیے ہاتھ نہ اٹھاؤں گا، میں اللہ رب العالمین سے ڈرتا ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcxcviii{میں چاہتا ہوں کہ میرا اور اپنا گناہ تو ہی سمیٹ لے اور دوزخی بن کر رہے ظالموں کے ظلم کا یہی ٹھیک بدلہ ہے"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcxcix{آخر کار اس کے نفس نے اپنے بھائی کا قتل اس کے لیے آسان کر دیا اور وہ اسے مار کر اُن لوگوں میں شامل ہو گیا جو نقصان اٹھانے والے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcc{پھر اللہ نے ایک کوا بھیجا جو زمین کھودنے لگا تاکہ اُسے بتائے کہ اپنے بھائی کی لاش کیسے چھپائے یہ دیکھ کر وہ بولا افسوس مجھ پر! میں اس کوے جیسا بھی نہ ہوسکا کہ اپنے بھائی کی لاش چھپانے کی تدبیر نکال لیتا اس کے بعد وہ اپنے کیے پر بہت پچھتا یا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcci{اسی وجہ سے بنی اسرائیل پر ہم نے یہ فرمان لکھ دیا تھا کہ ``جس نے کسی انسان کو خون کے بدلے یا زمین میں فساد پھیلانے کے سوا کسی اور وجہ سے قتل کیا اس نے گویا تمام انسانوں کو قتل کر دیا اور جس نے کسی کی جان بچائی اُس نے گویا تمام انسانوں کو زندگی بخش دی" مگر اُن کا حال یہ ہے کہ ہمارے رسول پے در پے ان کے پاس کھلی کھلی ہدایات لے کر آئے پھر بھی ان میں بکثرت لوگ زمین میں زیادتیاں کرنے والے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dccii{جو لوگ اللہ اور اس کے رسول سے لڑتے ہیں اور زمین میں اس لیے تگ و دو کرتے پھرتے ہیں کہ فساد برپا کریں اُن کی سزا یہ ہے کہ قتل کیے جائیں، یا سولی پر چڑھائے جائیں، یا اُن کے ہاتھ اور پاؤں مخالف سمتوں سے کاٹ ڈالے جائیں، یا وہ جلا وطن کر دیے جائیں، یہ ذلت و رسوائی تو اُن کے لیے دنیا میں ہے اور آخرت میں اُن کے لیے اس سے بڑی سزا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcciii{مگر جو لوگ توبہ کر لیں قبل اس کے کہ تم ان پر قابو پاؤ تمہیں معلوم ہونا چاہیے کہ اللہ معاف کرنے والا اور رحم فرمانے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcciv{اے لوگو جو ایمان لائے ہو، اللہ سے ڈرو اور اُس کی جناب میں بار یابی کا ذریعہ تلاش کرو اور اس کی راہ میں جدوجہد کرو، شاید کہ تمہیں کامیابی نصیب ہو جائے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dccv{خوب جان لو کہ جن لوگوں نے کفر کا رویہ اختیار کیا ہے، اگر اُن کے قبضہ میں ساری زمین کی دولت ہو اور اتنی ہی اور اس کے ساتھ، اور وہ چاہیں کہ اسے فدیہ میں دے کر روز قیامت کے عذاب سے بچ جائیں، تب بھی وہ ان سے قبول نہ کی جائے گی اور انہیں درد ناک سزا مل کر رہے گی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dccvi{وہ چاہیں گے کہ دوزخ کی آگ سے نکل بھاگیں مگر نہ نکل سکیں گے اور انہیں قائم رہنے والا عذاب دیا جائے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dccvii{اور چور، خواہ عورت ہو یا مرد، دونوں کے ہاتھ کاٹ دو، یہ اُن کی کمائی کا بدلہ ہے اور اللہ کی طرف سے عبرتناک سزا اللہ کی قدرت سب پر غالب ہے اور وہ دانا و بینا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dccviii{پھر جو ظلم کرنے کے بعد توبہ کرے اور اپنی اصلاح کر لے تو اللہ کی نظر عنایت پھر اس پر مائل ہو جائے گی، اللہ بہت درگزر کرنے والا اور رحم فرمانے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dccix{کیا تم جانتے نہیں ہو کہ اللہ زمین اور آسمانوں کی سلطنت کا مالک ہے؟ جسے چاہے سزا دے اور جسے چاہے معاف کر دے، وہ ہر چیز کا اختیار رکھتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dccx{اے پیغمبرؐ! تمہارے لیے باعث رنج نہ ہوں وہ لوگ جو کفر کی راہ میں بڑی تیز گامی دکھا رہے ہیں خواہ وہ اُن میں سے ہوں جو منہ سے کہتے ہیں ہم ایمان لائے مگر دل اُن کے ایمان نہیں لائے، یا اُن میں سے ہوں جو یہودی بن گئے ہیں، جن کا حال یہ ہے کہ جھوٹ کے لیے کان لگاتے ہیں، اور دوسرے لوگوں کی خاطر، جو تمہارے پاس کبھی نہیں آئے، سن گن لیتے پھرتے ہیں، کتاب اللہ کے الفاظ کو اُن کا صحیح محل متعین ہونے کے باوجود اصل معنی سے پھیرتے ہیں، اور لوگوں سے کہتے ہیں کہ اگر تمہیں یہ حکم دیا جائے تو مانو نہیں تو نہ مانو جسے اللہ ہی نے فتنہ میں ڈالنے کا ارادہ کر لیا ہو تو اس کو اللہ کی گرفت سے بچانے کے لیے تم کچھ نہیں کرسکتے، یہ وہ لوگ ہیں جن کے دلوں کو اللہ نے پاک کرنا نہ چاہا، ان کے لیے دنیا میں رسوائی ہے اور آخرت میں سخت سزا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dccxi{یہ جھوٹ سننے والے اور حرام کے مال کھانے والے ہیں، لہٰذا اگر یہ تمہارے پاس (اپنے مقدمات لے کر) آئیں تو تمہیں اختیار دیا جاتا ہے کہ چاہو ان کا فیصلہ کرو ورنہ انکار کر دو انکار کر دو تو یہ تمہارا کچھ بگاڑ نہیں سکتے، اور فیصلہ کرو تو پھر ٹھیک ٹھیک انصاف کے ساتھ کرو کہ اللہ انصاف کرنے والوں کو پسند کرتا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dccxii{اور یہ تمہیں کیسے حَکم بناتے ہیں جبکہ ان کے پاس توراۃ موجود ہے جس میں اللہ کا حکم لکھا ہوا ہے اور پھر یہ اس سے منہ موڑ رہے ہیں؟ اصل بات یہ ہے کہ یہ لوگ ایمان ہی نہیں رکھتے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dccxiii{ہم نے توراۃ نازل کی جس میں ہدایت اور روشنی تھی سارے نبی، جو مسلم تھے، اُسی کے مطابق اِن یہودی بن جانے والوں کے معاملات کا فیصلہ کرتے تھے، اور اِسی طرح ربانی اور احبار بھی (اسی پر فیصلہ کا مدار رکھتے تھے) کیونکہ انہیں کتاب اللہ کی حفاظت کا ذمہ دار بنایا گیا تھا اور وہ اس پر گواہ تھے پس (اے گروہ یہود!) تم لوگوں سے نہ ڈرو بلکہ مجھ سے ڈرو اور میری آیات کو ذرا ذرا سے معاوضے لے کر بیچنا چھوڑ دو جو لوگ اللہ کے نازل کردہ قانون کے مطابق فیصلہ نہ کریں وہی کافر ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dccxiv{توراۃ میں ہم نے یہودیوں پر یہ حکم لکھ دیا تھا کہ جان کے بدلے جان، آنکھ کے بدلے آنکھ، ناک کے بدلے ناک، کان کے بدلے کان، دانت کے بدلے دانت، اور تمام زخموں کے لیے برابر کا بدلہ پھر جو قصاص کا صدقہ کر دے تو وہ اس کے لیے کفارہ ہے اور جو لوگ اللہ کے نازل کردہ قانون کے مطابق فیصلہ نہ کریں وہی ظالم ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dccxv{پھر ہم نے ان پیغمبروں کے بعد مریمؑ کے بیٹے عیسیٰؑ کو بھیجا توراۃ میں سے جو کچھ اس کے سامنے موجود تھا وہ اس کی تصدیق کرنے والا تھا اور ہم نے اس کو انجیل عطا کی جس میں رہنمائی اور روشنی تھی اور وہ بھی توراۃ میں سے جو کچھ اُس وقت موجود تھا اُس کی تصدیق کرنے والی تھی اور خدا ترس لوگوں کے لیے سراسر ہدایت اور نصیحت تھی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dccxvi{ہمارا حکم تھا کہ اہل انجیل اس قانون کے مطابق فیصلہ کریں جو اللہ نے اس میں نازل کیا ہے اور جو لوگ اللہ کے نازل کردہ قانون کے مطابق فیصلہ نہ کریں وہی فاسق ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dccxvii{پھر اے محمدؐ! ہم نے تمہاری طرف یہ کتاب بھیجی جو حق لے کر آئی ہے اور الکتاب میں سے جو کچھ اس کے آگے موجود ہے اُس کی تصدیق کرنے والی اور اس کی محافظ و نگہبان ہے لہٰذا تم خدا کے نازل کردہ قانون کے مطابق لوگوں کے معاملات کا فیصلہ کرو اور جو حق تمہارے پاس آیا ہے اُس سے منہ موڑ کر ان کی خواہشات کی پیروی نہ کرو ہم نے تم میں سے ہر ایک کے لیے ایک شریعت اور ایک راہ عمل مقرر کی اگرچہ تمہارا خدا چاہتا تو تم سب کو ایک امت بھی بنا سکتا تھا، لیکن اُس نے یہ اِس لیے کیا کہ جو کچھ اُس نے تم لوگوں کو دیا ہے اس میں تمہاری آزمائش کرے لہٰذا بھلائیوں میں ایک دوسرے سے سبقت لے جانے کی کوشش کرو آخر کار تم سب کو خدا کی طرف پلٹ کر جانا ہے، پھر وہ تمہیں اصل حقیقت بتا دے گا جس میں تم اختلاف کرتے رہے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dccxviii{پس اے محمدؐ! تم اللہ کے نازل کردہ قانون کے مطابق اِن لوگوں کے معاملات کا فیصلہ کرو اور ان کی خواہشات کی پیروی نہ کرو ہوشیار رہو کہ یہ لوگ تم کو فتنہ میں ڈال کر اُس ہدایت سے ذرہ برابر منحرف نہ کرنے پائیں جو خدا نے تمہاری طرف نازل کی ہے پھر اگر یہ اس سے منہ موڑیں تو جان لو کہ اللہ نے اِن کے بعض گناہوں کی پاداش میں ان کو مبتلائے مصیبت کرنے کا ارادہ ہی کر لیا ہے، اور یہ حقیقت ہے کہ اِن لوگوں میں سے اکثر فاسق ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dccxix{(اگر یہ خدا کے قانون سے منہ موڑتے ہیں) تو کیا پھر جاہلیت کا فیصلہ چاہتے ہیں؟ حالانکہ جو لوگ اللہ پر یقین رکھتے ہیں ان کے نزدیک اللہ سے بہتر فیصلہ کرنے والا کوئی نہیں ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dccxx{اے لوگو جو ایمان لائے ہو! یہودیوں اور عیسائیوں کو اپنا رفیق نہ بناؤ، یہ آپس ہی میں ایک دوسرے کے رفیق ہیں اور اگر تم میں سے کوئی ان کو اپنا رفیق بناتا ہے تو اس کا شمار بھی پھر انہی میں ہے، یقیناً اللہ ظالموں کو اپنی رہنمائی سے محروم کر دیتا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dccxxi{تم دیکھتے ہو کہ جن کے دلوں میں نفاق کی بیماری ہے وہ اُنہی میں دوڑ دھوپ کرتے پھرتے ہیں کہتے ہیں ``ہمیں ڈر لگتا ہے کہ کہیں ہم کسی مصیبت کے چکر میں نہ پھنس جائیں" مگر بعید نہیں کہ اللہ جب تمہیں فیصلہ کن فتح بخشے گا یا اپنی طرف سے کوئی اور بات ظاہر کرے گا تو یہ لوگ اپنے اِس نفاق پر جسے یہ دلوں میں چھپائے ہوئے ہیں نادم ہوں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dccxxii{اور اُس وقت اہل ایمان کہیں گے ``کیا یہ وہی لوگ ہیں جو اللہ کے نام سے کڑی کڑی قسمیں کھا کر یقین دلاتے تھے کہ ہم تمہارے ساتھ ہیں؟" ان کے سب اعمال ضائع ہوگئے اور آخر کار یہ ناکام و نامراد ہو کر رہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dccxxiii{اے لوگو جو ایمان لائے ہو، اگر تم میں سے کوئی اپنے دین سے پھرتا ہے (تو پھر جائے) اللہ اور بہت سے لوگ ایسے پیدا کر دے گا جو اللہ کو محبوب ہوں گے اور اللہ اُن کو محبوب ہوگا، جو مومنوں پر نرم اور کفار پر سخت ہوں گے، جو اللہ کی راہ میں جدوجہد کریں گے اور کسی ملامت کرنے والے کی ملامت سے نہ ڈریں گے یہ اللہ کا فضل ہے، جسے چاہتا ہے عطا کرتا ہے اللہ وسیع ذرائع کا مالک ہے اور سب کچھ جانتا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dccxxiv{تمہارے رفیق تو حقیقت میں صرف اللہ اور اللہ کا رسول اور وہ اہل ایمان ہیں جو نماز قائم کرتے ہیں، زکوٰۃ دیتے ہیں اور اللہ کے آگے جھکنے والے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dccxxv{اور جو اللہ اور اس کے رسول اور اہل ایمان کو اپنا رفیق بنا لے اُسے معلوم ہو کہ اللہ کی جماعت ہی غالب رہنے والی ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dccxxvi{ا ے لوگو جو ایمان لائے ہو، تمہارے پیش رو اہل کتاب میں سے جن لوگوں نے تمہارے دین کو مذاق اور تفریح کا سامان بنا لیا ہے، اُنہیں اور دوسرے کافروں کو اپنا دوست اور رفیق نہ بناؤ اللہ سے ڈرو اگر تم مومن ہو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dccxxvii{جب تم نماز کے لیے منادی کرتے ہو تو وہ اس کا مذاق اڑاتے اور اس سے کھیلتے ہیں اس کی وجہ یہ ہے کہ وہ عقل نہیں رکھتے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dccxxviii{اِن سے کہو، ``اے اہل کتاب! تم جس بات پر ہم سے بگڑے ہو وہ اس کے سوا اور کیا ہے کہ ہم اللہ پر اور دین کی اُس تعلیم پر ایمان لے آئے ہیں جو ہماری طرف نازل ہوئی ہے اور ہم سے پہلے بھی نازل ہوئی تھی، اور تم میں سے اکثر لوگ فاسق ہیں؟"\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dccxxix{پھر کہو ``کیا میں اُن لوگوں کی نشاندہی کروں جن کا انجام خدا کے ہاں فاسقوں کے انجام سے بھی بدتر ہے؟ وہ جن پر خدا نے لعنت کی، جن پر اُس کا غضب ٹوٹا، جن میں سے بندر اور سور بنائے گئے، جنہوں نے طاغوت کی بندگی کی ان کا درجہ اور بھی زیادہ برا ہے اور وہ سَوَا٫ السّبیل سے بہت زیادہ بھٹکے ہوئے ہیں"\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dccxxx{جب یہ تم لوگوں کے پاس آتے ہیں تو کہتے ہیں کہ ہم ایمان لائے، حالانکہ کفر لیے ہوئے آئے تھے اور کفر ہی لیے ہوئے واپس گئے اور اللہ خوب جانتا ہے جو کچھ یہ دلوں میں چھپائے ہوئے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dccxxxi{تم دیکھتے ہو کہ ان میں سے بکثرت لوگ گناہ اور ظلم و زیادتی کے کاموں میں دوڑ دھوپ کرتے پھرتے ہیں اور حرام کے مال کھاتے ہیں بہت بری حرکات ہیں جو یہ کر رہے ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccxxxii{کیوں اِن کے عُلما٫ اور مشائخ انہیں گناہ پر زبان کھولنے اور حرام کھانے سے نہیں روکتے؟ یقیناً بہت ہی برا کارنامہ زندگی ہے جو وہ تیار کر رہے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dccxxxiii{یہودی کہتے ہیں اللہ کے ہاتھ بندھے ہوئے ہیں باندھے گئے ان کے ہاتھ، اور لعنت پڑی اِن پر اُس بکواس کی بدولت جو یہ کرتے ہیں اللہ کے ہاتھ تو کشادہ ہیں، جس طرح چاہتا ہے خرچ کرتا ہے حقیقت یہ ہے کہ جو کلام تمہارے رب کی طرف سے تم پر نازل ہوا ہے وہ ان میں سے اکثر لوگوں کی سرکشی و باطل پرستی میں الٹے اضافہ کا موجب بن گیا ہے، اور (اس کی پاداش میں) ہم نے ان کے درمیان قیامت تک کے لیے عداوت اور دشمنی ڈال دی ہے جب کبھی یہ جنگ کی آگ بھڑکاتے ہیں اللہ اُس کو ٹھنڈا کر دیتا ہے یہ زمین میں فساد پھیلانے کی سعی کر رہے ہیں مگر اللہ فساد برپا کرنے والوں کو ہرگز پسند نہیں کرتا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dccxxxiv{اگر (اِس سرکشی کے بجائے) یہ اہل کتاب ایمان لے آتے اور خدا ترسی کی روش اختیار کرتے تو ہم اِن کی برائیاں اِن سے دور کر دیتے اور ان کو نعمت بھری جنتوں میں پہنچاتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccxxxv{کاش انہوں نے توراۃ اور انجیل اور اُن دوسری کتابوں کو قائم کیا ہوتا جو اِن کے رب کی طرف سے اِن کے پاس بھیجی گئی تھیں ایسا کرتے تو اِن کے لیے اوپر سے رزق برستا اور نیچے سے ابلتا اگرچہ اِن میں کچھ لوگ راست رو بھی ہیں لیکن ان کی اکثریت سخت بد عمل ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccxxxvi{اے پیغمبرؐ! جو کچھ تمہارے رب کی طرف سے تم پر نازل کیا گیا ہے وہ لوگوں تک پہنچا دو اگر تم نے ایسا نہ کیا تو اس کی پیغمبری کا حق ادا نہ کیا اللہ تم کو لوگوں کے شر سے بچانے والا ہے یقین رکھو کہ وہ کافروں کو (تمہارے مقابلہ میں) کامیابی کی راہ ہرگز نہ دکھائے گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccxxxvii{صاف کہہ دو کہ ``اے اہل کتاب! تم ہرگز کسی اصل پر نہیں ہو جب تک کہ توراۃ اور انجیل اور اُن دوسری کتابوں کو قائم نہ کرو جو تمہارے رب کی طرف سے نازل کی گئی ہیں" ضرور ہے کہ یہ فرمان جو تم پر نازل کیا گیا ہے ان میں سے اکثر کی سرکشی اور انکار کو اور زیادہ بڑھا دے گا مگر انکار کرنے والوں کے حال پر کچھ افسوس نہ کرو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccxxxviii{(یقین جانو کہ یہاں اجارہ کسی کا بھی نہیں ہے) مسلمان ہو ں یا یہودی، صابی ہو ں یا عیسائی، جو بھی اللہ اور روز آخر پر ایمان لائے گا اور نیک عمل کرے گا بے شک اس کے لیے نہ کسی خوف کا مقام ہے نہ رنج کا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccxxxix{ہم نے بنی اسرائیل سے پختہ عہد لیا اور اُن کی طرف بہت سے رسول بھیجے، مگر جب کبھی ان کے پاس کوئی رسول اُن کی خواہشات نفس کے خلاف کچھ لے کر آیا تو کسی کو انہوں نے جھٹلایا اور کسی کو قتل کر دیا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccxl{اور اپنے نزدیک یہ سمجھے کہ کوئی فتنہ رونما نہ ہوگا، اس لیے اندھے اور بہرے بن گئے پھر اللہ نے اُنہیں معاف کیا تو اُن میں سے اکثر لوگ اور زیادہ اندھے اور بہرے بنتے چلے گئے اللہ اُن کی یہ سب حرکات دیکھتا رہا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccxli{یقیناً کفر کیا اُن لوگوں نے جنہوں نے کہا کہ اللہ مسیح ابن مریم ہی ہے حالانکہ مسیح نے کہا تھا کہ ``اے بنی اسرائیل! اللہ کی بندگی کرو جو میرا رب بھی ہے اور تمہارا رب بھی" جس نے اللہ کے ساتھ کسی کو شریک ٹھیرایا اُس پر اللہ نے جنت حرام کر دی اور اُس کا ٹھکانا جہنم ہے اور ایسے ظالموں کا کوئی مدد گار نہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccxlii{یقیناً کفر کیا اُن لوگوں نے جنہوں نے کہا کہ اللہ تین میں کا ایک ہے، حالانکہ ایک خدا کے سوا کوئی خدا نہیں ہے اگر یہ لوگ اپنی اِن باتوں سے باز نہ آئے تو ان میں سے جس جس نے کفر کیا ہے اُس کو درد ناک سزا دی جائے گی\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccxliii{پھر کیا یہ اللہ سے توبہ نہ کریں گے اور اس سے معافی نہ مانگیں گے؟ اللہ بہت درگزر فرمانے والا اور رحم کرنے والا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccxliv{مسیح ابن مریمؑ اِس کے سوا کچھ نہیں کہ بس ایک رسول تھا، اُس سے پہلے اور بھی بہت سے رسول گزر چکے تھے، اس کی ماں ایک راستباز عورت تھی، اور وہ دونوں کھانا کھاتے تھے، دیکھو ہم کس طرح ان کے سامنے حقیقت کی نشانیاں واضح کرتے ہیں، پھر دیکھو یہ کدھر الٹے پھر ے جاتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccxlv{اِن سے کہو، کیا تم اللہ کو چھوڑ کر اُس کی پرستش کرتے ہو جو نہ تمہارے لیے نقصان کا اختیار رکھتا ہے نہ نفع کا؟ حالانکہ سب کی سننے والا اور سب کچھ جاننے والا تو اللہ ہی ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccxlvi{کہو، اے اہل کتاب! اپنے دین میں ناحق غلو نہ کرو اور اُ ن لوگوں کے تخیلات کی پیروی نہ کرو جو تم سے پہلے خود گمراہ ہوئے اور بہتوں کو گمراہ کیا، اور ``سَوَا٫ السّبیل" سے بھٹک گئے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccxlvii{بنی اسرائیل میں سے جن لوگوں نے کفر کی راہ اختیار کی اُن پر داؤدؑ اور عیسیٰ ابن مریمؑ کی زبان سے لعنت کی گئی کیونکہ وہ سرکش ہوگئے تھے اور زیادتیاں کرنے لگے تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccxlviii{اُنہوں نے ایک دوسرے کو برے افعال کے ارتکاب سے روکنا چھوڑ دیا تھا، برا طرز عمل تھا جو اُنہوں نے اختیار کیا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccxlix{آج تم اُن میں بکثرت ایسے لوگ دیکھتے ہو جو (اہل ایمان کے مقابلہ میں) کفار کی حمایت و رفاقت کرتے ہیں یقیناً بہت برا انجام ہے جس کی تیاری اُن کے نفسوں نے اُن کے لیے کی ہے، اللہ اُن پر غضب ناک ہو گیا ہے اور وہ دائمی عذاب میں مبتلا ہونے والے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccl{اگر فی الواقع یہ لوگ اللہ اور پیغمبرؐ اور اُس چیز کے ماننے والے ہوتے جو پیغمبر پر نازل ہوئی تھی تو کبھی (اہل ایمان کے مقابلے میں) کافروں کو اپنا رفیق نہ بناتے مگر ان میں سے تو بیشتر لوگ خدا کی اطاعت سے نکل چکے ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccli{تم اہل ایمان کی عداوت میں سب سے زیادہ سخت یہود اور مشرکین کو پاؤ گے، اور ایمان لانے والوں کے لیے دوستی میں قریب تر اُن لوگوں کو پا ؤ گے جنہوں نے کہا تھا کہ ہم نصاریٰ ہیں یہ اِس وجہ سے کہ ان میں عبادت گزار عالم اور تارک الدنیا فقیر پائے جاتے ہیں اور اُن میں غرور نفس نہیں ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dcclii{جب وہ اس کلام کو سنتے ہیں جو رسول پر اترا ہے تو تم دیکھتے ہو کہ حق شناسی کے اثر سے اُن کی آنکھیں آنسوؤں سے تر ہو جاتی ہیں وہ بول اٹھتے ہیں کہ ``پروردگار! ہم ایمان لائے، ہمارا نام گواہی دینے والوں میں لکھ لے"\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccliii{اور وہ کہتے ہیں کہ ``آخر کیوں نہ ہم اللہ پر ایمان لائیں اور جو حق ہمارے پاس آیا ہے اُسے کیوں نہ مان لیں جبکہ ہم اِس بات کی خواہش رکھتے ہیں کہ ہمارا رب ہمیں صالح لوگوں میں شامل کرے؟"\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccliv{اُن کے اِس قول کی وجہ سے اللہ نے اُن کو ایسی جنتیں عطا کیں جن کے نیچے نہریں بہتی ہیں اور وہ ان میں ہمیشہ رہیں گے یہ جزا ہے نیک رویہ اختیار کرنے والوں کے لیے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dcclv{رہے وہ لوگ جنہوں نے ہماری آیات کو ماننے سے انکار کیا اور انہیں جھٹلایا، تو وہ جہنم کے مستحق ہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dcclvi{اے لوگو جو ایمان لائے ہو، جو پاک چیزیں اللہ نے تمہارے لیے حلال کی ہیں انہیں حرام نہ کر لو اور حد سے تجاوز نہ کرو، اللہ کو زیادتی کرنے والے سخت ناپسند ہیں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dcclvii{جو کچھ حلال و طیب رزق اللہ نے تم کو دیا ہے اُسے کھا ؤ پیو اور اُس خدا کی نافرمانی سے بچتے رہو جس پر تم ایمان لائے ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dcclviii{تم لوگ جو مہمل قسمیں کھا لیتے ہو اُن پر اللہ گرفت نہیں کرتا، مگر جو قسمیں تم جان بوجھ کر کھاتے ہو اُن پر ضرور تم سے مواخذہ کرے گا (ایسی قسم توڑنے کا) کفارہ یہ ہے کہ دس مسکینوں کو وہ اوسط درجے کا کھانا کھلاؤ جو تم اپنے بال بچوں کو کھلاتے ہو، یا انہیں کپڑے پہناؤ، یا ایک غلام آزاد کرو، اور جو اس کی استطاعت نہ رکھتا ہو وہ تین دن کے روزے رکھے یہ تمہاری قسموں کا کفارہ ہے جبکہ تم قسم کھا کر توڑ دو اپنی قسموں کی حفاظت کیا کرو اس طرح اللہ اپنے احکام تمہارے لیے واضح کرتا ہے شاید کہ تم شکر ادا کرو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dcclix{اے لوگو جو ایمان لائے ہو، یہ شراب اور جوا اور یہ آستانے اور پانسے، یہ سب گندے شیطانی کام ہیں، ان سے پرہیز کرو، امید ہے کہ تمہیں فلاح نصیب ہوگی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dcclx{شیطان تو یہ چاہتا ہے کہ شراب اور جوئے کے ذریعہ سے تمہارے درمیان عداوت اور بغض ڈال دے اور تمہیں خدا کی یاد سے اور نماز سے روک دے پھر کیا تم ان چیزوں سے باز رہو گے؟\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dcclxi{اللہ اور اُس کے رسول کی بات مانو اور باز آ جاؤ، لیکن اگر تم نے حکم عدولی کی تو جان لو کہ ہمارے رسول پر بس صاف صاف حکم پہنچا دینے کی ذمہ داری تھی\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dcclxii{جو لوگ ایمان لے آئے اور نیک عمل کرنے لگے انہوں نے پہلے جو کچھ کھایا پیا تھا اس پر کوئی گرفت نہ ہوگی بشرطیکہ وہ آئندہ اُن چیزوں سے بچے رہیں جو حرام کی گئی ہیں اور ایمان پر ثابت قدم رہیں اور اچھے کام کریں، پھر جس جس چیز سے روکا جائے اس سے رکیں اور جو فرمان الٰہی ہو اُسے مانیں، پھر خدا ترسی کے ساتھ نیک رویہ رکھیں اللہ نیک کردار لوگوں کو پسند کرتا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dcclxiii{اے لوگو جو ایمان لائے ہو، اللہ تمہیں اُس شکار کے ذریعہ سے سخت آزمائش میں ڈالے گا جو بالکل تمہارے ہاتھوں اور نیزوں کی زد میں ہوگا، یہ دیکھنے کے لیے کہ تم میں سے کون اس سے غائبانہ ڈرتا ہے، پھر جس نے اس تنبیہ کے بعد اللہ کی مقرر کی ہوئی حد سے تجاوز کیا اُس کے لیے درد ناک سزا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dcclxiv{اے لوگو جو ایمان لائے ہو! احرام کی حالت میں شکار نہ مارو، اور اگر تم میں سے کوئی جان بوجھ کر ایسا کر گزرے تو جو جانور اس نے مارا ہو اُسی کے ہم پلہ ایک جانور اُسے مویشیوں میں سے نذر دینا ہوگا جس کا فیصلہ تم میں سے دو عادل آدمی کریں گے، اور یہ نذرانہ کعبہ پہنچایا جائے گا، یا نہیں تو اِس گناہ کے کفارہ میں چند مسکینوں کو کھانا کھلانا ہوگا، یااس کے بقدر روزے رکھنے ہوں گے، تاکہ وہ اپنے کیے کا مزہ چکھے پہلے جو ہو چکا اُسے اللہ نے معاف کر دیا، لیکن اب اگر کسی نے اس حرکت کا اعادہ کیا تو اس سے اللہ بدلہ لے گا، اللہ سب پر غالب ہے اور بدلہ لینے کی طاقت رکھتا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dcclxv{تمہارے لیے سمندر کا شکار اور اس کا کھانا حلال کر دیا گیا، جہاں تم ٹھیرو وہاں بھی اُسے کھا سکتے ہو اور قافلے کے لیے زاد راہ بھی بناسکتے ہو البتہ خشکی کا شکار جب تک احرام کی حالت میں ہو، تم پر حرام کیا گیا ہے پس بچو اُس خدا کی نافرمانی سے جس کی پیشی میں تم سب کو گھیر کر حاضر کیا جائے گا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dcclxvi{اللہ نے مکان محترم، کعبہ کو لوگوں کے لیے (اجتماعی زندگی کے) قیام کا ذریعہ بنایا اور ماہ حرام اور قربانی کے جانوروں اور قلادوں کو بھی (اِس کام میں معاون بنا دیا) تاکہ تمہیں معلوم ہو جائے کہ اللہ آسمانوں او ر زمین کے سب حالات سے باخبر ہے اور اُسے ہر چیز کا علم ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dcclxvii{خبردار ہو جاؤ! اللہ سزا دینے میں بھی سخت ہے اور اس کے ساتھ بہت درگزر اور رحم بھی کرنے والا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dcclxviii{رسول پر تو صرف پیغام پہنچا دینے کی ذمہ داری ہے، آگے تمہارے کھلے اور چھپے سب حالات کا جاننے والا اللہ ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dcclxix{اے پیغمبرؐ! اِن سے کہہ دو کہ پاک اور ناپاک بہر حال یکساں نہیں ہیں خواہ ناپاک کی بہتا ت تمہیں کتنا ہی فریفتہ کرنے والی ہو، پس اے لوگو جو عقل رکھتے ہو! اللہ کی نافرمانی سے بچتے رہو، امید ہے کہ تمہیں فلاح نصیب ہوگی\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcclxx{اے لوگو جو ایمان لائے ہو، ایسی باتیں نہ پوچھا کرو جو تم پر ظاہر کر دی جائیں تو تمہیں ناگوار ہوں، لیکن اگر تم انہیں ایسے وقت پوچھو گے جب کہ قرآن نازل ہو رہا ہو تو وہ تم پر کھول دی جائیں گی اب تک جو کچھ تم نے کیا اُسے اللہ نے معاف کر دیا، وہ درگزر کرنے والا اور برد بار ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcclxxi{تم سے پہلے ایک گروہ نے اِسی قسم کے سوالات کیے تھے، پھر وہ لوگ انہی باتوں کی وجہ سے کفر میں مبتلا ہوگئے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcclxxii{اللہ نے نہ کوئی بَحِیرہ مقرر کیا ہے نہ سائبہ اور نہ وصیلہ اور نہ حام مگر یہ کافر اللہ پر جھوٹی تہمت لگاتے ہیں اور ان میں سے اکثر بے عقل ہیں (کہ ایسے وہمیات کو مان رہے ہیں)\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcclxxiii{اور جب ان سے کہا جاتا ہے کہ آؤ اُس قانون کی طرف جو اللہ نے نازل کیا ہے اور آؤ پیغمبرؐ کی طرف تو وہ جواب دیتے ہیں کہ ہمارے لیے تو بس وہی طریقہ کافی ہے جس پر ہم نے اپنے باپ دادا کو پایا ہے کیا یہ باپ دادا ہی کی تقلید کیے چلے جائیں گے خواہ وہ کچھ نہ جانتے ہوں اور صحیح راستہ کی انہیں خبر ہی نہ ہو؟\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcclxxiv{اے لوگو جو ایمان لائے ہو، اپنی فکر کرو، کسی دوسرے کی گمراہی سے تمہارا کچھ نہیں بگڑتا اگر تم خود راہ راست پر ہو، اللہ کی طرف تم سب کو پلٹ کر جانا ہے، پھر وہ تمہیں بتا دے گا کہ تم کیا کرتے رہے ہو\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcclxxv{اے لوگو جو ایمان لائے ہو، جب تم میں سے کسی کی موت کا وقت آ جائے اور وہ وصیت کر رہا ہو تو اس کے لیے شہادت کا نصاب یہ ہے کہ تمہاری جماعت میں سے دو صاحب عدل آدمی گواہ بنائے جائیں، یا اگر تم سفر کی حالت میں ہو اور وہاں موت کی مصیبت پیش آ جائے تو غیر مسلموں ہی میں سے دو گواہ لے لیے جائں پھر اگر کوئی شک پڑ جائے تو نماز کے بعد دونوں گواہوں کو (مسجد میں) روک لیا جائے اور وہ خدا کی قسم کھا کر کہیں کہ ``ہم کسی ذاتی فائدے کے عوض شہادت بیچنے والے نہیں ہیں، اور خواہ کوئی ہمارا رشتہ دار ہی کیوں نہ ہو (ہم اس کی رعایت کرنے والے نہیں) اور نہ خدا واسطے کی گواہی کو ہم چھپانے والے ہیں، اگر ہم نے یسا کیا تو گناہ گاروں میں شمار ہوں گے"\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcclxxvi{لیکن اگر پتہ چل جائے کہ ان دونوں نے اپنے آپ کو گناہ میں مبتلا کیا ہے تو پھر ان کی جگہ دو اور شخص جو ان کی بہ نسبت شہادت دینے کے لیے اہل تر ہوں ان لوگوں میں سے کھڑے ہوں جن کی حق تلفی ہوئی ہو، اور وہ خدا کی قسم کھا کر کہیں کہ ``ہماری شہادت اُن کی شہادت سے زیادہ بر حق ہے اور ہم نے اپنے گواہی میں کوئی زیادتی نہیں کی ہے، اگر ہم ایسا کریں تو ظالموں میں سے ہوں گے"\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcclxxvii{اس طریقہ سے زیادہ توقع کی جاسکتی ہے کہ لوگ ٹھیک ٹھیک شہادت دیں گے، یا کم از کم اس بات ہی کا خوف کریں گے کہ ان کی قسموں کے بعد ددسری قسموں سے کہیں ان کی تردید نہ ہو جائے اللہ سے ڈرو اور سنو، اللہ نافرمانی کرنے والوں کو اپنی رہنمائی سے محروم کر دیتا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcclxxviii{جس روز اللہ سب رسولوں کو جمع کر کے پو چھے گا کہ تمہیں کیا جواب دیا گیا ہے، تو وہ عرض کریں گے کہ ہمیں کچھ علم نہیں، آپ ہی تمام پوشیدہ حقیقتوں کو جانتے ہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcclxxix{پھر تصور کرو اس موقع کا جب اللہ فرمائے گا کہ ``اے مریم کے بیٹے عیسیٰؑ! یاد کر میری اس نعمت کو جو میں نے تجھے اور تیری ماں کو عطا کی تھی، میں نے روح پاک سے تیری مدد کی، تو گہوارے میں بھی لوگوں سے بات کرتا تھا اور بڑی عمر کو پہنچ کر بھی، میں نے تجھ کو کتاب اور حکمت اور تورات اور انجیل کی تعلیم دی، تو میرے حکم سے مٹی کا پتلا پرندے کی شکل کا بناتا اور اس میں پھونکتا تھا اور وہ میرے حکم سے پرندہ بن جاتا تھا، تو مادر زاد اندھے اور کوڑھی کو میرے حکم سے اچھا کرتا تھا، تو مُردوں کو میرے حکم سے نکالتا تھا، پھر جب تو بنی اسرائیل کے پاس صریح نشانیاں لے کر پہنچا اور جو لوگ ان میں سے منکر حق تھے انہوں نے کہا کہ یہ نشانیاں جادو گری کے سوا اور کچھ نہیں ہیں تو میں نے ہی تجھے اُن سے بچایا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dcclxxx{اور جب میں نے حواریوں کو اشارہ کیا کہ مجھ پر اور میرے رسول پر ایمان لاؤ تب اُنہوں نے کہا کہ ``ہم ایمان لائے اور گواہ رہو کہ ہم مسلم ہیں"\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcclxxxi{(حواریوں کے سلسلہ میں) یہ واقعہ بھی یاد رہے کہ جب حواریوں نے کہا اے عیسیٰ ابن مریم! کیا آپ کا رب ہم پر آسمان سے کھانے کا ایک خوان اتار سکتا ہے؟ تو عیسیٰؑ نے کہا اللہ سے ڈرو اگر تم مومن ہو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcclxxxii{اُنہوں نے کہا ہم بس یہ چاہتے ہیں کہ اس خوان سے کھانا کھائیں اور ہمارے دل مطمئن ہوں اور ہمیں معلوم ہو جائے کہ آپ نے جو کچھ ہم سے کہا ہے وہ سچ ہے اور ہم اس پر گواہ ہوں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiii{اس پر عیسیٰ ابن مریم نے دعا کی ``خدایا! ہمارے رب! ہم پر آسمان سے ایک خوان نازل کر جو ہمارے لیے اور ہمارے اگلوں پچھلوں کے لیے خوشی کا موقع قرار پائے اور تیری طرف سے ایک نشانی ہو، ہم کو رزق دے اور تو بہترین رازق ہے"\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiv{اللہ نے جواب دیا ``میں اُس کو تم پر نازل کرنے والا ہو ں، مگر اس کے بعد جو تم میں سے کفر کرے گا اسے میں ایسی سزا دوں گا جو دنیا میں کسی کو نہ دی ہوگی"\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcclxxxv{غرض جب (یہ احسانات یاد دلا کر) اللہ فرمائے گا کہ ``اے عیسیٰ ابن مریم! کیا تو نے لوگوں سے کہا تھا کہ خدا کے سوا مجھے اور میری ماں کو بھی خدا بنا لو؟" تو وہ جواب میں عرض کرے گا کہ ``سبحان اللہ! میرا یہ کام نہ تھا کہ وہ بات کہتا جس کے کہنے کا مجھے حق نہ تھا، اگر میں نے ایسی بات کہی ہوتی، تو آپ کو ضرور علم ہوتا، آپ جانتے ہیں جو کچھ میرے دل میں ہے اور میں نہیں جانتا جو کچھ آپ کے دل میں ہے، آپ تو ساری پوشیدہ حقیقتوں کے عالم ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvi{میں نے اُن سے اُس کے سوا کچھ نہیں کہا جس کا آپ نے حکم دیا تھا، یہ کہ اللہ کی بندگی کرو جو میرا رب بھی ہے اور تمہارا رب بھی میں اُسی وقت تک ان کا نگراں تھا جب تک کہ میں ان کے درمیان تھا جب آپ نے مجھے واپس بلا لیا تو آپ ان پر نگراں تھے اور آپ تو ساری ہی چیزوں پر نگراں ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvii{اب اگر آپ انہیں سزا دیں تو وہ آپ کے بندے ہیں اور اگر معاف کر دیں تو آپ غالب اور دانا ہیں"\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcclxxxviii{تب اللہ فرمائے گا ``یہ وہ دن ہے جس میں سچوں کو اُن کی سچائی نفع دیتی ہے، ان کے لیے ایسے باغ ہیں جن کے نیچے نہریں بہہ رہی ہیں، یہاں وہ ہمیشہ رہیں گے، اللہ ان سے راضی ہوا اور وہ اللہ سے، یہی بڑی کامیابی ہے"\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcclxxxix{زمین اور آسمانوں اور تمام موجودات کی پادشاہی اللہ ہی کے لیے ہے اور وہ ہر چیز پر قدرت رکھتا ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dccxc{\basmalahur تعریف اللہ کے لیے ہے جس نے زمین اور آسمان بنائے، روشنی اور تاریکیاں پیدا کیں پھر بھی وہ لوگ جنہوں نے دعوت حق کو ماننے سے انکار کر دیا ہے دوسروں کو اپنے رب کا ہمسر ٹھیرا رہے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dccxci{وہی ہے جس نے تم کو مٹی سے پیدا کیا، پھر تمہارے لیے زندگی کی ایک مدت مقرر کر دی، اور ایک دوسری مدت اور بھی ہے جواس کے ہاں طے شدہ ہے مگر تم لوگ ہو کہ شک میں پڑے ہوئے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dccxcii{وہی ایک خدا آسمانوں میں بھی ہے اور زمین میں بھی، تمہارے کھلے اور چھپے سب حال جانتا ہے اور جو برائی یا بھلائی تم کماتے ہو اس سے خوب واقف ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dccxciii{لوگوں کا حال یہ ہے کہ ان کے رب کی نشانیوں میں سے کوئی نشانی ایسی نہیں جو ان کے سامنے آئی ہو اور انہوں نے اس سے منہ نہ موڑ لیا ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dccxciv{چنانچہ اب جو حق ان کے پاس آیا تو اسے بھی انہوں نے جھٹلا دیا اچھا، جس چیز کا وہ اب تک مذاق اڑاتے رہے ہیں عنقریب اس کے متعلق کچھ خبریں انہیں پہنچیں گی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dccxcv{کیا انہوں نے دیکھا نہیں کہ ان سے پہلے کتنی ایسی قوموں کو ہم ہلاک کر چکے ہیں جن کا اپنے اپنے زمانہ میں دور دورہ رہا ہے؟ اُن کو ہم نے زمین میں وہ اقتدار بخشا تھا جو تمہیں نہیں بخشا ہے، ان پر ہم نے آسمان سے خوب بارشیں برسائیں اور ان کے نیچے نہریں بہا دیں، (مگر جب انہوں نے کفران نعمت کیا تو) آخر کار ہم نے ان کے گناہوں کی پاداش میں انہیں تباہ کر دیا اور ان کی جگہ دوسرے دور کی قوموں کو اٹھایا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dccxcvi{اے پیغمبرؐ! اگر ہم تمہارے اوپر کوئی کاغذ میں لکھی لکھائی کتاب بھی اتار دیتے اور لوگ اسے اپنے ہاتھوں سے چھو کر بھی دیکھ لیتے تب بھی جنہوں نے حق کا انکار کیا ہے وہ یہی کہتے کہ یہ تو صریح جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dccxcvii{کہتے ہیں کہ اس نبی پر کوئی فرشتہ کیوں نہیں اتارا گیا اگر کہیں ہم نے فرشتہ اتار دیا ہوتا تو اب تک کبھی کا فیصلہ ہو چکا ہوتا، پھر انہیں کوئی مہلت نہ دی جاتی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dccxcviii{اور اگر ہم فرشتے کو اتارتے تب بھی اسے انسانی شکل ہی میں اتارتے اور اس طرح انہیں اُسی شبہ میں مبتلا کر دیتے جس میں اب یہ مبتلا ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dccxcix{اے محمدؐ! تم سے پہلے بھی بہت سے رسولوں کا مذاق اڑایا جا چکا ہے، مگر ان مذاق اڑانے والوں پر آخر کار وہی حقیقت مسلط ہو کر رہی جس کا وہ مذاق اڑاتے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dccc{اِن سے کہو، ذرا زمین میں چل پھر کر دیکھو جھٹلانے والوں کا کیا انجام ہوا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dccci{ان سے پوچھو، آسمانوں اور زمین میں جو کچھ ہے وہ کس کاہے؟کہو سب کچھ اللہ ہی کا ہے، اس نے رحم و کرم کا شیوہ اپنے اوپر لازم کر لیا ہے (اسی لیے وہ نافرمانیوں اور سرکشیوں پر تمہیں جلدی سے نہیں پکڑ لیتا)، قیامت کے روز وہ تم سب کو ضرور جمع کرے گا، یہ بالکل ایک غیر مشتبہ حقیقت ہے، مگر جن لوگوں نے اپنے آپ کو خود تباہی کے خطرے میں مبتلا کر لیا ہے وہ اسے نہیں مانتے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dcccii{رات کے اندھیرے اور دن کے اجالے میں جو کچھ ٹھیرا ہوا ہے، سب اللہ کا ہے اور وہ سب کچھ سنتا اور جانتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dccciii{کہو، اللہ کو چھوڑ کر کیا میں کسی اور کو اپنا سر پرست بنا لوں؟ اُس خدا کو چھوڑ کر جو زمین و آسمان کا خالق ہے اور جو روزی دیتا ہے روزی لیتا نہیں ہے؟ کہو، مجھے تو یہی حکم دیا گیا ہے کہ سب سے پہلے میں اُس کے آگے سر تسلیم خم کروں (اور تاکید کی گئی ہے کہ کوئی شرک کرتا ہے تو کرے) تو بہرحال مشرکوں میں شامل نہ ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dccciv{کہو، اگر میں اپنے رب کی نافرمانی کروں تو ڈرتا ہوں کہ ایک بڑے (خوفناک) دن مجھے سزا بھگتنی پڑے گی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dcccv{اُس دن جو سزا سے بچ گیا اس پر اللہ نے بڑا ہی رحم کیا اور یہی نمایاں کامیابی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dcccvi{اگر اللہ تمہیں کسی قسم کا نقصان پہنچائے تو اس کے سوا کوئی نہیں جو تمہیں اس نقصان سے بچا سکے، اور اگر وہ تمہیں کسی بھلائی سے بہرہ مند کرے تو وہ ہر چیز پر قادر ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dcccvii{وہ اپنے بندوں پر کامل اختیارات رکھتا ہے اور دانا اور باخبر ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dcccviii{ان سے پوچھو، کس کی گواہی سب سے بڑھ کر ہے؟کہو، میرے اور تمہارے درمیان اللہ گواہ ہے، اور یہ قرآن میری طرف بذریعہ وحی بھیجا گیا ہے تاکہ تمہیں اور جس جس کو یہ پہنچے، سب کو متنبہ کر دوں کیا واقعی تم لوگ یہ شہادت دے سکتے ہو کہ اللہ کے ساتھ دوسرے خدا بھی ہیں؟ کہو، میں تو اس کی شہادت ہرگز نہیں دے سکتا کہو، خدا تو وہی ایک ہے اور میں اس شرک سے قطعی بیزار ہوں جس میں تم مبتلا ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dcccix{جن لوگوں کو ہم نے کتاب دی ہے وہ اس بات کو اس طرح غیر مشتبہ طور پر پہچانتے ہیں جیسے ان کو اپنے بیٹوں کے پہچاننے میں کوئی اشتباہ پیش نہیں آتا مگر جنہوں نے اپنے آپ کو خود خسارے میں ڈال دیا ہے وہ اِسے نہیں مانتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcccx{اور اُس شخص سے بڑھ کر ظالم کون ہوگا جو اللہ پر جھوٹا بہتان لگائے، یا اللہ کی نشانیوں کو جھٹلائے؟ یقیناً ایسے ظالم کبھی فلاح نہیں پا سکتے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcccxi{جس روز ہم ان سب کو اکٹھا کریں گے اور مشرکوں سے پوچھیں گے کہ اب وہ تمہارے ٹھیرائے ہوئے شریک کہاں ہیں جن کو تم اپنا خدا سمجھتے تھے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcccxii{تو وہ اِس کے سوا کوئی فتنہ نہ اٹھا سکیں گے کہ (یہ جھوٹا بیان دیں کہ) اے ہمارے آقا! تیری قسم ہم ہرگز مشر ک نہ تھے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcccxiii{دیکھو، اُس وقت یہ کس طرح اپنے اوپر آپ جھوٹ گھڑیں گے، اور وہاں اُن کے سارے بناوٹی معبود گم ہو جائیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcccxiv{ان میں سے بعض لوگ ایسے ہیں جو کان لگا کر تمہاری بات سنتے ہیں مگر حال یہ ہے کہ ہم نے اُن کے دلوں پر پردے ڈال رکھے ہیں جن کی وجہ سے وہ اس کو کچھ نہیں سمجھتے اور ان کے کانوں میں گرانی ڈال دی ہے (کہ سب کچھ سننے پر بھی کچھ نہیں سنتے) وہ خواہ کوئی نشانی دیکھ لیں، اس پر ایمان لا کر نہ دیں گے حد یہ ہے کہ جب وہ تمہارے پاس آ کر تم سے جھگڑتے ہیں تو ان میں سے جن لوگوں نے انکار کا فیصلہ کر لیا ہے وہ (ساری باتیں سننے کے بعد) یہی کہتے ہیں کہ یہ ایک داستان پارینہ کے سوا کچھ نہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcccxv{وہ اس امر حق کو قبول کرنے سے لوگوں کو روکتے ہیں اور خود بھی اس سے دور بھاگتے ہیں (وہ سمجھتے ہیں کہ اس حرکت سے وہ تمہارا کچھ بگاڑ رہے ہیں) حالانکہ دراصل وہ خو د اپنی ہی تباہی کا سامان کر رہے ہیں مگر انہیں اس کا شعور نہیں ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcccxvi{کاش تم اس وقت ان کی حالت دیکھ سکتے جب وہ دوزخ کے کنارے کھڑے کیے جائیں گے اس وقت وہ کہیں گے کہ کاش کوئی صورت ایسی ہو کہ ہم دنیا میں پھر واپس بھیجے جائیں اور اپنے رب کی نشانیوں کو نہ جھٹلائیں اور ایمان لانے والوں میں شامل ہوں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcccxvii{در حقیقت یہ با ت وہ محض اس وجہ سے کہیں گے کہ جس حقیقت پر انہوں نے پردہ ڈال رکھا تھا وہ اس وقت بے نقاب ہو کر ان کے سامنے آ چکی ہوگی، ورنہ اگر انہیں سابق زندگی کی طرف واپس بھیجا جائے تو پھر وہی سب کچھ کریں جس سے انہیں منع کیا گیا ہے، وہ تو ہیں ہی جھوٹے (اس لیے اپنی اس خواہش کے اظہار میں بھی جھوٹ ہی سے کام لیں گے)\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcccxviii{آج یہ لوگ کہتے ہیں کہ زندگی جو کچھ بھی ہے بس یہی دنیا کی زندگی ہے اور ہم مرنے کے بعد ہرگز دوبارہ نہ اٹھائے جائیں گے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcccxix{کاش وہ منظر تم دیکھ سکو جب یہ اپنے رب کے سامنے کھڑے کیے جائیں گے اس وقت ان کا رب ان سے پوچھے گا ``کیا یہ حقیقت نہیں ہے؟" یہ کہیں گے ``ہاں اے ہمارے رب! یہ حقیقت ہی ہے" وہ فرمائے گا ``اچھا! تو اب اپنے انکار حقیقت کی پاداش میں عذاب کا مزا چکھو"\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcccxx{نقصان میں پڑ گئے وہ لوگ جنہوں نے اللہ سے اپنی ملاقات کی اطلاع کو جھوٹ قرار دیا جب اچانک وہ گھڑی آ جائے گی تو یہی لوگ کہیں گے ``افسوس! ہم سے اس معاملہ میں کیسی تقصیر ہوئی" اور اِن کا حال یہ ہوگا کہ اپنی پیٹھوں پر اپنے گناہوں کا بوجھ لادے ہوئے ہوں گے دیکھو! کیسا برا بوجھ ہے جو یہ اٹھا رہے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcccxxi{دنیا کی زندگی تو ایک کھیل اور ایک تماشا ہے، حقیقت میں آخرت ہی کا مقام اُن لوگوں کے لیے بہتر ہے جو زیاں کاری سے بچنا چاہتے ہیں، پھر کیا تم لوگ عقل سے کام نہ لو گے؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dcccxxii{اے محمدؐ! ہمیں معلوم ہے کہ جو باتیں یہ لوگ بناتے ہیں ان سے تمہیں رنج ہوتا ہے، لیکن یہ لوگ تمہیں نہیں جھٹلاتے بلکہ یہ ظالم دراصل اللہ کی آیات کا انکار کر رہے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcccxxiii{تم سے پہلے بھی بہت سے رسول جھٹلائے جا چکے ہیں، مگر اس تکذیب پر اور اُن اذیتوں پر جو انہیں پہنچائی گئیں، انہوں نے صبر کیا، یہاں تک کہ انہیں ہماری مدد پہنچ گئی اللہ کی باتوں کو بدلنے کی طاقت کسی میں نہیں ہے، اور پچھلے رسولوں کے ساتھ جو کچھ پیش آیا اس کی خبریں تمہیں پہنچ ہی چکی ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcccxxiv{تاہم اگر ان لوگوں کی بے رخی تم سے برداشت نہیں ہوتی تو اگر تم میں کچھ زور ہے تو زمین میں کوئی سرنگ ڈھونڈو یا آسمان میں سیڑھی لگاؤ اور ان کے پاس کوئی نشانی لانے کی کوشش کرو اگر اللہ چاہتا تو ان سب کو ہدایت پر جمع کر سکتا تھا، لہٰذا نادان مت بنو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dcccxxv{دعوت حق پر لبیک وہی لوگ کہتے ہیں جو سننے والے ہیں، رہے مُردے، تو انہیں تو اللہ بس قبروں ہی سے اٹھائے گا اور پھر وہ (اس کی عدالت میں پیش ہونے کے لیے) واپس لائے جائیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dcccxxvi{یہ لوگ کہتے ہیں کہ اِس نبی پر اس کے رب کی طرف سے کوئی نشانی کیوں نہیں اتری؟ کہو، اللہ نشانی اتارنے کی پوری قدرت رکھتا ہے، مگر ان میں سے اکثر لوگ نادانی میں مبتلا ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dcccxxvii{زمین میں چلنے والے کسی جانور اور ہوا میں پروں سے اڑنے والے کسی پرندے کو دیکھ لو، یہ سب تمہاری ہی طرح کی انواع ہیں، ہم نے ان کی تقدیر کے نوشتے میں کوئی کسر نہیں چھوڑی ہے، پھر یہ سب اپنے رب کی طرف سمیٹے جاتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dcccxxviii{مگر جو لوگ ہماری نشانیوں کو جھٹلاتے ہیں وہ بہرے اور گونگے ہیں، تاریکیوں میں پڑے ہوئے ہیں اللہ جسے چاہتا ہے بھٹکا دیتا ہے اور جسے چاہتا ہے سیدھے رستے پر لگا دیتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dcccxxix{ان سے کہو، ذرا غور کر کے بتاؤ، اگر کبھی تم پر اللہ کی طرف سے کوئی بڑی مصیبت آ جاتی ہے یا آخری گھڑی آ پہنچتی ہے تو کیا اس وقت تم اللہ کے سوا کسی اور کو پکارتے ہو؟ بولو اگر تم سچے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dcccxxx{ا س وقت تم اللہ ہی کو پکارتے ہو، پھر اگر وہ چاہتا ہے تو اس مصیبت کو تم پر سے ٹال دیتا ہے ایسے موقعوں پر تم اپنے ٹھیرائے ہوئے شریکوں کو بھول جاتے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dcccxxxi{تم سے پہلے بہت سی قوموں کی طرف ہم نے رسول بھیجے اور اُن قوموں کو مصائب و آلام میں مبتلا کیا تاکہ وہ عاجزی کے ساتھ ہمارے سامنے جھک جائیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dcccxxxii{پس جب ہماری طرف سے ان پر سختی آئی تو کیوں نہ انہوں نے عاجزی اختیار کی؟ مگر ان کے دل تو اور سخت ہوگئے اور شیطان نے ان کو اطمینان دلایا کہ جو کچھ تم کر رہے ہو خوب کر رہے ہو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiii{پھر جب انہوں نے اس نصیحت کو، جو انہیں کی گئی تھی، بھلا دیا تو ہم نے ہر طرح کی خوشحالیوں کے دروازے ان کے لیے کھول دیے، یہاں تک کہ جب وہ اُن بخششوں میں جو انہیں عطا کی گئی تھیں خوب مگن ہوگئے تو اچانک ہم نے انہیں پکڑ لیا اور اب حال یہ تھا کہ وہ ہر خیر سے مایوس تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiv{اس طرح ان لوگوں کی جڑ کاٹ کر رکھ دی گئی جنہوں نے ظلم کیا تھا اور تعریف ہے اللہ رب العالمین کے لیے (کہ اس نے ان کی جڑ کاٹ دی)\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dcccxxxv{اے محمدؐ! ان سے کہو، کبھی تم نے یہ بھی سوچا کہ اگر اللہ تمہاری بینائی اور سماعت تم سے چھین لے اور تمہارے دلوں پر مہر کر دے تو اللہ کے سوا اور کون سا خدا ہے جو یہ قوتیں تمہیں واپس دلاسکتا ہو؟ دیکھو، کس طرح ہم بار بار اپنی نشانیاں ان کے سامنے پیش کرتے ہیں اور پھر یہ کس طرح ان سے نظر چرا جاتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvi{کہو، کبھی تم نے سوچا کہ اگر اللہ کی طرف سے اچانک یا علانیہ تم پر عذاب آ جائے تو کیا ظالم لوگوں کے سوا کوئی اور ہلاک ہوگا؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvii{ہم جو رسول بھیجتے ہیں اسی لیے تو بھیجتے ہیں کہ وہ نیک کردار لوگوں کے لیے خوش خبری دینے والے اور بد کرداروں کے لیے ڈرانے والے ہوں پھر جو لوگ ان کی بات مان لیں اور اپنے طرز عمل کی اصلاح کر لیں ان کے لیے کسی خوف اور رنج کا موقع نہیں ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dcccxxxviii{اور جو ہماری آیات کو جھٹلائیں وہ اپنی نافرمانیوں کی پاداش میں سزا بھگت کر رہیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dcccxxxix{ا ے محمدؐ! ان سے کہو، ``میں تم سے یہ نہیں کہتا کہ میرے پاس اللہ کے خزانے ہیں نہ میں غیب کا علم رکھتا ہوں، اور نہ یہ کہتا ہوں کہ میں فرشتہ ہوں میں تو صرف اُس وحی کی پیروی کرتا ہوں جو مجھ پر نازل کی جاتی ہے" پھر ان سے پوچھو کیا اندھا اور آنکھوں والا دونوں برابر ہوسکتے ہیں؟ کیا تم غور نہیں کرتے؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dcccxl{اے محمدؐ! تم اس (علم وحی) کے ذریعہ سے اُن لوگوں کو نصیحت کرو جو اس بات کا خوف رکھتے ہیں کہ اپنے رب کے سامنے کبھی اس حال میں پیش کیے جائیں گے کہ اُس کے سوا وہاں کوئی (ایسا ذی اقتدار) نہ ہوگا جو ان کا حامی و مدد گار ہو، یا ان کی سفارش کرے، شاید کہ (اس نصیحت سے متنبہ ہو کر) وہ خدا ترسی کی روش اختیار کر لیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dcccxli{اور جو لوگ اپنے رب کو رات دن پکارتے رہتے ہیں او ر اس کی خوشنودی کی طلب میں لگے ہوئے ہیں انہیں اپنے سے دور نہ پھینکو اُن کے حساب میں سے کسی چیز کا بار تم پر نہیں ہے اور تمہارے حساب میں سے کسی چیز کا بار اُن پر نہیں اس پر بھی اگر تم انہیں دور پھینکو گے تو ظالموں میں شمار ہو گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dcccxlii{دراصل ہم نے اس طرح ان لوگوں میں سے بعض کو بعض کے ذریعہ سے آزمائش میں ڈالا ہے تاکہ وہ اِنہیں دیکھ کر کہیں ``کیا یہ ہیں وہ لوگ جن پر ہمارے درمیان اللہ کا فضل و کرم ہوا ہے؟" ہاں! کیا خدا اپنے شکر گزار بندوں کو اِن سے زیادہ نہیں جانتا ہے؟\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dcccxliii{جب تمہارے پاس وہ لوگ آئیں جو ہماری آیات پر ایمان لاتے ہیں تو ان سے کہو ``تم پر سلامتی ہے تمہارے رب نے رحم و کرم کا شیوہ اپنے اوپر لازم کر لیا ہے یہ اس کا رحم و کرم ہی ہے کہ اگر تم میں سے کوئی نادانی کے ساتھ کسی برائی کا ارتکاب کر بیٹھا ہو پھر اس کے بعد توبہ کرے اور اصلاح کر لے تو وہ اُسے معاف کر دیتا ہے اور نرمی سے کام لیتا ہے"\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dcccxliv{اور اس طرح ہم اپنی نشانیاں کھول کھول کر پیش کرتے ہیں تاکہ مجرموں کی راہ بالکل نمایاں ہو جائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dcccxlv{اے محمدؐ! اِن سے کہو کہ تم لوگ اللہ کے سوا جن دوسروں کو پکارتے ہو اُن کی بندگی کرنے سے مجھے منع کیا گیا ہے کہو، میں تمہاری خواہشات کی پیروی نہیں کروں گا، اگر میں نے ایسا کیا تو گمراہ ہو گیا، راہ راست پانے والوں میں سے نہ رہا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dcccxlvi{کہو، میں اپنے رب کی طرف سے ایک دلیل روشن پر قائم ہوں اور تم نے اسے جھٹلا دیا ہے، اب میرے اختیار میں وہ چیز ہے نہیں جس کے لیے تم جلدی مچا رہے ہو، فیصلہ کا سارا اختیار اللہ کو ہے، وہی امر حق بیان کرتا ہے اور وہی بہترین فیصلہ کرنے والا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dcccxlvii{کہو، اگر کہیں وہ چیز میرے اختیار میں ہوتی جس کی تم جلدی مچا رہے ہو تو میرے اور تمہارے درمیان کبھی کا فیصلہ ہو چکا ہوتا مگر اللہ زیادہ بہتر جانتا ہے کہ ظالموں کے ساتھ کیا معاملہ کیا جانا چاہیے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dcccxlviii{اُسی کے پاس غیب کی کنجیاں ہیں جنہیں اس کے سوا کوئی نہیں جانتا بحر و بر میں جو کچھ ہے سب سے وہ واقف ہے درخت سے گرنے والا کوئی پتہ ایسا نہیں جس کا اسے علم نہ ہو زمین کے تاریک پردوں میں کوئی دانہ ایسا نہیں جس سے وہ باخبر نہ ہو خشک و ترسب کچھ ایک کھلی کتاب میں لکھا ہوا ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dcccxlix{وہی ہے جو رات کو تمہاری روحیں قبض کرتا ہے اور دن کو جو کچھ تم کرتے ہو اسے جانتا ہے، پھر دوسرے روز وہ تمہیں اِسی کاروبار کے عالم میں واپس بھیج دیتا ہے تاکہ زندگی کی مقرر مدت پوری ہو آخر کار اسی کی طرف تمہاری واپسی ہے، پھر و ہ تمہیں بتا دے گا کہ تم کیا کرتے رہے ہو\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dcccl{اپنے بندوں پر وہ پوری قدرت رکھتا ہے اور تم پر نگرانی کرنے والے مقرر کر کے بھیجتا ہے، یہاں تک کہ جب تم میں سے کسی کی موت کا وقت آ جاتا ہے تو اس کے بھیجے ہوئے فرشتے اس کی جان نکال لیتے ہیں اور اپنا فرض انجام دینے میں ذرا کوتاہی نہیں کرتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dcccli{پھر سب کے سب اللہ، اپنے حقیقی آقا کی طرف واپس لائے جاتے ہیں خبردار ہو جاؤ، فیصلہ کے سارے اختیارات اسی کو حاصل ہیں اور وہ حساب لینے میں بہت تیز ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccclii{اے محمدؐ! ا ن سے پوچھو، صحرا اور سمندر کی تاریکیوں میں کون تمہیں خطرات سے بچاتا ہے؟ کو ن ہے جس سے تم (مصیبت کے وقت) گڑ گڑا، گڑگڑا کر اور چپکے چپکے دعائیں مانگتے ہو؟ کس سے کہتے ہو کہ اگر اس بلا سے تو نے ہم کو بچا لیا تو ہم ضرور شکر گزار ہوں گے؟\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dcccliii{کہو، اللہ تمہیں اُس سے اور ہر تکلیف سے نجات دیتا ہے پھر تم دوسروں کو اُس کا شریک ٹھیراتے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dcccliv{کہو، وہ اِس پر قادر ہے کہ تم پر کوئی عذاب اوپر سے نازل کر دے، یا تمہارے قدموں کے نیچے سے برپا کر دے، یا تمہیں گروہوں میں تقسیم کر کے ایک گروہ کو دوسرے گروہ کی طاقت کا مزہ چکھوا دے دیکھو، ہم کس طرح بار بار مختلف طریقوں سے اپنی نشانیاں ان کے سامنے پیش کر رہے ہیں شاید کہ یہ حقیقت کو سمجھ لیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccclv{تمہاری قوم اُس کا انکار کر رہی ہے حالانکہ وہ حقیقت ہے اِن سے کہہ دو کہ میں تم پر حوالہ دار نہیں بنایا گیا ہوں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccclvi{ہر خبر کے ظہور میں آنے کا ایک وقت مقرر ہے، عنقریب تم کو خود انجام معلوم ہو جائے گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccclvii{اور اے محمدؐ! جب تم دیکھو کہ لوگ ہماری آیات پر نکتہ چینیاں کر رہے ہیں تو ان کے پاس سے ہٹ جاؤ یہاں تک کہ وہ اس گفتگو کو چھوڑ کر دوسری باتوں میں لگ جائیں اور اگر کبھی شیطان تمہیں بھلاوے میں ڈال دے تو جس وقت تمہیں اس غلطی کا احساس ہو جائے اس کے بعد پھر ایسے ظالم لوگوں کے پاس نہ بیٹھو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccclviii{اُن کے حساب میں سے کسی چیز کی ذمہ داری پرہیز گار لوگوں پر نہیں ہے، البتہ نصیحت کرنا اُن کا فرض ہے شاید کہ وہ غلط روی سے بچ جائیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccclix{چھوڑو اُن لوگوں کو جنہوں نے اپنے دین کو کھیل اور تماشا بنا رکھا ہے اور جنہیں دنیا کی زندگی فریب میں مبتلا کیے ہوئے ہے ہاں مگر یہ قرآن سنا کر نصیحت اور تنبیہ کرتے رہو کہ کہیں کوئی شخص اپنے کیے کرتوتوں کے وبال میں گرفتار نہ ہو جائے، اور گرفتار بھی اِس حال میں ہو کہ اللہ سے بچانے والا کوئی حامی و مدد گار اور کوئی سفارشی اس کے لیے نہ ہو، اور گر وہ ہر ممکن چیز فدیہ میں دے کر چھوٹنا چاہے تو وہ بھی اس سے قبول نہ کی جائے، کیونکہ ایسے لوگ تو خود اپنی کمائی کے نتیجہ میں پکڑے جائیں گے، ان کو تو اپنے انکار حق کے معاوضہ میں کھولتا ہوا پانی پینے کو اور درد ناک عذاب بھگتنے کو ملے گا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccclx{اے محمدؐ! ان سے پو چھو کیا ہم اللہ کو چھوڑ کر اُن کو پکاریں جو نہ ہمیں نفع دے سکتے ہیں نہ نقصان؟ اور جبکہ اللہ ہمیں سیدھا راستہ دکھا چکا ہے تو کیا اب ہم الٹے پاؤں پھر جائیں؟ کیا ہم اپنا حال اُس شخص کا سا کر لیں جسے شیطانوں نے صحرا میں بھٹکا دیا ہو اور وہ حیران و سرگرداں پھر رہا ہو درآں حالیکہ اس کے ساتھی اسے پکار رہے ہوں کہ اِدھر آ یہ سیدھی راہ موجود ہے؟کہو، حقیقت میں صحیح رہنمائی تو صرف اللہ ہی کی رہنمائی ہے اور اس کی طرف سے ہمیں یہ حکم ملا ہے کہ مالک کائنات کے آگے سر اطاعت خم کر دو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccclxi{نماز قائم کرو اور اس کی نافرمانی سے بچو، اسی کی طرف تم سمیٹے جاؤ گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccclxii{وہی ہے جس نے آسمان و زمین کو بر حق پیدا کیا ہے اور جس د ن وہ کہے گا کہ حشر ہو جائے اسی دن وہ ہو جائے گا اس کا ارشاد عین حق ہے اور جس روز صور پھونکا جائیگا اس روز پادشاہی اُسی کی ہوگی، وہ غیب اور شہادت ہر چیز کا عالم ہے اور دانا اور باخبر ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccclxiii{ابراہیمؑ کا واقعہ یاد کرو جبکہ اُس نے اپنے باپ آزر سے کہا تھا ``کیا تو بتوں کو خدا بناتا ہے؟ میں تو تجھے اور تیری قوم کو کھلی گمراہی میں پاتا ہوں"\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccclxiv{ابراہیمؑ کو ہم اِسی طرح زمین اور آسمانوں کا نظام سلطنت دکھاتے تھے اور اس لیے دکھاتے تھے کہ وہ یقین کرنے والوں میں سے ہو جائے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccclxv{چنانچہ جب رات اس پر طاری ہوئی تو اُس نے ایک تار ا دیکھا کہا یہ میرا رب ہے مگر جب وہ ڈوب گیا تو بولا ڈوب جانے والوں کا تو میں گرویدہ نہیں ہوں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccclxvi{پھر جب چاند چمکتا نظر آیا تو کہا یہ ہے میرا رب مگر جب وہ بھی ڈوب گیا تو کہا اگر میرے رب نے میر ی رہنمائی نہ کی ہوتی تو میں بھی گمراہ لوگوں میں شامل ہو گیا ہوتا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccclxvii{پھر جب سورج کو روشن دیکھا تو کہا یہ ہے میرا رب، یہ سب سے بڑا ہے مگر جب وہ بھی ڈوبا تو ابراہیمؑ پکار اٹھا ``اے برادران قوم! میں اُن سب سے بیزار ہوں جنہیں تم خدا کا شریک ٹھیراتے ہو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccclxviii{میں نے تویکسو ہو کر اپنا رخ اُس ہستی کی طرف کر لیا جس نے زمین اور آسمانوں کو پیدا کیا ہے اور میں ہرگز شرک کرنے والوں میں سے نہیں ہوں"\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccclxix{اس کی قوم اس سے جھگڑنے لگی تو اس نے قوم سے کہا ``کیا تم لوگ اللہ کے معاملہ میں مجھ سے جھگڑتے ہو؟ حالانکہ اس نے مجھے راہ راست دکھا دی ہے اور میں تمہارے ٹھیرائے ہوئے شریکوں سے نہیں ڈرتا، ہاں اگر میرا رب کچھ چاہے تو وہ ضرور ہو سکتا ہے میرے رب کا علم ہر چیز پر چھایا ہوا ہے، پھر کیا تم ہوش میں نہ آؤ گے؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccclxx{اور آخر میں تمہارے ٹھیرائے ہوئے شریکوں سے کیسے ڈروں جبکہ تم اللہ کے ساتھ ان چیزوں کو خدائی میں شریک بناتے ہوئے نہیں ڈرتے جن کے لیے اس نے تم پر کوئی سند نازل نہیں کی ہے؟ ہم دونوں فریقوں میں سے کون زیادہ بے خوفی و اطمینان کا مستحق ہے؟ بتاؤ اگر تم کچھ علم رکھتے ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccclxxi{حقیقت میں تو امن انہی کے لیے ہے اور راہ راست پر وہی ہیں جو ایمان لائے اور جنہوں نے اپنے ایمان کو ظلم کے ساتھ آلودہ نہیں کیا"\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dccclxxii{یہ تھی ہماری وہ حجت جو ہم نے ابراہیمؑ کو اس کی قوم کے مقابلہ میں عطا کی ہم جسے چاہتے ہیں بلند مرتبے عطا کرتے ہیں حق یہ ہے کہ تمہارا رب نہایت دانا اور علیم ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccclxxiii{پھر ہم نے ابراہیمؑ کو اسحاقؑ اور یعقوبؑ جیسی اولاد دی اور ہر ایک کو راہ راست دکھائی (وہی راہ راست جو) اس سے پہلے نوحؑ کو دکھائی تھی اور اُسی کی نسل سے ہم نے داؤدؑ، سلیمانؑ، ایوبؑ، یوسفؑ، موسیٰؑ اور ہارونؑ کو (ہدایت بخشی) اِس طرح ہم نیکو کاروں کو ان کی نیکی کا بدلہ دیتے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccclxxiv{(اُسی کی اولاد سے) زکریاؑ، یحییٰؑ، عیسیٰؑ اور الیاسؑ کو (راہ یاب کیا) ہر ایک ان میں سے صالح تھا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dccclxxv{(اسی کے خاندان سے) اسماعیلؑ، الیسعؑ، اور یونسؑ اور لوطؑ کو (راستہ دکھایا) اِن میں سے ہر ایک کو ہم نے تمام دنیا والوں پر فضیلت عطا کی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dccclxxvi{نیز ان کے آبا و اجداد اور ان کی اولاد اور ان کے بھائی بندوں میں سے بہتوں کو ہم نے نوازا، انہیں اپنی خدمت کے لیے چن لیا اور سیدھے راستے کی طرف اُن کی رہنمائی کی\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dccclxxvii{یہ اللہ کی ہدایت ہے جس کے ساتھ وہ اپنے بندوں میں سے جس کی چاہتا ہے رہنمائی کرتا ہے لیکن اگر کہیں ان لوگوں نے شرک کیا ہوتا تو ان کا سب کیا کرایا غارت ہو جاتا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dccclxxviii{وہ لوگ تھے جن کو ہم نے کتاب اور حکم اور نبوت عطا کی تھی اب اگر یہ لوگ اس کو ماننے سے انکار کرتے ہیں تو (پروا نہیں) ہم نے کچھ اور لوگوں کو یہ نعمت سونپ دی ہے جو اس سے منکر نہیں ہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dccclxxix{اے محمدؐ! وہی لوگ اللہ کی طرف سے ہدایت یافتہ تھے، انہی کے راستہ پر تم چلو، اور کہہ دو کہ میں (اس تبلیغ و ہدایت کے) کام پر تم سے کسی اجر کا طالب نہیں ہوں، یہ تو ایک عام نصیحت ہے تمام دنیا والوں کے لیے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dccclxxx{ان لوگوں نے اللہ کا بہت غلط اندازہ لگایا جب کہا کہ اللہ نے کسی بشر پر کچھ نازل نہیں کیا ہے ان سے پوچھو، پھر وہ کتاب جسے موسیٰؑ لایا تھا، جو تمام انسانوں کے لیے روشنی اور ہدایت تھی، جسے تم پارہ پارہ کر کے رکھتے ہو، کچھ دکھاتے ہو اور بہت کچھ چھپا جاتے ہو، اور جس کے ذریعہ سے تم کو وہ علم دیا گیا جو نہ تمہیں حاصل تھا اور نہ تمہارے باپ دادا کو، آخر اُس کا نازل کرنے والا کون تھا؟ بس اتنا کہہ دو کہ اللہ، پھر اُنہیں اپنی دلیل بازیوں سے کھیلنے کے لیے چھوڑ دو\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dccclxxxi{(اُسی کتاب کی طرح) یہ ایک کتاب ہے جسے ہم نے نازل کیا ہے بڑی خیر و برکت والی ہے اُس چیز کی تصدیق کرتی ہے جو اس سے پہلے آئی تھی اور اس لیے نازل کی گئی ہے کہ اس کے ذریعہ سے تم بستیوں کے اِس مرکز (یعنی مکہ) اور اس کے اطراف میں رہنے والوں کو متنبہ کرو جو لو گ آخرت کو مانتے ہیں وہ اس کتاب پر ایمان لاتے ہیں اور ان کا حال یہ ہے کہ اپنی نمازوں کی پابندی کرتے ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dccclxxxii{اور اُس شخص سے بڑا ظالم اور کون ہوگا جو اللہ پر جھوٹا بہتان گھڑے، یا کہے کہ مجھ پر وحی آئی ہے درآں حالیکہ اس پر کوئی وحی نازل نہ کی گئی ہو، یا جو اللہ کی نازل کردہ چیز کے مقابلہ میں کہے کہ میں بھی ایسی چیز نازل کر کے دکھا دوں گا؟ کاش تم ظالموں کو اس حالت میں دیکھ سکو جب کہ وہ سکرات موت میں ڈبکیاں کھا رہے ہوتے ہیں اور فرشتے ہاتھ بڑھا بڑھا کر کہہ رہے ہوتے ہیں کہ ``لاؤ، نکالو اپنی جان، آج تمہیں اُن باتوں کی پاداش میں ذلت کا عذاب دیا جائے گا جو تم اللہ پر تہمت رکھ کر ناحق بکا کرتے تھے اور اُس کی آیات کے مقابلہ میں سرکشی دکھاتے تھے"\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiii{(اور اللہ فرمائے گا) ``لو اب تم ویسے ہی تن تنہا ہمارے سامنے حاضر ہوگئے جیسا ہم نے تمہیں پہلی مرتبہ اکیلا پیدا کیا تھا، جو کچھ ہم نے تمہیں دنیا میں دیا تھا وہ سب تم پیچھے چھوڑ آئے ہو، اور اب ہم تمہارے ساتھ تمہارے اُن سفارشیوں کو بھی نہیں دیکھتے جن کے متعلق تم سمجھتے تھے کہ تمہارے کام بنانے میں ان کا بھی کچھ حصہ ہے، تمہارے آپس کے سب رابطے ٹوٹ گئے اور وہ سب تم سے گم ہوگئے جن کا تم زعم رکھتے تھے"\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiv{دانے اور گٹھلی کو پھاڑنے والا اللہ ہے وہی زندہ کو مُردہ سے نکالتا ہے اور وہی مُردہ کو زندہ سے خارج کرتا ہے یہ سارے کام کرنے والا اللہ ہے، پھر تم کدھر بہکے چلے جا رہے ہو؟\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dccclxxxv{پردہ شب کو چاک کر کے وہی صبح نکالتا ہے اُسی نے رات کو سکون کا وقت بنایا ہے اُسی نے چاند اور سورج کے طلوع و غروب کا حساب مقرر کیا ہے یہ سب اُسی زبردست قدرت اور علم رکھنے والے کے ٹھیرائے ہوئے اندازے ہیں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvi{اور وہی ہے جس نے تمہارے لیے تاروں کو صحرا اور سمندر کی تاریکیوں میں راستہ معلوم کرنے کا ذریعہ بنایا دیکھو ہم نے نشانیاں کھول کر بیان کر دی ہیں اُن لوگوں کے لیے جو علم رکھتے ہیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvii{اور وہی ہے جس نے ایک متنفس سے تم کو پید ا کیا پھر ہر ایک کے لیے ایک جائے قرار ہے اور ایک اس کے سونپے جانے کی جگہ یہ نشانیاں ہم نے واضح کر دی ہیں اُن لوگوں کے لیے جو سمجھ بوجھ رکھتے ہیں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dccclxxxviii{اور وہی ہے جس نے آسمان سے پانی برسایا، پھر اس کے ذریعہ سے ہر قسم کی نباتات اگائی، پھر اس سے ہرے ہرے کھیت اور درخت پیدا کیے، پھر ان سے تہ بہ تہ چڑھے ہوئے دانے نکالے اور کھجور کے شگوفوں سے پھلوں کے گچھے کے گچھے پیدا کیے جو بوجھ کے مارے جھکے پڑتے ہیں، اور انگور، زیتون اور انار کے باغ لگائے جن کے پھل ایک دوسرے سے ملتے جلتے بھی ہیں اور پھر اُن کے پکنے کی کیفیت ذرا غور کی نظر سے دیکھو، اِن چیزوں میں نشانیاں ہیں اُن لوگوں کے لیے جو ایمان لاتے ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dccclxxxix{اِس پر بھی لوگوں نے جنوں کو اللہ کا شریک ٹھیرا دیا، حالانکہ وہ اُن کا خالق ہے، اور بے جانے بوجھے اس کے لیے بیٹے اور بیٹیاں تصنیف کر دیں، حالانکہ وہ پاک اور بالا تر ہے اُن باتوں سے جو یہ لوگ کہتے ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcccxc{وہ تو آسمانوں اور زمین کا موجد ہے اس کا کوئی بیٹا کیسے ہوسکتا ہے جبکہ کوئی اس کی شریک زندگی ہی نہیں ہے اس نے ہر چیز کو پیدا کیا ہے اور وہ ہر چیز کا علم رکھتا ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcccxci{یہ ہے اللہ تمہارا رب، کوئی خدا اس کے سوا نہیں ہے، ہر چیز کا خالق، لہٰذا تم اسی کی بندگی کرو اور وہ ہر چیز کا کفیل ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcccxcii{نگاہیں اس کو نہیں پا سکتیں اور وہ نگاہوں کو پا لیتا ہے، وہ نہایت باریک بیں اور باخبر ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcccxciii{دیکھو، تمہارے پاس تمہارے رب کی طرف سے بصیرت کی روشنیاں آ گئی ہیں، اب جو بینائی سے کام لے گا اپنا ہی بھلا کرے گا اور جو اندھا بنے گا خود نقصان اٹھائے گا، میں تم پر کوئی پاسبان نہیں ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcccxciv{اِس طرح ہم اپنی آیات کو بار بار مختلف طریقوں سے بیان کرتے ہیں اور اس لیے کرتے ہیں کہ یہ لوگ کہیں تم کسی سے پڑھ آئے ہو، اور جو لوگ علم رکھتے ہیں ان پر ہم حقیقت کو روشن کر دیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcccxcv{اے محمدؐ! اُس وحی کی پیروی کیے جاؤ جو تم پر تمہارے رب کی طرف سے نازل ہوئی ہے کیونکہ اُس ایک رب کے سوا کوئی اور خدا نہیں ہے اور ان مشرکین کے پیچھے نہ پڑو\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcccxcvi{اگر اللہ کی مشیت ہوتی تو (وہ خود ایسا بندوبست کرسکتا تھا کہ) یہ لوگ شرک نہ کرتے تم کو ہم نے ان پر پاسبان مقرر نہیں کیا ہے اور نہ تم ان پر حوالہ دار ہو\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcccxcvii{اور (اے ایمان لانے والو!) یہ لوگ اللہ کے سوا جن کو پکارتے ہیں انہیں گالیاں نہ دو، کہیں ایسا نہ ہو کہ یہ شرک سے آگے بڑھ کر جہالت کی بنا پر اللہ کو گالیاں دینے لگیں ہم نے اسی طرح ہر گروہ کے لیے اس کے عمل کو خوشنما بنا دیا ہے پھر انہیں اپنے رب ہی کی طرف پلٹ کر آنا ہے، اُس وقت وہ اُنہیں بتا دے گا کہ وہ کیا کرتے رہے ہیں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcccxcviii{یہ لوگ کڑی کڑی قسمیں کھا کھا کر کہتے ہیں کہ اگر کوئی نشانی ہمارے سامنے آ جائے تو ہم اس پر ایمان لے آئیں گے اے محمدؐ! ان سے کہو کہ ``نشانیاں تو اللہ کے پاس ہیں" اور تمہیں کیسے سمجھایا جائے کہ اگر نشانیاں آ بھی جائیں تو یہ ایمان لانے والے نہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcccxcix{ہم اُسی طرح ان کے دلوں اور نگاہوں کو پھیر رہے ہیں جس طرح یہ پہلی مرتبہ اس پر ایمان نہیں لائے تھے ہم انہیں ان کی سرکشی ہی میں بھٹکنے کے لیے چھوڑے دیتے ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cm{اگر ہم فرشتے بھی ان پر نازل کر دیتے اور مُردے ان سے باتیں کرتے اور دنیا بھر کی چیزوں کو ہم ان کی آنکھوں کے سامنے جمع کر دیتے تب بھی یہ ایمان لانے والے نہ تھے، الا یہ کہ مشیت الٰہی یہی ہو کہ وہ ایمان لائیں، مگر اکثر لوگ نادانی کی باتیں کرتے ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cmi{اور ہم نے تو اسی طرح ہمیشہ شیطان انسانوں اور شیطان جنوں کو ہر نبی کا دشمن بنایا ہے جو ایک دوسرے پر خوش آیند باتیں دھوکے اور فریب کے طور پر القا کرتے رہے ہیں اگر تمہارے رب کی مشیت یہ ہوتی کہ وہ ایسا نہ کریں تو وہ کبھی نہ کرتے پس تم اُنہیں ان کے حال پر چھوڑ دو کہ اپنی افترا پردازیاں کرتے رہیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cmii{(یہ سب کچھ ہم انہیں اسی لیے کرنے دے رہے ہیں کہ) جو لوگ آخرت پر ایمان نہیں رکھتے اُن کے دل اِس (خوشنما دھوکے) کی طرف مائل ہوں اور وہ اس سے راضی ہو جائیں اور اُن برائیوں کا اکتساب کریں جن کا اکتساب وہ کرنا چاہتے ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cmiii{پھر جب حال یہ ہے تو کیا میں اللہ کے سوا کوئی اور فیصلہ کرنے والا تلاش کروں، حالانکہ اس نے پوری تفصیل کے ساتھ تمہاری طرف کتاب نازل کر دی ہے؟ اور جن لوگوں کو ہم نے (تم سے پہلے) کتاب دی تھی وہ جانتے ہیں کہ یہ کتاب تمہارے رب ہی کی طرف سے حق کے ساتھ نازل ہوئی ہے لہٰذا تم شک کرنے والوں میں شامل نہ ہو\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cmiv{تمہارے رب کی بات سچائی اور انصاف کے اعتبار سے کامل ہے، کوئی اس کے فرامین کو تبدیل کرنے والا نہیں ہے اور وہ سب کچھ سنتا اور جانتا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cmv{اور اے محمدؐ! اگر تم اُن لوگوں کی اکثریت کے کہنے پر چلو جو زمین میں بستے ہیں تو وہ تمہیں اللہ کے راستہ سے بھٹکا دیں گے وہ تو محض گمان پر چلتے اور قیاس آرائیاں کرتے ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cmvi{در حقیقت تمہارا رب زیادہ بہتر جانتا ہے کہ کون اُس کے راستے سے ہٹا ہوا ہے اور کون سیدھی راہ پر ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cmvii{پھر اگر تم لوگ اللہ کی آیات پر ایمان رکھتے ہو تو جس جانور پر اللہ کا نام لیا گیا ہو اُس کا گوشت کھاؤ\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cmviii{آخر کیا وجہ ہے کہ تم وہ چیز نہ کھاؤ جس پر اللہ کا نام لیا گیا ہو، حالانکہ جن چیزوں کا استعمال حالت اضطرار کے سوا دوسری تمام حالتوں میں اللہ نے حرام کر دیا ہے اُن کی تفصیل وہ تمہیں بتا چکا ہے بکثرت لوگوں کا حال یہ ہے کہ علم کے بغیر محض اپنی خواہشات کی بنا پر گمراہ کن باتیں کرتے ہیں، ان حد سے گزرنے والوں کو تمہارا رب خوب جانتا ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cmix{تم کھلے گناہوں سے بھی بچو اور چھپے گناہوں سے بھی، جو لوگ گناہ کا اکتساب کرتے ہیں وہ اپنی اس کمائی کا بدلہ پاکر رہیں گے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cmx{اور جس جانور کو اللہ کا نام لے کر ذبح نہ کیا گیا ہو اس کا گوشت نہ کھاؤ، ایسا کرنا فسق ہے شیاطین اپنے ساتھیوں کے دلوں میں شکوک و اعتراضات القا کرتے ہیں تاکہ وہ تم سے جھگڑا کریں لیکن اگر تم نے اُن کی اطاعت قبول کر لی تو یقیناً تم مشرک ہو\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cmxi{کیا وہ شخص جو پہلے مُردہ تھا پھر ہم نے اسے زندگی بخشی اور اس کو وہ روشنی عطا کی جس کے اجالے میں وہ لوگوں کے درمیان زندگی کی راہ طے کرتا ہے اُس شخص کی طرح ہو سکتا ہے جو تاریکیوں میں پڑا ہوا ہو اور کسی طرح اُن سے نہ نکلتا ہو؟ کافروں کے لیے تو اسی طرح ان کے اعمال خوشنما بنا دیے گئے ہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cmxii{اور اسی طرح ہم نے ہر بستی میں اس کے بڑے بڑے مجرموں کو لگا دیا ہے کہ وہاں اپنے مکر و فریب کا جال پھیلائیں دراصل وہ اپنے فریب کے جال میں آپ پھنستے ہیں، مگر اُنہیں اس کا شعور نہیں ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cmxiii{جب ان کے سامنے کوئی آیت آتی ہے تو وہ کہتے ہیں ``ہم نہ مانیں گے جب تک کہ وہ چیز خود ہم کو نہ دی جائے جو اللہ کے رسولوں کو دی گئی ہے" اللہ زیادہ بہتر جانتا ہے کہ اپنی پیغامبری کا کام کس سے لے اور کس طرح لے قریب ہے وہ وقت جب یہ مجرم اپنی مکاریوں کی پاداش میں اللہ کے ہاں ذلت اور سخت عذاب سے دو چار ہوں گے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cmxiv{پس (یہ حقیقت ہے کہ) جسے اللہ ہدایت بخشنے کا ارادہ کرتا ہے اُس کا سینہ اسلام کے لیے کھول دیتا ہے اور جسے گمراہی میں ڈالنے کا ارادہ کرتا ہے اُس کے سینے کو تنگ کر دیتا ہے اور ایسا بھینچتا ہے کہ (اسلام کا تصور کرتے ہی) اُسے یوں معلوم ہونے لگتا ہے کہ گویا اس کی روح آسمان کی طرف پرواز کر رہی ہے اِس طرح اللہ (حق سے فرار اور نفرت کی) ناپاکی اُن لوگوں پر مسلط کر دیتا ہے جو ایمان نہیں لاتے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cmxv{حالانکہ یہ راستہ تمہارے رب کا سیدھا راستہ ہے اور اس کے نشانات اُن لوگوں کے لیے واضح کر دیے گئے ہیں جو نصیحت قبول کرتے ہیں\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cmxvi{اُن کیلیے اُن کے رب کے پاس سلامتی کا گھر ہے اور وہ ان کا سر پرست ہے اُس صحیح طرز عمل کی وجہ سے جو انہوں نے اختیار کیا\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cmxvii{جس روز اللہ ان سب لوگوں کو گھیر کر جمع کرے گا، اس روز وہ جنوں سے خطاب کر کے فرمائے گا کہ ``ا ے گروہ جن! تم نے نوع انسانی پر خوب ہاتھ صاف کیا" انسانوں میں سے جو اُن کے رفیق تھے وہ عرض کریں گے ``پروردگار! ہم میں سے ہر ایک نے دوسرے کو خو ب استعمال کیا ہے، اور اب ہم اُس وقت پر آ پہنچے ہیں جو تو نے ہمارے لیے مقرر کر دیا تھا" اللہ فرمائے گا ``اچھا اب آگ تمہارا ٹھکانا ہے، اس میں تم ہمیشہ رہو گے" ا"س سے بچیں گے صرف وہی جنہیں اللہ بچانا چاہے گا، بے شک تمہارا رب دانا اور علیم ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cmxviii{دیکھو، اس طرح ہم (آخر ت میں) ظالموں کو ایک دوسرے کا ساتھی بنائیں گے اُس کمائی کی وجہ سے جو وہ (دنیا میں ایک دوسرے کے ساتھ مل کر) کرتے تھے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cmxix{(اس موقع پر اللہ ان سے پوچھے گا کہ) ``اے گروہ جن وانس، کیا تمہارے پاس خود تم ہی میں سے وہ پیغمبر نہیں آئے تھے جو تم کو میری آیات سناتے اور اِس دن کے انجام سے ڈراتے تھے؟" وہ کہیں گے ``ہاں، ہم اپنے خلاف خود گواہی دیتے ہیں" آج دنیا کی زندگی نے اِن لوگوں کو دھوکے میں ڈال رکھا ہے، مگر اُس وقت وہ خود اپنے خلاف گواہی دیں گے کہ وہ کافر تھے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cmxx{(یہ شہادت اُن سے اس لیے لی جائے گی کہ یہ ثابت ہو جائے کہ) تمہارا رب بستیوں کو ظلم کے ساتھ تباہ کرنے والا نہ تھا جبکہ ان کے باشندے حقیقت سے نا واقف ہوں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cmxxi{ہر شخص کا درجہ اُس کے عمل کے لحاظ سے ہے اور تمہارا رب لوگوں کے اعمال سے بے خبر نہیں ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cmxxii{تمہارا رب بے نیاز ہے اور مہربانی اس کا شیوہ ہے اگر و ہ چاہے تو تم لوگوں کو لے جائے اور تمہاری جگہ دوسرے جن لوگوں کو چاہے لے آئے جس طرح اُس نے تمہیں کچھ اور لوگوں کی نسل سے اٹھایا ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cmxxiii{تم سے جس چیز کا وعدہ کیا جا رہا ہے وہ یقیناً آنے والی ہے اور تم خدا کو عاجز کر دینے کی طاقت نہیں رکھتے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cmxxiv{اے محمدؐ! کہہ دو کہ لوگو! تم اپنی جگہ عمل کرتے رہو اور میں بھی اپنی جگہ عمل کر رہا ہوں، عنقریب تمہیں معلوم ہو جائے گا کہ انجام کار کس کے حق میں بہتر ہوتا ہے، بہر حال یہ حقیقت ہے کہ ظالم کبھی فلاح نہیں پا سکتے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cmxxv{اِن لوگوں نے اللہ کے لیے خود اُسی کی پیدا کی ہوئی کھیتیوں اور مویشیوں میں سے ایک حصہ مقرر کیا ہے اور کہتے ہیں یہ اللہ کے لیے ہے، بزعم خود، اور یہ ہمارے ٹھیرائے ہوئے شریکوں کے لیے پھر جو حصہ ان کے ٹھیرائے ہوئے شریکوں کے لیے ہے وہ تو اللہ کو نہیں پہنچتا مگر جو اللہ کے لیے ہے وہ ان کے شریکوں کو پہنچ جاتا ہے کیسے برے فیصلے کرتے ہیں یہ لوگ!\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cmxxvi{اور اسی طرح بہت سے مشرکوں کے لیے ان کے شریکوں نے اپنی اولاد کے قتل کو خوشنما بنا دیا ہے تاکہ ان کو ہلاکت میں مبتلا کریں اور ان پر ان کے دین کو مشتبہ بنا دیں اگر اللہ چاہتا تو یہ ایسا نہ کرتے، لہٰذا انہیں چھوڑ دو کہ اپنی افترا پرداز یوں میں لگے رہیں\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cmxxvii{کہتے ہیں یہ جانور اور یہ کھیت محفوظ ہیں، ا نہیں صرف وہی لوگ کھا سکتے ہیں جنہیں ہم کھلانا چاہیں، حالانکہ یہ پابندی ان کی خود ساختہ ہے پھر کچھ جانور ہیں جن پر سواری اور بار برداری حرام کر دی گئی ہے اور کچھ جانور ہیں جن پر اللہ کا نام نہیں لیتے، اور یہ سب کچھ انہوں نے اللہ پر افترا کیا ہے، عنقریب اللہ انہیں ان افترا پرداز یوں کا بدلہ دے گا\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cmxxviii{اور کہتے ہیں کہ جو کچھ ان جانوروں کے پیٹ میں ہے یہ ہمارے مردوں کے لیے مخصوص ہے اور ہماری عورتوں پر حرام، لیکن اگر وہ مُردہ ہو تو دونوں اس کے کھانے میں شریک ہو سکتے ہیں یہ باتیں جو انہوں نے گھڑ لی ہیں ان کا بدلہ اللہ انہیں دے کر رہے گا یقیناً وہ حکیم ہے اور سب باتوں کی اسے خبر ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cmxxix{یقیناً خسارے میں پڑ گئے وہ لوگ جنہوں نے اپنی اولاد کو جہالت و نادانی کی بنا پر قتل کیا اور اللہ کے دیے ہوئے رزق کو اللہ پر افترا پردازی کر کے حرام ٹھیرا لیا یقیناً وہ بھٹک گئے اور ہرگز وہ راہ راست پانے والوں میں سے نہ تھے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cmxxx{وہ اللہ ہی ہے جس نے طرح طرح کے باغ اور تاکستان اور نخلستان پیدا کیے، کھیتیاں اگائیں جن سے قسم قسم کے ماکولات حاصل ہوتے ہیں، زیتون اور انار کے درخت پیدا کیے جن کے پھل صورت میں مشابہ اور مزے میں مختلف ہوتے ہیں کھاؤ ان کی پیداوار جب کہ یہ پھلیں، اور اللہ کا حق ادا کرو جب اس کی فصل کاٹو، اور حد سے نہ گزرو کہ اللہ حد سے گزرنے والوں کو پسند نہیں کرتا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cmxxxi{پھر وہی ہے جس نے مویشیوں میں سے وہ جانور بھی پیدا کیے جن سے سواری و بار برداری کا کام لیا جاتا ہے اور وہ بھی جو کھانے اور بچھانے کے کام آتے ہیں کھاؤ اُن چیزوں میں سے جو اللہ نے تمہیں بخشی ہیں اور شیطان کی پیرو ی نہ کرو کہ وہ تمہارا کھلا دشمن ہے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cmxxxii{یہ آٹھ نر و مادہ ہیں، دو بھیڑ کی قسم سے اور دو بکری کی قسم سے، اے محمدؐ! ان سے پوچھو کہ اللہ نے اُن کے نر حرام کیے ہیں یا مادہ، یا وہ بچے جو بھیڑوں اور بکریوں کے پیٹ میں ہوں؟ ٹھیک ٹھیک علم کے ساتھ مجھے بتاؤ اگر تم سچے ہو\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cmxxxiii{اور اسی طرح دو اونٹ کی قسم سے ہیں اور دو گائے کی قسم سے پوچھو، اِن کے نر اللہ نے حرام کیے ہیں یا مادہ، یا وہ بچے جو اونٹنی اور گائے کے پیٹ میں ہوں؟ کیا تم اُس وقت حاضر تھے جب اللہ نے ان کے حرام ہونے کا حکم تمہیں دیا تھا؟ پھر اُس شخص سے بڑھ کر ظالم اور کون ہوگا جو اللہ کی طرف منسوب کر کے جھوٹی بات کہے تاکہ علم کے بغیر لوگوں کی غلط راہ نمائی کرے یقیناً اللہ ایسے ظالموں کو راہ راست نہیں دکھاتا\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cmxxxiv{اے محمدؐ! ان سے کہو کہ جو وحی تمہارے پاس آئی ہے اس میں تو میں کوئی چیز ایسی نہیں پاتا جو کسی کھانے والے پر حرام ہو، الا یہ کہ وہ مُردار ہو، یا بہایا ہوا خون ہو، یاسور کا گوشت ہو کہ وہ ناپاک ہے، یا فسق ہو کہ اللہ کے سوا کسی اور کے نام پر ذبح کیا گیا ہو پھر جو شخص مجبوری کی حالت میں (کوئی چیز اِن میں سے کھا لے) بغیر اس کے کہ وہ نافرمانی کا ارادہ رکھتا ہو اور بغیر اس کے کہ وہ حد ضرورت سے تجاوز کرے، تو یقیناً تمہارا رب در گزر سے کام لینے والا اور رحم فرمانے والا ہے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cmxxxv{اور جن لوگوں نے یہودیت اختیار کی ان پر ہم نے سب ناخن والے جانور حرام کر دیے تھے، اور گائے اور بکری کی چربی بھی بجز اُس کے جو اُن کی پیٹھ یا اُن کی آنتوں سے لگی ہوئی ہو یا ہڈی سے لگی رہ جائے یہ ہم نے ان کی سرکشی کی سزا اُنہیں دی تھی اور یہ جو کچھ ہم کہہ رہے ہیں بالکل سچ کہہ رہے ہیں\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cmxxxvi{اب اگر وہ تمہیں جھٹلائیں تو ان سے کہہ دو کہ تمہارے رب کا دامن رحمت وسیع ہے اور مجرموں سے اس کے عذاب کو پھیرا نہیں جاسکتا\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cmxxxvii{یہ مشرک لوگ (تمہاری ان باتوں کے جواب میں) ضرور کہیں گے کہ ``اگر اللہ چاہتا تو نہ ہم شرک کرتے اور نہ ہمارے باپ دادا، اور نہ ہم کسی چیز کو حرام ٹھراتے" ایسی ہی باتیں بنا بنا کر اِن سے پہلے کے لوگوں نے بھی جھٹلایا تھا یہاں تک کہ آخر کار ہمارے عذاب کا مزا انہوں نے چکھ لیا ان سے کہو ``کیا تمہارے پاس کوئی علم ہے جسے ہمارے سامنے پیش کرسکو؟ تم تو محض گمان پر چل رہے ہو اور نری قیاس آرائیاں کرتے ہو"\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cmxxxviii{پھر کہو (تمہاری اس حجت کے مقابلہ میں) ``حقیقت رس حجت تو اللہ کے پاس ہے، بے شک اگر اللہ چاہتا تو تم سب کو ہدایت دے دیتا"\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cmxxxix{ان سے کہو کہ ``لاؤ اپنے وہ گواہ جو اس بات کی شہادت دیں کہ اللہ ہی نے اِن چیزوں کو حرام کیا ہے" پھر اگر وہ شہادت دے دیں تو تم ان کے ساتھ شہادت نہ دینا، اور ہرگز اُن لوگوں کی خواہشات کے پیچھے نہ چلنا جنہوں نے ہماری آیات کو جھٹلایا ہے، اور جو آخرت کے منکر ہیں، اور جو دوسروں کو اپنے رب کا ہمسر بناتے ہیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cmxl{اے محمدؐ! ان سے کہو کہ آؤ میں تمہیں سناؤں تمہارے رب نے تم پر کیا پابندیاں عائد کی ہیں: یہ کہ اس کے ساتھ کسی کو شریک نہ کرو، اور والدین کے ساتھ نیک سلوک کرو، اور اپنی اولاد کو مفلسی کے ڈر سے قتل نہ کرو، ہم تمہیں بھی رزق دیتے ہیں اور ا ن کو بھی دیں گے اور بے شرمی کی باتوں کے قریب بھی نہ جاؤ خواہ وہ کھلی ہوں یا چھپی اور کسی جان کو جسے اللہ نے محترم ٹھیرایا ہے ہلاک نہ کرو مگر حق کے ساتھ یہ باتیں ہیں جن کی ہدایت اس نے تمہیں کی ہے، شاید کہ تم سمجھ بوجھ سے کام لو\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cmxli{اور یہ کہ یتیم کے مال کے قریب نہ جاؤ مگر ایسے طریقہ سے جو بہترین ہو، یہاں تک کہ وہ اپنے سن رشد کو پہنچ جائے اور ناپ تول میں پورا انصاف کرو، ہم ہر شخص پر ذمہ داری کا اتنا ہی بار رکھتے ہیں جتنا اس کے امکان میں ہے، اور جب بات کہو انصاف کی کہو خواہ معاملہ اپنے رشتہ دار ہی کا کیوں نہ ہو، اور اللہ کے عہد کو پورا کرو ان باتوں کی ہدایت اللہ نے تمہیں کی ہے شاید کہ تم نصیحت قبول کرو\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cmxlii{نیز اس کی ہدایت یہ ہے کہ یہی میرا سیدھا راستہ ہے لہٰذا تم اسی پر چلو اور دوسرے راستوں پر نہ چلو کہ وہ اس کے راستے سے ہٹا کر تمہیں پراگندہ کر دیں گے یہ ہے وہ ہدایت جو تمہارے رب نے تمہیں کی ہے، شاید کہ تم کج روی سے بچو\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cmxliii{پھر ہم نے موسیٰؑ کو کتاب عطا کی تھی جو بھلائی کی روش اختیار کرنے والے انسان پر نعمت کی تکمیل اور ہر ضروری چیز کی تفصیل اور سراسر ہدایت اور رحمت تھی (اور اس لیے بنی اسرائیل کو دی گئی تھی کہ) شاید لوگ اپنے رب کی ملاقات پر ایمان لائیں\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cmxliv{اور اسی طرح یہ کتاب ہم نے نازل کی ہے، ایک برکت والی کتاب پس تم اِس کی پیروی کرو اور تقویٰ کی روش اختیار کرو، بعید نہیں کہ تم پر رحم کیا جائے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cmxlv{اب تم یہ نہیں کہہ سکتے کہ کتاب تو ہم سے پہلے کے دو گروہوں کو دی گئی تھی، اور ہم کو کچھ خبر نہ تھی کہ وہ کیا پڑھتے پڑھاتے تھے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cmxlvi{اور اب تم یہ بہانہ بھی نہیں کرسکتے کہ اگر ہم پر کتاب نازل کی گئی ہوتی تو ہم ان سے زیادہ راست رو ثابت ہوتے تمہارے پاس تمہارے رب کی طرف سے ایک دلیل روشن اور ہدایت اور رحمت آ گئی ہے، اب اس سے بڑھ کر ظالم کون ہوگا جو اللہ کی آیات کو جھٹلائے اور ان سے منہ موڑے جو لوگ ہماری آیات سے منہ موڑتے ہیں انہیں اس رو گردانی کی پاداش میں ہم بدترین سزا دے کر رہیں گے\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cmxlvii{کیا اب لوگ اس کے منتظر ہیں کہ ان کے سامنے فرشتے آ کھڑے ہوں، یا تمہارا رب خود آ جائے، یا تمہارے رب کی بعض صریح نشانیاں نمودار ہو جائیں؟ جس روز تمہارے رب کی بعض مخصوص نشانیاں نمودار ہو جائیں گی پھر کسی ایسے شخص کو اس کا ایمان کچھ فائدہ نہ دے گا جو پہلے ایمان نہ لایا ہو یا جس نے اپنے ایمان میں کوئی بھلائی نہ کمائی ہو اے محمدؐ! ان سے کہہ دو کہ اچھا، تم انتظار کرو، ہم بھی انتظار کرتے ہیں\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cmxlviii{جن لوگوں نے اپنے دین کو ٹکڑے ٹکڑے کر دیا اور گروہ گروہ بن گئے یقیناً ان سے تمہارا کچھ واسطہ نہیں، ان کا معاملہ تو اللہ کے سپرد ہے، وہی ان کو بتائے گا کہ انہوں نے کیا کچھ کیا ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cmxlix{جو اللہ کے حضور نیکی لے کر آئے گا اس کے لیے دس گنا اجر ہے، اور جو بدی لے کر آئے گا اس کو اتنا ہی بدلہ دیا جائے گا جتنا اس نے قصور کیا ہے، اور کسی پر ظلم نہ کیا جائے گا\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cml{اے محمدؐ! کہو میرے رب نے بالیقین مجھے سیدھا راستہ دکھا دیا ہے، بالکل ٹھیک دین جس میں کوئی ٹیڑھ نہیں، ابراہیمؑ کا طریقہ جسے یکسو ہو کر اُس نے اختیار کیا تھا اور وہ مشرکوں میں سے نہ تھا\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cmli{کہو، میری نماز، میرے تمام مراسم عبودیت، میرا جینا اور میرا مرنا، سب کچھ اللہ رب العالمین کے لیے ہے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cmlii{جس کا کوئی شریک نہیں اسی کا مجھے حکم دیا گیا ہے اور سب سے پہلے سر اطاعت جھکانے والا میں ہوں\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cmliii{کہو، کیا میں اللہ کے سوا کوئی اور رب تلاش کروں حالاں کہ وہی ہر چیز کا رب ہے؟ ہر شخص جو کچھ کماتا ہے اس کا ذمہ دار وہ خود ہے، کوئی بوجھ اٹھانے والا دوسرے کا بوجھ نہیں اٹھاتا، پھر تم سب کو اپنے رب کی طرف پلٹنا ہے، اُس وقت وہ تمہارے اختلافات کی حقیقت تم پر کھول دے گا\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cmliv{وہی ہے جس نے تم کو زمین کا خلیفہ بنایا، اور تم میں سے بعض کو بعض کے مقابلہ میں زیادہ بلند درجے دیے، تاکہ جو کچھ تم کو دیا ہے اسی میں تمہاری آزمائش کرے بے شک تمہارا رب سزا دینے میں بھی بہت تیز ہے اور بہت درگزر کرنے اور رحم فرمانے والا بھی ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cmlv{\basmalahur ا، ل، م، ص\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cmlvi{یہ ایک کتاب ہے جو تمہاری طرف نازل کی گئی ہے، پس اے محمدؐ، تمہارے دل میں اس سے کوئی جھجک نہ ہو اس کے اتارنے کی غرض یہ ہے کہ تم اس کے ذریعہ سے (منکرین کو) ڈراؤ اور ایمان لانے والے لوگوں کو یاد دہانی ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cmlvii{لوگو، جو کچھ تمہارے رب کی طرف سے تم پر نازل کیا گیا ہے اُس کی پیروی کرو اور اپنے رب کو چھوڑ کر دوسرے سرپرستوں کی پیروی نہ کرو مگر تم نصیحت کم ہی مانتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cmlviii{کتنی ہی بستیاں ہیں جنہیں ہم نے ہلاک کر دیا اُن پر ہمارا عذاب اچانک رات کے وقت ٹوٹ پڑا، یا دن دہاڑے ایسے وقت آیا جب وہ آرام کر رہے تھے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cmlix{اور جب ہمارا عذاب اُن پر آ گیا تو ان کی زبان پر اِس کے سوا کوئی صدا نہ تھی کہ واقعی ہم ظالم تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cmlx{پس یہ ضرور ہو کر رہنا ہے کہ ہم اُن لوگوں سے باز پرس کریں، جن کی طرف ہم نے پیغمبر بھیجے ہیں اور پیغمبروں سے بھی پوچھیں (کہ اُنہوں نے پیغام رسانی کا فرض کہاں تک انجام دیا اور انہیں اس کا کیا جواب ملا)\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@cmlxi{پھر ہم خود پور ے علم کے ساتھ سرگزشت ان کے آگے پیش کر دیں گے، آخر ہم کہیں غائب تو نہیں تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@cmlxii{اور وزن اس روز عین حق ہوگا جن کے پلڑے بھاری ہوں گے وہی فلاح پائیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cmlxiii{اور جن کے پلڑے ہلکے رہیں گے وہی اپنے آپ کو خسارے میں مبتلا کرنے والے ہوں گے کیونکہ وہ ہماری آیات کے ساتھ ظالمانہ برتاؤ کرتے رہے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@cmlxiv{ہم نے تمھیں زمین میں اختیارات کے ساتھ بسایا اور تمہارے لیے یہاں سامان زیست فراہم کیا، مگر تم لوگ کم ہی شکر گزار ہوتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@cmlxv{ہم نے تمہاری تخلیق کی ابتدا کی، پھر تمہاری صورت بنائی، پھر فرشتوں سے کہا آدمؑ کو سجدہ کرو اس حکم پر سب نے سجدہ کیا مگر ابلیس سجدہ کرنے والوں میں شامل نہ ہوا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cmlxvi{پوچھا، ``تجھے کس چیز نے سجدہ کرنے سے روکا جب کہ میں نے تجھ کو حکم دیا تھا؟" بولا، ``میں اُس سے بہتر ہوں، تو نے مجھے آگ سے پیدا کیا ہے اور اُسے مٹی سے"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cmlxvii{فرمایا، ``اچھا تو یہاں سے نیچے اتر تجھے حق نہیں ہے کہ یہاں بڑائی کا گھمنڈ کرے نکل جا کہ در حقیقت تو ان لوگوں میں سے ہے جو خود اپنی ذلت چاہتے ہیں"\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cmlxviii{بولا، ``مجھے اُس دن تک مہلت دے جب کہ یہ سب دوبارہ اٹھائے جائیں گے"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cmlxix{فرمایا، ``تجھے مہلت ہے"\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cmlxx{بولا، ``اچھا تو جس طرح تو نے مجھے گمراہی میں مبتلا کیا میں بھی اب تیری سیدھی راہ پر\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cmlxxi{اِن انسانوں کی گھات میں لگا رہوں گا، آگے اور پیچھے، دائیں اور بائیں، ہر طرف سے اِن کو گھیروں گا اور تو ان میں سے اکثر کو شکر گزار نہ پائے گا"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cmlxxii{فرمایا، `` نکل جا یہاں سے ذلیل اور ٹھکرایا ہوا یقین رکھ کہ اِن میں سے جو تیری پیروی کریں گے، تجھ سمیت ان سب سے جہنم کو بھر دوں گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cmlxxiii{اور اے آدمؑ، تو اور تیری بیوی، دونوں اس جنت میں رہو، جہاں جس چیز کو تمہارا جی چاہے کھاؤ، مگر اس درخت کے پاس نہ پھٹکنا ورنہ ظالموں میں سے ہو جاؤ گے"\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cmlxxiv{پھر شیطان نے اُن کو بہکایا تاکہ ان کی شرمگاہیں جو ایک دوسرے سے چھپائی گئی تھیں ان کے سامنے کھول دے اس نے ان سے کہا، ``تمہارے رب نے تمہیں جو اس درخت سے روکا ہے اس کی وجہ اِس کے سوا کچھ نہیں ہے کہ کہیں تم فرشتے نہ بن جاؤ، یا تمہیں ہمیشگی کی زندگی حاصل نہ ہو جائے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cmlxxv{اور اس نے قسم کھا کر ان سے کہا کہ میں تمہارا سچا خیر خواہ ہوں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cmlxxvi{اس طرح دھو کا دے کر وہ ان دونوں کو رفتہ رفتہ اپنے ڈھب پرلے آیا آخرکار جب انہوں نے اس درخت کا مزا چکھا تو ان کے ستر ایک دوسرے کے سامنے کھل گئے اور اپنے جسموں کو جنت کے پتوں سے ڈھانکنے لگے تب ان کے رب نے انہیں پکارا، `` کیا میں نے تمہیں اس درخت سے نہ روکا تھا اور نہ کہا تھا کہ شیطان تمہارا کھلا دشمن ہے؟"\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cmlxxvii{دونوں بول اٹھے، ``اے رب، ہم نے اپنے اوپر ستم کیا، اب اگر تو نے ہم سے در گزر نہ فرمایا اور رحم نہ کیا تو یقیناً ہم تباہ ہو جائیں گے"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cmlxxviii{فرمایا، ``اتر جاؤ، تم ایک دوسرے کے دشمن ہو، اور تمہارے لیے ایک خاص مدت تک زمین ہی میں جائے قرار اور سامان زیست ہے"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cmlxxix{اور فرمایا، ``وہیں تم کو جینا اور وہیں مرنا ہے اور اسی میں سے تم کو آخرکار نکالا جائے گا"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cmlxxx{اے اولاد آدم، ہم نے تم پر لباس نازل کیا ہے کہ تمہارے جسم کے قابل شرم حصوں کو ڈھانکے اور تمہارے لیے جسم کی حفاظت اور زینت کا ذریعہ بھی ہو، اور بہترین لباس تقویٰ کا لباس ہے یہ اللہ کی نشانیوں میں سے ایک نشانی ہے، شاید کہ لوگ اس سے سبق لیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cmlxxxi{اے بنی آدم، ایسا نہ ہو کہ شیطان تمہیں پھر اُسی طرح فتنے میں مبتلا کر دے جس طرح اس نے تمہارے والدین کو جنت سے نکلوایا تھا اور ا ن کے لباس ان پر سے اتروا دیے تھے تاکہ ان کی شرمگاہیں ایک دوسرے کے سامنے کھولے وہ اور اس کے ساتھی تمہیں ایسی جگہ سے دیکھتے ہیں جہاں سے تم انہیں نہیں دیکھ سکتے اِن شیاطین کو ہم نے اُن لوگوں کا سرپرست بنا دیا ہے جو ایمان نہیں لاتے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cmlxxxii{یہ لوگ جب کوئی شرمناک کام کرتے ہیں تو کہتے ہیں ہم نے اپنے باپ دادا کو اسی طریقہ پر پایا ہے اور اللہ ہی نے ہمیں ایسا کرنے کا حکم دیا ہے اِن سے کہو اللہ بے حیائی کا حکم کبھی نہیں دیا کرتا کیا تم اللہ کا نام لے کر وہ باتیں کہتے ہو جن کے متعلق تمہیں علم نہیں ہے (وہ اللہ کی طرف سے ہیں)؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiii{اے محمدؐ، ان سے کہو، میرے رب نے تو راستی و انصاف کا حکم دیا ہے، اور اس کا حکم تو یہ ہے کہ ہر عبادت میں اپنا رخ ٹھیک رکھو اور اُسی کو پکارو اپنے دین کو اس کے لیے خالص رکھ کر جس طرح اُس نے تمہیں اب پیدا کیا ہے اسی طرح تم پھر پیدا کیے جاؤ گے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiv{ایک گروہ کوتو اس نے سیدھا راستہ دکھا دیا ہے، مگر دوسرے گروہ پر گمراہی چسپاں ہو کر رہ گئی ہے، کیونکہ انہوں نے خدا کے بجائے شیاطین کو اپنا سر پرست بنا لیا ہے اور وہ سمجھ رہے ہیں کہ ہم سیدھی راہ پر ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cmlxxxv{اے بنی آدم، ہر عبادت کے موقع پر اپنی زینت سے آراستہ رہو اور کھاؤ پیو اور حد سے تجاوز نہ کرو، اللہ حد سے بڑھنے والوں کو پسند نہیں کرتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvi{اے محمدؐ، ان سے کہو کس نے اللہ کی اُس زینت کو حرام کر دیا جسے اللہ نے اپنے بندوں کے لیے نکالا تھا اور کس نے خدا کی بخشی ہوئی پاک چیزیں ممنوع کر دیں؟ کہو، یہ ساری چیزیں دنیا کی زندگی میں بھی ایمان لانے والوں کے لیے ہیں، اور قیامت کے روز تو خالصتاً انہی کے لیے ہوں گی اِس طرح ہم اپنی باتیں صاف صاف بیان کرتے ہیں اُن لوگوں کے لیے جو علم رکھنے والے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvii{اے محمدؐ، اِن سے کہو کہ میرے رب نے جو چیزیں حرام کی ہیں وہ تو یہ ہیں: بے شرمی کے کام خواہ کھلے ہوں یا چھپے اور گناہ اور حق کے خلاف زیادتی اور یہ کہ اللہ کے ساتھ تم کسی کو شریک کرو جس کے لیے اُس نے کوئی سند نازل نہیں کی اور یہ کہ اللہ کے نام پر کوئی ایسی بات کہو جس کے متعلق تمہیں علم نہ ہو کہ وہ حقیقت میں اسی نے فرمائی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cmlxxxviii{ہر قوم کے لیے مہلت کی ایک مدت مقرر ہے، پھر جب کسی قوم کی مدت آن پوری ہوتی ہے تو ایک گھڑی بھر کی تاخیر و تقدیم بھی نہیں ہوتی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cmlxxxix{(اور یہ بات اللہ نے آغاز تخلیق ہی میں صاف فرما دی تھی کہ) اے بنی آدم، یاد رکھو، اگر تمہارے پاس خود تم ہی میں سے ایسے رسول آئیں جو تمہیں میری آیات سنا رہے ہوں، تو جو کوئی نافرمانی سے بچے گا اور اپنے رویہ کی اصلاح کر لے گا اس کے لیے کسی خوف اور رنج کا موقع نہیں ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cmxc{اور جو لوگ ہماری آیات کو جھٹلائیں گے اور ان کے مقابلہ میں سرکشی برتیں گے وہی اہل دوزخ ہوں گے جہاں وہ ہمیشہ رہیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cmxci{ظاہر ہے کہ اُس سے بڑا ظالم اور کو ن ہو گا جو بالکل جھوٹی باتیں گھڑ کر اللہ کی طرف منسوب کرے یا اللہ کی سچی آیات کو جھٹلائے ایسے لوگ اپنے نوشتہ تقدیر کے مطابق اپنا حصہ پاتے رہیں گے، یہاں تک کہ وہ گھڑی آ جائے گی جب ہمارے بھیجے ہوئے فرشتے ان کی روحیں قبض کرنے کے لیے پہنچیں گے اُس وقت وہ اُن سے پوچھیں گے کہ بتاؤ، اب کہاں ہیں تمہارے وہ معبود جن کو تم کو خدا کے بجائے پکارتے تھے؟ وہ کہیں گے کہ، ``سب ہم سے گم ہو گئے" اور وہ خود اپنے خلاف گواہی دیں گے کہ ہم واقعی منکر حق تھے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cmxcii{اللہ فرمائے گا جاؤ، تم بھی اسی جہنم میں چلے جاؤ جس میں تم سے پہلے گزرے ہوئے گروہ جن و انس جا چکے ہیں ہر گروہ جب جہنم میں داخل ہوگا تو اپنے پیش رو گروہ پر لعنت کرتا ہوا داخل ہوگا، حتیٰ کہ جب سب وہاں جمع ہو جائیں گے تو ہر بعد والا گروہ پہلے گروہ کے حق میں کہے گا کہ اے رب، یہ لوگ تھے جنہوں نے ہم کو گمراہ کیا لہٰذا انہیں آگ کا دوہرا عذاب دے جواب میں ارشاد ہوگا، ہر ایک کے لیے دوہرا ہی عذاب ہے مگر تم جانتے نہیں ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cmxciii{اور پہلا گروہ دوسرے گروہ سے کہے گا کہ (اگر ہم قابل الزام تھے) تو تمہی کو ہم پر کونسی فضیلت حاصل تھی، اب اپنی کمائی کے نتیجہ میں عذاب کا مزا چکھو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cmxciv{یقین جانو، جن لوگوں نے ہماری آیات کو جھٹلایا ہے اور ان کے مقابلہ میں سرکشی کی ہے ان کے لیے آسمان کے دروازے ہرگز نہ کھولے جائیں گے اُن کا جنت میں جانا اتنا ہی ناممکن ہے جتنا سوئی کے ناکے سے اونٹ کا گزرنا مجرموں کو ہمارے ہاں ایسا ہی بدلہ ملا کرتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cmxcv{ان کے لیے تو جہنم کا بچھونا ہوگا اور جہنم ہی کا اوڑھنا یہ ہے وہ جزا جو ہم ظالموں کو دیا کرتے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cmxcvi{بخلاف اس کے جن لوگوں نے ہماری آیات کو مان لیا ہے اور اچھے کام کیے ہیں اور اس باب میں ہم ہر ایک کو اس کی استطاعت ہی کے مطابق ذمہ دار ٹھیراتے ہیں وہ اہل جنت ہیں جہاں وہ ہمیشہ رہیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cmxcvii{ان کے دلوں میں ایک دوسرے کے خلاف جو کچھ کدورت ہوگی اسے ہم نکال دیں گے اُن کے نیچے نہریں بہتی ہونگی، اور وہ کہیں گے کہ ``تعریف خدا ہی کے لیے ہے جس نے ہمیں یہ راستہ دکھایا، ہم خود راہ نہ پا سکتے تھے اگر خدا ہماری رہنمائی نہ کرتا، ہمارے رب کے بھیجے ہوئے رسول واقعی حق ہی لے کر آئے تھے" اُس وقت ندا آئے گی کہ ``یہ جنت جس کے تم وارث بنائے گئے ہو تمہیں اُن اعمال کے بدلے میں ملی ہے جو تم کرتے رہے تھے"\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cmxcviii{پھر یہ جنت کے لوگ دوزخ والوں سے پکار کر کہیں گے، ``ہم نے اُن سارے وعدوں کو ٹھیک پا لیا جو ہمارے رب نے ہم سے کیے تھے، کیا تم نے بھی ان وعدوں کو ٹھیک پایا جو تمہارے رب نے کیے تھے؟" وہ جواب دیں گے ``ہاں" تب ایک پکارنے والا ان کے درمیان پکارے گا کہ ``خدا کی لعنت اُن ظالموں پر\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cmxcix{جو اللہ کے راستے سے لوگوں کو روکتے اور اسے ٹیڑھا کرنا چاہتے تھے اور آخرت کے منکر تھے"\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@m{ان دونوں گروہوں کے درمیان ایک اوٹ حائل ہوگی جس کی بلندیوں (اعراف) پر کچھ اور لوگ ہوں گے یہ ہر ایک کو اس کے قیافہ سے پہچانیں گے اور جنت والوں سے پکار کر کہیں گے کہ ``سلامتی ہو تم پر" یہ لوگ جنت میں داخل تو نہیں ہوئے مگر اس کے امیدوار ہونگے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mi{اور جب ان کی نگاہیں دوزخ والوں کی طرف پھریں گی تو کہیں گے، ``اے رب! ہمیں اِن ظالم لوگوں میں شامل نہ کیجیو"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mii{پھر یہ اعراف کے لوگ دوزخ کی چند بڑی بڑی شخصیتوں کو ان کی علامتوں سے پہچان کر پکاریں گے کہ ``دیکھ لیا تم نے، آج نہ تمہارے جتھے تمہارے کسی کام آئے اور نہ وہ ساز و سامان جن کو تم بڑی چیز سمجھتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@miii{اور کیا یہ اہل جنت وہی لوگ نہیں ہیں جن کے متعلق تم قسمیں کھا کھا کر کہتے تھے کہ اِن کو تو خدا پنی رحمت میں سے کچھ بھی نہ دے گا؟ آج انہی سے کہا گیا کہ داخل ہو جاؤ جنت میں، تمہارے لیے نہ خوف ہے نہ رنج"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@miv{اور دوزخ کے لوگ جنت والوں کو پکاریں گے کہ کچھ تھوڑا سا پانی ہم پر ڈال دو یا جو رزق اللہ نے تمہیں دیا ہے اُسی میں سے کچھ پھینک دو وہ جواب دیں گے کہ ``اللہ نے یہ دونوں چیزیں اُن منکرین حق پر حرام کر دی ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mv{جنہوں نے اپنے دین کو کھیل اور تفریح بنا لیا تھا اور جنہیں دنیا کی زندگی نے فریب میں مبتلا کر رکھا تھا اللہ فرماتا ہے کہ آج ہم بھی انہیں اسی طرح بھلا دیں گے جس طرح وہ اِس دن کی ملاقات کو بھولے رہے اور ہماری آیتوں کا انکار کرتے رہے"\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mvi{ہم اِن لوگوں کے پاس ایک ایسی کتاب لے آئے ہیں جس کو ہم نے علم کی بنا پر مفصل بنایا ہے اور جو ایمان لانے والوں کے لیے ہدایت اور رحمت ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mvii{اب کیا یہ لوگ اِس کے سوا کسی اور بات کے منتظر ہیں کہ وہ انجام سامنے آ جائے جس کی یہ کتاب خبر دے رہی ہے؟ جس روز وہ انجام سامنے آ گیا وہی لوگ جنہوں نے اسے نظر انداز کر دیا تھا کہیں گے کہ ``واقعی ہمارے رب کے رسول حق لے کر آئے تھے، پھر کیا اب ہمیں کچھ سفارشی ملیں گے جو ہمارے حق میں سفارش کریں؟ یا ہمیں دوبارہ واپس ہی بھیج دیا جائے تاکہ جو کچھ ہم پہلے کرتے تھے اس کے بجائے اب دوسرے طریقے پر کام کر کے دکھائیں" انہوں نے اپنے آپ کو خسارے میں ڈال دیا اور وہ سارے جھوٹ جو انہوں نے تصنیف کر رکھے تھے آج ان سے گم ہو گئے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mviii{در حقیقت تمہارا رب اللہ ہی ہے جس نے آسمانوں اور زمین کو چھ دنوں میں پیدا کیا، پھر اپنے تخت سلطنت پر جلوہ فرما ہوا جو رات کو دن پر ڈھانک دیتا ہے اور پھر دن رات کے پیچھے دوڑا چلا آتا ہے جس نے سورج اور چاند اور تارے پیدا کیے سب اس کے فرمان کے تابع ہیں خبردار رہو! اُسی کی خلق ہے اور اسی کا امر ہے بڑا با برکت ہے اللہ، سارے جہانوں کا مالک و پروردگار\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mix{ا پنے رب کو پکارو گڑگڑاتے ہوئے اور چپکے چپکے، یقیناً و ہ حد سے گزرنے والوں کو پسند نہیں کرتا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mx{زمین میں فساد برپا نہ کرو جبکہ اس کی اصلاح ہو چکی ہے اور خدا ہی کو پکارو خوف کے ساتھ اور طمع کے ساتھ، یقیناً اللہ کی رحمت نیک کردار لوگوں سے قریب ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mxi{اور وہ اللہ ہی ہے جو ہواؤں کو اپنی رحمت کے آگے آگے خوشخبری لیے ہوئے بھیجتا ہے، پھر جب وہ پانی سے لدے ہوئے بادل اٹھا لیتی ہیں تو انہیں کسی مردہ سر زمین کی طرف حرکت دیتا ہے، اور وہاں مینہ برسا کر (اُسی مری ہوئی زمین سے) طرح طرح کے پھل نکال لاتا ہے دیکھو، اس طرح ہم مُردوں کو حالت موت سے نکالتے ہیں، شاید کہ تم اس مشاہدے سے سبق لو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mxii{جو زمین اچھی ہوتی ہے وہ اپنے رب کے حکم سے خوب پھل پھول لاتی ہے اور جو زمین خراب ہوتی ہے ا س سے ناقص پیداوار کے سوا کچھ نہیں نکلتا اس طرح ہم نشانیوں کو بار بار پیش کرتے ہیں اُن لوگوں کے لیے جو شکر گزار ہونے والے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mxiii{ہم نے نوحؑ کو اُس کی قوم کی طرف بھیجا اس نے کہا ``اے برادران قوم، اللہ کی بندگی کرو، اُس کے سوا تمہارا کوئی خدا نہیں ہے میں تمہارے حق میں ایک ہولناک دن کے عذاب سے ڈرتا ہوں"\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mxiv{اس کی قوم کے سرداروں نے جواب دیا ``ہم کو تو یہ نظر آتا ہے کہ تم صریح گمراہی میں مبتلا ہو"\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mxv{نوحؑ نے کہا ``اے برادران قوم، میں کسی گمراہی میں نہیں پڑا ہو ں بلکہ، میں رب العالمین کا رسول ہوں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mxvi{تمہیں اپنے رب کے پیغامات پہنچاتا ہوں، تمہارا خیر خواہ ہوں اور مجھے اللہ کی طرف سے وہ کچھ معلوم ہے جو تمھیں معلوم نہیں ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mxvii{کیا تمہیں اس بات پر تعجب ہوا کہ تمہارے پاس خود تمہاری اپنی قوم کے ایک آدمی کے ذریعہ سے تمہارے رب کی یاد دہانی آئی تاکہ تمہیں خبردار کرے اور تم غلط روی سے بچ جاؤ اور تم پر رحم کیا جائے؟"\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mxviii{مگر انہوں نے اس کو جھٹلا دیا آخر کار ہم نے اسے اور اس کے ساتھیوں کو ایک کشتی میں نجات دی اور اُن لوگوں کو ڈبو دیا جنہوں نے ہماری آیات کو جھٹلایا تھا، یقیناً وہ اندھے لوگ تھے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mxix{اور عاد کی طرف ہم نے ان کے بھائی ہودؑ کو بھیجا اس نے کہا ``اے برادران قو م، اللہ کی بندگی کرو، اُس کے سوا تمہارا کوئی خدا نہیں ہے پھر کیا تم غلط روی سے پرہیز نہ کرو گے؟"\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mxx{اس کی قوم کے سرداروں نے، جو اس کی بات ماننے سے انکار کر رہے تھے، جواب میں کہا ``ہم تو تمہیں بے عقلی میں مبتلا سمجھتے ہیں اور ہمیں گمان ہے کہ تم جھوٹے ہو"\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mxxi{اس نے کہا ``اے برادران قوم، میں بے عقلی میں مبتلا نہیں ہوں بلکہ میں رب العالمین کا رسول ہوں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mxxii{تم کو اپنے رب کے پیغامات پہنچاتا ہوں، اور تمہارا ایسا خیر خواہ ہوں جس پر بھروسہ کیا جاسکتا ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mxxiii{کیا تمہیں اس بات پر تعجب ہوا کہ تمہارے پاس خود تمہاری اپنی قوم کے ایک آدمی کے ذریعہ سے تمہارے رب کی یاد دہانی آئی تاکہ وہ تمھیں خبردار کرے؟ بھول نہ جاؤ کہ تمہارے رب نے نوحؑ کی قوم کے بعد تم کو اُس کا جانشین بنایا اور تمہیں خوب تنو مند کیا، پس اللہ کی قدرت کے کرشموں کو یاد رکھو، امید ہے کہ فلاح پاؤ گے"\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mxxiv{انہوں نے جواب دیا ``کیا تو ہمارے پاس اس لیے آیا ہے کہ ہم اکیلے اللہ ہی کی عبادت کریں اور اُنہیں چھوڑ دیں جن کی عبادت ہمارے باپ دادا کرتے آئے ہیں؟ اچھا تو لے آ وہ عذاب جس کی تو ہمیں دھمکی دیتا ہے اگر تو سچا ہے"\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mxxv{اس نے کہا ``تمہارے رب کی پھٹکار تم پر پڑ گئی اور اس کا غضب ٹوٹ پڑا کیا تم مجھ سے اُن ناموں پر جھگڑتے ہو جو تم نے اور تمہارے باپ دادا نے رکھ لیے ہیں، جن کے لیے اللہ نے کوئی سند نازل نہیں کی ہے اچھا تو تم بھی انتظار کرو اور میں بھی تمہارے ساتھ انتظار کرتا ہوں"\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mxxvi{آخر کار ہم نے اپنی مہربانی سے ہودؑ اور اس کے ساتھیوں کو بچا لیا اور اُن لوگوں کی جڑ کاٹ دی جو ہماری آیات کو جھٹلا چکے تھے اور ایمان لانے والے نہ تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mxxvii{اور ثمود کی طرف ہم نے اُن کے بھائی صالحؑ کو بھیجا اس نے کہا ``اے برادران قوم، اللہ کی بندگی کرو، اس کے سوا تمہارا کوئی خدا نہیں ہے تمہارے پاس تمہارے رب کی کھلی دلیل آ گئی ہے یہ اللہ کی اونٹنی تمہارے لیے ایک نشانی کے طور پر ہے، لہٰذا اسے چھوڑ دو کہ خدا کی زمین میں چرتی پھرے اس کو کسی برے ارادے سے ہاتھ نہ لگانا ورنہ ایک درد ناک عذاب تمہیں آ لے گا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mxxviii{یاد کرو وہ وقت جب اللہ نے قوم عاد کے بعد تمہیں اس کا جانشین بنایا اور تم کو زمین میں یہ منزلت بخشی کہ تم اُس کے ہموار میدانوں میں عالی شان محل بناتے اور اس کے پہاڑوں کو مکانات کی شکل میں تراشتے ہو پس اس کی قدرت کے کرشموں سے غافل نہ ہو جاؤ اور زمین میں فساد برپا نہ کرو"\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mxxix{اُس کی قوم کے سرداروں نے جو بڑے بنے ہوئے تھے، کمزور طبقہ کے اُن لوگوں سے جو ایمان لے آئے تھے کہا ``کیا تم واقعی یہ جانتے ہو کہ صالحؑ اپنے رب کا پیغمبر ہے؟" انہوں نے جواب دیا ``بے شک جس پیغام کے ساتھ وہ بھیجا گیا ہے اُسے ہم مانتے ہیں"\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mxxx{اُن برائی کے مدعیوں نے کہا جس چیز کو تم نے مانا ہے ہم اس کے منکر ہیں"\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mxxxi{پھر انہوں نے اس اونٹنی کو مار ڈالا اور پورے تمرد کے ساتھ اپنے رب کے حکم کی خلاف ورزی کر گزرے، اور صالحؑ سے کہہ دیا کہ لے آ وہ عذاب جس کی تو ہمیں دھمکی دیتا ہے اگر تو واقعی پیغمبروں میں سے ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mxxxii{آخر کا ر ایک دہلا دینے والی آفت نے اُنہیں آ لیا اور وہ اپنے گھروں میں اوندھے پڑے کے پڑے رہ گئے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mxxxiii{اور صالحؑ یہ کہتا ہوا ان کی بستیوں سے نکل گیا کہ ``اے میری قوم، میں نے اپنے رب کا پیغام تجھے پہنچا دیا اور میں نے تیری بہت خیر خواہی کی، مگر میں کیا کروں کہ تجھے اپنے خیر خواہ پسند ہی نہیں ہیں"\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mxxxiv{اور لوطؑ کو ہم نے پیغمبر بنا کر بھیجا، پھر یاد کرو جب اُس نے اپنی قوم سے کہا ``کیا تم ایسے بے حیا ہو گئے ہو، کہ وہ فحش کام کرتے ہو جو تم سے پہلے دنیا میں کسی نے نہیں کیا؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mxxxv{تم عورتوں کو چھوڑ کر مردوں سے اپنی خواہش پوری کرتے ہو حقیقت یہ ہے کہ تم بالکل ہی حد سے گزر جانے والے لوگ ہو"\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mxxxvi{مگر اس کی قوم کا جواب اس کے سوا کچھ نہ تھا کہ ``نکالو اِن لوگوں کو اپنی بستیوں سے، بڑے پاکباز بنتے ہیں یہ"\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mxxxvii{آخر کار ہم نے لوطؑ اوراس کے گھر والوں کو بجز اس کی بیوی کے جو پیچھے رہ جانے والوں میں تھی\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mxxxviii{بچا کر نکال دیا اور اس قوم پر برسائی ایک بارش، پھر دیکھو کہ اُن مجرموں کا کیا انجام ہوا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mxxxix{اور مدین والوں کی طرف ہم نے ان کے بھائی شعیبؑ کو بھیجا اس نے کہا ``اے برادران قوم، اللہ کی بندگی کرو، اُس کے سوا تمہارا کوئی خدا نہیں ہے تمہارے پاس تمہارے رب کی صاف رہنمائی آ گئی ہے، لہٰذا وزن اور پیمانے پورے کرو، لوگوں کو اُن کی چیزوں میں گھاٹا نہ دو، اور زمین میں فساد برپا نہ کرو جب کہ اس کی اصلاح ہو چکی ہے، اسی میں تمہاری بھلائی ہے اگر تم واقعی مومن ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mxl{اور (زندگی کے) ہر راستے پر رہزن بن کر نہ بیٹھ جاؤ کہ لوگوں کو خوف زدہ کرنے اور ایمان لانے والوں کو خدا کے راستے سے روکنے لگو اور سیدھی راہ کو ٹیڑھا کرنے کے درپے ہو جاؤ یاد کرو وہ زمانہ جبکہ تم تھوڑے تھے پھر اللہ نے تمہیں بہت کر دیا، اور آنکھیں کھول کر دیکھو کہ دنیا میں مفسدوں کا کیا انجام ہوا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mxli{اگر تم میں سے ایک گروہ اس تعلیم پر جس کے ساتھ میں بھیجا گیا ہوں، ایمان لاتا ہے اور دوسرا ایمان نہیں لاتا، تو صبر کے ساتھ دیکھتے رہو یہاں تک کہ اللہ ہمارے درمیان فیصلہ کر دے، اور وہی سب سے بہتر فیصلہ کرنے والا ہے"\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mxlii{اس کی قوم کے سرداروں نے، جو اپنی بڑائی کے گھمنڈ میں مبتلا تھے، ا س سے کہا کہ ``اے شعیبؑ، ہم تجھے اور اُن لوگوں کو جو تیرے ساتھ ایمان لائے ہیں اپنی بستی سے نکال دیں گے ورنہ تم لوگوں کو ہماری ملت میں واپس آنا ہوگا" شعیبؑ نے جواب دیا ``کیا زبردستی ہمیں پھیرا جائے گا خواہ ہم راضی نہ ہوں؟\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mxliii{ہم اللہ پر جھوٹ گھڑنے والے ہوں گے اگر تمہاری ملت میں پلٹ آئیں جبکہ اللہ ہمیں اس سے نجات دے چکا ہے ہمارے لیے تو اس کی طرف پلٹنا اب کسی طرح ممکن نہیں الا یہ کہ خدا ہمارا رب ہی ایسا چاہے ہمارے رب کا علم ہر چیز پر حاوی ہے، اُسی پر ہم نے اعتماد کر لیا اے رب، ہمارے اور ہماری قوم کے درمیان ٹھیک ٹھیک فیصلہ کر دے اور تو بہترین فیصلہ کرنے والا ہے"\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mxliv{اس کی قوم کے سرداروں نے، جو اس کی بات ماننے سے انکار کر چکے تھے، آپس میں کہا ``اگر تم نے شعیبؑ کی پیروی قبول کر لی تو برباد ہو جاؤ گے"\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mxlv{مگر ہوا یہ کہ ایک دہلا دینے والی آفت نے اُن کو آ لیا اور وہ اپنے گھروں میں اوندھے پڑے کے پڑے رہ گئے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mxlvi{جن لوگوں نے شعیبؑ کو جھٹلایا وہ ایسے مٹے کہ گویا کبھی ان گھروں میں بسے ہی نہ تھے شعیبؑ کے جھٹلانے والے ہی آخر کار برباد ہو کر رہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mxlvii{اور شعیبؑ یہ کہہ کر ان کی بستیوں سے نکل گیا کہ ``اے برادران قوم، میں نے اپنے رب کے پیغامات تمہیں پہنچا دیے اور تمہاری خیر خواہی کا حق ادا کر دیا اب میں اُس قوم پر کیسے افسوس کروں جو قبول حق سے انکار کرتی ہے"\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mxlviii{کبھی ایسا نہیں ہوا کہ ہم نے کسی بستی میں نبی بھیجا ہو اور اُس بستی کے لوگوں کو پہلے تنگی اور سختی میں مبتلا نہ کیا ہو اس خیال سے کہ شاید وہ عاجزی پر اتر آئیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mxlix{پھر ہم نے ان کی بدحالی کو خوش حالی سے بدل دیا یہاں تک کہ وہ خوب پھلے پھولے اور کہنے لگے کہ ``ہمارے اسلاف پر بھی اچھے اور برے دن آتے ہی رہے ہیں" آخر کار ہم نے انہیں اچانک پکڑ لیا اور انہیں خبر تک نہ ہوئی\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ml{اگر بستیوں کے لوگ ایمان لاتے اور تقویٰ کی روش اختیار کرتے تو ہم ان پر آسمان اور زمین سے برکتوں کے دروازے کھو ل دیتے، مگر اُنہوں نے تو جھٹلایا، لہٰذا ہم نے اُس بری کمائی کے حساب میں انہیں پکڑ لیا جو وہ سمیٹ رہے تھے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mli{پھر کیا بستیوں کے لوگ اب اس سے بے خوف ہو گئے ہیں کہ ہماری گرفت کبھی اچانک اُن پر رات کے وقت نہ آ جائے گی جب کہ وہ سوتے پڑے ہوں؟\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mlii{یا انہیں اطمینان ہو گیا ہے کہ ہمارا مضبوط ہاتھ کبھی یکایک ان پر دن کے وقت نہ پڑے گا جب کہ وہ کھیل رہے ہوں؟\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mliii{کیا یہ لوگ اللہ کی چال سے بے خوف ہیں؟ حالانکہ اللہ کی چال سے وہی قوم بے خوف ہوتی ہے جو تباہ ہونے والی ہو\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mliv{اور کیا اُن لوگوں کو جو سابق اہل زمین کے بعد زمین کے وارث ہوتے ہیں، اِس امر واقعی نے کچھ سبق نہیں دیا کہ اگر ہم چاہیں تو ان کے قصوروں پر انہیں پکڑ سکتے ہیں؟ (مگر وہ سبق آموز حقائق سے تغافل برتتے ہیں) اور ہم ان کے دلوں پر مہر لگا دیتے ہیں، پھر وہ کچھ نہیں سنتے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mlv{یہ قومیں جن کے قصے ہم تمہیں سنا رہے ہیں (تمہارے سامنے مثال میں موجود ہیں) ان کے رسول ان کے پا س کھلی کھلی نشانیاں لے کر آئے، مگر جس چیز کو وہ ایک دفعہ جھٹلا چکے تھے پھر اُسے وہ ماننے والے نہ تھے دیکھو اس طرح ہم منکرین حق کے دلوں پر مہر لگا دیتے ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mlvi{ہم نے ان میں سے اکثر میں کوئی پاس عہد نہ پایا بلکہ اکثر کو فاسق ہی پایا\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mlvii{پھر اُن قوموں کے بعد (جن کا ذکر اوپر کیا گیا) ہم نے موسیٰؑ کو اپنی نشانیوں کے ساتھ فرعون اور اس کی قوم کے سرداروں کے پاس بھیجا مگر انہوں نے بھی ہماری نشانیوں کے ساتھ ظلم کیا، پس دیکھو کہ ان مفسدوں کا کیا انجام ہوا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mlviii{موسیٰؑ نے کہا ``اے فرعون، میں کائنات کے مالک کی طرف سے بھیجا ہوا آیا ہو ں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mlix{میرا منصب یہی ہے کہ اللہ کا نام لے کر کوئی بات حق کے سوا نہ کہوں، میں تم لوگوں کے پاس تمہارے رب کی طرف سے صریح دلیل ماموریت لے کر آیا ہوں، لہٰذا تو بنی اسرائیل کو میرے ساتھ بھیج دے"\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mlx{فرعون نے کہا ``اگر تو کوئی نشانی لایا ہے اور اپنے دعوے میں سچا ہے تو اسے پیش کر"\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mlxi{موسیٰؑ نے اپنا عصا پھینکا اور یکا یک وہ ایک جیتا جاگتا اژدہا تھا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mlxii{اس نے اپنی جیب سے ہاتھ نکالا اور سب دیکھنے والوں کے سامنے وہ چمک رہا تھا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mlxiii{ا س پر فرعون کی قوم کے سرداروں نے آپس میں کہا کہ ``یقیناً یہ شخص بڑا ماہر جادو گر ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mlxiv{تمہیں تمہاری زمین سے بے دخل کرنا چاہتا ہے، اب کہو کیا کہتے ہو؟"\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mlxv{پھر اُن سب نے فرعون کو مشورہ دیا کہ اسے اور اس کے بھائی کو انتظار میں رکھیے اور تمام شہروں میں ہرکارے بھیج دیجیے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mlxvi{کہ ہر ماہر فن جادوگر کو آپ کے پاس لے آئیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mlxvii{چنانچہ جادوگر فرعون کے پاس آ گئے اُنہوں نے ``اگر ہم غالب رہے تو ہمیں اس کا صلہ تو ضرور ملے گا؟"\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mlxviii{فرعون نے جواب دیا ``ہاں، اور تم مقرب بارگاہ ہو گے"\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mlxix{پھر اُنہوں نے موسیٰؑ سے کہا ``تم پھینکتے ہو یا ہم پھینکیں؟"\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mlxx{موسیٰؑ نے جواب دیا ``تم ہی پھینکو" انہوں نے جو اپنے آنچھر پھینکے تو نگاہوں کو مسحور اور دلوں کو خوف زدہ کر دیا اور بڑا ہی زبردست جادو بنا لائے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mlxxi{ہم نے موسیٰؑ کو اشارہ کیا کہ پھینک اپنا عصا اس کا پھینکنا تھا کہ آن کی آن میں وہ ان کے اس جھوٹے طلسم کو نگلتا چلا گیا\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mlxxii{اس طرح جو حق تھا وہ حق ثابت ہوا اور جو کچھ اُنہوں نے بنا رکھا تھا وہ باطل ہو کر رہ گیا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mlxxiii{فرعون اور اس کے ساتھی میدان مقابلہ میں مغلوب ہوئے اور (فتح مند ہونے کے بجائے) الٹے ذلیل ہو گئے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mlxxiv{اور جادوگروں کا حال یہ ہوا کہ گویا کسی چیز نے اندر سے انہیں سجدے میں گرا دیا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mlxxv{کہنے لگے ``ہم نے مان لیا رب العالمین کو\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mlxxvi{اُس رب کو جسے موسیٰؑ اور ہارونؑ مانتے ہیں"\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mlxxvii{فرعون نے کہا ``تم اس پر ایمان لے آئے قبل اس کے کہ میں تمہیں اجازت دوں؟ یقیناً یہ کوئی خفیہ ساز ش تھی جو تم لوگوں نے اس دارالسلطنت میں کی تاکہ اس کے مالکوں کو اقتدار سے بے دخل کر دو اچھا توا س کا نتیجہ اب تمہیں معلوم ہوا جاتا ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mlxxviii{میں تمہارے ہاتھ پاؤں مخالف سمتوں سے کٹوا دوں گا اور اس کے بعد تم سب کو سولی پر چڑھاؤں گا"\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mlxxix{انہوں نے جواب دیا ``بہر حال ہمیں پلٹنا اپنے رب ہی کی طرف ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mlxxx{تو جس بات پر ہم سے انتقام لینا چاہتا ہے وہ اِس کے سوا کچھ نہیں کہ ہمارے رب کی نشانیاں جب ہمارے سامنے آ گئیں تو ہم نے انہیں مان لیا اے رب، ہم پر صبر کا فیضان کر اور ہمیں دنیا سے اٹھا تو اِس حال میں کہ ہم تیرے فرماں بردار ہوں"\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mlxxxi{فرعون سے اُس کی قوم کے سرداروں نے کہا ``کیا تو موسیٰؑ اور اُس کی قوم کو یونہی چھوڑ دے گا کہ ملک میں فساد پھیلائیں اور وہ تیری اور تیرے معبودوں کی بندگی چھوڑ بیٹھے؟" فرعون نے جواب دیا ``میں اُن کے بیٹوں کو قتل کراؤں گا اور اُن کی عورتوں کو جیتا رہنے دوں گا ہمارے اقتدار کی گرفت ان پر مضبوط ہے"\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mlxxxii{موسیٰؑ نے اپنی قوم سے کہا ``اللہ سے مدد مانگو اور صبر کرو، زمین اللہ کی ہے، اپنے بندوں میں سے جس کو چاہتا ہے اس کا وارث بنا دیتا ہے، اور آخری کامیابی انہی کے لیے جو اس سے ڈرتے ہوئے کام کریں"\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mlxxxiii{اس کی قوم کے لوگوں نے کہا ``تیرے آنے سے پہلے بھی ہم ستائے جاتے تھے اور اب تیرے آنے پر بھی ستائے جا رہے ہیں" اس نے جواب دیا ``قریب ہے وہ وقت کہ تمہارا رب تمہارے دشمن کو ہلاک کر دے اور تم کو زمین میں خلیفہ بنائے، پھر دیکھے کہ تم کیسے عمل کرتے ہو"\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mlxxxiv{ہم نے فرعون کے لوگوں کو کئی سال تک قحط اور پیداوار کی کمی میں مبتلا رکھا کہ شاید ان کو ہوش آئے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mlxxxv{مگر اُن کا حال یہ تھا کہ جب اچھا زمانہ آتا تو کہتے کہ ہم اِسی کے مستحق ہیں، اور جب برا زمانہ آتا تو موسیٰؑ اور اس کے ساتھیوں کو اپنے لیے فال بد ٹھیراتے، حالانکہ در حقیقت ان کی فال بد تو اللہ کے پاس تھی، مگر ان میں سے اکثر بے علم تھے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mlxxxvi{انہوں نے موسیٰؑ سے کہا کہ ``تو ہمیں مسحور کرنے کے لیے خواہ کوئی نشانی لے آئے، ہم تو تیری بات ماننے والے نہیں ہیں"\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mlxxxvii{آخر کار ہم نے ان پر طوفان بھیجا، ٹڈی دل چھوڑے، سرسریاں پھیلائیں، مینڈک نکالے، اور خو ن برسایا یہ سب نشانیاں الگ الگ کر کے دکھائیں، مگر وہ سر کشی کیے چلے گئے اور وہ بڑے ہی مجرم لوگ تھے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mlxxxviii{جب کبھی اُن پر بلا نازل ہو جاتی تو کہتے ``اے موسیٰؑ، تجھے اپنے رب کی طرف سے جو منصب حاصل ہے اس کی بنا پر ہمارے حق میں دعا کر، اگر اب کے تو ہم پر سے یہ بلا ٹلوا دے تو ہم تیری بات مان لیں گے اور بنی اسرائیل کو تیرے ساتھ بھیج دیں گے"\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mlxxxix{مگر جب ہم ان پر سے اپنا عذاب ایک وقت مقرر تک کے لیے، جس کو وہ بہرحال پہنچنے والے تھے، ہٹا لیتے تو وہ یکلخت اپنے عہد سے پھر جاتے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mxc{تب ہم نے اُن سے انتقام لیا اور انہیں سمندر میں غرق کر دیا کیونکہ انہوں نے ہماری نشانیوں کو جھٹلایا تھا اور اُن سے بے پروا ہو گئے تھے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mxci{اور اُن کی جگہ ہم نے اُن لوگوں کو جو کمزور بنا کر رکھے گئے تھے، اُس سرزمین کے مشرق و مغرب کا وارث بنا دیا جسے ہم نے برکتوں سے مالا مال کیا تھا اس طرح بنی اسرائیل کے حق میں تیرے رب کا وعدہ خیر پورا ہوا کیونکہ اُنہوں نے صبر سے کام لیا تھا اور فرعون اور اس کی قوم کا وہ سب کچھ برباد کر دیا گیا جو وہ بناتے اور چڑھاتے تھے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mxcii{بنی اسرائیل کو ہم نے سمندر سے گزار دیا، پھر وہ چلے اور راستے میں ایک ایسی قوم پر اُن کا گزر ہوا جو اپنے چند بتوں کی گرویدہ بنی ہوئی تھی کہنے لگے، ``اے موسیٰؑ، ہمارے لیے بھی کوئی ایسا معبود بنا دے جیسے اِن لوگوں کے معبود ہیں" موسیٰؑ نے کہا ``تم لوگ بڑی نادانی کی باتیں کرتے ہو\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mxciii{یہ لوگ جس طریقہ کی پیروی کر رہے ہیں وہ تو برباد ہونے والا ہے اور جو عمل وہ کر رہے ہیں وہ سراسر باطل ہے"\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mxciv{پھر موسیٰؑ نے کہا ``کیا میں اللہ کے سوا کوئی اور معبود تمہارے لیے تلاش کروں؟ حالانکہ وہ اللہ ہی ہے جس نے تمہیں دنیا بھر کی قوموں پر فضیلت بخشی ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mxcv{اور (اللہ فرماتا ہے) وہ وقت یاد کرو جب ہم نے فرعون والوں سے تمہیں نجات دی جن کا حال یہ تھا کہ تمہیں سخت عذاب میں مبتلا رکھتے تھے، تمہارے بیٹوں کو قتل کرتے اور تمہاری عورتوں کو زندہ رہنے دیتے تھے اور اس میں تمہارے رب کی طرف سے تمہاری بڑی آزمائش تھی\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mxcvi{ہم نے موسیٰؑ کو تیس شب و روز کے لیے (کوہ سینا پر) طلب کیا اور بعد میں دس دن کا اور اضافہ کر دیا، اِس طرح اُس کے رب کی مقرر کردہ مدت پورے چالیس دن ہو گئی موسیٰؑ نے چلتے ہوئے اپنے بھائی ہارونؑ سے کہا کہ ``میرے پیچھے تم میری قوم میں میری جانشینی کرنا اور ٹھیک کام کرتے رہنا اور بگاڑ پیدا کرنے والوں کے طریقے پر نہ چلنا"\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mxcvii{جب وہ ہمارے مقرر کیے ہوئے وقت پر پہنچا اور اس کے رب نے اس سے کلام کیا تو اس نے التجا کی کہ ``اے رب، مجھے یارائے نظر دے کہ میں تجھے دیکھوں" فرمایا ``تو مجھے نہیں دیکھ سکتا ہاں ذرا سامنے کے پہاڑ کی طرف دیکھ، اگر وہ اپنی جگہ قائم رہ جائے تو البتہ تو مجھے دیکھ سکے گا" چنانچہ اس کے رب نے جب پہاڑ پر تجلی کی تو اسے ریزہ ریزہ کر دیا اور موسیٰؑ غش کھا کر گر پڑا جب ہوش آیا تو بولا ``پاک ہے تیری ذات، میں تیرے حضور توبہ کرتا ہوں اور سب سے پہلا ایمان لانے والا میں ہوں"\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mxcviii{فرمایا ``اے موسیٰؑ، میں نے تمام لوگوں پر ترجیح دے کر تجھے منتخب کیا کہ میر ی پیغمبری کرے اور مجھ سے ہم کلام ہو پس جو کچھ میں تجھے دوں اسے لے اور شکر بجالا"\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mxcix{اس کے بعد ہم نے موسیٰؑ کو ہر شعبہ زندگی کے متعلق نصیحت اور ہر پہلو کے متعلق واضح ہدایت تختیوں پر لکھ کر دے دی اور اس سے کہا: ``اِن ہدایات کو مضبوط ہاتھوں سے سنبھال اور اپنی قوم کو حکم دے کہ ان کے بہتر مفہوم کی پیروی کریں عنقریب میں تمہیں فاسقوں کے گھر دکھاؤں گا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mc{میں اپنی نشانیوں سے اُن لوگوں کی نگاہیں پھیر دوں گا جو بغیر کسی حق کے زمین میں بڑے بنتے ہیں، وہ خواہ کوئی نشانی دیکھ لیں کبھی اس پر ایمان نہ لائیں گے، اگر سیدھا راستہ اُن کے سامنے آئے تو اسے اختیار نہ کریں گے اور اگر ٹیٹرھا راستہ نظر آئے تو اس پر چل پڑیں گے، اس لیے کہ انہوں نے ہماری نشانیوں کو جھٹلایا اور ان سے بے پروائی کرتے رہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mci{ہماری نشانیوں کو جس کسی نے جھٹلایا اور آخرت کی پیشی کا انکار کیا اُس کے سارے اعمال ضائع ہو گئے کیا لوگ اِس کے سوا کچھ اور جزا پا سکتے ہیں کہ جیسا کریں ویسا بھریں؟"\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mcii{موسیٰؑ کے پیچھے اس کی قوم کے لوگوں نے اپنے زیوروں سے ایک بچھڑے کا پتلا بنا لیا جس میں سے بیل کی سی آواز نکلتی تھی کیا اُنہیں نظر نہ آتا تھا کہ وہ نہ ان سے بولتا ہے نہ کسی معاملہ میں ان کی رہنمائی کرتا ہے؟ مگر پھر بھی اُنہوں نے اسے معبود بنا لیا اور وہ سخت ظالم تھے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mciii{پھر جب ان کی فریب خوردگی کا طلسم ٹوٹ گیا او ر اُنہوں نے دیکھ لیا کہ در حقیقت وہ گمراہ ہو گئے ہیں تو کہنے لگے کہ ``اگر ہمارے رب نے ہم پر رحم نہ فرمایا اور ہم سے درگزر نہ کیا تو ہم برباد ہو جائیں گے"\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mciv{ادھر سے موسیٰؑ غصے اور رنج میں بھرا ہوا اپنی قوم کی طرف پلٹا آتے ہی اس نے کہا ``بہت بری جانشینی کی تم لوگوں نے میرے بعد! کیا تم سے اتنا صبر نہ ہوا کہ اپنے رب کے حکم کا انتظار کر لیتے؟" اور تختیاں پھینک دیں اور اپنے بھا ئی (ہارونؑ) کے سر کے بال پکڑ کر اسے کھینچا ہارونؑ نے کہا ``اے میری ماں کے بیٹے، اِن لوگوں نے مجھے دبا لیا اور قریب تھا کہ مجھے مار ڈالتے پس تو دشمنوں کو مجھ پر ہنسنے کا موقع نہ دے اور اس ظالم گروہ کے ساتھ مجھے نہ شامل کر"\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mcv{تب موسیٰؑ نے کہا ``اے رب، مجھے اور میرے بھائی کو معاف کر اور ہمیں اپنی رحمت میں داخل فرما، تو سب سے بڑھ کر رحیم ہے"\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mcvi{(جواب میں ارشاد ہوا کہ) ``جن لوگوں نے بچھڑے کو معبود بنایا وہ ضرور اپنے رب کے غضب میں گرفتار ہو کر رہیں گے اور دنیا کی زندگی میں ذلیل ہوں گے جھوٹ گھڑنے والوں کو ہم ایسی ہی سزا دیتے ہیں\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mcvii{اور جو لوگ برے عمل کریں پھر توبہ کر لیں اور ایمان لے آئیں تو یقیناً اِس توبہ و ایمان کے بعد تیرا رب درگزر اور رحم فرمانے والا ہے"\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mcviii{پھر جب موسیٰؑ کا غصہ ٹھنڈا ہوا تو اس نے وہ تختیاں اٹھا لیں جن کی تحریر میں ہدایت اور رحمت تھی اُن لوگوں کے لیے جو اپنے رب سے ڈرتے ہیں\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mcix{اور اُس نے اپنی قوم کے ستر آدمیوں کو منتخب کیا تاکہ وہ (اُس کے ساتھ) ہمارے مقرر کیے ہوئے وقت پر حاضر ہوں جب اِن لوگوں کو ایک سخت زلزلے نے آ پکڑا تو موسیٰؑ نے عرض کیا ``اے میرے سرکار، آپ چاہتے تو پہلے ہی اِن کو اور مجھے ہلاک کرسکتے تھے کیا آپ اُس قصور میں جو ہم میں سے چند نادانوں نے کیا تھا ہم سب کو ہلاک کر دیں گے؟ یہ تو آپ کی ڈالی ہوئی ایک آزمائش تھی جس کے ذریعہ سے آپ جسے چاہتے ہیں گمراہی میں مبتلا کر دیتے ہیں اور جسے چاہتے ہیں ہدایت بخش دیتے ہیں ہمارے سر پرست تو آپ ہی ہیں پس ہمیں معاف کر دیجیے اور ہم پر رحم فرمائیے، آپ سب سے بڑھ کر معاف فرمانے والے ہیں\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mcx{اور ہمارے لیے اس دنیا کی بھلائی بھی لکھ دیجیے اور آخرت کی بھی، ہم نے آپ کی طرف رجوع کر لیا" جواب میں ارشاد ہوا ``سزا تو میں جسے چاہتا ہوں دیتا ہوں، مگر میری رحمت ہر چیز پر چھائی ہوئی ہے، اور اُسے میں اُن لوگوں کے حق میں لکھوں گا جو نافرمانی سے پرہیز کریں گے، زکوٰۃ دیں گے اور میری آیات پر ایمان لائیں گے"\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mcxi{(پس آج یہ رحمت اُن لوگوں کا حصہ ہے) جو اِس پیغمبر، نبی امی کی پیروی اختیار کریں جس کا ذکر اُنہیں اپنے ہاں تورات اور انجیل میں لکھا ہوا ملتا ہے وہ انہیں نیکی کا حکم دیتا ہے، بدی سے روکتا ہے، ان کے لیے پاک چیزیں حلال او ر ناپاک چیزیں حرام کرتا ہے، اور ان پر سے وہ بوجھ اتارتا ہے جو اُن پر لدے ہوئے تھے اور وہ بندشیں کھولتا ہے جن میں وہ جکڑے ہوئے تھے لہٰذا جو لوگ اس پر ایمان لائیں اور اس کی حمایت اور نصرت کریں اور اُس روشنی کی پیروی اختیار کریں جو اس کے ساتھ نازل کی گئی ہے، وہی فلاح پانے والے ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mcxii{اے محمدؐ، کہو کہ ``اے انسانو، میں تم سب کی طرف اُس خدا کا پیغمبر ہوں جو زمین اور آسمانوں کی بادشاہی کا مالک ہے، اُس کے سوا کوئی خدا نہیں ہے، وہی زندگی بخشتا ہے اور وہی موت دیتا ہے، پس ایمان لاؤ اللہ پر اور اس کے بھیجے ہوئے نبی اُمی پر جو اللہ اور اس کے ارشادات کو مانتا ہے، اور پیروی اختیار کرو اُس کی، امید ہے کہ تم راہ راست پا لو گے"\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mcxiii{موسیٰؑ کی قوم میں ایک گروہ ایسا بھی تھا جو حق کے مطابق ہدایت کرتا اور حق ہی کے مطابق انصاف کرتا تھا\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mcxiv{اور ہم نے اس قوم کو بارہ گھرانوں میں تقسیم کر کے انہیں مستقل گروہوں کی شکل دے دی تھی اور جب موسیٰؑ سے اس کی قوم نے پانی مانگا تو ہم نے اس کو اشارہ کیا کہ فلاں چٹان پر اپنی لاٹھی مارو چنانچہ اس چٹان سے یکایک بارہ چشمے پھوٹ نکلے اور ہر گروہ نے اپنے پانی لینے کی جگہ متعین کر لی ہم نے اُن پر بادل کا سایہ کیا اور اُن پر من و سلویٰ اتارا کھاؤ وہ پاک چیزیں جو ہم نے تم کو بخشی ہیں مگر اس کے بعد انہوں نے جو کچھ کیا تو ہم پر ظلم نہیں کیا بلکہ آپ اپنے ہی اوپر ظلم کرتے رہے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mcxv{یاد کرو وہ وقت جب ان سے کہا گیا تھا کہ اِس بستی میں جا کر بس جاؤ اور اس کی پیداوار سے حسب منشا روزی حاصل کرو اور حطۃ حطۃ کہتے جاؤ اور شہر کے دروازے میں سجدہ ریز ہوتے ہوئے داخل ہو، ہم تمہاری خطائیں معاف کریں گے اور نیک رویہ رکھنے والوں کو مزید فضل سے نوازیں گے"\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mcxvi{مگر جو لوگ اُن میں سے ظالم تھے اُنہوں نے اُس بات کو جو اُن سے کہی گئی تھی بدل ڈالا، اور نتیجہ یہ ہوا کہ ہم نے ان کے ظلم کی پاداش میں ان پر آسمان سے عذاب بھیج دیا\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mcxvii{اور ذرا اِن سے اُ س بستی کا حال بھی پوچھو جو سمندر کے کنارے واقع تھی اِنہیں یاد دلاؤ وہ واقعہ کہ وہاں کے لوگ سبت (ہفتہ) کے دن احکام الٰہی کی خلاف ورزی کرتے تھے اور یہ کہ مچھلیاں سبت ہی کے دن ابھر ابھر کر سطح پر اُن کے سامنے آتی تھیں اور سبت کے سوا باقی دنوں میں نہیں آتی تھیں یہ اس لیے ہوتا تھا کہ ہم ان کی نافرمانیوں کی وجہ سے ان کو آزمائش میں ڈال رہے تھے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mcxviii{اور انہیں یہ بھی یاد لاؤ کہ جب اُن میں سے ایک گروہ نے دوسرے گروہ سے کہا تھا کہ ``تم ایسے لوگوں کو کیوں نصیحت کرتے ہو جنہیں اللہ ہلاک کرنے والا یا سخت سزا دینے والا ہے `` تو انہوں نے جواب دیا تھا کہ ``ہم یہ سب کچھ تمہارے رب کے حضور اپنی معذرت پیش کرنے کے لیے کرتے ہیں اور اس امید پر کرتے ہیں کہ شاید یہ لوگ اس کی نافرمانی سے پرہیز کرنے لگیں"\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mcxix{آخرکارجب وہ اُن ہدایات کو بالکل ہی فراموش کر گئے جو انہیں یاد کرائی گئی تھیں تو ہم نے اُن لوگوں کو بچا لیا جو برائی سے روکتے تھے اور باقی سب لوگوں کو جو ظالم تھے ان کی نافرمانیوں پر سخت عذاب میں پکڑ لیا\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mcxx{پھر جب وہ پوری سرکشی کے ساتھ وہی کام کیے چلے گئے جس سے انہیں روکا گیا تھا، تو ہم نے کہا کہ بندر ہو جاؤ ذلیل اور خوار\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mcxxi{اور یاد کرو جبکہ تمہارے رب نے اعلان کر دیا کہ ``وہ قیامت تک برابر ایسے لوگ بنی اسرائیل پر مسلط کرتا رہے گا جو ان کو بدترین عذاب دیں گے،" یقیناً تمہارا رب سزا دینے میں تیز دست ہے اور یقیناً وہ در گزر اور رحم سے بھی کام لینے والا ہے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mcxxii{ہم نے ان کو زمین میں ٹکڑے ٹکڑے کر کے بہت سی قوموں میں تقسیم کر دیا کچھ لوگ ان میں نیک تھے اور کچھ ا س سے مختلف اور ہم ان کو اچھے اور برے حالات سے آزمائش میں مبتلا کرتے رہے کہ شاید یہ پلٹ آئیں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mcxxiii{پھر اگلی نسلوں کے بعد ایسے نا خلف لوگ ان کے جانشین ہوئے جو کتاب الٰہی کے وارث ہو کر اِسی دنیائے دنی کے فائدے سمیٹتے ہیں اور کہہ دیتے ہیں کہ توقع ہے ہمیں معاف کر دیا جائے گا، اور اگر وہی متاع دنیا پھر سامنے آتی ہے تو پھر لپک کر اسے لے لیتے ہیں کیا ان سے کتاب کا عہد نہیں لیا جا چکا ہے کہ اللہ کے نام پر وہی بات کہیں جو حق ہو؟ اور یہ خود پڑھ چکے ہیں جو کتاب میں لکھا ہے آخرت کی قیام گاہ تو خدا ترس لوگوں کے لیے ہی بہتر ہے، کیا تم اتنی سی بات نہیں سمجھتے؟\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mcxxiv{جو لوگ کتاب کی پابندی کر تے ہیں اور جنہوں نے نماز قائم رکھی ہے، یقیناً ایسے نیک کردار لوگوں کا اجر ہم ضائع نہیں کریں گے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mcxxv{انہیں وہ وقت بھی کچھ یاد ہے جبکہ ہم نے پہاڑ کو ہلا کر ان پر اس طرح چھا دیا تھا کہ گویا وہ چھتری ہے اور یہ گمان کر رہے تھے کہ وہ ان پر آ پڑے گا اور اُس وقت ہم نے ان سے کہا تھا کہ جو کتاب ہم تمہیں دے رہے ہیں اسے مضبوطی کے ساتھ تھامو اور جو کچھ اس میں لکھا ہے اسے یاد رکھو، توقع ہے کہ تم غلط روی سے بچے رہو گے\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mcxxvi{اور اے نبی، لوگوں کو یاد دلاؤ وہ وقت جبکہ تمہارے رب نے بنی آدم کی پشتوں سے ان کی نسل کو نکالا تھا اور انہیں خود ان کے اوپر گواہ بناتے ہوئے پوچھا تھا ``کیا میں تمہارا رب نہیں ہوں؟" انہوں نے کہا ``ضرور آپ ہی ہمارے رب ہیں، ہم اس پر گواہی دیتے ہیں" یہ ہم نے اس لیے کیا کہ کہیں تم قیامت کے روز یہ نہ کہہ دو کہ ``ہم تو اس بات سے بے خبر تھے،"\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mcxxvii{یا یہ نہ کہنے لگو کہ ``شرک کی ابتدا تو ہمارے باپ دادا نے ہم سے پہلے کی تھی اور ہم بعد کو ان کی نسل سے پیدا ہوئے، پھر کیا آپ ہمیں اُس قصور میں پکڑتے ہیں جو غلط کار لوگوں نے کیا تھا"\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mcxxviii{دیکھو، اِس طرح ہم نشانیاں واضح طور پر پیش کرتے ہیں اور اس لیے کرتے ہیں کہ یہ لوگ پلٹ آئیں\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mcxxix{اور اے محمدؐ، اِن کے سامنے اُس شخص کا حال بیان کرو جس کو ہم نے اپنی آیات کا علم عطا کیا تھا مگر وہ ان کی پابندی سے نکل بھاگا آخرکار شیطان اس کے پیچھے پڑ گیا یہاں تک کہ وہ بھٹکنے والوں میں شامل ہو کر رہا\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mcxxx{اگر ہم چاہتے تو اسے اُن آیتوں کے ذریعہ سے بلندی عطا کرتے، مگر وہ تو زمین ہی کی طرف جھک کر رہ گیا اور اپنی خواہش نفس ہی کے پیچھے پڑا رہا، لہٰذا اس کی حالت کتے کی سی ہو گئی کہ تم اس پر حملہ کرو تب بھی زبان لٹکائے رہے اور اسے چھوڑ دو تب بھی زبان لٹکائے رہے یہی مثال ہے اُن لوگوں کی جو ہماری آیات کو جھٹلاتے ہیں تم یہ حکایات اِن کو سناتے رہو، شاید کہ یہ کچھ غور و فکر کریں\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mcxxxi{بڑی ہی بری مثال ہے ایسے لوگوں کی جنہوں نے ہماری آیات کو جھٹلایا، اور وہ آپ اپنے ہی اوپر ظلم کرتے رہے ہیں\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mcxxxii{جسے اللہ ہدایت بخشے بس وہی راہ راست پاتا ہے اور جس کو اللہ اپنی رہنمائی سے محروم کر دے وہی ناکام و نامراد ہو کر رہتا ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mcxxxiii{اور یہ حقیقت ہے کہ بہت سے جن اور انسان ایسے ہیں جن کو ہم نے جہنم ہی کے لیے پیدا کیا ہے ان کے پاس دل ہیں مگر وہ ان سے سوچتے نہیں ان کے پاس آنکھیں ہیں مگر وہ ان سے دیکھتے نہیں ان کے پاس کان ہیں مگر وہ ان سے سنتے نہیں وہ جانوروں کی طرح ہیں بلکہ ان سے بھی زیادہ گئے گزرے، یہ وہ لوگ ہیں جو غفلت میں کھو ئے گئے ہیں\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mcxxxiv{اللہ اچھے ناموں کا مستحق ہے، اس کو اچھے ہی ناموں سے پکارو اور اُن لوگوں کو چھوڑ دو جو اس کے نام رکھنے میں راستی سے منحرف ہو جاتے ہیں جو کچھ وہ کرتے رہے ہیں اس کا بدلہ وہ پاکر رہیں گے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mcxxxv{ہماری مخلوق میں ایک گروہ ایسا بھی ہے جو ٹھیک ٹھیک حق کے مطابق ہدایت اور حق ہی کے مطابق انصاف کرتا ہے\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mcxxxvi{رہے وہ لوگ جنہوں نے ہماری آیات کو جھٹلا دیا ہے، تو انہیں ہم بتدریج ایسے طریقہ سے تباہی کی طرف لے جائیں گے کہ انہیں خبر تک نہ ہوگی\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mcxxxvii{میں ان کو ڈھیل دے رہا ہوں، میری چال کا کوئی توڑ نہیں ہے\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mcxxxviii{اور کیا اِن لوگوں نے کبھی سوچا نہیں؟ اِن کے رفیق پر جنون کا کوئی اثر نہیں ہے وہ تو ایک خبردار ہے جو (برا انجام سامنے آنے سے پہلے) صاف صاف متنبہ کر رہا ہے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mcxxxix{کیا ان لوگوں نے آسمان و زمین کے انتظام پر کبھی غور نہیں کیا اور کسی چیز کو بھی جو خدا نے پیدا کی ہے آنکھیں کھول کر نہیں دیکھا؟ اور کیا یہ بھی انہوں نے نہیں سوچا کہ شاید اِن کی مہلت زندگی پوری ہونے کا وقت قریب آ لگا ہو؟ پھر آخر پیغمبرؐ کی اِس تنبیہ کے بعد اور کونسی بات ایسی ہو سکتی ہے جس پر یہ ایمان لائیں؟\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mcxl{جس کو اللہ رہنمائی سے محروم کر دے اُس کے لیے پھر کوئی رہنما نہیں ہے، اور اللہ اِنہیں اِن کی سرکشی ہی میں بھٹکتا ہوا چھوڑے دیتا ہے\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mcxli{یہ لوگ تم سے پوچھتے ہیں کہ آخر وہ قیامت کی گھڑی کب نازل ہوگی؟ کہو ``اس کا علم میرے رب ہی کے پاس ہے اُسے اپنے وقت پر وہی ظاہر کرے گا آسمانوں اور زمین میں وہ بڑا سخت وقت ہوگا وہ تم پر اچانک آ جائے گا" یہ لوگ اس کے متعلق تم سے اس طرح پوچھتے ہیں گویا کہ تم اس کی کھوج میں لگے ہوئے ہو کہو ``اس کا علم تو صرف اللہ کو ہے مگر اکثر لوگ اس حقیقت سے نا واقف ہیں"\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mcxlii{اے محمدؐ، ان سے کہو ``میں اپنی ذات کے لیے کسی نفع اور نقصان کا اختیار نہیں رکھتا، اللہ ہی جو کچھ چاہتا ہے وہ ہو تا ہے اور اگر مجھے غیب کا علم ہوتا تو میں بہت سے فائدے اپنے لیے حاصل کر لیتا اور مجھے کبھی کوئی نقصان نہ پہنچتا میں تو محض ایک خبردار کرنے والا اور خوش خبری سنانے والا ہوں اُن لوگوں کے لیے جو میری بات مانیں"\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mcxliii{وہ اللہ ہی ہے جس نے تمہیں ایک جان سے پیدا کیا اور اسی کی جنس سے اس کا جوڑا بنایا تاکہ اس کے پاس سکون حاصل کرے پھر جب مرد نے عورت کو ڈھانک لیا تو اسے ایک خفیف سا حمل رہ گیا جسے لیے لیے وہ چلتی پھرتی رہی پھر جب وہ بوجھل ہو گئی تو دونوں نے مل کر اللہ، اپنے رب سے دعا کی کہ اگر تو نے ہم کو اچھا سا بچہ دیا تو ہم تیرے شکر گزار ہوں گے\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mcxliv{مگر جب اللہ نے ان کو ایک صحیح و سالم بچہ دے دیا تو وہ اس کی اِس بخشش و عنایت میں دوسروں کو اس کا شریک ٹھیرانے لگے اللہ بہت بلند و برتر ہے ان مشرکانہ باتوں سے جو یہ لوگ کرتے ہیں\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mcxlv{کیسے نادان ہیں یہ لوگ کہ اُن کو خدا کا شریک ٹھیراتے ہیں جو کسی چیز کو بھی پیدا نہیں کرتے بلکہ خود پیدا کیے جاتے ہیں\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mcxlvi{جو نہ ان کی مدد کر سکتے ہیں اور نہ آپ اپنی مدد ہی پر قادر ہیں\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mcxlvii{اگر تم انہیں سیدھی راہ پر آنے کی دعوت دو تو وہ تمہارے پیچھے نہ آئیں، تم خواہ انہیں پکارو یا خاموش رہو، دونوں صورتوں میں تمہارے لیے یکساں ہی رہے\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mcxlviii{تم لوگ خدا کو چھوڑ کر جنہیں پکارتے ہو وہ تو محض بندے ہیں جیسے تم بندے ہو ان سے دعائیں مانگ دیکھو، یہ تمہاری دعاؤں کا جواب دیں اگر ان کے بارے میں تمہارے خیالات صحیح ہیں\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mcxlix{کیا یہ پاؤں رکھتے ہیں کہ ان سے چلیں؟ کیا یہ ہاتھ رکھتے ہیں کہ ان سے پکڑیں؟ کیا یہ آنکھیں رکھتے ہیں کہ ان سے دیکھیں؟ کیا یہ کان رکھتے ہیں کہ ان سے سنیں؟ اے محمدؐ، ان سے کہو کہ ``بلا لو اپنے ٹھیرائے ہوئے شریکوں کو پھر تم سب مل کر میرے خلاف تدبیریں کرو اور مجھے ہرگز مہلت نہ دو\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mcl{میرا حامی و ناصر وہ خدا ہے جس نے یہ کتاب نازل کی ہے اور وہ نیک آدمیوں کی حمایت کرتا ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mcli{بخلاف اِس کے تم جنہیں خدا کو چھوڑ کر پکارتے ہو وہ نہ تمہاری مدد کرسکتے ہیں اور نہ خود اپنی مدد ہی کرنے کے قابل ہیں\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mclii{بلکہ اگر تم انہیں سیدھی راہ پر آنے کے لیے کہو تو وہ تمہاری بات سن بھی نہیں سکتے بظاہر تم کو ایسا نظر آتا ہے کہ وہ تمہاری طرف دیکھ رہے ہیں مگر فی الواقع وہ کچھ بھی نہیں دیکھتے"\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mcliii{اے نبیؐ، نرمی و درگزر کا طریقہ اختیار کرو، معروف کی تلقین کیے جاؤ، اور جاہلوں سے نہ الجھو\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mcliv{اگر کبھی شیطان تمہیں اکسائے تو اللہ کی پناہ مانگو، وہ سب کچھ سننے اور جاننے والا ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mclv{حقیقت میں جو لو گ متقی ہیں اُن کا حال تو یہ ہوتا ہے کہ کبھی شیطان کے اثر سے کوئی برا خیال اگر انہیں چھو بھی جاتا ہے تو وہ فوراً چوکنے ہو جاتے ہیں اور پھر انہیں صاف نظر آنے لگتا ہے کہ ان کے لیے صحیح طریق کار کیا ہے\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mclvi{رہے ان کے (یعنی شیاطین کے) بھائی بند، تو وہ انہیں ان کی کج روی میں کھینچے لیے چلے جاتے ہیں اور انہیں بھٹکانے میں کوئی کسر اٹھا نہیں رکھتے\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mclvii{اے نبیؐ، جب تم اِن لوگوں کے سامنے کوئی نشانی (یعنی معجزہ) پیش نہیں کرتے تو یہ کہتے ہیں کہ تم نے اپنے لیے کوئی نشانی کیوں نہ انتخاب کر لی؟ ان سے کہو ``میں تو صرف اُس وحی کی پیروی کرتا ہوں جو میرے رب نے میری طرف بھیجی ہے یہ بصیرت کی روشنیاں ہیں تمہارے رب کی طرف سے اور ہدایت اور رحمت ہے اُن لوگوں کے لیے جو اِسے قبول کریں\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mclviii{جب قرآن تمہارے سامنے پڑھا جائے تو اسے توجہ سے سنو اور خاموش رہو، شاید کہ تم پر بھی رحمت ہو جائے"\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mclix{اے نبیؐ، اپنے رب کو صبح و شام یاد کیا کرو دل ہی دل میں زاری اور خوف کے ساتھ اور زبان سے بھی ہلکی آواز کے ساتھ تم ان لوگوں میں سے نہ ہو جاؤ جو غفلت میں پڑے ہوئے ہیں\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mclx{جو فرشتے تمہارے رب کے حضور تقرب کا مقام رکھتے ہیں وہ کبھی اپنی بڑائی کے گھمنڈ میں آ کر اس کی عبادت سے منہ نہیں موڑتے اور اس کی تسبیح کرتے ہیں، اور اس کے آگے جھکے رہتے ہیں\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mclxi{\basmalahur تم سے انفال کے متعلق پوچھتے ہیں؟ کہو “یہ انفال تو اللہ اور اُس کے رسُولؐ کے ہیں، پس تم لوگ اللہ سے ڈرو اور اپنے آپس کے تعلقات درست کرو اور اللہ اور اُس کے رسولؐ کی اطاعت کرو اگر تم مومن ہو"\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mclxii{سچّے اہل ایمان تو وہ لوگ ہیں جن کے دل اللہ کا ذکر سُن کر لرز جاتے ہیں اور جب اللہ کی آیات ان کے سامنے پڑھی جاتی ہیں تو ان کا ایمان بڑھ جاتا ہے اور وہ اپنے رب پر اعتماد رکھتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mclxiii{جو نماز قائم کرتے ہیں اور جو کچھ ہم نے ان کو دیا ہے اس میں سے (ہماری راہ میں) خرچ کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mclxiv{ایسے ہی لوگ حقیقی مومن ہیں ان کے لیے ان کے رب کے پاس بڑے درجے ہیں قصوروں سے درگزر ہے اور بہترین رزق ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mclxv{(اِس مال غنیمت کے معاملہ میں بھی ویسی ہی صورت پیش آ رہی ہے جیسی اُس وقت پیش آئی تھی جبکہ) تیرا رب تجھے حق کے ساتھ تیرے گھر سے نکال لایا تھا اور مومنوں میں سے ایک گروہ کو یہ سخت ناگوار تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mclxvi{وہ اس حق کے معاملہ میں تجھ سے جھگڑ رہے تھے دراں حالے کہ وہ صاف صاف نمایاں ہو چکا تھا ان کا حال یہ تھا کہ گویا وہ آنکھوں دیکھے موت کی طرف ہانکے جا رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mclxvii{یاد کرو وہ موقع جب کہ اللہ تم سے وعدہ کر رہا تھا کہ دونوں گروہوں میں سے ایک تمہیں مِل جائے گا تم چاہتے تھے کہ کمزور گروہ تمہیں ملے مگر اللہ کا ارادہ یہ تھا کہ اپنے ارشادات سے حق کو حق کر دکھائے اور کافروں کی جڑ کاٹ دے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mclxviii{تاکہ حق حق ہو کر رہے اور باطل باطل ہو جائے خواہ مجرموں کو یہ کتنا ہی ناگوار ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mclxix{اور وہ موقع یاد کرو جبکہ تم اپنے رب سے فریاد کر رہے تھے جواب میں اس نے فرمایا کہ میں تمہاری مدد کے لیے پے در پے ایک ہزار فرشتے بھیج رہا ہوں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mclxx{یہ بات اللہ نے تمہیں صرف اس لیے بتا دی کہ تمہیں خوشخبری ہو اور تمہارے دل اس سے مطمئن ہو جائیں، ورنہ مدد تو جب بھی ہوتی ہے اللہ ہی کی طرف سے ہوتی ہے، یقیناً اللہ زبردست اور دانا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mclxxi{اور وہ وقت جبکہ اللہ اپنی طرف سے غنودگی کی شکل میں تم پر اطمینان و بے خوفی کی کیفیت طاری کر رہا تھا، اور آسمان سے تمہارے اوپر پانی برسا رہا تھا تاکہ تمہیں پاک کرے اور تم سے شیطان کی ڈالی ہوئی نجاست دُور کرے اور تمہاری ہمت بندھائے اور اس کے ذریعہ سے تمہارے قدم جما دے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mclxxii{اور وہ وقت جبکہ تمہارا رب فرشتوں کو اشارہ کر رہا تھا کہ “میں تمہارے ساتھ ہوں، تم اہلِ ایمان کو ثابت قدم رکھو، میں ابھی ان کافروں کے دلوں میں رُعب ڈالے دیتا ہوں، پس تم ان کی گردنوں پر ضرب اور جوڑ جوڑ پر چوٹ لگاؤ"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mclxxiii{یہ اس لیے کہ ان لوگوں نے اللہ اور اس کے رسولؐ کا مقابلہ کیا اور جو اللہ اور اس کے رسولؐ کا مقابلہ کرے اللہ اس کے لیے نہایت سخت گیر ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mclxxiv{یہ ہے تم لوگوں کی سزا، اب اس کا مزا چکھو، اور تمہیں معلوم ہو کہ حق کا انکار کرنے والوں کے لیے دوزخ کا عذاب ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mclxxv{اے ایمان لانے والو، جب تم ایک لشکر کی صورت میں کفار سے دوچار ہو تو ان کے مقابلہ میں پیٹھ نہ پھیرو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mclxxvi{جس نے ایسے موقع پر پیٹھ پھیری، الا یہ کہ جنگی چال کے طور پر ایسا کرے یا کسی دُوسری فوج سے جا ملنے کے لیے، تو وہ اللہ کے غضب میں گھِر جائے گا، اُس کا ٹھکانہ جہنم ہوگا، اور وہ بہت بُری جائے بازگشت ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mclxxvii{پس حقیقت یہ ہے کہ تم نے انہیں قتل نہیں کیا بلکہ اللہ نے ان کو قتل کیا اور تو نے نہیں پھینکا بلکہ اللہ نے پھینکا (اور مومنوں کے ہاتھ جو اِس کام میں استعمال کیے گئے) تو یہ اس لیے تھا کہ اللہ مومنوں کو ایک بہترین آزمائش سے کامیابی کے ساتھ گزار دے، یقیناً اللہ سُننے والا اور جاننے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mclxxviii{یہ معاملہ تو تمہارے ساتھ ہے اور کافروں کے ساتھ معاملہ یہ ہے کہ اللہ ان کی چالوں کو کمزور کرنے والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mclxxix{(اِن کافروں سے کہہ دو) “اگر تم فیصلہ چاہتے تھے تو لو، فیصلہ تمہارے سامنے آ گیا اب باز آ جاؤ تو تمہارے ہی لیے بہتر ہے، ورنہ پھر پلٹ کر اسی حماقت کا اعادہ کرو گے تو ہم بھی اسی سزا کا اعادہ کریں گے اور تمہاری جمعیت، خواہ وہ کتنی ہی زیادہ ہو، تمہارے کچھ کام نہ آ سکے گی اللہ مومنوں کے ساتھ ہے"\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mclxxx{اے ایمان لانے والو، اللہ اور اُس کے رسُول کی اطاعت کرو اور حکم سُننے کے بعد اس سے سرتابی نہ کرو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mclxxxi{اُن لوگوں کی طرح نہ ہو جاؤ جنہوں نے کہا کہ ہم نے سُنا حالانکہ وہ نہیں سُنتے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mclxxxii{یقیناً خدا کے نزدیک بدترین قسم کے جانور وہ بہرے گونگے لوگ ہیں جو عقل سے کام نہیں لیتے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mclxxxiii{اگر اللہ کو معلوم ہوتا کہ ان میں کچھ بھی بھلائی ہے تو وہ ضرور انہیں سُننے کی توفیق دیتا (لیکن بھلائی کے بغیر) اگر وہ ان کو سُنواتا تو وہ بے رُخی کے ساتھ منہ پھیر جاتے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mclxxxiv{اے ایمان لانے والو، اللہ اور اس کے رسول کی پکار پر لبیک کہو جبکہ رسُول تمہیں اس چیز کی طرف بُلائے جو تمہیں زندگی بخشنے والی ہے، اور جان رکھو کہ اللہ آدمی اور اس کے دل کے درمیان حائل ہے اور اسی کی طرف تم سمیٹے جاؤ گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mclxxxv{اور بچو اُس فتنے سے جس کی شامت مخصوص طور پر صرف اُنہی لوگوں تک محدود نہ رہے گی جنہوں نے تم میں سے گناہ کیا ہو اور جان رکھو کہ اللہ سخت سزا دینے والا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mclxxxvi{یاد کرو وہ وقت جبکہ تم تھوڑے تھے، زمین میں تم کو بے زور سمجھا جاتا تھا، تم ڈرتے رہتے تھے کہ کہیں لوگ تمہیں مٹا نہ دیں پھر اللہ نے تم کو جائے پناہ مہیا کر دی، اپنی مدد سے تمہارے ہاتھ مضبُوط کیے اور تمہیں اچھا رزق پہنچایا، شاید کہ تم شکر گزار بنو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mclxxxvii{اے ایمان لانے والو، جانتے بُوجھتے اللہ اور اس کے رسُولؐ کے ساتھ خیانت نہ کرو، اپنی امانتوں میں غداری کے مرتکب نہ ہو\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mclxxxviii{اور جان رکھو کہ تمہارے مال اور تمہاری اولاد حقیقت میں سامانِ آزمائش ہیں اور اللہ کے پاس اجر دینے کے لیے بہت کچھ ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mclxxxix{اے ایمان لانے والو، اگر تم خدا ترسی اختیار کرو گے تو اللہ تمہارے لیے کسوٹی بہم پہنچا دے گا اور تمہاری بُرائیوں کو تم سے دُور کر دے گا، اور تمہارے قصور معاف کر دے گا اللہ بڑا فضل فرمانے والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcxc{وہ وقت بھی یاد کرنے کے قابل ہے جبکہ منکرینِ حق تیرے خلاف تدبیریں سوچ رہے تھے کہ تجھے قید کر دیں یا قتل کر ڈالیں یا جلا وطن کر دیں وہ اپنی چالیں چل رہے تھے اور اللہ اپنی چال چل رہا تھا اور اللہ سب سے بہتر چال چلنے والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcxci{جب ان کو ہماری آیات سنائی جاتی تھیں تو کہتے تھے کہ “ہاں سُن لیا ہم نے، ہم چاہیں تو ایسی ہی باتیں ہم بھی بنا سکتے ہیں، یہ تو وہی پُرانی کہانیاں ہیں جو پہلے سے لوگ کہتے چلے آ رہے ہیں ``\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcxcii{اور وہ بات بھی یاد ہے جو اُنہوں نے کہی تھی کہ “خدایا اگر یہ واقعی حق ہے اور تیری طرف سے ہے تو ہم پر آسمان سے پتھر برسا دے یا کوئی درد ناک عذاب ہم پر لے آ"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcxciii{اُس وقت تو اللہ ان پر عذاب نازل کرنے والا نہ تھا جبکہ تو ان کے درمیان موجود تھا اور نہ اللہ کا یہ قاعدہ ہے کہ لوگ استغفار کر رہے ہوں اور وہ ان کو عذاب دیدے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcxciv{لیکن اب کیوں نہ وہ ان پر عذاب نازل کرے جبکہ وہ مسجد حرام کا راستہ روک رہے ہیں، حالانکہ وہ اس مسجد کے جائز متولی نہیں ہیں اس کے جائز متولی تو صرف اہلِ تقویٰ ہی ہو سکتے ہیں مگر اکثر لوگ اس بات کو نہیں جانتے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcxcv{بیت اللہ کے پاس ان لوگوں کی نماز کیا ہوتی ہے، بس سیٹیاں بجاتے اور تالیاں پیٹتے ہیں پس اب لو، اِس عذاب کا مزہ چکھو اپنے اُس انکارِ حق کی پاداش میں جو تم کرتے رہے ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcxcvi{جن لوگوں نے حق کو ماننے سے انکار کیا ہے وہ اپنے مال خدا کے راستے سے روکنے کے لیے صرف کر رہے ہیں اور ابھی اور خرچ کرتے رہیں گے مگر آخر کار یہی کوششیں ان کے لیے پچھتاوے کا سبب بنیں گی، پھر وہ مغلوب ہوں گے، پھر یہ کافر جہنم کی طرف گھیر لائے جائیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcxcvii{تاکہ اللہ گندگی کو پاکیزگی سے چھانٹ کر الگ کرے اور ہر قسم کی گندگی کو ملا کر اکٹھا کرے پھر اس پلندے کو جہنم میں جھونک دے یہی لوگ اصلی دیوالیے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcxcviii{اے نبیؐ، ان کافروں سے کہو کہ اگر اب بھی باز آ جائیں تو جو کچھ پہلے ہو چکا ہے اس سے درگزر کر لیا جائے گا، لیکن اگر یہ اسی پچھلی روش کا اعادہ کریں گے تو گزشتہ قوموں کے ساتھ جو کچھ ہو چکا ہے وہ سب کو معلوم ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcxcix{اے ایمان لانے والو، ان کافروں سے جنگ کرو یہاں تک کہ فتنہ باقی نہ رہے اور دین پورا کا پورا اللہ کے لیے ہو جائے پھر اگر وہ فتنہ سے رُک جائیں تو ان کے اعمال کا دیکھنے والا اللہ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcc{اور اگر وہ نہ مانیں تو جان رکھو کہ اللہ تمہارا سرپرست ہے اور وہ بہترین حامی و مدد گار ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcci{اور تمہیں معلوم ہو کہ جو کچھ مال غنیمت تم نے حاصل کیا ہے اس کا پانچواں حصہ اللہ اور اس کے رسُولؐ اور رشتہ داروں اور یتیموں اور مسکینوں اور مسافروں کے لیے ہے اگر تم ایمان لائے ہو اللہ پر اور اس چیز پر جو فیصلے کے روز، یعنی دونوں فوجوں کی مڈبھیڑ کے دن، ہم نے اپنے بندے پر نازل کی تھی، (تو یہ حصہ بخوشی ادا کرو) اللہ ہر چیز پر قادر ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mccii{یاد کرو وہ وقت جبکہ تم وادی کے اِس جانب تھے اور وہ دُوسری جانب پڑاؤ ڈالے ہوئے تھے اور قافلہ تم سے نیچے (ساحل) کی طرف تھا اگر کہیں پہلے سے تمہارے اور ان کے درمیان مقابلہ کی قرارداد ہو چکی ہوتی تو تم ضرور اس موقع پر پہلو تہی کر جاتے، لیکن جو کچھ پیش آیا وہ اس لیے تھا کہ جس بات کا فیصلہ اللہ کر چکا تھا اسے ظہُور میں لے آئے تاکہ جسے ہلاک ہونا ہے وہ دلیل روشن کے ساتھ ہلاک ہو اور جسے زندہ رہنا ہے وہ دلیل روشن کے ساتھ زندہ رہے، یقیناً خدا سُننے والا اور جاننے والا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcciii{اور یاد کرو وہ وقت جبکہ اے نبیؐ، خدا اُن کو تمہارے خواب میں تھوڑا دکھا رہا تھا، اگر کہیں وہ تمہیں اُن کی تعداد زیادہ دکھا دیتا تو ضرور تم لوگ ہمت ہار جاتے اور لڑائی کے معاملہ میں جھگڑا شروع کر دیتے، لیکن اللہ ہی نے اِس سے تمہیں بچایا، یقیناً وہ سینوں کا حال تک جانتا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcciv{اور یاد کرو جب کہ مقابلے کے وقت خدا نے تم لوگوں کی نگاہوں میں دشمنوں کو تھوڑا دکھایا اور ان کی نگاہوں میں تمہیں کم کر کے پیش کیا، تاکہ جو بات ہونی تھی اُسے اللہ ظہُور میں لے آئے، اور آخر کار سارے معاملات اللہ ہی کی طرف رجوع کرتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mccv{اے ایمان لانے والو، جب کسی گروہ سے تمہارا مقابلہ ہو تو ثابت قدم رہو اور اللہ کو کثرت سے یاد کرو، توقع ہے کہ تمہیں کامیابی نصیب ہو گی\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mccvi{اور اللہ اور اس کے رسُول کی اطاعت کرو اور آپس میں جھگڑو نہیں ورنہ تمہارے اندر کمزوری پیدا ہو جائے گی اور تمہاری ہوا اکھڑ جائے گی صبر سے کام لو، یقیناً اللہ صبر کرنے والوں کے ساتھ ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mccvii{اور اُن لوگوں کے سے رنگ ڈھنگ نہ اختیار کرو جو اپنے گھروں سے اِتراتے اور لوگوں کو اپنی شان دکھاتے ہوئے نکلے اور جن کی روش یہ ہے کہ اللہ کے راستے سے روکتے ہیں جو کچھ وہ کر رہے ہیں وہ اللہ کی گرفت سے باہر نہیں ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mccviii{ذرا خیال کرو اس وقت کا جب کہ شیطان نے ان لوگوں کے کرتوت ان کی نگاہوں میں خوشنما بنا کر دکھائے تھے اور ان سے کہا تھا کہ آج کوئی تم پر غالب نہیں آ سکتا اور یہ کہ میں تمہارے ساتھ ہوں مگر جب دونوں گروہوں کا آمنا سامنا ہوا تو وہ اُلٹے پاؤں پھر گیا اور کہنے لگا کہ میرا تمہارا ساتھ نہیں ہے، میں وہ کچھ دیکھ رہا ہوں جو تم لوگ نہیں دیکھتے، مجھے خدا سے ڈر لگتا ہے اور خدا بڑی سخت سزا دینے والا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mccix{جب کہ منافقین اور وہ سب لوگ جن کے دلوں کو روگ لگا ہوا ہے، کہہ رہے تھے کہ ان لوگوں کو تو اِن کے دین نے خبط میں مبتلا کر رکھا ہے حالانکہ اگر کوئی اللہ پر بھروسہ کرے تو یقیناً اللہ بڑا زبردست اور دانا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mccx{کاش تم اُس حالت کو دیکھ سکتے جبکہ فرشتے مقتول کافروں کی رُوحیں قبض کر رہے تھے وہ ان کے چہروں اور ان کے کولھوں پر ضربیں لگاتے جاتے تھے اور کہتے جاتے تھے “لو اب جلنے کی سزا بھگتو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mccxi{یہ وہ جزا ہے جس کا سامان تمہارے اپنے ہاتھوں نے پیشگی مہیا کر رکھا تھا، ورنہ اللہ تو اپنے بندوں پر ظلم کرنے والا نہیں ہے ``\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mccxii{یہ معاملہ ان کے ساتھ اُسی طرح پیش آیا جس طرح آلِ فرعون اور ان سے پہلے کے دُوسرے لوگوں کے ساتھ پیش آتا رہا ہے کہ انہوں نے اللہ کی آیات کو ماننے سے انکار کیا اور اللہ نے ان کے گناہوں پر انہیں پکڑ لیا اللہ قوت رکھتا ہے اور سخت سزا دینے والا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mccxiii{یہ اللہ کی اِس سنت کے مطابق ہوا کہ وہ کسی نعمت کو جو اس نے کسی قوم کو عطا کی ہو اس وقت تک نہیں بدلتا جب تک کہ وہ قوم خود اپنے طرزِ عمل کو نہیں بدل دیتی اللہ سب کچھ سننے اور جاننے والا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mccxiv{آلِ فرعون اور ان سے پہلے کی قوموں کے ساتھ جو کچھ پیش آیا وہ اِسی ضابطہ کے مطابق تھا انہوں نے اپنے رب کی آیات کو جھٹلایا تب ہم نے ان کے گناہوں کی پاداش میں انہیں ہلاک کیا اور آل فرعون کو غرق کر دیا یہ سب ظالم لوگ تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxv{یقیناً اللہ کے نزدیک زمین پر چلنے والی مخلوق میں سب سے بدتر وہ لوگ ہیں جنہوں نے حق کو ماننے سے انکار کر دیا پھر کسی طرح وہ اسے قبول کرنے پر تیار نہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxvi{(خصوصاً) ان میں سے وہ لوگ جن کے ساتھ تو نے معاہدہ کیا پھر وہ ہر موقع پر اس کو توڑتے ہیں اور ذرا خدا کا خوف نہیں کرتے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxvii{پس اگر یہ لوگ تمہیں لڑائی میں مل جائیں تو ان کی ایسی خبر لو کہ ان کے بعد جو دُوسرے لوگ ایسی روش اختیار کرنے والے ہوں ان کے حواس باختہ ہو جائیں توقع ہے کہ کہ بد عہدوں کے اِس انجام سے وہ سبق لیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxviii{اور اگر کبھی تمہیں کسی قوم سے خیانت کا اندیشہ ہو تو اس کے معاہدے کو علانیہ اس کے آگے پھینک دو، یقیناً اللہ خائنوں کو پسند نہیں کرتا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxix{منکرینِ حق اس غلط فہمی میں نہ رہیں کہ وہ بازی لے گئے، یقیناً وہ ہم کو ہرا نہیں سکتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxx{اور تم لوگ، جہاں تک تمہارا بس چلے، زیادہ سے زیادہ طاقت اور تیار بندھے رہنے والے گھوڑے اُن کے مقابلہ کے لیے مہیا رکھو تاکہ اس کے ذریعہ سے اللہ کے اور اپنے دشمنوں کو اور ان دُوسرے اعداء کو خوف زدہ کرو جنہیں تم نہیں جانتے مگر اللہ جانتا ہے اللہ کی راہ میں جو کچھ تم خرچ کرو گے اس کا پورا پورا بدل تمہاری طرف پلٹایا جائے گا اور تمہارے ساتھ ہرگز ظلم نہ ہوگا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxxi{اور اے نبیؐ، اگر دشمن صلح و سلامتی کی طرف مائل ہوں تو تم بھی اس کے لیے آمادہ ہو جاؤ اور اللہ پر بھروسہ کرو، یقیناً وہی سننے اور جاننے والا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxxii{اور اگر وہ دھوکے کی نیت رکھتے ہوں تو تمہارے لیے اللہ کافی ہے وہی تو ہے جس نے اپنی مدد سے اور مومنوں کے ذریعہ سے تمہاری تائید کی\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxxiii{اور مومنوں کے دل ایک دُوسرے کے ساتھ جوڑ دیے تم روئے زمین کی ساری دولت بھی خرچ کر ڈالتے تو اِن لوگوں کے دل نہ جوڑ سکتے تھے مگر وہ اللہ ہے جس نے ان لوگوں کے دل جوڑے، یقیناً وہ بڑا زبردست اور دانا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxxiv{اے نبیؐ، تمہارے لیے اور تمہارے پیرو اہلِ ایمان کے لیے تو بس اللہ کافی ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccxxv{اے نبیؐ، مومنوں کو جنگ پر اُبھارو اگر تم میں سے بیس آدمی صابر ہوں تو وہ دو سو پر غالب آئیں گے اور اگر سو آدمی ایسے ہوں تو منکرین حق میں سے ہزار آدمیوں پر بھاری رہیں گے کیونکہ وہ ایسے لوگ ہیں جو سمجھ نہیں رکھتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccxxvi{اچھا، اب اللہ نے تمہارا بوجھ ہلکا کیا اور اسے معلوم ہوا کہ ابھی تم میں کمزوری ہے، پس اگر تم میں سے سو آدمی صابر ہوں تو وہ دو سو پر اور ہزار آدمی ایسے ہوں تو دو ہزار پر اللہ کے حکم سے غالب آئیں گے، اور اللہ ان لوگوں کے ساتھ ہے جو صبر کرنے والے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mccxxvii{کسی نبی کے لیے یہ زیبا نہیں ہے کہ اس کے پاس قیدی ہوں جب تک کہ وہ زمین میں دشمنوں کو اچھی طرح کچل نہ دے تم لوگ دنیا کے فائدے چاہتے ہو، حالانکہ اللہ کے پیشِ نظر آخرت ہے، اور اللہ غالب اور حکیم ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccxxviii{اگر اللہ کا نوشتہ پہلے نہ لکھا جا چکا ہوتا تو جو کچھ تم لوگوں نے لیا ہے اس کی پاداش میں تم کو بڑی سزا دی جاتی\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccxxix{پس جو کچھ تم نے مال حاصل کیا ہے اسے کھاؤ کہ وہ حلال اور پاک ہے اور اللہ سے ڈرتے رہو یقیناً اللہ درگزر کرنے والا اور رحم فرمانے والا ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mccxxx{اے نبیؐ، تم لوگوں کے قبضہ میں جو قیدی ہیں ان سے کہو اگر اللہ کو معلوم ہوا کہ تمہارے دلوں میں کچھ خیر ہے تو وہ تمہیں اُس سے بڑھ چڑھ کر دے گا جو تم سے لیا گیا ہے اور تمہاری خطائیں معاف کرے گا، اللہ درگزر کرنے والا اور رحم فرمانے والا ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mccxxxi{لیکن اگر وہ تیرے ساتھ خیانت کا ارادہ رکھتے ہیں تو اس سے پہلے وہ اللہ کے ساتھ خیانت کر چکے ہیں، چنانچہ اسی کی سزا اللہ نے انہیں دی کہ وہ تیرے قابو میں آ گئے، اللہ سب کچھ جانتا اور حکیم ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mccxxxii{جن لوگوں نے ایمان قبول کیا اور ہجرت کی اور اللہ کی راہ میں اپنی جانیں لڑائیں اور اپنے مال کھپائے، اور جن لوگوں نے ہجرت کرنے والوں کو جگہ دی اور ان کی مدد کی، وہی دراصل ایک دوسرے کے ولی ہیں رہے وہ لوگ جو ایمان تو لے آئے مگر ہجرت کر کے (دارالاسلام میں) آ نہیں گئے تو ان سے تمہارا ولایت کا کوئی تعلق نہیں ہے جب تک کہ وہ ہجرت کر کے نہ آ جائیں ہاں اگر وہ دین کے معاملہ میں تم سے مدد مانگیں تو ان کی مدد کرنا تم پر فرض ہے، لیکن کسی ایسی قوم کے خلاف نہیں جس سے تمہارا معاہدہ ہو جو کچھ تم کرتے ہو اللہ اسے دیکھتا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mccxxxiii{جو لوگ منکرِ حق ہیں وہ ایک دوسرے کی حمایت کرتے ہیں اگر تم یہ نہ کرو گے تو زمین میں فتنہ اور بڑا فساد برپا ہو گا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mccxxxiv{جو لوگ ایمان لائے اور جنہوں نے اللہ کی راہ میں گھر بار چھوڑے اور جدوجہد کی اور جنہوں نے پناہ دی اور مدد کی وہی سچے مومن ہیں ان کے لیے خطاؤں سے درگزر ہے اور بہترین رزق ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mccxxxv{اور جو لوگ بعد میں ایمان لائے اور ہجرت کر کے آ گئے اور تمہارے ساتھ مل کر جدوجہد کرنے لگے وہ بھی تم ہی میں شامل ہیں مگر اللہ کی کتاب میں خون کے رشتہ دار ایک دوسرے کے زیادہ حقدار ہیں، یقیناً اللہ ہر چیز کو جانتا ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mccxxxvi{\basmalahur اعلان برات ہے اللہ اور اس کے رسول کی طرف سے اُن مشرکین کو جن سے تم نے معاہدے کیے تھے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccxxxvii{پس تم لوگ ملک میں چار مہینے اور چل پھر لو اور جان رکھو کہ تم اللہ کو عاجز کرنے والے نہیں ہو، اور یہ کہ اللہ منکرین حق کو رسوا کرنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccxxxviii{اطلاع عام ہے اللہ اور اس کے رسول کی طرف سے حج اکبر کے دن تمام لوگوں کے لیے کہ اللہ مشرکین سے بری الذمہ ہے اور اُس کا رسول بھی اب اگر تم لوگ توبہ کر لو تو تمہارے ہی لیے بہتر ہے اور جو منہ پھیرتے ہو تو خوب سمجھ لو کہ تم اللہ کو عاجز کرنے والے نہیں ہو اور اے نبیؐ، انکار کرنے والوں کو سخت عذاب کی خوشخبری سنا دو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccxxxix{بجز اُن مشرکین کے جن سے تم نے معاہد ے کیے پھر انہوں نے اپنے عہد کو پورا کرنے میں تمہارے ساتھ کوئی کمی نہیں کی اور نہ تمہارے خلاف کسی کی مدد کی، تو ایسے لوگوں کے ساتھ تم بھی مدت معاہدہ تک وفا کرو کیونکہ اللہ متقیوں ہی کو پسند کرتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccxl{پس جب حرام مہینے گزر جائیں تو مشرکین کو قتل کرو جہاں پاؤ اور انہیں پکڑو اور گھیرو اور ہر گھات میں اُن کی خبر لینے کے لیے بیٹھو پھر اگر وہ توبہ کر لیں اور نماز قائم کریں اور زکوٰۃ دیں تو انہیں چھوڑ دو اللہ درگزر کرنے والا اور رحم فرمانے والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccxli{اور اگر مشرکین میں سے کوئی شخص پناہ مانگ کر تمہارے پاس آنا چاہے (تاکہ اللہ کا کلام سنے) تو اُسے پناہ دے دو یہاں تک کہ وہ اللہ کا کلام سن لے پھر اُسے اس کے مامن تک پہنچا دو یہ اس لیے کرنا چاہیے کہ یہ لوگ علم نہیں رکھتے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccxlii{اِن مشرکین کے لیے اللہ اور اس کے رسول کے نزدیک کوئی عہد آخر کیسے ہوسکتا ہے؟ بجز اُن لوگوں کے جن سے تم نے مسجد حرام کے پاس معاہدہ کیا تھا، تو جب تک وہ تمہارے ساتھ سیدھے رہیں تم بھی ان کے ساتھ سیدھے رہو کیونکہ اللہ متقیوں کو پسند کرتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccxliii{مگر اِن کے سوا دوسرے مشرکین کے ساتھ کوئی عہد کیسے ہوسکتا ہے جبکہ اُن کا حال یہ ہے کہ تم پر قابو پا جائیں تو نہ تمہارے معاملہ میں کسی قرابت کا لحاظ کریں نہ کسی معاہدہ کی ذمہ داری کا وہ اپنی زبانوں سے تم کو راضی کرنے کی کوشش کرتے ہیں مگر دل ان کے انکار کرتے ہیں اور ان میں سے اکثر فاسق ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccxliv{انہوں نے اللہ کی آیات کے بدلے تھوڑی سی قیمت قبول کر لی پھر اللہ کے راستے میں سدراہ بن کر کھڑے ہو گئے بہت برے کرتوت تھے جو یہ کرتے رہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccxlv{کسی مومن کے معاملہ میں نہ یہ قرابت کا لحاظ کرتے ہیں اور نہ کسی عہد کی ذمہ داری کا اور زیادتی ہمیشہ انہی کی طرف سے ہوئی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccxlvi{پس اگر یہ توبہ کر لیں اور نماز قائم کریں اور زکوٰۃ دیں تو تمہارے دینی بھائی ہیں اور جاننے والوں کے لیے ہم اپنے احکام واضح کیے دیتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccxlvii{اور اگر عہد کرنے کے بعد یہ پھر اپنی قسموں کو توڑ ڈالیں اور تمہارے دین پر حملے کرنے شروع کر دیں تو کفر کے علمبرداروں سے جنگ کرو کیونکہ ان کی قسموں کا اعتبار نہیں شاید کہ (پھر تلوار ہی کے زور سے) وہ باز آئیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccxlviii{کیا تم نہ لڑو گے ایسے لوگوں سے جو اپنے عہد توڑتے رہے ہیں اور جنہوں نے رسول کو ملک سے نکال دینے کا قصد کیا تھا اور زیادتی کی ابتدا کرنے والے وہی تھے؟ کیا تم ان سے ڈرتے ہو؟ اگر تم مومن ہو تو اللہ اِس کا زیادہ مستحق ہے کہ اس سے ڈرو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccxlix{ان سے لڑو، اللہ تمہارے ہاتھوں سے ان کو سزا دلوائے گا اور انہیں ذلیل و خوار کرے گا اور ان کے مقابلہ میں تمہاری مدد کرے گا اور بہت سے مومنوں کے دل ٹھنڈے کرے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccl{اور ان کے قلوب کی جلن مٹا دے گا، اور جسے چاہے گا توبہ کی توفیق بھی دے گا اللہ سب کچھ جاننے والا اور دانا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccli{کیا تم لوگوں نے یہ سمجھ رکھا ہے کہ یونہی چھوڑ دیے جاؤ گے حالانکہ ابھی اللہ نے یہ تو دیکھا ہی نہیں کہ تم میں سے کون وہ لوگ ہیں جنہوں نے (اس کی راہ میں) جاں فشانی کی اور اللہ اور رسول اور مومنین کے سوا کسی کو جگری دوست نہ بنایا، جو کچھ تم کرتے ہو اللہ اس سے باخبر ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcclii{مشرکین کا یہ کام نہیں ہے کہ وہ اللہ کی مسجدوں کے مجاور و خادم بنیں درآں حالیکہ اپنے اوپر وہ خود کفر کی شہادت دے رہے ہیں ان کے تو سارے اعمال ضائع ہو گئے اور جہنم میں انہیں ہمیشہ رہنا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccliii{اللہ کی مسجدوں کے آباد کار (مجاور و خادم) تو وہی لوگ ہوسکتے ہیں جو اللہ اور روز آخر کو مانیں اور نما ز قائم کریں، زکوٰۃ دیں اور اللہ کے سوا کسی سے نہ ڈریں انہی سے یہ توقع ہے کہ سیدھی راہ چلیں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccliv{کیا تم لوگوں نے حاجیوں کو پانی پلانے اور مسجد حرام کی مجاوری کرنے کو اس شخص کے کام کے برابر ٹھیرا لیا ہے جو ایمان لایا اللہ پر اور روز آخر پر اور جس نے جانفشانی کی اللہ کی راہ میں؟ اللہ کے نزدیک تو یہ دونوں برابر نہیں ہیں اور اللہ ظالموں کی رہنمائی نہیں کرتا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcclv{اللہ کے ہاں تو انہی لوگوں کا درجہ بڑا ہے جو ایمان لائے اور جنہوں نے اس کی راہ میں گھر بار چھوڑے اور جان و مال سے جہاد کیا وہی کامیاب ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcclvi{ان کا رب انہیں اپنی رحمت اور خوشنودی اور ایسی جنتوں کی بشارت دیتا ہے جہاں ان کے لیے پائیدار عیش کے سامان ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcclvii{ان میں وہ ہمیشہ رہیں گے یقیناً اللہ کے پاس خدمات کا صلہ دینے کو بہت کچھ ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcclviii{اے لوگو جو ایمان لائے ہو، اپنے باپوں اور بھائیوں کو بھی اپنا رفیق نہ بناؤ اگر وہ ایمان پر کفر کو ترجیح دیں تم میں سے جو ان کو رفیق بنائیں گے وہی ظالم ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcclix{اے نبیؐ، کہہ دو کہ اگر تمہارے باپ اور تمہارے بیٹے، اور تمہارے بھائی، اور تمہاری بیویاں اور تمہارے عزیز و اقارب اور تمہارے وہ مال جو تم نے کما ئے ہیں، اور تمہارے وہ کاروبار جن کے ماند پڑ جانے کا تم کو خوف ہے اور تمہارے وہ گھر جو تم کو پسند ہیں، تم کو اللہ اور اس کے رسول اور اس کی راہ میں جہاد سے عزیز تر ہیں تو انتظار کرو یہاں تک کہ اللہ اپنا فیصلہ تمہارے سامنے لے آئے، اور اللہ فاسق لوگوں کی رہنمائی نہیں کیا کرتا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcclx{اللہ اس سے پہلے بہت سے مواقع پر تمہاری مدد کر چکا ہے ابھی غزوہ حنین کے روز (اُس کی دستگیری کی شان تم دیکھ چکے ہو) اس روز تمہیں اپنی کثرت تعداد کا غرہ تھا مگر وہ تمہارے کچھ کام نہ آئی اور زمین اپنی وسعت کے باوجود تم پر تنگ ہو گئی اور تم پیٹھ پھیر کر بھاگ نکلے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcclxi{پھر اللہ نے اپنی سکینت اپنے رسول پر اور مومنین پر نازل فرمائی اور وہ لشکر اتارے جو تم کو نظر نہ آتے تھے اور منکرین حق کو سزا دی کہ یہی بدلہ ہے اُن لوگوں کے لیے جو حق کا انکار کریں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcclxii{پھر (تم یہ بھی دیکھ چکے ہو کہ) اس طرح سزا دینے کے بعد اللہ جس کو چاہتا ہے توبہ کی توفیق بھی بخش دیتا ہے، اللہ در گزر کرنے والا اور رحم فرمانے والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcclxiii{اے ایمان لانے والو، مشرکین ناپاک ہیں لہٰذا اس سال کے بعد یہ مسجد حرام کے قریب نہ پھٹکنے پائیں اور اگر تمہیں تنگ دستی کا خوف ہے تو بعید نہیں کہ اللہ چاہے تو تمہیں ا پنے فضل سے غنی کر دے، اللہ علیم و حکیم ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcclxiv{جنگ کرو اہل کتاب میں سے اُن لوگوں کے خلاف جو اللہ اور روز آخر پر ایمان نہیں لاتے اور جو کچھ اللہ اور اس کے رسول نے حرام قرار دیا ہے اسے حرام نہیں کرتے اور دین حق کو اپنا دین نہیں بناتے (ان سے لڑو) یہاں تک کہ وہ اپنے ہاتھ سے جزیہ دیں اور چھوٹے بن کر رہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcclxv{یہودی کہتے ہیں کہ عزیر اللہ کا بیٹا ہے، اور عیسائی کہتے ہیں کہ مسیح اللہ کا بیٹا ہے یہ بے حقیقت باتیں ہیں جو وہ اپنی زبانوں سے نکالتے ہیں اُن لوگوں کی دیکھا دیکھی جو ان سے پہلے کفر میں مبتلا ہوئے تھے خدا کی مار اِن پر، یہ کہاں سے دھوکہ کھار ہے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcclxvi{انہوں نے اپنے علماء اور درویشوں کو اللہ کے سوا اپنا رب بنا لیا ہے اور اسی طرح مسیح ابن مریم کو بھی حالانکہ ان کو ایک معبود کے سوا کسی کی بندگی کرنے کا حکم نہیں دیا گیا تھا، وہ جس کے سوا کوئی مستحق عبادت نہیں، پاک ہے وہ ان مشرکانہ باتوں سے جو یہ لوگ کرتے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcclxvii{یہ لوگ چاہتے ہیں کہ اللہ کی روشنی کو اپنی پھونکوں سے بجھا دیں مگر اللہ اپنی روشنی کو مکمل کیے بغیر ماننے والا نہیں ہے خواہ کافروں کو یہ کتنا ہی ناگوار ہو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcclxviii{وہ اللہ ہی ہے جس نے اپنے رسول کو ہدایت اور دین حق کے ساتھ بھیجا ہے تاکہ اسے پوری جنس دین پر غالب کر دے خواہ مشرکوں کو یہ کتنا ہی ناگوار ہو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcclxix{اے ایمان لانے والو، اِن اہل کتاب کے اکثر علماء اور درویشوں کا حال یہ ہے کہ وہ لوگوں کے مال باطل طریقوں سے کھاتے ہیں اور انہیں اللہ کی راہ سے روکتے ہیں دردناک سزا کی خوش خبری دو ان کو جو سونے اور چاندی جمع کر کے رکھتے ہیں اور انہیں خدا کی راہ میں خرچ نہیں کرتے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcclxx{ایک دن آئے گا کہ اسی سونے چاندی پر جہنم کی آگ دہکائی جائے گی اور پھر اسی سے ان لوگوں کی پیشانیوں اور پہلوؤں اور پیٹھوں کو داغا جائے گا یہ ہے وہ خزانہ جو تم نے اپنے لیے جمع کیا تھا، لو اب اپنی سمیٹی ہوئی دولت کا مزہ چکھو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcclxxi{حقیقت یہ ہے کہ مہینوں کی تعداد جب سے اللہ نے آسمان و زمین کو پیدا کیا ہے اللہ کے نوشتے میں بارہ ہی ہے، اور ان میں سے چار مہینے حرام ہیں یہی ٹھیک ضابطہ ہے لہٰذا ان چار مہینوں میں اپنے اوپر ظلم نہ کرو اور مشرکوں سے سب مل کر لڑو جس طرح وہ سب مل کر تم سے لڑتے ہیں اور جان رکھو کہ اللہ متقیوں ہی کے ساتھ ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcclxxii{نسی تو کفر میں ایک مزید کافرانہ حرکت ہے جس سے یہ کافر لوگ گمراہی میں مبتلا کیے جاتے ہیں کسی سال ایک مہینے کو حلال کر لیتے ہیں اور کسی سال اُس کو حرام کر دیتے ہیں، تاکہ اللہ کے حرام کیے ہوئے مہینوں کی تعداد پوری بھی کر دیں اور اللہ کا حرام کیا ہوا حلال بھی کر لیں ان کے برے اعمال ان کے لیے خوشنما بنا دیے گئے ہیں اور اللہ منکرین حق کو ہدایت نہیں دیا کرتا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcclxxiii{اے لوگو جو ایمان لائے ہو، تمہیں کیا ہو گیا کہ جب تم سے اللہ کی راہ میں نکلنے کے لیے کہا گیا تو تم زمین سے چمٹ کر رہ گئے؟ کیا تم نے آخرت کے مقابلہ میں دنیا کی زندگی کو پسند کر لیا؟ ایسا ہے تو تمہیں معلوم ہو کہ دنیوی زندگی کا یہ سب سروسامان آخرت میں بہت تھوڑا نکلے گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcclxxiv{تم نہ اٹھو گے تو خدا تمہیں دردناک سزا دے گا، اور تمہاری جگہ کسی اور گروہ کو اٹھائے گا، اور تم خدا کا کچھ بھی نہ بگاڑ سکو گے، وہ ہر چیز پر قدرت رکھتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcclxxv{تم نے اگر نبیؐ کی مدد نہ کی تو کچھ پروا نہیں، اللہ اُس کی مدد اس وقت کر چکا ہے جب کافروں نے اسے نکال دیا تھا، جب وہ صرف دو میں کا دوسرا تھا، جب وہ دونوں غار میں تھے، جب وہ اپنی ساتھی سے کہہ رہا تھا کہ ``غم نہ کر، اللہ ہمارے ساتھ ہے" اُس وقت اللہ نے اس پر اپنی طرف سے سکون قلب نازل کیا اور اس کی مدد ایسے لشکروں سے کی جو تم کو نظر نہ آتے تھے اور کافروں کا بول نیچا کر دیا اور اللہ کا بول تو اونچا ہی ہے، اللہ زبردست اور دانا و بینا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcclxxvi{نکلو، خواہ ہلکے ہو یا بوجھل، اور جہاد کرو اللہ کی راہ میں اپنے مالوں اور اپنی جانوں کے ساتھ، یہ تمہارے لیے بہتر ہے اگر تم جانو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcclxxvii{اے نبیؐ، اگر فائدہ سہل الحصول ہوتا اور سفر ہلکا ہوتا تو وہ ضرور تمہارے پیچھے چلنے پر آمادہ ہو جاتے، مگر ان پر تو یہ راستہ بہت کٹھن ہو گیا اب وہ خدا کی قسم کھا کھا کر کہیں گے کہ اگر ہم چل سکتے تو یقیناً تمہارے ساتھ چلتے وہ اپنے آپ کو ہلاکت میں ڈال رہے ہیں اللہ خوب جانتا ہے کہ وہ جھوٹے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcclxxviii{اے نبیؐ، اللہ تمہیں معاف کرے، تم نے کیوں انہیں رخصت دے دی؟ (تمہیں چاہیے تھا کہ خود رخصت نہ دیتے) تاکہ تم پر کھل جاتا کہ کون لوگ سچے ہیں اور جھوٹوں کو بھی تم جان لیتے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcclxxix{جو لوگ اللہ اور روز آخر پر ایمان رکھتے ہیں وہ تو کبھی تم سے یہ درخواست نہ کریں گے کہ انہیں اپنی جان و مال کے ساتھ جہاد کرنے سے معاف رکھا جائے اللہ متقیوں کو خوب جانتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcclxxx{ایسی درخواستیں تو صرف وہی لوگ کرتے ہیں جو اللہ اور روز آخر پر ایمان نہیں رکھتے، جن کے دلوں میں شک ہے اور وہ اپنے شک ہی میں متردد ہو رہے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcclxxxi{اگر واقعی ان کا ارادہ نکلنے کا ہوتا تو وہ اس کے لیے کچھ تیاری کرتے لیکن اللہ کو ان کا اٹھنا پسندہی نہ تھا، اس لیے اس نے انہیں سست کر دیا اور کہہ دیا کہ بیٹھ رہو بیٹھنے والوں کے ساتھ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcclxxxii{اگر وہ تمہارے ساتھ نکلتے تو تمہارے اندر خرابی کے سوا کسی چیز کا اضافہ نہ کرتے وہ تمہارے درمیان فتنہ پردازی کے لیے دوڑ دھوپ کرتے، اور تمہارے گروہ کا حال یہ ہے کہ ابھی اُس میں بہت سے ایسے لوگ موجود ہیں جو اُن کی باتیں کان لگا کر سنتے ہیں، اللہ اِن ظالموں کو خوب جانتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiii{اس سے پہلے بھی اِن لوگوں نے فتنہ انگیزی کی کوششیں کی ہیں اور تمہیں ناکام کرنے کے لیے یہ ہر طرح کی تدبیروں کا الٹ پھیر کر چکے ہیں یہاں تک کہ ان کی مرضی کے خلاف حق آ گیا اور اللہ کا کام ہو کر رہا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiv{ان میں سے کوئی ہے جو کہتا ہے کہ ``مجھے رخصت دے دیجیے اور مجھ کو فتنے میں نہ ڈالیے" سن رکھو! فتنے ہی میں تو یہ لوگ پڑے ہوئے ہیں اور جہنم نے ان کافروں کو گھیر رکھا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcclxxxv{تمہارا بھلا ہوتا ہے تو انہیں رنج ہوتا ہے اور تم پر کوئی مصیبت آتی ہے تو یہ منہ پھیر کر خوش خوش پلٹتے ہیں اور کہتے جاتے ہیں کہ اچھا ہوا ہم نے پہلے ہی اپنا معاملہ ٹھیک کر لیا تھا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvi{ان سے کہو ``ہمیں ہرگز کوئی (برائی یا بھلائی) نہیں پہنچتی مگر وہ جو اللہ نے ہمارے لیے لکھ دی ہے اللہ ہی ہمارا مولیٰ ہے، اور اہل ایمان کو اسی پر بھروسہ کرنا چاہیے"\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvii{ان سے کہو، ``تم ہمارے معاملہ میں جس چیز کے منتظر ہو وہ اس کے سوا اور کیا ہے کہ دو بھلائیوں میں سے ایک بھلائی ہے اور ہم تمہارے معاملہ میں جس چیز کے منتظر ہیں وہ یہ ہے کہ اللہ خود تم کو سزا دیتا ہے یا ہمارے ہاتھوں دلواتا ہے؟ اچھا تو اب تم بھی انتظار کرو اور ہم بھی تمہارے ساتھ منتظر ہیں"\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcclxxxviii{ان سے کہو ``تم اپنے مال خواہ راضی خوشی خرچ کرو یا بکراہت، بہر حال وہ قبول نہ کیے جائیں گے کیونکہ تم فاسق لوگ ہو"\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcclxxxix{ان کے دیے ہوئے مال قبول نہ ہونے کی کوئی وجہ اس کے سوا نہیں ہے کہ انہوں نے اللہ اور اس کے رسول سے کفر کیا ہے، نماز کے لیے آتے ہیں تو کسمساتے ہوئے آتے ہیں اور راہ خدا میں خرچ کرتے ہیں تو بادل ناخواستہ خرچ کرتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxc{اِن کے مال و دولت اور ان کی کثرت اولاد کو دیکھ کر دھوکہ نہ کھاؤ، اللہ تو یہ چاہتا ہے کہ اِنہی چیزوں کے ذریعہ سے ان کو دنیا کی زندگی میں بھی مبتلائے عذاب کرے اور یہ جان بھی دیں تو انکار حق ہی کی حالت میں دیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxci{وہ خدا کی قسم کھا کھا کر کہتے ہیں کہ ہم تمہی میں سے ہیں، حالانکہ وہ ہرگز تم میں سے نہیں ہیں اصل میں تو وہ ایسے لوگ ہیں جو تم سے خوف زدہ ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxcii{اگر وہ کوئی جائے پناہ پالیں یا کوئی کھوہ یا گھس بیٹھنے کی جگہ، تو بھاگ کر اُس میں جا چھپیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxciii{اے نبیؐ، ان میں سے بعض لوگ صدقات کی تقسیم میں تم پر اعتراضات کرتے ہیں اگر اس مال میں سے انہیں کچھ دے دیا جائے تو خو ش ہو جائیں، اور نہ دیا جائے تو بگڑنے لگتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxciv{کیا اچھا ہوتا کہ اللہ اور رسولؐ نے جو کچھ بھی انہیں دیا تھا اس پر وہ راضی رہتے اور کہتے کہ ``اللہ ہمارے لیے کافی ہے، وہ اپنے فضل سے ہمیں بہت کچھ دے گا اور اس کا رسول بھی ہم پر عنایت فرمائے گا، ہم اللہ ہی کی طرف نظر جمائے ہوئے ہیں"\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxcv{یہ صدقات تو دراصل فقیروں اور مسکینوں کے لیے ہیں اور اُن لوگوں کے لیے جو صدقات کے کام پر مامور ہوں، اور اُن کے لیے جن کی تالیف قلب مطلوب ہو نیز یہ گردنوں کے چھڑانے اور قرض داروں کی مدد کرنے میں اور راہ خدا میں اور مسافر نوازی میں استعمال کرنے کے لیے ہیں ایک فریضہ ہے اللہ کی طرف سے اور اللہ سب کچھ جاننے والا اور دانا و بینا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxcvi{ان میں سے کچھ لوگ ہیں جو اپنی باتوں سے نبی کو دکھ دیتے ہیں اور کہتے ہیں کہ یہ شخص کانوں کا کچا ہے کہو، ``وہ تمہاری بھلائی کے لیے ایسا ہے، اللہ پر ایمان رکھتا ہے اور اہل ایمان پر اعتماد کرتا ہے اور سراسر رحمت ہے ان لوگوں کے لیے جو تم میں سے ایماندار ہیں اور جو لوگ اللہ کے رسول کو دکھ دیتے ہیں ان کے لیے دردناک سزا ہے"\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxcvii{یہ لوگ تمہارے سامنے قسمیں کھاتے ہیں تاکہ تمہیں راضی کریں، حالانکہ اگر یہ مومن ہیں تو اللہ اور رسول اس کے زیادہ حق دار ہیں کہ یہ ان کو راضی کرنے کی فکر کریں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxcviii{کیا انہیں معلوم نہیں ہے کہ جو اللہ اور اس کے رسول کا مقابلہ کرتا ہے اس کے لیے دوزخ کی آگ ہے جس میں وہ ہمیشہ رہے گا یہ بہت بڑی رسوائی ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxcix{یہ منافق ڈر رہے ہیں کہ کہیں مسلمانوں پر کوئی ایسی سورت نازل نہ ہو جائے جو ان کے دلوں کے بھید کھول کر رکھ دے اے نبیؐ، ان سے کہو، ``اور مذاق اڑاؤ، اللہ اُس چیز کو کھول دینے والا ہے جس کے کھل جانے سے تم ڈرتے ہو"\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccc{اگر ان سے پوچھو کہ تم کیا باتیں کر رہے تھے، تو جھٹ کہہ دیں گے کہ ہم تو ہنسی مذاق اور دل لگی کر رہے تھے ان سے کہو، ``کیا تمہاری ہنسی دل لگی اللہ اور اُس کی آیات اور اس کے رسول ہی کے ساتھ تھی؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccci{اب عذرات نہ تراشو، تم نے ایمان لانے کے بعد کفر کیا ہے، اگر ہم نے تم میں سے ایک گروہ کو معاف کر بھی دیا تو دوسرے گروہ کو تو ہم ضرور سزا دیں گے کیونکہ وہ مجرم ہے"\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcccii{منافق مرد اور منافق عورتیں سب ایک دوسرے کے ہم رنگ ہیں برائی کا حکم دیتے ہیں اور بھلائی سے منع کرتے ہیں اور اپنے ہاتھ خیر سے روکے رکھتے ہیں یہ اللہ کو بھول گئے تو اللہ نے بھی انہیں بھلا دیا یقیناً یہ منافق ہی فاسق ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccciii{ان منافق مردوں اور عورتوں اور کافروں کے لیے اللہ نے آتش دوزخ کا وعدہ کیا ہے جس میں وہ ہمیشہ رہیں گے، وہی ان کے لیے موزوں ہے ان پر اللہ کی پھٹکار ہے اور ان کے لیے قائم ر ہنے والا عذاب ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccciv{تم لوگوں کے رنگ ڈھنگ وہی ہیں جو تمہارے پیش روؤں کے تھے وہ تم سے زیادہ زور آور اور تم سے بڑھ کر مال اور اولاد والے تھے پھر انہوں نے دنیا میں اپنے حصہ کے مزے لوٹ لیے اور تم نے بھی اپنے حصے کے مزے اسی طرح لوٹے جیسے انہوں نے لوٹے تھے، اور ویسی ہی بحثوں میں تم بھی پڑے جیسی بحثوں میں وہ پڑے تھے، سو ان کا انجام یہ ہوا کہ دنیا اور آخرت میں ان کا سب کیا دھرا ضائع ہو گیا اور وہی خسارے میں ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcccv{کیا اِن لوگوں کو اپنے پیش روؤں کی تاریخ نہیں پہنچی؟ نوحؑ کی قوم، عاد، ثمود، ابراہیمؑ کی قوم، مدین کے لوگ اور وہ بستیاں جنہیں الٹ دیا گیا اُن کے رسول ان کے پاس کھلی کھلی نشانیاں لے کر آئے، پھر یہ اللہ کا کام نہ تھا کہ ان پر ظلم کرتا مگر وہ آپ ہی اپنے اوپر ظلم کرنے والے تھے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcccvi{مومن مرد اور مومن عورتیں، یہ سب ایک دوسرے کے رفیق ہیں، بھلائی کا حکم دیتے اور برائی سے روکتے ہیں، نماز قائم کرتے ہیں، زکوٰۃ دیتے ہیں اور اللہ اور اس کے رسول کی اطاعت کرتے ہیں یہ وہ لوگ ہیں جن پر اللہ کی رحمت نازل ہو کر رہے گی، یقیناً اللہ سب پر غالب اور حکیم و دانا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcccvii{ان مومن مردوں اور عورتوں سے اللہ کا وعدہ ہے کہ انہیں ایسے باغ دے گا جن کے نیچے نہریں بہتی ہوں گی اور وہ ان میں ہمیشہ رہیں گے ان سدا بہار باغوں میں ان کے لیے پاکیزہ قیام گاہیں ہوں گی، اور سب سے بڑھ کر یہ کہ اللہ کی خوشنودی انہیں حاصل ہوگی یہی بڑی کامیابی ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcccviii{اے نبیؐ، کفار اور منافقین دونوں کا پوری قوت سے مقابلہ کرو اور ان کے ساتھ سختی سے پیش آؤ آخر کار ان کا ٹھکانا جہنم ہے اور وہ بدترین جائے قرار ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcccix{یہ لوگ خدا کی قسم کھا کھا کر کہتے ہیں کہ ہم نے وہ بات نہیں کہی، حالانکہ انہوں نے ضرور وہ کافرانہ بات کہی ہے وہ اسلام لانے کے بعد کفر کے مرتکب ہوئے اور انہوں نے وہ کچھ کرنے کا ارادہ کیا جسے کر نہ سکے یہ ان کا سارا غصہ اسی بات پر ہے نا کہ اللہ اور اس کے رسول نے اپنے فضل سے ان کو غنی کر دیا ہے! اب اگر یہ اپنی اس روش سے باز آ جائیں تو انہی کے لیے بہتر ہے اور اگر یہ باز نہ آئے تو اللہ ان کو نہایت درد ناک سزا دے گا، دنیا میں بھی اور آخرت میں بھی، اور زمین میں کوئی نہیں جو اِن کا حمایتی اور مددگار ہو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcccx{ان میں سے بعض ایسے بھی ہیں جنہوں نے اللہ سے عہد کیا تھا کہ اگر اس نے اپنے فضل سے ہم کو نوازا تو ہم خیرات کریں گے اور صالح بن کر رہیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcccxi{مگر جب اللہ نے اپنے فضل سے ان کو دولت مند کر دیا تو وہ بخل پر اتر آئے اور اپنے عہد سے ایسے پھرے کہ انہیں اس کی پروا تک نہیں ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcccxii{نتیجہ یہ نکلا کہ ان کی اِس بد عہدی کی وجہ سے جو انہوں نے اللہ کے ساتھ کی، اور اس جھوٹ کی وجہ سے جو وہ بولتے رہے، اللہ نے ان کے دلوں میں نفاق بٹھا دیا جو اس کے حضور ان کی پیشی کے دن تک ان کا پیچھا نہ چھوڑے گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcccxiii{کیا یہ لوگ جانتے نہیں ہیں کہ اللہ کو ان کے مخفی راز اور ان کی پوشیدہ سرگوشیاں تک معلوم ہیں اور وہ تمام غیب کی باتوں سے پوری طرح باخبر ہے؟\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcccxiv{(وہ خوب جانتا ہے اُن کنجوس دولت مندوں کو) جو برضا و رغبت دینے والے اہل ایمان کی مالی قربانیوں پر باتیں چھانٹتے ہیں اور ان لوگوں کا مذاق اڑاتے ہیں جن کے پاس (راہ خدا میں دینے کے لیے) اُس کے سوا کچھ نہیں ہے جو وہ اپنے اوپر مشقت برداشت کر کے دیتے ہیں اللہ اِن مذاق اڑانے والوں کا مذاق اڑاتا ہے اور ان کے لیے درد ناک سزا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcccxv{اے نبیؐ، تم خواہ ایسے لوگوں کے لیے معافی کی درخواست کرو یا نہ کرو، اگر تم ستر مرتبہ بھی انہیں معاف کردینے کی درخواست کرو گے تو اللہ انہیں ہرگز معاف نہ کرے گا اس لیے کہ انہوں نے اللہ اور اس کے رسول کے ساتھ کفر کیا ہے، اور اللہ فاسق لوگوں کو راہ نجات نہیں دکھاتا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcccxvi{جن لوگوں کو پیچھے رہ جانے کی اجازت دے دی گئی تھی وہ اللہ کے رسول کا ساتھ نہ دینے اور گھر بیٹھے رہنے پر خوش ہوئے اور انہیں گوارا نہ ہوا کہ اللہ کی راہ میں جان و مال سے جہاد کریں انہوں نے لوگوں سے کہا کہ ``اس سخت گرمی میں نہ نکلو" ان سے کہو کہ جہنم کی آگ اس سے زیادہ گرم ہے، کاش انہیں اس کا شعور ہوتا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcccxvii{اب چاہیے کہ یہ لوگ ہنسنا کم کریں اور روئیں زیادہ، اس لیے کہ جو بدی یہ کماتے رہے ہیں اس کی جزا ایسی ہی ہے (کہ انہیں اس پر رونا چاہیے)\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcccxviii{اگر اللہ ان کے درمیان تمہیں واپس لے جائے اور آئندہ ان میں سے کوئی گروہ جہاد کے لیے نکلنے کی تم سے اجازت مانگے تو صاف کہہ دینا کہ، ``اب تم میرے ساتھ ہرگز نہیں چل سکتے اور نہ میری معیت میں کسی دشمن سے لڑ سکتے ہو، تم نے پہلے بیٹھ ر ہنے کو پسند کیا تھا تو اب گھر بیٹھنے والوں ہی کے ساتھ بیٹھے رہو"\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcccxix{اور آئندہ ان میں سے جو کوئی مرے اس کی نماز جنازہ بھی تم ہرگز نہ پڑھنا اور نہ کبھی اس کی قبر پر کھڑے ہونا کیونکہ انہوں نے اللہ اور اس کے رسولؐ کے ساتھ کفر کیا ہے اور وہ مرے ہیں اس حال میں کہ وہ فاسق تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcccxx{ان کی مالداری اور ان کی کثرت اولاد تم کو دھوکے میں نہ ڈالے اللہ نے تو ارادہ کر لیا ہے کہ اِس مال و اولاد کے ذریعہ سے ان کو اسی دنیا میں سزا دے اور ان کی جانیں اس حال میں نکلیں کہ وہ کافر ہوں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcccxxi{جب کبھی کوئی سورۃ اس مضمون کی نازل ہوئی کہ اللہ کو مانو اور اس کے رسول کے ساتھ جہاد کرو تو تم نے دیکھا کہ جو لوگ ان میں سے صاحب مقدرت تھے وہی تم سے درخواست کرنے لگے کہ انہیں جہاد کی شرکت سے معاف رکھا جائے اور انہوں نے کہا کہ ہمیں چھوڑ دیجیے کہ ہم بیٹھنے والوں کے ساتھ رہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcccxxii{ان لوگوں نے گھر بیٹھنے والیوں میں شامل ہونا پسند کیا اور ان کے دلوں پر ٹھپہ لگا دیا گیا، اس لیے ان کی سمجھ میں اب کچھ نہیں آتا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcccxxiii{بخلاف اس کے رسولؐ نے اور ان لوگوں نے جو رسولؐ کے ساتھ ایمان لائے تھے ا پنی جان و مال سے جہاد کیا اور اب ساری بھلائیاں انہی کے لیے ہیں اور وہی فلاح پانے والے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcccxxiv{اللہ نے ان کے لیے ایسے باغ تیار رکھے ہیں جن کے نیچے نہریں بہ رہی ہیں، ان میں وہ ہمیشہ رہیں گے یہ ہے عظیم الشان کامیابی\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcccxxv{بدوی عربوں میں سے بھی بہت سے لوگ آئے جنہوں نے عذر کیے تاکہ انہیں بھی پیچھے رہ جانے کی اجازت دی جائے اِس طرح بیٹھ رہے وہ لوگ جنہوں نے اللہ اور اس کے رسول سے ایمان کا جھوٹا عہد کیا تھا ان بدویوں میں سے جن لوگوں نے کفر کا طریقہ اختیار کیا ہے عنقریب وہ دردناک سزا سے دوچار ہوں گے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcccxxvi{ضعیف اور بیمار لوگ اور وہ لوگ جو شرکت جہاد کے لیے راہ نہیں پاتے، اگر پیچھے رہ جائیں تو کوئی حرج نہیں جبکہ وہ خلوص دل کے ساتھ اللہ اور اس کے رسولؐ کے وفادار ہوں ایسے محسنین پر اعتراض کی کوئی گنجائش نہیں ہے اور اللہ درگزر کرنے والا اور رحم فرمانے والا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcccxxvii{اسی طرح اُن لوگوں پر بھی کوئی اعتراض کا موقع نہیں ہے جنہوں نے خود آ کر تم سے درخواست کی تھی کہ ہمارے لیے سواریاں بہم پہنچائی جائیں، اور جب تم نے کہا کہ میں تمہارے لیے سواریوں کا انتظام نہیں کرسکتا تو وہ مجبوراً واپس گئے اور حال یہ تھا کہ ان کی آنکھوں سے آنسو جاری تھے اور انہیں اس بات کا بڑا رنج تھا کہ وہ اپنے خرچ پر شریک جہاد ہونے کی مقدرت نہیں رکھتے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcccxxviii{البتہ اعتراض ان لوگوں پر ہے جو مالدار ہیں اور پھر بھی تم سے درخواستیں کرتے ہیں کہ انہیں شرکت جہاد سے معاف رکھا جائے انہوں نے گھر بیٹھنے والیوں میں شامل ہونا پسند کیا اور اللہ نے ان کے دلوں پر ٹھپہ لگا دیا، اس لیے اب یہ کچھ نہیں جانتے (کہ اللہ کے ہاں ان کی روش کا کیا نتیجہ نکلنے والا ہے)\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcccxxix{تم جب پلٹ کر ان کے پاس پہنچو گے تو یہ طرح طرح کے عذرات پیش کریں گے مگر تم صاف کہہ دینا کہ ``بہانے نہ کرو، ہم تہاری کسی بات کا اعتبار نہ کریں گے اللہ نے ہم کو تمہارے حالات بتا دیے ہیں اب اللہ اور اس کا رسول تمہارے طرز عمل کو دیکھے گا پھر تم اس کی طرف پلٹائے جاؤ گے جو کھلے اور چھپے سب کا جاننے والا ہے اور وہ تمہیں بتا دے گا کہ تم کیا کچھ کرتے رہے ہو"\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcccxxx{تمہاری واپسی پر یہ تمہارے سامنے قسمیں کھائیں گے تاکہ تم ان سے صرف نظر کرو تو بے شک تم ان سے صرف نظر ہی کر لو، کیونکہ یہ گندگی ہیں اور ان کا اصلی مقام جہنم ہے جو ان کی کمائی کے بدلے میں انہیں نصیب ہوگی\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcccxxxi{یہ تمہارے سامنے قسمیں کھائیں گے کہ تاکہ تم ان سے راضی ہو جاؤ حالانکہ اگر تم ان سے راضی ہو بھی گئے تو اللہ ہرگز ایسے فاسق لوگوں سے راضی نہ ہوگا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcccxxxii{یہ بدوی عرب کفر و نفاق میں زیادہ سخت ہیں اور ان کے معاملہ میں اس امر کے امکانات زیادہ ہیں کہ اس دین کے حدود سے نا واقف رہیں جو اللہ نے اپنے رسول پر نازل کیا ہے اللہ سب کچھ جانتا ہے اور حکیم و دانا ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiii{ان بدویوں میں ایسے ایسے لوگ موجود ہیں جو راہ خدا میں کچھ خرچ کرتے ہیں تو اسے اپنے اوپر زبردستی کی چٹی سمجھتے ہیں اور تمہارے حق میں زمانہ کی گردشوں کا انتظار کر رہے ہیں (کہ تم کسی چکر میں پھنسو تو وہ اپنی گردن سے اس نظام کی اطاعت کا قلادہ اتار پھینکیں جس میں تم نے انہیں کس دیا ہے) حالانکہ بدی کا چکر خود انہی پر مسلط ہے اور اللہ سب کچھ سنتا اور جانتا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiv{اور انہی بدویوں میں کچھ لوگ ایسے بھی ہیں جو اللہ اور روز آخر پر ایمان رکھتے ہیں اور جو کچھ خرچ کرتے ہیں اُسے اللہ کے تقرب کا اور رسولؐ کی طرف سے رحمت کی دعائیں لینے کا ذریعہ بناتے ہیں ہاں! وہ ضرور ان کے لیے تقرب کا ذریعہ ہے اور اللہ ضرور ان کو اپنی رحمت میں داخل کریگا، یقیناً اللہ درگزر کرنے والا اور رحم فرمانے والا ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcccxxxv{وہ مہاجر و انصار جنہوں نے سب سے پہلے دعوت ایمان پر لبیک کہنے میں سبقت کی، نیز وہ جو بعد میں راستبازی کے ساتھ پیچھے آئے، اللہ ان سے راضی ہوا اور وہ اللہ سے راضی ہوئے، اللہ نے ان کے لیے ایسے باغ مہیا کر رکھے ہیں جن کے نیچے نہریں بہتی ہوں گی اور وہ ان میں ہمیشہ رہیں گے، یہی عظیم الشان کامیابی ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvi{تمہارے گرد و پیش جو بدوی رہتے ہیں ان میں بہت سے منافق ہیں اور اسی طرح خود مدینہ کے باشندوں میں بھی منافق موجود ہیں جو نفاق میں طاق ہو گئے ہیں تم انہیں نہیں جانتے، ہم ان کو جانتے ہیں قریب ہے وہ وقت جب ہم ان کو دوہری سزا دیں گے، پھر وہ زیادہ بڑی سزا کے لیے واپس لائے جائیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvii{کچھ اور لوگ ہیں جنہوں نے اپنے قصوروں کا اعتراف کر لیا ہے ان کا عمل مخلوط ہے، کچھ نیک ہے اور کچھ بد، بعید نہیں کہ اللہ ان پر پھر مہربان ہو جائے کیونکہ وہ درگزر کرنے والا اور رحم فرمانے والا ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcccxxxviii{اے نبیؐ، تم ان کے اموال میں سے صدقہ لے کر انہیں پاک کرو اور (نیکی کی راہ میں) انہیں بڑھاؤ، اور ان کے حق میں دعائے رحمت کرو کیونکہ تمہاری دعا ان کے لیے وجہ تسکین ہوگی، اللہ سب کچھ سنتا اور جانتا ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcccxxxix{کیا اِن لوگوں کو معلوم نہیں ہے کہ وہ اللہ ہی ہے جو اپنے بندوں کی توبہ قبول کرتا ہے اور ان کی خیرات کو قبولیت عطا فرماتا ہے، اور یہ کہ اللہ بہت معاف کرنے والا اور رحیم ہے؟\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcccxl{اور اے نبیؐ، اِن لوگوں سے کہدو کہ تم عمل کرو، اللہ اور اس کا رسول اور مومنین سب دیکھیں گے کہ تمہارا طرز عمل اب کیا رہتا ہے پھر تم اُس کی طرف پلٹائے جاؤ گے جو کھلے اور چھپے سب کو جانتا ہے اور وہ تمہیں بتا دے گا کہ تم کیا کرتے رہے ہو\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcccxli{کچھ دوسر ے لوگ ہیں جن کا معاملہ ابھی خدا کے حکم پر ٹھیرا ہوا ہے، چاہے انہیں سزا دے اور چاہے اُن پر از سر نو مہربان ہو جائے اللہ سب کچھ جانتا ہے اور حکیم و دانا ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcccxlii{کچھ اور لوگ ہیں جنہوں نے ایک مسجد بنائی اِس غرض کے لیے کہ (دعوت حق کو) نقصان پہنچائیں، اور (خدا کی بندگی کرنے کے بجائے) کفر کریں، اور اہل ایمان میں پھوٹ ڈالیں، اور (اس بظاہر عبادت گاہ کو) اُس شخص کے لیے کمین گاہ بنائیں جو اس سے پہلے خدا اور رسولؐ کے خلاف بر سر پیکار ہو چکا ہے وہ ضرور قسمیں کھا کھا کر کہیں گے کہ ہمارا ارادہ تو بھلائی کے سوا کسی دوسری چیز کا نہ تھا مگر اللہ گواہ ہے کہ وہ قطعی جھوٹے ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcccxliii{تم ہرگز اس عمارت میں کھڑے نہ ہونا جو مسجد اول روز سے تقویٰ پر قائم کی گئی تھی وہی اس کے لیے زیادہ موزوں ہے کہ تم اس میں (عباد ت کے لیے) کھڑے ہو، اس میں ایسے لوگ ہیں جو پاک رہنا پسند کرتے ہیں اور اللہ کو پاکیزگی اختیار کرنے والے ہی پسند ہیں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcccxliv{پھر تمہارا کیا خیال ہے کہ بہتر انسان وہ ہے جس نے اپنی عمارت کی بنیاد خدا کے خوف اور اس کی رضا کی طلب پر رکھی ہو یا وہ جس نے اپنی عمارت ایک وادی کی کھوکھلی بے ثبات کگر پر اٹھائی اور وہ اسے لے کر سیدھی جہنم کی آگ میں جا گری؟ ایسے ظالم لوگوں کو اللہ کبھی سیدھی راہ نہیں دکھاتا\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcccxlv{یہ عمارت جو انہوں نے بنائی ہے، ہمیشہ ان کے دلوں میں بے یقینی کی جڑ بنی رہے گی (جس کے نکلنے کی اب کوئی صورت نہیں) بجز اس کے کہ ان کے دل ہی پارہ پارہ ہو جائیں اللہ نہایت باخبر اور حکیم و دانا ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mcccxlvi{حقیقت یہ ہے کہ اللہ نے مومنوں سے ان کے نفس اور ان کے مال جنت کے بدلے خرید لیے ہیں وہ اللہ کی راہ میں لڑتے اور مارتے اور مرتے ہیں ان سے (جنت کا وعدہ) اللہ کے ذمے ایک پختہ وعدہ ہے توراۃ اور انجیل اور قرآن میں اور کون ہے جو اللہ سے بڑھ کر اپنے عہد کا پورا کرنے والا ہو؟ پس خوشیاں مناؤ اپنے اس سودے پر جو تم نے خدا سے چکا لیا ہے، یہی سب سے بڑی کامیابی ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mcccxlvii{اللہ کی طرف بار بار پلٹنے والے، اُس کے بندگی بجا لانے والے، اُس کی تعریف کے گن گانے والے، اُس کی خاطر زمین میں گردش کرنے والے، اُس کے آگے رکوع اور سجدے کرنے والے، نیکی کا حکم دینے والے، بدی سے روکنے والے، اور اللہ کے حدود کی حفاظت کرنے والے، (اس شان کے ہوتے ہیں وہ مومن جو اللہ سے خرید و فروخت کا یہ معاملہ طے کرتے ہیں) اور اے نبیؐ ان مومنوں کو خوش خبری دے دو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mcccxlviii{نبیؐ کو اور اُن لوگوں کو جو ایمان لائے ہیں، زیبا نہیں ہے کہ مشرکوں کے لیے مغفرت کی دعا کریں، چاہے وہ ان کے رشتہ دار ہی کیوں نہ ہوں، جبکہ ان پر یہ بات کھل چکی ہے کہ وہ جہنم کے مستحق ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mcccxlix{ابراہیمؑ نے اپنے باپ کے لیے جو دعائے مغفرت کی تھی وہ تو اُس وعدے کی وجہ سے تھی جو اس نے اپنے باپ سے کیا تھا، مگر جب اس پر یہ بات کھل گئی کہ اس کا باپ خدا کا دشمن ہے تو وہ اس سے بیزار ہو گیا، حق یہ ہے کہ ابراہیمؑ بڑا رقیق القلب و خداترس اور بردبار آدمی تھا\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mcccl{اللہ کا یہ طریقہ نہیں ہے کہ لوگوں کو ہدایت دینے کے بعد پھر گمراہی میں مبتلا کرے جب تک کہ انہیں صاف صاف بتا نہ دے کہ انہیں کن چیزوں سے بچنا چاہیے درحقیقت اللہ ہر چیز کا علم رکھتا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mcccli{اور یہ بھی واقعہ ہے کہ اللہ ہی کے قبضہ میں آسمان و زمین کی سلطنت ہے، اسی کے اختیار میں زندگی و موت ہے، اور تمہارا کوئی حامی و مددگار ایسانہیں ہے جو تمہیں اس سے بچا سکے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mccclii{اللہ نے معاف کر دیا نبیؐ کو اور ان مہاجرین و انصار کو جنہوں نے بڑی تنگی کے وقت میں نبیؐ کا ساتھ دیا اگر چہ ان میں سے کچھ لوگوں کے دل کجی کی طرف مائل ہو چکے تھے (مگر جب انہوں نے اس کجی کا اتباع نہ کیا بلکہ نبیؐ کا ساتھ ہی دیا تو) اللہ نے انہیں معاف کر دیا، بے شک اُس کا معاملہ اِن لوگوں کے ساتھ شفقت و مہربانی کا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mcccliii{اور اُن تینوں کو بھی اس نے معاف کیا جن کے معاملہ کو ملتوی کر دیا گیا تھا جب زمین اپنی ساری وسعت کے باوجود ان پر تنگ ہو گئی اور ان کی اپنی جانیں بھی ان پر بار ہونے لگیں اور انہوں نے جان لیا کہ اللہ سے بچنے کے لیے کوئی جائے پناہ خود اللہ ہی کے دامن رحمت کے سوا نہیں ہے، تو اللہ اپنی مہربانی سے ان کی طرف پلٹا تاکہ وہ اس کی طرف پلٹ آئیں، یقیناً وہ بڑا معاف کرنے والا اور رحیم ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mcccliv{اے لوگو جو ایمان لائے ہو، اللہ سے ڈرو اور سچے لوگوں کا ساتھ دو\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mccclv{مدینے کے باشندوں اور گرد و نواح کے بدویوں کو یہ ہرگز زبیا نہ تھا کہ اللہ کے رسول کو چھوڑ کر گھر بیٹھ رہتے اور اس کی طرف سے بے پروا ہو کر اپنے اپنے نفس کی فکر میں لگ جاتے اس لیے کہ ایسا کبھی نہ ہوگا کہ اللہ کی راہ میں بھوک پیاس اور جسمانی مشقت کی کوئی تکلیف وہ جھیلیں، اور منکرین حق کو جو راہ ناگوار ہے اُس پر کوئی قدم وہ اٹھائیں، اور کسی دشمن سے (عداوت حق کا) کا کوئی انتقام وہ لیں اور اس کے بدلے ان کے حق میں ایک عمل صالح نہ لکھا جائے یقیناً اللہ کے ہاں محسنوں کا حق الخدمت مارا نہیں جاتا ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mccclvi{اسی طرح یہ بھی کبھی نہ ہوگا کہ (راہ خدا میں) تھوڑا یا بہت کوئی خرچ وہ اٹھائیں اور (سعی جہاد میں) کوئی وادی وہ پار کریں اور ان کے حق میں اسے لکھ نہ لیا جائے تاکہ اللہ ان کے اس اچھے کارنامے کا صلہ انہیں عطا کرے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mccclvii{اور یہ کچھ ضروری نہ تھا کہ اہل ایمان سارے کے سارے ہی نکل کھڑے ہوتے، مگر ایسا کیوں نہ ہوا کہ ان کی آبادی کے ہر حصہ میں سے کچھ لوگ نکل کر آتے اور دین کی سمجھ پیدا کرتے اور واپس جا کر اپنے علاقے کے باشندوں کو خبردار کرتے تاکہ وہ (غیر مسلمانہ روش سے) پرہیز کرتے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mccclviii{اے لوگو جو ایمان لائے ہو، جنگ کرو اُن منکرین حق سے جو تم سے قریب ہیں اور چاہیے کہ وہ تمہارے اندر سختی پائیں، اور جان لو کہ اللہ متقیوں کے ساتھ ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mccclix{جب کوئی نئی سورت نازل ہوتی ہے تو ان میں سے بعض لوگ (مذاق کے طور پر مسلمانوں سے) پوچھتے ہیں کہ ``کہو، تم میں سے کس کے ایمان میں اس سے اضافہ ہوا؟" (اس کا جواب یہ ہے کہ) جو لوگ ایمان لائے ہیں ان کے ایمان میں تو فی الواقع (ہر نازل ہونے والی سورت نے) اضافہ ہی کیا ہے اور وہ اس سے دلشاد ہیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mccclx{البتہ جن لوگوں کے دلوں کو (نفاق کا) روگ لگا ہوا تھا اُن کی سابق نجاست پر (ہر نئی سورت نے) ایک اور نجاست کا اضافہ کر دیا اور وہ مرتے دم تک کفر ہی میں مبتلا رہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mccclxi{کیا یہ لوگ دیکھتے نہیں کہ ہر سال ایک دو مرتبہ یہ آزمائش میں ڈالے جاتے ہیں؟ مگر اِس پر بھی نہ توبہ کرتے ہیں نہ کوئی سبق لیتے ہیں\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mccclxii{جب کوئی سورت نازل ہوتی ہے تو یہ لوگ آنکھوں ہی آنکھوں میں ایک دوسرے سے باتیں کرتے ہیں کہ کہیں کوئی تم کو دیکھ تو نہیں رہا ہے، پھر چپکے سے نکل بھاگتے ہیں اللہ نے ان کے دل پھیر دیے ہیں کیونکہ یہ ناسمجھ لوگ ہیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mccclxiii{دیکھو! تم لوگوں کے پاس ایک رسول آیا ہے جو خود تم ہی میں سے ہے، تمہارا نقصان میں پڑنا اس پر شاق ہے، تمہاری فلاح کا وہ حریص ہے، ایمان لانے والوں کے لیے وہ شفیق اور رحیم ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mccclxiv{اب اگر یہ لوگ تم سے منہ پھیرتے ہیں تو اے نبیؐ، ان سے کہدو کہ ``میرے لیے اللہ بس کرتا ہے، کوئی معبود نہیں مگر وہ، اُسی پر میں نے بھروسہ کیا اور وہ مالک ہے عرش عظیم کا"\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mccclxv{\basmalahur ا ل ر، یہ اُس کتاب کی آیات ہیں جو حکمت و دانش سے لبریز ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccclxvi{کیا لوگوں کے لیے یہ ایک عجیب بات ہو گئی کہ ہم نے خود اُنہی میں سے ایک آدمی کو اشارہ کیا کہ (غفلت میں پڑے ہوئے) لوگوں کو چونکا دے اور جو مان لیں ان کو خوشخبری دیدے کہ ان کے لیے اُن کے رب کے پاس سچی عزت و سرفرازی ہے؟ (کیا یہی وہ بات ہے جس پر) منکرین نے کہا کہ یہ شخص تو کھلا جادوگر ہے؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccclxvii{حقیقت یہ ہے کہ تمہارا رب وہی خدا ہے جس نے آسمانوں اور زمین کو چھ دنوں میں پیدا کیا، پھر تخت حکومت پر جلوہ گر ہوا اور کائنات کا انتظام چلا رہا ہے کوئی شفاعت (سفارش) کرنے والا نہیں اِلّا یہ کہ اس کی اجازت کے بعد شفاعت کرے یہی اللہ تمہارا رب ہے لہٰذا تم اُسی کی عبادت کرو پھر کیا تم ہوش میں نہ آؤ گے؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccclxviii{اسی کی طرف تم سب کو پلٹ کر جانا ہے، یہ اللہ کا پکا وعدہ ہے بے شک پیدائش کی ابتدا وہی کرتا ہے، پھر وہی دوبارہ پیدا کرے گا، تاکہ جو لوگ ایمان لائے اور جنہوں نے نیک عمل کیے ان کو پورے انصاف کے ساتھ جزا دے، اور جنہوں نے کفر کا طریقہ اختیار کیا وہ کھولتا ہوا پانی پییں اور دردناک سزا بھگتیں اُس انکار حق کی پاداش میں جو وہ کرتے رہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccclxix{وہی ہے جس نے سُورج کو اجیالا بنایا اور چاند کو چمک دی اور چاند کے گھٹنے بڑھنے کی منزلیں ٹھیک ٹھیک مقرر کر دیں تاکہ تم اُس سے برسوں اور تاریخوں کے حساب معلوم کرو اللہ نے یہ سب کچھ (کھیل کے طور پر نہیں بلکہ) با مقصد ہی بنایا ہے وہ اپنی نشانیوں کو کھول کھول کر پیش کر رہا ہے اُن لوگوں کے لیے جو علم رکھتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccclxx{یقیناً رات اور دن کے الٹ پھیر میں اور ہر اُس چیز میں جو اللہ نے زمین اور آسمانوں میں پیدا کی ہے، نشانیاں ہیں اُن لوگوں کے لیے جو (غلط بینی و غلط روی سے) بچنا چاہتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccclxxi{حقیقت یہ ہے کہ جو لوگ ہم سے ملنے کی توقع نہیں رکھتے اور دنیا کی زندگی ہی پر راضی اور مطمئن ہو گئے ہیں، اور جو لوگ ہماری نشانیوں سے غافل ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccclxxii{اُن کا آخری ٹھکانہ جہنم ہو گا اُن برائیوں کی پاداش میں جن کا اکتساب وہ (اپنے اس غلط عقیدے اور غلط طرز عمل کی وجہ سے) کرتے رہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccclxxiii{اور یہ بھی حقیقت ہے کہ جو لوگ ایمان لائے (یعنی جنہوں نے اُن صداقتوں کو قبول کر لیا جو اس کتاب میں پیش کی گئی ہیں) اور نیک اعمال کرتے رہے انہیں اُن کا رب اُن کے ایمان کی وجہ سے سیدھی راہ چلائے گا، نعمت بھری جنتوں میں ان کے نیچے نہریں بہیں گی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccclxxiv{وہاں ان کی صدا یہ ہوگی کہ “پاک ہے تو اے خدا، `` اُن کی دعا یہ ہوگی کہ “سلامتی ہو `` اور ان کی ہر بات کا خاتمہ اس پر ہوگا کہ “ساری تعریف اللہ رب العالمین ہی کے لیے ہے ``\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccclxxv{اگر کہیں اللہ لوگوں کے ساتھ برا معاملہ کرنے میں بھی اتنی ہی جلدی کرتا جتنی وہ دنیا کی بھلائی مانگنے میں جلدی کرتے ہیں تو ان کی مہلت عمل کبھی کی ختم کر دی گئی ہوتی (مگر ہمارا یہ طریقہ نہیں ہے) اس لیے ہم اُن لوگوں کو جو ہم سے ملنے کی توقع نہیں رکھتے اُن کی سرکشی میں بھٹکنے کے لیے چھُوٹ دے دیتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccclxxvi{انسان کا حال یہ ہے کہ جب اس پر کوئی سخت وقت آتا ہے تو کھڑے اور بیٹھے اور لیٹے ہم کو پکارتا ہے، مگر جب ہم اس کی مصیبت ٹال دیتے ہیں تو ایسا چل نکلتا ہے کہ گویا اس نے کبھی اپنے کسی بُرے وقت پر ہم کو پکارا ہی نہ تھا اس طرح حد سے گزر جانے والوں کے لیے ان کے کرتوت خوشنما بنا دیے گئے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccclxxvii{لوگو، تم سے پہلے کی قوموں کو (جو اپنے اپنے زمانہ میں برسر عروج تھیں) ہم نے ہلاک کر دیا جب انہوں نے ظلم کی روش اختیار کی اور اُن کے رسُول اُن کے پاس کھُلی کھُلی نشانیاں لے کر آئے اور انہوں نے ایمان لا کر ہی نہ دیا اس طرح ہم مجرموں کو ان کے جرائم کا بدلہ دیا کرتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccclxxviii{اب ان کے بعد ہم نے تم کو زمین میں ان کی جگہ دی ہے تاکہ دیکھیں تم کیسے عمل کرتے ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccclxxix{جب انہیں ہماری صاف صاف باتیں سُنائی جاتی ہیں تو وہ لوگ جو ہم سے ملنے کی توقع نہیں رکھتے، کہتے ہیں کہ “اِس کے بجائے کوئی اور قرآن لاؤ یا اس میں کچھ ترمیم کرو `` اے محمدؐ، ان سے کہو “میرا یہ کام نہیں ہے کہ اپنی طرف سے اس میں کوئی تغیر و تبّدل کر لوں میں تو بس اُس وحی کا پیرو ہوں جو میرے پاس بھیجی جاتی ہے اگر میں اپنے رب کی نافرمانی کروں تو مجھے ایک بڑے ہولناک دن کے عذاب کا ڈر ہے"\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccclxxx{اور کہو “اگر اللہ کی مشیّت نہ ہوتی تو میں یہ قرآن تمہیں کبھی نہ سناتا اور اللہ تمہیں اس کی خبر تک نہ دیتا آخر اس سے پہلے میں ایک عمر تمہارے درمیان گزار چکا ہوں، کیا تم عقل سے کام نہیں لیتے؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mccclxxxi{پھر اُس سے بڑھ کر ظالم اور کون ہو گا جو ایک جھوٹی بات گھڑ کر اللہ کی طرف منسُوب کرے یا اللہ کی واقعی آیات کو جھُوٹا قرار دے یقیناً مجرم کبھی فلاح نہیں پا سکتے ``\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccclxxxii{یہ لوگ اللہ کے سوا اُن کی پرستش کر رہے ہیں جو ان کو نہ نقصان پہنچا سکتے ہیں نہ نفع، اور کہتے یہ ہیں کہ یہ اللہ کے ہاں ہمارے سفارشی ہیں اے محمدؐ، ان سے کہو “کیا تم اللہ کو اُس بات کی خبر دیتے ہو جسے وہ نہ آسمانوں میں جانتا ہے نہ زمین میں؟" پاک ہے وہ اور بالا و برتر ہے اُس شرک سے جو یہ لوگ کرتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiii{ابتداءً سارے انسان ایک ہی امّت تھے، بعد میں انہوں نے مختلف عقیدے اور مسلک بنا لیے، اور اگر تیرے رب کی طرف سے پہلے ہی ایک بات طے نہ کر لی گئی ہوتی تو جس چیز میں وہ باہم اختلاف کر رہے ہیں اس کا فیصلہ کر دیا جاتا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiv{اور یہ جو وہ کہتے ہیں کہ اِس نبیؐ پر اس کے رب کی طرف سے کوئی نشانی کیوں نہ اتاری گئی، تو ان سے کہو “غیب کا مالک و مختار تو اللہ ہی ہے، اچھا، انتظار کرو، میں بھی تمہارے ساتھ انتظار کرتا ہوں ``\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mccclxxxv{لوگوں کا حال یہ ہے کہ مصیبت کے بعد جب ہم ان کو رحمت کا مزا چکھاتے ہیں تو فوراً ہی وہ ہماری نشانیوں کے معاملہ میں چال بازیاں شروع کر دیتے ہیں ان سے کہو “اللہ اپنی چال میں تم سے زیادہ تیز ہے، اس کے فرشتے تمہاری سب مکّاریوں کو قلم بند کر رہے ہیں ``\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvi{وہ اللہ ہی ہے جو تم کو خشکی اور تری میں چلاتا ہے چنانچہ جب تم کشتیوں میں سوار ہو کر بادِ موافق پر فرحاں و شاداں سفر کر رہے ہوتے ہو اور پھر یکایک بادِ مخالف کا زور ہوتا ہے اور ہر طرف سے موجوں کے تھپیڑے لگتے ہیں اور مسافر سمجھ لیتے ہیں کہ طوفان میں گھر گئے، اُس وقت سب اپنے دین کو اللہ ہی کے لیے خالص کر کے اس سے دُعائیں مانگتے ہیں کہ “اگر تو نے ہم کو اس بلا سے نجات دے دی تو ہم شکر گزار بندے بنیں گے"\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvii{مگر جب وہ ان کو بچا لیتا ہے تو پھر وہی لوگ حق سے منحرف ہو کر زمین میں بغاوت کرنے لگتے ہیں لوگو، تمہاری یہ بغاوت اُلٹی تمہارے ہی خلاف پڑ رہی ہے دنیا کے چند روزہ مزے ہیں (لُوٹ لو)، پھر ہماری طرف تمہیں پلٹ کر آنا ہے، اُس وقت ہم تمہیں بتا دیں گے کہ تم کیا کچھ کرتے رہے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mccclxxxviii{دنیا کی یہ زندگی (جس کے نشے میں مست ہو کر تم ہماری نشانیوں سے غفلت برت رہے ہو) اس کی مثال ایسی ہے جیسے آسمان سے ہم نے پانی برسایا تو زمین کی پیداوار، جسے آدمی اور جانور سب کھاتے ہیں، خوب گھنی ہو گئی، پھر عین اُس وقت جبکہ زمین اپنی بہار پر تھی اور کھیتیاں بنی سنوری کھڑی تھیں اور ان کے مالک یہ سمجھ رہے تھے کہ اب ہم ان سے فائدہ اُٹھانے پر قادر ہیں، یکایک رات کو یا دن کو ہمارا حکم آ گیا اور ہم نے اسے ایسا غارت کر کے رکھ دیا کہ گویا کل وہاں کچھ تھا ہی نہیں اس طرح ہم نشانیاں کھول کھول کر پیش کرتے ہیں اُن لوگوں کے لیے جو سوچنے سمجھنے والے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mccclxxxix{(تم اِس نا پائیدار زندگی کے فریب میں مبتلا ہو رہے ہو) اور اللہ تمہیں دار السلام کی طرف دعوت دے رہا ہے (ہدایت اُس کے اختیار میں ہے) جس کو وہ چاہتا ہے سیدھا راستہ دکھا دیتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcccxc{جن لوگوں نے بھَلائی کا طریقہ اختیار کیا ان کے لیے بھَلائی ہے اور مزید فضل ان کے چہروں پر رُو سیاہی اور ذلّت نہ چھائے گی وہ جنت کے مستحق ہیں جہاں وہ ہمیشہ رہیں گے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcccxci{اور جن لوگوں نے بُرائیاں کمائیں ان کی بُرائی جیسی ہے ویسا ہی وہ بدلہ پائیں گے، ذلّت ان پر مسلّط ہو گی، کوئی اللہ سے ان کو بچانے والا نہ ہو گا، ان کے چہروں پر ایسی تاریکی چھائی ہوئی ہو گی جیسے رات کے سیاہ پردے ان پر پڑے ہوئے ہوں، وہ دوزخ کے مستحق ہیں جہاں وہ ہمیشہ رہیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcccxcii{جس روز ہم ان سب کو ایک ساتھ (اپنی عدالت میں) اکٹھا کریں گے، پھر ان لوگوں سے جنہوں نے شرک کیا ہے کہیں گے کہ ٹھیر جاؤ تم بھی اور تمہارے بنائے ہوئے شریک بھی، پھر ہم ان کے درمیان سے اجنبیّت کا پردہ ہٹا دیں گے اور ان کے شریک کہیں گے کہ “تم ہماری عبادت تو نہیں کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcccxciii{ہمارے اور تمہارے درمیان اللہ کی گواہی کافی ہے کہ (تم اگر ہماری عبادت کرتے بھی تھے تو) ہم تمہاری اس عبادت سے بالکل بے خبر تھے ``\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcccxciv{اُس وقت ہر شخص اپنے کیے کا مزا چکھ لے گا، سب اپنے مالک حقیقی کی طرف پھیر دیے جائیں گے اور وہ سارے جھوٹ جو انہوں نے گھڑ رکھے تھے گم ہو جائیں گے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcccxcv{اِن سے پُوچھو، کون تم کو آسمان اور زمین سے رزق دیتا ہے؟ یہ سماعت اور بینائی کی قوتیں کس کے اختیار میں ہیں؟ کون بے جان میں سے جاندار کو اور جاندار میں سے بے جان کو نکالتا ہے؟ کون اِس نظم عالم کی تدبیر کر رہا ہے؟ وہ ضرور کہیں گے کہ اللہ کہو، پھر تم (حقیقت کے خلاف چلنے سے) پرہیز نہیں کرتے؟\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcccxcvi{تب تو یہی اللہ تمہارا حقیقی رب ہے پھر حق کے بعد گمراہی کے سوا اور کیا باقی رہ گیا؟ آخر یہ تم کدھر پھرائے جا رہے ہو؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcccxcvii{(اے نبیؐ، دیکھو) اس طرح نافرمانی اختیار کرنے والوں پر تمہارے رب کی بات صادق آ گئی کہ وہ مان کر نہ دیں گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcccxcviii{اِن سے پُوچھو، تمہارے ٹھیرائے ہوئے شریکوں میں کوئی ہے جو تخلیق کی ابتدا بھی کرتا ہو اور پھر اس کا اعادہ بھی کرے؟ کہو وہ صرف اللہ ہے جو تخلیق کی ابتدا بھی کرتا ہے اور اس کا اعادہ بھی، پھر تم یہ کس اُلٹی راہ پر چلائے جا رہے ہو؟\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcccxcix{اِن سے پُوچھو تمہارے ٹھیرائے ہوئے شریکوں میں کوئی ایسا بھی ہے جو حق کی طرف رہنمائی کرتا ہو؟ کہو وہ صرف اللہ ہے جو حق کی طرف رہنمائی کرتا ہے پھر بھلا بتاؤ، جو حق کی طرف رہنمائی کرتا ہے وہ اِس کا زیادہ مستحق ہے کہ اس کی پیروی کی جائے یا وہ جو خود راہ نہیں پاتا اِلّا یہ کہ اس کی رہنمائی کی جائے؟ آخر تمہیں ہو کیا گیا ہے، کیسے اُلٹے الٹے فیصلے کرتے ہو؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcd{حقیقت یہ ہے کہ اِن میں سے اکثر لوگ محض قیاس و گمان کے پیچھے چلے جا رہے ہیں، حالاں کہ گمان حق کی ضرورت کو کچھ بھی پُورا نہیں کرتا جو کچھ یہ کر رہے ہیں اللہ اُس کو خوب جانتا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcdi{اور یہ قرآن وہ چیز نہیں ہے جو اللہ کی وحی و تعلیم کے بغیر تصنیف کر لیا جائے بلکہ یہ تو جو کچھ پہلے آ چکا تھا اس کی تصدیق اور الکتاب کی تفصیل ہے اِس میں کوئی شک نہیں کہ یہ فرمانروائے کائنات کی طرف سے ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcdii{کیا یہ لوگ کہتے ہیں کہ پیغمبرؐ نے اسے خود تصنیف کر لیا ہے؟ کہو، “اگر تم اپنے اس الزام میں سچّے ہو تو ایک سُورۃ اس جیسی تصنیف کر لاؤ اور ایک خدا کو چھوڑ کر جس جس کو بُلا سکتے ہو مدد کے لیے بُلا لو"\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcdiii{اصل یہ ہے کہ جو چیز اِن کے علم کی گرفت میں نہیں آئی اور جس کا مآل بھی ان کے سامنے نہیں آیا، اُس کو اِنہوں نے (خوامخواہ اٹکل پچّو) جھٹلا دیا اِسی طرح تو ان سے پہلے کے لوگ بھی جھٹلا چکے ہیں پھر دیکھ لو اُن ظالموں کا کیا انجام ہُوا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcdiv{اِن میں سے کچھ لوگ ایمان لائیں گے اور کچھ نہیں لائیں گے اور تیرا رب اُن مفسدوں کو خوب جانتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcdv{اگر یہ تجھے جھٹلاتے ہیں تو کہہ دے کہ “میرا عمل میرے لیے ہے اور تمہارا عمل تمہارے لیے، جو کچھ میں کرتا ہوں اس کی ذمہ داری سے تم بَری ہو اور جو کچھ تم کر رہے ہو اس کی ذمہ داری سے میں بَری ہوں"\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcdvi{ان میں بہت سے لوگ ہیں جو تیری باتیں سنتے ہیں، مگر کیا تو بہروں کو سنائیگا خواہ وہ کچھ نہ سمجھتے ہوں؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcdvii{اِن میں بہت سے لوگ ہیں جو تجھے دیکھتے ہیں، مگر کیا تو اندھوں کو راہ بتائے گا خواہ انہیں کچھ نہ سُوجھتا ہو؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcdviii{حقیقت یہ ہے کہ اللہ لوگوں پر ظلم نہیں کرتا، لوگ خود ہی اپنے اُوپر ظلم کرتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcdix{(آج یہ دُنیا کی زندگی میں مست ہیں) اور جس روز اللہ اِن کو اکٹھا کرے گا تو (یہی دُنیا کی زندگی اِنہیں ایسی محسُوس ہوگی) گویا یہ محض ایک گھڑی بھر آپس میں جان پہچان کرنے کو ٹھیرے تھے (اس وقت تحقیق ہو جائے گا کہ) فی الواقع سخت گھاٹے میں رہے وہ لوگ جنہوں نے اللہ کی ملاقات کو جھٹلایا اور ہرگز وہ راہِ راست پر نہ تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcdx{جن بُرے نتائج سے ہم انہیں ڈرا رہے ہیں ان کا کوئی حصہ ہم تیرے جیتے جی دکھا دیں یا اس سے پہلے ہی تجھے اُٹھا لیں، بہرحال اِنہیں آنا ہماری ہی طرف ہے اور جو کچھ یہ کر رہے ہیں اس پر اللہ گواہ ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcdxi{ہر امّت کے لیے ایک رسُول ہے پھر جب کسی امّت کے پاس اُس کا رسُول آ جاتا ہے تو اس کا فیصلہ پُورے انصاف کے ساتھ چکا دیا جاتا ہے اور اس پر ذرہ برابر ظلم نہیں کیا جاتا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcdxii{کہتے ہیں اگر تمہاری یہ دھمکی سچّی ہے تو آخر یہ کب پُوری ہو گی؟\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcdxiii{کہو “میرے اختیار میں خود اپنا نفع و ضرر بھی نہیں، سب کچھ اللہ کی مشیّت پر موقوف ہے ہر امّت کے لیے مُہلت کی ایک مدّت ہے، جب یہ مدّت پُوری ہو جاتی ہے تو گھڑی بھر کی تقدیم و تاخیر بھی نہیں ہوتی"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcdxiv{اِن سے کہو، کبھی تم نے یہ بھی سوچا کہ اگر اللہ کا عذاب اچانک رات کو یا دن کو آ جائے (تو تم کیا کر سکتے ہو؟) آخر یہ ایسی کونسی چیز ہے جس کے لیے مجرم جلدی مچائیں؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcdxv{کیا جب وہ تم پر آ پڑے اسی وقت تم اسے مانو گے؟ اب بچنا چاہتے ہو؟ حالانکہ تم خود ہی اس کے جلدی آنے کا تقاضا کر رہے تھے!\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcdxvi{پھر ظالموں سے کہا جائے گا کہ اب ہمیشہ کے عذاب کا مزا چکھو، جو کچھ تم کماتے رہے ہو اس کی پاداش کے سوا اور کیا بدلہ تم کو دیا جا سکتا ہے؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcdxvii{پھر پُوچھتے ہیں کیا واقعی یہ سچ ہے جو تم کہہ رہے ہو؟ کہو “میرے رب کی قسم، یہ بالکل سچ ہے اور تم اتنا بل بوتا نہیں رکھتے کہ اسے ظہُور میں آنے سے روک دو"\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcdxviii{اگر ہر اُس شخص کے پاس جس نے ظلم کیا ہے، رُوئے زمین کی دولت بھی ہو تو اُس عذاب سے بچنے کے لیے وہ اسے فدیہ میں دینے پر آمادہ ہو جائے گا جب یہ لوگ اس عذاب کو دیکھ لیں گے تو دل ہی دل میں پچھتائیں گے مگر ان کے درمیان پُورے انصاف سے فیصلہ کیا جائے گا کوئی ظلم ان پر نہ ہو گا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcdxix{سنو! آسمانوں اور زمین میں جو کچھ ہے اللہ کا ہے سُن رکھو! اللہ کا وعدہ سچّا ہے مگر اکثر انسان جانتے نہیں ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcdxx{وہی زندگی بخشتا ہے اور وہی موت دیتا ہے اور اسی کی طرف تم سب کو پلٹنا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcdxxi{لوگو! تمہارے پاس تمہارے رب کی طرف سے نصیحت آ گئی ہے یہ وہ چیز ہے جو دلوں کے امراض کی شفا ہے اور جو اسے قبول کر لیں ان کے لیے رہنمائی اور رحمت ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcdxxii{اے نبیؐ، کہو کہ “یہ اللہ کا فضل اور اس کی مہربانی ہے کہ یہ چیز اس نے بھیجی، اس پر تو لوگوں کو خوشی منانی چاہیے، یہ اُن سب چیزوں سے بہتر ہے جنہیں لوگ سمیٹ رہے ہیں"\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcdxxiii{اے نبیؐ، ان سے کہو “تم لوگوں نے کبھی یہ بھی سوچا ہے کہ جو رزق اللہ نے تمہارے لیے اتارا تھا اس میں سے تم نے خود ہی کسی کو حرام اور کسی کو حلال ٹھیرا لیا!" اِن سے پوچھو، اللہ نے تم کو اس کی اجازت دی تھی؟ یا تم اللہ پر افترا کر رہے ہو؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcdxxiv{جو لوگ اللہ پر یہ جھوٹا افترا باندھتے ہیں ان کا کیا گمان ہے کہ قیامت کے روز ان سے کیا معاملہ ہو گا؟ اللہ تو لوگوں پر مہربانی کی نظر رکھتا ہے مگر اکثر انسان ایسے ہیں جو شکر نہیں کرتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcdxxv{اے نبیؐ، تم جس حال میں بھی ہوتے ہو اور قرآن میں سے جو کچھ بھی سُناتے ہو، اور لوگو، تم بھی جو کچھ کرتے ہو اُس سب کے دوران میں ہم تم کو دیکھتے رہتے ہیں کوئی ذرہ برابر چیز آسمان اور زمین میں ایسی نہیں ہے، نہ چھوٹی نہ بڑی، جو تیرے رب کی نظر سے پوشیدہ ہو اور ایک صاف دفتر میں درج نہ ہو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcdxxvi{سُنو! جو اللہ کے دوست ہیں، جو ایمان لائے اور جنہوں نے تقویٰ کا رویہ اختیار کیا،\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcdxxvii{ان کے لیے کسی خوف اور رنج کا موقع نہیں ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcdxxviii{دُنیا اور آخرت دونوں زندگیوں میں ان کے لیے بشارت ہی بشارت ہے اللہ کی باتیں بدل نہیں سکتیں یہی بڑی کامیابی ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcdxxix{اے نبیؐ، جو باتیں یہ لوگ تجھ پر بناتے ہیں وہ تجھے رنجیدہ نہ کریں، عزّت ساری کی ساری خدا کے اختیار میں ہے، اور وہ سب کچھ سنتا اور جانتا ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcdxxx{آگاہ رہو! آسمان کے بسنے والے ہوں یا زمین کے، سب سے سب اللہ کے مملوک ہیں اور جو لوگ اللہ کے سوا کچھ (اپنے خودساختہ) شریکوں کو پکار رہے ہیں وہ نِرے وہم و گمان کے پیرو ہیں اور محض قیاس آرائیاں کرتے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcdxxxi{وہ اللہ ہی ہے جس نے تمہارے لیے رات بنائی کہ اس میں سکون حاصل کرو اور دن کو روشن بنایا اس میں نشانیاں ہیں اُن لوگوں کے لیے جو (کھلے کانوں سے پیغمبر کی دعوت کو) سنتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcdxxxii{لوگوں نے کہہ دیا کہ اللہ نے کسی کو بیٹا بنایا ہے سبحان اللہ! وہ تو بے نیاز ہے، آسمانوں اور زمین میں جو کچھ ہے سب اس کی ملک ہے تمہارے پاس اس قول کے لیے آخر کیا دلیل ہے؟ کیا تم اللہ کے متعلق وہ باتیں کہتے ہو جو تمہارے علم میں نہیں ہیں؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiii{اے محمدؐ، کہہ دو کہ جو لوگ اللہ پر جھوٹے افترا باندھتے ہیں وہ ہرگز فلاح نہیں پا سکتے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiv{دنیا کی چند روزہ زندگی میں مزے کر لیں، پھر ہماری طرف اُن کو پلٹنا ہے پھر ہم اس کفر کے بدلے جس کا ارتکاب وہ کر رہے ہیں ان کو سخت عذاب کا مزہ چکھائیں گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcdxxxv{اِن کو نوحؑ کا قصہ سناؤ، اُس وقت کا قصہ جب اُس نے اپنی قوم سے کہا تھا کہ “اے برادران قوم، اگر میرا تمہارے درمیان رہنا اور اللہ کی آیات سنا سنا کر تمہیں غفلت سے بیدار کرنا تمہارے لیے ناقابل برداشت ہو گیا ہے تو میرا بھروسہ اللہ پر ہے، تم اپنے ٹھیرائے ہوئے شریکوں کو ساتھ لے کر ایک متفقہ فیصلہ کر لو اور جو منصوبہ تمہارے پیش نظر ہو اس کو خوب سوچ سمجھ لو تاکہ اس کا کو ئی پہلو تمہاری نگاہ سے پوشیدہ نہ رہے، پھر میرے خلاف اس کو عمل میں لے آؤ اور مجھے ہرگز مہلت نہ دو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvi{تم نے میری نصیحت سے منہ موڑا (تو میرا کیا نقصان کیا) میں تم سے کسی اجر کا طلب گار نہ تھا، میرا اجر تو اللہ کے ذمہ ہے اور مجھے حکم دیا گیا ہے کہ (خواہ کوئی مانے یا نہ مانے) میں خود مسلم بن کر رہوں"\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvii{انہوں نے اسے جھٹلایا اور نتیجہ یہ ہوا کہ ہم نے اسے اور اُن لوگوں کو جو اس کے ساتھ کشتی میں تھے، بچا لیا اور انہی کو زمین میں جانشین بنایا اور ان سب لوگوں کو غرق کر دیا جنہوں نے ہماری آیات کو جھٹلایا تھا پس دیکھ لو کہ جنہیں متنبہ کیا گیا تھا (اور پھر بھی انہوں نے مان کر نہ دیا) اُن کا کیا انجام ہوا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcdxxxviii{پھر نوحؑ کے بعد ہم نے مختلف پیغمبروں کو اُن کی قوموں کی طرف بھیجا اور وہ اُن کے پاس کھلی کھلی نشانیاں لے کر آئے، مگر جس چیز کو انہوں نے پہلے جھٹلا دیا تھا اسے پھر مان کر نہ دیا اس طرح ہم حد سے گزر جانے والوں کے دلوں پر ٹھپہ لگا دیتے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcdxxxix{پھر ان کے بعد ہم نے موسیٰؑ اور ہارونؑ کو اپنی نشانیوں کے ساتھ فرعون اور اس کے سرداروں کی طرف بھیجا، مگر انہوں نے اپنی بڑائی کا گھمنڈ کیا اور وہ مجرم لوگ تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcdxl{پس جب ہمارے پاس سے حق ان کے سامنے آیا تو انہوں نے کہہ دیا کہ یہ تو کھلا جادو ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcdxli{موسیٰؑ نے کہا: “تم حق کو یہ کہتے ہو جبکہ وہ تمہارے سامنے آگیا؟ کیا یہ جادو ہے؟ حالانکہ جادو گر فلاح نہیں پایا کرتے"\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcdxlii{اُنہوں نے جواب میں کہا “کیا تواس لیے آیا ہے کہ ہمیں اُ س طریقے سے پھیر دے جس پر ہم نے اپنے باپ دادا کو پایا ہے اور زمین میں بڑائی تم دونوں کی قائم ہو جائے؟ تمہارے بات تو ہم ماننے والے نہیں ہیں"\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcdxliii{اور فرعون نے (اپنے آدمیوں سے) کہا کہ “ہر ماہر فن جادوگر کو میرے پاس حاضر کرو ``\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcdxliv{جب جادو گر آ گئے تو موسیٰؑ نے ان سے کہا “جو کچھ تمہیں پھینکنا ہے پھینکو"\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcdxlv{پھر جب انہوں نے اپنے آنچھر پھینک دیے تو موسیٰؑ نے کہا “یہ جو کچھ تم نے پھینکا ہے یہ جادو ہے، اللہ ابھی اِسے باطل کیے دیتا ہے، مفسدوں کے کام کو اللہ سدھرنے نہیں دیتا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcdxlvi{اور اللہ اپنے فرمانوں سے حق کو حق کر دکھاتا ہے، خواہ مجرموں کو وہ کتنا ہی ناگوار ہو"\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcdxlvii{(پھر دیکھو کہ) موسیٰؑ کو اس کی قوم میں سے چند نوجوانوں کے سوا کسی نے نہ مانا، فرعون کے ڈر سے اور خود اپنی قوم کے سر بر آوردہ لوگوں کے ڈر سے (جنہیں خوف تھا کہ) فرعون ان کو عذاب میں مبتلا کرے گا اور واقعہ یہ ہے کہ فرعون زمین میں غلبہ رکھتا تھا اور وہ اُن لوگوں میں سے تھا جو کسی حد پر رکتے نہیں ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcdxlviii{موسیٰؑ نے اپنی قوم سے کہا کہ “لوگو، اگر تم واقعی اللہ پر ایمان رکھتے ہو تو اس پر بھروسہ کرو اگر مسلمان ہو"\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcdxlix{انہوں نے جواب دیا “ہم نے اللہ ہی پر بھروسہ کیا، اے ہمارے رب، ہمیں ظالم لوگوں کے لیے فتنہ نہ بنا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcdl{اور اپنی رحمت سے ہم کو کافروں سے نجات دے"\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcdli{اور ہم نے موسیٰؑ اور اس کے بھائی کو اشارہ کیا کہ “مصر میں چند مکان اپنی قوم کے لیے مہیا کرو اور اپنے ان مکانوں کو قبلہ ٹھیرا لو اور نماز قائم کرو اور اہل ایمان کو بشارت دے دو"\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcdlii{موسیٰؑ نے دعا کی “اے ہمارے رب، تو نے فرعون اور اس کے سرداروں کو دنیا کی زندگی میں زینت اور اموال سے نواز رکھا ہے اے رب، کیا یہ اس لیے ہے کہ وہ لوگوں کو تیری راہ سے بھٹکائیں؟ اے رب، ان کے مال غارت کر دے اور ان کے دلوں پر ایسی مہر کر دے کہ ایمان نہ لائیں جب تک دردناک عذاب نہ دیکھ لیں"\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcdliii{اللہ تعالیٰ نے جواب میں فرمایا “تم دونوں کی دعا قبول کی گئی ثابت قدم رہو اور اُن لوگوں کے طریقے کی ہرگز پیروی نہ کرو جو علم نہیں رکھتے"\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcdliv{اور ہم بنی اسرائیل کو سمندر سے گزار لے گئے پھر فرعون اور اس کے لشکر ظلم اور زیادتی کی غرض سے ان کے پیچھے چلے حتیٰ کہ جب فرعون ڈوبنے لگا تو بول اٹھا ``میں نے مان لیا کہ خداوند حقیقی اُس کے سوا کوئی نہیں ہے جس پر بنی اسرائیل ایمان لائے، اور میں بھی سر اطاعت جھکا دینے والوں میں سے ہوں"\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcdlv{(جواب دیا گیا) “اب ایمان لاتا ہے! حالانکہ اِس سے پہلے تک تو نافرمانی کرتا رہا اور فساد برپا کرنے والوں میں سے تھا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcdlvi{اب تو ہم صرف تیری لاش ہی کو بچائیں گے تاکہ تو بعد کی نسلوں کے لیے نشان عبرت بنے اگرچہ بہت سے انسان ایسے ہیں جو ہماری نشانیوں سے غفلت برتتے ہیں"\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcdlvii{ہم نے بنی اسرائیل کو بہت اچھا ٹھکانا دیا اور نہایت عمدہ وسائل زندگی انہیں عطا کیے پھر انہوں نے باہم اختلاف نہیں کیا مگراُس وقت جبکہ علم اُن کے پاس آ چکا تھا یقیناً تیرا رب قیامت کے روز اُن کے درمیان اُس چیز کا فیصلہ کر دے گا جس میں وہ اختلاف کرتے رہے ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcdlviii{اب اگر تجھے اُس ہدایت کی طرف سے کچھ بھی شک ہو جو ہم نے تجھ پر نازل کی ہے تو اُن لوگوں سے پوچھ لے جو پہلے سے کتاب پڑھ رہے ہیں فی الواقع یہ تیرے پاس حق ہی آیا ہے تیرے رب کی طرف سے، لہٰذا تو شک کرنے والوں میں سے نہ ہو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcdlix{اور ان لوگوں میں نہ شامل ہو جنہوں نے اللہ کی آیات کو جھٹلایا ہے، ورنہ تو نقصان اٹھانے والوں میں سے ہوگا\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcdlx{حقیقت یہ ہے کہ جن لوگوں پر تیرے رب کا قول راست آگیا ہے ان کے سامنے خواہ کوئی نشانی آ جائے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcdlxi{وہ کبھی ایمان لا کر نہیں دیتے جب تک کہ درد ناک عذاب سامنے آتا نہ دیکھ لیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcdlxii{پھر کیا ایسی کوئی مثال ہے کہ ایک بستی عذاب دیکھ کر ایمان لائی ہو اور اس کا ایمان اس کے لیے نفع بخش ثابت ہوا ہو؟ یونسؑ کی قوم کے سوا (اس کی کوئی نظیر نہیں) وہ قوم جب ایمان لے آئی تھی تو البتہ ہم نے اس پر سے دنیا کی زندگی میں رسوائی کا عذاب ٹال دیا تھا اور اس کو ایک مدت تک زندگی سے بہرہ مند ہونے کا موقع دے دیا تھا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcdlxiii{اگر تیرے رب کی مشیت یہ ہوتی (کہ زمین میں سب مومن و فرمانبردار ہی ہوں) تو سارے اہل زمین ایمان لے آئے ہوتے پھر کیا تو لوگوں کو مجبور کرے گا کہ وہ مومن ہو جائیں؟\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcdlxiv{کوئی متنفس اللہ کے اذن کے بغیر ایمان نہیں لا سکتا، اور اللہ کا طریقہ یہ ہے کہ جو لوگ عقل سے کام نہیں لیتے وہ ان پر گندگی ڈال دیتا ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcdlxv{اِن سے کہو “زمین اور آسمانوں میں جو کچھ ہے اسے آنکھیں کھول کر دیکھو" اور جو لوگ ایمان لانا ہی نہیں چاہتے ان کے لیے نشانیاں اور تنبیہیں آخر کیا مفید ہو سکتی ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcdlxvi{اب یہ لوگ اِس کے سوا اور کس چیز کے منتظر ہیں کہ وہی برے دن دیکھیں جو اِن سے پہلے گزرے ہوئے لوگ دیکھ چکے ہیں؟ اِن سے کہو “اچھا، انتظار کرو، میں بھی تمہارے ساتھ انتظار کرتا ہوں"\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcdlxvii{پھر (جب ایسا وقت آتا ہے تو) ہم اپنے رسولوں کو اور اُن لوگوں کو بچا لیا کرتے ہیں جو ایمان لائے ہوں ہمارا یہی طریقہ ہے ہم پر یہ حق ہے کہ مومنوں کو بچا لیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcdlxviii{اے نبیؐ! کہہ دو کہ لوگو، اگر تم ابھی تک میرے دین کے متعلق کسی شک میں ہو تو سن لو کہ تم اللہ کے سوا جن کی بندگی کرتے ہو میں ان کی بندگی نہیں کرتا بلکہ صرف اسی خدا کی بندگی کرتا ہوں جس کے قبضے میں تمہاری موت ہے مجھے حکم دیا گیا ہے کہ میں ایمان لانے والوں میں سے ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcdlxix{اور مجھ سے فرمایا گیا ہے کہ تو یکسو ہو کر اپنے آپ کو ٹھیک ٹھیک اِس دین پر قائم کر دے، اور ہرگز ہرگز مشرکوں میں سے نہ ہو\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcdlxx{اور اللہ کو چھوڑ کر کسی ایسی ہستی کو نہ پکار جو تجھے نہ فائدہ پہنچا سکتی ہے نہ نقصان اگر تو ایسا کرے گا تو ظالموں میں سے ہوگا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcdlxxi{اگر اللہ تجھے کسی مصیبت میں ڈالے تو خود اس کے سوا کوئی نہیں جو اس مصیبت کو ٹال دے، اور اگر وہ تیرے حق میں کسی بھلائی کا ارادہ کرے تو اس کے فضل کو پھیرنے والا بھی کوئی نہیں ہے وہ اپنے بندوں میں سے جس کو چاہتا ہے اپنے فضل سے نوازتا ہے اور وہ درگزر کرنے والا اور رحم فرمانے والا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcdlxxii{اے محمدؐ، کہہ دو کہ “لوگو، تمہارے پاس تمہارے رب کی طرف سے حق آ چکا ہے اب جو سیدھی راہ اختیار کرے اس کی راست روی اسی کے لیے مفید ہے، اور جو گمراہ رہے اس کی گمراہی اسی کے لیے تباہ کن ہے اور میں تمہارے اوپر کوئی حوالہ دار نہیں ہوں"\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiii{اور اے نبیؐ، تم اس ہدایت کی پیروی کیے جاؤ جو تمہاری طرف بذریعہ وحی بھیجی جا رہی ہے، اور صبر کرو یہاں تک کہ اللہ فیصلہ کر دے، اور وہی بہترین فیصلہ کرنے والا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiv{\basmalahur ا ل ر فرمان ہے، جس کی آیتیں پختہ اور مفصل ارشاد ہوئی ہیں، ایک دانا اور باخبر ہستی کی طرف سے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcdlxxv{کہ تم بندگی نہ کرو مگر صرف اللہ کی میں اُس کی طرف سے تم کو خبردار کرنے والا بھی ہوں اور بشارت دینے والا بھی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvi{اور یہ کہ تم اپنے رب سے معافی چاہو اور اس کی طرف پلٹ آؤ تو وہ ایک مدت خاص تک تم کو اچھا سامان زندگی دے گا اور ہر صاحب فضل کو اس کا فضل عطا کرے گا لیکن اگر تم منہ پھیرتے ہو تو میں تمہارے حق میں ایک بڑے ہولناک دن کے عذاب سے ڈرتا ہوں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvii{تم سب کو اللہ کی طرف پلٹنا ہے اور وہ سب کچھ کرسکتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcdlxxviii{دیکھو! یہ لوگ اپنے سینوں کو موڑتے ہیں تاکہ اس سے چھپ جائیں خبردار! جب یہ کپڑوں سے اپنے آپ کو ڈھانپتے ہیں، اللہ ان کے چھپے کو بھی جانتا ہے اور کھلے کو بھی، وہ تو اُن بھیدوں سے بھی واقف ہے جو سینوں میں ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcdlxxix{زمین میں چلنے والا کوئی جاندار ایسا نہیں ہے جس کا رزق اللہ کے ذمے نہ ہو اور جس کے متعلق وہ نہ جانتا ہو کہ کہاں وہ رہتا ہے اور کہاں وہ سونپا جاتا ہے، سب کچھ ایک صاف دفتر میں درج ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcdlxxx{اور وہی ہے جس نے آسمانوں اور زمین کو چھ دنوں میں پیدا کیا جبکہ اس سے پہلے اس کا عرش پانی پر تھا تاکہ تم کو آزما کر دیکھے تم میں کون بہتر عمل کرنے والا ہے اب اگر اے محمدؐ، تم کہتے ہو کہ لوگو، مرنے کے بعد تم دوبارہ اٹھائے جاؤ گے، تو منکرین فوراً بول اٹھتے ہیں کہ یہ تو صریح جادو گری ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxi{اور اگر ہم ایک خاص مدت تک ان کی سزا کو ٹالتے ہیں تو وہ کہنے لگتے ہیں کہ آخر کس چیز نے اُسے روک رکھا ہے؟ سنو! جس روز اُس سزا کا وقت آگیا تو وہ کسی کے پھیرے نہ پھر سکے گا اور وہی چیز ان کو آ گھیرے گی جس کا وہ مذاق اڑا رہے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxii{اگر کبھی ہم انسان کو اپنی رحمت سے نوازنے کے بعد پھر اس سے محروم کر دیتے ہیں تو وہ مایوس ہوتا ہے اور ناشکری کرنے لگتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiii{اور اگر اُس مصیبت کے بعد جو اُس پر آئی تھی ہم اسے نعمت کا مزا چکھاتے ہیں تو کہتا ہے میرے تو سارے دلدر پار ہو گئے، پھر وہ پھولا نہیں سماتا اور اکڑنے لگتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiv{اس عیب سے پاک اگر کوئی ہیں تو بس وہ لوگ جو صبر کرنے والے اور نیکو کار ہیں اور وہی ہیں جن کے لیے درگزر بھی ہے اور بڑا اجر بھی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxv{تو اے پیغمبرؐ! کہیں ایسا نہ ہو کہ تم اُن چیزوں میں سے کسی چیز کو (بیان کر نے سے) چھوڑ دو جو تمہاری طرف وحی کی جا رہی ہیں اور اِس بات پر دل تنگ ہو کہ وہ کہیں گے ``اس شخص پر کوئی خزانہ کیوں نہ اتارا گیا" یا یہ کہ ``اس کے ساتھ کوئی فرشتہ کیوں نہ آیا" تم تو محض خبردار کرنے والے ہو، آگے ہر چیز کا حوالہ دار اللہ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvi{کیا یہ کہتے ہیں کہ پیغمبر نے یہ کتاب خود گھڑ لی ہے؟ کہو، ``اچھا یہ بات ہے تو اس جیسی گھڑی ہوئی دس سورتیں تم بنا لاؤ اور اللہ کے سوا اور جو جو (تمہارے معبود) ہیں اُن کو مدد کے لیے بلا سکتے ہو تو بلا لو اگر تم (انہیں معبود سمجھنے میں) سچے ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvii{اب اگر وہ (تمہارے معبود) تمہاری مدد کو نہیں پہنچتے تو جان لو کہ یہ اللہ کے علم سے نازل ہوئی ہے اور یہ کہ اللہ کے سوا کوئی حقیقی معبود نہیں ہے پھر کیا تم (اس امر حق کے آگے) سر تسلیم خم کر تے ہو؟"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxviii{جو لوگ بس اِسی دنیا کی زندگی اور اس کی خو ش نمائیوں کے طالب ہوتے ہیں ان کی کار گزاری کا سارا پھل ہم یہیں ان کو دے دیتے ہیں اور اس میں ان کے ساتھ کوئی کمی نہیں کی جاتی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxix{مگر آخرت میں ایسے لوگوں کے لیے آگ کے سوا کچھ نہیں ہے (وہاں معلوم ہو جائے گا کہ) جو کچھ انہوں نے دنیا میں بنایا وہ سب ملیامیٹ ہو گیا اور اب ان کا سارا کیا دھرا محض باطل ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcdxc{پھر بھلا وہ شخص جو اپنے رب کی طرف سے ایک صاف شہادت رکھتا تھا، اس کے بعد ایک گواہ بھی پروردگار کی طرف سے (اس شہادت کی تائید میں) آ گیا، اور پہلے موسیٰؑ کی کتاب رہنما اور رحمت کے طور پر آئی ہوئی بھی موجود تھی (کیا وہ بھی دنیا پرستوں کی طرح اس سے انکار کرسکتا ہے؟) ایسے لوگ تو اس پر ایمان ہی لائیں گے اور انسانی گروہوں میں سے جو کوئی اس کا انکار کرے تو اس کے لیے جس جگہ کا وعدہ ہے وہ دوزخ ہے پس اے پیغمبرؐ، تم اِس چیز کی طرف سے کسی شک میں نہ پڑنا، یہ حق ہے تمہارے رب کی طرف سے مگر اکثر لوگ نہیں مانتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcdxci{اور اُس شخص سے بڑھ کر ظالم اور کون ہوگا جو اللہ پر جھوٹ گھڑے؟ ایسے لوگ اپنے رب کے حضور پیش ہوں گے اور گواہ شہادت دیں گے کہ یہ ہیں وہ لوگ جنہوں نے اپنے رب پر جھوٹ گھڑا تھا سنو! خدا کی لعنت ہے ظالموں پر\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcdxcii{اُن ظالموں پر جو خدا کے راستے سے لوگوں کو روکتے ہیں، اس کے راستے کو ٹیٹرھا کرنا چاہتے ہیں اور آخرت کا انکار کرتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcdxciii{وہ زمین میں اللہ کو بے بس کرنے والے نہ تھے اور نہ اللہ کے مقابلہ میں کوئی ان کا حامی تھا انہیں اب دوہرا عذاب دیا جائے گا وہ نہ کسی کی سن ہی سکتے تھے اور نہ خود ہی انہیں کچھ سوجھتا تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcdxciv{یہ وہ لوگ ہیں جنہوں نے اپنے آپ کو خود گھاٹے میں ڈالا اور وہ سب کچھ ان سے کھویا گیا جو انہوں نے گھڑ رکھا تھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcdxcv{نا گزیر ہے کہ وہی آخرت میں سب سے بڑھ کر گھاٹے میں رہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcdxcvi{رہے وہ لوگ جو ایمان لائے اور جنہوں نے نیک عمل کیے اور اپنے رب ہی کے ہو کر رہے، تو یقیناً وہ جنتی لوگ ہیں اور جنت میں وہ ہمیشہ رہیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcdxcvii{اِن دونوں فریقوں کی مثال ایسی ہے جیسے ایک آدمی تو ہو اندھا بہرا اور دوسرا ہو دیکھنے اور سننے والا، کیا یہ دونوں یکساں ہو سکتے ہیں؟ کیا تم (اِس مثال سے) کوئی سبق نہیں لیتے؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcdxcviii{(اور ایسے ہی حالات تھے جب) ہم نے نوحؑ کو اُس کی قوم کی طرف بھیجا تھا (اُس نے کہا) ``میں تم لوگوں کو صاف صاف خبردار کرتا ہوں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcdxcix{کہ اللہ کے سوا کسی کی بندگی نہ کرو ورنہ مجھے اندیشہ ہے کہ تم پر ایک روز دردناک عذاب آئے گا"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@md{جواب میں اُس کی قوم کے سردار، جنہوں نے اس کی بات ماننے سے انکار کیا تھا، بولے ``ہماری نظر میں تو تم اس کے سوا کچھ نہیں ہو کہ بس ایک انسان ہو ہم جیسے اور ہم دیکھ رہے ہیں کہ ہماری قوم میں سے بس اُن لوگوں نے جو ہمارے ہاں اراذل تھے بے سوچے سمجھے تمہاری پیروی اختیار کر لی ہے اور ہم کوئی چیز بھی ایسی نہیں پاتے جس میں تم لوگ ہم سے کچھ بڑھے ہوئے ہو، بلکہ ہم تو تمہیں جھوٹا سمجھتے ہیں"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdi{اس نے کہا ``اے برادران قوم، ذرا سوچو تو سہی کہ اگر میں اپنے رب کی طرف سے ایک کھلی شہادت پر قائم تھا اور پھر اس نے مجھ کو اپنی خاص رحمت سے بھی نواز دیا مگر وہ تم کو نظر نہ آئی تو آخر ہمارے پاس کیا ذریعہ ہے کہ تم ماننا نہ چاہو اور ہم زبردستی اس کو تمہارے سر چپیک دیں؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdii{اور اے برادران قوم، میں اِس کام پر تم سے کوئی مال نہیں مانگتا، میرا اجر تو اللہ کے ذمہ ہے اور میں اُن لوگوں کو دھکے دینے سے بھی رہا جنہوں نے میری بات مانی ہے، وہ آپ ہی اپنے رب کے حضور جانے والے ہیں مگر میں دیکھتا ہوں کہ تم لوگ جہالت برت رہے ہو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdiii{اور اے قوم، اگر میں اِن لوگوں کو دھتکار دوں تو خدا کی پکڑ سے کون مجھے بچانے آئے گا؟ تم لوگوں کی سمجھ میں کیا اتنی بات بھی نہیں آتی؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdiv{اور میں تم سے نہیں کہتا کہ میرے پاس اللہ کے خزانے ہیں، نہ یہ کہتا ہوں کہ میں غیب کا علم رکھتا ہوں، نہ یہ میرا دعویٰ ہے کہ میں فرشتہ ہوں اور یہ بھی میں نہیں کہہ سکتا کہ جن لوگوں کو تمہاری آنکھیں حقارت سے دیکھتی ہیں انہیں اللہ نے کوئی بھلائی نہیں دی ان کے نفس کا حال اللہ ہی بہتر جانتا ہے اگر میں ایسا کہوں تو ظالم ہوں گا"\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdv{آخر کار ان لوگوں نے کہا کہ ``اے نوحؑ، تم نے ہم سے جھگڑا کیا اور بہت کر لیا اب تو بس وہ عذاب لے آؤ جس کی تم ہمیں دھمکی دیتے ہو اگر سچے ہو"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdvi{نوحؑ نے جواب دیا ``وہ تو اللہ ہی لائے گا، اگر چاہے گا، اور تم اتنا بل بوتا نہیں رکھتے کہ اسے روک دو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdvii{اب اگر میں تمہاری کچھ خیر خواہی کرنا بھی چاہوں تو میری خیر خواہی تمہیں کوئی فائدہ نہیں دے سکتی جبکہ اللہ ہی نے تمہیں بھٹکا دینے کا ارادہ کر لیا ہو، وہی تمہارا رب ہے اور اُسی کی طرف تمہیں پلٹنا ہے"\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdviii{اے محمدؐ، کیا یہ لوگ کہتے ہیں کہ اِس شخص نے یہ سب کچھ خود گھڑ لیا ہے؟ ان سے کہو ``اگر میں نے یہ خود گھڑا ہے تو مجھ پر اپنے جرم کی ذمہ داری ہے، اور جو جرم تم کر رہے ہو اس کی ذمہ داری سے میں بری ہوں"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdix{نوحؑ پر وحی کی گئی کہ تمہاری قوم میں سے جو لوگ ایمان لا چکے بس وہ لا چکے، اب کوئی ماننے والا نہیں ہے ان کے کرتوتوں پر غم کھانا چھوڑو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdx{اور ہماری نگرانی میں ہماری وحی کے مطابق ایک کشتی بنانی شروع کر دو اور دیکھو، جن لوگوں نے ظلم کیا ہے اُن کے حق میں مجھ سے کوئی سفارش نہ کرنا، یہ سارے کے سارے اب ڈوبنے والے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdxi{نوحؑ کشتی بنا رہا تھا اور اس کی قوم کے سرداروں میں سے جو کوئی اس کے پاس سے گزرتا تھا وہ اس کا مذاق اڑاتا تھا اس نے کہا ``اگر تم ہم پر ہنستے ہو تو ہم بھی تم پر ہنس رہے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdxii{عنقریب تمہیں خود معلوم ہو جائے گا کہ کس پر وہ عذاب آتا ہے جو اُسے رسوا کر دے گا اور کس پر وہ بلا ٹوٹ پڑتی ہے جو ٹالے نہ ٹلے گی"\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdxiii{یہاں تک کہ جب ہمارا حکم آگیا اور وہ تنو ر ابل پڑا تو ہم نے کہا ``ہر قسم کے جانوروں کا ایک ایک جوڑا کشتی میں رکھ لو، اپنے گھر والوں کو بھی سوائے اُن اشخاص کے جن کی نشان دہی پہلے کی جا چکی ہے اس میں سوار کرا دو اور ان لوگوں کو بھی بٹھا لو جو ایمان لائے ہیں" اور تھوڑے ہی لوگ تھے جو نوحؑ کے ساتھ ایمان لائے تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdxiv{نوحؑ نے کہا ``سوار ہو جاؤ اِس میں، اللہ ہی کے نام سے ہے اس کا چلنا بھی اور اس کا ٹھیرنا بھی، میرا رب بڑا غفور و رحیم ہے"\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdxv{کشتی ان لوگوں کو لیے چلی جا رہی تھی اور ایک ایک موج پہاڑ کی طرح اٹھ رہی تھی نوحؑ کا بیٹا دور فاصلے پر تھا نوحؑ نے پکار کر کہا ``بیٹا، ہمارے ساتھ سوار ہو جا، کافروں کے ساتھ نہ رہ"\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdxvi{اُس نے پلٹ کر جواب دیا ``میں ابھی ایک پہاڑ پر چڑھا جاتا ہوں جو مجھے پانی سے بچا لے گا" نوحؑ نے کہا، آج کوئی چیز اللہ کے حکم سے بچانے والی نہیں ہے سوائے اِس کے کہ اللہ ہی کسی پر رحم فرمائے" اتنے میں ایک موج دونوں کے درمیان حائل ہو گئی اور وہ بھی ڈوبنے والوں میں شامل ہو گیا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdxvii{حکم ہوا ``اے زمین، اپنا سارا پانی نگل جا اور اے آسمان، رک جا" چنانچہ پانی زمین میں بیٹھ گیا، فیصلہ چکا دیا گیا، کشتی جودی پر ٹک گئی، اور کہہ دیا گیا کہ دور ہوئی ظالموں کی قو م!\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdxviii{نوحؑ نے اپنے رب کو پکارا کہا ``اے رب، میرا بیٹا میرے گھر والوں میں سے ہے اور تیرا وعدہ سچا ہے اور تو سب حاکموں سے بڑا اور بہتر حاکم ہے"\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdxix{جواب میں ارشاد ہوا ``اے نوحؑ، وہ تیرے گھر والوں میں سے نہیں ہے، وہ تو ایک بگڑا ہوا کام ہے، لہٰذا تو اُس بات کی مجھ سے درخواست نہ کر جس کی حقیقت تو نہیں جانتا، میں تجھے نصیحت کرتا ہوں کہ اپنے آپ کو جاہلوں کی طرح نہ بنا لے"\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdxx{نوحؑ نے فوراً عرض کیا ``اے میرے رب، میں تیری پناہ مانگتا ہوں اِس سے کہ وہ چیز تجھ سے مانگوں جس کا مجھے علم نہیں اگر تو نے مجھ معاف نہ کیا اور رحم نہ فرمایا تو میں برباد ہو جاؤں گا"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdxxi{حکم ہوا ``اے نوحؑ اتر جا، ہماری طرف سے سلامتی اور برکتیں ہیں تجھ پر اور ان گروہوں پر جو تیرے ساتھ ہیں، اور کچھ گروہ ایسے بھی ہیں جن کو ہم کچھ مدت سامان زندگی بخشیں گے پھر انہیں ہماری طرف سے درد ناک عذاب پہنچے گا"\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdxxii{اے محمدؐ، یہ غیب کی خبریں ہیں جو ہم تمہاری طرف وحی کر رہے ہیں اس سے پہلے نہ تم ان کو جانتے تھے اور نہ تمہاری قوم، پس صبر کرو، ا نجام کار متقیوں ہی کے حق میں ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdxxiii{اور عاد کی طرف ہم نے ان کے بھائی ہودؑ کو بھیجا اُس نے کہا ``اے برادران قوم، اللہ کی بندگی کرو، تمہارا کوئی خدا اُس کے سوا نہیں ہے تم نے محض جھوٹ گھڑ رکھے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdxxiv{اے برادران قوم، اس کام پر میں تم سے کوئی اجر نہیں چاہتا، میرا اجر تو اس کے ذمہ ہے جس نے مجھے پیدا کیا ہے، کیا تم عقل سے ذرا کام نہیں لیتے؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdxxv{اور اے میری قوم کے لوگو، اپنے رب سے معافی چاہو، پھر اس کی طرف پلٹو، وہ تم پر آسمان کے دہانے کھول دے گا اور تمہاری موجودہ قوت پر مزید قوت کا اضافہ کرے گا مجرموں کی طرح منہ نہ پھیرو"\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdxxvi{انہوں نے جواب دیا ``اے ہودؑ، تو ہمارے پاس کوئی صریح شہادت لے کر نہیں آیا ہے، اور تیرے کہنے سے ہم اپنے معبودوں کو نہیں چھوڑ سکتے، اور تجھ پر ہم ایمان لانے والے نہیں ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdxxvii{ہم تو یہ سمجھتے ہیں کہ تیرے اوپر ہمارے معبودوں میں سے کسی کی مار پڑ گئی ہے" ہودؑ نے کہا ``میں اللہ کی شہادت پیش کرتا ہوں اور تم گواہ رہو کہ یہ جو اللہ کے سوا دوسروں کو تم نے خدائی میں شریک ٹھیرا رکھا ہے اس سے میں بیزار ہوں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdxxviii{تم سب کے سب مل کر میرے خلاف اپنی کرنی میں کسر نہ اٹھا رکھو اور مجھے ذرا مہلت نہ دو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdxxix{میرا بھروسہ اللہ پر ہے جو میرا رب بھی ہے اور تمہارا رب بھی کوئی جاندار ایسا نہیں جس کی چوٹی اس کے ہاتھ میں نہ ہو بے شک میرا رب سیدھی ر اہ پر ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdxxx{اگر تم منہ پھیرتے ہو تو پھیر لو جو پیغام دے کر میں تمہارے پاس بھیجا گیا تھا وہ میں تم کو پہنچا چکا ہوں اب میرا رب تمہاری جگہ دوسری قوم کو اٹھائے گا اور تم اس کا کچھ نہ بگاڑ سکو گے یقیناً میرا رب ہر چیز پر نگراں ہے"\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdxxxi{پھر جب ہمارا حکم آگیا تو ہم نے اپنی رحمت سے ہودؑ کو اور اُن لوگوں کو جو اُس کے ساتھ ایمان لائے تھے نجات دے دی اور ایک سخت عذاب سے بچا لیا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdxxxii{یہ ہیں عاد، اپنے رب کی آیات سے انہوں نے انکار کیا، اس کے رسولوں کی بات نہ مانی، اور ہر جبار دشمن حق کی پیروی کرتے رہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdxxxiii{آخر کار اس دنیا میں بھی ان پر پھٹکار پڑی اور قیامت کے روز بھی سنو! عاد نے اپنے رب سے کفر کیا، سنو! دور پھینک دیے گئے عاد، ہودؑ کی قوم کے لوگ\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdxxxiv{اور ثمود کی طرف ہم نے ان کے بھائی صالحؑ کو بھیجا اُس نے کہا ``اے میری قوم کے لوگو، اللہ کی بندگی کرو، اُ س کے سوا تمہارا کوئی خدا نہیں ہے وہی ہے جس نے تم کو زمین سے پیدا کیا ہے اور یہاں تم کو بسایا ہے لہٰذا تم اس سے معافی چاہو اور اس کی طرف پلٹ آؤ، یقیناً میرا رب قریب ہے اور وہ دعاؤں کا جواب دینے والا ہے"\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdxxxv{انہوں نے کہا ``اے صالحؑ، اس سے پہلے تو ہمارے درمیان ایسا شخص تھا جس سے بڑی توقعات وابستہ تھیں کیا تو ہمیں ان معبودوں کی پرستش سے روکنا چاہتا ہے جن کی پرستش ہمارے باپ دادا کرتے تھے؟ تو جس طریقے کی طرف ہمیں بلا رہا ہے اس کے بارے میں ہم کو سخت شبہ ہے جس نے ہمیں خلجان میں ڈال رکھا ہے"\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdxxxvi{صالحؑ نے کہا ``اے برادران قوم، تم نے کچھ اس بات پر بھی غور کیا کہ اگر میں اپنے رب کی طرف سے ایک صاف شہادت رکھتا تھا، اور پھر اس نے اپنی رحمت سے بھی مجھ کو نواز دیا تو اِس کے بعد اللہ کی پکڑ سے مجھے کون بچائے گا اگر میں اُس کی نافرمانی کروں؟ تم میرے کس کام آ سکتے ہو سوائے اس کے کہ مجھے اور زیادہ خسارے میں ڈال دو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdxxxvii{اور اے میری قوم کے لوگو، دیکھو یہ اللہ کی اونٹنی تمہارے لیے ایک نشانی ہے اِسے خدا کی زمین میں چرنے کے لیے آزاد چھوڑ دو اِس سے ذرا تعرض نہ کرنا ورنہ کچھ زیادہ دیر نہ گزرے گی کہ تم پر خدا کا عذاب آ جائے گا"\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdxxxviii{مگر انہوں نے اونٹنی کو مار ڈالا اس پر صالحؑ نے اُن کو خبردار کر دیا کہ ``بس اب تین دن اپنے گھروں میں اور رہ بس لو یہ ایسی میعاد ہے جو جھوٹی نہ ثابت ہوگی"\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdxxxix{آخر کار جب ہمارے فیصلے کا وقت آ گیا تو ہم نے اپنی رحمت سے صالحؑ کو اور اُن لوگوں کو جو اس کے ساتھ ایمان لائے تھے بچا لیا اور اُس دن کی رسوائی سے ان کو محفوظ رکھا بے شک تیرا رب ہی دراصل طاقتور اور بالا دست ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdxl{رہے وہ لوگ جنہوں نے ظلم کیا تھا تو ایک سخت دھماکے نے ان کو دھر لیا اور وہ اپنی بستیوں میں اس طرح بے حس و حرکت پڑے کے پڑے رہ گئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdxli{کہ گویا وہ وہاں کبھی بسے ہی نہ تھے سنو! ثمود نے اپنے رب سے کفر کیا سنو! دور پھینک دیے گئے ثمود!\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdxlii{اور دیکھو، ابراہیمؑ کے پاس ہمارے فرشتے خوشخبری لیے ہوئے پہنچے کہا تم پر سلام ہو ابراہیمؑ نے جواب دیا تم پر بھی سلام ہو پھر کچھ دیر نہ گزری کہ ابراہیمؑ ایک بھنا ہوا بچھڑا (ان کی ضیافت کے لیے) لے آیا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdxliii{مگر جب دیکھا کہ ان کے ہاتھ کھانے پر نہیں بڑھتے تو وہ ان سے مشتبہ ہو گیا اور دل میں ان سے خوف محسوس کرنے لگا اُنہوں نے کہا ``ڈرو نہیں، ہم تو لوطؑ کی قوم کی طرف بھیجے گئے ہیں"\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdxliv{ابراہیمؑ کی بیوی بھی کھڑی ہوئی تھی وہ یہ سن کر ہنس دی پھر ہم نے اس کو اسحاقؑ کی اور اسحاقؑ کے بعد یعقوب کی خوشخبری دی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdxlv{وہ بولی ``ہائے میری کم بختی! کیا اب میرے ہاں اولاد ہوگی جبکہ میں بڑھیا پھونس ہو گئی اور یہ میرے میاں بھی بوڑھے ہو چکے؟ یہ تو بڑی عجیب بات ہے"\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdxlvi{فرشتوں نے کہا ``اللہ کے حکم پر تعجب کرتی ہو؟ ابراہیمؑ کے گھر والو، تم لوگوں پر تو اللہ کی رحمت اور اُس کی برکتیں ہیں، اور یقیناً اللہ نہایت قابل تعریف اور بڑی شان والا ہے"\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdxlvii{پھر جب ابراہیمؑ کی گھبراہٹ دور ہو گئی اور (اولاد کی بشارت سے) اس کا دل خوش ہو گیا تو اس نے قوم لوط کے معاملے میں ہم سے جھگڑا شروع کیا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdxlviii{حقیقت میں ابراہیمؑ بڑا حلیم اور نرم دل آدمی تھا اور ہر حال میں ہماری طرف رجوع کرتا تھا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdxlix{(آخر کار ہمارے فرشتوں نے اس سے کہا) ``اے ابراہیمؑ، اس سے باز آ جاؤ، تمہارے رب کا حکم ہو چکا ہے اور اب ان لوگوں پر وہ عذاب آکر رہے گا جو کسی کے پھیرے نہیں پھر سکتا"\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdl{اور جب ہمارے فرشتے لوطؑ کے پاس پہنچے تو اُن کی آمد سے وہ بہت گھبرایا اور دل تنگ ہوا اور کہنے لگا کہ آج بڑی مصیبت کا دن ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdli{(ان مہمانوں کا آنا تھا کہ) اس کی قوم کے لوگ بے اختیار اس کے گھر کی طرف دوڑ پڑے پہلے سے وہ ایسی ہی بد کاریوں کے خوگر تھے لوطؑ نے ان سے کہا ``بھائیو، یہ میری بیٹیاں موجود ہیں، یہ تمہارے لیے پاکیزہ تر ہیں کچھ خدا کا خوف کرو اور میرے مہمانوں کے معاملے میں مجھے ذلیل نہ کرو کیا تم میں کوئی بھلا آدمی نہیں؟"\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdlii{انہوں نے جواب دیا ``تجھے تو معلوم ہی ہے کہ تیری بیٹیوں میں ہمارا کوئی حصہ نہیں ہے اور تو یہ بھی جانتا ہے کہ ہم چاہتے کیا ہیں"\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdliii{لوطؑ نے کہا ``کاش میرے پاس اتنی طاقت ہوتی کہ تمہیں سیدھا کر دیتا، یا کوئی مضبوط سہارا ہی ہوتا کہ اس کی پناہ لیتا"\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdliv{تب فرشتوں نے اس سے کہا کہ ``اے لوطؑ، ہم تیرے رب کے بھیجے ہوئے فرشتے ہیں، یہ لوگ تیرا کچھ نہ بگاڑ سکیں گے بس تو کچھ رات رہے اپنے اہل و عیال کو لے کر نکل جا اور دیکھو، تم میں سے کوئی شخص پیچھے پلٹ کر نہ دیکھے مگر تیر ی بیوی (ساتھ نہیں جائے گی) کیونکہ اس پر بھی وہی کچھ گزرنے والا ہے جو اِن لوگوں پر گزرنا ہے ان کی تباہی کے لیے صبح کا وقت مقرر ہے صبح ہوتے اب دیر ہی کتنی ہے!"\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdlv{پھر جب ہمارے فیصلے کا وقت آ پہنچا تو ہم نے اس بستی کو تل پٹ کر دیا اور اس پر پکی ہوئی مٹی کے پتھر تابڑ توڑ برسائے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdlvi{جن میں سے ہر پتھر تیرے رب کے ہاں نشان زدہ تھا اور ظالموں سے یہ سزا کچھ دور نہیں ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdlvii{اور مدین والوں کی طرف ہم نے ان کے بھائی شعیبؑ کو بھیجا اُس نے کہا ``اے میری قوم کے لوگو، اللہ کی بندگی کرو، اس کے سوا تمہارا کوئی خدا نہیں ہے اور ناپ تول میں کمی نہ کیا کرو آج میں تم کو اچھے حال میں دیکھ رہا ہوں، مگر مجھے ڈر ہے کہ کل تم پر ایسا دن آئے گا جس کا عذاب سب کو گھیر لے گا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdlviii{اور اے برادران قوم، ٹھیک ٹھیک انصاف کے ساتھ پورا ناپو اور تولو اور لوگوں کو ان کی چیزوں میں گھاٹا نہ دیا کرو اور زمین میں فساد نہ پھیلاتے پھرو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdlix{اللہ کی دی ہوئی بچت تمہارے لیے بہتر ہے اگر تم مومن ہو اور بہر حال میں تمہارے اوپر کوئی نگران کار نہیں ہوں"\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdlx{انہوں نے جواب دیا ``اے شعیبؑ، کیا تیری نماز تجھے یہ سکھاتی ہے کہ ہم ان سارے معبودوں کو چھوڑ دیں جن کی پر ستش ہمارے باپ دادا کرتے تھے؟ یا یہ کہ ہم کو اپنے مال میں اپنے منشا کے مطابق تصرف کرنے کا اختیار نہ ہو؟ بس تو ہی تو ایک عالی ظرف اور راستباز آدمی رہ گیا ہے!"\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdlxi{شعیبؑ نے کہا ``بھائیو، تم خود ہی سوچو کہ اگر میں اپنے رب کی طرف سے ایک کھلی شہادت پر تھا اور پھر اس نے اپنے ہاں سے مجھ کو اچھا رزق بھی عطا کیا (تو اس کے بعد میں تمہاری گمراہیوں اور حرام خوریوں میں تمہارا شریک حال کیسے ہوسکتا ہوں؟) اور میں ہرگز یہ نہیں چاہتا کہ جن باتوں سے میں تم کو روکتا ہوں ان کا خود ارتکاب کروں میں تو اصلاح کرنا چاہتا ہوں جہاں تک بھی میرا بس چلے اور یہ جو کچھ میں کرنا چاہتا ہوں اس کا سارا انحصار اللہ کی توفیق پر ہے، اُسی پر میں نے بھروسہ کیا اور ہر معاملہ میں اسی کی طرف میں رجوع کرتا ہوں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdlxii{اور اے برادران قوم، میرے خلاف تمہاری ہٹ دھرمی کہیں یہ نوبت نہ پہنچا دے کہ آخر کار تم پر بھی وہی عذاب آ کر رہے جو نوحؑ یا ہودؑ یا صالحؑ کی قوم پر آیا تھا اور لوطؑ کی قوم تو تم سے کچھ زیادہ دور بھی نہیں ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdlxiii{دیکھو! اپنے رب سے معافی مانگو اور اس کی طرف پلٹ آؤ، بے شک میرا رب رحیم ہے اور اپنی مخلوق سے محبت رکھتا ہے"\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdlxiv{انہوں نے جواب دیا ``اے شعیبؑ، تیری بہت سی باتیں تو ہماری سمجھ ہی میں نہیں آتیں اور ہم دیکھتے ہیں کہ تو ہمارے درمیان ایک بے زور آدمی ہے، تیری برادری نہ ہوتی تو ہم کبھی کا تجھے سنگسار کر چکے ہوتے، تیرا بل بوتا تو اتنا نہیں ہے کہ ہم پر بھاری ہو"\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdlxv{شعیبؑ نے کہا ``بھائیو، کیا میری برادری تم پر اللہ سے زیادہ بھاری ہے کہ تم نے (برادری کا تو خوف کیا اور) اللہ کو بالکل پس پشت ڈال دیا؟ جان رکھو کہ جو کچھ تم کر رہے ہو وہ اللہ کی گرفت سے باہر نہیں ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdlxvi{اے میری قوم کے لوگو، تم اپنے طریقے پر کام کیے جاؤ اور میں اپنے طریقے پر کرتا رہوں گا، جلدی ہی تمہیں معلوم ہو جائے گا کہ کس پر ذلت کا عذاب آتا ہے اور کون جھوٹا ہے تم بھی انتظار کرو اور میں بھی تمہارے ساتھ چشم براہ ہوں"\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdlxvii{آخر کار جب ہمارے فیصلے کا وقت آ گیا تو ہم نے اپنی رحمت سے شعیبؑ اور اس کے ساتھی مومنوں کو بچا لیا اور جن لوگوں نے ظلم کیا تھا ان کو ایک سخت دھماکے نے ایسا پکڑا کہ وہ اپنی بستیوں میں بے حس و حرکت پڑے کے پڑے رہ گئے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdlxviii{گویا وہ کبھی وہاں رہے بسے ہی نہ تھے سنو! مدین والے بھی دور پھینک دیے گئے جس طرح ثمود پھینکے گئے تھے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdlxix{اور موسیٰؑ کو ہم نے اپنی نشانیوں اور کھلی کھلی سند ماموریت کے ساتھ فرعون اور اس کے اعیان سلطنت کی طرف بھیجا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdlxx{مگر انہوں نے فرعون کے حکم کی پیروی کی حالانکہ فرعون کا حکم راستی پر نہ تھا\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdlxxi{قیامت کے روز وہ اپنی قوم کے آگے آگے ہوگا اور اپنی پیشوائی میں انہیں دوزخ کی طرف لے جائے گا کیسی بدتر جائے وُرُود ہے یہ جس پر کوئی پہنچے!\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdlxxii{اور ان لوگوں پر دنیا میں بھی لعنت پڑی اور قیامت کے روز بھی پڑے گی کیسا برا صلہ ہے یہ جو کسی کو ملے!\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdlxxiii{یہ چند بستیوں کی سرگزشت ہے جو ہم تمہیں سنا رہے ہیں ان میں سے بعض اب بھی کھڑی ہیں اور بعض کی فصل کٹ چکی ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdlxxiv{ہم نے اُن پر ظلم نہیں کیا، انہوں نے آپ ہی اپنے اوپر ستم ڈھایا اور جب اللہ کا حکم آ گیا تو ان کے وہ معبود جنہیں وہ اللہ کو چھوڑ کر پکارا کرتے تھے ان کے کچھ کام نہ آ سکے اور انہوں نے ہلاکت و بربادی کے سوا انہیں کچھ فائدہ نہ دیا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdlxxv{اور تیرا رب جب کسی ظالم بستی کو پکڑتا ہے تو پھر اس کی پکڑ ایسی ہی ہوا کرتی ہے، فی الواقع اس کی پکڑ بڑی سخت اور درد ناک ہوتی ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdlxxvi{حقیقت یہ ہے کہ اس میں ایک نشانی ہے ہر اُس شخص کے لیے جو عذاب آخرت کا خوف کرے وہ ایک دن ہوگا جس میں سب لوگ جمع ہوں گے اور پھر جو کچھ بھی اُس روز ہوگا سب کی آنکھوں کے سامنے ہوگا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdlxxvii{ہم اس کے لانے میں کچھ بہت زیادہ تاخیر نہیں کر رہے ہیں، بس ایک گنی چنی مدت اس کے لیے مقرر ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdlxxviii{جب وہ آئے گا تو کسی کو بات کرنے کی مجال نہ ہوگی، الا یہ کہ خدا کی اجازت سے کچھ عرض کرے پھر کچھ لوگ اس روز بد بخت ہوں گے اور کچھ نیک بخت\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdlxxix{جو بد بخت ہوں گے وہ دوزخ میں جائیں گے (جہاں گرمی اور پیاس کی شدت سے) وہ ہانپیں گے اور پھنکارے ماریں گے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdlxxx{اور اسی حالت میں وہ ہمیشہ رہیں گے جب تک کہ زمین و آسمان قائم ہیں، الا یہ کہ تیرا رب کچھ اور چاہے بے شک تیرا رب پورا اختیار رکھتا ہے کہ جو چاہے کرے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdlxxxi{رہے وہ لوگ جو نیک بخت نکلیں گے، تو وہ جنت میں جائیں گے اور وہاں ہمیشہ رہیں گے جب تک زمین و آسمان قائم ہیں، الا یہ کہ تیرا رب کچھ اور چاہے ایسی بخشش ان کو ملے گی جس کا سلسلہ کبھی منقطع نہ ہوگا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdlxxxii{پس اے نبیؐ، تو ان معبودوں کی طرف سے کسی شک میں نہ رہ جن کی یہ لوگ عبادت کر رہے ہیں یہ تو (بس لکیر کے فقیر بنے ہوئے) اُسی طرح پوجا پاٹ کیے جا رہے ہیں جس طرح پہلے ان کے باپ دادا کرتے تھے، اور ہم اِن کا حصہ اِنہیں بھرپور دیں گے بغیر اس کے کہ اس میں کچھ کاٹ کسر ہو\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiii{ہم اس سے پہلے موسیٰؑ کو بھی کتاب دے چکے ہیں اور اس کے بارے میں بھی اختلاف کیا گیا تھا (جس طرح آج اِس کتاب کے بارے میں کیا جا رہا ہے جو تمہیں دی گئی ہے) اگر تیرے رب کی طرف سے ایک بات پہلے ہی طے نہ کر دی گئی ہوتی تو اِن اختلاف کرنے والوں کے درمیان کبھی کا فیصلہ چکا دیا گیا ہوتا یہ واقعہ ہے کہ یہ لوگ اس کی طرف سے شک اور خلجان میں پڑے ہوئے ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiv{اور یہ بھی واقعہ ہے کہ تیرا رب انہیں ان کے اعمال کا پورا پورا بدلہ دے کر رہے گا، یقیناً وہ ان کی سب حرکتوں سے باخبر ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdlxxxv{پس اے محمدؐ، تم، اور تمہارے وہ ساتھی جو (کفر و بغاوت سے ایمان و طاعت کی طرف) پلٹ آئے ہیں، ٹھیک ٹھیک راہ راست پر ثابت قدم رہو جیسا کہ تمہیں حکم دیا گیا ہے اور بندگی کی حد سے تجاوز نہ کرو جو کچھ تم کر رہے ہو اس پر تمہارا رب نگاہ رکھتا ہے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvi{اِن ظالموں کی طرف ذرا نہ جھکنا ورنہ جہنم کی لپیٹ میں آ جاؤ گے اور تمہیں کوئی ایسا ولی و سرپرست نہ ملے گا جو خدا سے تمہیں بچا سکے اور کہیں سے تم کو مدد نہ پہنچے گی\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvii{اور دیکھو، نماز قائم کرو دن کے دونوں سروں پر اور کچھ رات گزرنے پر درحقیقت نیکیاں برائیوں کو دور کر دیتی ہیں، یہ ایک یاد دہانی ہے ان لوگوں کے لیے جو خدا کو یاد رکھنے والے ہیں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mdlxxxviii{اور صبر کر، اللہ نیکی کرنے والوں کا اجر کبھی ضائع نہیں کرتا\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mdlxxxix{پھر کیوں نہ اُن قوموں میں جو تم سے پہلے گزر چکی ہیں ایسے اہل خیر موجود رہے جو لوگوں کو زمین میں فساد برپا کرنے سے روکتے؟ ایسے لوگ نکلے بھی تو بہت کم، جن کو ہم نے ان قوموں میں سے بچا لیا، ورنہ ظالم لوگ تو انہی مزوں کے پیچھے پڑے رہے جن کے سامان انہیں فراوانی کے ساتھ دیے گئے تھے اور وہ مجرم بن کر رہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mdxc{تیرا رب ایسا نہیں ہے کہ بستیوں کو ناحق تباہ کر دے حالانکہ ان کے باشندے اصلاح کرنے والے ہوں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mdxci{بے شک تیرا رب اگر چاہتا تو تمام انسانوں کو ایک گروہ بنا سکتا تھا، مگر اب تو وہ مختلف طریقوں ہی پر چلتے رہیں گے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mdxcii{اور بے راہ رویوں سے صرف وہ لوگ بچیں گے جن پر تیرے رب کی رحمت ہے اِسی (آزادی انتخاب و اختیار) کے لیے ہی تو اس نے انہیں پیدا کیا تھا اور تیرے رب کی وہ بات پوری ہو گئی جو اس نے کہی تھی کہ میں جہنم کو جن اور انسان، سب سے بھر دوں گا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mdxciii{اور اے محمدؐ، یہ پیغمبروں کے قصے جو ہم تمہیں سناتے ہیں، وہ چیزیں ہیں جن کے ذریعے سے ہم تمہارے دل کو مضبوط کرتے ہیں ان کے اندر تم کو حقیقت کا علم ملا اور ایمان لانے والوں کو نصیحت اور بیداری نصیب ہوئی\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mdxciv{رہے وہ لوگ جو ایمان نہیں لاتے، تو ان سے کہہ دو کہ تم اپنے طریقے پر کام کرتے رہو اور ہم اپنے طریقے پر کیے جاتے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mdxcv{انجام کار کا تم بھی انتظار کرو اور ہم بھی منتظر ہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mdxcvi{آسمانوں اور زمین میں جو کچھ چھپا ہوا ہے سب اللہ کے قبضہ قدرت میں ہے اور سارا معاملہ اسی کی طرف رجوع کیا جاتا ہے پس اے نبیؐ، تو اس کی بندگی کر اور اسی پر بھروسا رکھ، جو کچھ تم لوگ کر رہے ہو تیرا رب اس سے بے خبر نہیں ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mdxcvii{\basmalahur ا، ل، ر یہ اُس کتاب کی آیات ہیں جو اپنا مدعا صاف صاف بیان کرتی ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdxcviii{ہم نے اسے نازل کیا ہے قرآن بنا کر عربی زبان میں تاکہ تم (اہل عرب) اس کو اچھی طرح سمجھ سکو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdxcix{اے محمدؐ، ہم اس قرآن کو تمہاری طرف وحی کر کے بہترین پیرایہ میں واقعات اور حقائق تم سے بیان کرتے ہیں، ورنہ اس سے پہلے تو (ان چیزو ں سے) تم بالکل ہی بے خبر تھے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdc{یہ اُس وقت کا ذکر ہے جب یوسفؑ نے اپنے باپ سے کہا ``ابا جان، میں نے خواب دیکھا ہے کہ گیارہ ستارے ہیں اور سورج اور چاند ہیں اور وہ مجھے سجدہ کر رہے ہیں"\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdci{جواب میں اس کے باپ نے کہا، ``بیٹا، اپنا یہ خواب اپنے بھائیوں کو نہ سنانا ورنہ وہ تیرے درپے آزار ہو جائیں گے، حقیقت یہ ہے کہ شیطان آدمی کا کھلا دشمن ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcii{اور ایسا ہی ہوگا (جیسا تو نے خواب میں دیکھا ہے کہ) تیرا رب تجھے (اپنے کام کے لیے) منتخب کرے گا اور تجھے باتوں کی تہ تک پہنچنا سکھائے گا اور تیرے اوپر اور آل یعقوبؑ پر اپنی نعمت اسی طرح پوری کرے گا جس طرح اس سے پہلے وہ تیرے بزرگوں، ابراہیمؑ اور اسحاقؑ پر کر چکا ہے، یقیناً تیرا رب علیم اور حکیم ہے"\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdciii{حقیقت یہ ہے کہ یوسفؑ اور اس کے بھائیوں کے قصہ میں اِن پوچھنے والوں کے لیے بڑی نشانیاں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdciv{یہ قصہ یوں شروع ہوتا ہے کہ اس کے بھائیوں نے آپس میں کہا ``یہ یوسفؑ اور اس کا بھائی، دونوں ہمارے والد کو ہم سب سے زیادہ محبوب ہیں حالانکہ ہم ایک پورا جتھا ہیں سچی بات یہ ہے کہ ہمارے ابا جان با لکل ہی بہک گئے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcv{چلو یوسفؑ کو قتل کر دو یا اسے کہیں پھینک دو تاکہ تمہارے والد کی توجہ صرف تمہاری ہی طرف ہو جائے یہ کام کر لینے کے بعد پھر نیک بن رہنا"\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcvi{اس پر ان میں سے ایک بولا ``یوسفؑ کو قتل نہ کرو، اگر کچھ کرنا ہی ہے تو اسے کسی اندھے کنویں میں ڈال دو کوئی آتا جاتا قافلہ اسے نکال لے جائے گا"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcvii{اس قرارداد پر انہوں نے جا کر اپنے باپ سے کہا ``ابا جان، کیا بات ہے کہ آپ یوسفؑ کے معاملہ میں ہم پر بھروسہ نہیں کرتے حالانکہ ہم اس کے سچے خیر خواہ ہیں؟\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcviii{کل اسے ہمارے ساتھ بھیج د یجیے، کچھ چر چگ لے گا اور کھیل کود سے بھی دل بہلائے گا ہم اس کی حفاظت کو موجود ہیں"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcix{باپ نے کہا ``تمہارا اسے لے جانا مجھے شاق گزرتا ہے اور مجھ کو اندیشہ ہے کہ کہیں اسے بھیڑیا نہ پھاڑ کھا ئے جبکہ تم اس سے غافل ہو"\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcx{انہوں نے جواب دیا ``اگر ہمارے ہوتے اسے بھڑ یے نے کھا لیا، جبکہ ہم ایک جتھا ہیں، تب تو ہم بڑے ہی نکمے ہوں گے"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcxi{اِس طرح اصرار کر کے جب وہ اُسے لے گئے اور انہوں نے طے کر لیا کہ اسے ایک اندھے کنویں میں چھوڑ دیں، تو ہم نے یوسفؑ کو وحی کی کہ ``ایک وقت آئے گا جب تو ان لوگوں کو ان کی یہ حرکت جتائے گا، یہ اپنے فعل کے نتائج سے بے خبر ہیں"\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcxii{شام کو وہ روتے پیٹتے اپنے باپ کے پاس آئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcxiii{اور کہا ``ابا جان، ہم دوڑ کا مقابلہ کرنے میں لگ گئے تھے اور یوسفؑ کو ہم نے اپنے سامان کے پاس چھوڑ دیا تھا کہ اتنے میں بھیڑیا آ کر اُسے کھا گیا آپ ہماری بات کا یقین نہ کریں گے چاہے ہم سچے ہی ہوں"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcxiv{اور وہ یوسفؑ کے قمیص پر جھوٹ موٹ کا خون لگا کر آئے تھے یہ سن کر ان کے باپ نے کہا ``بلکہ تمہارے نفس نے تمہارے لیے ایک بڑے کام کو آسان بنا دیا اچھا، صبر کروں گا اور بخوبی کروں گا، جو بات تم بنا رہے ہو اس پر اللہ ہی سے مدد مانگی جا سکتی ہے"\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcxv{ادھر ایک قافلہ آیا اور اُس نے اپنے سقے کو پانی لانے کے لیے بھیجا سقے نے جو کنویں میں ڈول ڈالا تو (یوسفؑ کو دیکھ کر) پکار اٹھا ``مبارک ہو، یہاں تو ایک لڑکا ہے" ان لوگوں نے اس کو مال تجارت سمجھ کر چھپا لیا، حالانکہ جو کچھ وہ کر رہے تھے خدا اس سے باخبر تھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcxvi{آخر کار انہوں نے اس کو تھوڑی سی قیمت پر چند درہموں کے عوض بیچ ڈالا اور وہ اس کی قیمت کے معاملہ میں کچھ زیادہ کے امیدوار نہ تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcxvii{مصر کے جس شخص نے اسے خریدا اس نے اپنی بیوی سے کہا ``اِس کو اچھی طرح رکھنا، بعید نہیں کہ یہ ہمارے لیے مفید ثابت ہو یا ہم اسے بیٹا بنا لیں" اس طرح ہم نے یوسفؑ کے لیے اُس سرزمین میں قدم جمانے کی صورت نکالی اور اسے معاملہ فہمی کی تعلیم دینے کا انتظام کیا اللہ اپنا کام کر کے رہتا ہے، مگر اکثر لوگ جانتے نہیں ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcxviii{اور جب وہ اپنی پوری جوانی کو پہنچا تو ہم نے اسے قوت فیصلہ اور علم عطا کیا، اِس طرح ہم نیک لوگوں کو جزا دیتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcxix{جس عورت کے گھر میں وہ تھا وہ اُس پر ڈورے ڈالنے لگی اور ایک روز دروازے بند کر کے بولی ``آ جا" یوسفؑ نے کہا ``خدا کی پناہ، میرے رب نے تو مجھے اچھی منزلت بخشی (اور میں یہ کام کروں!) ایسے ظالم کبھی فلاح نہیں پایا کرتے"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcxx{وہ اُس کی طرف بڑھی اور یوسفؑ بھی اس کی طرف بڑھتا اگر اپنے رب کی برہان نہ دیکھ لیتا ایسا ہوا، تاکہ ہم اس سے بدی اور بے حیائی کو دور کر دیں، در حقیقت وہ ہمارے چنے ہوئے بندوں میں سے تھا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcxxi{آخر کار یوسفؑ اور وہ آگے پیچھے دروازے کی طرف بھاگے اور اس نے پیچھے سے یوسفؑ کا قمیص (کھینچ کر) پھاڑ دیا دروازے پر دونوں نے اس کے شوہر کو موجود پایا اسے دیکھتے ہی عورت کہنے لگی، ``کیا سزا ہے اس شخص کی جو تیری گھر والی پر نیت خراب کرے؟ اِس کے سوا اور کیا سزا ہوسکتی ہے کہ وہ قید کیا جائے یا اسے سخت عذاب دیا جائے"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcxxii{یوسفؑ نے کہا ``یہی مجھے پھانسنے کی کوشش کر رہی تھی" اس عورت کے اپنے کنبہ والوں میں سے ایک شخص نے (قرینے کی) شہادت پیش کی کہ ``اگر یوسفؑ کا قمیص آگے سے پھٹا ہو تو عورت سچی ہے اور یہ جھوٹا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcxxiii{اور اگر اس کا قمیص پیچھے سے پھٹا ہو تو عورت جھوٹی ہے اور یہ سچا"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcxxiv{جب شوہر نے دیکھا کہ یوسفؑ کا قمیص پیچھے سے پھٹا ہے تو اس نے کہا ``یہ تم عورتوں کی چالاکیاں ہیں، واقعی بڑ ے غضب کی ہوتی ہیں تمہاری چالیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcxxv{یوسفؑ، اس معاملے سے درگزر کر اور اے عورت، تو اپنے قصور کی معافی مانگ، تو ہی اصل میں خطا کار تھی"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcxxvi{شہر کی عورتیں آپس میں چرچا کرنے لگیں کہ ``عزیز کی بیوی اپنے نوجوان غلام کے پیچھے پڑی ہوئی ہے، محبت نے اس کو بے قابو کر رکھا ہے، ہمارے نزدیک تو وہ صریح غلطی کر رہی ہے"\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcxxvii{اس نے جو اُن کی یہ مکارانہ باتیں سنیں تو اُن کو بلاوا بھیج دیا اور ان کے لیے تکیہ دار مجلس آراستہ کی اور ضیافت میں ہر ایک کے آگے ایک چھری رکھ دی (پھر عین اس وقت جبکہ وہ پھل کاٹ کاٹ کر کھا رہی تھیں) اس نے یوسفؑ کو اشارہ کیا کہ ان کے سامنے نکل آ جب ان عورتوں کی نگاہ اس پر پڑی تو وہ دنگ رہ گئیں اور اپنے ہاتھ کاٹ بیٹھیں اور بے ساختہ پکا ر اٹھیں ``حاشاللّٰہ، یہ شخص انسان نہیں ہے، یہ تو کوئی بزرگ فرشتہ ہے"\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcxxviii{عزیز کی بیوی نے کہا ``دیکھ لیا! یہ ہے یہ وہ شخص جس کے معاملہ میں تم مجھ پر باتیں بناتی تھیں بے شک میں نے اِسے رجھانے کی کوشش کی تھی مگر یہ بچ نکلا اگر یہ میرا کہنا نہ مانے گا تو قید کیا جائے گا اور بہت ذلیل و خوار ہوگا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcxxix{یوسفؑ نے کہا ``اے میرے رب، قید مجھے منظور ہے بہ نسبت اس کے کہ میں وہ کام کروں جو یہ لوگ مجھ سے چاہتے ہیں اور اگر تو نے ان کی چالوں کو مجھ سے دفع نہ کیا تو میں ان کے دام میں پھنس جاؤں گا اور جاہلوں میں شامل ہو رہوں گا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcxxx{اس کے رب نے اس کی دعا قبول کی اور اُن عورتوں کی چالیں اس سے دفع کر دیں، بے شک وہی ہے جو سب کی سنتا اور سب کچھ جانتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcxxxi{پھر ان لوگوں کو یہ سوجھی کہ ایک مدت کے لیے اسے قید کر دیں حالانکہ وہ (اس کی پاکدامنی اور خود اپنی عورتوں کے برے اطوار کی) صریح نشانیاں دیکھ چکے تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcxxxii{قید خانہ میں دو غلام اور بھی اس کے ساتھ داخل ہوئے ایک روز اُن میں سے ایک نے اُس سے کہا ``میں نے خواب میں دیکھا ہے کہ میں شراب کشید کر رہا ہوں" دوسرے نے کہا ``میں نے دیکھا کہ میرے سر پر روٹیاں رکھی ہیں اور پرندے ان کو کھا رہے ہیں" دونوں نے کہا ``ہمیں اس کی تعبیر بتائیے، ہم دیکھتے ہیں کہ آپ ایک نیک آدمی ہیں"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiii{یوسفؑ نے کہا: ``یہاں جو کھانا تمہیں ملا کرتا ہے اس کے آنے سے پہلے میں تمہیں اِن خوابوں کی تعبیر بتا دوں گا یہ علم اُن علوم میں سے ہے جو میرے رب نے مجھے عطا کیے ہیں واقعہ یہ ہے کہ میں نے اُن لوگوں کا طریقہ چھوڑ کر جو اللہ پر ایمان نہیں لاتے اور آخرت کا انکار کرتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiv{اپنے بزرگوں، ابراہیمؑ، اسحاقؑ اور یعقوبؑ کا طریقہ اختیار کیا ہے ہمارا یہ کام نہیں ہے کہ اللہ کے ساتھ کسی کو شریک ٹھیرائیں در حقیقت یہ اللہ کا فضل ہے ہم پر اور تمام انسانوں پر (کہ اس نے اپنے سوا کسی کا بندہ ہمیں نہیں بنایا) مگر اکثر لوگ شکر نہیں کرتے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcxxxv{اے زنداں کے ساتھیو، تم خود ہی سوچو کہ بہت سے متفرق رب بہتر ہیں یا وہ ایک اللہ جو سب غالب ہے؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvi{اُس کو چھوڑ کر تم جن کی بندگی کر رہے ہو وہ اس کے سوا کچھ نہیں ہیں کہ بس چند نام ہیں جو تم نے اور تمہارے آباؤ اجداد نے رکھ لیے ہیں، اللہ نے ان کے لیے کوئی سند نازل نہیں کی فرماں روائی کا اقتدار اللہ کے سوا کسی کے لیے نہیں ہے اس کا حکم ہے کہ خود اس کے سوا تم کسی کی بندگی نہ کرو یہی ٹھیٹھ سیدھا طریق زندگی ہے، مگر اکثر لوگ جانتے نہیں ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvii{اے زنداں کے ساتھیو، تمہارے خواب کی تعبیر یہ ہے کہ تم میں سے ایک تو اپنے رب (شاہ مصر) کو شراب پلائے گا، رہا دوسرا تو اسے سولی پر چڑھایا جائے گا اور پرندے اس کا سر نوچ نوچ کر کھائیں گے فیصلہ ہو گیا اُس بات کا جو تم پوچھ رہے تھے"\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcxxxviii{پھر اُن میں سے جس کے متعلق خیال تھا کہ وہ رہا ہو جائے گا اس سے یوسفؑ نے کہا کہ ``اپنے رب (شاہ مصر) سے میرا ذکر کرنا" مگر شیطان نے اسے ایسا غفلت میں ڈالا کہ وہ اپنے رب (شاہ مصر) سے اس کا ذکر کرنا بھول گیا اور یوسفؑ کئی سال قید خانے میں پڑا رہا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcxxxix{ایک روز بادشاہ نے کہا ``میں نے خواب میں دیکھا ہے کہ سات موٹی گائیں ہیں جن کو سات دبلی گائیں کھا رہی ہیں، اور اناج کی سات بالیں ہری ہیں اور دوسری سات سوکھی اے اہل دربار، مجھے اس خواب کی تعبیر بتاؤ اگر تم خوابوں کا مطلب سمجھتے ہو"\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcxl{لوگوں نے کہا ``یہ تو پریشان خوابوں کی باتیں ہیں اور ہم اس طرح کے خوابوں کا مطلب نہیں جانتے"\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcxli{اُن دو قیدیوں میں سے جو شخص بچ گیا تھا اور اُسے ایک مدت دراز کے بعد اب بات یاد آئی، اُس نے کہا ``میں آپ حضرات کو اس کی تاویل بتاتا ہوں، مجھے ذرا (قید خانے میں یوسفؑ کے پاس) بھیج دیجیے"\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcxlii{اس نے جا کر کہا ``یوسفؑ، اے سراپا راستی، مجھے اس خواب کا مطلب بتا کہ سات موٹی گائیں جن کو سات دبلی گائیں کھا رہی ہیں اور سات بالیں ہری ہیں اور سات سوکھی شاید کہ میں اُن لوگوں کے پاس جاؤں اور شاید کہ وہ جان لیں"\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcxliii{یوسفؑ نے کہا ``سات بر س تک لگاتار تم لوگ کھیتی باڑی کرتے رہو گے اس دوران میں جو فصلیں تم کاٹو اُن میں سے بس تھوڑا ساحصہ، جو تمہاری خوراک کے کام آئے، نکالو اور باقی کو اس کی بالوں ہی میں رہنے دو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcxliv{پھر سات برس بہت سخت آئیں گے اُس زمانے میں وہ سب غلہ کھا لیا جائے گا جو تم اُس وقت کے لیے جمع کرو گے اگر کچھ بچے گا تو بس وہی جو تم نے محفوظ کر رکھا ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcxlv{اس کے بعد پھر ایک سال ایسا آئے گا جس میں باران رحمت سے لوگوں کی فریاد رسی کی جائے گی اور وہ رس نچوڑیں گے"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdcxlvi{بادشاہ نے کہا اسے میرے پاس لاؤ مگر جب شاہی فرستادہ یوسفؑ کے پاس پہنچا تو اس نے کہا ``اپنے رب کے پاس واپس جا اور اس سے پوچھ کہ اُن عورتوں کا کیا معاملہ ہے جنہوں نے اپنے ہاتھ کاٹ لیے تھے؟ میرا رب تو ان کی مکاری سے واقف ہی ہے"\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcxlvii{اس پر بادشاہ نے ان عورتوں سے دریافت کیا ``تمہارا کیا تجربہ ہے اُس وقت کا جب تم نے یوسفؑ کو رجھانے کی کوشش کی تھی؟" سب نے یک زبان ہو کر کہا ``حاشاللہ، ہم نے تو اُس میں بدی کا شائبہ تک نہ پایا" عزیز کی بیوی بول اٹھی ``اب حق کھل چکا ہے، وہ میں ہی تھی جس نے اُس کو پھسلانے کی کوشش کی تھی، بے شک وہ بالکل سچا ہے"\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcxlviii{(یوسفؑ نے کہا) ``اِس سے میری غرض یہ تھی کہ (عزیز) یہ جان لے کہ میں نے درپردہ اس کی خیانت نہیں کی تھی، اور یہ کہ جو خیانت کرتے ہیں ان کی چالوں کو اللہ کامیابی کی راہ پر نہیں لگاتا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdcxlix{میں کچھ اپنے نفس کی براءَت نہیں کر رہا ہوں، نفس تو بدی پر اکساتا ہی ہے الا یہ کہ کسی پر میرے رب کی رحمت ہو، بے شک میرا رب بڑا غفور و رحیم ہے"\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdcl{بادشاہ نے کہا ``اُنہیں میرے پاس لاؤ تاکہ میں ان کو اپنے لیے مخصوص کر لوں" جب یوسفؑ نے اس سے گفتگو کی تو اس نے کہا ``اب آپ ہمارے ہاں قدر و منزلت رکھتے ہیں اور آپ کی امانت پر پورا بھروسا ہے"\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdcli{یوسفؑ نے کہا، ``ملک کے خزانے میرے سپرد کیجیے، میں حفاظت کرنے والا بھی ہوں اور علم بھی رکھتا ہوں"\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdclii{اِس طرح ہم نے اُس سرزمین میں یوسفؑ کے لیے اقتدار کی راہ ہموار کی وہ مختار تھا کہ اس میں جہاں چاہے اپنی جگہ بنائے ہم اپنی رحمت سے جس کو چاہتے ہیں نوازتے ہیں، نیک لوگوں کا اجر ہمارے ہاں مارا نہیں جاتا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdcliii{اور آخرت کا اجر اُن لوگو ں کے لیے زیادہ بہتر ہے جو ایمان لے آئے اور خدا ترسی کے ساتھ کام کرتے رہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdcliv{یوسفؑ کے بھائی مصر آئے اور اس کے ہاں حاضر ہوئے اس نے انہیں پہچان لیا مگر وہ اس سے نا آشنا تھے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdclv{پھر جب اس نے ان کا سامان تیار کروا دیا تو چلتے وقت ان سے کہا، ``اپنے سوتیلے بھائی کو میرے پاس لانا دیکھتے نہیں ہو کہ میں کس طرح پیمانہ بھر کر دیتا ہوں اور کیسا اچھا مہمان نواز ہوں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdclvi{اگر تم اسے نہ لاؤ گے تو میرے پاس تمہارے لیے کوئی غلہ نہیں ہے بلکہ تم میرے قریب بھی نہ پھٹکنا"\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdclvii{انہوں نے کہا، ``ہم کوشش کریں گے کہ والد صاحب اسے بھیجنے پر ر اضی ہو جائیں، اور ہم ایسا ضرور کریں گے"\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdclviii{یوسفؑ نے اپنے غلاموں کو اشارہ کیا کہ ``اِن لوگوں نے غلے کے عوض جو مال دیا ہے وہ چپکے سے ان کے سامان ہی میں رکھ دو" یہ یوسفؑ نے اِس امید پر کیا کہ گھر پہنچ کر وہ اپنا واپس پایا ہوا مال پہچان جائیں گے (یا اِس فیاضی پر احسان مند ہوں گے) اور عجب نہیں کہ پھر پلٹیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdclix{جب وہ اپنے باپ کے پاس گئے تو کہا ``ابا جان، آئندہ ہم کو غلہ دینے سے انکار کر دیا گیا ہے، لہٰذا آپ ہمارے بھائی کو ہمارے ساتھ بھیج دیجیے تاکہ ہم غلہ لے کر آئیں اور اس کی حفاظت کے ہم ذمہ دار ہیں"\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdclx{باپ نے جواب دیا ``کیا میں اُس کے معاملہ میں تم پر ویسا ہی بھروسہ کروں جیسا اِس سے پہلے اُس کے بھائی کے معاملہ میں کر چکا ہوں؟ اللہ ہی بہتر محافظ ہے اور وہ سب سے بڑھ کر رحم فرمانے والا ہے"\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdclxi{پھر جب انہوں نے اپنا سامان کھولا تو دیکھا کہ ان کا مال بھی انہیں واپس کر دیا گیا ہے یہ دیکھ کر وہ پکار اٹھے ``ابا جان، اور ہمیں کیا چاہیے، دیکھیے یہ ہمارا مال بھی ہمیں واپس دے دیا گیا ہے بس اب ہم جائیں گے اور اپنے اہل و عیال کے لیے رسد لے آئیں گے، اپنے بھائی کی حفاظت بھی کریں گے اور ایک بارشتر اور زیادہ بھی لے آئیں گے، اتنے غلہ کا اضافہ آسانی کے ساتھ ہو جائے گا"\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdclxii{ان کے باپ نے کہا ``میں اس کو ہرگز تمہارے ساتھ نہ بھیجوں گا جب تک کہ تم اللہ کے نام سے مجھ کو پیمان نہ دے دو کہ اِسے میرے پا س ضرور واپس لے کر آؤ گے الا یہ کہ کہیں تم گھیر ہی لیے جاؤ" جب انہوں نے اس کو اپنے اپنے پیمان دے دیے تو اس نے کہا ``دیکھو، ہمارے اس قول پر اللہ نگہبان ہے"\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdclxiii{پھر اس نے کہا ``میرے بچو، مصر کے دارالسطنت میں ایک دروازے سے داخل نہ ہونا بلکہ مختلف دروازوں سے جانا مگر میں اللہ کی مشیت سے تم کو نہیں بچا سکتا، حکم اُس کے سوا کسی کا بھی نہیں چلتا، اسی پر میں نے بھروسہ کیا، اور جس کو بھی بھروسہ کرنا ہو اسی پر کرے"\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdclxiv{اور واقعہ بھی یہی ہوا کہ جب وہ اپنے باپ کی ہدایت کے مطابق شہر میں (متفرق دروازوں سے) داخل ہوئے تو اس کی یہ احتیاطی تدبیر اللہ کی مشیت کے مقابلے میں کچھ بھی کام نہ آسکی ہاں بس یعقوبؑ کے دل میں جو ایک کھٹک تھی اسے دور کرنے کے لیے اس نے اپنی سی کوشش کر لی بے شک وہ ہماری دی ہوئی تعلیم سے صاحب علم تھا مگر اکثر لوگ معاملہ کی حقیقت کو جانتے نہیں ہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdclxv{یہ لوگ یوسفؑ کے حضور پہنچے تو اس نے اپنے بھائی کو اپنے پاس الگ بلا لیا اور اسے بتا دیا کہ ``میں تیرا وہی بھائی ہوں (جو کھویا گیا تھا) اب تو اُن باتوں کا غم نہ کر جو یہ لوگ کرتے رہے ہیں"\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdclxvi{جب یوسفؑ ان بھائیوں کا سامان لدوانے لگا تو اس نے اپنے بھائی کے سامان میں اپنا پیالہ رکھ دیا پھر ایک پکارنے والے نے پکار کر کہا ``اے قافلے والو، تم لو گ چور ہو"\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdclxvii{انہوں نے پلٹ کر پوچھا ``تمہاری کیا چیز کھوئی گئی؟ ``\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdclxviii{سرکاری ملازموں نے کہا ``بادشاہ کا پیمانہ ہم کو نہیں ملتا" (اور ان کے جمعدار نے کہا) ``جو شخص لا کر دے گا اُس کے لیے ایک بارشتر انعام ہے، اس کا میں ذمہ لیتا ہوں"\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdclxix{ان بھائیوں نے کہا ``خدا کی قسم، تو لوگ خوب جانتے ہو کہ ہم اس ملک میں فساد کرنے نہیں آئے ہیں اور ہم چوریاں کرنے والے لوگ نہیں ہیں"\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdclxx{اُنہوں نے کہا ``اچھا، اگر تمہاری بات جھوٹی نکلی تو چور کی کیا سزا ہے؟"\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdclxxi{اُنہوں نے کہا ``اُس کی سزا؟ جس کے سامان میں سے چیز نکلے وہ آپ ہی اپنی سزا میں رکھ لیا جائے، ہمارے ہاں تو ایسے ظالموں کو سزا دینے کا یہی طریقہ ہے"\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdclxxii{تب یوسفؑ نے اپنے بھائی سے پہلے اُن کی خرجیوں کی تلاشی لینی شروع کی، پھر اپنے بھائی کی خرجی سے گم شدہ چیز برآمد کر لی اِس طرح ہم نے یوسفؑ کی تائید اپنی تدبیر سے کی اُس کا یہ کام نہ تھا کہ بادشاہ کے دین (یعنی مصر کے شاہی قانون) میں اپنے بھائی کو پکڑتا الا یہ کہ اللہ ہی ایسا چاہے ہم جس کے درجے چاہتے ہیں بلند کر دیتے ہیں، اور ایک علم رکھنے والا ایسا ہے جو ہر صاحب علم سے بالا تر ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdclxxiii{ان بھائیوں نے کہا ``یہ چوری کرے تو کچھ تعجب کی بات بھی نہیں، اس سے پہلے اس کا بھائی (یوسفؑ) بھی چوری کر چکا ہے" یوسفؑ ان کی یہ بات سن کر پی گیا، حقیقت ان پر نہ کھولی بس (زیر لب) اتنا کہہ کر رہ گیا کہ ``بڑے ہی برے ہو تم لوگ، (میرے منہ در منہ مجھ پر) جو الزام تم لگا رہے ہو اس کی حقیقت خدا خوب جانتا ہے"\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdclxxiv{انہوں نے کہا ``اے سردار ذی اقتدار (عزیز)، اس کا باپ بہت بوڑھا آدمی ہے، اس کی جگہ آپ ہم میں سے کسی کو رکھ لیجیے، ہم آپ کو بڑا ہی نیک نفس انسان پاتے ہیں"\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdclxxv{یوسفؑ نے کہا ``پناہ بخدا، دوسرے کسی شخص کو ہم کیسے رکھ سکتے ہیں جس کے پاس ہم نے اپنا مال پایا ہے اس کو چھوڑ کر دوسرے کو رکھیں گے تو ہم ظالم ہوں گے"\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdclxxvi{جب وہ یوسفؑ سے مایوس ہو گئے تو ایک گوشے میں جا کر آپس میں مشورہ کرنے لگے ان میں جو سب سے بڑا تھا وہ بولا ``تم جانتے نہیں ہو کہ تمہارے والد تم سے خدا کے نام پر کیا عہد و پیمان لے چکے ہیں اور اس سے پہلے یوسفؑ کے معاملہ میں جو زیادتی تم کر چکے ہو وہ بھی تم کو معلوم ہے اب میں تو یہاں سے ہرگز نہ جاؤں گا جب تک کہ میرے والد مجھے اجازت نہ دیں، یا پھر اللہ ہی میرے حق میں کوئی فیصلہ فرما دے کہ وہ سب سے بہتر فیصلہ کرنے والا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdclxxvii{تم جا کر اپنے والد سے کہو کہ ``ابا جان، آپ کے صاحبزادے نے چوری کی ہے ہم نے اسے چوری کرتے ہوئے نہیں دیکھا، جو کچھ ہمیں معلوم ہوا ہے بس وہی ہم بیان کر رہے ہیں، اور غیب کی نگہبانی تو ہم نہ کر سکتے تھے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdclxxviii{آپ اُس بستی کے لوگوں سے پوچھ لیجیے جہاں ہم تھے اُس قافلے سے دریافت کر لیجیے جس کے ساتھ ہم آئے ہیں ہم اپنے بیان میں بالکل سچے ہیں"\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdclxxix{باپ نے یہ داستان سن کر کہا ``دراصل تمہارے نفس نے تمہارے لیے ایک اور بڑی بات کو سہل بنا دیا اچھا اس پر بھی صبر کروں گا اور بخوبی کروں گا کیا بعید ہے کہ اللہ ان سب کو مجھ سے لا ملا ئے، وہ سب کچھ جانتا ہے اور اس کے سب کام حکمت پر مبنی ہیں"\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdclxxx{پھر وہ ان کی طرف سے منہ پھیر کر بیٹھ گیا اور کہنے لگا کہ ``ہا ئے یوسف!" وہ دل ہی دل میں غم سے گھٹا جا رہا تھا اور اس کی آنکھیں سفید پڑ گئی تھیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdclxxxi{بیٹوں نے کہا ``خدارا! آپ تو بس یوسف ہی کو یاد کیے جاتے ہیں نوبت یہ آ گئی ہے کہ اس کے غم میں اپنے آپ کو گھلا دیں گے یا اپنی جان ہلاک کر ڈالیں گے"\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdclxxxii{اُس نے کہا ``میں اپنی پریشانی اور اپنے غم کی فریاد اللہ کے سوا کسی سے نہیں کرتا، اور اللہ سے جیسا میں واقف ہوں تم نہیں ہو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiii{میرے بچو، جا کر یوسفؑ اور اس کے بھائی کی کچھ ٹوہ لگاؤ، اللہ کی رحمت سے مایوس نہ ہو، اس کی رحمت سے تو بس کافر ہی مایوس ہوا کرتے ہیں"\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiv{جب یہ لوگ مصر جا کر یوسفؑ کی پیشی میں داخل ہوئے تو انہوں نے عرض کیا کہ ``اے سردار با اقتدار، ہم اور ہمارے اہل و عیال سخت مصیبت میں مبتلا ہیں اور ہم کچھ حقیر سی پونجی لے کر آئے ہیں، آپ ہمیں بھر پور غلہ عنایت فرمائیں اور ہم کو خیرات دیں، اللہ خیرات کرنے والوں کو جزا دیتا ہے"\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdclxxxv{(یہ سن کریوسفؑ سے نہ رہا گیا) اُس نے کہا ``تمہیں کچھ یہ بھی معلوم ہے کہ تم نے یوسفؑ اور اُس کے بھائی کے ساتھ کیا کیا تھا جبکہ تم نادان تھے"\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvi{وہ چونک کر بولے ``کیا تم یوسفؑ ہو؟" اُس نے کہا، ``ہاں، میں یوسفؑ ہوں اور یہ میرا بھائی ہے اللہ نے ہم پر احسان فرمایا حقیقت یہ ہے کہ اگر کوئی تقویٰ اور صبر سے کام لے تو اللہ کے ہاں ایسے نیک لوگوں کا اجر مارا نہیں جاتا"\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvii{انہوں نے کہا ``بخدا کہ تم کو اللہ نے ہم پر فضیلت بخشی اور واقعی ہم خطا کار تھے"\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdclxxxviii{اس نے جواب دیا، ``آج تم پر کوئی گرفت نہیں، اللہ تمہیں معاف کرے، وہ سب سے بڑھ کر رحم فرمانے والا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdclxxxix{جاؤ، میرا یہ قمیص لے جاؤ اور میرے والد کے منہ پر ڈال دو، اُن کی بینائی پلٹ آئے گی، اور اپنے سب اہل و عیال کو میرے پاس لے آؤ"\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcxc{جب یہ قافلہ (مصر سے) روانہ ہوا تو ان کے باپ نے (کنعان میں) کہا ``میں یوسفؑ کی خوشبو محسوس کر رہا ہوں، تم لوگ کہیں یہ نہ کہنے لگو کہ میں بڑھاپے میں سٹھیا گیا ہوں"\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcxci{گھر کے لوگ بولے ``خدا کی قسم آپ ابھی تک اپنے اسی پرانے خبط میں پڑے ہوئے ہیں"\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcxcii{پھر جب خو ش خبری لانے والا آیا تو اس نے یوسفؑ کا قمیص یعقوبؑ کے منہ پر ڈال دیا اور یکا یک اس کی بینائی عود کر آئی تب اس نے کہا ``میں تم سے کہتا نہ تھا؟ میں اللہ کی طرف سے وہ کچھ جانتا ہوں جو تم نہیں جانتے"\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcxciii{سب بول اٹھے ``ابا جان، آپ ہمارے گناہوں کی بخشش کے لیے دعا کریں، واقعی ہم خطا کار تھے"\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdcxciv{اُس نے کہا ``میں اپنے رب سے تمہارے لیے معافی کی درخواست کروں گا، وہ بڑا معاف کرنے والا اور رحیم ہے"\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdcxcv{پھر جب یہ لوگ یوسفؑ کے پاس پہنچے تو اُس نے اپنے والدین کو اپنے ساتھ بٹھا لیا اور (اپنے سب کنبے والوں سے) کہا ``چلو، اب شہر میں چلو، اللہ نے چاہا تو امن چین سے رہو گے"\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdcxcvi{(شہر میں داخل ہونے کے بعد) اس نے اپنے والدین کو اٹھا کر اپنے پاس تخت پر بٹھایا اور سب اس کے آگے بے اختیار سجدے میں جھک گئے یوسفؑ نے کہا ``ابا جان، یہ تعبیر ہے میرے اُس خواب کی جو میں نے پہلے دیکھا تھا، میرے رب نے اسے حقیقت بنا دیا اس کا احسان ہے کہ اُس نے مجھے قید خانے سے نکالا، اور آپ لوگوں کو صحرا سے لا کر مجھ سے ملایا حالانکہ شیطان میرے اور میرے بھائیوں کے درمیان فساد ڈال چکا تھا واقعہ یہ ہے کہ میرا رب غیر محسوس تدبیروں سے اپنی مشیت پوری کرتا ہے، بے شک و ہ علیم اور حکیم ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdcxcvii{اے میرے رب، تو نے مجھے حکومت بخشی اور مجھ کو باتوں کی تہ تک پہنچنا سکھایا زمین و آسمان کے بنانے والے، تو ہی دنیا اور آخرت میں میرا سرپرست ہے، میرا خاتمہ اسلام پر کر اور انجام کار مجھے صالحین کے ساتھ ملا"\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdcxcviii{اے محمدؐ، یہ قصہ غیب کی خبروں میں سے ہے جو ہم تم پر وحی کر رہے ہیں ورنہ تم اُس وقت موجود نہ تھے جب یوسفؑ کے بھائیوں نے آپس میں اتفاق کر کے سازش کی تھی\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdcxcix{مگر تم خواہ کتنا ہی چاہو اِن میں سے اکثر لوگ مان کر دینے والے نہیں ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdcc{حالانکہ تم اس خدمت پر ان سے کوئی اجرت بھی نہیں مانگتے ہو یہ تو ایک نصیحت ہے جو دنیا والوں کے لیے عام ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdcci{زمین اور آسمانوں میں کتنی ہی نشانیاں ہیں جن پر سے یہ لوگ گزرتے رہتے ہیں اور ذرا توجہ نہیں کرتے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdccii{ان میں سے اکثر اللہ کو مانتے ہیں مگر اس طرح کہ اُس کے ساتھ دوسروں کو شر یک ٹھیراتے ہیں\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdcciii{کیا یہ مطمئن ہیں کہ خدا کے عذاب کی کوئی بلا انہیں دبوچ نہ لے گی یا بے خبری میں قیامت کی گھڑی اچانک ان پر نہ آ جائے گی؟\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdcciv{تم ان سے صاف کہہ دو کہ ``میرا راستہ تو یہ ہے، میں اللہ کی طرف بلاتا ہوں، میں خود بھی پوری روشنی میں اپنا راستہ دیکھ رہا ہوں اور میرے ساتھی بھی، اور اللہ پاک ہے اور شرک کرنے والوں سے میرا کوئی واسطہ نہیں"\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdccv{اے محمدؐ، تم سے پہلے ہم نے جو پیغمبر بھیجے تھے وہ سب بھی انسان ہی تھے، اور انہی بستیوں کے رہنے والوں میں سے تھے، اور اُنہی کی طرف ہم وحی بھیجتے رہے ہیں پھر کیا یہ لوگ زمین میں چلے پھرے نہیں ہیں کہ اُن قوموں کا انجام انہیں نظر نہ آیا جو ان سے پہلے گزر چکی ہیں؟ یقیناً آخرت کا گھر اُن لوگوں کے لیے اور زیادہ بہتر ہے جنہوں نے (پیغمبروں کی بات مان کر) تقویٰ کی روش اختیار کی کیا اب بھی تم لوگ نہ سمجھو گے؟\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdccvi{(پہلے پیغمبروں کے ساتھ بھی یہی ہوتا رہا ہے کہ وہ مدتوں نصیحت کرتے رہے اور لوگوں نے سن کر نہ دیا) یہاں تک کہ جب پیغمبر لوگوں سے مایوس ہو گئے اور لوگوں نے بھی سمجھ لیا کہ اُن سے جھوٹ بولا گیا تھا، تو یکا یک ہماری مدد پیغمبروں کو پہنچ گئی پھر جب ایسا موقع آ جاتا ہے تو ہمارا قاعدہ یہ ہے کہ جسے ہم چاہتے ہیں بچا لیتے ہیں اور مجرموں پر سے تو ہمارا عذاب ٹالا ہی نہیں جا سکتا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdccvii{اگلے لوگوں کے ان قصوں میں عقل و ہوش رکھنے والوں کے لیے عبرت ہے یہ جو کچھ قرآن میں بیان کیا جا رہا ہے یہ بناوٹی باتیں نہیں ہیں بلکہ جو کتابیں اس سے پہلے آئی ہوئی ہیں انہی کی تصدیق ہے اور ہر چیز کی تفصیل اور ایمان لانے والوں کے لیے ہدایت اور رحمت\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdccviii{\basmalahur ا ل م ر یہ کتاب الٰہی کی آیات ہیں، اور جو کچھ تمہارے رب کی طرف سے تم پر نازل کیا گیا ہے وہ عین حق ہے، مگر (تمہاری قوم کے) اکثر لوگ مان نہیں رہے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccix{وہ اللہ ہی ہے جس نے آسمانوں کو ایسے سہاروں کے بغیر قائم کیا جو تم کو نظر آتے ہو ں، پھر وہ اپنے تخت سلطنت پر جلوہ فرما ہوا، اور اُس نے آفتاب و ماہتاب کو ایک قانون کا پابند بنایا اِس سارے نظام کی ہر چیز ایک وقت مقرر تک کے لیے چل رہی ہے اور اللہ ہی اِس سارے کام کی تدبیر فرما رہا ہے وہ نشانیاں کھول کھول کر بیان کرتا ہے، شاید کہ تم اپنے رب کی ملاقات کا یقین کرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccx{اور وہی ہے جس نے یہ زمین پھیلا رکھی ہے، اس میں پہاڑوں کے کھو نٹے گاڑ رکھے ہیں اور دریا بہا دیے ہیں اُسی نے ہر طرح کے پھلوں کے جوڑے پیدا کیے ہیں، اور وہی دن پر رات طاری کرتا ہے ان ساری چیزوں میں بڑی نشانیاں ہیں اُن لوگوں کے لیے جو غور و فکر سے کام لیتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccxi{اور دیکھو، زمین میں الگ الگ خطے پائے جاتے ہیں جو ایک دوسرے سے متصل واقع ہیں انگور کے باغ ہیں، کھیتیاں ہیں، کھجور کے درخت ہیں جن میں سے کچھ اکہرے ہیں اور کچھ دوہرے سب کو ایک ہی پانی سیراب کرتا ہے مگر مزے میں ہم کسی کو بہتر بنا دیتے ہیں اور کسی کو کمتر ان سب چیزوں میں بہت سی نشانیاں ہیں اُن لوگوں کے لیے جو عقل سے کام لیتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdccxii{اب اگر تمہیں تعجب کرنا ہے تو تعجب کے قابل لوگوں کا یہ قول ہے کہ ``جب ہم مر کر مٹی ہو جائیں گے تو کیا ہم نئے سرے سے پیدا کیے جائیں گے؟" یہ وہ لوگ ہیں جنہوں نے اپنے رب سے کفر کیا ہے یہ وہ لوگ ہیں جن کی گردنوں میں طوق پڑے ہوئے ہیں یہ جہنمی ہیں اور جہنم میں ہمیشہ رہیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdccxiii{یہ لوگ بھلائی سے پہلے برائی کے لیے جلدی مچا رہے ہیں حالانکہ ان سے پہلے (جو لوگ اس روش پر چلے ہیں ان پر خدا کے عذاب کی) عبرت ناک مثالیں گزر چکی ہیں حقیقت یہ ہے کہ تیرا رب لوگوں کی زیادتیوں کے باوجود ان کے ساتھ چشم پوشی سے کام لیتا ہے اور یہ بھی حقیقت ہے کہ تیرا رب سخت سزا دینے والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdccxiv{یہ لوگ جنہوں نے تمہاری با ت ماننے سے انکار کر دیا ہے، کہتے ہیں کہ ``اِس شخص پر اس کے رب کی طرف سے کوئی نشانی کیوں نہ اتری؟ تم تو محض خبردار کر دینے والے ہو، اور ہر قوم کے لیے ایک رہنما ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdccxv{اللہ ایک ایک حاملہ کے پیٹ سے واقف ہے جو کچھ اس میں بنتا ہے اسے بھی وہ جانتا ہے اور جو کچھ اس میں کمی یا بیشی ہوتی ہے اس سے بھی وہ باخبر رہتا ہے ہر چیز کے لیے اُس کے ہاں ایک مقدار مقر رہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdccxvi{وہ پوشیدہ اور ظاہر، ہر چیز کا عالم ہے وہ بزرگ ہے اور ہر حال میں بالا تر رہنے والا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdccxvii{تم میں سے کوئی شخص خواہ زور سے با ت کرے یا آہستہ، اور کوئی رات کی تاریکی میں چھپا ہوا ہو یا دن کی روشنی میں چل رہا ہو، اس کے لیے سب یکساں ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdccxviii{ہر شخص کے آگے اور پیچھے اس کے مقرر کیے ہوئے نگراں لگے ہوئے ہیں جو اللہ کے حکم سے اس کی دیکھ بھال کر رہے ہیں حقیقت یہ ہے کہ اللہ کسی قوم کے حال کو نہیں بدلتا جب تک وہ خود اپنے اوصاف کو نہیں بدل دیتی اور جب اللہ کسی قوم کی شامت لانے کا فیصلہ کر لے تو پھر وہ کسی کے ٹالے نہیں ٹل سکتی، نہ اللہ کے مقابلے میں ایسی قوم کا کوئی حامی و مدد گار ہو سکتا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdccxix{وہی ہے جو تمہارے سامنے بجلیاں چمکاتا ہے جنہیں دیکھ کر تمہیں اندیشے بھی لاحق ہوتے ہیں اور امیدیں بھی بندھتی ہیں وہی ہے جو پانی سے لدے ہوئے بادل اٹھاتا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdccxx{بادلوں کی گرج اس کی حمد کے ساتھ اس کی پاکی بیان کرتی ہے اور فرشتے اس کی ہیبت سے لرزتے ہوئے اُس کی تسبیح کرتے ہیں وہ کڑکتی ہوئی بجلیوں کو بھیجتا ہے اور (بسا اوقات) اُنہیں جس پر چاہتا ہے عین اس حالت میں گرا دیتا ہے جبکہ لوگ اللہ کے بارے میں جھگڑ رہے ہوتے ہیں فی الواقع اس کی چال بڑی زبردست ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdccxxi{اسی کو پکارنا برحق ہے رہیں وہ دوسری ہستیاں جنہیں اس کو چھوڑ کر یہ لوگ پکارتے ہیں، وہ اُن کی دعاؤں کا کوئی جواب نہیں دے سکتیں اُنہیں پکارنا تو ایسا ہے جیسے کوئی شخص پانی کی طرف ہاتھ پھیلا کر اُس سے درخواست کرے کہ تو میرے منہ تک پہنچ جا، حالانکہ پانی اُس تک پہنچنے والا نہیں بس اِسی طرح کافروں کی دعائیں بھی کچھ نہیں ہیں مگر ایک تیر بے ہدف!\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdccxxii{وہ تو اللہ ہی ہے جس کو زمین و آسمان کی ہر چیز طوعاً و کرہاً سجدہ کر رہی ہے اور سب چیزوں کے سائے صبح و شام اُس کے آگے جھکتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdccxxiii{اِن سے پوچھو، آسمان و زمین کا رب کون ہے؟ کہو، اللہ پھر ان سے کہو کہ جب حقیقت یہ ہے تو کیا تم نے اُسے چھوڑ کر ایسے معبودوں کو اپنا کارساز ٹھیرا لیا جو خود اپنے لیے بھی کسی نفع و نقصان کا اختیار نہیں رکھتے؟ کہو، کیا اندھا اور آنکھوں والا برابر ہوا کرتا ہے؟ کیا روشنی اور تاریکیاں یکساں ہوتی ہیں؟ اور اگر ایسا نہیں تو کیا اِن ٹھیرائے ہوئے شریکوں نے بھی اللہ کی طرح کچھ پیدا کیا ہے کہ اُس کی وجہ سے اِن پر تخلیق کا معاملہ مشتبہ ہو گیا؟ کہو، ہر چیز کا خالق صرف اللہ ہے اور وہ یکتا ہے، سب پر غالب!\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdccxxiv{اللہ نے آسمان سے پانی برسایا اور ہر ندی نالہ اپنے ظرف کے مطابق اسے لے کر چل نکلا پھر جب سیلاب اٹھا تو سطح پر جھاگ بھی آ گئے اور ویسے ہی جھاگ اُن دھاتوں پر بھی اٹھتے ہیں جنہیں زیور اور برتن وغیرہ بنانے کے لیے لوگ پگھلایا کرتے ہیں اِسی مثال سے اللہ حق اور باطل کے معاملے کو واضح کرتا ہے جو جھاگ ہے وہ اڑ جایا کرتا ہے اور جو چیز انسانوں کے لیے نافع ہے وہ زمین میں ٹھیر جاتی ہے اس طرح اللہ مثالوں سے اپنی بات سمجھاتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdccxxv{جن لوگوں نے اپنے رب کی دعوت قبول کر لی ہے اُن کے لیے بھلائی ہے اور جنہوں نے اسے قبول نہ کیا وہ اگر زمین کی ساری دولت کے بھی مالک ہوں اور اتنی ہی اور فراہم کر لیں تو وہ خدا کی پکڑ سے بچنے کے لیے اس سب کو فدیہ میں دے ڈالنے پر تیا ر ہو جائیں گے یہ وہ لوگ ہیں جن سے بری طرح حساب لیا جائے گا اور اُن کا ٹھکانہ جہنم ہے، بہت ہی برا ٹھکانا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdccxxvi{بھلا یہ کس طرح ممکن ہے کہ وہ شخص جو تمہارے رب کی اِس کتاب کو جو اس نے تم پر نازل کی ہے حق جانتا ہے، اور وہ شخص جو اس حقیقت کی طرف سے اندھا ہے، دونوں یکساں ہو جائیں؟ نصیحت تو دانش مند لوگ ہی قبول کیا کرتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdccxxvii{اور اُن کا طرز عمل یہ ہوتا ہے کہ اللہ کے ساتھ اپنے عہد کو پورا کرتے ہیں، اُسے مضبوط باندھنے کے بعد توڑ نہیں ڈالتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdccxxviii{اُن کی روش یہ ہوتی ہے کہ اللہ نے جن جن روابط کو برقرار رکھنے کا حکم دیا ہے انہیں برقرار رکھتے ہیں، اپنے رب سے ڈرتے ہیں اور اس بات کا خوف رکھتے ہیں کہ کہیں ان سے بری طرح حساب نہ لیا جائے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdccxxix{اُن کا حال یہ ہوتا ہے کہ اپنے رب کی رضا کے لیے صبر سے کام لیتے ہیں، نماز قائم کرتے ہیں، ہمارے دیے ہوئے رزق میں سے علانیہ اور پوشیدہ خرچ کرتے ہیں، اور برائی کو بھلائی سے دفع کرتے ہیں آخرت کا گھر انہی لوگوں کے لیے ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdccxxx{یعنی ایسے باغ جو اُن کی ابدی قیام گاہ ہوں گے وہ خود بھی ان میں داخل ہوں گے اور ان کے آباؤ اجداد اور اُن کی بیویوں اور اُن کی اولاد میں سے جو جو صالح ہیں وہ بھی اُن کے ساتھ وہاں جائیں گے ملائکہ ہر طرف سے اُن کے استقبال کے لیے آئیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdccxxxi{اور اُن سے کہیں گے کہ ``تم پر سلامتی ہے، تم نے دنیا میں جس طرح صبر سے کام لیا اُس کی بدولت آج تم اِس کے مستحق ہوئے ہو" پس کیا ہی خوب ہے یہ آخرت کا گھر!\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdccxxxii{رہے وہ لوگ جو اللہ کے عہد کو مضبوط باندھ لینے کے بعد توڑ ڈالتے ہیں، جو اُن رابطوں کو کاٹتے ہیں جنہیں اللہ نے جوڑنے کا حکم دیا ہے، اور جو زمین میں فساد پھیلاتے ہیں، وہ لعنت کے مستحق ہیں اور ان کے لیے آخرت میں بہت برا ٹھکانا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiii{اللہ جس کو چاہتا ہے رزق کی فراخی بخشتا ہے اور جسے چاہتا ہے کہ نپا تلا رزق دیتا ہے یہ لوگ دنیوی زندگی میں مگن ہیں، حالانکہ د نیا کی زندگی آخرت کے مقابلے میں ایک متاع قلیل کے سوا کچھ بھی نہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiv{یہ لوگ جنہوں نے (رسالت محمدیؐ کو ماننے سے) انکار کر دیا ہے کہتے ہیں ``اِس شخص پر اِس کے رب کی طرف سے کوئی نشانی کیوں نہ اتری" کہو، اللہ جسے چاہتا ہے گمراہ کر دیتا ہے اور وہ اپنی طرف آنے کا راستہ اُسی کو دکھاتا ہے جو اُس کی طرف رجوع کرے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdccxxxv{ایسے ہی لوگ ہیں وہ جنہوں نے (اِس نبی کی دعوت کو) مان لیا اور اُن کے دلوں کو اللہ کی یاد سے اطمینان نصیب ہوتا ہے خبردار رہو! اللہ کی یاد ہی وہ چیز ہے جس سے دلوں کو اطمینان نصیب ہوا کرتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvi{پھر جن لوگوں نے دعوت حق کو مانا اور نیک عمل کیے وہ خوش نصیب ہیں اور ان کے لیے اچھا انجام ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvii{اے محمدؐ، اِسی شان سے ہم نے تم کو رسول بنا کر بھیجا ہے، ایک ایسی قوم میں جس سے پہلے بہت سی قومیں گزر چکی ہیں، تاکہ تم اِن لوگوں کو وہ پیغام سناؤ جو ہم نے تم پر نازل کیا ہے، اِس حال میں کہ یہ اپنے نہایت مہربان خدا کے کافر بنے ہوئے ہیں اِن سے کہو کہ وہی میرا رب ہے، اُس کے سوا کوئی معبود نہیں ہے، اُسی پر میں نے بھروسہ کیا اور وہی میرا ملجا و ماویٰ ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdccxxxviii{اور کیا ہو جاتا اگر کوئی ایسا قرآن اتار دیا جاتا جس کے زور سے پہاڑ چلنے لگتے، یا زمین شق ہو جاتی، یا مُردے قبروں سے نکل کر بولنے لگتے؟ (اس طرح کی نشانیاں دکھا دینا کچھ مشکل نہیں ہے) بلکہ سارا اختیار ہی اللہ کے ہاتھ میں ہے پھر کیا اہل ایمان (ابھی تک کفار کی طلب کے جواب میں کسی نشانی کے ظہور کی آس لگا ئے بیٹھے ہیں اور وہ یہ جان کر) مایوس نہیں ہو گئے کہ اگر اللہ چاہتا تو سارے انسانوں کو ہدایت دے دیتا؟ جن لوگوں نے خدا کے ساتھ کفر کا رویہ اختیار کر ر کھا ہے اُن پر ان کے کرتوتوں کی وجہ سے کوئی نہ کوئی آفت آتی ہی رہتی ہے، یا ان کے گھر کے قریب کہیں نازل ہوتی ہے یہ سلسلہ چلتا رہے گا یہاں تک کہ اللہ کا وعدہ آن پورا ہو یقیناً اللہ اپنے وعدے کی خلاف ورزی نہیں کرتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdccxxxix{تم سے پہلے بھی بہت سے رسولوں کا مذاق اڑایا جا چکا ہے، مگر میں نے ہمیشہ منکر ین کو ڈھیل دی اور آخر کار ان کو پکڑ لیا، پھر دیکھ لو کہ میری سزا کیسی سخت تھی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdccxl{پھر کیا وہ جو ایک ایک متنفس کی کمائی پر نظر رکھتا ہے (اُس کے مقابلے میں یہ جسارتیں کی جا رہی ہیں کہ) لوگوں نے اُس کے کچھ شریک ٹھیرا رکھے ہیں؟ اے نبیؐ، اِن سے کہو (اگر واقعی وہ خدا کے اپنے بنائے ہوئے شریک ہیں تو) ذرا اُن کے نا م لو کہ وہ کون ہیں؟ کیا تم اللہ کو ایک نئی بات کی خبر دے رہے ہو جسے وہ اپنی زمین میں نہیں جانتا؟ یا تم لوگ بس یونہی جو منہ میں آتا ہے کہہ ڈالتے ہو؟ حقیقت یہ ہے کہ جن لوگوں نے دعوت حق کو ماننے سے انکار کیا ہے ان کے لیے اُن کی مکاریاں خوشنما بنا دی گئی ہیں اور وہ راہ راست سے روک دیے گئے ہیں، پھر جس کو اللہ گمراہی میں پھینک دے اُسے کوئی راہ دکھانے والا نہیں ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdccxli{ایسے لوگوں کے لیے دنیا کی زندگی ہی میں عذاب ہے، اور آخرت کا عذاب اُس سے بھی زیادہ سخت ہے کوئی ایسا نہیں جو اُنہیں خدا سے بچانے والا ہو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdccxlii{خدا ترس انسانوں کے لیے جس جنت کا وعدہ کیا گیا ہے اس کی شان یہ ہے کہ اس کے نیچے نہریں بہہ رہی ہیں، اس کے پھل دائمی ہیں اور اس کا سایہ لازوال یہ انجام ہے متقی لوگوں کا اور منکرین حق کا انجام یہ ہے کہ ان کے لیے دوزخ کی آگ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdccxliii{اے نبیؐ، جن لوگوں کو ہم نے پہلے کتاب دی تھی وہ اِس کتاب سے جو ہم نے تم پر نازل کی ہے، خوش ہیں اور مختلف گروہوں میں کچھ لوگ ایسے بھی ہیں جو اس کی بعض باتوں کو نہیں مانتے تم صاف کہہ دو کہ ``مجھے تو صرف اللہ کی بندگی کا حکم دیا گیا ہے اور اس سے منع کیا گیا ہے کہ کسی کو اس کے ساتھ شریک ٹھیراؤں لہٰذا میں اسی کی طرف دعوت دیتا ہوں اور اسی کی طرف میرا رجوع ہے"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdccxliv{اِسی ہدایت کے ساتھ ہم نے یہ فرمان عربی تم پر نازل کیا ہے اب اگر تم نے اِس علم کے باوجود جو تمہارے پاس آ چکا ہے لوگوں کی خواہشات کی پیروی کی تو اللہ کے مقابلے میں نہ کوئی تمہارا حامی و مددگار ہے اور نہ کوئی اس کی پکڑسے تم کو بچا سکتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdccxlv{تم سے پہلے بھی ہم بہت سے رسول بھیج چکے ہیں اور اُن کو ہم نے بیوی بچوں والا ہی بنایا تھا اور کسی رسول کی بھی یہ طاقت نہ تھی کہ اللہ کے اذن کے بغیر کوئی نشانی خود لا دکھاتا ہر دور کے لیے ایک کتاب ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdccxlvi{اللہ جو کچھ چاہتا ہے مٹا دیتا ہے اور جس چیز کو چاہتا ہے قائم رکھتا ہے، ام الکتاب اُسی کے پاس ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxlvii{اور اے نبیؐ، جس برے انجام کی دھمکی ہم اِن لوگوں کو دے رہے ہیں اُس کوئی حصہ خواہ ہم تمہارے جیتے جی دکھا دیں یا اس کے ظہور میں آنے سے پہلے ہم تمہیں اٹھا لیں، بہر حال تمہارا کام صرف پیغام پہنچا دینا ہے اور حساب لینا ہمارا کام ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxlviii{کیا یہ لوگ دیکھتے نہیں ہیں کہ ہم اِس سرزمین پر چلے آ رہے ہیں اور اس کا دائرہ ہر طرف سے تنگ کرتے چلے آتے ہیں؟ اللہ حکومت کر رہا ہے، کوئی اس کے فیصلوں پر نظر ثانی کرنے و الا نہیں ہے، اور اُسے حساب لیتے کچھ دیر نہیں لگتی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxlix{اِن سے پہلے جو لوگ ہو گزرے ہیں وہ بھی بڑی بڑی چالیں چل چکے ہیں، مگر اصل فیصلہ کن چال تو پوری کی پوری اللہ ہی کے ہاتھ میں ہے وہ جانتا ہے کہ کون کیا کچھ کمائی کر رہا ہے، اور عنقریب یہ منکرین حق دیکھ لیں گے کہ انجام کس کا بخیر ہوتا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccl{یہ منکرین کہتے ہیں کہ تم خدا کے بھیجے ہوئے نہیں ہو کہو ``میرے اور تمہارے درمیان اللہ کی گواہی کافی ہے اور پھر ہر اُس شخص کی گواہی جو کتاب آسمانی کا علم رکھتا ہے"\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccli{\basmalahur ا ل ر اے محمدؐ، یہ ایک کتاب ہے جس کو ہم نے تمہاری طرف نازل کیا ہے تاکہ تم لوگوں کو تاریکیوں سے نکال کر روشنی میں لاؤ، ان کے رب کی توفیق سے، اُس خدا کے راستے پر جو زبردست اور اپنی ذات میں آپ محمود ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdcclii{اور زمین اور آسمانوں کی ساری موجودات کا مالک ہے اور سخت تباہ کن سزا ہے قبول حق سے انکار کرنے والوں کے لیے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccliii{جو دنیا کی زندگی کو آخرت پر ترجیح دیتے ہیں، جو اللہ کے راستے سے لوگوں کو روک رہے ہیں اور چاہتے ہیں کہ یہ راستہ (ان کی خواہشات کے مطابق) ٹیٹرھا ہو جائے یہ لوگ گمراہی میں بہت دور نکل گئے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccliv{ہم نے اپنا پیغام دینے کے لیے جب کبھی کوئی رسول بھیجا ہے، اُس نے اپنی قوم ہی کی زبان میں پیغام دیا ہے تاکہ وہ انہیں اچھی طرح کھول کر بات سمجھائے پھر اللہ جسے چاہتا ہے بھٹکا دیتا ہے اور جسے چاہتا ہے ہدایت بخشتا ہے، وہ بالا دست اور حکیم ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcclv{ہم اِس سے پہلے موسیٰؑ کو بھی اپنی نشانیوں کے ساتھ بھیج چکے ہیں اسے بھی ہم نے حکم دیا تھا کہ اپنی قوم کو تاریکیوں سے نکال کر روشنی میں لا اور انہیں تاریخ الٰہی کے سبق آموز واقعات سنا کر نصیحت کر اِن واقعات میں بڑی نشانیاں ہیں ہر اُس شخص کے لیے جو صبر اور شکر کرنے والا ہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcclvi{یاد کرو جب موسیٰؑ نے اپنی قوم سے کہا ``اللہ کے اُس احسان کو یاد رکھو جو اس نے تم پر کیا ہے اس نے تم کو فرعون والوں سے چھڑایا جو تم کو سخت تکلیفیں دیتے تھے، تمہارے لڑکوں کو قتل کر ڈالتے تھے اور تمہاری عورتوں کو زندہ بچا رکھتے تھے اس میں تمہارے رب کی طرف سے تمہاری بڑی آزمائش تھی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcclvii{اور یاد رکھو، تمہارے رب نے خبردار کر دیا تھا کہ اگر شکر گزار بنو گے تو میں تم کو اور زیادہ نوازوں گا اور اگر کفران نعمت کرو گے تو میری سزا بہت سخت ہے"\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcclviii{اور موسیٰؑ نے کہا کہ ``اگر تم کفر کرو اور زمین کے سارے رہنے والے بھی کافر ہو جائیں تو اللہ بے نیاز اور اپنی ذات میں آپ محمود ہے"\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcclix{کیا تمہیں اُن قوموں کے حالات نہیں پہنچے جو تم سے پہلے گزر چکی ہیں؟ قوم نوحؑ، عاد، ثمود اور اُن کے بعد آنے والی بہت سی قومیں جن کا شمار اللہ ہی کو معلوم ہے؟ اُن کے رسول جب اُن کے پاس صاف صاف باتیں اور کھلی کھلی نشانیاں لیے ہوئے آئے تو اُنہوں نے اپنے منہ میں ہاتھ دبا لیے اور کہا کہ ``جس پیغام کے ساتھ تم بھیجے گئے ہو ہم اس کو نہیں مانتے اور جس چیز کی تم ہمیں دعوت دیتے ہو اُس کی طرف سے ہم سخت خلجان آمیز شک میں پڑے ہوئے ہیں"\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcclx{اُن کے رسولوں نے کہا ``کیا خدا کے بارے میں شک ہے جو آسمانوں اور زمین کا خالق ہے؟ وہ تمہیں بلا ر =ہا ہے تاکہ تمہارے قصور معاف کرے اور تم کو ایک مدت مقرر تک مہلت دے" اُنہوں نے جواب دیا ``تم کچھ نہیں ہو مگر ویسے ہی انسان جیسے ہم ہیں تم ہمیں اُن ہستیوں کی بندگی سے روکنا چاہتے ہو جن کی بندگی باپ دادا سے ہوتی چلی آ رہی ہے اچھا تو لاؤ کوئی صریح سند"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcclxi{ان کے رسولوں نے ان سے کہا ``واقعی ہم کچھ نہیں ہیں مگر تم ہی جیسے انسان لیکن اللہ اپنے بندوں میں سے جس کو چاہتا ہے نوازتا ہے اور یہ ہمارے اختیار میں نہیں ہے کہ تمہیں کوئی سند لا دیں سند تو اللہ ہی کے اذن سے آسکتی ہے اور اللہ ہی پر اہل ایمان کو بھروسہ کرنا چاہیے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcclxii{اور ہم کیوں نہ اللہ پر بھروسہ کریں جبکہ ہماری زندگی کی راہوں میں اس نے ہماری رہنمائی کی ہے؟ جو اذیتیں تم لوگ ہمیں دے رہے ہو اُن پر ہم صبر کریں گے اور بھروسا کرنے والوں کا بھروسا اللہ ہی پر ہونا چاہیے"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcclxiii{آخر کار منکرین نے اپنے رسولوں سے کہہ دیا کہ ``یا تو تمہیں ہماری ملت میں واپس آنا ہوگا ورنہ ہم تمہیں اپنے ملک سے نکال دیں گے" تب اُن کے رب نے اُن پر وحی بھیجی کہ ``ہم اِن ظالموں کو ہلا ک کر دیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcclxiv{اور اُن کے بعد تمہیں زمین میں آباد کریں گے یہ انعام ہے اُس کا جو میرے حضور جواب دہی کا خوف رکھتا ہو اور میری وعید سے ڈرتا ہو"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcclxv{اُنہوں نے فیصلہ چاہا تھا (تو یوں اُن کا فیصلہ ہوا) اور ہر جبار دشمن حق نے منہ کی کھائی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcclxvi{پھر اس کے بعد آگے اس کے لیے جہنم ہے وہاں اُسے کچ لہو کا سا پانی پینے کو دیا جائے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcclxvii{جسے وہ زبردستی حلق سے اتارنے کی کوشش کرے گا اور مشکل ہی سے اتار سکے گا موت ہر طرف سے اس پر چھائی رہے گی مگر وہ مرنے نہ پائے گا اور آگے ایک سخت عذاب اس کی جان کا لاگو رہے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcclxviii{جن لوگوں نے اپنے رب سے کفر کیا ہے ان کے اعمال کی مثال اُس راکھ کی سی ہے جسے ایک طوفانی دن کی آندھی نے اڑا دیا ہو وہ اپنے کیے کا کچھ بھی پھل نہ پا سکیں گے یہی پرلے درجے کی گم گشتگی ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcclxix{کیا تم دیکھتے نہیں ہو کہ اللہ نے آسمان و زمین کی تخلیق کو حق پر قائم کیا ہے؟ وہ چاہے تو تم لوگوں کو لے جائے اور ایک نئی خلقت تمہاری جگہ لے آئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcclxx{ایسا کرنا اس پر کچھ بھی دشوار نہیں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcclxxi{اور یہ لوگ جب اکٹھے اللہ کے سامنے بے نقاب ہوں گے تو اُس وقت اِن میں سے جو دنیا میں کمزور تھے و ہ اُن لوگوں سے جو بڑے بنے ہوئے تھے، کہیں گے ``دنیا میں ہم تمہارے تابع تھے، اب کیا تم اللہ کے عذاب سے ہم کو بچانے کے لیے بھی کچھ کرسکتے ہو؟"وہ جواب دیں گے ``اگر اللہ نے ہمیں نجات کی کوئی راہ دکھائی ہوتی تو ہم ضرور تمہیں بھی دکھا دیتے اب تو یکساں ہے، خواہ ہم جزع فزع کریں یا صبر، بہرحال ہمارے بچنے کی کوئی صورت نہیں"\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcclxxii{اور جب فیصلہ چکا دیا جائے گا تو شیطان کہے گا ``حقیقت یہ ہے کہ اللہ نے جو وعدے تم سے کیے تھے و ہ سب سچے تھے اور میں نے جتنے وعدے کیے ان میں سے کوئی بھی پورا نہ کیا میرا تم پر کوئی زور تو تھا نہیں، میں نے اِس کے سوا کچھ نہیں کیا کہ اپنے راستے کی طرف تمہیں دعوت دی اور تم نے میری دعوت پر لبیک کہا اب مجھے ملامت نہ کرو، اپنے آپ ہی کو ملامت کرو یہاں نہ میں تمہاری فریاد رسی کر سکتا ہوں اور نہ تم میر ی اس سے پہلے جو تم نے مجھے خدائی میں شریک بنا رکھا تھا میں اس سے بری الذمہ ہوں، ایسے ظالموں کے لیے درد ناک سزا یقینی ہے"\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiii{بخلاف اس کے جو لوگ دنیا میں ایمان لائے ہیں اور جنہوں نے نیک عمل کیے ہیں وہ ایسے باغوں میں داخل کیے جائیں گے جن کے نیچے نہریں بہتی ہوں گی وہاں وہ اپنے رب کے اذن سے ہمیشہ رہیں گے، اور وہاں ان کا استقبال سلامتی کی مبارک باد سے ہوگا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiv{کیا تم دیکھتے نہیں ہو کہ اللہ نے کلمہ طیبہ کو کس چیز سے مثال دی ہے؟ اس کی مثال ایسی ہے جیسے ایک اچھی ذات کا درخت، جس کی جڑ زمین میں گہری جمی ہوئی ہے اور شاخیں آسمان تک پہنچی ہوئی ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcclxxv{ہر آن وہ اپنے رب کے حکم سے اپنے پھل دے رہا ہے یہ مثالیں اللہ اس لیے دیتا ہے کہ لوگ اِن سے سبق لیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvi{اور کلمہ خبیثہ کی مثال ایک بد ذات درخت کی سی ہے جو زمین کی سطح سے اکھاڑ پھینکا جاتا ہے، اُس کے لیے کوئی استحکام نہیں ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvii{ایمان لانے والوں کو اللہ ایک قول ثابت کی بنیاد پر دنیا اور آخرت، دونوں میں ثبات عطا کرتا ہے، اور ظالموں کو اللہ بھٹکا دیتا ہے اللہ کو اختیار ہے جو چاہے کرے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcclxxviii{تم نے دیکھا اُن لوگوں کو جنہوں نے اللہ کی نعمت پائی اور اُسے کفران نعمت سے بدل ڈالا اور (اپنے ساتھ) اپنی قوم کو بھی ہلاکت کے گھر میں جھونک دیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcclxxix{یعنی جہنم، جس میں وہ جھلسے جائیں گے اور وہ بد ترین جائے قرار ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcclxxx{اور اللہ کے کچھ ہمسر تجویز کر لیے تاکہ وہ انہیں اللہ کے راستے سے بھٹکا دیں اِن سے کہو، اچھا مزے کر لو، آخرکار تمہیں پلٹ کر جانا دوزخ ہی میں ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxi{اے نبیؐ، میرے جو بندے ایمان لائے ہیں اُن سے کہہ دو کہ نماز قائم کریں اور جو کچھ ہم نے اُن کو دیا ہے، اُس میں سے کھلے اور چھپے (راہ خیر میں) خرچ کریں قبل اِس کے کہ وہ دن آئے جس میں نہ خرید و فروخت ہوگی اور نہ دوست نوازی ہوسکے گی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxii{اللہ وہی تو ہے جس نے زمین اور آسمانوں کو پیدا کیا اور آسمان سے پانی برسایا، پھر اس کے ذریعہ سے تمہاری رزق رسانی کے لیے طرح طرح کے پھل پیدا کیے جس نے کشتی کو تمہارے لیے مسخر کیا کہ سمندر میں اُس کے حکم سے چلے اور دریاؤں کو تمہارے لیے مسخر کیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiii{جس نے سورج اور چاند کو تمہارے لیے مسخر کیا کہ لگاتار چلے جا رہے ہیں اور رات اور دن کو تمہارے لیے مسخر کیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiv{جس نے وہ سب کچھ تمہیں دیا جو تم نے مانگا اگر تم اللہ کی نعمتوں کا شمار کرنا چاہو تو کر نہیں سکتے حقیقت یہ ہے کہ انسان بڑا ہی بے انصاف اور ناشکرا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxv{یاد کرو وہ وقت جب ابراہیمؑ نے دعا کی تھی کہ ``پروردگار، اِس شہر کو امن کا شہر بنا اور مجھے اور میری اولاد کو بت پرستی سے بچا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvi{پروردگار، اِن بتوں نے بہتوں کو گمراہی میں ڈالا ہے (ممکن ہے کہ میری اولاد کو بھی یہ گمراہ کر دیں، لہٰذا اُن میں سے) جو میرے طریقے پر چلے وہ میرا ہے اور جو میرے خلاف طریقہ اختیار کرے تو یقیناً تو درگزر کرنے والا مہربان ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvii{پروردگار، میں نے ایک بے آب و گیاہ وادی میں اپنی اولاد کے ایک حصے کو تیرے محترم گھر کے پاس لا بسایا ہے پروردگار، یہ میں نے اس لیے کیا ہے کہ یہ لوگ یہاں نماز قائم کریں، لہٰذا تو لوگوں کے دلوں کو اِن کا مشتاق بنا اور انہیں کھانے کو پھل دے، شاید کہ یہ شکر گزار بنیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxviii{پروردگار، تو جانتا ہے جو کچھ ہم چھپاتے ہیں اور جو کچھ ظاہر کرتے ہیں" اور واقعی اللہ سے کچھ بھی چھپا ہوا نہیں ہے، نہ زمین میں نہ آسمانوں میں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxix{``شکر ہے اُس خدا کا جس نے مجھے اِس بڑھاپے میں اسماعیلؑ اور اسحاقؑ جیسے بیٹے دیے، حقیقت یہ ہے کہ میرا رب ضرور دعا سنتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxc{ا ے میرے پروردگار، مجھے نماز قائم کرنے والا بنا اور میری اولاد سے بھی (ایسے لوگ اٹھا جو یہ کام کریں) پروردگار، میری دعا قبول کر\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxci{پروردگار، مجھے اور میرے والدین کو اور سب ایمان لانے والوں کو اُس دن معاف کر دیجیو جبکہ حساب قائم ہوگا"\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxcii{اب یہ ظالم لوگ جو کچھ کر رہے ہیں، اللہ کو تم اس سے غافل نہ سمجھو اللہ تو اِنہیں ٹال رہا ہے اُس دن کے لیے جب حال یہ ہوگا کہ آنکھیں پھٹی کی پھٹی رہ گئی ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccxciii{سر اٹھائے بھاگے چلے جا رہے ہیں، نظریں اوپر جمی ہیں اور دل اڑے جاتے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccxciv{اے محمدؐ، اُس دن سے تم اِنہیں ڈراؤ جبکہ عذاب اِنہیں آلے گا اُس وقت یہ ظالم کہیں گے کہ ``اے ہمارے رب، ہمیں تھوڑی سی مہلت اور دے دے، ہم تیری دعوت کو لبیک کہیں گے اور رسولوں کی پیروی کریں گے" (مگر انہیں صاف جواب دے دیا جائے گا کہ) کیا تم وہی لوگ نہیں ہو جو اِس سے پہلے قسمیں کھا کھا کر کہتے تھے کہ ہم پر تو کبھی زوال آنا ہی نہیں ہے؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdccxcv{حالانکہ تم ان قوموں کی بستیوں میں رہ بس چکے تھے جنہوں نے اپنے اوپر آپ ظلم کیا تھا اور دیکھ چکے تھے کہ ہم نے اُن سے کیا سلوک کیا اور اُن کی مثالیں دے دے کر ہم تمہیں سمجھا بھی چکے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdccxcvi{انہوں نے اپنی ساری ہی چالیں چل دیکھیں، مگر اُن کی ہر چال کا توڑ اللہ کے پاس تھا اگرچہ اُن کی چالیں ایسی غضب کی تھیں کہ پہاڑ اُن سے ٹل جائیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdccxcvii{پس اے نبیؐ، تم ہرگز یہ گمان نہ کرو کہ اللہ کبھی اپنے رسولوں سے کیے ہوئے وعدوں کے خلاف کرے گا اللہ زبردست ہے اور انتقام لینے والا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdccxcviii{ڈراؤ اِنہیں اُس دن سے جبکہ زمین اور آسمان بدل کر کچھ سے کچھ کر دیے جائیں گے اور سب کے سب اللہ واحد قہار کے سامنے بے نقاب حاضر ہو جائیں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdccxcix{اُس روز تم مجرموں کو دیکھو گے کہ زنجیروں میں ہاتھ پاؤں جکڑے ہونگے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccc{تارکول کے لباس پہنے ہوئے ہوں گے اور آگ کے شعلے اُن کے چہروں پر چھائے جا رہے ہوں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdccci{یہ اِس لیے ہوگا کہ اللہ ہر متنفس کو اس کے کیے کا بدلہ دے گا اللہ کوحساب لیتے کچھ دیر نہیں لگتی\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccii{یہ ایک پیغام ہے سب انسانوں کے لیے، اور یہ بھیجا گیا ہے اس لیے کہ اُن کو اِس کے ذریعہ سے خبردار کر دیا جائے اور وہ جان لیں کہ حقیقت میں خدا بس ایک ہی ہے اور جو عقل رکھتے ہیں وہ ہوش میں آ جائیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccciii{\basmalahur ا ل ر یہ آیات ہیں کتاب الٰہی اور قرآن مبین کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccciv{بعید نہیں کہ ایک وقت وہ آ جائے جب وہی لوگ جنہوں نے آج (دعوت اسلام کو قبول کرنے سے) انکار کر دیا ہے پچھتا پچھتا کر کہیں گے کہ کاش ہم نے سر تسلیم خم کر دیا ہوتا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdcccv{چھوڑو اِنہیں کھائیں، پییں، مزے کریں، اور بھلاوے میں ڈالے رکھے اِن کو جھوٹی امید عنقریب اِنہیں معلوم ہو جائے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdcccvi{ہم نے اِس سے پہلے جس بستی کو بھی ہلاک کیا ہے اس کے لیے ایک خاص مہلت عمل لکھی جاچکی تھی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcccvii{کوئی قوم نہ اپنے وقت مقرر سے پہلے ہلاک ہوسکتی ہے، نہ اُس کے بعد چھوٹ سکتی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcccviii{یہ لوگ کہتے ہیں ``اے وہ شخص جس پر ذکر نازل ہوا ہے، تو یقیناً دیوانہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcccix{اگر تو سچا ہے تو ہمارے سامنے فرشتوں کو لے کیوں نہیں آتا؟"\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcccx{ہم فرشتوں کو یوں ہی نہیں اتار دیا کرتے وہ جب اترتے ہیں تو حق کے ساتھ اترتے ہیں، اور پھر لوگوں کو مہلت نہیں دی جاتی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcccxi{رہا یہ ذکر، تو اِس کو ہم نے نازل کیا ہے اور ہم خود اِس کے نگہبان ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcccxii{اے محمدؐ، ہم تم سے پہلے بہت سی گزری ہوئی قوموں میں رسول بھیج چکے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcccxiii{کبھی ایسا نہیں ہوا کہ اُن کہ پاس کوئی رسول آیا ہو اور اُنہوں نے اُس کا مذاق نہ اڑایا ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcccxiv{مجرمین کے دلوں میں تو ہم اس ذکر کو اِسی طرح (سلاخ کے مانند) گزارتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcccxv{وہ اِس پر ایمان نہیں لایا کرتے قدیم سے اِس قماش کے لوگوں کا یہی طریقہ چلا آ رہا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcccxvi{اگر ہم اُن پر آسمان کا کوئی دروازہ کھول دیتے اور وہ دن دہاڑے اُس میں چڑھنے بھی لگتے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcccxvii{تب بھی وہ یہی کہتے کہ ہماری آنکھوں کو دھوکا ہو رہا ہے، بلکہ ہم پر جادو کر دیا گیا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcccxviii{یہ ہماری کار فرمائی ہے کہ آسمان میں ہم نے بہت سے مضبوط قلعے بنائے، اُن کو دیکھنے والوں کے لیے مزین کیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcccxix{اور ہر شیطان مردود سے ان کو محفوظ کر دیا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcccxx{کوئی شیطان ان میں راہ نہیں پا سکتا، الا یہ کہ کچھ سن گن لے لے اور جب وہ سن گن لینے کی کوشش کرتا ہے تو ایک شعلہ روشن اُس کا پیچھا کرتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcccxxi{ہم نے زمین کو پھیلایا، اُس میں پہاڑ جمائے، اس میں ہر نوع کی نباتات ٹھیک ٹھیک نپی تلی مقدار کے ساتھ اگائی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcccxxii{اور اس میں معیشت کے اسباب فراہم کیے، تمہارے لیے بھی اور اُن بہت سی مخلوقات کے لیے بھی جن کے رازق تم نہیں ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiii{کوئی چیز ایسی نہیں جس کے خزانے ہمارے پاس نہ ہوں، اور جس چیز کو بھی ہم نازل کرتے ہیں ایک مقرر مقدار میں نازل کرتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiv{بار آور ہواؤں کو ہم ہی بھیجتے ہیں، پھر آسمان سے پانی برساتے ہیں، اور اُس پانی سے تمہیں سیراب کرتے ہیں اِس دولت کے خزانہ دار تم نہیں ہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcccxxv{زندگی اور موت ہم دیتے ہیں، اور ہم ہی سب کے وارث ہونے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvi{پہلے جو لوگ تم میں سے ہو گزرے ہیں اُن کو بھی ہم نے دیکھ رکھا ہے، اور بعد کے آنے والے بھی ہماری نگاہ میں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvii{یقیناً تمہارا رب ان سب کو اکٹھا کرے گا، وہ حکیم بھی ہے اور علیم بھی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcccxxviii{ہم نے انسان کو سٹری ہوئی مٹی کے سوکھے گارے سے بنایا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcccxxix{اور اُس سے پہلے جنوں کو ہم آگ کی لپٹ سے پیدا کر چکے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcccxxx{پھر یاد کرو اُس موقع کو جب تمہارے رب نے فرشتوں سے کہا کہ ``میں سڑی ہوئی مٹی کے سوکھے گارے سے ایک بشر پیدا کر رہا ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxi{جب میں اُسے پورا بنا چکوں اور اس میں اپنی روح سے کچھ پھونک دوں تو تم سب اس کے آگے سجدے میں گر جانا"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxii{چنانچہ تمام فرشتوں نے سجدہ کیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiii{سوائے ابلیس کے کہ اُس نے سجدہ کرنے والوں کا ساتھ دینے سے انکار کر دیا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiv{رب نے پوچھا ``اے ابلیس، تجھے کیا ہوا کہ تو نے سجدہ کرنے والوں کا ساتھ نہ دیا؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxv{اس نے کہا ``میرا یہ کام نہیں ہے کہ میں اِس بشر کو سجدہ کروں جسے تو نے سڑی ہوئی مٹی کے سوکھے گارے سے پیدا کیا ہے"\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvi{رب نے فرمایا ``اچھا تو نکل جا یہاں سے کیونکہ تو مردود ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvii{اور اب روز جزا تک تجھ پر لعنت ہے"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxviii{اُس نے عرض کیا ``میرے رب، یہ بات ہے تو پھر مجھے اُس روز تک کے لیے مہلت دے جبکہ سب انسان دوبارہ اٹھائے جائیں گے"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxix{فرمایا ``اچھا، تجھے مہلت ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcccxl{اُس دن تک جس کا وقت ہمیں معلوم ہے"\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcccxli{وہ بولا ``میرے رب، جیسا تو نے مجھے بہکایا اُسی طرح اب میں زمین میں اِن کے لیے دل فریبیاں پیدا کر کے اِن سب کو بہکا دوں گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcccxlii{سوائے تیرے اُن بندوں کے جنہیں تو نے اِن میں سے خالص کر لیا ہو"\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcccxliii{فرمایا ``یہ راستہ ہے جو سیدھا مجھ تک پہنچتا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcccxliv{بے شک، جو میرے حقیقی بندے ہیں ان پر تیرا بس نہ چلے گا تیرا بس تو صرف اُن بہکے ہوئے لوگوں ہی پر چلے گا جو تیری پیروی کریں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcccxlv{اور ان سب کے لیے جہنم کی وعید ہے"\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvi{یہ جہنم (جس کی وعید پیروان ابلیس کے لیے کی گئی ہے) اس کے سات دروازے ہیں ہر دروازے کے لیے اُن میں سے ایک حصہ مخصوص کر دیا گیا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvii{بخلاف اِس کے متقی لوگ باغوں اور چشموں میں ہوں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcccxlviii{اور اُن سے کہا جائے گا کہ داخل ہو جاؤ ان میں سلامتی کے ساتھ بے خوف و خطر\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcccxlix{اُن کے دلوں میں جو تھوڑی بہت کھوٹ کپٹ ہوگی اسے ہم نکال دیں گے، وہ آپس میں بھائی بھائی بن کر آمنے سامنے تختوں پر بیٹھیں گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcccl{اُنہیں نہ وہاں کسی مشقت سے پالا پڑے گا اور نہ وہ وہاں سے نکالے جائیں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcccli{اے نبیؐ، میرے بندوں کو خبر دے دو کہ میں بہت درگزر کرنے والا اور رحیم ہوں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccclii{مگر اِس کے ساتھ میرا عذاب بھی نہایت دردناک عذاب ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcccliii{اور انہیں ذرا ابراہیمؑ کے مہمانوں کا قصہ سناؤ\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccliv{جب وہ آئے اُس کے ہاں اور کہا ``سلام ہو تم پر،" تو اُس نے کہا ``ہمیں تم سے ڈر لگتا ہے"\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccclv{اُنہوں نے جواب دیا ``ڈرو نہیں، ہم تمہیں ایک بڑے سیانے لڑکے کی بشارت دیتے ہیں"\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdccclvi{ابراہیمؑ نے کہا ``کیا تم اِس بڑھاپے میں مجھے اولاد کی بشارت دیتے ہو؟ ذرا سوچو تو سہی کہ یہ کیسی بشارت تم مجھے دے رہے ہو؟"\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdccclvii{اُنہوں نے جواب دیا ``ہم تمہیں برحق بشارت دے رہے ہیں، تم مایوس نہ ہو"\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdccclviii{ابراہیمؑ نے کہا ``اپنے رب کی رحمت سے مایوس تو گمراہ لوگ ہی ہوا کرتے ہیں"\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdccclix{پھر ابراہیمؑ نے پوچھا ``اے فرستادگان الٰہی، وہ مہم کیا ہے جس پر آپ حضرات تشریف لائے ہیں؟"\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdccclx{وہ بولے، ``ہم ایک مجرم قوم کی طرف بھیجے گئے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdccclxi{صرف لوطؑ کے گھر والے مستثنیٰ ہیں، ان سب کو ہم بچا لیں گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdccclxii{سوائے اُس کی بیوی کے جس کے لیے (اللہ فرماتا ہے کہ) ہم نے مقدر کر دیا ہے کہ وہ پیچھے رہ جانے والوں میں شامل رہے گی"\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdccclxiii{پھر جب یہ فرستادے لوطؑ کے ہاں پہنچے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdccclxiv{تو اُس نے کہا ``آپ لوگ اجنبی معلوم ہوتے ہیں"\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdccclxv{اُنہوں نے جواب دیا ``نہیں، بلکہ ہم وہی چیز لے کر آئے ہیں جس کے آنے میں یہ لوگ شک کر رہے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdccclxvi{ہم تم سے سچ کہتے ہیں کہ ہم حق کے ساتھ تمہارے پاس آئے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdccclxvii{لہٰذا اب تم کچھ رات رہے اپنے گھر والوں کو لے کر نکل جاؤ اور خود ان کے پیچھے پیچھے چلو تم میں سے کوئی پلٹ کر نہ دیکھے بس سیدھے چلے جاؤ جدھر جانے کا تمہیں حکم دیا جا رہا ہے"\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdccclxviii{اور اُسے ہم نے اپنا یہ فیصلہ پہنچا دیا کہ صبح ہوتے ہوتے اِن لوگوں کی جڑ کاٹ دی جائے گی\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdccclxix{اتنے میں شہر کے لوگ خوشی کے مارے بے تاب ہو کر لوطؑ کے گھر چڑھ آئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdccclxx{لوطؑ نے کہا ``بھائیو، یہ میرے مہمان ہیں، میری فضیحت نہ کرو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdccclxxi{اللہ سے ڈرو، مجھے رسوا نہ کرو"\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdccclxxii{وہ بولے ``کیا ہم بارہا تمہیں منع نہیں کر چکے ہیں کہ دنیا بھر کے ٹھیکے دار نہ بنو؟"\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiii{لوطؑ نے عاجز ہو کر کہا ``اگر تمہیں کچھ کرنا ہی ہے تو یہ میری بیٹیاں موجود ہیں!"\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiv{تیری جان کی قسم اے نبیؐ، اُس وقت اُن پر ایک نشہ سا چڑھا ہوا تھا جس میں وہ آپے سے باہر ہوئے جاتے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdccclxxv{آخرکار پو پھٹتے ہی اُن کو ایک زبردست دھماکے نے آ لیا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvi{اور ہم نے اُس بستی کو تل پٹ کر کے رکھ دیا اور ان پر پکی ہوئی مٹی کے پتھروں کی بارش برسا دی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvii{اِس واقعے میں بڑی نشانیاں ہیں اُن لوگوں کے لیے جو صاحب فراست ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdccclxxviii{اور وہ علاقہ (جہاں یہ واقعہ پیش آیا تھا) گزرگاہ عام پر واقع ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdccclxxix{اُس میں سامان عبرت ہے اُن لوگوں کے لیے جو صاحب ایمان ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdccclxxx{اور ایکہ والے ظالم تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxi{تو دیکھ لو کہ ہم نے بھی اُن سے انتقام لیا، اور اِن دونوں قوموں کے اجڑے ہوئے علاقے کھلے راستے پر واقع ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxii{حجر کے لوگ بھی رسولوں کی تکذیب کر چکے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiii{ہم نے اپنی آیات اُن کے پاس بھیجیں، اپنی نشانیاں اُن کو دکھائیں، مگر وہ سب کو نظر انداز ہی کرتے رہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiv{وہ پہاڑ تراش تراش کر مکان بناتے تھے اور اپنی جگہ بالکل بے خوف اور مطمئن تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxv{آخرکار ایک زبردست دھماکے نے اُن کو صبح ہوتے آ لیا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvi{اور اُن کی کمائی اُن کے کچھ کام نہ آئی\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvii{ہم نے زمین اور آسمان کو اور ان کی سب موجودات کو حق کے سوا کسی اور بنیاد پر خلق نہیں کیا ہے، اور فیصلے کی گھڑی یقیناً آنے والی ہے، پس اے محمدؐ، تم (اِن لوگوں کی بیہودگیوں پر) شریفانہ درگزر سے کام لو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxviii{یقیناً تمہارا رب سب کا خالق ہے اور سب کچھ جانتا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxix{ہم نے تم کو سات ایسی آیتیں دے رکھی ہیں جو بار بار دہرائی جانے کے لائق ہیں، اور تمہیں قرآن عظیم عطا کیا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdcccxc{تم اُس متاع دنیا کی طرف آنکھ اٹھا کر نہ دیکھو جو ہم نے اِن میں سے مختلف قسم کے لوگوں کو دے رکھی ہے، اور نہ اِن کے حال پر اپنا دل کڑھاؤ انہیں چھوڑ کر ایمان لانے والوں کی طرف جھکو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdcccxci{اور (نہ ماننے والوں سے) کہہ دو کہ میں تو صاف صاف تنبیہ کرنے والا ہوں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdcccxcii{یہ اُسی کی طرح کی تنبیہ ہے جیسی ہم نے اُن تفرقہ پردازوں کی طرف بھیجی تھی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdcccxciii{جنہوں نے اپنے قرآن کو ٹکڑے ٹکڑے کر ڈالا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdcccxciv{تو قسم ہے تیرے رب کی، ہم ضرور ان سب سے پوچھیں گے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdcccxcv{کہ تم کیا کرتے رہے ہو\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvi{پس اے نبیؐ، جس چیز کا تمہیں حکم دیا جا رہا ہے، اُسے ہانکے پکارے کہہ دو اور شرک کرنے والوں کی ذرا پروا نہ کرو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvii{تمہاری طرف سے ہم اُن مذاق اڑانے والوں کی خبر لینے کے لیے کافی ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcccxcviii{جو اللہ کے ساتھ کسی اور کو بھی خدا قرار دیتے ہیں عنقریب انہیں معلوم ہو جائے گا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcccxcix{ہمیں معلوم ہے کہ جو باتیں یہ لوگ تم پر بناتے ہیں ان سے تمہارے دل کو سخت کوفت ہوتی ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcm{اس کا علاج یہ ہے کہ اپنے رب کی حمد کے ساتھ اس کی تسبیح کرو، اس کی جناب میں سجدہ بجا لاؤ\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcmi{اور اُس آخری گھڑی تک اپنے رب کی بندگی کرتے رہو جس کا آنا یقینی ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcmii{\basmalahur آ گیا اللہ کا فیصلہ، اب اس کے لیے جلدی نہ مچاؤ پاک ہے وہ اور بالا تر ہے اُس شرک سے جو یہ لوگ کر رہے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcmiii{وہ اِس روح کو اپنے جس بندے پر چاہتا ہے اپنے حکم سے ملائکہ کے ذریعے نازل فرما دیتا ہے (اِس ہدایت کے ساتھ کہ لوگوں کو) ``آگاہ کر دو، میرے سوا کوئی تمہارا معبود نہیں ہے، لہٰذا تم مجھی سے ڈرو"\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcmiv{اُس نے آسمان و زمین کو برحق پیدا کیا ہے، وہ بہت بالا و برتر ہے اُس شرک سے جو یہ لوگ کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcmv{اُس نے انسان کو ایک ذرا سی بوند سے پیدا کیا اور دیکھتے دیکھتے صریحاً وہ ایک جھگڑالو ہستی بن گیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcmvi{اس نے جانور پیدا کیے جن میں تمہارے لیے پوشاک بھی ہے اور خوراک بھی، اور طرح طرح کے دوسرے فائدے بھی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcmvii{اُن میں تمہارے لیے جمال ہے جب کہ صبح تم انہیں چرنے کے لیے بھیجتے ہو اور جبکہ شام انہیں واپس لاتے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcmviii{وہ تمہارے لیے بوجھ ڈھو کر ایسے ایسے مقامات تک لے جاتے ہیں جہاں تم سخت جانفشانی کے بغیر نہیں پہنچ سکتے حقیقت یہ ہے کہ تمہارا رب بڑا ہی شفیق اور مہربان ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcmix{اُس نے گھوڑے اور خچر اور گدھے پیدا کیے تاکہ تم ان پر سوار ہو اور وہ تمہاری زندگی کی رونق بنیں وہ اور بہت سی چیزیں (تمہارے فائدے کے لیے) پیدا کرتا ہے جن کا تمہیں علم تک نہیں ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcmx{اور اللہ ہی کے ذمہ ہے سیدھا راستہ بتانا جب کہ راستے ٹیڑھے بھی موجود ہیں اگر وہ چاہتا تو تم سب کو ہدایت دے دیتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcmxi{وہی ہے جس نے آسمان سے تمہارے لیے پانی برسایا جس سے تم خود بھی سیراب ہوتے ہو اور تمہارے جانوروں کے لیے بھی چارہ پیدا ہوتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcmxii{وہ اس پانی کے ذریعہ سے کھیتیاں اگاتا ہے اور زیتون اور کھجور اور انگور اور طرح طرح کے دوسرے پھل پیدا کرتا ہے اِس میں ایک بڑی نشانی ہے اُن لوگوں کے لیے جو غور و فکر کرتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcmxiii{اُس نے تمہاری بھلائی کے لیے رات اور دن کو اور سورج اور چاند کو مسخر کر رکھا ہے اور سب تارے بھی اُسی کے حکم سے مسخر ہیں اِس میں بہت سی نشانیاں ہیں اُن لوگوں کے لیے جو عقل سے کام لیتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcmxiv{اور یہ جو بہت سی رنگ برنگ کی چیزیں اس نے تمہارے لیے زمین میں پیدا کر رکھی ہیں، اِن میں بھی ضرور نشانی ہے اُن لوگوں کے لیے جو سبق حاصل کرنے والے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcmxv{وہی ہے جس نے تمہارے لیے سمندر کو مسخر کر رکھا ہے تاکہ تم اس سے ترو تازہ گوشت لے کر کھاؤ اور اس سے زینت کی وہ چیزیں نکالو جنہیں تم پہنا کرتے ہو تم دیکھتے ہو کہ کشتی سمندر کا سینہ چیرتی ہوئی چلتی ہے یہ سب کچھ اس لیے ہے کہ تم اپنے رب کا فضل تلاش کرو اور اس کے شکر گزار بنو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcmxvi{اُس نے زمین میں پہاڑوں کی میخیں گاڑ دیں تاکہ زمین تم کو لے کر ڈھلک نہ جائے اس نے د ریا جاری کیے اور قدرتی راستے بنائے تاکہ تم ہدایت پاؤ\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcmxvii{اس نے زمین میں راستہ بتانے والی علامتیں رکھ دیں، اور تاروں سے بھی لوگ ہدایت پاتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcmxviii{پھر کیا وہ جو پیدا کرتا ہے اور وہ جو کچھ بھی پیدا نہیں کرتے، دونوں یکساں ہیں؟ کیا تم ہوش میں نہیں آتے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcmxix{اگر تم اللہ کی نعمتوں کو گننا چاہو تو گن نہیں سکتے، حقیقت یہ ہے کہ وہ بڑا ہی درگزر کرنے والا اور رحیم ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcmxx{حالانکہ وہ تمہارے کھلے سے بھی واقف ہے اور چھپے سے بھی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcmxxi{اور وہ دوسری ہستیاں جنہیں اللہ کو چھوڑ کر لوگ پکارتے ہیں، وہ کسی چیز کی بھی خالق نہیں ہیں بلکہ خود مخلوق ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcmxxii{مردہ ہیں نہ کہ زندہ اور ان کو کچھ معلوم نہیں ہے کہ انہیں کب (دوبارہ زندہ کر کے) اٹھایا جائے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcmxxiii{تمہارا خدا بس ایک ہی خدا ہے مگر جو لوگ آخرت کو نہیں مانتے اُن کے دلوں میں انکار بس کر رہ گیا ہے اور وہ گھمنڈ میں پڑ گئے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcmxxiv{اللہ یقیناً اِن کے سب کرتوت جانتا ہے چھپے ہوئے بھی اور کھلے ہوئے بھی وہ اُن لوگوں کو ہرگز پسند نہیں کرتا جو غرور نفس میں مبتلا ہوں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcmxxv{اور جب کوئی ان سے پوچھتا ہے کہ تمہارے رب نے یہ کیا چیز نازل کی ہے، تو کہتے ہیں ``اجی وہ تو اگلے وقتوں کی فرسودہ کہانیاں ہیں"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcmxxvi{یہ باتیں وہ اس لیے کرتے ہیں کہ قیامت کے روز اپنے بوجھ بھی پورے اٹھائیں، اور ساتھ ساتھ کچھ اُن لوگوں کے بوجھ بھی سمیٹیں جنہیں یہ بر بنائے جہالت گمراہ کر رہے ہیں دیکھو! کیسی سخت ذمہ داری ہے جو یہ اپنے سر لے رہے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcmxxvii{اِن سے پہلے بھی بہت سے لوگ (حق کو نیچا دکھانے کے لیے) ایسی ہی مکاریاں کر چکے ہیں، تو دیکھ لو کہ اللہ نے اُن کے مکر کی عمارت جڑ سے اکھاڑ پھینکی اور اس کی چھت اوپر سے ان کے سر پر آ رہی اور ایسے رخ سے ان پر عذاب آیا جدھر سے اس کے آنے کا اُن کو گمان تک نہ تھا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcmxxviii{پھر قیامت کے روز اللہ اُنہیں ذلیل و خوار کرے گا اور اُن سے کہے گا ``بتاؤ اب کہاں ہیں میرے وہ شریک جن کے لیے تم (اہل حق سے) جھگڑے کیا کرتے تھے؟" جن لوگوں کو دنیا میں علم حاصل تھا وہ کہیں گے ``آج رسوائی اور بدبختی ہے کافروں کے لیے"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcmxxix{ہاں، اُنہی کافروں کے لیے جو اپنے نفس پر ظلم کرتے ہوئے جب ملائکہ کے ہاتھوں گرفتار ہوتے ہیں تو (سرکشی چھوڑ کر) فوراً ڈگیں ڈال دیتے ہیں اور کہتے ہیں ``ہم تو کوئی قصور نہیں کر رہے تھے" ملائکہ جواب دیتے ہیں ``کر کیسے نہیں رہے تھے! اللہ تمہارے کرتوتوں سے خوب واقف ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcmxxx{اب جاؤ، جہنم کے دروازوں میں گھس جاؤ وہیں تم کو ہمیشہ رہنا ہے" پس حقیقت یہ ہے کہ بڑا ہی برا ٹھکانہ ہے متکبروں کے لیے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcmxxxi{دوسری طرف جب خدا ترس لوگوں سے پوچھا جاتا ہے کہ یہ کیا چیز ہے جو تمہارے رب کی طرف سے نازل ہوئی ہے، تو وہ جواب دیتے ہیں کہ ``بہترین چیز اتری ہے" اِس طرح کے نیکوکار لوگوں کے لیے اِس دنیا میں بھی بھلائی ہے اور آخرت کا گھر تو ضرور ہی ان کے حق میں بہتر ہے بڑا اچھا گھر ہے متقیوں کا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcmxxxii{دائمی قیام کی جنتیں، جن میں وہ داخل ہوں گے، نیچے نہریں بہہ رہی ہونگی، اور سب کچھ وہاں عین اُن کی خواہش کے مطابق ہوگا یہ جزا دیتا ہے اللہ متقیوں کو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiii{اُن متقیوں کو جن کی روحیں پاکیزگی کی حالت میں جب ملائکہ قبض کرتے ہیں تو کہتے ہیں ``سلام ہو تم پر، جاؤ جنت میں اپنے اعمال کے بدلے"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiv{اے محمدؐ، اب جو یہ لوگ انتظار کر رہے ہیں تو اِس کے سوا اب اور کیا باقی رہ گیا ہے کہ ملائکہ ہی آ پہنچیں، یا تیرے رب کا فیصلہ صادر ہو جائے؟ اِس طرح کی ڈھٹائی اِن سے پہلے بہت سے لوگ کر چکے ہیں پھر جو کچھ اُن کے ساتھ ہوا وہ اُن پر اللہ کا ظلم نہ تھا بلکہ اُن کا اپنا ظلم تھا جو اُنہوں نے خود اپنے اوپر کیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcmxxxv{اُن کے کرتوتوں کی خرابیاں آخر اُن کی دامنگیر ہو گئیں اور وہی چیز اُن پر مسلط ہو کر رہی جس کا وہ مذاق اڑایا کرتے تھے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvi{یہ مشرکین کہتے ہیں ``اگر اللہ چاہتا تو نہ ہم اور نہ ہمارے باپ دادا اُس کے سوا کسی اور کی عبادت کرتے اور نہ اُس کے حکم کے بغیر کسی چیز کو حرام ٹھیراتے" ایسے ہی بہانے اِن سے پہلے کے لوگ بھی بناتے رہے ہیں تو کیا رسولوں پر صاف صاف بات پہنچا دینے کے سوا اور بھی کوئی ذمہ داری ہے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvii{ہم نے ہر امت میں ایک رسول بھیج دیا، اور اُس کے ذریعہ سے سب کو خبردار کر دیا کہ ``اللہ کی بندگی کرو اور طاغوت کی بندگی سے بچو" اس کے بعد ان میں سے کسی کو اللہ نے ہدایت بخشی اور کسی پر ضلالت مسلط ہو گئی پھر ذرا زمین میں چل پھر کر دیکھ لو کہ جھٹلانے والوں کا کیا انجام ہو چکا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcmxxxviii{اے محمدؐ، تم چاہے اِن کی ہدایت کے لیے کتنے ہی حریص ہو، مگر اللہ جس کو بھٹکا دیتا ہے پھر اسے ہدایت نہیں دیا کرتا اور اس طرح کے لوگوں کی مدد کوئی نہیں کر سکتا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcmxxxix{یہ لوگ اللہ کے نام سے کڑی کڑی قسمیں کھا کر کہتے ہیں کہ ``اللہ کسی مرنے والے کو پھر سے زندہ کر کے نہ اٹھائے گا" اٹھائے گا کیوں نہیں، یہ تو ایک وعدہ ہے جسے پورا کرنا اس نے اپنے اوپر واجب کر لیا ہے، مگر اکثر لوگ جانتے نہیں ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcmxl{اور ایسا ہونا اس لیے ضروری ہے کہ اللہ اِن کے سامنے اُس حقیقت کو کھول دے جس کے بارے میں یہ اختلاف کر رہے ہیں اور منکرین حق کو معلوم ہو جائے کہ وہ جھوٹے تھے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcmxli{(رہا اس کا امکان تو) ہمیں کسی چیز کو وجود میں لانے کے لیے اس سے زیادہ کچھ کرنا نہیں ہوتا کہ اسے حکم دیں ``ہو جا" اور بس وہ ہو جاتی ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcmxlii{جو لوگ ظلم سہنے کے بعد اللہ کی خاطر ہجرت کر گئے ہیں ان کو ہم دنیا ہی میں اچھا ٹھکانا دیں گے اور آخرت کا اجر تو بہت بڑا ہے کاش جان لیں وہ مظلوم\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcmxliii{جنہوں نے صبر کیا ہے اور جو اپنے رب کے بھروسے پر کام کر رہے ہیں (کہ کیسا اچھا انجام اُن کا منتظر ہے)\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcmxliv{اے محمدؐ، ہم نے تم سے پہلے بھی جب کبھی رسول بھیجے ہیں آدمی ہی بھیجے ہیں جن کی طرف ہم اپنے پیغامات وحی کیا کرتے تھے اہل ذکر سے پوچھ لو اگر تم لوگ خود نہیں جانتے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcmxlv{پچھلے رسولوں کو بھی ہم نے روشن نشانیاں اور کتابیں دے کر بھیجا تھا، اور اب یہ ذکر تم پر نازل کیا ہے تاکہ تم لوگوں کے سامنے اُس تعلیم کی تشریح و توضیح کرتے جاؤ جو اُن کے لیے اتاری گئی ہے، اور تاکہ لوگ (خود بھی) غور و فکر کریں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcmxlvi{پھر کیا وہ لوگ جو (دعوت پیغمبر کی مخالفت میں) بدتر سے بدتر چالیں چل رہے ہیں اِس بات سے بالکل ہی بے خوف ہو گئے ہیں کہ اللہ ان کو زمین میں دھنسا دے، یا ایسے گوشے میں ان پر عذاب لے آئے جدھر سے اس کے آنے کا ان کو وہم و گمان تک نہ ہو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcmxlvii{یا اچانک چلتے پھرتے ان کو پکڑ لے، یا ایسی حالت میں انہیں پکڑے جبکہ انہیں خود آنے والی مصیبت کا کھٹکا لگا ہوا ہو اور وہ اس سے بچنے کی فکر میں چوکنے ہوں؟\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcmxlviii{وہ جو کچھ بھی کرنا چاہے یہ لوگ اس کو عاجز کرنے کی طاقت نہیں رکھتے حقیقت یہ ہے کہ تمہارا رب بڑا ہی نرم خو اور رحیم ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcmxlix{اور کیا یہ لوگ اللہ کی پیدا کی ہوئی کسی چیز کو بھی نہیں دیکھتے کہ اس کا سایہ کس طرح اللہ کے حضور سجدہ کرتے ہوئے دائیں اور بائیں گرتا ہے؟ سب کے سب اِس طرح اظہار عجز کر رہے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcml{زمین اور آسمانوں میں جس قدر جان دار مخلوقات ہیں اور جتنے ملائکہ ہیں سب اللہ کے آگے سر بسجود ہیں وہ ہرگز سرکشی نہیں کرتے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcmli{اپنے رب سے جو اُن کے اوپر ہے، ڈرتے ہیں اور جو کچھ حکم دیا جاتا ہے اسی کے مطابق کام کرتے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcmlii{اللہ کا فرمان ہے کہ ``دو خدا نہ بنا لو، خدا تو بس ایک ہی ہے، لہٰذا تم مجھی سے ڈرو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcmliii{اُسی کا ہے وہ سب کچھ جو آسمانوں میں ہے اور جو زمین میں ہے، اور خالصاً اُسی کا دین (ساری کائنات میں) چل رہا ہے پھر کیا اللہ کو چھوڑ کر تم کسی اور سے تقویٰ کرو گے؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcmliv{تم کو جو نعمت بھی حاصل ہے اللہ ہی کی طرف سے ہے پھر جب کوئی سخت وقت تم پر آتا ہے تو تم لوگ خود اپنی فریادیں لے کر اُسی کی طرف دوڑتے ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcmlv{مگر جب اللہ اس وقت کو ٹال دیتا ہے تو یکا یک تم میں سے ایک گروہ اپنے رب کے ساتھ دوسروں کو (اس مہربانی کے شکریے میں) شریک کرنے لگتا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcmlvi{تاکہ اللہ کے احسان کی ناشکری کرے اچھا، مزے کر لو، عنقریب تمہیں معلوم ہو جائے گا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcmlvii{یہ لوگ جن کی حقیقت سے واقف نہیں ہیں اُن کے حصے ہمارے دیے ہوئے رزق میں سے مقرر کرتے ہیں خدا کی قسم، ضرور تم سے پوچھا جائے گا کہ یہ جھوٹ تم نے کیسے گھڑ لیے تھے؟\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcmlviii{یہ خدا کے لیے بیٹیاں تجویز کرتے ہیں سبحان اللہ! اور اِن کے لیے وہ جو یہ خود چاہیں؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcmlix{جب اِن میں سے کسی کو بیٹی کے پیدا ہونے کی خوش خبری دی جاتی ہے تو اُس کے چہرے پر کلونس چھا جاتی ہے اور وہ بس خون کا سا گھونٹ پی کر رہ جاتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcmlx{لوگوں سے چھپتا پھرتا ہے کہ اِس بری خبر کے بعد کیا کسی کو منہ دکھائے سوچتا ہے کہ ذلت کے ساتھ بیٹی کو لیے رہے یا مٹی میں دبا دے؟ دیکھو کیسے برے حکم ہیں جو یہ خدا کے بارے میں لگاتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcmlxi{بری صفات سے متصف کیے جانے کے لائق تو وہ لوگ ہیں جو آخرت کا یقین نہیں رکھتے رہا اللہ، تو اُس کے لیے سب سے برتر صفات ہیں، وہی تو سب پر غالب اور حکمت میں کامل ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcmlxii{اگر کہیں اللہ لوگوں کو اُن کی زیادتی پر فوراً ہی پکڑ لیا کر تا تو روئے زمین پر کسی متنفس کو نہ چھوڑتا لیکن وہ سب کو ایک وقت مقرر تک مہلت دیتا ہے، پھر جب وہ وقت آ جاتا ہے تو اس سے کوئی ایک گھڑی بھر بھی آگے پیچھے نہیں ہو سکتا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcmlxiii{آج یہ لوگ وہ چیزیں اللہ کے لیے تجویز کر رہے ہیں جو خود اپنے لیے اِنہیں ناپسند ہیں، اور جھوٹ کہتی ہیں اِن کی زبانیں کہ اِن کے لیے بھلا ہی بھلا ہے اِن کے لیے تو ایک ہی چیز ہے، اور وہ ہے دوزخ کی آگ ضرور یہ سب سے پہلے اُس میں پہنچائے جائیں گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcmlxiv{خدا کی قسم، اے محمدؐ، تم سے پہلے بھی بہت سی قوموں میں ہم رسول بھیج چکے ہیں (اور پہلے بھی یہی ہوتا رہا ہے کہ) شیطان نے اُن کے برے کرتوت اُنہیں خوشنما بنا کر دکھائے (اور رسولوں کی بات انہوں نے مان کر نہ دی) وہی شیطان آج اِن لوگوں کا بھی سرپرست بنا ہوا ہے اور یہ دردناک سزا کے مستحق بن رہے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcmlxv{ہم نے یہ کتاب تم پر اس لیے نازل کی ہے کہ تم اُن اختلافات کی حقیقت اِن پر کھول دو جن میں یہ پڑے ہوئے ہیں یہ کتاب رہنمائی اور رحمت بن کر اتری ہے اُن لوگوں کے لیے جو اِسے مان لیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcmlxvi{(تم ہر برسات میں دیکھتے ہو کہ) اللہ نے آسمان سے پانی برسایا اور یکا یک مردہ پڑی ہوئی زمین میں اُس کی بدولت جان ڈال دی یقیناً اس میں ایک نشانی ہے سننے والوں کے لیے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcmlxvii{اور تمہارے لیے مویشیوں میں بھی ایک سبق موجود ہے اُن کے پیٹ سے گوبر اور خون کے درمیان ہم ایک چیز تمہیں پلاتے ہیں، یعنی خالص دودھ، جو پینے والوں کے لیے نہایت خو ش گوار ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcmlxviii{(اسی طرح) کھجور کے درختوں اور انگور کی بیلوں سے بھی ہم ایک چیز تمہیں پلاتے ہیں جسے تم نشہ آور بھی بنا لیتے ہو اور پاک رزق بھی یقیناً اس میں ایک نشانی ہے عقل سے کام لینے والوں کے لیے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcmlxix{اور دیکھو، تمہارے رب نے شہد کی مکھی پر یہ بات وحی کر دی کہ پہاڑوں میں، اور درختوں میں، اور ٹٹیوں پر چڑھائی ہوئی بیلوں میں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcmlxx{اپنے چھتے بنا اور ہر طرح کے پھلوں کا رس چوس اور اپنے رب کی ہموار کی ہوئی راہوں پر چلتی رہ اِس مکھی کے اندر سے رنگ برنگ کا ایک شربت نکلتا ہے جس میں شفا ہے لوگوں کے لیے یقیناً اس میں بھی ایک نشانی ہے اُن لوگوں کے لیے جو غور و فکر کرتے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcmlxxi{اور دیکھو، اللہ نے تم کو پیدا کیا، پھر وہ تم کو موت دیتا ہے، اور تم میں سے کوئی بد ترین عمر کو پہنچا دیا جاتا ہے تاکہ سب کچھ جاننے کے بعد پھر کچھ نہ جانے حق یہ ہے کہ اللہ ہی علم میں بھی کامل ہے اور قدرت میں بھی\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcmlxxii{اور دیکھو، اللہ نے تم میں سے بعض کو بعض پر رزق میں فضیلت عطا کی ہے پھر جن لوگوں کو یہ فضیلت دی گئی ہے وہ ایسے نہیں ہیں کہ اپنا رزق اپنے غلاموں کی طرف پھیر دیا کرتے ہوں تاکہ دونوں اس رزق میں برابر کے حصہ دار بن جائیں تو کیا اللہ ہی کا احسان ماننے سے اِن لوگوں کو انکار ہے؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiii{اور وہ اللہ ہی ہے جس نے تمہارے لیے تمہاری ہم جنس بیویاں بنائیں اور اسی نے ان بیویوں سے تمہیں بیٹے پوتے عطا کیے اور اچھی اچھی چیزیں تمہیں کھانے کو دیں پھر کیا یہ لوگ (یہ سب کچھ دیکھتے اور جانتے ہوئے بھی) باطل کو مانتے ہیں اور اللہ کے احسان کا انکار کرتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiv{اور اللہ کو چھوڑ کر اُن کو پوجتے ہیں جن کے ہاتھ میں نہ آسمانوں سے انہیں کچھ بھی رزق دینا ہے نہ زمین سے اور نہ یہ کام وہ کر ہی سکتے ہیں؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcmlxxv{پس اللہ کے لیے مثالیں نہ گھڑو، اللہ جانتا ہے، تم نہیں جانتے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvi{اللہ ایک مثال دیتا ہے ایک تو ہے غلام، جو دوسرے کا مملوک ہے اور خود کوئی اختیار نہیں رکھتا دوسرا شخص ایسا ہے جسے ہم نے اپنی طرف سے اچھا رزق عطا کیا ہے اور وہ اس میں سے کھلے اور چھپے خوب خرچ کرتا ہے بتاؤ، کیا یہ دونوں برابر ہیں؟ الحمدللہ، مگر اکثر لوگ (اس سیدھی بات کو) نہیں جانتے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvii{اللہ ایک اور مثال دیتا ہے دو آدمی ہیں ایک گونگا بہرا ہے، کوئی کام نہیں کر سکتا، اپنے آقا پر بوجھ بنا ہوا ہے، جدھر بھی وہ اسے بھیجے کوئی بھلا کام اُس سے بن نہ آئے دوسرا شخص ایسا ہے کہ انصاف کا حکم دیتا ہے اور خود راہ راست پر قائم ہے بتاؤ کیا یہ دونوں یکساں ہیں؟\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcmlxxviii{اور زمین و آسمان کے پوشیدہ حقائق کا علم تو اللہ ہی کو ہے اور قیامت کے برپا ہونے کا معاملہ کچھ دیر نہ لے گا مگر بس اتنی کہ جس میں آدمی کی پلک جھپک جائے، بلکہ اس سے بھی کچھ کم حقیقت یہ ہے کہ اللہ سب کچھ کر سکتا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcmlxxix{اللہ نے تم کو تمہاری ماؤں کے پیٹوں سے نکالا اس حالت میں کہ تم کچھ نہ جانتے تھے اُس نے تمہیں کان دیے، آنکھیں دیں، اور سوچنے والے دل دیے، اس لیے کہ تم شکر گزار بنو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcmlxxx{کیا اِن لوگوں نے کبھی پرندوں کو نہیں دیکھا کہ فضائے آسمانی میں کسی طرح مسخر ہیں؟ اللہ کے سوا کس نے اِن کو تھام رکھا ہے؟ اِس میں بہت نشانیاں ہیں اُن لوگوں کے لیے جو ایمان لاتے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxi{اللہ نے تمہارے لیے تمہارے گھروں کو جائے سکون بنایا اس نے جانوروں کی کھالوں سے تمہارے لیے ایسے مکان پیدا کیے جنہیں تم سفر اور قیام، دونوں حالتوں میں ہلکا پاتے ہو اُس نے جانوروں کے صوف اور اون اور بالوں سے تمہارے لیے پہننے اور برتنے کی بہت سی چیزیں پیدا کر دیں جو زندگی کی مدت مقررہ تک تمہارے کام آتی ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxii{اس نے اپنی پیدا کی ہوئی بہت سی چیزوں سے تمہارے لیے سائے کا انتظام کیا، پہاڑوں میں تمہارے لیے پناہ گاہیں بنائیں، اور تمہیں ایسی پوشاکیں بخشیں جو تمہیں گرمی سے بچاتی ہیں اور کچھ دوسری پوشاکیں جو آپس کی جنگ میں تمہاری حفاظت کرتی ہیں اس طرح وہ تم پر اپنی نعمتوں کی تکمیل کرتا ہے شاید کہ تم فرماں بردار بنو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiii{اب اگر یہ لوگ منہ موڑتے ہیں تو اے محمدؐ، تم پر صاف صاف پیغام حق پہنچا دینے کے سوا اور کوئی ذمہ داری نہیں ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiv{یہ اللہ کے احسان کو پہچانتے ہیں، پھر اس کا انکار کرتے ہیں اور اِن میں بیش تر لوگ ایسے ہیں جو حق ماننے کے لیے تیار نہیں ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxv{(اِنہیں کچھ ہوش بھی ہے کہ اُس روز کیا بنے گی) جبکہ ہم ہر امت میں سے ایک گواہ کھڑا کریں گے، پھر کافروں کو نہ حجتیں پیش کرنے کا موقع دیا جائیگا نہ ان سے توبہ و استغفار ہی کا مطالبہ کیا جائے گا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvi{ظالم لوگ جب ایک دفعہ عذاب دیکھ لیں گے تو اس کے بعد نہ اُن کے عذاب میں کوئی تخفیف کی جائے گی اور نہ انہیں ایک لمحہ بھر کی مہلت دی جائے گی\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvii{اور جب وہ لوگ جنہوں نے دنیا میں شرک کیا تھا اپنے ٹھیرائے ہوئے شریکوں کو دیکھیں گے تو کہیں گے ``اے پروردگار، یہی ہیں ہمارے وہ شریک جنہیں ہم تجھے چھوڑ کر پکارا کرتے تھے" اس پر اُن کے وہ معبود انہیں صاف جواب دیں گے کہ ``تم جھوٹے ہو"\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxviii{اُس وقت یہ سب اللہ کے آگے جھک جائیں گے اور ان کی وہ ساری افترا پردازیاں رفو چکر ہو جائیں گی جو یہ دنیا میں کرتے رہے تھے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxix{جن لوگوں نے خود کفر کی راہ اختیار کی اور دوسروں کو اللہ کی راہ سے روکا انہیں ہم عذاب پر عذاب دیں گے اُس فساد کے بدلے جو وہ دنیا میں برپا کرتے رہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcmxc{(اے محمدؐ، اِنہیں اُس دن سے خبردار کر دو) جب کہ ہم ہر امت میں خود اُسی کے اندر سے ایک گواہ اٹھا کھڑا کریں گے جو اُس کے مقابلے میں شہادت دے گا، اور اِن لوگوں کے مقابلے میں شہادت دینے کے لیے ہم تمہیں لائیں گے اور (یہ اسی شہادت کی تیاری ہے کہ) ہم نے یہ کتاب تم پر نازل کر دی ہے جو ہر چیز کی صاف صاف وضاحت کرنے والی ہے اور ہدایت و رحمت اور بشارت ہے اُن لوگوں کے لیے جنہوں نے سر تسلیم خم کر دیا ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcmxci{اللہ عدل اور احسان اور صلہ رحمی کا حکم دیتا ہے اور بدی و بے حیائی اور ظلم و زیادتی سے منع کرتا ہے وہ تمہیں نصیحت کرتا ہے تاکہ تم سبق لو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcmxcii{اللہ کے عہد کو پورا کرو جبکہ تم نے اس سے کوئی عہد باندھا ہو، اور اپنی قسمیں پختہ کرنے کے بعد توڑ نہ ڈالو جبکہ تم اللہ کو اپنے اوپر گواہ بنا چکے ہو اللہ تمہارے سب افعال سے باخبر ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcmxciii{تمہاری حالت اُس عورت کی سی نہ ہو جائے جس نے آپ ہی محنت سے سوت کاتا اور پھر آپ ہی اسے ٹکڑے ٹکڑے کر ڈالا تم اپنی قسموں کو آپس کے معاملات میں مکر و فریب کا ہتھیار بناتے ہو تاکہ ایک قوم دوسری قوم سے بڑھ کر فائدے حاصل کرے حالاں کہ اللہ اس عہد و پیمان کے ذریعہ سے تم کو آزمائش میں ڈالتا ہے، اور ضرور وہ قیامت کے روز تمہارے تمام اختلافات کی حقیقت تم پر کھول دے گا\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcmxciv{اگر اللہ کی مشیت یہ ہوتی (کہ تم میں کوئی اختلاف نہ ہو) تو وہ تم سب کو ایک ہی امت بنا دیتا، مگر وہ جسے چاہتا ہے گمراہی میں ڈالتا ہے اور جسے چاہتا ہے راہ راست دکھا دیتا ہے، اور ضرور تم سے تمہارے اعمال کی باز پرس ہو کر رہے گی\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcmxcv{(اور اے مسلمانو،) تم اپنی قسموں کو آپس میں ایک دوسرے کو دھوکہ دینے کا ذریعہ نہ بنا لینا، کہیں ایسا نہ ہو کہ کوئی قدم جمنے کے بعد اکھڑ جائے اور تم اِس جرم کی پاداش میں کہ تم نے لوگوں کو اللہ کی راہ سے روکا، برا نتیجہ دیکھو اور سخت سزا بھگتو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcmxcvi{اللہ کے عہد کو تھوڑے سے فائدے کے بدلے نہ بیچ ڈالو، جو کچھ اللہ کے پاس ہے وہ تمہارے لیے زیادہ بہتر ہے اگر تم جانو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcmxcvii{جو کچھ تمہارے پاس ہے وہ خرچ ہو جانے والا ہے اور جو کچھ اللہ کے پاس ہے وہی باقی رہنے والا ہے، اور ہم ضرور صبر سے کام لینے والوں کو اُن کے اجر اُن کے بہترین اعمال کے مطابق دیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcmxcviii{جو شخص بھی نیک عمل کرے گا، خواہ وہ مرد ہو یا عورت، بشر طیکہ ہو وہ مومن، اسے ہم دنیا میں پاکیزہ زندگی بسر کرائیں گے اور (آخرت میں) ایسے لوگوں کو ان کے اجر ان کے بہترین اعمال کے مطابق بخشیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcmxcix{پھر جب تم قرآن پڑھنے لگو تو شیطان رجیم سے خدا کی پناہ مانگ لیا کرو\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mm{اُسے اُن لوگوں پر تسلط حاصل نہیں ہوتا جو ایمان لاتے اور اپنے رب پر بھروسا کرتے ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmi{اس کا زور تو انہی لوگوں پر چلتا ہے جو اس کو اپنا سرپرست بناتے اور اس کے بہکانے سے شرک کرتے ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmii{جب ہم ایک آیت کی جگہ دوسری آیت نازل کرتے ہیں اور اللہ بہتر جانتا ہے کہ وہ کیا نازل کرے تو یہ لوگ کہتے ہیں کہ تم یہ قرآن خو د گھڑ تے ہو اصل بات یہ ہے کہ اِن میں سے اکثر لوگ حقیقت سے ناواقف ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmiii{اِن سے کہو کہ اِسے تو روح القدس نے ٹھیک ٹھیک میرے رب کی طرف سے بتدریج نازل کیا ہے تاکہ ایمان لانے والوں کے ایمان کو پختہ کرے اور فرماں برداروں کو زندگی کے معاملات میں سیدھی راہ بتائے اور اُنہیں فلاح و سعادت کی خوش خبری دے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmiv{ہمیں معلوم ہے یہ لوگ تمہارے متعلق کہتے ہیں کہ اس شخص کو ایک آدمی سکھاتا پڑھاتا ہے حالانکہ ان کا اشارہ جس آدمی کی طرف ہے اس کی زبان عجمی ہے اور یہ صاف عربی زبان ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmv{حقیقت یہ ہے کہ جو لوگ اللہ کی آیات کو نہیں مانتے اللہ کبھی ان کو صحیح بات تک پہنچنے کی توفیق نہیں دیتا اور ایسے لوگوں کے لیے دردناک عذاب ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmvi{(جھوٹی باتیں نیا نہیں گھڑ تا بلکہ) جھوٹ وہ لوگ گھڑ رہے ہیں، جو اللہ کی آیات کو نہیں مانتے، وہی حقیقت میں جھوٹے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmvii{جو شخص ایمان لانے کے بعد کفر کرے (وہ اگر) مجبور کیا گیا ہو اور دل اس کا ایمان پر مطمئن ہو (تب تو خیر) مگر جس نے دل کی رضا مندی سے کفر کو قبول کر لیا اس پر اللہ کا غضب ہے اور ایسے سب لوگوں کے لیے بڑا عذاب ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmviii{یہ اس لیے کہ اُنہوں نے آخرت کے مقابلہ میں دنیا کی زندگی کو پسند کر لیا، اور اللہ کا قاعدہ ہے کہ وہ اُن لوگوں کو راہ نجات نہیں دکھاتا جو اُس کی نعمت کا کفران کریں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmix{یہ وہ لوگ ہیں جن کے دلوں اور کانوں اور آنکھوں پر اللہ نے مہر لگا دی ہے یہ غفلت میں ڈوب چکے ہیں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmx{ضرور ہے کہ آخرت میں یہی خسارے میں رہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmxi{بخلاف اس کے جن لوگوں کا حال یہ ہے کہ جب (ایمان لانے کی وجہ سے) وہ ستائے گئے تو اُنہوں نے گھر بار چھوڑ دیے، ہجرت کی، راہ خدا میں سختیاں جھیلیں اور صبرسے کام لیا، اُن کے لیے یقیناً تیرا رب غفور و رحیم ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmxii{(اِن سب کا فیصلہ اُس دن ہوگا) جب کہ ہر متنفس اپنے ہی بچاؤ کی فکر میں لگا ہوا ہوگا اور ہر ایک کو اس کے کیے کا بدلہ پورا پورا دیا جائے گا اور کسی پر ذرہ برابر ظلم نہ ہونے پائے گا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmxiii{اللہ ایک بستی کی مثال دیتا ہے وہ امن و اطمینان کی زندگی بسر کر رہی تھی اور ہر طرف سے اس کو بفراغت رزق پہنچ رہا تھا کہ اُس نے اللہ کی نعمتوں کا کفران شروع کر دیا تب اللہ نے اس کے باشندوں کو اُن کے کرتوتوں کا یہ مزا چکھایا کہ بھوک اور خوف کی مصیبتیں ان پر چھا گئیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmxiv{اُن کے پاس ان کی اپنی قوم میں سے ایک رسول آیا مگر اُنہوں نے اس کو جھٹلا دیا آخر کار عذاب نے اُن کو آ لیا جبکہ وہ ظالم ہو چکے تھے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmxv{پس اے لوگو، اللہ نے جو کچھ حلال اور پاک رزق تم کو بخشا ہے اُسے کھاؤ اور اللہ کے احسان کا شکر ادا کرو اگر تم واقعی اُسی کی بندگی کرنے والے ہو\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmxvi{اللہ نے جو کچھ تم پر حرام کیا ہے وہ ہے مُردار اور خون اور سور کا گوشت اور وہ جانور جس پر اللہ کے سوا کسی اور کا نام لیا گیا ہو البتہ بھوک سے مجبور ہو کر اگر کوئی اِن چیزوں کو کھا لے، بغیر اس کے کہ وہ قانون الٰہی کی خلاف ورزی کا خواہش مند ہو، یا حد ضرورت سے تجاوز کا مرتکب ہو، تو یقیناً اللہ معاف کرنے اور رحم فرمانے والا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmxvii{اور یہ جو تمہاری زبانیں جھوٹے احکام لگایا کرتی ہیں کہ یہ چیز حلال ہے اور وہ حرام، تو اس طرح کے حکم لگا کر اللہ پر جھوٹ نہ باندھا کرو جو لوگ اللہ پر جھوٹے افترا باندھتے ہیں وہ ہرگز فلاح نہیں پایا کرتے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmxviii{دنیا کا عیش چند روزہ ہے آخرکار اُن کے لیے دردناک سزا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmxix{وہ چیزیں ہم نے خاص طور پر یہودیوں کے لیے حرام کی تھیں جن کا ذکر ہم اس سے پہلے تم سے کر چکے ہیں اور یہ اُن پر ہمارا ظلم نہ تھا بلکہ اُن کا اپنا ہی ظلم تھا جو وہ اپنے اوپر کر رہے تھے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmxx{البتہ جن لوگوں نے جہالت کی بنا پر برا عمل کیا اور پھر توبہ کر کے اپنے عمل کی اصلاح کر لی تو یقیناً توبہ و اصلاح کے بعد تیرا رب اُن کے لیے غفور اور رحیم ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmxxi{واقعہ یہ ہے کہ ابراہیمؑ اپنی ذات سے ایک پوری امت تھا، اللہ کا مطیع فرمان اور یک سو وہ کبھی مشرک نہ تھا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmxxii{اللہ کی نعمتوں کا شکر ادا کرنے والا تھا اللہ نے اس کو منتخب کر لیا اور سیدھا راستہ دکھایا\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmxxiii{دنیا میں اس کو بھلائی دی اور آخرت میں وہ یقیناً صالحین میں سے ہوگا\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmxxiv{پھر ہم نے تمہاری طرف یہ وحی بھیجی کہ یک سو ہو کر ابراہیمؑ کے طریقے پر چلو اور وہ مشرکوں میں سے نہ تھا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmxxv{رہا سبت، تو وہ ہم نے اُن لوگوں پر مسلط کیا تھا جنہوں نے اس کے احکام میں اختلاف کیا، اور یقیناً تیرا رب قیامت کے روز ان سب باتوں کا فیصلہ کر دے گا جن میں وہ اختلاف کرتے رہے ہیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmxxvi{اے نبیؐ، اپنے رب کے راستے کی طرف دعوت دو حکمت اور عمدہ نصیحت کے ساتھ، اور لوگوں سے مباحثہ کرو ایسے طریقہ پر جو بہترین ہو تمہارا رب ہی زیادہ بہتر جانتا ہے کہ کون اس کی راہ سے بھٹکا ہوا ہے اور کون راہ راست پر ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmxxvii{اور اگر تم لوگ بدلہ لو تو بس اسی قدر لے لو جس قدر تم پر زیادتی کی گئی ہو لیکن اگر تم صبر کرو تو یقیناً یہ صبر کرنے والوں ہی کے حق میں بہتر ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmxxviii{اے محمدؐ، صبر سے کام کیے جاؤ اور تمہارا یہ صبر اللہ ہی کی توفیق سے ہے اِن لوگوں کی حرکات پر ر نج نہ کرو اور نہ ان کی چال بازیوں پر دل تنگ ہو\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmxxix{اللہ اُن لوگوں کے ساتھ ہے جو تقویٰ سے کام لیتے ہیں اور احسان پر عمل کرتے ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmxxx{\basmalahur پاک ہے وہ جو لے گیا ایک رات اپنے بندے کو مسجد حرام سے دور کی اُس مسجد تک جس کے ماحول کو اس نے برکت دی ہے، تاکہ اسے اپنی کچھ نشانیوں کا مشاہدہ کرائے حقیقت میں وہی ہے سب کچھ سننے اور دیکھنے والا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmxxxi{ہم نے اِس سے پہلے موسیٰؑ کو کتاب دی تھی اور اُسے بنی اسرائیل کے لیے ذریعہ ہدایت بنایا تھا، اِس تاکید کے ساتھ کہ میرے سوا کسی کو اپنا وکیل نہ بنانا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmxxxii{تم اُن لوگوں کی اولاد ہو جنہیں ہم نے نوحؑ کے ساتھ کشتی پر سوار کیا تھا، اور نوحؑ ایک شکر گزار بندہ تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmxxxiii{پھر ہم نے اپنی کتاب میں بنی اسرائیل کو اِس بات پر بھی متنبہ کر دیا تھا کہ تم دو مرتبہ زمین میں فساد عظیم برپا کرو گے اور بڑی سرکشی دکھاؤ گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmxxxiv{آخرکار جب اُن میں سے پہلی سرکشی کا موقع پیش آیا، تو اے بنی اسرائیل، ہم نے تمہارے مقابلے پر اپنے ایسے بندے اٹھائے جو نہایت زور آور تھے اور وہ تمہارے ملک میں گھس کر ہر طرف پھیل گئے یہ ایک وعدہ تھا جسے پورا ہو کر ہی رہنا تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmxxxv{اِس کے بعد ہم نے تمہیں اُن پر غلبے کا موقع دے دیا اور تمہیں مال اور اولاد سے مدد دی اور تمہاری تعداد پہلے سے بڑھا دی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmxxxvi{دیکھو! تم نے بھلائی کی تو وہ تمہارے اپنے ہی لیے بھلائی تھی، اور برائی کی تو وہ تمہاری اپنی ذات کے لیے برائی ثابت ہوئی پھر جب دوسرے وعدے کا وقت آیا تو ہم نے دوسرے دشمنوں کو تم پر مسلط کیا تاکہ وہ تمہارے چہرے بگاڑ دیں اور مسجد (بیت المقدس) میں اُسی طرح گھس جائیں جس طرح پہلے دشمن گھسے تھے اور جس چیز پر ان کا ہاتھ پڑے اُسے تباہ کر کے رکھ دیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmxxxvii{ہوسکتا ہے کہ اب تمہارا رب تم پر رحم کرے، لیکن اگر تم نے پھر اپنی سابق روش کا اعادہ کیا تو ہم بھی پر اپنی سزا کا اعادہ کریں گے، اور کا فر نعمت لوگوں کے لیے ہم نے جہنم کو قید خانہ بنا رکھا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmxxxviii{حقیقت یہ ہے کہ یہ قرآن وہ راہ دکھاتا ہے جو بالکل سیدھی ہے جو لو گ اسے مان کر بھلے کام کرنے لگیں انہیں یہ بشارت دیتا ہے کہ ان کے لیے بڑا اجر ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmxxxix{اور جو لوگ آخرت کو نہ مانیں انہیں یہ خبر دیتا ہے کہ ان کے لیے ہم نے دردناک عذاب مہیا کر رکھا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmxl{انسان شر اُس طرح مانگتا ہے جس طرح خیر مانگنی چاہیے انسان بڑا ہی جلد باز واقع ہوا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmxli{دیکھو، ہم نے رات اور دن کو دو نشانیاں بنایا ہے رات کی نشانی کو ہم نے بے نور بنایا، اور دن کی نشانی کو روشن کر دیا تاکہ تم اپنے رب کا فضل تلاش کر سکو اور ماہ و سال کا حساب معلوم کر سکو اِسی طرح ہم نے ہر چیز کو الگ الگ ممیز کر کے رکھا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmxlii{ہر انسان کا شگون ہم نے اُس کے اپنے گلے میں لٹکا رکھا ہے، اور قیامت کے روز ہم ایک نوشتہ اُس کے لیے نکالیں گے جسے وہ کھلی کتاب کی طرح پائے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmxliii{پڑھ اپنا نامہ اعمال، آج اپنا حساب لگانے کے لیے تو خود ہی کافی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmxliv{جو کوئی راہ راست اختیار کرے اس کی راست روی اس کے اپنے ہی لیے مفید ہے، اور جو گمراہ ہو اس کی گمراہی کا وبا ل اُسی پر ہے کوئی بوجھ اٹھانے والا دوسرے کا بوجھ نہ اٹھائے گا اور ہم عذاب دینے والے نہیں ہیں جب تک کہ (لوگوں کو حق و باطل کا فرق سمجھانے کے لیے) ایک پیغام بر نہ بھیج دیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmxlv{جب ہم کسی بستی کو ہلاک کرنے کا ارادہ کرتے ہیں تو اس کے خوشحال لوگوں کو حکم دیتے ہیں اور وہ اس میں نافرمانیاں کرنے لگتے ہیں، تب عذاب کا فیصلہ اس بستی پر چسپاں ہو جاتا ہے اور ہم اسے برباد کر کے رکھ دیتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmxlvi{دیکھ لو، کتنی ہی نسلیں ہیں جو نوحؑ کے بعد ہمارے حکم سے ہلاک ہوئیں تیرا رب اپنے بندوں کے گناہوں سے پوری طرح باخبر ہے اور سب کچھ دیکھ رہا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmxlvii{جو کوئی عاجلہ کا خواہشمند ہو، اسے یہیں ہم دے دیتے ہیں جو کچھ بھی جسے دینا چاہیں، پھر اس کے مقسوم میں جہنم لکھ دیتے ہیں جسے وہ تاپے گا ملامت زدہ اور رحمت سے محروم ہو کر\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmxlviii{اور جو آخرت کا خواہشمند ہو اور اس کے لیے سعی کرے جیسی کہ اس کے لیے سعی کرنی چاہیے، اور ہو وہ مومن، تو ایسے ہر شخص کی سعی مشکور ہوگی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmxlix{اِن کو بھی اور اُن کو بھی، دونوں فریقوں کو ہم (دنیا میں) سامان زیست دیے جا رہے ہیں، یہ تیرے رب کا عطیہ ہے، اور تیرے رب کی عطا کو روکنے والا کوئی نہیں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mml{مگر دیکھ لو، دنیا ہی میں ہم نے ایک گروہ کو دوسرے پر کیسی فضیلت دے رکھی ہے، اور آخرت میں اُس کے درجے اور بھی زیادہ ہوں گے، اور اس کی فضیلت اور بھی زیادہ بڑھ چڑھ کر ہوگی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmli{تو اللہ کے ساتھ کوئی دوسرا معبود نہ بنا ورنہ ملامت زدہ اور بے یار و مدد گار بیٹھا رہ جائیگا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmlii{تیرے رب نے فیصلہ کر دیا ہے کہ: تم لوگ کسی کی عبادت نہ کرو، مگر صرف اُس کی والدین کے ساتھ نیک سلوک کرو اگر تمہارے پاس اُن میں سے کوئی ایک، یا دونوں، بوڑھے ہو کر رہیں تو انہیں اف تک نہ کہو، نہ انہیں جھڑک کر جواب دو، بلکہ ان سے احترام کے ساتھ بات کرو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmliii{اور نرمی و رحم کے ساتھ ان کے سامنے جھک کر رہو، اور دعا کیا کرو کہ ``پروردگار، ان پر رحم فرما جس طرح اِنہوں نے رحمت و شفقت کے ساتھ مجھے بچپن میں پالا تھا"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmliv{تمہارا رب خوب جانتا ہے کہ تمہارے دلوں میں کیا ہے اگر تم صالح بن کر رہو تو وہ ایسے سب لوگوں کے لیے در گزر کرنے والا ہے جو اپنے قصور پر متنبہ ہو کر بندگی کے رویے کی طرف پلٹ آئیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmlv{رشتہ دار کو اس کا حق دو اور مسکین اور مسافر کو اس کا حق فضول خرچی نہ کرو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmlvi{فضول خرچ لوگ شیطان کے بھائی ہیں، اور شیطان اپنے رب کا ناشکرا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmlvii{اگر اُن سے (یعنی حاجت مند رشتہ داروں، مسکینوں اور مسافروں سے) تمہیں کترانا ہو، اس بنا پر کہ ابھی تم اللہ کی اُس رحمت کو جس کے تم امیدوار ہو تلاش کر رہے ہو، تو انہیں نرم جواب دے دو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmlviii{نہ تو اپنا ہاتھ گردن سے باندھ رکھو اور نہ اسے بالکل ہی کھلا چھوڑ دو کہ ملامت زدہ اور عاجز بن کر رہ جاؤ\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmlix{تیر ا رب جس کے لیے چاہتا ہے رزق کشادہ کرتا ہے اور جس کے لیے چاہتا ہے تنگ کر دیتا ہے وہ اپنے بندوں کے حال سے باخبر ہے اور انہیں دیکھ رہا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmlx{اپنی اولاد کو افلاس کے اندیشے سے قتل نہ کرو ہم انہیں بھی رزق دیں گے اور تمہیں بھی در حقیقت اُن کا قتل ایک بڑی خطا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmlxi{زنا کے قریب نہ پھٹکو وہ بہت برا فعل ہے اور بڑا ہی برا راستہ\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmlxii{قتل نفس کا ارتکاب نہ کرو جسے اللہ نے حرام کیا ہے مگر حق کے ساتھ اور جو شخص مظلومانہ قتل کیا گیا ہو اس کے ولی کو ہم نے قصاص کے مطالبے کا حق عطا کیا ہے، پس چاہیے کہ وہ قتل میں حد سے نہ گزرے، اُس کی مدد کی جائے گی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmlxiii{ما ل یتیم کے پاس نہ پھٹکو مگر احسن طریقے سے، یہاں تک کہ وہ اپنے شباب کو پہنچ جائے عہد کی پابندی کرو، بے شک عہد کے بارے میں تم کو جواب دہی کرنی ہوگی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmlxiv{پیمانے سے دو تو پورا بھر کر دو، اور تولو تو ٹھیک ترازو سے تولو یہ اچھا طریقہ ہے اور بلحاظ انجام بھی یہی بہتر ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmlxv{کسی ایسی چیز کے پیچھے نہ لگو جس کا تمہیں علم نہ ہو یقیناً آنکھ، کان اور دل سب ہی کی باز پرس ہونی ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmlxvi{زمین میں اکڑ کر نہ چلو، تم نہ زمین کو پھاڑ سکتے ہو، نہ پہاڑوں کی بلندی کو پہنچ سکتے ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmlxvii{اِن امور میں سے ہر ایک کا برا پہلو تیرے رب کے نزدیک ناپسندیدہ ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmlxviii{یہ وہ حکمت کی باتیں ہیں جو تیرے رب نے تجھ پر وحی کی ہیں اور دیکھ! اللہ کے ساتھ کوئی دوسرا معبود نہ بنا بیٹھ ورنہ تو جہنم میں ڈال دیا جائے گا ملامت زدہ اور ہر بھلائی سے محروم ہو کر\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmlxix{کیسی عجیب بات ہے کہ تمہارے رب نے تمہیں تو بیٹوں سے نوازا اور خود اپنے لیے ملائکہ کو بیٹیاں بنا لیا؟ بڑی جھوٹی بات ہے جو تم لوگ زبانوں سے نکالتے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmlxx{ہم نے اِس قرآن میں طرح طرح سے لوگوں کو سمجھایا کہ ہوش میں آئیں، مگر وہ حق سے اور زیادہ دور ہی بھاگے جا رہے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmlxxi{اے محمدؐ، ان سے کہو کہ اگر اللہ کے ساتھ دوسرے خدا بھی ہوتے، جیسا کہ یہ لوگ کہتے ہیں، تو وہ مالک عرش کے مقام پر پہنچنے کی ضرور کوشش کرتے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmlxxii{پاک ہے وہ اور بہت بالا و برتر ہے اُن باتوں سے جو یہ لوگ کہہ رہے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmlxxiii{اُس کی پاکی تو ساتوں آسمان اور زمین اور وہ ساری چیزیں بیان کر رہی ہیں جو آسمان و زمین میں ہیں کوئی چیز ایسی نہیں جو اس کی حمد کے ساتھ اس کی تسبیح نہ کر رہی ہو، مگر تم ان کی تسبیح سمجھتے نہیں ہو حقیقت یہ ہے کہ وہ بڑا ہی بردبار اور درگزر کرنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmlxxiv{جب تم قرآن پڑھتے ہو تو ہم تمہارے اور آخرت پر ایمان نہ لانے والوں کے درمیان ایک پردہ حائل کر دیتے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmlxxv{اور ان کے دلوں پر ایسا غلاف چڑھا دیتے ہیں کہ وہ کچھ نہیں سمجھتے، اور ان کے کانوں میں گرانی پیدا کر دیتے ہیں اور جب تم قرآن میں اپنے ایک ہی رب کا ذکر کرتے ہو تو وہ نفرت سے منہ موڑ لیتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmlxxvi{ہمیں معلوم ہے کہ جب وہ کان لگا کر تمہاری بات سنتے ہیں تو دراصل کیا سنتے ہیں، اور جب بیٹھ کر باہم سرگوشیاں کرتے ہیں تو کیا کہتے ہیں یہ ظالم آپس میں کہتے ہیں کہ یہ ایک سحر زدہ آدمی ہے جس کے پیچھے تم لوگ جا رہے ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmlxxvii{دیکھو، کیسی باتیں ہیں جو یہ لوگ تم پر چھانٹتے ہیں یہ بھٹک گئے ہیں اِنہیں راستہ نہیں ملتا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmlxxviii{وہ کہتے ہیں ``جب ہم صرف ہڈیاں اور خاک ہو کر رہ جائیں گے تو کیا ہم نئے سرے سے پیدا کر کے اٹھائے جائیں گے؟"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmlxxix{ان سے کہو ``تم پتھر یا لوہا بھی ہو جاؤ\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmlxxx{یا اس سے بھی زیادہ سخت کوئی چیز جو تمہارے ذہن میں قبول حیات سے بعید تر ہو" (پھر بھی تم اٹھ کر رہو گے) وہ ضرور پوچھیں گے ``کون ہے وہ جو ہمیں پھر زندگی کی طرف پلٹا کر لائے گا؟" جواب میں کہو ``وہی جس نے پہلی بار تم کو پیدا کیا" وہ سر ہلا ہلا کر پوچھیں گے ``اچھا، تو یہ ہوگا کب؟" تم کہو ``کیا عجب، وہ وقت قریب ہی آ لگا ہو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmlxxxi{جس روز وہ تمہیں پکارے گا تو تم اس کی حمد کرتے ہوئے اس کی پکار کے جواب میں نکل آؤ گے اور تمہارا گمان اُس وقت یہ ہوگا کہ ہم بس تھوڑی دیر ہی اِس حالت میں پڑے رہے ہیں"\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmlxxxii{اور اے محمدؐ، میرے بندوں سے کہہ دو کہ زبان سے وہ بات نکالا کریں جو بہترین ہو دراصل یہ شیطان ہے جو انسانوں کے درمیان فساد ڈلوانے کی کوشش کرتا ہے حقیقت یہ ہے کہ شیطان انسا ن کا کھلا دشمن ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiii{تمہارا رب تمہارے حال سے زیادہ واقف ہے، وہ چاہے تو تم پر رحم کرے اور چاہے تو تمہیں عذاب دے دے اور اے نبیؐ، ہم نے تم کو لوگوں پر حوالہ دار بنا کر نہیں بھیجا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiv{تیرا رب زمین اور آسمانوں کی مخلوقات کو زیادہ جانتا ہے ہم نے بعض پیغمبروں کو بعض سے بڑھ کر مرتبے دیے، اور ہم نے ہی داؤدؑ کو زبور دی تھی\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmlxxxv{اِن سے کہو، پکار دیکھو اُن معبودوں کو جن کو تم خدا کے سوا (اپنا کارساز) سمجھتے ہو، وہ کسی تکلیف کو تم سے نہ ہٹا سکتے ہیں نہ بدل سکتے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvi{جن کو یہ لوگ پکارتے ہیں وہ تو خود اپنے رب کے حضور رسائی حاصل کرنے کا وسیلہ تلاش کر رہے ہیں کہ کون اُس سے قریب تر ہو جائے اور وہ اُس کی رحمت کے امیدوار اور اُس کے عذاب سے خائف ہیں حقیقت یہ ہے کہ تیرے رب کا عذاب ہے ہی ڈرنے کے لائق\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvii{اور کوئی بستی ایسی نہیں جسے ہم قیامت سے پہلے ہلاک نہ کریں یا سخت عذاب نہ دیں یہ نوشتہ الٰہی میں لکھا ہوا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmlxxxviii{اور ہم کو نشانیاں بھیجنے سے نہیں روکا مگر اس بات نے کہ اِن سے پہلے کے لوگ اُن کو جھٹلا چکے ہیں (چنانچہ دیکھ لو) ثمود کو ہم نے علانیہ اونٹنی لا کر دی اور اُنہوں نے اس پر ظلم کیا ہم نشانیاں اسی لیے تو بھیجتے ہیں کہ لوگ انہیں دیکھ کر ڈریں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmlxxxix{یاد کرو اے محمدؐ، ہم نے تم سے کہہ دیا تھا کہ تیرے رب نے اِن لوگوں کو گھیر رکھا ہے اور یہ جو کچھ ابھی ہم نے تمہیں دکھایا ہے، اِس کو اور اُس درخت کو جس پر قرآن میں لعنت کی گئی ہے، ہم نے اِن لوگوں کے لیے بس ایک فتنہ بنا کر رکھ دیا ہم اِنہیں تنبیہ پر تنبیہ کیے جا رہے ہیں، مگر ہر تنبیہ اِن کی سر کشی ہی میں اضافہ کیے جاتی ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmxc{اور یاد کرو جبکہ ہم نے ملائکہ سے کہا کہ آدمؑ کو سجدہ کرو، تو سب نے سجدہ کیا، مگر ابلیس نے نہ کیا ا س نے کہا ``کیا میں اُس کو سجدہ کروں جسے تو نے مٹی سے بنایا ہے؟"\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmxci{پھر وہ بولا ``دیکھ تو سہی، کیا یہ اس قابل تھا کہ تو نے اِسے مجھ پر فضیلت دی؟ اگر تو مجھے قیامت کے دن تک مہلت دے تو میں اس کی پوری نسل کی بیخ کنی کر ڈالوں، بس تھوڑے ہی لوگ مجھ سے بچ سکیں گے"\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmxcii{اللہ تعالیٰ نے فرمایا ``اچھا تو جا، ان میں سے جو بھی تیری پیروی کریں، تجھ سمیت اُن سب کے لیے جہنم ہی بھرپور جزا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmxciii{تو جس جس کو اپنی دعوت سے پھسلا سکتا ہے پھسلا لے، ان پر اپنے سوار اور پیادے چڑھا لا، مال اور اولاد میں ان کے ساتھ ساجھا لگا، اور ان کو وعدوں کے جال میں پھانس اور شیطان کے وعدے ایک دھوکے کے سوا اور کچھ بھی نہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmxciv{یقیناً میرے بندوں پر تجھے کوئی اقتدار حاصل نہ ہوگا، اور توکل کے لیے تیرا رب کافی ہے"\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmxcv{تمہارا (حقیقی) رب تو وہ ہے جو سمندر میں تمہاری کشتی چلاتا ہے تاکہ تم اس کا فضل تلا ش کرو حقیقت یہ ہے کہ وہ تمہارے حال پر نہایت مہربان ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmxcvi{جب سمندر میں تم پر مصیبت آتی ہے تو اُس ایک کے سوا دوسرے جن جن کو تم پکارا کرتے ہو وہ سب گم ہو جاتے ہیں، مگر جب وہ تم کو بچا کر خشکی پر پہنچا دیتا ہے تو تم اُس سے منہ موڑ جاتے ہو انسان واقعی بڑا ناشکرا ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmxcvii{اچھا، تو کیا تم اِس بات سے بالکل بے خوف ہو کہ خدا کبھی خشکی پر ہی تم کو زمین میں دھنسا دے، یا تم پر پتھراؤ کرنے والی آندھی بھیج دے اور تم اس سے بچانے والا کوئی حمایتی نہ پاؤ؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmxcviii{اور کیا تمہیں اِس کا کوئی اندیشہ نہیں کہ خدا پھر کسی وقت سمندر میں تم کو لے جائے اور تمہاری ناشکری کے بدلے تم پر سخت طوفانی ہوا بھیج کر تمہیں غرق کر دے اور تم کو ایسا کوئی نہ ملے جو اُس سے تمہارے اِس انجام کی پوچھ گچھ کرسکے؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmxcix{یہ تو ہماری عنایت ہے کہ ہم نے بنی آدم کو بزرگی دی اور انہیں خشکی و تری میں سواریاں عطا کیں اور ان کو پاکیزہ چیزوں سے رزق دیا اور اپنی بہت سی مخلوقات پر نمایاں فوقیت بخشی\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmc{پھر خیال کرو اس دن کا جب کہ ہم ہر انسانی گروہ کو اس کے پیشوا کے ساتھ بلائیں گے اُس وقت جن لوگوں کو ان کا نامہ اعمال سیدھے ہاتھ میں دیا گیا وہ اپنا کارنامہ پڑھیں گے اور ان پر ذرہ برابر ظلم نہ ہوگا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmci{اور جو اِس دنیا میں اندھا بن کر رہا وہ آخرت میں بھی اندھا ہی رہے گا بلکہ راستہ پانے میں اندھے سے بھی زیادہ ناکام\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcii{اے محمدؐ، ان لوگوں نے اِس کوشش میں کوئی کسر اٹھا نہیں رکھی کہ تمہیں فتنے میں ڈال کر اُس وحی سے پھیر دیں جو ہم نے تمہاری طرف بھیجی ہے تاکہ تم ہمارے نام پر اپنی طرف سے کوئی بات گھڑو اگر تم ایسا کرتے تو وہ ضرور تمہیں اپنا دوست بنا لیتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmciii{اور بعید نہ تھا کہ اگر ہم تمہیں مضبوط نہ رکھتے تو تم ان کی طرف کچھ نہ کچھ جھک جاتے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmciv{لیکن اگر تم ایسا کرتے تو ہم تمہیں دنیا میں بھی دوہرے عذاب کا مزہ چکھاتے اور آخرت میں بھی دوہرے عذاب کا، پھر ہمارے مقابلے میں تم کوئی مددگار نہ پاتے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcv{اور یہ لوگ اس بات پر بھی تلے رہے ہیں کہ تمہارے قدم اِس سر زمین سے اکھاڑ دیں اور تمہیں یہاں سے نکال باہر کریں لیکن اگر یہ ایسا کریں گے تو تمہارے بعد یہ خود یہاں کچھ زیادہ دیر نہ ٹھیر سکیں گے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcvi{یہ ہمارا مستقل طریق کار ہے جو اُن سب رسولوں کے معاملے میں ہم نے برتا ہے جہیں تم سے پہلے ہم نے بھیجا تھا، اور ہمارے طریق کار میں تم کوئی تغیر نہ پاؤ گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcvii{نماز قائم کرو زوال آفتاب سے لے کر اندھیرے تک اور فجر کے قرآن کا بھی التزام کرو کیونکہ قرآن فجر مشہود ہوتا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcviii{اور رات کو تہجد پڑھو، یہ تمہارے لیے نفل ہے، بعید نہیں کہ تمہارا رب تمہیں مقام محمود پر فائز کر دے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcix{اور دعا کرو کہ پروردگار، مجھ کو جہاں بھی تو لے جا سچائی کے ساتھ لے جا اور جہاں سے بھی نکال سچائی کے ساتھ نکال اور اپنی طرف سے ایک اقتدار کو میرا مددگار بنا دے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcx{اور اعلان کر دو کہ ``حق آ گیا اور باطل مٹ گیا، باطل تو مٹنے ہی والا ہے"\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcxi{ہم اِس قرآن کے سلسلہ تنزیل میں وہ کچھ نازل کر رہے ہیں جو ماننے والوں کے لیے تو شفا اور رحمت ہے، مگر ظالموں کے لیے خسارے کے سوا اور کسی چیز میں اضافہ نہیں کرتا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcxii{انسان کا حال یہ ہے کہ جب ہم اس کو نعمت عطا کرتے ہیں تو وہ اینٹھتا اور پیٹھ موڑ لیتا ہے، اور جب ذرا مصیبت سے دو چار ہوتا ہے تو مایوس ہونے لگتا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcxiii{اے نبیؐ، ان لوگوں سے کہہ دو کہ ``ہر ایک اپنے طریقے پر عمل کر رہا ہے، اب یہ تمہارا رب ہی بہتر جانتا ہے کہ سیدھی راہ پر کون ہے"\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcxiv{یہ لوگ تم سے روح کے متعلق پوچھتے ہیں کہو ``یہ روح میرے رب کے حکم سے آتی ہے، مگر تم لوگوں نے علم سے کم ہی بہرہ پایا ہے"\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcxv{اور اے محمدؐ، ہم چاہیں تو وہ سب کچھ تم سے چھین لیں جو ہم نے وحی کے ذریعہ سے تم کو عطا کیا ہے، پھر تم ہمارے مقابلے میں کوئی حمایتی نہ پاؤ گے جو اسے واپس دلا سکے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcxvi{یہ تو جو کچھ تمہیں ملا ہے تمہارے رب کی رحمت سے ملا ہے، حقیقت یہ ہے کہ اس کا فضل تم پر بہت بڑا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcxvii{کہہ دو کہ اگر انسان اور جن سب کے سب مل کر اس قرآن جیسی کوئی چیز لانے کی کوشش کریں تو نہ لاسکیں گے، چاہے وہ سب ایک دوسرے کے مدد گار ہی کیوں نہ ہوں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcxviii{ہم نے اس قرآن میں لوگوں کو طرح طرح سے سمجھایا مگر اکثر انکار ہی پر جمے رہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcxix{اور انہوں نے کہا ``ہم تیر ی بات نہ مانیں گے جب تک کہ تو ہمارے لیے زمین کو پھاڑ کر ایک چشمہ جاری نہ کر دے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcxx{یا تیرے لیے کھجوروں اور انگوروں کا ایک باغ پیدا ہو اور تو اس میں نہریں رواں کر دے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcxxi{یا تو آسمانوں کو ٹکڑے ٹکڑے کر کے ہمارے اوپر گرا دے جیسا کہ تیرا دعویٰ ہے یا خدا اور فرشتوں کو رُو در رُو ہمارے سامنے لے آئے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcxxii{یا تیرے لیے سونے کا ایک گھر بن جائے یا تو آسمان پر چڑھ جائے، اور تیرے چڑھنے کا بھی ہم یقین نہ کریں گے جب تک کہ تو ہمارے اوپر ایک ایسی تحریر نہ اتار لائے جسے ہم پڑھیں" اے محمدؐ، اِن سے کہو ``پاک ہے میرا پروردگار! کیا میں ایک پیغام لانے والے انسان کے سوا اور بھی کچھ ہوں؟"\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcxxiii{لوگوں کے سامنے جب کبھی ہدایت آئی تو اس پر ایمان لانے سے اُن کو کسی چیز نے نہیں روکا مگر اُن کے اِسی قول نے کہ ``کیا اللہ نے بشر کو پیغمبر بنا کر بھیج دیا؟"\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcxxiv{اِن سے کہو اگر زمین میں فرشتے اطمینان سے چل پھر رہے ہوتے تو ہم ضرور آسمان سے کسی فرشتے ہی کو اُن کے لیے پیغمبر بنا کر بھیجتے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcxxv{اے محمدؐ، ان سے کہہ دو کہ میرے اور تمہارے درمیان بس ایک اللہ کی گواہی کافی ہے وہ اپنے بندوں کے حال سے باخبر ہے اور سب کچھ دیکھ رہا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcxxvi{جس کو اللہ ہدایت دے وہی ہدایت پانے والا ہے، اور جسے وہ گمراہی میں ڈال دے تو اسکے سوا ایسے لوگوں کے لیے تو کوئی حامی و ناصر نہیں پا سکتا ان لوگوں کو ہم قیامت کے روز اوندھے منہ کھینچ لائیں گے، اندھے، گونگے اور بہرے اُن کا ٹھکانا جہنم ہے جب کبھی اس کی آگ دھیمی ہونے لگے گی ہم اسے اور بھڑکا دیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcxxvii{یہ بدلہ ہے ان کی اس حرکت کا کہ انہوں نے ہماری آیات کا انکار کیا اور کہا ``کیا جب ہم صرف ہڈیاں اور خاک ہو کر رہ جائیں گے تو نئے سرے سے ہم کو پیدا کر کے اٹھا کھڑا کیا جائے گا؟"\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcxxviii{کیا ان کو یہ نہ سوجھا کہ جس خدا نے زمین اور آسمانو ں کو پیدا کیا ہے وہ اِن جیسوں کو پیدا کرنے کی ضرور قدرت رکھتا ہے؟ اس نے اِن کے حشر کے لیے ایک وقت مقرر کر رکھا ہے جس کا آنا یقینی ہے، مگر ظالموں کو اصرار ہے کہ وہ اس کا انکار ہی کریں گے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcxxix{اے محمدؐ، اِن سے کہو، اگر کہیں میرے رب کی رحمت کے خزانے تمہارے قبضے میں ہوتے تو تم خرچ ہو جانے کے اندیشے سے ضرور ان کو روک رکھتے واقعی انسان بڑا تنگ دل واقع ہوا ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcxxx{ہم نے موسیٰؑ کو تو نشانیاں عطا کی تھیں جو صریح طور پر دکھائی دے رہی تھیں اب یہ تم خود بنی اسرائیل سے پوچھ لو کہ جب وہ سامنے آئیں تو فرعون نے یہی کہا تھا نا کہ ``اے موسیٰؑ، میں سمجھتا ہوں کہ تو ضرور ایک سحر زدہ آدمی ہے"\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcxxxi{موسیٰؑ نے اس کے جواب میں کہا ``تو خوب جانتا ہے کہ یہ بصیرت افروز نشانیاں رب السماوات و الارض کے سوا کسی نے نازل نہیں کی ہیں، اور میرا خیال یہ ہے کہ اے فرعون، تو ضرور ایک شامت زدہ آدمی ہے"\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcxxxii{آخرکار فرعون نے ارادہ کیا کہ موسیٰؑ اور بنی اسرائیل کو زمین سے اکھاڑ پھینکے، مگر ہم نے اس کو اوراس کے ساتھیوں کو اکٹھا غرق کر دیا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiii{اور اس کے بعد بنی اسرائیل سے کہا کہ اب تم زمین میں بسو، پھر جب آخرت کے وعدے کا وقت آن پورا ہوگا تو ہم تم سب کو ایک ساتھ لا حاضر کریں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiv{اس قرآن کو ہم نے حق کے ساتھ نازل کیا ہے اور حق ہی کے ساتھ یہ نازل ہوا ہے، اور اے محمدؐ، تمہیں ہم نے اِس کے سوا اور کسی کام کے لیے نہیں بھیجا کہ (جو مان لے اسے) بشارت دے دو اور (جو نہ مانے اُسے) متنبہ کر دو\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcxxxv{اور اس قرآن کو ہم نے تھوڑا تھوڑا کر کے نازل کیا ہے تاکہ تم ٹھیر ٹھیر کر اسے لوگوں کو سناؤ، اور اسے ہم نے (موقع موقع سے) بتدریج اتارا ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvi{اے محمدؐ، اِن لوگوں سے کہہ دو کہ تم اسے مانو یا نہ مانو، جن لوگوں کو اس سے پہلے علم دیا گیا ہے انہیں جب یہ سنایا جاتا ہے تو وہ منہ کے بل سجدے میں گر جاتے ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvii{اور پکار اٹھتے ہیں ``پاک ہے ہمارا رب، اُس کا وعدہ تو پورا ہونا ہی تھا"\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcxxxviii{اور وہ منہ کے بل روتے ہوئے گر جاتے ہیں اور اسے سن کر اُن کا خشوع اور بڑھ جاتا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcxxxix{اے نبیؐ، اِن سے کہو، اللہ کہہ کر پکارو یا رحمان کہہ کر، جس نام سے بھی پکارو اُس کے لیے سب اچھے ہی نام ہیں اور اپنی نماز نہ بہت زیادہ بلند آواز سے پڑھو اور نہ بہت پست آواز سے، ان دونوں کے درمیان اوسط درجے کا لہجہ اختیار کرو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcxl{اور کہو ``تعریف ہے اس خدا کے لیے جس نے نہ کسی کو بیٹا بنایا، نہ کوئی بادشاہی میں اس کا شریک ہے، اور نہ وہ عاجز ہے کہ کوئی اس کا پشتیبان ہو" اور اس کی بڑائی بیان کرو، کمال درجے کی بڑائی\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcxli{\basmalahur تعریف اللہ کے لئے ہے جس نے اپنے بندے پر یہ کتاب نازل کی اور اس میں کوئی ٹیڑھ نہ رکھی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcxlii{ٹھیک ٹھیک سیدھی بات کہنے والی کتاب، تاکہ وہ لوگوں کو خدا کے سخت عذاب سے خبردار کر دے، اور ایمان لا کر نیک عمل کرنے والوں کو خوشخبری دیدے کہ ان کے لیے اچھا اجر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcxliii{جس میں وہ ہمیشہ رہیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcxliv{اور اُن لوگوں کو ڈرا دے جو کہتے ہیں کہ اللہ نے کسی کو بیٹا بنایا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcxlv{اِس بات کا نہ اُنہیں کوئی علم ہے اور نہ ان کے باپ دادا کو تھا بڑی بات ہے جو ان کے منہ سے نکلتی ہے وہ محض جھوٹ بکتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcxlvi{اچھا، تو اے محمدؐ، شاید تم ان کے پیچھے غم کے مارے اپنی جان کھو دینے والے ہو اگر یہ اِس تعلیم پر ایمان نہ لائے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcxlvii{واقعہ یہ ہے کہ یہ جو کچھ سر و سامان بھی زمین پر ہے اس کو ہم نے زمین کی زینت بنایا ہے تاکہ اِن لوگوں کو آزمائیں اِن میں کون بہتر عمل کرنے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcxlviii{آخرکار اِس سب کو ہم ایک چٹیل میدان بنا دینے والے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcxlix{کیا تم سمجھتے ہو کہ غار اور کتبے والے ہماری کوئی بڑی عجیب نشانیوں میں سے تھے؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcl{جب وہ چند نوجوان غار میں پناہ گزیں ہوئے اور انہوں نے کہا کہ ``اے پروردگار، ہم کو اپنی رحمت خاص سے نواز اور ہمارا معاملہ درست کر دے،"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcli{تو ہم نے انہیں اُسی غار میں تھپک کر سالہا سال کے لیے گہری نیند سلا دیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmclii{پھر ہم نے انہیں اٹھایا تاکہ دیکھیں اُن کے دو گروہوں میں سے کون اپنی مدت قیام کا ٹھیک شمار کرتا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcliii{ہم ان کا اصل قصہ تمہیں سناتے ہیں وہ چند نوجوان تھے جو اپنے رب پر ایمان لے آئے تھے اور ہم نے ان کو ہدایت میں ترقی بخشی تھی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcliv{ہم نے ان کے دل اُس وقت مضبوط کر دیے جب وہ اٹھے اور انہوں نے اعلان کر دیا کہ ``ہمارا رب تو بس وہی ہے جو آسمانوں اور زمین کا رب ہے ہم اُسے چھوڑ کر کسی دوسرے معبود کو نہ پکاریں گے اگر ہم ایسا کریں تو بالکل بیجا بات کریں گے"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmclv{(پھر انہوں نے آپس میں ایک دوسرے سے کہا) ``یہ ہماری قوم تو ربِّ کائنات کو چھوڑ کر دوسرے خدا بنا بیٹھی ہے یہ لوگ ان کے معبود ہونے پر کوئی واضح دلیل کیوں نہیں لاتے؟ آخر اُس شخص سے بڑا ظالم اور کون ہو سکتا ہے جو اللہ پر جھوٹ باندھے؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmclvi{اب جبکہ تم ان سے اور اِن کے معبودانِ غیر اللہ سے بے تعلق ہو چکے ہو تو چلو اب فلاں غار میں چل کر پناہ لو تمہارا رب تم پر اپنی رحمت کا دامن وسیع کرے گا اور تمہارے کام کے لیے سر و سامان مہیا کر دے گا"\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmclvii{تم انہیں غار میں دیکھتے تو تمہیں یوں نظر آتا کہ سورج جب نکلتا ہے تو ان کے غار کو چھوڑ کر دائیں جانب چڑھ جاتا ہے اور جب غروب ہوتا ہے تو ان سے بچ کر بائیں جانب اتر جاتا ہے اور وہ ہیں کہ غار کے اندر ایک وسیع جگہ میں پڑے ہیں یہ اللہ کی نشانیوں میں سے ایک ہے جس کو اللہ ہدایت دے وہی ہدایت پانے والا ہے اور جسے اللہ بھٹکا دے اس کے لیے تم کوئی ولی مرشد نہیں پا سکتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmclviii{تم انہیں دیکھ کر یہ سمجھتے کہ وہ جاگ رہے ہیں، حالانکہ وہ سو رہے تھے ہم انہیں دائیں بائیں کروٹ دلواتے رہتے تھے اور ان کا کتا غار کے دہانے پر ہاتھ پھیلائے بیٹھا تھا اگر تم کہیں جھانک کر اُنہیں دیکھتے تو الٹے پاؤں بھاگ کھڑے ہوتے اور تم پر ان کے نظارے سے دہشت بیٹھ جاتی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmclix{اور اسی عجیب کرشمے سے ہم نے انہیں اٹھا بٹھایا تاکہ ذرا آپس میں پوچھ گچھ کریں ان میں سے ایک نے پوچھا ``کہو کتنی دیر اس حال میں رہے؟"دوسروں نے کہا ``شاید دن بھر یا اس سے کچھ کم رہے ہوں گے" پھر وہ بولے ``اللہ ہی بہتر جانتا ہے کہ ہمارا کتنا وقت اس حالت میں گزرا چلو، اب اپنے میں سے کسی کو چاندی کا یہ سکہ دے کر شہر بھیجیں اور وہ دیکھے کہ سب سے اچھا کھانا کہاں ملتا ہے وہاں سے وہ کچھ کھانے کے لیے لائے اور چاہیے کہ ذرا ہوشیاری سے کام کرے، ایسا نہ ہو کہ وہ کسی کو ہمارے یہاں ہونے سے خبردار کر بیٹھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmclx{اگر کہیں اُن لوگوں کا ہاتھ ہم پر پڑ گیا تو بس سنگسار ہی کر ڈالیں گے، یا پھر زبردستی ہمیں اپنی ملت میں واپس لے جائیں گے، اور ایسا ہوا توہم کبھی فلاح نہ پا سکیں گے"\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmclxi{اِس طرح ہم نے اہل شہر کو ان کے حال پر مطلع کیا تاکہ لوگ جان لیں کہ اللہ کا وعدہ سچا ہے اور یہ کہ قیامت کی گھڑی بے شک آ کر رہے گی (مگر ذرا خیال کرو کہ جب سوچنے کی اصل بات یہ تھی) اُس وقت وہ آپس میں اِس بات پر جھگڑ رہے تھے کہ اِن (اصحاب کہف) کے ساتھ کیا کیا جائے کچھ لوگوں نے کہا ``اِن پر ایک دیوار چن دو، ان کا رب ہی اِن کے معاملہ کو بہتر جانتا ہے" مگر جو لوگ اُن کے معاملات پر غالب تھے انہوں نے کہا `` ہم تو ان پر ایک عبادت گاہ بنائیں گے"\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmclxii{کچھ لوگ کہیں گے کہ وہ تین تھے اور چوتھا ان کا کتا تھا اور کچھ دوسرے کہہ دیں گے کہ پانچ تھے اور چھٹا اُن کا کتا تھا یہ سب بے تکی ہانکتے ہیں کچھ اور لوگ کہتے ہیں کہ سات تھے اور آٹھواں اُن کا کتا تھا کہو، میرا رب ہی بہتر جانتا ہے کہ وہ کتنے تھے کم ہی لوگ ان کی صحیح تعداد جانتے ہیں پس تم سرسری بات سے بڑھ کر ان کی تعداد کے معاملے میں لوگوں سے بحث نہ کرو، اور نہ ان کے متعلق کسی سے کچھ پوچھو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmclxiii{اور دیکھو، کسی چیز کے بارے میں کبھی یہ نہ کہا کرو کہ میں کل یہ کام کر دوں گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmclxiv{(تم کچھ نہیں کر سکتے) اِلّا یہ کہ اللہ چاہے اگر بھولے سے ایسی بات زبان سے نکل جائے تو فوراً اپنے رب کو یاد کرو اور کہو ``امید ہے کہ میرا رب اِس معاملے میں رشد سے قریب تر بات کی طرف میری رہنمائی فرما دے گا"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmclxv{اور وہ اپنے غار میں تین سو سال رہے، اور (کچھ لوگ مدّت کے شمار میں) ۹ سال اور بڑھ گئے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmclxvi{تم کہو، اللہ ان کے قیام کی مدّت زیادہ جانتا ہے، آسمانوں اور زمین کے سب پوشیدہ احوال اُسی کو معلوم ہیں، کیا خوب ہے وہ دیکھنے والا اور سننے والا! زمین و آسمان کی مخلوقات کا کوئی خبرگیر اُس کے سوا نہیں، اور وہ اپنی حکومت میں کسی کو شریک نہیں کرتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmclxvii{اے نبیؐ! تمہارے رب کی کتاب میں سے جو کچھ تم پر وحی کیا گیا ہے اسے (جوں کا توں) سنا دو، کوئی اُس کے فرمودات کو بدل دینے کا مجاز نہیں ہے، (اور اگر تم کسی کی خاطر اس میں رد و بدل کرو گے تو) اُس سے بچ کر بھاگنے کے لیے کوئی جائے پناہ نہ پاؤ گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmclxviii{اور اپنے دل کو اُن لوگوں کی معیت پر مطمئن کرو جو اپنے رب کی رضا کے طلب گار بن کر صبح و شام اُسے پکارتے ہیں، اور اُن سے ہرگز نگاہ نہ پھیرو کیا تم دنیا کی زینت پسند کرتے ہو؟ کسی ایسے شخص کی اطاعت نہ کرو جس کے دل کو ہم نے اپنی یاد سے غافل کر دیا ہے اور جس نے اپنی خواہش نفس کی پیروی اختیار کر لی ہے اور جس کا طریق کار افراط و تفریط پر مبنی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmclxix{صاف کہہ دو کہ یہ حق ہے تمہارے رب کی طرف سے، اب جس کا جی چاہے مان لے اور جس کا جی چاہے انکار کر دے ہم نے (انکار کرنے والے) ظالموں کے لیے ایک آگ تیار کر رکھی ہے جس کی لپٹیں انہیں گھیرے میں لے چکی ہیں وہاں اگر وہ پانی مانگیں گے توایسے پانی سے ان کی تواضع کی جائے گی جو تیل کی تلچھٹ جیسا ہوگا اور ان کا منہ بھون ڈالے گا، بدترین پینے کی چیز اور بہت بری آرامگاہ!\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmclxx{رہے وہ لوگ جو مان لیں اور نیک عمل کریں، تو یقیناً ہم نیکو کار لوگوں کا اجر ضائع نہیں کیا کرتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmclxxi{ان کے لیے سدا بہار جنتیں ہیں جن کے نیچے نہریں بہہ رہی ہوں گی، وہاں وہ سونے کے کنگنوں سے آراستہ کیے جائیں گے، باریک ریشم اور اطلس و دیبا کے سبز کپڑے پہنیں گے، اور اونچی مسندوں پر تکیے لگا کر بیٹھیں گے بہترین اجر اور اعلیٰ درجے کی جائے قیام!\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmclxxii{اے محمدؐ! اِن کے سامنے ایک مثال پیش کرو دو شخص تھے ان میں سے ایک کو ہم نے انگور کے دو باغ دیے اور اُن کے گرد کھجور کے درختوں کی باڑھ لگائی اور ان کے درمیان کاشت کی زمین رکھی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmclxxiii{دونوں باغ خوب پھلے پھولے اور بار آور ہونے میں انہوں نے ذرا سی کسر بھی نہ چھوڑی اُن باغوں کے اندر ہم نے ایک نہر جاری کر دی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmclxxiv{اوراُسے خوب نفع حاصل ہوا یہ کچھ پا کر ایک دن وہ اپنے ہمسائے سے بات کرتے ہوئے بولا ``میں تجھ سے زیادہ مالدار ہوں اور تجھ سے زیادہ طاقتور نفری رکھتا ہوں"\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmclxxv{پھر وہ اپنی جنّت میں داخل ہوا اور اپنے نفس کے حق میں ظالم بن کر کہنے لگا ``میں نہیں سمجھتا کہ یہ دولت کبھی فنا ہو جائے گی\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmclxxvi{اور مجھے توقع نہیں کہ قیامت کی گھڑی کبھی آئے گی تاہم اگر کبھی مجھے اپنے رب کے حضور پلٹایا بھی گیا تو ضرور اِس سے بھی زیادہ شاندار جگہ پاؤں گا"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmclxxvii{اُس کے ہمسائے نے گفتگو کرتے ہوئے اس سے کہا ``کیا تو کفر کرتا ہے اُس ذات سے جس نے تجھے مٹی سے اور پھر نطفے سے پیدا کیا اور تجھے ایک پورا آدمی بنا کھڑا کیا؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmclxxviii{رہا میں، تو میرا رب تو وہی اللہ ہے اور میں اس کے ساتھ کسی کو شریک نہیں کرتا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmclxxix{اور جب تو اپنی جنت میں داخل ہو رہا تھا تو اس وقت تیری زبان سے یہ کیوں نہ نکلا کہ ماشاءاللہ، لا قوة الّا باللہ؟ اگر تو مجھے مال اور اولاد میں اپنے سے کمتر پا رہا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmclxxx{تو بعید نہیں کہ میرا رب مجھے تیری جنت سے بہتر عطا فرما دے اور تیری جنت پر آسمان سے کوئی آفت بھیج دے جس سے وہ صاف میدان بن کر رہ جائے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmclxxxi{یا اس کا پانی زمین میں اتر جائے اور پھر تو اسے کسی طرح نہ نکال سکے"\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmclxxxii{آخرکار ہوا یہ کہ اس کا سارا ثمرہ مارا گیا اور وہ اپنے انگوروں کے باغ کو ٹٹیوں پر الٹا پڑا دیکھ کر اپنی لگائی ہوئی لاگت پر ہاتھ ملتا رہ گیا اور کہنے لگا کہ ``کاش! میں نے اپنے رب کے ساتھ کسی کو شریک نہ ٹھیرایا ہوتا"\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiii{نہ ہوا اللہ کو چھوڑ کر اس کے پاس کوئی جتھا کہ اس کی مدد کرتا، اور نہ کر سکا وہ آپ ہی اس آفت کا مقابلہ\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiv{اُس وقت معلوم ہوا کہ کارسازی کا اختیار خدائے برحق ہی کے لیے ہے، انعام وہی بہتر ہے جو وہ بخشے اور انجام وہی بخیر ہے جو وہ دکھائے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmclxxxv{اور اے نبیؐ! اِنہیں حیات دنیا کی حقیقت اِس مثال سے سمجھاؤ کہ آج ہم نے آسمان سے پانی برسا دیا تو زمین کی پَود خُوب گھنی ہو گئی، اور کل وہی نباتات بھُس بن کر رہ گئی جسے ہوائیں اڑائے لیے پھرتی ہیں اللہ ہر چیز پر قدرت رکھتا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvi{یہ مال اور یہ اولاد محض دُنیوی زندگی کی ایک ہنگامی آرائش ہے اصل میں تو باقی رہ جانے والی نیکیاں ہی تیرے رب کے نزدیک نتیجے کے لحاظ سے بہتر ہیں اور اُنہی سے اچھی اُمّیدیں وابستہ کی جا سکتی ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvii{فکر اُس دن کی ہونی چاہیے جب کہ ہم پہاڑوں کو چلائیں گے، اور تم زمین کو بالکل برہنہ پاؤ گے، اور ہم تمام انسانوں کو اس طرح گھیر کر جمع کریں گے کہ (اگلوں پچھلوں میں سے) ایک بھی نہ چھوٹے گا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmclxxxviii{اور سب کے سب تمہارے رب کے حضور صف در صف پیش کیے جائیں گے لو دیکھ لو، آ گئے نا تم ہمارے پاس اُسی طرح جیسا ہم نے تم کو پہلی بار پیدا کیا تھا تم نے تو یہ سمجھا تھا کہ ہم نے تمہارے لیے کوئی وعدے کا وقت مقرر ہی نہیں کیا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmclxxxix{اور نامہ اعمال سامنے رکھ دیا جائے گا اس وقت تم دیکھو گے کہ مجرم لوگ اپنی کتاب زندگی کے اندراجات سے ڈر رہے ہوں گے اور کہہ رہے ہوں گے کہ ہائے ہماری کم بختی، یہ کیسی کتاب ہے کہ ہماری کوئی چھوٹی بڑی حرکت ایسی نہیں رہی جو اس میں درج نہ ہو گئی ہو جو جو کچھ انہوں نے کیا تھا وہ سب اپنے سامنے حاضر پائیں گے اور تیرا رب کسی پر ذرا ظلم نہ کرے گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcxc{یاد کرو، جب ہم نے فرشتوں سے کہا کہ آدمؑ کو سجدہ کرو تو انہوں نے سجدہ کیا مگر ابلیس نے نہ کیا وہ جنوں میں سے تھا اس لیے اپنے رب کے حکم کی اطاعت سے نکل گیا اب کیا تم مجھے چھوڑ کر اُس کو اور اس کی ذرّیّت کو اپنا سرپرست بناتے ہو حالانکہ وہ تمہارے دشمن ہیں؟ بڑا ہی برا بدل ہے جسے ظالم لوگ اختیار کر رہے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcxci{میں نے آسمان و زمین پیدا کرتے وقت اُن کو نہیں بلایا تھا اور نہ خود اُن کی اپنی تخلیق میں انہیں شریک کیا تھا میرا یہ کام نہیں ہے کہ گمراہ کرنے والوں کو اپنا مدد گار بنایا کروں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcxcii{پھر کیا کریں گے یہ لوگ اُس روز جبکہ اِن کا رب اِن سے کہے گا کہ پکارو اب اُن ہستیوں کو جنہیں تم میرا شریک سمجھ بیٹھے تھے یہ ان کو پکاریں گے، مگر وہ اِن کی مدد کو نہ آئیں گے اور ہم ان کے درمیان ایک ہی ہلاکت کا گڑھا مشترک کر دیں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcxciii{سارے مجرم اُس روز آگ دیکھیں گے اورسمجھ لیں گے کہ اب انہیں اس میں گرنا ہے اور وہ اس سے بچنے کے لیے کوئی جائے پناہ نہ پائیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcxciv{ہم نے اِس قرآن میں لوگوں کو طرح طرح سے سمجھایا مگر انسان بڑا ہی جھگڑالو واقع ہوا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcxcv{اُن کے سامنے جب ہدایت آئی تو اسے ماننے اور اپنے رب کے حضور معافی چاہنے سے آخر اُن کوکس چیز نے روک دیا؟ اِس کے سوا اور کچھ نہیں کہ وہ منتظر ہیں کہ اُن کے ساتھ بھی وہی کچھ ہو جو پچھلی قوموں کے ساتھ ہو چکا ہے، یا یہ کہ وہ عذاب کو سامنے آتے دیکھ لیں!\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcxcvi{رسولوں کو ہم اس کام کے سوا اور کسی غرض کے لیے نہیں بھیجتے کہ وہ بشارت اور تنبیہ کی خدمت انجام دے دیں مگر کافروں کا حال یہ ہے کہ وہ باطل کے ہتھیار لے کر حق کو نیچا دکھانے کی کوشش کرتے ہیں اور انہوں نے میری آیات کو اور اُن تنبیہات کو جو انہیں کی گئیں مذاق بنا لیا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcxcvii{اور اُس شخص سے بڑھ کر ظالم اور کون ہے جسے اس کے رب کی آیات سنا کر نصیحت کی جائے اور وہ اُن سے منہ پھیرے اور اُس برے انجام کو بھول جائے جس کا سر و سامان اس نے اپنے لیے خود اپنے ہاتھوں کیا ہے؟ (جن لوگوں نے یہ روش اختیار کی ہے) ان کے دلوں پر ہم نے غلاف چڑھا دیے ہیں جو انہیں قرآن کی بات نہیں سمجھنے دیتے، اور اُن کے کانوں میں ہم نے گرانی پیدا کر دی ہے تم انہیں ہدایت کی طرف کتنا ہی بلاؤ، وہ اس حالت میں کبھی ہدایت نہ پائیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcxcviii{تیرا رب بڑا درگزر کرنے والا اور رحیم ہے وہ ان کے کرتوتوں پر انہیں پکڑنا چاہتا تو جلدی ہی عذاب بھیج دیتا مگر ان کے لیے وعدے کا ایک وقت مقرر ہے اور اس سے بچ کر بھاگ نکلنے کی یہ کوئی راہ نہ پائیں گے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcxcix{یہ عذاب رسیدہ بستیاں تمہارے سامنے موجود ہیں انہوں نے جب ظلم کیا تو ہم نے انہیں ہلاک کر دیا، اور ان میں سے ہر ایک کی ہلاکت کے لیے ہم نے وقت مقرر کر رکھا تھا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcc{(ذرا اِن کو وہ قصہ سناؤ جو موسیٰؑ کو پیش آیا تھا) جبکہ موسیٰؑ نے اپنے خادم سے کہا تھا کہ ``میں اپنا سفر ختم نہ کروں گا جب تک کہ دونوں دریاؤں کے سنگم پر نہ پہنچ جاؤں، ورنہ میں ایک زمانہ دراز تک چلتا ہی رہوں گا"\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcci{پس جب وہ ان کے سنگم پر پہنچے تو اپنی مچھلی سے غافل ہو گئے اور وہ نکل کر اس طرح دریا میں چلی گئی جیسے کہ کوئی سرنگ لگی ہو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmccii{آگے جا کر موسیٰؑ نے اپنے خادم سے کہا `` لاؤ ہمارا ناشتہ، آج کے سفر میں تو ہم بری طرح تھک گئے ہیں"\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcciii{خادم نے کہا ``آپ نے دیکھا! یہ کیا ہوا؟ جب ہم اُس چٹان کے پاس ٹھیرے ہوئے تھے اُس وقت مجھے مچھلی کا خیال نہ رہا اور شیطان نے مجھ کو ایسا غافل کر دیا کہ میں اس کا ذکر (آپ سے کرنا) بھول گیا مچھلی تو عجیب طریقے سے نکل کر دریا میں چلی گئی"\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcciv{موسیٰؑ نے کہا ``اسی کی تو ہمیں تلاش تھی" چنانچہ وہ دونوں اپنے نقش قدم پر پھر واپس ہوئے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmccv{اور وہاں انہوں نے ہمارے بندوں میں سے ایک بندے کو پایا جسے ہم نے اپنی رحمت سے نوازا تھا اور اپنی طرف سے ایک خاص علم عطا کیا تھا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmccvi{موسیٰؑ نے اس سے کہا ``کیا میں آپ کے ساتھ رہ سکتا ہوں تاکہ آپ مجھے بھی اُس دانش کی تعلیم دیں جو آپ کوسکھائی گئی ہے؟"\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmccvii{اس نے جواب دیا ``آپ میرے ساتھ صبر نہیں کر سکتے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmccviii{اور جس چیز کی آپ کو خبر نہ ہو آخر آپ اس پر صبر کر بھی کیسے سکتے ہیں"\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmccix{موسیٰؑ نے کہا ``انشاءاللہ آپ مجھے صابر پائیں گے اور میں کسی معاملہ میں آپ کی نافرمانی نہ کروں گا"\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmccx{اس نے کہا ``اچھا، اگر آپ میرے ساتھ چلتے ہیں تو مجھ سے کوئی بات نہ پوچھیں جب تک کہ میں خود اس کا آپ سے ذکر نہ کروں"\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmccxi{اب وہ دونوں روانہ ہوئے، یہاں تک کہ جب وہ ایک کشتی میں سوار ہو گئے تو اس شخص نے کشتی میں شگاف ڈال دیا موسیٰؑ نے کہا ``آپ نے اس میں شگاف ڈال دیا تاکہ سب کشتی والوں کو ڈبو دیں؟ یہ تو آپ نے ایک سخت حرکت کر ڈالی"\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmccxii{اس نے کہا ``میں نے تم سے کہا نہ تھا کہ تم میرے ساتھ صبر نہیں کر سکتے؟"\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmccxiii{موسیٰؑ نے کہا ``بھول چوک پر مجھے نہ پکڑیے میرے معاملے میں آپ ذرا سختی سے کام نہ لیں"\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmccxiv{پھر وہ دونوں چلے، یہاں تک کہ ان کو ایک لڑکا ملا اور اس شخص نے اسے قتل کر دیا موسیٰؑ نے کہا ``آپ نے ایک بے گناہ کی جان لے لی حالانکہ اُس نے کسی کا خون نہ کیا تھا؟ یہ کام تو آپ نے بہت ہی برا کیا"\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmccxv{اُس نے کہا `` میں نے تم سے کہا نہ تھا کہ تم میرے ساتھ صبر نہیں کر سکتے؟"\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmccxvi{موسیٰؑ نے کہا `` اس کے بعد اگر میں آپ سے کچھ پوچھوں تو آپ مجھے ساتھ نہ رکھیں لیجیے، اب تو میری طرف سے آپ کو عذر مل گیا"\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmccxvii{پھر وہ آگے چلے یہاں تک کہ ایک بستی میں پہنچے اور وہاں کے لوگوں سے کھانا مانگا مگر انہوں نے ان دونوں کی ضیافت سے انکار کر دیا وہاں انہوں نے ایک دیوار دیکھی جوگرا چاہتی تھی اُس شخص نے اس دیوار کو پھر قائم کر دیا موسیٰؑ نے کہا `` اگر آپ چاہتے تو اس کام کی اُجرت لے سکتے تھے"\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmccxviii{اُس نے کہا ``بس میرا تمہارا ساتھ ختم ہوا اب میں تمہیں ان باتوں کی حقیقت بتاتا ہوں جن پر تم صبر نہ کر سکے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmccxix{اُس کشتی کا معاملہ یہ ہے کہ وہ چند غریب آدمیوں کی تھی جو دریا میں محنت مزدوری کرتے تھے میں نے چاہا کہ اسے عیب دار کر دوں، کیونکہ آگے ایک ایسے بادشاہ کا علاقہ تھا جو ہر کشتی کو زبردستی چھین لیتا تھا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmccxx{رہا وہ لڑکا، تو اس کے والدین مومن تھے، ہمیں اندیشہ ہوا کہ یہ لڑکا اپنی سرکشی اور کفر سے ان کو تنگ کرے گا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmccxxi{اس لیے ہم نے چاہا کہ ان کا رب اس کے بدلے ان کو ایسی اولاد دے جو اخلاق میں بھی اس سے بہتر ہو اور جس سے صلہ رحمی بھی زیادہ متوقع ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmccxxii{اور اس دیوار کا معاملہ یہ ہے کہ یہ دو یتیم لڑکوں کی ہے جو اس شہر میں رہتے ہیں اس دیوار کے نیچے اِن بچّوں کے لیے ایک خزانہ مدفون ہے اور ان کا باپ ایک نیک آدمی تھا اس لیے تمہارے رب نے چاہا کہ یہ دونوں بچّے بالغ ہوں اور اپنا خزانہ نکال لیں یہ تمہارے رب کی رحمت کی بنا پرکیا گیا ہے، میں نے کچھ اپنے اختیار سے نہیں کر دیا ہے یہ ہے حقیقت اُن باتوں کی جن پر تم صبر نہ کر سکے"\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmccxxiii{اور اے محمدؐ، یہ لوگ تم سے ذوالقرنین کے بارے میں پوچھتے ہیں ان سے کہو، میں اس کا کچھ حال تم کو سناتا ہوں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmccxxiv{ہم نے اس کو زمین میں اقتدار عطا کر رکھا تھا اور اسے ہر قسم کے اسباب و وسائل بخشے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmccxxv{اس نے (پہلے مغرب کی طرف ایک مہم کا) سر و سامان کیا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmccxxvi{حتیٰ کہ جب وہ غروب آفتاب کی حَد تک پہنچ گیا تو اس نے سورج کو ایک کالے پانی میں ڈوبتے دیکھا اور وہاں اُسے ایک قوم ملی ہم نے کہا ``اے ذوالقرنین، تجھے یہ مقدرت بھی حاصل ہے کہ ان کو تکلیف پہنچائے اور یہ بھی کہ اِن کے ساتھ نیک رویّہ اختیار کرے"\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmccxxvii{اس نے کہا، ``جو ان میں سے ظلم کرے گا ہم اس کو سزا دیں گے، پھر وہ اپنے رب کی طرف پلٹایا جائے گا اور وہ اسے اور زیادہ سخت عذاب دے گا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmccxxviii{اور جو ان میں سے ایمان لائے گا اور نیک عمل کرے گا اُس کے لیے اچھی جزا ہے اور ہم اس کو نرم احکام دیں گے"\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmccxxix{پھر اُس نے (ایک دُوسری مہم کی) تیاری کی\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmccxxx{یہاں تک کہ طلوعِ آفتاب کی حد تک جا پہنچا وہاں اس نے دیکھا کہ سورج ایک ایسی قوم پر طلوع ہو رہا ہے جس کے لیے دُھوپ سے بچنے کا کوئی سامان ہم نے نہیں کیا ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmccxxxi{یہ حال تھا اُن کا، اور ذوالقرنین کے پاس جو کچھ تھا اُسے ہم جانتے تھے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmccxxxii{پھر اس نے (ایک اور مہم کا) سامان کیا\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiii{یہاں تک کہ جب دو پہاڑوں کے درمیان پہنچا تو اسے ان کے پاس ایک قوم ملی جو مشکل ہی سے کوئی بات سمجھتی تھی\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiv{اُن لوگوں نے کہا کہ ``اے ذوالقرنین، یاجوج اور ماجوج اس سرزمین میں فساد پھیلاتے ہیں تو کیا ہم تجھے کوئی ٹیکس اس کام کے لیے دیں کہ تو ہمارے اور ان کے درمیان ایک بند تعمیر کر دے؟"\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmccxxxv{اس نے کہا `` جو کچھ میرے رب نے مجھے دے رکھا ہے وہ بہت ہے تم بس محنت سے میری مدد کرو، میں تمہارے اور ان کے درمیان بند بنائے دیتا ہوں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvi{مجھے لوہے کی چادریں لا کر دو" آخر جب دونوں پہاڑوں کے درمیانی خلا کو اس نے پاٹ دیا تو لوگوں سے کہا کہ اب آگ دہکاؤ حتیٰ کہ جب (یہ آہنی دیوار) بالکل آگ کی طرح سُرخ ہو گئی تو اس نے کہا ``لاؤ، اب میں اس پر پگھلا ہوا تانبا انڈیلوں گا"\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvii{(یہ بند ایسا تھا کہ) یاجوج و ماجوج اس پر چڑھ کر بھی نہ آ سکتے تھے اور اس میں نقب لگانا ان کے لیے اور بھی مشکل تھا\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmccxxxviii{ذوالقرنین نے کہا `` یہ میرے رب کی رحمت ہے مگر جب میرے رب کے وعدے کا وقت آئیگا تو وہ اس کو پیوند خاک کر دے گا، اور میرے رب کا وعدہ برحق ہے"\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmccxxxix{اور اُس روز ہم لوگوں کو چھوڑ دیں گے کہ (سمندر کی موجوں کی طرح) ایک دُوسرے سے گتھم گتھا ہوں اور صُور پھُونکا جائے گا اور ہم سب انسانوں کو ایک ساتھ جمع کریں گے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmccxl{اور وہ دن ہوگا جب ہم جہنم کو کافروں کے سامنے لائیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmccxli{اُن کافروں کے سامنے جو میری نصیحت کی طرف سے اندھے بنے ہوئے تھے اور کچھ سننے کے لیے تیار ہی نہ تھے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmccxlii{تو کیا یہ لوگ، جنہوں نے کفر اختیار کیا ہے، یہ خیال رکھتے ہیں کہ مجھے چھوڑ کر میرے بندوں کو اپنا کارساز بنا لیں؟ ہم نے ایسے کافروں کی ضیافت کے لیے جہنم تیار کر رکھی ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmccxliii{اے محمدؐ، ان سے کہو، کیا ہم تمہیں بتائیں کہ اپنے اعمال میں سب سے زیادہ ناکام و نامراد لوگ کون ہیں؟\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmccxliv{وہ کہ دنیا کی زندگی میں جن کی ساری سعی و جہد راہِ راست سے بھٹکی رہی اور وہ سمجھتے رہے کہ وہ سب کچھ ٹھیک کر رہے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmccxlv{یہ وہ لوگ ہیں جنہوں نے اپنے رب کی آیات کو ماننے سے انکار کیا اور اس کے حضور پیشی کا یقین نہ کیا اس لیے اُن کے سارے اعمال ضائع ہو گئے، قیامت کے روز ہم انہیں کوئی وزن نہ دیں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmccxlvi{ان کی جزا جہنم ہے اُس کفر کے بدلے جو انہوں نے کیا اور اُس مذاق کی پاداش میں جو وہ میری آیات اور میرے رسولوں کے ساتھ کرتے رہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmccxlvii{البتّہ وہ لوگ جو ایمان لائے اور جنہوں نے نیک عمل کیے، ان کی میزبانی کے لیے فردوس کے باغ ہوں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmccxlviii{جن میں وہ ہمیشہ رہیں گے اور کبھی اُس جگہ سے نکل کر کہیں جانے کو اُن کا جی نہ چاہے گا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmccxlix{اے محمدؐ، کہو کہ اگر سمندر میرے رب کی باتیں لکھنے کے لیے روشنائی بن جائے تو وہ ختم ہو جائے مگر میرے رب کی باتیں ختم نہ ہوں، بلکہ اتنی ہی روشنائی ہم اور لے آئیں تو وہ بھی کفایت نہ کرے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmccl{اے محمدؐ، کہو کہ میں تو ایک انسان ہوں تم ہی جیسا، میری طرف وحی کی جاتی ہے کہ تمہارا خدا بس ایک ہی خدا ہے، پس جو کوئی اپنے رب کی ملاقات کا امیدوار ہو اسے چاہیے کہ نیک عمل کرے اور بندگی میں اپنے رب کے ساتھ کسی اور کو شریک نہ کرے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmccli{\basmalahur ک، ہ، ی، ع، ص\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcclii{ذکر ہے اُس رحمت کا جو تیرے رب نے اپنے بندے زکریاؑ پر کی تھی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmccliii{جبکہ اُس نے اپنے رب کو چپکے چپکے پکارا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccliv{اُس نے عرض کیا ``اے پروردگار، میری ہڈیاں تک گھل گئی ہیں اور سر بڑھاپے سے بھڑک اٹھا ہے اے پروردگار، میں کبھی تجھ سے دعا مانگ کر نامراد نہیں رہا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcclv{مجھے اپنے پیچھے اپنے بھائی بندوں کی برائیوں کا خوف ہے، اور میری بیوی بانجھ ہے تو مجھے اپنے فضلِ خاص سے ایک وارث عطا کر دے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcclvi{جو میرا وارث بھی ہو اور آلِ یعقوب کی میراث بھی پائے، اور اے پروردگار، اُس کو ایک پسندیدہ انسان بنا"\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcclvii{(جواب دیا گیا) ``اے زکریاؑ، ہم تجھے ایک لڑکے کی بشارت دیتے ہیں جس کا نام یحییٰؑ ہو گا ہم نے اِس نام کا کوئی آدمی اس سے پہلے پیدا نہیں کیا"\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcclviii{عرض کیا، ``پروردگار، بھلا میرے ہاں کیسے بیٹا ہوگا جبکہ میری بیوی بانجھ ہے اور میں بوڑھا ہو کر سوکھ چکا ہوں؟"\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcclix{جواب ملا ``ایسا ہی ہو گا تیرا رب فرماتا ہے کہ یہ تو میرے لیے ایک ذرا سی بات ہے، آخر اس سے پہلے میں تجھے پیدا کر چکا ہوں جب کہ تو کوئی چیز نہ تھا"\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcclx{زکریاؑ نے کہا، ``پروردگار، میرے لیے کوئی نشانی مقرر کر دے" فرمایا ``تیرے لیے نشانی یہ ہے کہ تو پیہم تین دن لوگوں سے بات نہ کر سکے"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcclxi{چنانچہ وہ محراب سے نکل کر اپنی قوم کے سامنے آیا اور اس نے اشارے سے ان کو ہدایت کی کہ صبح و شام تسبیح کرو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcclxii{``اے یحییٰؑ! کتاب الٰہی کو مضبوط تھام لے" ہم نے اُسے بچپن ہی میں ``حکم" سے نوازا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcclxiii{اور اپنی طرف سے اس کو نرم دلی اور پاکیزگی عطا کی اور وہ بڑا پرہیزگار\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcclxiv{اور اپنے والدین کا حق شناس تھا وہ جبّار نہ تھا اور نہ نافرمان\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcclxv{سلام اُس پر جس روز کہ وہ پیدا ہوا اور جس دن وہ مرے اور جس روز وہ زندہ کر کے اٹھایا جائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcclxvi{اور اے محمدؐ، اس کتاب میں مریم کا حال بیان کرو، جبکہ وہ اپنے لوگوں سے الگ ہو کر شرقی جانب گوشہ نشین ہو گئی تھی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcclxvii{اور پردہ ڈال کر اُن سے چھپ بیٹھی تھی اس حالت میں ہم نے اس کے پاس اپنی روح کو (یعنی فرشتے کو) بھیجا اور وہ اس کے سامنے ایک پورے انسان کی شکل میں نمودار ہو گیا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcclxviii{مریم یکایک بول اٹھی کہ"اگر تو کوئی خدا ترس آدمی ہے تو میں تجھ سے رحمٰن کی پناہ مانگتی ہوں"\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcclxix{اُس نے کہا ``میں تو تیرے رب کا فرستادہ ہوں اور اس لیے بھیجا گیا ہوں کہ تجھے ایک پاکیزہ لڑکا دوں"\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcclxx{مریم نے کہا ``میرے ہاں کیسے لڑکا ہوگا جبکہ مجھے کسی بشر نے چھوا تک نہیں ہے اور میں کوئی بدکار عورت نہیں ہوں"\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcclxxi{فرشتے نے کہا ``ایسا ہی ہوگا، تیرا رب فرماتا ہے کہ ایسا کرنا میرے لیے بہت آسان ہے اور ہم یہ اس لیے کریں گے کہ اُس لڑکے کو لوگوں کے لیے ایک نشانی بنائیں اور اپنی طرف سے ایک رحمت اور یہ کام ہو کر رہنا ہے"\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcclxxii{مریم کو اس بچے کا حمل رہ گیا اور وہ اس حمل کو لیے ہوئے ایک دُور کے مقام پر چلی گئی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiii{پھر زچگی کی تکلیف نے اُسے ایک کھُجور کے درخت کے نیچے پہنچا دیا وہ کہنے لگی `` کاش میں اس سے پہلے ہی مر جاتی اور میرا نام و نشان نہ رہتا"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiv{فرشتے نے پائنتی سے اس کو پکار کر کہا ``غم نے کر تیرے رب نے تیرے نیچے ایک چشمہ رواں کر دیا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcclxxv{اور تو ذرا اِس درخت کے تنے کو ہلا، تیرے اوپر تر و تازہ کھجوریں ٹپک پڑیں گی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvi{پس تو کھا اور پی اور اپنی آنکھیں ٹھنڈی کر پھر اگر کوئی آدمی تجھے نظر آئے تو اس سے کہہ دے کہ میں نے رحمان کے لیے روزے کی نذر مانی ہے، اس لیے آج میں کسی سے نہ بولوں گی"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvii{پھر وہ اس بچے کو لیے ہوئے اپنی قوم میں آئی لوگ کہنے لگے `` اے مریم، یہ تو تُو نے بڑا پاپ کر ڈالا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcclxxviii{اے ہارون کی بہن، نہ تیرا باپ کوئی برا آدمی تھا اور نہ تیری ماں ہی کوئی بدکار عورت تھی"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcclxxix{مریم نے بچے کی طرف اشارہ کر دیا لوگوں نے کہا `` ہم اِس سے کیا بات کریں جو گہوارے میں پڑا ہوا ایک بچہ ہے؟"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcclxxx{بچہ بول اٹھا ``میں اللہ کا بندہ ہوں اُس نے مجھے کتاب دی، اور نبی بنایا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxi{اور بابرکت کیا جہاں بھی میں رہوں، اور نماز اور زکوٰۃ کی پابندی کا حکم دیا جب تک میں زندہ رہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxii{اور اپنی والدہ کا حق ادا کرنے والا بنایا، اور مجھ کو جبّار اور شقی نہیں بنایا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiii{سلام ہے مجھ پر جبکہ میں پیدا ہوا اور جبکہ میں مروں اور جبکہ زندہ کر کے اٹھایا جاؤں"\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiv{یہ ہے عیسٰی ابن مریم اور یہ ہے اُس کے بارے میں وہ سچی بات جس میں لوگ شک کر رہے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxv{اللہ کا یہ کام نہیں ہے کہ وہ کسی کو بیٹا بنائے وہ پاک ذات ہے وہ جب کسی بات کا فیصلہ کرتا ہے تو کہتا ہے کہ ہو جا، اور بس وہ ہو جاتی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvi{(اور عیسٰیؑ نے کہا تھا کہ) ``اللہ میرا رب بھی ہے اور تمہارا رب بھی، پس تم اُسی کی بندگی کرو، یہی سیدھی راہ ہے"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvii{مگر پھر مختلف گروہ باہم اختلاف کرنے لگے سو جن لوگوں نے کفر کیا ان کے لیے وہ وقت بڑی تباہی کا ہوگا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxviii{جب کہ وہ ایک بڑا دن دیکھیں گے جب وہ ہمارے سامنے حاضر ہوں گے اُس روز تو اُن کے کان بھی خوب سُن رہے ہوں گے اور اُن کی آنکھیں بھی خوب دیکھتی ہوں گی، مگر آج یہ ظالم کھلی گمراہی میں مبتلا ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxix{اے نبیؐ، اِس حالت میں جبکہ یہ لوگ غافل ہیں اور ایمان نہیں لا رہے ہیں، اِنہیں اس دن سے ڈرا دو جبکہ فیصلہ کر دیا جائے گا اور پچھتاوے کے سوا کوئی چارہ کار نہ ہوگا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccxc{آخرکار ہم ہی زمین اور اس کی ساری چیزوں کے وارث ہوں گے اور سب ہماری طرف ہی پلٹائے جائیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccxci{اور اس کتاب میں ابراہیمؑ کا قصہ بیان کرو، بے شک وہ ایک راست باز انسان اور ایک نبی تھا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmccxcii{(انہیں ذرا اُس موقع کی یاد دلاؤ) جبکہ اُس نے اپنے باپ سے کہا کہ ``ابّا جان، آپ کیوں اُن چیزوں کی عبادت کرتے ہیں جو نہ سنتی ہیں نہ دیکھتی ہیں اور نہ آپ کا کوئی کام بنا سکتی ہیں؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmccxciii{ابّا جان، میرے پاس ایک ایسا عِلم آیا ہے جو آپ کے پاس نہیں آیا، آپ میرے پیچھے چلیں، میں آپ کو سیدھا راستہ بتاؤں گا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmccxciv{ابّا جان! آپ شیطان کی بندگی نہ کریں، شیطان تو رحمٰن کا نافرمان ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmccxcv{ابّا جان، مجھے ڈر ہے کہ کہیں آپ رحمان کے عذاب میں مُبتلا نہ ہو جائیں اور شیطان کے ساتھی بن کر رہیں"\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmccxcvi{باپ نے کہا ``ابراہیمؑ، کیا تو میرے معبُودوں سے پھر گیا ہے؟ اگر تو باز نہ آیا تو میں تجھے سنگسار کر دوں گا بس تو ہمیشہ کے لیے مجھ سے الگ ہو جا"\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmccxcvii{ابراہیمؑ نے کہا ``سلام ہے آپ کو میں اپنے رب سے دُعا کروں گا کہ آپ کو معاف کر دے، میرا رب مجھ پر بڑا ہی مہربان ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmccxcviii{میں آپ لوگوں کو بھی چھوڑتا ہوں اور اُن ہستیوں کو بھی جنہیں آپ لوگ خدا کو چھوڑ کر پکارا کرتے ہیں میں تو اپنے رب ہی کو پکاروں گا، امید ہے کہ میں اپنے رب کو پکار کے نامراد نہ رہوں گا"\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmccxcix{پس جب وہ اُن لوگوں سے اور اُن کے معبُودانِ غیر اللہ سے جُدا ہو گیا تو ہم نے اُس کو اسحاقؑ اور یعقوبؑ جیسی اولاد دی اور ہر ایک کو نبی بنایا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmccc{اور ان کو اپنی رحمت سے نوازا اور ان کو سچی ناموری عطا کی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmccci{اور ذکر کرو اس کتاب میں موسیٰؑ کا وہ ایک چیدہ شخص تھا اور رسول نبی تھا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcccii{ہم نے اُس کو طُور کے داہنی جانب سے پکارا اور راز کی گفتگو سے اس کو تقرب عطا کیا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmccciii{اور اپنی مہربانی سے اس کے بھائی ہارونؑ کو نبی بنا کر اُسے (مدد گار کے طور پر) دیا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmccciv{اور اس کتاب میں اسماعیلؑ کا ذکر کرو وہ وعدے کا سچا تھا اور رسُول نبی تھا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcccv{وہ اپنے گھر والوں کو نماز اور زکوٰۃ کا حکم دیتا تھا اور اپنے رب کے نزدیک ایک پسندیدہ انسان تھا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcccvi{اور اس کتاب میں ادریسؑ کا ذکر کرو وہ ایک راستباز انسان اور ایک نبی تھا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcccvii{اور اسے ہم نے بلند مقام پر اٹھایا تھا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcccviii{یہ وہ پیغمبر ہیں جن پر اللہ نے انعام فرمایا آدمؑ کی اولاد میں سے، اور اُن لوگوں کی نسل سے جنہیں ہم نے نوحؑ کے ساتھ کشتی پر سوار کیا تھا، ا ور ابراہیمؑ کی نسل سے اور اسرائیلؑ کی نسل سے اور یہ ان لوگوں میں سے تھے جن کو ہم نے ہدایت بخشی اور برگزیدہ کیا ان کا حال یہ تھا کہ جب رحمان کی آیات ان کو سنائی جاتیں تو روتے ہوئے سجدے میں گر جاتے تھے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcccix{پھر ان کے بعد وہ ناخلف لوگ ان کے جانشین ہوئے جنہوں نے نماز کو ضائع کیا اور خواہشاتِ نفس کی پیروی کی، پس قریب ہے کہ وہ گمراہی کے انجام سے دوچار ہوں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcccx{البتہ جو توبہ کر لیں اور ایمان لے آئیں اور نیک عملی اختیار کر لیں وہ جنّت میں داخل ہوں گے اور ان کی ذرّہ برابر حق تلفی نہ ہو گی\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcccxi{ان کے لیے ہمیشہ رہنے والی جنتیں ہیں جن کا رحمان نے اپنے بندوں سے در پردہ وعدہ کر رکھا ہے اور یقیناً یہ وعدہ پُورا ہو کر رہنا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcccxii{وہاں وہ کوئی بے ہودہ بات نہ سُنیں گے، جو کچھ بھی سُنیں گے ٹھیک ہی سنیں گے اور ان کا رزق انہیں پیہم صبح و شام ملتا رہے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcccxiii{یہ ہے وہ جنت جس کا وارث ہم اپنے بندوں میں سے اُس کو بنائیں گے جو پرہیزگار رہا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcccxiv{اے محمدؐ، ہم تمہارے رب کے حکم کے بغیر نہیں اُترا کرتے جو کچھ ہمارے آگے ہے اور جو کچھ پیچھے ہے اور جو کچھ اس کے درمیان ہے ہر چیز کا مالک وہی ہے اور تمہارا رب بھولنے والا نہیں ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcccxv{وہ رب ہے آسمانوں کا اور زمین کا اور اُن ساری چیزوں کا جو آسمان و زمین کے درمیان ہیں پس تم اُس کے بندگی کرو اور اُسی کی بندگی پر ثابت قدم رہو کیا ہے کوئی ہستی تمہارے علم میں اس کی ہم پایہ؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcccxvi{انسان کہتا ہے کیا واقعی جب میں مر چکوں گا تو پھر زندہ کر کے نکال لایا جاؤں گا؟\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcccxvii{کیا انسان کو یاد نہیں آتا کہ ہم پہلے اس کو پیدا کر چکے ہیں جبکہ وہ کچھ بھی نہ تھا؟\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcccxviii{تیرے رب کی قسم، ہم ضرور ان سب کو اور ان کے ساتھ شیاطین کو بھی گھیر لائیں گے، پھر جہنم کے گرد لا کر انہیں گھٹنوں کے بل گرا دیں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcccxix{پھر ہر گروہ میں سے ہر اُس شخص کو چھانٹ لیں گے جو رحمان کے مقابلے میں زیادہ سرکش بنا ہُوا تھا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcccxx{پھر یہ ہم جانتے ہیں کہ ان میں سے کون سب سے بڑھ کر جہنم میں جھونکے جانے کا مستحق ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcccxxi{تم میں سے کوئی ایسا نہیں ہے جو جہنم پر وارد نہ ہو، یہ تو ایک طے شدہ بات ہے جسے پُورا کرنا تیرے رب کا ذمہ ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcccxxii{پھر ہم اُن لوگوں کو بچا لیں گے جو (دنیا میں) متقی تھے اور ظالموں کو اُسی میں گرا ہُوا چھوڑ دیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiii{اِن لوگوں کو جب ہماری کھُلی کھُلی آیات سنائی جاتی ہیں تو انکار کرنے والے ایمان لانے والوں سے کہتے ہیں ``بتاؤ ہم دونوں گروہوں میں سے کون بہتر حالت میں ہے اور کس کی مجلسیں زیادہ شاندار ہیں؟"\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiv{حالانکہ ان سے پہلے ہم کتنی ہی ایسی قوموں کو ہلاک کر چکے ہیں جو اِن سے زیادہ سر و سامان رکھتی تھیں اور ظاہری شان و شوکت میں اِن سے بڑھی ہوئی تھیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcccxxv{اِن سے کہو، جو شخص گمراہی میں مُبتلا ہوتا ہے اُسے رحمان ڈھیل دیا کرتا ہے یہاں تک کہ جب ایسے لوگ وہ چیز دیکھ لیتے ہیں جس کا اُن سے وعدہ کیا گیا ہے خواہ وہ عذاب الٰہی ہو یا قیامت کی گھڑی تب انہیں معلوم ہو جاتا ہے کہ کس کا حال خراب ہے اور کس کا جتھا کمزور!\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvi{اس کے برعکس جو لوگ راہِ راست اختیار کرتے ہیں اللہ ان کو راست روی میں ترقی عطا فرماتا ہے اور باقی رہ جانے والی نیکیاں ہی تیرے رب کے نزدیک جزا اور انجام کے اعتبار سے بہتر ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvii{پھر تو نے دیکھا اُس شخص کو جو ہماری آیات کو ماننے سے انکار کرتا ہے اور کہتا ہے کہ میں تو مال اور اولاد سے نوازا ہی جاتا رہوں گا؟\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcccxxviii{کیا اسے غیب کا پتہ چل گیا ہے یا اس نے رحمان سے کوئی عہد لے رکھا ہے؟\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcccxxix{ہرگز نہیں، جو کچھ یہ بکتا ہے اسے ہم لکھ لیں گے اور اس کے لیے سزا میں اور زیادہ اضافہ کریں گے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcccxxx{جس سر و سامان اور لاؤ لشکر کا یہ ذکر کر رہا ہے وہ سب ہمارے پاس رہ جائے گا اور یہ اکیلا ہمارے سامنے حاضر ہوگا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxi{اِن لوگوں نے اللہ کو چھوڑ کر اپنے کچھ خدا بنا رکھے ہیں تاکہ وہ اِن کے پشتیبان ہوں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxii{کوئی پشتیبان نہ ہوگا وہ سب ان کی عبادت کا انکار کریں گے اور الٹے اِن کے مخالف بن جائیں گے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiii{کیا تم دیکھتے نہیں ہو کہ ہم نے اِن منکرین حق پر شیاطین چھوڑ رکھے ہیں جو اِنہیں خُوب خُوب (مخالفتِ حق پر) اکسا رہے ہیں؟\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiv{اچھا، تو اب اِن پر نزول عذاب کے لیے بیتاب نہ ہو ہم اِن کے دن گن رہے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxv{وہ دن آنے والا ہے جب متقی لوگوں کو ہم مہمانوں کی طرح رحمان کے حضور پیش کریں گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvi{اور مجرموں کو پیاسے جانوروں کی طرح جہنم کی طرف ہانک لے جائیں گے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvii{اُس وقت لوگ کوئی سفارش لانے پر قادر نہ ہوں گے بجز اُس کے جس نے رحمان کے حضور سے پروانہ حاصل کر لیا ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxviii{وہ کہتے ہیں کہ رحمان نے کسی کو بیٹا بنایا ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxix{سخت بیہودہ بات ہے جوتم لوگ گھڑ لائے ہو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcccxl{قریب ہے کہ آسمان پھٹ پڑیں، زمین شق ہو جائے اور پہاڑ گر جائیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcccxli{اس بات پر کہ لوگوں نے رحمان کے لیے اولاد ہونے کا دعویٰ کیا!\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcccxlii{رحمان کی یہ شان نہیں ہے کہ وہ کسی کو بیٹا بنائے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcccxliii{زمین اور آسمان کے اندر جو بھی ہیں سب اس کے حضور بندوں کی حیثیت سے پیش ہونے والے ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcccxliv{سب پر وہ محیط ہے اور اس نے اُن کو شمار کر رکھا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcccxlv{سب قیامت کے روز فرداً فرداً اس کے سامنے حاضر ہوں گے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvi{یقیناً جو لوگ ایمان لے آئے ہیں اور عمل صالح کر رہے ہیں عنقریب رحمان اُن کے لیے دلوں میں محبت پیدا کر دے گا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvii{پس اے محمدؐ، اِس کلام کو ہم نے آسان کر کے تمہاری زبان میں اسی لیے نازل کیا ہے کہ تم پرہیز گاروں کو خوشخبری دے دو اور ہٹ دھرم لوگوں کو ڈرا دو\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcccxlviii{ان سے پہلے ہم کتنی ہی قوموں کو ہلاک کر چکے ہیں، پھر آج کہیں تم ان کا نشان پاتے ہو یا اُن کی بھنک بھی کہیں سنائی دیتی ہے؟\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcccxlix{\basmalahur طٰہٰ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcccl{ہم نے یہ قرآن تم پر اس لیے نازل نہیں کیا ہے کہ تم مصیبت میں پڑ جاؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcccli{یہ تو ایک یاد دہانی ہے ہر اس شخص کے لیے جو ڈرے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccclii{نازل کیا گیا ہے اُس ذات کی طرف سے جس نے پیدا کیا ہے زمین کو اور بلند آسمانوں کو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcccliii{وہ رحمان (کائنات کے) تخت سلطنت پر جلوہ فرما ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcccliv{مالک ہے اُن سب چیزوں کا جو آسمانوں اور زمین میں ہیں اور جو زمین و آسمان کے درمیان میں ہیں اور جو مٹی کے نیچے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmccclv{تم چاہے اپنی بات پکار کر کہو، وہ تو چپکے سے کہی ہوئی بات بلکہ اس سے مخفی تر بات بھی جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmccclvi{وہ اللہ ہے، اس کے سوا کوئی خدا نہیں، اس کے لیے بہترین نام ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmccclvii{اور تمہیں کچھ موسیٰؑ کی خبر بھی پہنچی ہے؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmccclviii{جب کہ اس نے ایک آگ دیکھی اور اپنے گھر والوں سے کہا کہ `` ذرا ٹھیرو، میں نے ایک آگ دیکھی ہے، شاید کہ تمہارے لیے ایک آدھ انگارا لے آؤں، یا اِس آگ پر مجھے (راستے کے متعلق) کوئی رہنمائی مل جائے"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmccclix{وہاں پہنچا تو پکارا گیا ``اے موسیٰؑ!\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmccclx{میں ہی تیرا رب ہوں، جوتیاں اتار دے تو وادی مقدس طویٰ میں ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmccclxi{اور میں نے تجھ کو چُن لیا ہے، سُن جو کچھ وحی کیا جاتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmccclxii{میں ہی اللہ ہوں، میرے سوا کوئی خدا نہیں ہے، پس تو میری بندگی کر اور میری یاد کے لیے نماز قائم کر\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmccclxiii{قیامت کی گھڑی ضرور آنے والی ہے میں اُس کا وقت مخفی رکھنا چاہتا ہوں، تاکہ ہر متنفّس اپنی سعی کے مطابق بدلہ پائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmccclxiv{پس کوئی ایسا شخص جو اُس پر ایمان نہیں لاتا اور اپنی خواہش نفس کا بندہ بن گیا ہے تجھ کو اُس گھڑی کی فکر سے نہ روک دے، ورنہ تو ہلاکت میں پڑ جائے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmccclxv{اور اے موسیٰؑ، یہ تیرے ہاتھ میں کیا ہے؟"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmccclxvi{موسیٰؑ نے جواب دیا ``یہ میری لاٹھی ہے، اس پر ٹیک لگا کر چلتا ہوں، اس سے اپنی بکریوں کے لیے پتے جھاڑتا ہوں، اور بھی بہت سے کام ہیں جو اس سے لیتا ہوں"\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmccclxvii{فرمایا ``پھینک دے اس کو موسیٰؑ"\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmccclxviii{اس نے پھینک دیا اور یکایک وہ ایک سانپ تھی جو دَوڑ رہا تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmccclxix{فرمایا ``پکڑ لے اس کو اور ڈر نہیں، ہم اسے پھر ویسا ہی کر دیں گے جیسی یہ تھی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmccclxx{اور ذرا اپنا ہاتھ اپنی بغل میں دبا، چمکتا ہوا نکلے گا بغیر کسی تکلیف کے یہ دوسری نشانی ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmccclxxi{اس لیے کہ ہم تجھے اپنی بڑی نشانیاں دکھانے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmccclxxii{اب تو فرعون کے پاس جا، وہ سرکش ہو گیا ہے"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiii{موسیٰؑ نے عرض کیا `` پروردگار، میرا سینہ کھول دے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiv{اور میرے کام کو میرے لیے آسان کر دے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmccclxxv{اور میری زبان کی گرہ سُلجھا دے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvi{تاکہ لوگ میری بات سمجھ سکیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvii{اور میرے لیے میرے اپنے کنبے سے ایک وزیر مقرر کر دے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmccclxxviii{ہارونؑ، جو میرا بھائی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmccclxxix{اُس کے ذریعہ سے میرا ہاتھ مضبُوط کر\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmccclxxx{اور اس کو میرے کام میں شریک کر دے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxi{تاکہ ہم خوب تیری پاکی بیان کریں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxii{اور خوب تیرا چرچا کریں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiii{تو ہمیشہ ہمارے حال پر نگران رہا ہے"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiv{فرمایا ``دیا گیا جو تو نے مانگا اے موسیٰؑ\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxv{ہم نے پھر ایک مرتبہ تجھ پر احسان کیا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvi{یاد کر وہ وقت جبکہ ہم نے تیری ماں کو اشارہ کیا ایسا اشارہ جو وحی کے ذریعہ سے ہی کیا جاتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvii{کہ اس بچے کو صندوق میں رکھ دے اور صندوق کو دریا میں چھوڑ دے دریا اسے ساحل پر پھینک دے گا اور اسے میرا دشمن اور اس بچے کا دشمن اٹھا لے گا میں نے اپنی طرف سے تجھ پر محبت طاری کر دی اور ایسا انتظام کیا کہ تو میری نگرانی میں پالا جائے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxviii{یاد کر جبکہ تیری بہن چل رہی تھی، پھر جا کر کہتی ہے، ``میں تمہیں اُس کا پتہ دوں جو اِس بچے کی پرورش اچھی طرح کرے؟" اس طرح ہم نے تجھے پھر تیری ماں کے پاس پہنچا دیا تاکہ اُس کی آنکھ ٹھنڈی رہے اور وہ رنجیدہ نہ ہو اور (یہ بھی یاد کر کہ) تو نے ایک شخص کو قتل کر دیا تھا، ہم نے تجھے اِس پھندے سے نکالا اور تجھے مختلف آزمائشوں سے گزارا اور تو مَدیَن کے لوگوں میں کئی سال ٹھیرا رہا پھر اب ٹھیک اپنے وقت پر تو آ گیا ہے اے موسیٰؑ\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxix{میں نے تجھ کو اپنے کام کا بنا لیا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcccxc{جا، تُو اور تیرا بھائی میری نشانیوں کے ساتھ ا ور دیکھو، تم میری یاد میں تقصیر نہ کرنا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcccxci{جاؤ تم دونوں فرعون کے پاس کہ وہ سرکش ہو گیا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcccxcii{اس سے نرمی کے ساتھ بات کرنا، شاید کہ وہ نصیحت قبول کرے یا ڈر جائے"\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcccxciii{دونوں نے عرض کیا `` پروردگار، ہمیں اندیشہ ہے کہ وہ ہم پر زیادتی کرے گا یا پل پڑے گا"\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcccxciv{فرمایا `` ڈرو مت، میں تمہارے ساتھ ہوں، سب کچھ سُن رہا ہوں اور دیکھ رہا ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcccxcv{جاؤ اس کے پاس اور کہو کہ ہم تیرے رب کے فرستادے ہیں، بنی اسرائیل کو ہمارے ساتھ جانے کے لیے چھوڑ دے اور ان کو تکلیف نہ دے ہم تیرے پاس تیرے رب کی نشانی لے کر آئے ہیں اور سلامتی ہے اُس کے لیے جو راہِ راست کی پیروی کرے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvi{ہم کو وحی سے بتایا گیا ہے کہ عذاب ہے اُس کے لیے جو جھُٹلائے اور منہ موڑے"\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvii{فرعون نے کہا `` اچھا، تو پھر تم دونوں کا رب کون ہے اے موسیٰؑ؟"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcccxcviii{موسیٰؑ نے جواب دیا ``ہمارا رب وہ ہے جس نے ہر چیز کو اُس کی ساخت بخشی، پھر اس کو راستہ بتایا"\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcccxcix{فرعون بولا ``اور پہلے جو نسلیں گزر چکی ہیں ان کی پھر کیا حالت تھی؟"\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcd{موسیٰؑ نے کہا ``اُس کا علم میرے رب کے پاس ایک نوشتے میں محفوظ ہے میرا رب نہ چُوکتا ہے نہ بھُولتا ہے"\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcdi{وہی جس نے تمہارے لیے زمین کا فرش بچھایا، اور اُس میں تمہارے چلنے کو راستے بنائے، اور اوپر سے پانی برسایا، پھر اُس کے ذریعہ سے مختلف اقسام کی پیداوار نکالی\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcdii{کھاؤ اور اپنے جانوروں کو بھی چَراؤ یقیناً اِس میں بہت سی نشانیاں ہیں عقل رکھنے والوں کے لیے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcdiii{اِسی زمین سے ہم نے تم کو پیدا کیا ہے، اِسی میں ہم تمہیں واپس لے جائیں گے اور اسی سے تم کو دوبارہ نکالیں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcdiv{ہم نے فرعون کو اپنی سب ہی نشانیاں دکھائیں مگر وہ جھٹلائے چلا گیا اور نہ مانا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcdv{کہنے لگا ``اے موسیٰؑ، کیا تو ہمارے پاس اس لیے آیا ہے کہ اپنے جادو کے زور سے ہم کو ہمارے ملک سے نکال باہر کرے؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcdvi{اچھا، ہم بھی تیرے مقابلے میں ویساہی جادو لاتے ہیں طے کر لے کب اور کہاں مقابلہ کرنا ہے نہ ہم اِس قرارداد سے پھریں گے نہ تو پھریو کھُلے میدان میں سامنے آ جا"\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcdvii{موسیٰؑ نے کہا ``جشن کا دن طے ہوا، ا ور دن چڑھے لوگ جمع ہوں"\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcdviii{فرعون نے پلٹ کر اپنے سارے ہتھکنڈے جمع کیے اور مقابلے میں آ گیا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcdix{موسیٰؑ نے (عین موقع پر گروہ مقابل کو مخاطب کر کے) کہا ``شامت کے مارو، نہ جھُوٹی تہمتیں باندھو اللہ پر، ورنہ وہ ایک سخت عذاب سے تمہارا ستیاناس کر دے گا جھوٹ جس نے بھی گھڑا وہ نامراد ہوا"\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcdx{یہ سُن کر اُن کے درمیان اختلاف رائے ہو گیا اور وہ چپکے چپکے باہم مشورہ کرنے لگے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcdxi{آخر کار کچھ لوگو ں نے کہا کہ ``یہ دونوں تو محض جادوگر ہیں اِن کا مقصد یہ ہے کہ اپنے جادو کے زور سے تم کو تمہاری زمین سے بے دخل کر دیں اور تمہارے مثالی طریق زندگی کا خاتمہ کر دیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcdxii{اپنی ساری تدبیریں آج اکٹھی کر لو اور اَیکا کر کے میدان میں آؤبس یہ سمجھ لو کہ آج جو غالب رہا وہی جیت گیا"\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcdxiii{جادوگر بولے ``موسیٰؑ، تم پھینکتے ہو یا پہلے ہم پھینکیں؟"\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcdxiv{موسیٰؑ نے کہا ``نہیں، تم ہی پھینکو" یکایک اُن کی رسّیاں اور اُن کی لاٹھیاں اُن کے جادو کے زور سے موسیٰؑ کو دَوڑتی ہوئی محسوس ہونے لگیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcdxv{اور موسیٰؑ اپنے دل میں ڈر گیا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcdxvi{ہم نے کہا ``مت ڈر، تو ہی غالب رہے گا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcdxvii{پھینک جو کچھ تیرے ہاتھ میں ہے، ابھی اِن کی ساری بناوٹی چیزوں کو نگلے جاتا ہے یہ جو کچھ بنا کر لائے ہیں یہ تو جادوگر کا فریب ہے، اور جادوگر کبھی کامیاب نہیں ہو سکتا، خواہ کسی شان سے وہ آئے"\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcdxviii{آخر کو یہی ہُوا کہ سارے جادوگر سجدے میں گرا دیے گئے اور پکار اٹھے ``مان لیا ہم نے ہارونؑ اور موسیٰؑ کے رب کو"\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcdxix{فرعون نے کہا `` تم ایمان لے آئے قبل اس کے کہ میں تمہیں اس کی اجازت دیتا؟ معلوم ہو گیا کہ یہ تمہارا گرو ہے جس نے تمہیں جادوگری سکھائی تھی اچھا، اب میں تمہارے ہاتھ پاؤں مخالف سمتوں سے کٹواتا ہوں اور کھجور کے تنوں پر تم کو سُولی دیتا ہوں پھر تمہیں پتہ چل جائے گا کہ ہم دونوں میں سے کس کا عذاب زیادہ سخت اور دیر پا ہے" (یعنی میں تمہیں زیادہ سخت سزا دے سکتا ہوں یا موسیٰؑ)\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcdxx{جادوگروں نے جواب دیا ``قسم ہے اُس ذات کی جس نے ہمیں پیدا کیا ہے، یہ ہرگز نہیں ہو سکتا کہ ہم روشن نشانیاں سامنے آ جانے کے بعد بھی (صداقت پر) تجھے ترجیح دیں، تُو جو کچھ کرنا چاہے کر لے تو زیادہ سے زیادہ بس اِسی دُنیا کی زندگی کا فیصلہ کر سکتا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcdxxi{ہم تو اپنے رب پر ایمان لے آئے تاکہ وہ ہماری خطائیں معاف کر دے اور اس جادوگری سے، جس پر تو نے ہمیں مجبور کیا تھا، درگزر فرمائے اللہ ہی اچھا ہے اور وہی باقی رہنے والا ہے"\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcdxxii{حقیقت یہ ہے کہ جو مجرم بن کر اپنے رب کے حضور حاضر ہوگا اُس کے لیے جہنم ہے جس میں وہ نہ جیے گا نہ مرے گا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiii{اور جو اس کے حضور مومن کی حیثیت سے حاضر ہو گا، جس نے نیک عمل کیے ہوں گے، ایسے سب لوگوں کے لیے بلند درجے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiv{سدا بہار باغ ہیں جن کے نیچے نہریں بہہ رہی ہوں گی، ان میں وہ ہمیشہ رہیں گے یہ جزا ہے اُس شخص کی جو پاکیزگی اختیار کرے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcdxxv{ہم نے موسیٰؑ پر وحی کی کہ اب راتوں رات میرے بندوں کو لے کر چل پڑ، اور اُن کے لیے سمندر میں سے سُوکھی سڑک بنا لے، تجھے کسی کے تعاقب کا ذرا خوف نہ ہو اور نہ (سمندر کے بیچ سے گزرتے ہوئے) ڈر لگے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvi{پیچھے سے فرعون اپنے لشکر لے کر پہنچا اور پھر سمندر اُن پر چھا گیا جیسا کہ چھا جانے کا حق تھا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvii{فرعون نے اپنی قوم کو گمراہ ہی کیا تھا، کوئی صحیح رہنمائی نہیں کی تھی\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcdxxviii{اے بنی اسرائیل، ہم نے تم کو تمہارے دشمن سے نجات دی، اور طور کے دائیں جانب تمہاری حاضری کے لیے وقت مقرر کیا اور تم پر من و سلویٰ اتارا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcdxxix{کھاؤ ہمارا دیا ہوا پاک رزق اور اسے کھا کر سرکشی نہ کرو، ورنہ تم پر میرا غضب ٹوٹ پڑے گا اور جس پر میرا غضب ٹوٹا وہ پھر گر کر ہی رہا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcdxxx{البتہ جو توبہ کر لے اور ایمان لائے اور نیک عمل کرے، پھر سیدھا چلتا رہے، اُس کے لیے میں بہت درگزر کرنے والا ہوں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxi{اور کیا چیز تمہیں اپنی قوم سے پہلے لے آئی موسیٰؑ؟\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxii{اُس نے عرض کیا `` وہ بس میرے پیچھے آ ہی رہے ہیں میں جلدی کر کے تیرے حضور آ گیا ہوں اے میرے رب، تاکہ تو مجھ سے خوش ہو جائے"\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiii{فرمایا ``اچھا، تو سنو، ہم نے تمہارے پیچھے تمہاری قوم کو آزمائش میں ڈال دیا اور سامری نے انہیں گمراہ کر ڈالا"\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiv{موسیٰؑ سخت غصّے اور رنج کی حالت میں اپنی قوم کی طرف پلٹا جا کر اُس نے کہا ``اے میری قوم کے لوگو، کیا تمہارے رب نے تم سے اچھے وعدے نہیں کیے تھے؟ کیا تمہیں دن لگ گئے ہیں؟ یا تم اپنے رب کا غضب ہی اپنے اوپر لانا چاہتے تھے کہ تم نے مجھ سے وعدہ خلافی کی؟"\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxv{انہوں نے جواب دیا ``ہم نے آپ سے وعدہ خلافی کچھ اپنے اختیار سے نہیں کی، معاملہ یہ ہُوا کہ لوگوں کے زیورات کے بوجھ سے ہم لَد گئے تھے اور ہم نے بس اُن کو پھینک دیا تھا" پھر اس طرح سامری نے بھی کچھ ڈالا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvi{اور ان کے لیے ایک بچھڑے کی مورت بنا کر نکال لایا جس میں سے بیل کی سی آواز نکلتی تھی لوگ پکار اٹھے ``یہی ہے تمہارا خدا اور موسیٰؑ کا خدا، موسیٰؑ اسے بھول گیا"\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvii{کیا وہ نہ دیکھتے تھے کہ نہ وہ اُن کی بات کا جواب دیتا ہے اور نہ ان کے نفع و نقصان کا کچھ اختیار رکھتا ہے؟\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxviii{ہارونؑ (موسیٰؑ کے آنے سے) پہلے ہی ان سے کہہ چکا تھا کہ ``لوگو، تم اِس کی وجہ سے فتنے میں پڑ گئے ہو، تمہارا رب تو رحمٰن ہے، پس تم میری پیروی کرو اور میری بات مانو"\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxix{مگر اُنہوں نے اس سے کہہ دیا کہ ``ہم تو اسی کی پرستش کرتے رہیں گے جب تک کہ موسیٰؑ واپس نہ آ جائے"\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcdxl{موسیٰؑ (قوم کو ڈانٹنے کے بعد ہارونؑ کی طرف پلٹا اور) بولا ``ہارونؑ، تم نے جب دیکھا تھا کہ یہ گمراہ ہو رہے ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcdxli{تو کس چیز نے تمہارا ہاتھ پکڑا تھا کہ میرے طریقے پر عمل نہ کرو؟ کیا تم نے میرے حکم کی خلاف ورزی کی؟"\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcdxlii{ہارونؑ نے جواب دیا ``اے میری ماں کے بیٹے، میری داڑھی نہ پکڑ، نہ میرے سر کے بال کھینچ، مجھے اِس بات کا ڈر تھا کہ تو آ کر کہے گا تم نے بنی اسرائیل میں پھوٹ ڈال دی اور میری بات کا پاس نہ کیا"\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcdxliii{موسیٰؑ نے کہا ``اور سامری، تیرا کیا معاملہ ہے؟"\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcdxliv{اس نے جواب دیا ``میں نے وہ چیز دیکھی جو اِن لوگوں کو نظر نہ آئی، پس میں نے رسُول کے نقش قدم سے ایک مٹھی اٹھا لی اور اُس کو ڈال دیا میرے نفس نے مجھے کچھ ایسا ہی سجھایا"\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcdxlv{موسیٰؑ نے کہا `` اچھا تو جا، اب زندگی بھر تجھے یہی پکارتے رہنا ہے کہ مجھے نہ چھونا اور تیرے لیے بازپُرس کا ایک وقت مقرر ہے جو تجھ سے ہرگز نہ ٹلے گا اور دیکھ اپنے اِس خدا کو جس پر تو ریجھا ہُوا تھا، اب ہم اسے جلا ڈالیں گے اور ریزہ ریزہ کر کے دریا میں بہا دیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvi{لوگو، تمہارا خدا تو بس ایک ہی اللہ ہے جس کے سوا کوئی اور خدا نہیں ہے، ہر چیز پر اُس کا علم حاوی ہے"\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvii{اے محمدؐ، ا س طرح ہم پچھلے گزرے ہوئے حالات کی خبریں تم کو سُناتے ہیں، اور ہم نے خاص اپنے ہاں سے تم کو ایک ``ذکر"(درسِ نصیحت) عطا کیا ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcdxlviii{جو کوئی اِس سے منہ موڑے گا وہ قیامت کے دن سخت بار گناہ اٹھائے گا\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcdxlix{اور ایسے سب لوگ ہمیشہ اس کے وبال میں گرفتار رہیں گے، اور قیامت کے دن اُن کے لیے (اِس جرم کی ذمہ داری کا بوجھ) بڑا تکلیف دہ بوجھ ہوگا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcdl{اُس دن جبکہ صُور پھُونکا جائے گا اور ہم مجرموں کو اِس حال میں گھیر لائیں گے کہ ان کی آنکھیں (دہشت کے مارے) پتھرائی ہوئی ہوں گی\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcdli{آپس میں چپکے چپکے کہیں گے کہ دُنیا میں مشکل ہی سے تم نے کوئی دس دن گزارے ہوں گے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcdlii{ہمیں خوب معلوم ہے کہ وہ کیا باتیں کر رہے ہوں گے (ہم یہ بھی جانتے ہیں کہ) اُس وقت ان میں سے جو زیادہ سے زیادہ محتاط اندازہ لگانے والا ہوگا وہ کہے گا کہ نہیں، تمہاری دنیا کی زندگی بس ایک دن کی تھی\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcdliii{یہ لوگ تم سے پُوچھتے ہیں کہ آخر اُس دن یہ پہاڑ کہاں چلے جائیں گے؟ کہو کہ میرا رب ان کو دھول بنا کر اڑا دے گا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcdliv{اور زمین کو ایسا ہموار چٹیل میدان بنا دے گا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcdlv{کہ اس میں تم کوئی بل اور سلوٹ نہ دیکھو گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcdlvi{اس روز سب لوگ منادی کی پکار پر سیدھے چلے آئیں گے، کوئی ذرا اکڑ نہ دکھا سکے گا اور آوازیں رحمان کے آگے دب جائیں گی، ایک سرسراہٹ کے سوا تم کچھ نہ سنو گے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcdlvii{اُس روز شفاعت کارگر نہ ہو گی، اِلّا یہ کہ کسی کو رحمان اس کی اجازت دے اور اس کی بات سننا پسند کرے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcdlviii{وہ لوگوں کا اگلا پچھلا سب حال جانتا ہے اور دُوسروں کو اس کا پورا عِلم نہیں ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcdlix{لوگوں کے سر اُس حیّ و قیّوم کے آگے جھک جائیں گے نامراد ہوگا جو اُس وقت کسی ظلم کا بار گناہ اٹھائے ہوئے ہو\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcdlx{اور کسی ظلم یا حق تلفی کا خطرہ نہ ہوگا اُس شخص کو جو نیک عمل کرے اور اِس کے ساتھ وہ مومن بھی ہو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmcdlxi{اور اے محمدؐ، اِسی طرح ہم نے اِسے قرآن عربی بنا کر نازل کیا ہے اور اس میں طرح طرح سے تنبیہات کی ہیں شاید کہ یہ لوگ کج روی سے بچیں یا ان میں کچھ ہوش کے آثار اِس کی بدولت پیدا ہوں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmcdlxii{پس بالا و برتر ہے اللہ، پادشاہ حقیقی اور دیکھو، قرآن پڑھنے میں جلدی نہ کیا کرو جب تک کہ تمہاری طرف اُس کی وحی تکمیل کو نہ پہنچ جائے، اور دُعا کرو کہ اے پروردگار مجھے مزید علم عطا کر\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiii{ہم نے اِس سے پہلے آدمؑ کو ایک حکم دیا تھا، مگر وہ بھول گیا اور ہم نے اُس میں عزم نہ پایا\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiv{یاد کرو وہ وقت جبکہ ہم نے فرشتوں سے کہا تھا کہ آدمؑ کو سجدہ کرو وہ سب تو سجدہ کر گئے، مگر ایک ابلیس تھا کہ انکار کر بیٹھا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmcdlxv{اس پر ہم نے آدمؑ سے کہا کہ ``دیکھو، یہ تمہارا اور تمہاری بیوی کا دشمن ہے، ایسا نہ ہو کہ یہ تمہیں جنت سے نکلوا دے اور تم مصیبت میں پڑ جاؤ\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvi{یہاں تو تمہیں یہ آسائشیں حاصل ہیں کہ نہ بھوکے ننگے رہتے ہو\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvii{نہ پیاس اور دھوپ تمہیں ستاتی ہے"\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmcdlxviii{لیکن شیطان نے اس کو پھُسلایا کہنے لگا ``آدم، بتاؤں تمہیں وہ درخت جس سے ابدی زندگی اور لازوال سلطنت حاصل ہوتی ہے؟"\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmcdlxix{آخرکار وہ دونوں (میاں بیوی) اُس درخت کا پھل کھا گئے نتیجہ یہ ہُوا کہ فوراً ہی ان کے ستر ایک دوسرے کے آگے کھُل گئے اور لگے دونوں اپنے آپ کو جنّت کے پتّوں سے ڈھانکنے آدمؑ نے اپنے رب کی نافرمانی کی اور راہِ راست سے بھٹک گیا\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmcdlxx{پھر اُس کے رب نے اُسے برگزیدہ کیا اور اس کی توبہ قبول کر لی اور اسے ہدایت بخشی\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxi{اور فرمایا ``تم دونوں (فریق، یعنی انسان اور شیطان) یہاں سے اتر جاؤ تم ایک دُوسرے کے دشمن رہو گے اب اگر میری طرف سے تمہیں کوئی ہدایت پہنچے تو جو کوئی میری اُس ہدایت کی پیروی کرے گا وہ نہ بھٹکے گا نہ بد بختی میں مبتلا ہو گا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxii{اور جو میرے ``ذِکر"(درسِ نصیحت) سے منہ موڑے گا اُس کے لیے دنیا میں تنگ زندگی ہو گی اور قیامت کے روز ہم اسے اندھا اٹھائیں گے"\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiii{وہ کہے گا ``پروردگار، دُنیا میں تو میں آنکھوں والا تھا، یہاں مجھے اندھا کیوں اُٹھایا؟"\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiv{اللہ تعالیٰ فرمائے گا ``ہاں، اِسی طرح تو ہماری آیات کو، جبکہ وہ تیرے پاس آئی تھیں، تُو نے بھُلا دیا تھا اُسی طرح آج تو بھلایا جا رہا ہے"\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxv{اِس طرح ہم حد سے گزرنے والے اور اپنے رب کی آیات نہ ماننے والے کو (دُنیا میں) بدلہ دیتے ہیں، اور آخرت کا عذاب زیادہ سخت اور زیادہ دیر پا ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvi{پھر کیا اِن لوگوں کو (تاریخ کے اس سبق سے) کوئی ہدایت نہ ملی کہ اِن سے پہلے کتنی ہی قوموں کو ہم ہلاک کر چکے ہیں جن کی (برباد شدہ) بستیوں میں آج یہ چلتے پھرتے ہیں؟ در حقیقت اِس میں بہت سی نشانیاں ہیں اُن لوگوں کے لیے جو عقل سلیم رکھنے والے ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvii{اگر تیرے رب کی طرف سے پہلے ایک بات طے نہ کر دی گئی ہوتی اور مہلت کی ایک مدّت مقرّر نہ کی جا چکی ہوتی تو ضرور اِن کا بھی فیصلہ چکا دیا جاتا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxviii{پس اے محمدؐ، جو باتیں یہ لوگ بناتے ہیں اُن پر صبر کرو، اور اپنے رب کی حمد و ثنا کے ساتھ اُس کی تسبیح کرو سورج نکلنے سے پہلے اور غروب ہونے سے پہلے، اور رات کے اوقات میں بھی تسبیح کرو اور دن کے کناروں پر بھی، شاید کہ تم راضی ہو جاؤ\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxix{اور نگاہ اُٹھا کر بھی نہ دیکھو دُنیوی زندگی کی اُس شان و شوکت کو جو ہم نے اِن میں سے مختلف قسم کے لوگوں کو دے رکھی ہے وہ تو ہم نے انہیں آزمائش میں ڈالنے کے لیے دی ہے، اور تیرے رب کا دیا ہوا رزق حلال ہی بہتر اور پائندہ تر ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxx{اپنے اہل و عیال کو نماز کی تلقین کرو اور خود بھی اس کے پابند رہو ہم تم سے کوئی رزق نہیں چاہتے، رزق تو ہم ہی تمہیں دے رہے ہیں اور انجام کی بھلائی تقویٰ ہی کے لیے ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxi{وہ کہتے ہیں کہ یہ شخص اپنے رب کی طرف سے کوئی نشانی (معجزہ) کیوں نہیں لاتا؟ اور کیا ان کے پاس اگلے صحیفوں کی تمام تعلیمات کا بیان واضح نہیں آ گیا؟\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxii{اگر ہم اُس کے آنے سے پہلے اِن کو کسی عذاب سے ہلاک کر دیتے تو پھر یہی لوگ کہتے کہ اے ہمارے پروردگار، تو نے ہمارے پاس کوئی رسول کیوں نہ بھیجا کہ ذلیل و رسوا ہونے سے پہلے ہی ہم تیری آیات کی پیروی اختیار کر لیتے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiii{اے محمدؐ، ان سے کہو، ہر ایک انجام کار کے انتظار میں ہے، پس اب منتظر رہو، عنقریب تمہیں معلوم ہو جائے گا کہ کون سیدھی راہ چلنے والے ہیں اور کون ہدایت یافتہ ہیں\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiv{\basmalahur قریب آ گیا ہے لوگوں کے حساب کا وقت، اور وہ ہیں کہ غفلت میں منہ موڑے ہوئے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxv{ان کے پاس جو تازہ نصیحت بھی ان کے رب کی طرف سے آتی ہے اُس کو بہ تکلف سنتے ہیں اور کھیل میں پڑے رہتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvi{دِل ان کے (دوسری ہی فکروں میں) منہمک ہیں اور ظالم آپس میں سرگوشیاں کرتے ہیں کہ ``یہ شخص آخر تم جیسا ایک بشر ہی تو ہے، پھر کیا تم آنکھوں دیکھتے جادُو کے پھندے میں پھنس جاؤ گے؟"\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvii{رسُولؐ نے کہا میرا رب ہر اُس بات کو جانتا ہے جو آسمان اور زمین میں کی جائے، وہ سمیع اور علیم ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxviii{وہ کہتے ہیں ``بلکہ یہ پراگندہ خواب ہیں، بلکہ یہ اِس کی مَن گھڑت ہے، بلکہ یہ شخص شاعر ہے ورنہ یہ لائے کوئی نشانی جس طرح پرانے زمانے کے رسول نشانیوں کے ساتھ بھیجے گئے تھے"\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxix{حالاں کہ اِن سے پہلے کوئی بستی بھی، جسے ہم نے ہلاک کیا، ایمان نہ لائی، اب کیا یہ ایمان لائیں گے؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcdxc{اور اے محمدؐ، تم سے پہلے بھی ہم نے انسانوں ہی کو رسول بنا کر بھیجا تھا جن پر ہم وحی کیا کرتے تھے تم لوگ اگر علم نہیں رکھتے تو اہلِ کتاب سے پوچھ لو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcdxci{اُن رسُولوں کو ہم نے کوئی ایسا جسم نہیں دیا تھا کہ وہ کھاتے نہ ہوں، اور نہ وہ سدا جینے والے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcdxcii{پھر دیکھ لو کہ آخرکار ہم نے ان کے ساتھ اپنے وعدے پُورے کیے، اور انہیں اور جس جس کو ہم نے چاہا بچا لیا، اور حد سے گزر جانے والوں کو ہلاک کر دیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcdxciii{لوگو، ہم نے تمہاری طرف ایک ایسی کتاب بھیجی ہے جس میں تمہارا ہی ذکر ہے، کیا تم سمجھتے نہیں ہو؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcdxciv{کتنی ہی ظالم بستیاں ہیں جن کو ہم نے پیس کر رکھ دیا اور اُن کے بعد دُوسری کسی قوم کو اُٹھایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcdxcv{جب اُن کو ہمارا عذاب محسُوس ہوا تو لگے وہاں سے بھاگنے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvi{(کہا گیا) ``بھاگو نہیں، جاؤ اپنے انہی گھروں میں اور عیش کے سامانوں میں جن کے اندر تم چین کر رہے تھے، شاید کہ تم سے پوچھا جائے"\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvii{کہنے لگے ``ہائے ہماری کم بختی، بے شک ہم خطا وار تھے"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcdxcviii{اور وہ یہی پکارتے رہے یہاں تک کہ ہم نے ان کو کھلیان کر دیا، زندگی کا ایک شرارہ تک ان میں نہ رہا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcdxcix{ہم نے اِس آسمان اور زمین کو اور جو کچھ بھی ان میں ہے کچھ کھیل کے طور پر نہیں بنایا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmd{اگر ہم کوئی کھلونا بنانا چاہتے اور بس یہی کچھ ہمیں کرنا ہوتا تو اپنے ہی پاس سے کر لیتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdi{مگر ہم تو باطل پر حق کی چوٹ لگاتے ہیں جو اس کا سر توڑ دیتی ہے اور وہ دیکھتے دیکھتے مِٹ جاتا ہے اور تمہارے لیے تباہی ہے اُن باتوں کی وجہ سے جو تم بناتے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdii{زمین اور آسمان میں جو مخلوق بھی ہے اللہ کی ہے اور جو (فرشتے) اس کے پاس ہیں وہ نہ اپنے آپ کو بڑا سمجھ کر اُس کی بندگی سے سرتابی کرتے ہیں اور نہ ملول ہوتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdiii{شب و روز اس کی تسبیح کرتے رہتے ہیں، دَم نہیں لیتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdiv{کیا اِن لوگوں کے بنائے ہوئے ارضی خدا ایسے ہیں کہ (بے جان کو جان بخش کر) اُٹھا کھڑا کرتے ہوں؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdv{اگر آسمان و زمین میں ایک اللہ کے سوا دُوسرے خدا بھی ہوتے تو (زمین اور آسمان) دونوں کا نظام بگڑ جاتا پس پاک ہے اللہ ربّ العرش اُن باتوں سے جو یہ لوگ بنا رہے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdvi{وہ اپنے کاموں کے لیے (کسی کے آگے) جواب دہ نہیں ہے اور سب جواب دہ ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdvii{کیا اُسے چھوڑ کر اِنہوں نے دوسرے خدا بنا لیے ہیں؟ اے محمدؐ، ان سے کہو کہ ``لاؤ اپنی دلیل، یہ کتاب بھی موجود ہے جس میں میرے دَور کے لوگوں کے لیے نصیحت ہے اور وہ کتابیں بھی موجود ہیں جن میں مجھ سے پہلے لوگوں کے لیے نصیحت تھی" مگر ان میں سے اکثر لوگ حقیقت سے بے خبر ہیں، اس لیے منہ موڑے ہوئے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdviii{ہم نے تُم سے پہلے جو رسُول بھی بھیجا ہے اُس کو یہی وحی کی ہے کہ میرے سوا کوئی خدا نہیں ہے، پس تم لوگ میری ہی بندگی کرو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdix{یہ کہتے ہیں ``رحمان اولاد رکھتا ہے" سبحان اللہ، وہ تو بندے ہیں جنہیں عزّت دی گئی ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdx{اُس کے حضور بڑھ کر نہیں بولتے اور بس اُس کے حکم پر عمل کرتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdxi{جو کچھ اُن کے سامنے ہے اسے بھی وہ جانتا ہے اور جو کچھ اُن سے اوجھل ہے اس سے بھی وہ باخبر ہے وہ کسی کی سفارش نہیں کرتے بجز اُس کے جس کے حق میں سفارش سننے پر اللہ راضی ہو، اور وہ اس کے خوف سے ڈرے رہتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdxii{اور جو اُن میں سے کوئی کہہ دے کہ اللہ کے سوا میں بھی ایک خدا ہوں، تو اسے ہم جہنّم کی سزا دیں، ہمارے ہاں ظالموں کا یہی بدلہ ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdxiii{کیا وہ لوگ جنہوں نے (نبیؐ کی بات ماننے سے) انکار کر دیا ہے غور نہیں کرتے کہ یہ سب آسمان اور زمین باہم ملے ہوئے تھے، پھر ہم نے اِنہیں جدا کیا، اور پانی سے ہر زندہ چیز پیدا کی کیا وہ (ہماری اس خلّاقی کو) نہیں مانتے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdxiv{اور ہم نے زمین میں پہاڑ جما دیے تاکہ وہ انہیں لے کر ڈھلک نہ جائے اور اس میں کشادہ راہیں بنا دیں، شاید کہ لوگ اپنا راستہ معلوم کر لیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdxv{اور ہم نے آسمان کو ایک محفوظ چھت بنا دیا، مگر یہ ہیں کہ اس کی نشانیوں کی طرف توجّہ ہی نہیں کرتے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdxvi{اور وہ اللہ ہی ہے جس نے رات اور دن بنائے اور سُورج اور چاند کو پیدا کیا سب ایک ایک فلک میں تیر رہے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdxvii{اور اے محمدؐ، ہمیشگی تو ہم نے تم سے پہلے بھی کسی انسان کے لیے نہیں رکھی ہے اگر تم مر گئے تو کیا یہ لوگ ہمیشہ جیتے رہیں گے؟\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdxviii{ہر جاندار کو مَوت کا مزہ چکھنا ہے، اور ہم اچھے اور بُرے حالات میں ڈال کر تم سب کی آزمائش کر رہے ہیں آخرکار تمہیں ہماری ہی طرف پلٹنا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdxix{یہ منکرین حق جب تمہیں دیکھتے ہیں تو تمہارا مذاق بنا لیتے ہیں کہتے ہیں ``کیا یہ ہے وہ شخص جو تمہارے خداؤں کا ذکر کیا کرتا ہے؟" اور ان کا اپنا حال یہ ہے کہ رحمان کے ذکر سے منکر ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdxx{انسان جلد باز مخلوق ہے ابھی میں تم کو اپنی نشانیاں دکھائے دیتا ہوں، جلدی نہ مچاؤ\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdxxi{یہ لوگ کہتے ہیں ``آخر یہ دھمکی پُوری کب ہو گی اگر تم سچے ہو"\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdxxii{کاش اِن کافروں کو اُس وقت کا کچھ علم ہوتا جبکہ یہ نہ اپنے منہ آگ سے بچا سکیں گے نہ اپنی پیٹھیں، اور نہ ان کو کہیں سے مدد پہنچے گی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdxxiii{وہ بلا اچانک آئے گی اور اِنہیں اِس طرح یک لخت دبوچ لے گی کہ یہ نہ اس کو دفع کر سکیں گے اور نہ اِن کو لمحہ بھر مُہلت ہی مل سکے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdxxiv{مذاق تم سے پہلے بھی رسُولوں کا اڑایا جا چکا ہے، مگر اُن کا مذاق اڑانے والے اُسی چیز کے پھیر میں آ کر رہے جس کا وہ مذاق اڑاتے تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdxxv{اے محمدؐ، اِن سے کہو، ``کون ہے جو رات کو یا دن کو تمہیں رحمان سے بچا سکتا ہو؟" مگر یہ اپنے رب کی نصیحت سے منہ موڑ رہے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdxxvi{کیا یہ کچھ ایسے خدا رکھتے ہیں جو ہمارے مقابلے میں ان کی حمایت کریں؟ وہ نہ تو خود اپنی مدد کر سکتے ہیں اور نہ ہماری ہی تائید اُن کو حاصل ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdxxvii{اصل بات یہ ہے کہ اِن لوگوں کو اور اِن کے آباء و اجداد کو ہم زندگی کا سر و سامان دیے چلے گئے یہاں تک کہ اِن کو دن لگ گئے مگر کیا اِنہیں نظر نہیں آتا کہ ہم زمین کو مختلف سمتوں سے گھٹاتے چلے آ رہے ہیں؟ پھر کیا یہ غالب آ جائیں گے؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdxxviii{اِن سے کہہ دو کہ ``میں تو وحی کی بنا پر تمہیں متنبہ کر رہا ہوں" مگر بہرے پکار کو نہیں سنا کرتے جبکہ اُنہیں خبردار کیا جائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdxxix{اور اگر تیرے رب کا عذاب ذرا سا انہیں چھو جائے تو ابھی چیخ اٹھیں کہ ہائے ہماری کم بختی، بے شک ہم خطا وار تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdxxx{قیامت کے روز ہم ٹھیک ٹھیک تولنے والے ترازو رکھ دیں گے، پھر کسی شخص پر ذرہ برابر ظلم نہ ہو گا جس کا رائی کے دانے کے برابر بھی کچھ کیا دھرا ہو گا وہ ہم سامنے لے آئیں گے اور حساب لگانے کے لیے ہم کافی ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdxxxi{پہلے ہم موسیٰؑ اور ہارونؑ کو فرقان اور روشنی اور ``ذکر" عطا کر چکے ہیں اُن متقی لوگوں کی بھَلائی کے لیے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdxxxii{جو بے دیکھے اپنے رب سے ڈریں اور جن کو (حساب کی) اُس گھڑی کا کھٹکا لگا ہُوا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiii{اور اب یہ بابرکت ``ذکر" ہم نے (تمہارے لیے) نازل کیا ہے پھر کیا تم اِس کو قبول کرنے سے انکاری ہو؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiv{اُس سے بھی پہلے ہم نے ابراہیمؑ کو اُس کی ہوش مندی بخشی تھی اور ہم اُس کو خوب جانتے تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdxxxv{یاد کرو وہ موقع جبکہ اُس نے اپنے باپ اور اپنی قوم سے کہا تھا کہ ``یہ مورتیں کیسی ہیں جن کے تم لوگ گرویدہ ہو رہے ہو؟"\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvi{انہوں نے جواب دیا ``ہم نے اپنے باپ دادا کو ان کی عبادت کرتے پایا ہے"\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvii{اس نے کہا ``تم بھی گمراہ ہو اور تمہارے باپ دادا بھی صریح گمراہی میں پڑے ہوئے تھے؟"\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdxxxviii{انہوں نے کہا ``کیا تو ہمارے سامنے اپنے اصلی خیالات پیش کر رہا ہے یا مذاق کرتا ہے؟"\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdxxxix{اُس نے جواب دیا ``نہیں، بلکہ فی الواقع تمہارا رب وہی ہے جو زمین اور آسمانوں کا رب اور اُن کا پیدا کرنے والا ہے اِس پر میں تمہارے سامنے گواہی دیتا ہوں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdxl{اور خدا کی قسم میں تمہاری غیر موجودگی میں ضرور تمہارے بتوں کی خبر لوں گا"\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdxli{چنانچہ اس نے اُن کو ٹکڑے ٹکڑے کر دیا اور صرف ان کے بڑے کو چھوڑ دیا تاکہ شاید وہ اس کی طرف رجوع کریں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdxlii{(اُنہوں نے آ کر بتوں کا یہ حال دیکھا تو) کہنے لگے ``ہمارے خداؤں کا یہ حال کس نے کر دیا؟ بڑا ہی کوئی ظالم تھا وہ"\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdxliii{(بعض لوگ) بولے ``ہم نے ایک نوجوان کو ان کا ذکر کرتے سُنا تھا جس کا نام ابراہیمؑ ہے"\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdxliv{انہوں نے کہا ``تو پکڑ لاؤ اُسے سب کے سامنے تاکہ لوگ دیکھ لیں (اُس کی کیسی خبر لی جاتی ہے)"\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdxlv{(ابراہیمؑ کے آنے پر) اُنہوں نے پوچھا ``کیوں ابراہیمؑ، تو نے ہمارے خداؤں کے ساتھ یہ حرکت کی ہے؟"\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdxlvi{اُس نے جواب دیا ``بلکہ یہ سب کچھ ان کے اس سردار نے کیا ہے، اِن ہی سے پوچھ لو اگر یہ بولتے ہوں"\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdxlvii{یہ سُن کر وہ لوگ اپنے ضمیر کی طرف پلٹے اور (اپنے دلوں میں) کہنے لگے ``واقعی تم خود ہی ظالم ہو"\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdxlviii{مگر پھر اُن کی مت پلٹ گئی اور بولے ``تُو جانتا ہے کہ یہ بولتے نہیں ہیں"\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdxlix{ابراہیمؑ نے کہا ``پھر کیا تم اللہ کو چھوڑ کر اُن چیزوں کو پوج رہے ہو جو نہ تمہیں نفع پہنچانے پر قادر ہیں نہ نقصان\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdl{تف ہے تم پر اور تمہارے اِن معبُودوں پر جن کی تم اللہ کو چھوڑ کر پوجا کر رہے ہو کیا تم کچھ بھی عقل نہیں رکھتے؟"\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdli{انہوں نے کہا ``جلا ڈالو اس کو اور حمایت کرو اپنے خداؤں کی اگر تمہیں کچھ کرنا ہے"\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdlii{ہم نے کہا ``اے آگ، ٹھنڈی ہو جا اور سلامتی بن جا ابراہیمؑ پر"\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdliii{وہ چاہتے تھے کہ ابراہیمؑ کے ساتھ بُرائی کریں مگر ہم نے ان کو بُری طرح ناکام کر دیا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdliv{اور ہم نے اُسے اور لوطؑ کو بچا کر اُس سرزمین کی طرف لے گئے جس میں ہم نے دنیا والوں کے لیے برکتیں رکھی ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdlv{اور ہم نے اسے اسحاقؑ عطا کیا اور یعقوبؑ اس پر مزید، اور ہر ایک کو صالح بنایا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdlvi{اور ہم نے اُن کو امام بنا دیا جو ہمارے حکم سے رہنمائی کرتے تھے اور ہم نے انہیں وحی کے ذریعہ نیک کاموں کی اور نماز قائم کرنے اور زکوٰۃ دینے کی ہدایت کی، اور وہ ہمارے عبادت گزار تھے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdlvii{اور لوطؑ کو ہم نے حکم اور علم بخشا اور اُسے اُس بستی سے بچا کر نکال دیا جو بدکاریاں کرتی تھی درحقیقت وہ بڑی ہی بُری، فاسق قوم تھی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdlviii{اور لوطؑ کو ہم نے اپنی رحمت میں داخل کیا، وہ صالح لوگوں میں سے تھا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdlix{اور یہی نعمت ہم نے نوحؑ کو دی یاد کرو جبکہ اِن سب سے پہلے اُس نے ہمیں پکارا تھا ہم نے اس کی دعا قبول کی اور اسے اور اس کے گھر والوں کو کرب عظیم سے نجات دی\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdlx{اور اُس قوم کے مقابلے میں اُس کی مدد کی جس نے ہماری آیات کو جھٹلا دیا تھا وہ بڑے بُرے لوگ تھے، پس ہم نے ان سب کو غرق کر دیا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdlxi{اور اِسی نعمت سے ہم نے داؤدؑ اورسلیمانؑ کو سرفراز کیا یاد کرو وہ موقع جبکہ وہ دونوں ایک کھیت کے مقدمے میں فیصلہ کر رہے تھے جس میں رات کے وقت دُوسرے لوگوں کی بکریاں پھیل گئی تھیں، اور ہم اُن کی عدالت خود دیکھ رہے تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdlxii{اُس وقت ہم نے صحیح فیصلہ سلیمانؑ کو سمجھا دیا، حالانکہ حکم اور علم ہم نے دونوں ہی کو عطا کیا تھا داؤدؑ کے ساتھ ہم نے پہاڑوں اور پرندوں کو مسخّر کر دیا تھا جو تسبیح کرتے تھے، اِس فعل کے کرنے والے ہم ہی تھے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdlxiii{اور ہم نے اُس کو تمہارے فائدے کے لیے زرہ بنانے کی صنعت سکھا دی تھی، تاکہ تم کو ایک دُوسرے کی مار سے بچائے، پھر کیا تم شکر گزار ہو؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdlxiv{اور سلیمانؑ کے لیے ہم نے تیز ہوا کو مسخّر کر دیا تھا جو اس کے حکم سے اُس سرزمین کی طرف چلتی تھی جس میں ہم نے برکتیں رکھی ہیں، ہم ہر چیز کا علم رکھنے والے تھے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdlxv{اور شیاطین میں سے ہم نے ایسے بہت سوں کو اس کا تابع بنا دیا تھا جو اس کے لیے غوطے لگاتے اور اس کے سوا دُوسرے کام کرتے تھے ان سب کے نگران ہم ہی تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdlxvi{اور یہی (ہوش مندی اور حکم و علم کی نعمت) ہم نے ایّوبؑ کو دی تھی یاد کرو، جبکہ اس نے اپنے رب کو پکارا کہ ``مجھے بیماری لگ گئی ہے اور تو ارحم الراحمین ہے"\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdlxvii{ہم نے اس کی دُعا قبول کی اور جو تکلیف اُسے تھی اس کو دُور کر دیا، اور صرف اس کے اہل و عیال ہی اس کو نہیں دیے بلکہ ان کے ساتھ اتنے ہی اور بھی دیے، اپنی خاص رحمت کے طور پر، اور اس لیے کہ یہ ایک سبق ہو عبادت گزاروں کے لیے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdlxviii{اور یہی نعمت اسماعیلؑ اور ادریسؑ اور ذوالکفلؑ کو دی کہ یہ سب صابر لوگ تھے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdlxix{اور ان کو ہم نے اپنی رحمت میں داخل کیا کہ وہ صالحوں میں سے تھے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdlxx{اور مچھلی والے کو بھی ہم نے نوازا یاد کرو جبکہ وہ بگڑ کر چلا گیا تھا اور سمجھا تھا کہ ہم اس پر گرفت نہ کریں گے آخر کو اُس نے تاریکیوں میں پکارا ``نہیں ہے کوئی خدا مگر تُو، پاک ہے تیری ذات، بے شک میں نے قصور کیا"\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdlxxi{تب ہم نے اس کی دُعا قبول کی اور غم سے اس کو نجات بخشی، اور اِسی طرح ہم مومنوں کو بچا لیا کرتے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdlxxii{اور زکریّاؑ کو، جبکہ اس نے اپنے رب کو پکارا کہ ``اے پروردگار، مجھے اکیلا نہ چھوڑ، اور بہترین وارث تو تُو ہی ہے"\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiii{پس ہم نے اس کی دُعا قبول کی اور اسے یحییٰ عطا کیا اور اس کی بیوی کو اس کے لیے درست کر دیا یہ لوگ نیکی کے کاموں میں دَوڑ دھوپ کرتے تھے اور ہمیں رغبت اور خوف کے ساتھ پکارتے تھے، اور ہمارے آگے جھکے ہوئے تھے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiv{اور وہ خاتون جس نے اپنی عصمت کی حفاظت کی تھی ہم نے اُس کے اندر اپنی روح سے پھونکا اور اُسے اور اُس کے بیٹے کو دنیا بھر کے لیے نشانی بنا دیا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdlxxv{یہ تمہاری امّت حقیقت میں ایک ہی امّت ہے اور میں تمہارا رب ہوں، پس تم میری عبادت کرو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvi{مگر (یہ لوگوں کی کارستانی ہے کہ) انہوں نے آپس میں دین کو ٹکڑے ٹکڑے کر ڈالا سب کو ہماری طرف پلٹنا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvii{پھر جو نیک عمل کرے گا، اِس حال میں کہ وہ مومن ہو، تو اس کے کام کی نا قدری نہ ہو گی، اور اُسے ہم لکھ رہے ہیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdlxxviii{اور ممکن نہیں ہے کہ جس بستی کو ہم نے ہلاک کر دیا ہو وہ پھر پلٹ سکے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdlxxix{یہاں تک کہ جب یاجُوج و ماجُوج کھول دیے جائیں گے اور ہر بلندی سے وہ نکل پڑیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdlxxx{اور وعدہ برحق کے پورا ہونے کا وقت قریب آ لگے گا تو یکا یک اُن لوگوں کے دیدے پھٹے کے پھٹے رہ جائیں گے جنہوں نے کفر کیا تھا کہیں گے ``ہائے ہماری کم بختی، ہم اِس چیز کی طرف سے غفلت میں پڑے ہوئے تھے، بلکہ ہم خطا کار تھے"\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxi{بے شک تم اور تمہارے وہ معبُود جنہیں تم پوجتے ہو، جہنّم کا ایندھن ہیں، وہیں تم کو جانا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxii{اگر یہ واقعی خدا ہوتے تو وہاں نہ جاتے اب سب کو ہمیشہ اسی میں رہنا ہے"\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiii{وہاں وہ پھنکارے ماریں گے اور حال یہ ہو گا کہ اس میں کان پڑی آواز نہ سنائی دے گی\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiv{رہے وہ لوگ جن کے لیے ہماری طرف سے بھَلائی کا پہلے ہی فیصلہ ہو چکا ہوگا، تو وہ یقیناً اُس سے دُور رکھے جائیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxv{اس کی سرسراہٹ تک نہ سُنیں گے اور وہ ہمیشہ ہمیشہ اپنی من بھاتی چیزوں کے درمیان رہیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvi{وہ انتہائی گھبراہٹ کا وقت اُن کو ذرا پریشان نہ کرے گا، اور ملائکہ بڑھ کر اُن کو ہاتھوں ہاتھ لیں گے کہ ``یہ تمہارا وہی دن ہے جس کا تم سے وعدہ کیا جاتا تھا"\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvii{وہ دن جبکہ آسمان کو ہم یوں لپیٹ کر رکھ دیں گے جیسے طومار میں اوراق لپیٹ دیے جاتے ہیں جس طرح پہلے ہم نے تخلیق کی ابتدا کی تھی اُسی طرح ہم پھر اُس کا اعادہ کریں گے یہ ایک وعدہ ہے ہمارے ذمے، اور یہ کام ہمیں بہرحال کرنا ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxviii{اور زَبور میں ہم نصیحت کے بعد یہ لکھ چکے ہیں کہ زمین کے وارث ہمارے نیک بندے ہوں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxix{اِس میں ایک بڑی خبر ہے عبادت گزار لوگوں کے لیے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdxc{اے محمدؐ، ہم نے جو تم کو بھیجا ہے تو یہ دراصل دنیا والوں کے حق میں ہماری رحمت ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdxci{اِن سے کہو ``میرے پاس جو وحی آتی ہے وہ یہ ہے کہ تمہارا خدا صرف ایک خدا ہے، پھر کیا تم سرِ اطاعت جھکاتے ہو؟"\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdxcii{اگر وہ منہ پھیریں تو کہہ دو کہ ``میں نے علی الاعلان تم کو خبردار کر دیا ہے اب یہ میں نہیں جانتا کہ وہ چیز جس کا تم سے وعدہ کیا جا رہا ہے قریب ہے یا دُور\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdxciii{اللہ وہ باتیں بھی جانتا ہے جو با آواز بلند کہی جاتی ہیں اور وہ بھی جو تم چھپا کر کرتے ہو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdxciv{میں تو یہ سمجھتا ہوں کہ شاید یہ (دیر) تمہارے لیے ایک فتنہ ہے اور تمہیں ایک وقت خاص تک کے لیے مزے کرنے کا موقع دیا جا رہا ہے"\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdxcv{(آخرکار) رسولؐ نے کہا کہ ``اے میرے رب، حق کے ساتھ فیصلہ کر دے، اور لوگو، تم جو باتیں بناتے ہو اُن کے مقابلے میں ہمارا ربِّ رحمان ہی ہمارے لیے مدد کا سہارا ہے"\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdxcvi{\basmalahur لوگو، اپنے رب کے غضب سے بچو، حقیقت یہ ہے کہ قیامت کا زلزلہ بڑی (ہولناک) چیز ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdxcvii{جس روز تم اسے دیکھو گے، حال یہ ہو گا کہ ہر دودھ پلانے والی اپنے دودھ پیتے بچّے سے غافل ہو جائے گی، ہر حاملہ کا حمل گر جائے گا، اور لوگ تم کو مدہوش نظر آئیں گے، حالانکہ وہ نشے میں نہ ہوں گے، بلکہ اللہ کا عذاب ہی کچھ ایسا سخت ہوگا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdxcviii{بعض لوگ ایسے ہیں جو عِلم کے بغیر اللہ کے بارے میں بحثیں کرتے ہیں اور ہر شیطان سرکش کی پیروی کرنے لگتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdxcix{حالانکہ اُس کے تو نصیب ہی میں یہ لکھا ہے کہ جو اس کو دوست بنائے گا اسے وہ گمراہ کر کے چھوڑے گا اور عذاب جہنّم کا راستہ دکھائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdc{لوگو، اگر تمہیں زندگی بعد موت کے بارے میں کچھ شک ہے تو تمہیں معلوم ہو کہ ہم نے تم کو مٹی سے پیدا کیا ہے، پھر نطفے سے، پھر خون کے لوتھڑے سے، پھر گوشت کی بوٹی سے جو شکل والی بھی ہوتی ہے اور بے شکل بھی (یہ ہم اس لیے بتا رہے ہیں) تاکہ تم پر حقیقت واضح کر دیں ہم جس (نطفے) کو چاہتے ہیں ایک وقت خاص تک رحموں میں ٹھیرائے رکھتے ہیں، پھر تم کو ایک بچّے کی صورت میں نکال لاتے ہیں (پھر تمہیں پرورش کرتے ہیں) تاکہ تم اپنی پُوری جوانی کو پہنچو اور تم میں سے کوئی پہلے ہی واپس بلا لیا جاتا ہے اور کوئی بدترین عمر کی طرف پھیر دیا جاتا ہے تاکہ سب کچھ جاننے کے بعد پھر کچھ نہ جانے اور تم دیکھتے ہو کہ زمین سوکھی پڑی ہے، پھر جہاں ہم نے اُس پر مینہ برسایا کہ یکایک وہ پھبک اٹھی اور پھول گئی اور اس نے ہر قسم کی خوش منظر نباتات اگلنی شروع کر دی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdci{یہ سب کچھ اس وجہ سے ہے کہ اللہ ہی حق ہے، اور وہ مُردوں کو زندہ کرتا ہے، اور وہ ہر چیز پر قادر ہے،\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdcii{اور یہ (اِس بات کی دلیل ہے) کہ قیامت کی گھڑی آ کر رہے گی، اس میں کسی شک کی گنجائش نہیں، اور اللہ ضرور اُن لوگوں کو اٹھائے گا جو قبروں میں جا چکے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdciii{بعض اور لوگ ایسے ہیں جو کسی علم اور ہدایت اور روشنی بخشنے والی کتاب کے بغیر، گردن اکڑائے ہوئے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdciv{خدا کے بارے میں جھگڑتے ہیں تاکہ لوگوں کو راہِ خدا سے بھٹکا دیں ایسے شخص کے لیے دُنیا میں رُسوائی ہے اور قیامت کے روز اُس کو ہم آگ کے عذاب کا مزا چکھائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdcv{یہ ہے تیرا وہ مستقبل جو تیرے اپنے ہاتھوں نے تیرے لیے تیار کیا ہے ورنہ اللہ اپنے بندوں پر ظلم کرنے والا نہیں ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcvi{اور لوگوں میں کوئی ایسا ہے جو کنارے پر رہ کر اللہ کی بندگی کرتا ہے، اگر فائدہ ہوا تو مطمئن ہو گیا اور جو کوئی مصیبت آ گئی تو الٹا پھر گیا اُس کی دنیا بھی گئی اور آخرت بھی یہ ہے صریح خسارہ\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdcvii{پھر وہ اللہ کو چھوڑ کر اُن کو پکارتا ہے جو نہ اُس کو نقصان پہنچا سکتے ہیں نہ فائدہ یہ ہے گمراہی کی انتہا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdcviii{وہ اُن کو پکارتا ہے جن کا نقصان اُن کے نفع سے قریب تر ہے بدترین ہے اُس کا مولیٰ اور بدترین ہے اُس کا رفیق\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcix{(اِس کے برعکس) اللہ اُن لوگوں کو جو ایمان لائے اور جنہوں نے نیک عمل کیے، یقیناً ایسی جنتوں میں داخل کرے گا جن کے نیچے نہریں بہہ رہی ہوں گی اللہ کرتا ہے جو کچھ چاہتا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcx{جو شخص یہ گمان رکھتا ہو کہ اللہ دُنیا اور آخرت میں اُس کی کوئی مدد نہ کرے گا اُسے چاہیے کہ ایک رسّی کے ذریعے آسمان تک پہنچ کر شگاف لگائے، پھر دیکھ لے کہ آیا اُس کی تدبیر کسی ایسی چیز کو رد کر سکتی ہے جو اس کو ناگوار ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcxi{ایسی ہی کھُلی کھُلی باتوں کے ساتھ ہم نے اس قرآن کو نازل کیا ہے، اور ہدایت اللہ جسے چاہتا ہے دیتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxii{جو لوگ ایمان لائے، اور جو یہودی ہوئے، اور صابئی، اور نصاریٰ، اور مجوس، اور جن لوگوں نے شرک کیا، ان سب کے درمیان اللہ قیامت کے روز فیصلہ کر دے گا، ہر چیز اللہ کی نظر میں ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxiii{کیا تم دیکھتے نہیں ہو کہ اللہ کے آگے سربسجود ہیں وہ سب جو آسمانوں میں ہیں اور جو زمین میں ہیں، سورج اور چاند اور تارے اور پہاڑ اور درخت اور جانور اور بہت سے انسان اور بہت سے وہ لوگ بھی جو عذاب کے مستحق ہو چکے ہیں؟ اور جسے اللہ ذلیل و خوار کر دے اُسے پھر کوئی عزّت دینے والا نہیں ہے، اللہ کرتا ہے جو کچھ چاہتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxiv{یہ دو فریق ہیں جن کے درمیان اپنے رب کے معاملے کا جھگڑا ہے اِن میں سے وہ لوگ جنہوں نے کفر کیا ہے اُن کے لیے آگ کے لباس کاٹے جا چکے ہیں، اُن کے سروں پر کھَولتا ہوا پانی ڈالا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxv{جس سے اُن کی کھالیں ہی نہیں پیٹ کے اندر کے حصے تک گل جائیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxvi{اور اُن کی خبر لینے کے لیے لوہے کے گُرز ہوں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxvii{جب کبھی وہ گھبرا کر جہنّم سے نکلنے کی کوشش کریں گے پھر اُسی میں دھکیل دیے جائیں گے کہ چکھو اب جلنے کی سزا کا مزا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxviii{(دوسری طرف) جو لوگ ایمان لائے اور جنہوں نے نیک عمل کیے اُن کو اللہ ایسی جنتوں میں داخل کرے گا جن کے نیچے نہریں بہہ رہی ہوں گی وہاں وہ سونے کے کنگنوں اور موتیوں سے آراستہ کیے جائیں گے اور ان کے لباس ریشم کے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxix{ان کو پاکیزہ بات قبول کرنے کی ہدایت بخشی گئی اور انہیں خدائے ستودہ صفات کا راستہ دکھایا گیا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxx{جن لوگوں نے کفر کیا اور جو (آج) اللہ کے راستے سے روک رہے ہیں اور اُس مسجدِ حرام کی زیارت میں مانع ہیں جسے ہم نے سب لوگوں کے لیے بنایا ہے، جس میں مقامی باشندوں اور باہر سے آنے والوں کے حقوق برابر ہیں (اُن کی روش یقیناً سزا کی مستحق ہے) اِس (مسجدِ حرام) میں جو بھی راستی سے ہٹ کر ظلم کا طریقہ اختیار کرے گا اسے ہم درد ناک عذاب کا مزا چکھائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxxi{یاد کرو وہ وقت جب ہم نے ابراہیمؑ کے لیے اِس گھر (خانہ کعبہ) کی جگہ تجویز کی تھی (اِس ہدایت کے ساتھ) کہ ``میرے ساتھ کسی چیز کو شریک نہ کرو، اور میرے گھر کو طواف کرنے والوں اور قیام و رکوع و سجود کرنے والوں کے لیے پاک رکھو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcxxii{اور لوگوں کو حج کے لیے اذنِ عام دے دو کہ وہ تمہارے پاس ہر دور دراز مقام سے پیدل اور اونٹوں پر سوار آئیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiii{تاکہ وہ فائدے دیکھیں جو یہاں اُن کے لیے رکھے گئے ہیں اور چند مقرر دنوں میں اُن جانوروں پر اللہ کا نام لیں جو اُس نے انہیں بخشے ہیں، خود بھی کھائیں اور تنگ دست محتاج کو بھی دیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiv{پھر اپنا میل کچیل دور کریں اور اپنی نذریں پوری کریں، اور اس قدیم گھر کا طواف کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcxxv{یہ تھا (تعمیر کعبہ کا مقصد) اور جو کوئی اللہ کی قائم کردہ حرمتوں کا احترام کرے تو یہ اس کے رب کے نزدیک خود اسی کے لیے بہتر ہے اور تمہارے لیے مویشی جانور حلال کیے گئے، ما سوا اُن چیزوں کے جو تمہیں بتائی جا چکی ہیں پس بتوں کی گندگی سے بچو، جھوٹی باتوں سے پرہیز کرو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvi{یکسُو ہو کر اللہ کے بندے بنو، اس کے ساتھ کسی کو شریک نہ کرو اور جو کوئی اللہ کے ساتھ شرک کرے تو گویا وہ آسمان سے گر گیا، اب یا تو اسے پرندے اُچک لے جائیں گے یا ہوا اُس کو ایسی جگہ لے جا کر پھینک دے گی جہاں اُس کے چیتھڑے اڑ جائیں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvii{یہ ہے اصل معاملہ (اسے سمجھ لو)، اور جو اللہ کے مقرر کردہ شعائر کا احترام کرے تو یہ دلوں کے تقویٰ سے ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcxxviii{تمہیں ایک وقت مقرر تک اُن (ہدی کے جانوروں) سے فائدہ اٹھانے کا حق ہے پھر اُن (کے قربان کرنے) کی جگہ اسی قدیم گھر کے پاس ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcxxix{ہر امّت کے لیے ہم نے قربانی کا ایک قاعدہ مقرر کر دیا ہے تاکہ (اُس امّت کے لوگ) اُن جانوروں پر اللہ کا نام لیں جو اُس نے اُن کو بخشے ہیں (اِن مختلف طریقوں کے اندر مقصد ایک ہی ہے) پس تمہارا خدا ایک ہی خدا ہے اور اُسی کے تم مطیع فرمان بنو اور اے نبیؐ، بشارت دے دے عاجزانہ رَوش اختیار کرنے والوں کو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcxxx{جن کا حال یہ ہے کہ اللہ کا ذکر سُنتے ہیں تو ان کے دل کانپ اٹھتے ہیں، جو مصیبت بھی اُن پر آتی ہے اُس پر صبر کرتے ہیں، نماز قائم کرتے ہیں، اور جو کچھ رزق ہم نے اُن کو دیا ہے اُس میں سے خرچ کرتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxi{اور (قربانی کے) اونٹوں کو ہم نے تمہارے لیے شعائر اللہ میں شامل کیا ہے، تمہارے لیے اُن میں بھَلائی ہے، پس انہیں کھڑا کر کے ان پر اللہ کا نام لو، اور جب (قربانی کے بعد) ان کی پیٹھیں زمین پر ٹک جائیں تو اُن میں سے خود بھی کھاؤ اور اُن کو بھی کھلاؤ جو قناعت کیے بیٹھے ہیں اور اُن کو بھی جو اپنی حاجت پیش کریں اِن جانوروں کو ہم نے اِس طرح تمہارے لیے مسخّر کیا ہے تاکہ تم شکریہ ادا کرو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxii{نہ اُن کے گوشت اللہ کو پہنچتے ہیں نہ خون، مگر اُسے تمہارا تقویٰ پہنچتا ہے اُس نے ان کو تمہارے لیے اِس طرح مسخّر کیا ہے تاکہ اُس کی بخشی ہوئی ہدایت پر تم اُس کی تکبیر کرو اور اے نبیؐ، بشارت دے دے نیکو کار لوگوں کو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiii{یقیناً اللہ مدافعت کرتا ہے اُن لوگوں کی طرف سے جو ایمان لائے ہیں یقیناً اللہ کسی خائن کافر نعمت کو پسند نہیں کرتا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiv{اجازت دے دی گئی اُن لوگوں کو جن کے خلاف جنگ کی جا رہی ہے، کیونکہ وہ مظلوم ہیں، اور اللہ یقیناً ان کی مدد پر قادر ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxv{یہ وہ لوگ ہیں جو اپنے گھروں سے ناحق نکال دیے گئے صرف اِس قصور پر کہ وہ کہتے تھے ``ہمارا رب اللہ ہے" اگر اللہ لوگوں کو ایک دوسرے کے ذریعے دفع نہ کرتا رہے تو خانقاہیں اور گرجا اور معبد اور مسجدیں، جن میں اللہ کا کثرت سے نام لیا جاتا ہے، سب مسمار کر ڈالی جائیں اللہ ضرور اُن لوگوں کی مدد کرے گا جو اس کی مدد کریں گے اللہ بڑا طاقتور اور زبردست ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvi{یہ وہ لوگ ہیں جنہیں اگر ہم زمین میں اقتدار بخشیں تو وہ نماز قائم کریں گے، زکوٰۃ دیں گے، معروف کا حکم دیں گے اور منکر سے منع کریں گے اور تمام معاملات کا انجام کار اللہ کے ہاتھ میں ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvii{اے نبیؐ، اگر وہ تمہیں جھٹلاتے ہیں تو اُن سے پہلے قوم نوحؑ اور عاد اور ثمود\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxviii{اور قوم ابراہیمؑ اور قوم لوطؑ\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxix{اور اہل مدین بھی جھٹلا چکے ہیں اور موسیٰؑ بھی جھٹلائے جا چکے ہیں ان سب منکرینِ حق کو میں نے پہلے مُہلت دی، پھر پکڑ لیا اب دیکھ لو کہ میری عقوبت کیسی تھی\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcxl{کتنی ہی خطاکاربستیاں ہیں جن کو ہم نے تباہ کیا ہے اور آج وہ اپنی چھتوں پر اُلٹی پڑی ہیں، کتنے ہی کنویں بیکار اور کتنے ہی قصر کھنڈر بنے ہوئے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcxli{کیا یہ لوگ زمین میں چلے پھرے نہیں ہیں کہ اِن کے دل سمجھنے والے اور اِن کے کان سُننے والے ہوتے؟ حقیقت یہ ہے کہ آنکھیں اندھی نہیں ہوتیں مگر وہ دل اندھے ہو جاتے ہیں جو سینوں میں ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcxlii{یہ لوگ عذاب کے لیے جلدی مچا رہے ہیں اللہ ہرگز اپنے وعدے کے خلاف نہ کرے گا، مگر تیرے رب کے ہاں کا ایک دن تمہارے شمار کے ہزار برس کے برابر ہُوا کرتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcxliii{کتنی ہی بستیاں ہیں جو ظالم تھیں، میں نے ان کو پہلے مہلت دی، پھر پکڑ لیا اور سب کو واپس تو میرے پاس ہی آنا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcxliv{اے محمدؐ، کہہ دو کہ ``لوگو، میں تو تمہارے لیے صرف وہ شخص ہوں جو (برا وقت آنے سے پہلے) صاف صاف خبردار کردینے والا ہوں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcxlv{پھر جو ایمان لائیں گے اور نیک عمل کریں گے اُن کے لیے مغفرت ہے اور عزّت کی روزی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvi{اور جو ہماری آیات کو نیچا دکھانے کی کوشش کریں گے وہ دوزخ کے یار ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvii{اور اے محمدؐ، تم سے پہلے ہم نے نہ کوئی رسول ایسا بھیجا ہے نہ نبی (جس کے ساتھ یہ معاملہ نہ پیش آیا ہو کہ) جب اُس نے تمنّا کی، شیطان اس کی تمنّا میں خلل انداز ہو گیا اِس طرح جو کچھ بھی شیطان خلل اندازیاں کرتا ہے اللہ ان کو مٹا دیتا ہے اور اپنی آیات کو پختہ کر دیتا ہے، اللہ علیم ہے اور حکیم\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcxlviii{(وہ اس لیے ایسا ہونے دیتا ہے) تاکہ شیطان کی ڈالی ہُوئی خرابی کو فتنہ بنا دے اُن لوگوں کے لیے جن کے دلوں کو (نفاق کا) روگ لگا ہُوا ہے اور جن کے دل کھوٹے ہیں حقیقت یہ ہے کہ یہ ظالم لوگ عناد میں بہت دور نکل گئے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcxlix{اور علم سے بہرہ مند لوگ جان لیں کہ یہ حق ہے تیرے رب کی طرف سے اور وہ اس پر ایمان لے آئیں اور ان کے دل اس کے آگے جھک جائیں، یقیناً اللہ ایمان لانے والوں کو ہمیشہ سیدھا راستہ دکھا دیتا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcl{انکار کرنے والے تو اس کی طرف سے شک ہی میں پڑے رہیں گے یہاں تک کہ یا تو اُن پر قیامت کی گھڑی اچانک آ جائے، یا ایک منحوس دن کا عذاب نازل ہو جائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcli{اُس روز بادشاہی اللہ کی ہو گی، اور وہ ان کے درمیان فیصلہ کر دے گا جو ایمان رکھنے والے اور عمل صالح کرنے والے ہوں گے وہ نعمت بھری جنتوں میں جائیں گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdclii{اور جنہوں نے کفر کیا ہو گا اور ہماری آیات کو جھٹلایا ہوگا اُن کے لیے رسوا کن عذاب ہوگا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcliii{اور جن لوگوں نے اللہ کی راہ میں ہجرت کی، پھر قتل کر دیے گئے یا مر گئے، اللہ ان کو اچھّا رزق دے گا اور یقیناً اللہ ہی بہترین رازق ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcliv{وہ انہیں ایسی جگہ پہنچائے گاجس سے وہ خوش ہو جائیں گے بے شک اللہ علیم اور حلیم ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdclv{یہ تو ہے اُن کا حال، اور جو کوئی بدلہ لے، ویسا ہی جیسا اس کے ساتھ کیا گیا، اور پھر اس پر زیادتی بھی کی گئی ہو، تو اللہ اس کی مدد ضرور کرے گا اللہ معاف کرنے والا اور درگزر کرنے والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdclvi{یہ اس لیے کہ رات سے دن اور دن سے رات نکالنے والا اللہ ہی ہے اور وہ سمیع و بصیر ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdclvii{یہ اس لیے کہ اللہ ہی حق ہے اور وہ سب باطل ہیں جنہیں اللہ کو چھوڑ کر یہ لوگ پکارتے ہیں اور اللہ ہی بالادست اور بزرگ ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdclviii{کیا تم دیکھتے نہیں ہو کہ اللہ آسمان سے پانی برساتا ہے اور اس کی بدولت زمین سرسبز ہو جاتی ہے؟ حقیقت یہ ہے کہ وہ لطیف و خبیر ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdclix{اُسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے بے شک وہی غنی و حمید ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdclx{کیا تم دیکھتے نہیں ہو کہ اُس نے وہ سب کچھ تمہارے لیے مسخر کر رکھا ہے جو زمین میں ہے، اور اسی نے کشتی کو قاعدے کا پابند بنایا ہے کہ وہ اس کے حکم سے سمندر میں چلتی ہے، اور وہی آسمان کو اس طرح تھامے ہوئے کہ اس کے اِذن کے بغیر وہ زمین پر نہیں گر سکتا؟ واقعہ یہ ہے کہ اللہ لوگوں کے حق میں بڑا شفیق اور رحیم ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdclxi{وہی ہے جس نے تمہیں زندگی بخشی ہے، وہی تم کو موت دیتا ہے اور وہی پھر تم کو زندہ کرے گا سچ یہ ہے کہ انسان بڑا ہی منکرِ حق ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdclxii{ہر امت کے لیے ہم نے ایک طریق عبادت مقرر کیا ہے جس کی وہ پیروی کرتی ہے، پس اے محمدؐ، وہ اِس معاملہ میں تم سے جھگڑا نہ کریں تم اپنے رب کی طرف دعوت دو، یقیناً تم سیدھے راستے پر ہو\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdclxiii{اور اگر وہ تم سے جھگڑیں تو کہہ دو کہ ``جو کچھ تم کر رہے ہو اللہ کو خوب معلوم ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdclxiv{اللہ قیامت کے روز تمہارے درمیان ان سب باتوں کا فیصلہ کر دے گا جن میں تم اختلاف کرتے رہے ہو"\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdclxv{کیا تم نہیں جانتے کہ آسمان و زمین کی ہر چیز اللہ کے علم میں ہے؟ سب کچھ ایک کتاب میں درج ہے اللہ کے لیے یہ کچھ بھی مشکل نہیں ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdclxvi{یہ لوگ اللہ کو چھوڑ کر ان کی عبادت کر رہے ہیں جن کے لیے نہ تو اس نے کوئی سند نازل کی ہے اور نہ یہ خود اُن کے بارے میں کوئی علم رکھتے ہیں اِن ظالموں کے لیے کوئی مددگار نہیں ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdclxvii{اور جب ان کو ہماری صاف صاف آیات سنائی جاتی ہیں تو تم دیکھتے ہو کہ منکرین حق کے چہرے بگڑنے لگتے ہیں اور ایسا محسُوس ہوتا ہے کہ ابھی وہ اُن لوگوں پر ٹوٹ پڑیں گے جو انہیں ہماری آیات سناتے ہیں ان سے کہو ``میں بتاؤں تمہیں کہ اس سے بدتر چیز کیا ہے؟ آگ، اللہ نے اُسی کا وعدہ اُن لوگوں کے حق میں کر رکھا ہے جو قبول حق سے انکار کریں، اور وہ بہت ہی برا ٹھکانہ ہے"\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdclxviii{لوگو، ایک مثال دی جاتی ہے، غور سے سنو جن معبودوں کو تم خدا کو چھوڑ کر پکارتے ہو وہ سب مِل کر ایک مکھی بھی پیدا کرنا چاہیں تو نہیں کر سکتے بلکہ اگر مکھی ان سے کوئی چیز چھین لے جائے تو وہ اسے چھڑا بھی نہیں سکتے مدد چاہنے والے بھی کمزور اور جن سے مدد چاہی جاتی ہے وہ بھی کمزور\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdclxix{اِن لوگوں نے اللہ کی قدر ہی نہ پہچانی جیسا کہ اس کے پہچاننے کا حق ہے واقعہ یہ ہے کہ قوت اور عزت والا تو اللہ ہی ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdclxx{حقیقت یہ ہے کہ اللہ (اپنے فرامین کی ترسیل کے لیے) ملائکہ میں سے بھی پیغام رساں منتخب کرتا ہے اور انسانوں میں سے بھی وہ سمیع اور بصیر ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdclxxi{جو کچھ اُن کے سامنے ہے اُسے بھی وہ جانتا ہے اور جو کچھ اُن سے اوجھل ہے اس سے بھی وہ واقف ہے، اور سارے معاملات اسی کی طرف رجوع ہوتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdclxxii{اے لوگو جو ایمان لائے ہو، رکوع اور سجدہ کرو، اپنے رب کی بندگی کرو، اور نیک کام کرو، شاید کہ تم کو فلاح نصیب ہو\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiii{اللہ کی راہ میں جہاد کرو جیسا کہ جہاد کرنے کا حق ہے اُس نے تمہیں اپنے کام کے لیے چن لیا ہے اور دین میں تم پر کوئی تنگی نہیں رکھی قائم ہو جاؤ اپنے باپ ابراہیمؑ کی ملت پر اللہ نے پہلے بھی تمہارا نام ``مسلم" رکھا تھا اور اِس (قرآن) میں بھی (تمہارا یہی نام ہے) تاکہ رسول تم پر گواہ ہو اور تم لوگوں پر گواہ پس نماز قائم کرو، زکوٰۃ دو اور اللہ سے وابستہ ہو جاؤ وہ ہے تمہارا مولیٰ، بہت ہی اچھا ہے وہ مولیٰ اور بہت ہی اچھا ہے وہ مددگار\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiv{\basmalahur یقیناً فلاح پائی ہے ایمان والوں نے جو:\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdclxxv{اپنی نماز میں خشوع اختیار کرتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvi{لغویات سے دور رہتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvii{زکوٰۃ کے طریقے پر عامل ہوتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdclxxviii{اپنی شرمگاہوں کی حفاظت کرتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdclxxix{سوائے اپنی بیویوں کے اور ان عورتوں کے جو ان کی ملک یمین میں ہوں کہ ان پر (محفوظ نہ رکھنے میں) وہ قابل ملامت نہیں ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdclxxx{البتہ جو اُس کے علاوہ کچھ اور چاہیں وہی زیادتی کرنے والے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxi{اپنی امانتوں اور اپنے عہد و پیمان کا پاس رکھتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxii{اور اپنی نمازوں کی محافظت کرتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiii{یہی لوگ وہ وارث ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiv{جو میراث میں فردوس پائیں گے اور اس میں ہمیشہ رہیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxv{ہم نے انسان کو مٹی کے ست سے بنایا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvi{پھر اسے ایک محفوظ جگہ ٹپکی ہوئی بوند میں تبدیل کیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvii{پھر اس بوند کو لوتھڑے کی شکل دی، پھر لوتھڑے کو بوٹی بنا دیا، پھر بوٹی کی ہڈیاں بنائیں، پھر ہڈیوں پر گوشت چڑھایا، پھر اسے ایک دوسری ہی مخلوق بنا کھڑا کیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxviii{پس بڑا ہی بابرکت ہے اللہ، سب کاریگروں سے اچھا کاریگر\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxix{پھر اس کے بعد تم کو ضرور مرنا ہے، پھر قیامت کے روز یقیناً تم اٹھائے جاؤ گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxc{اور تمہارے اوپر ہم نے سات راستے بنائے، تخلیق کے کام سے ہم کچھ نابلد نہ تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxci{اور آسمان سے ہم نے ٹھیک حساب کے مطابق ایک خاص مقدار میں پانی اتارا اور اس کو زمین میں ٹھیرا دیا ہم اُسے جس طرح چاہیں غائب کر سکتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxcii{پھر اس پانی کے ذریعہ سے ہم نے تمہارے لیے کھجور اور انگور کے باغ پیدا کر دیے، تمہارے لیے ان باغوں میں بہت سے لذیذ پھل ہیں اور ان سے تم روزی حاصل کرتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxciii{اور وہ درخت بھی ہم نے پیدا کیا جو طور سیناء سے نکلتا ہے، تیل بھی لیے ہوئے اگتا ہے اور کھانے والوں کے لیے سالن بھی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxciv{اور حقیقت یہ ہے کہ تمہارے لیے مویشیوں میں بھی ایک سبق ہے ان کے پیٹوں میں جو کچھ ہے اسی میں سے ایک چیز ہم تمہیں پلاتے ہیں، اور تمہارے لیے ان میں بہت سے دوسرے دُوسرے فائدے بھی ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxcv{اُن کو تم کھاتے ہو اور اُن پر اور کشتیوں پر سوار بھی کیے جاتے ہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvi{ہم نے نوحؑ کو اس کی قوم کی طرف بھیجا اس نے کہا ``اے میری قوم کے لوگو، اللہ کی بندگی کرو، اس کے سوا تمہارے لیے کوئی اور معبود نہیں ہے، کیا تم ڈرتے نہیں ہو؟"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvii{اس کی قوم کے جن سرداروں نے ماننے سے انکار کیا وہ کہنے لگے کہ ``یہ شخص کچھ نہیں ہے مگر ایک بشر تم ہی جیسا اِس کی غرض یہ ہے کہ تم پر برتری حاصل کرے اللہ کو اگر بھیجنا ہوتا تو فرشتے بھیجتا یہ بات تو ہم نے کبھی اپنے باپ دادا کے وقتوں میں سنی ہی نہیں (کہ بشر رسول بن کر آئے)\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxcviii{کچھ نہیں، بس اس آدمی کو ذرا جنون لاحق ہو گیا ہے کچھ مدت اور دیکھ لو (شاید افاقہ ہو جائے)"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxcix{نوحؑ نے کہا ``پروردگار، ان لوگوں نے جو میری تکذیب کی ہے اس پر اب تو ہی میری مدد فرما"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcc{ہم نے اس پر وحی کی کہ ``ہماری نگرانی میں اور ہماری وحی کے مطابق کشتی تیار کر پھر جب ہمارا حکم آ جائے اور تنور ابل پڑے تو ہر قسم کے جانوروں میں سے ایک ایک جوڑا لے کر اس میں سوار ہو جا، اور اپنے اہل و عیال کو بھی ساتھ لے سوائے اُن کے جن کے خلاف پہلے ہی فیصلہ ہو چکا ہے، اور ظالموں کے معاملہ میں مجھ سے کچھ نہ کہنا، یہ اب غرق ہونے والے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcci{پھر جب تو اپنے ساتھیوں سمیت کشتی پر سوار ہو جائے تو کہہ، شکر ہے اُس خدا کا جس نے ہمیں ظالم لوگوں سے نجات دی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccii{اور کہہ، پروردگار، مجھ کو برکت والی جگہ اتار اور تُو بہترین جگہ دینے والا ہے"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcciii{اِس قصے میں بڑی نشانیاں ہیں اور آزمائش تو ہم کر کے ہی رہتے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcciv{ان کے بعد ہم نے ایک دوسرے دَور کی قوم اٹھائی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccv{پھر اُن میں خود انہی کی قوم کا ایک رسول بھیجا (جس نے انہیں دعوت دی) کہ اللہ کی بندگی کرو، تمہارے لیے اُس کے سوا کوئی اور معبود نہیں ہے، کیا تم ڈرتے نہیں ہو؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccvi{اُس کی قوم کے جن سرداروں نے ماننے سے انکار کیا اور آخرت کی پیشی کو جھٹلایا، جن کو ہم نے دنیا کی زندگی میں آسودہ کر رکھا تھا، وہ کہنے لگے ``یہ شخص کچھ نہیں ہے مگر ایک بشر تم ہی جیسا جو کچھ تم کھاتے ہو وہی یہ کھاتا ہے اور جو کچھ تم پیتے ہو وہی یہ پیتا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccvii{اب اگر تم نے اپنے ہی جیسے ایک بشر کی اطاعت قبول کر لی تو تم گھاٹے ہی میں رہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdccviii{یہ تمہیں اطلاع دیتا ہے کہ جب تم مر کر مٹی ہو جاؤ گے اور ہڈیوں کا پنجر بن کر رہ جاؤ گے اُس وقت تم (قبروں سے) نکالے جاؤ گے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdccix{بعید، بالکل بعید ہے یہ وعدہ جو تم سے کیا جا رہا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdccx{زندگی کچھ نہیں ہے مگر بس یہی دنیا کی زندگی یہیں ہم کو مرنا اور جینا ہے اور ہم ہرگز اٹھائے جانے والے نہیں ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdccxi{یہ شخص خدا کے نام پر محض جھوٹ گھڑ رہا ہے اور ہم کبھی اس کی ماننے والے نہیں ہیں"\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdccxii{رسول نے کہا ``پروردگار، اِن لوگوں نے جو میری تکذیب کی ہے، اس پر اب تو ہی میری نصرت فرما"\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdccxiii{جواب میں ارشاد ہوا ``قریب ہے وہ وقت جب یہ اپنے کیے پر پچھتائیں گے"\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdccxiv{آخرکار ٹھیک ٹھیک حق کے مطابق ایک ہنگامہ عظیم نے ان کو آ لیا اور ہم نے ان کو کچرا بنا کر پھینک دیا دُور ہو ظالم قوم!\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdccxv{پھر ہم نے ان کے بعد دوسری قومیں اٹھائیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdccxvi{کوئی قوم نہ اپنے وقت سے پہلے ختم ہوئی اور نہ اس کے بعد ٹھیر سکی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdccxvii{پھر ہم نے پے در پے اپنے رسول بھیجے جس قوم کے پاس بھی اس کا رسول آیا، اس نے اُسے جھٹلایا، اور ہم ایک کے بعد ایک قوم کو ہلاک کرتے چلے گئے حتیٰ کہ ان کو بس افسانہ ہی بنا کر چھوڑا پھٹکار اُن لوگوں پر جو ایمان نہیں لاتے!\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdccxviii{پھر ہم نے موسیٰؑ اور اس کے بھائی ہارونؑ کو اپنی نشانیوں اور کھلی سند کے ساتھ فرعون اور اس کے اعیان سلطنت کی طرف بھیجا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdccxix{مگر انہوں نے تکبر کیا اور بڑی دوں کی لی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdccxx{کہنے لگے ``کیا ہم اپنے ہی جیسے دو آدمیوں پر ایمان لے آئیں؟ اور آدمی بھی وہ جن کی قوم ہماری بندی ہے"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdccxxi{پس انہوں نے دونوں کو جھٹلا دیا اور ہلاک ہونے والوں میں جا ملے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdccxxii{اور موسٰیؑ کو ہم نے کتاب عطا فرمائی تاکہ لوگ اس سے رہنمائی حاصل کریں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiii{اور ابن مریم اور اس کی ماں کو ہم نے ایک نشان بنایا اور ان کو ایک سطحِ مرتفع پر رکھا جو اطمینان کی جگہ تھی اور چشمے اس میں جاری تھے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiv{اے پیغمبرو، کھاؤ پاک چیزیں اور عمل کرو صالح، تم جو کچھ بھی کرتے ہو، میں اس کو خوب جانتا ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdccxxv{اور یہ تمہاری امت ایک ہی امت ہے اور میں تمہارا رب ہوں، پس مجھی سے تم ڈرو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvi{مگر بعد میں لوگوں نے اپنے دین کو آپس میں ٹکڑے ٹکڑے کر لیا ہر گروہ کے پاس جو کچھ ہے اُسی میں وہ مگن ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvii{اچھا، تو چھوڑو انہیں، ڈوبے رہیں اپنی غفلت میں ایک وقت خاص تک\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdccxxviii{کیا یہ سمجھتے ہیں کہ ہم جو انہیں مال و اولاد سے مدد دیے جا رہے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdccxxix{تو گویا انہیں بھلائیاں دینے میں سرگرم ہیں؟ نہیں، اصل معاملے کا انہیں شعور نہیں ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdccxxx{جو اپنے رب کے خوف سے ڈرے رہتے ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxi{جو اپنے رب کی آیات پر ایمان لاتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxii{جو اپنے رب کے ساتھ کسی کو شریک نہیں کرتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiii{اور جن کا حال یہ ہے کہ دیتے ہیں جو کچھ بھی دیتے ہیں اور دل اُن کے اس خیال سے کانپتے رہتے ہیں کہ ہمیں اپنے رب کی طرف پلٹنا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiv{بھلائیوں کی طرف دَوڑنے والے اور سبقت کر کے انہیں پا لینے والے تو درحقیقت یہ لوگ ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxv{ہم کسی شخص کو اس کی مقدرت سے زیادہ کی تکلیف نہیں دیتے اور ہمارے پاس ایک کتاب ہے جو (ہر ایک کا حال) ٹھیک ٹھیک بتا دینے والی ہے، اور لوگوں پر ظلم بہرحال نہیں کیا جائے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvi{مگر یہ لوگ اس معاملے سے بے خبر ہیں اور ان کے اعمال بھی اس طریقے سے (جس کا اوپر ذکر کیا گیا ہے) مختلف ہیں وہ اپنے یہ کرتوت کیے چلے جائیں گے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvii{یہاں تک کہ جب ہم ان کے عیاشوں کو عذاب میں پکڑ لیں گے تو پھر وہ ڈکرانا شروع کر دیں گے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxviii{اب بند کرو اپنی فریاد و فغاں، ہماری طرف سے اب کوئی مدد تمہیں نہیں ملنی\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxix{میری آیات سنائی جاتی تھیں تو تم (رسول کی آواز سُنتے ہی) الٹے پاؤں بھاگ نکلتے تھے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdccxl{اپنے گھمنڈ میں اُس کو خاطر ہی میں نہ لاتے تھے اپنی چوپالوں میں اُس پر باتیں چھانٹتے اور بکواس کیا کرتے تھے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdccxli{تو کیا اِن لوگوں نے کبھی اِس کلام پر غور نہیں کیا؟ یا وہ کوئی ایسی بات لایا ہے جو کبھی ان کے اسلاف کے پاس نہ آئی تھی؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdccxlii{یا یہ اپنے رسول سے کبھی کے واقف نہ تھے کہ (اَن جانا آدمی ہونے کے باعث) اُس سے بدکتے ہیں؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdccxliii{یا یہ اس بات کے قائل ہیں کہ وہ مجنون ہے؟ نہیں، بلکہ وہ حق لایا ہے اور حق ہی ان کی اکثریت کو ناگوار ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdccxliv{اور حق اگر کہیں اِن کی خواہشات کے پیچھے چلتا تو زمین اور آسمان اور ان کی ساری آبادی کا نظام درہم برہم ہو جاتا نہیں، بلکہ ہم ان کا اپنا ہی ذکر اُن کے پاس لائے ہیں اور وہ اپنے ذکر سے منہ موڑ رہے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdccxlv{کیا تُو ان سے کچھ مانگ رہا ہے؟ تیرے لیے تیرے رب کا دیا ہی بہتر ہے اور وہ بہترین رازق ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvi{تُو تو ان کوسیدھے راستے کی طرف بلا رہا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvii{مگر جو لوگ آخرت کو نہیں مانتے وہ راہِ راست سے ہٹ کر چلنا چاہتے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdccxlviii{اگر ہم اِن پر رحم کریں اور وہ تکلیف جس میں آج کل یہ مبتلا ہیں دُور کر دیں تو یہ اپنی سرکشی میں بالکل ہی بہک جائیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdccxlix{اِن کا حال تو یہ ہے کہ ہم نے انہیں تکلیف میں مبتلا کیا، پھر بھی یہ اپنے رب کے آگے نہ جھکے اور نہ عاجزی اختیار کرتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdccl{البتہ جب نوبت یہاں تک پہنچ جائے گی کہ ہم اِن پر سخت عذاب کا دروازہ کھول دیں گے تو یکایک تم دیکھو گے کہ اس حالت میں یہ ہر خیر سے مایوس ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdccli{وہ اللہ ہی تو ہے جس نے تمہیں سُننے اور دیکھنے کی قوتیں دیں اور سوچنے کو دل دیے مگر تم لوگ کم ہی شکر گزار ہوتے ہو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdcclii{وہی ہے جس نے تمہیں زمین میں پھیلایا، اور اسی کی طرف تم سمیٹے جاؤ گے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdccliii{وہی زندگی بخشتا ہے اور وہی موت دیتا ہے گردش لیل و نہار اسی کے قبضہ قدرت میں ہے کیا تمہاری سمجھ میں یہ بات نہیں آتی؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdccliv{مگر یہ لوگ وہی کچھ کہتے ہیں جو ان کے پیش رَو کہہ چکے ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdcclv{یہ کہتے ہیں ``کیا جب ہم مر کر مٹی ہو جائیں گے اور ہڈیوں کا پنجر بن کر رہ جائیں گے تو ہم کو پھر زندہ کر کے اٹھایا جائے گا؟\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdcclvi{ہم نے بھی یہ وعدے بہت سنے ہیں اور ہم سے پہلے ہمارے باپ دادا بھی سنتے رہے ہیں یہ محض افسانہائے پارینہ ہیں"\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdcclvii{ان سے کہو، بتاؤ اگر تم جانتے ہو، کہ یہ زمین اور اس کی ساری آبادی کس کی ہے؟\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdcclviii{یہ ضرور کہیں گے اللہ کی کہو، پھر تم ہوش میں کیوں نہیں آتے؟\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdcclix{ان سے پوچھو، ساتوں آسمانوں اور عرش عظیم کا مالک کون ہے؟\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdcclx{یہ ضرور کہیں گے اللہ کہو، پھر تم ڈرتے کیوں نہیں؟\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdcclxi{اِن سے کہو، بتاؤ اگر تم جانتے ہو کہ ہر چیز پر اقتدار کس کا ہے؟ اور کون ہے وہ جو پناہ دیتا ہے اور اس کے مقابلے میں کوئی پناہ نہیں دے سکتا؟\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdcclxii{یہ ضرور کہیں گے کہ یہ بات تو اللہ ہی کے لیے ہے کہو، پھر کہاں سے تم کو دھوکا لگتا ہے؟\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiii{جو امر حق ہے وہ ہم اِن کے سامنے لے آئے ہیں، اور کوئی شک نہیں کہ یہ لوگ جھوٹے ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiv{اللہ نے کسی کو اپنی اولاد نہیں بنایا ہے اور کوئی دوسرا خدا اُس کے ساتھ نہیں ہے اگر ایسا ہوتا تو ہر خدا اپنی خلق کو لے کر الگ ہو جاتا، اور پھر وہ ایک دوسرے پر چڑھ دوڑتے پاک ہے اللہ ان باتوں سے جو یہ لوگ بناتے ہیں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdcclxv{کھلے اور چھپے کا جاننے والا، وہ بالاتر ہے اُس شرک سے جو یہ لوگ تجویز کر رہے ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvi{اے محمدؐ، دعا کرو کہ ``پروردگار، جس عذاب کی اِن کو دھمکی دی جا رہی ہے وہ اگر میری موجودگی میں تو لائے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvii{تو اے میرے رب، مجھے ان ظالم لوگوں میں شامل نہ کیجیو"\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdcclxviii{اور حقیقت یہ ہے کہ ہم تمہاری آنکھوں کے سامنے ہی وہ چیز لے آنے کی پوری قدرت رکھتے ہیں جس کی دھمکی ہم انہیں دے رہے ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdcclxix{اے نبیؐ، برائی کو اس طریقہ سے دفع کرو جو بہترین ہو جو کچھ باتیں وہ تم پر بناتے ہیں وہ ہمیں خوب معلوم ہیں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdcclxx{اور دعا کرو کہ ``پروردگار، میں شیاطین کی اکساہٹوں سے تیری پناہ مانگتا ہوں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxi{بلکہ اے میرے رب، میں تو اس سے بھی تیری پناہ مانگتا ہوں کہ وہ میرے پاس آئیں"\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxii{(یہ لوگ اپنی کرنی سے باز نہ آئیں گے) یہاں تک کہ جب ان میں سے کسی کو موت آ جائے گی تو کہنا شروع کرے گا کہ ``اے میرے رب، مجھے اُسی دنیا میں واپس بھیج دیجیے جسے میں چھوڑ آیا ہوں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiii{امید ہے کہ اب میں نیک عمل کروں گا" ہرگز نہیں، یہ بس ایک بات ہے جو وہ بک رہا ہے اب اِن سب (مرنے والوں) کے پیچھے ایک برزخ حائل ہے دوسری زندگی کے دن تک\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiv{پھر جونہی کہ صور پھونک دیا گیا، ان کے درمیان پھر کوئی رشتہ نہ رہے گا اور نہ وہ ایک دوسرے کو پوچھیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxv{اُس وقت جن کے پلڑے بھاری ہوں گے وہی فلاح پائیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvi{اور جن کے پلڑے ہلکے ہوں گے وہی لوگ ہوں گے جنہوں نے اپنے آپ کو گھاٹے میں ڈال لیا وہ جہنم میں ہمیشہ رہیں گے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvii{آگ ان کے چہروں کی کھال چاٹ جائے گی اور اُن کے جبڑے باہر نکل آئیں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxviii{``کیا تم وہی لوگ نہیں ہو کہ میری آیات تمہیں سنائی جاتی تھیں تو تم انہیں جھٹلاتے تھے؟"\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxix{وہ کہیں گے ``اے ہمارے رب، ہماری بد بختی ہم پر چھا گئی تھی واقعی ہم گمراہ لوگ تھے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxx{اے پروردگار، اب ہمیں یہاں سے نکال دے پھر ہم ایسا قصور کریں تو ظالم ہوں گے"\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxi{اللہ تعالیٰ جواب دے گا ``دور ہو میرے سامنے سے، پڑے رہو اسی میں اور مجھ سے بات نہ کرو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxii{تم وہی لوگ تو ہو کہ میرے کچھ بندے جب کہتے تھے کہ اے ہمارے پروردگار، ہم ایمان لائے، ہمیں معاف کر دے، ہم پر رحم کر، تُو سب رحیموں سے اچھا رحیم ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiii{تو تم نے ان کا مذاق بنا لیا یہاں تک کہ اُن کی ضد نے تمہیں یہ بھی بھُلا دیا کہ میں بھی کوئی ہوں، اور تم ان پر ہنستے رہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiv{آج اُن کے اُس صبر کا میں نے یہ پھل دیا ہے کہ وہی کامیاب ہیں"\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxv{پھر اللہ تعالی ان سے پوچھے گا ``بتاؤ، زمین میں تم کتنے سال رہے؟"\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvi{وہ کہیں گے ``ایک دن یا دن کا بھی کچھ حصہ ہم وہاں ٹھیرے ہیں شمار کرنے والوں سے پوچھ لیجیے"\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvii{ارشاد ہو گا ``تھوڑی ہی دیر ٹھیرے ہو نا، کاش تم نے یہ اُس وقت جانا ہوتا\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxviii{کیا تم نے یہ سمجھ رکھا تھا کہ ہم نے تمہیں فضول ہی پیدا کیا ہے اور تمہیں ہماری طرف کبھی پلٹنا ہی نہیں ہے؟"\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxix{پس بالا و برتر ہے اللہ، پادشاہ حقیقی، کوئی خدا اُس کے سوا نہیں، مالک ہے عرش بزرگ کا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmdccxc{اور جو کوئی اللہ کے ساتھ کسی اور معبود کو پکارے، جس کے لیے اس کے پاس کوئی دلیل نہیں، تو اس کا حساب اس کے رب کے پاس ہے ایسے کافر کبھی فلاح نہیں پا سکتے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmdccxci{اے محمدؐ، کہو، ``میرے رب درگزر فرما، اور رحم کر، اور تو سب رحیموں سے اچھا رحیم ہے"\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmdccxcii{\basmalahur یہ ایک سورت ہے جس کو ہم نے نازل کیا ہے، اور اسے ہم نے فرض کیا ہے، اور اس میں ہم نے صاف صاف ہدایات نازل کی ہیں، شاید کہ تم سبق لو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccxciii{زانیہ عورت اور زانی مرد، دونوں میں سے ہر ایک کو سو کوڑے مارو اور ان پر ترس کھانے کا جذبہ اللہ کے دین کے معاملے میں تم کو دامن گیر نہ ہو اگر تم اللہ تعالیٰ اور روز آخر پر ایمان رکھتے ہو اور ان کو سزا دیتے وقت اہل ایمان کا ایک گروہ موجود رہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccxciv{زانی نکاح نہ کرے مگر زانیہ کے ساتھ یا مشرکہ کے ساتھ اور زانیہ کے ساتھ نکاح نہ کرے مگر زانی یا مشرک اور یہ حرام کر دیا گیا ہے اہل ایمان پر\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccxcv{اور جو لوگ پاک دامن عورتوں پر تہمت لگائیں، پھر چار گواہ لے کر نہ آئیں، ان کو اسی کوڑے مارو اور ان کی شہادت کبھی قبول نہ کرو، اور وہ خود ہی فاسق ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvi{سوائے اُن لوگوں کے جو اس حرکت کے بعد تائب ہو جائیں اور اصلاح کر لیں کہ اللہ ضرور (اُن کے حق میں) غفور و رحیم ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvii{اور جو لوگ اپنی بیویوں پر الزام لگائیں اور ان کے پاس خود ان کے اپنے سوا دوسرے کوئی گواہ نہ ہوں تو اُن میں سے ایک شخص کی شہادت (یہ ہے کہ وہ) چار مرتبہ اللہ کی قسم کھا کر گواہی دے کہ وہ (اپنے الزام میں) سچا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccxcviii{اور پانچویں بار کہے کہ اُس پر اللہ کی لعنت ہو اگر وہ (اپنے الزام میں) جھوٹا ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccxcix{اور عورت سے سزا اس طرح ٹل سکتی ہے کہ وہ چار مرتبہ اللہ کی قسم کھا کر شہادت دے کہ یہ شخص (اپنے الزام میں) جھوٹا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccc{اور پانچویں مرتبہ کہے کہ اُس بندی پر اللہ کا غضب ٹوٹے اگر وہ (اپنے الزام میں) سچا ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccci{تم لوگوں پر اللہ کا فضل اور اس کا رحم نہ ہوتا اور یہ بات نہ ہوتی کہ اللہ بڑا التفات فرمانے والا اور حکیم ہے، تو (بیویوں پر الزام کا معاملہ تمہیں بڑی پیچیدگی میں ڈال دیتا)\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcccii{جو لوگ یہ بہتان گھڑ لائے ہیں وہ تمہارے ہی اندر کا ایک ٹولہ ہیں اس واقعے کو اپنے حق میں شر نہ سمجھو بلکہ یہ بھی تمہارے لیے خیر ہی ہے جس نے اس میں جتنا حصہ لیا اس نے اتنا ہی گناہ سمیٹا اور جس شخص نے اِس کی ذمہ داری کا بڑا حصہ اپنے سر لیا اس کے لیے تو عذاب عظیم ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccciii{جس وقت تم لوگوں نے اسے سنا تھا اُسی وقت کیوں نہ مومن مردوں اور مومن عورتوں نے اپنے آپ سے نیک گمان کیا اور کیوں نہ کہہ دیا کہ یہ صریح بہتان ہے؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccciv{وہ لوگ (اپنے الزام کے ثبوت میں) چار گواہ کیوں نہ لائے؟اب کہ وہ گواہ نہیں لائے ہیں، اللہ کے نزدیک وہی جھوٹے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcccv{اگر تم لوگوں پر دنیا اور آخرت میں اللہ کا فضل اور رحم و کرم نہ ہوتا تو جن باتوں میں تم پڑ گئے تھے ان کی پاداش میں بڑا عذاب تمہیں آ لیتا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcccvi{(ذرا غور تو کرو، اُس وقت تم کیسی سخت غلطی کر رہے تھے) جبکہ تمہاری ایک زبان سے دوسری زبان اس جھوٹ کو لیتی جا رہی تھی اور تم اپنے منہ سے وہ کچھ کہے جا رہے تھے جس کے متعلق تمہیں کوئی علم نہ تھا تم اسے ایک معمولی بات سمجھ رہے تھے، حالانکہ اللہ کے نزدیک یہ بڑی بات تھی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcccvii{کیوں نہ اُسے سنتے ہی تم نے کہہ دیا کہ ``ہمیں ایسی بات زبان سے نکالنا زیب نہیں دیتا، سبحان اللہ، یہ تو ایک بہتان عظیم ہے"\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcccviii{اللہ تم کو نصیحت کرتا ہے کہ آئندہ کبھی ایسی حرکت نہ کرنا اگر تم مومن ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcccix{اللہ تمہیں صاف صاف ہدایات دیتا ہے اور وہ علیم و حکیم ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcccx{جو لوگ چاہتے ہیں کہ ایمان لانے والوں کے گروہ میں فحش پھیلے وہ دنیا اور آخرت میں دردناک سزا کے مستحق ہیں، اللہ جانتا ہے اور تم نہیں جانتے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcccxi{اگر اللہ کا فضل اور اس کا رحم و کرم تم پر نہ ہوتا اور یہ بات نہ ہوتی کہ اللہ بڑا شفیق و رحیم ہے (تو یہ چیز جو ابھی تمہارے اندر پھیلائی گئی تھی بدترین نتائج دکھا دیتی)\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcccxii{اے لوگو جو ایمان لائے ہو، شیطان کے نقش قدم پر نہ چلو اس کی پیروی کوئی کرے گا تو وہ اسے فحش اور بدی ہی کا حکم دے گا اگر اللہ کا فضل اور اس کا رحم و کرم تم پر نہ ہوتا تو تم میں سے کوئی شخص پاک نہ ہوسکتا مگر اللہ ہی جسے چاہتا ہے پاک کر دیتا ہے، اور اللہ سننے والا اور جاننے والا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiii{تم میں سے جو لوگ صاحب فضل اور صاحب مقدرت ہیں وہ اس بات کی قسم نہ کھا بیٹھیں کہ اپنے رشتہ دار، مسکین اور مہاجر فی سبیل اللہ لوگوں کی مدد نہ کریں گے انہیں معاف کر دینا چاہیے اور درگزر کرنا چاہیے کیا تم نہیں چاہتے کہ اللہ تمہیں معاف کرے؟ اور اللہ کی صفت یہ ہے کہ وہ غفور اور رحیم ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiv{جو لوگ پاک دامن، بے خبر، مومن عورتوں پر تہمتیں لگاتے ہیں ان پر دنیا اور آخرت میں لعنت کی گئی اور ان کے لیے بڑا عذاب ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcccxv{وہ اس دن کو بھول نہ جائیں جبکہ ان کی اپنی زبانیں اور ان کے اپنے ہاتھ پاؤں ان کے کرتوتوں کی گواہی دیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvi{اس دن اللہ وہ بدلہ انہیں بھرپور دے گا جس کے وہ مستحق ہیں اور انہیں معلوم ہو جائے گا کہ اللہ ہی حق ہے سچ کو سچ کر دکھانے والا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvii{خبیث عورتیں خبیث مردوں کے لیے ہیں اور خبیث مرد خبیث عورتوں کے لیے پاکیزہ عورتیں پاکیزہ مردوں کے لیے ہیں اور پاکیزہ مرد پاکیزہ عورتوں کے لیے ان کا دامن پاک ہے اُن باتوں سے جو بنانے والے بناتے ہیں، ان کے لیے مغفرت ہے اور رزق کریم\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcccxviii{اے لوگو جو ایمان لائے ہو، اپنے گھروں کے سوا دوسرے گھروں میں داخل نہ ہوا کرو جب تک کہ گھر والوں کی رضا نہ لے لو اور گھر والوں پر سلام نہ بھیج لو، یہ طریقہ تمہارے لیے بہتر ہے توقع ہے کہ تم اس کا خیال رکھو گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcccxix{پھر اگر وہاں کسی کو نہ پاؤ تو داخل نہ ہو جب تک کہ تم کو اجازت نہ دے دی جائے، اور اگر تم سے کہا جائے کہ واپس چلے جاؤ تو واپس ہو جاؤ، یہ تمہارے لیے زیادہ پاکیزہ طریقہ ہے، اور جو کچھ تم کرتے ہو اللہ اسے خوب جانتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcccxx{البتہ تمہارے لیے اس میں کوئی مضائقہ نہیں ہے کہ ایسے گھروں میں داخل ہو جاؤ جو کسی کے رہنے کی جگہ نہ ہوں اور جن میں تمہارے فائدے (یا کام) کی کوئی چیز ہو، تم جو کچھ ظاہر کرتے ہو اور جو کچھ چھپاتے ہو سب کی اللہ کو خبر ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxi{اے نبیؐ، مومن مردوں سے کہو کہ اپنی نظریں بچا کر رکھیں اور اپنی شرمگاہوں کی حفاظت کریں، یہ اُن کے لیے زیادہ پاکیزہ طریقہ ہے، جو کچھ وہ کرتے ہیں اللہ اُس سے باخبر رہتا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxii{اور اے نبیؐ، مومن عورتوں سے کہہ دو کہ اپنی نظریں بچا کر رکھیں، اور اپنی شرمگاہوں کی حفاظت کریں، اور اپنا بناؤ سنگھار نہ دکھائیں بجز اُس کے جو خود ظاہر ہو جائے، اور اپنے سینوں پر اپنی اوڑھنیوں کے آنچل ڈالے رہیں وہ اپنا بناؤ سنگھار نہ ظاہر کریں مگر اِن لوگوں کے سامنے: شوہر، باپ، شوہروں کے باپ، اپنے بیٹے، شوہروں کے بیٹے، بھائی، بھائیوں کے بیٹے، بہنوں کے بیٹے، اپنے میل جول کی عورتیں، ا پنے مملوک، وہ زیردست مرد جو کسی اور قسم کی غرض نہ رکھتے ہوں، اور وہ بچے جو عورتوں کی پوشیدہ باتوں سے ابھی واقف نہ ہوئے ہوں وہ ا پنے پاؤں زمین پر مارتی ہوئی نہ چلا کریں کہ اپنی جو زینت انہوں نے چھپا رکھی ہو اس کا لوگوں کو علم ہو جائے اے مومنو، تم سب مل کر اللہ سے توبہ کرو، توقع ہے کہ فلاح پاؤ گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiii{تم میں سے جو لوگ مجرد ہوں، اور تمہارے لونڈی غلاموں میں سے جو صالح ہوں، ان کے نکاح کر دو اگر وہ غریب ہوں تو اللہ اپنے فضل سے اُن کو غنی کر دے گا، اللہ بڑی وسعت والا اور علیم ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiv{اور جو نکاح کا موقع نہ پائیں انہیں چاہیے کہ عفت مآبی اختیار کریں، یہاں تک کہ اللہ اپنے فضل سے اُن کو غنی کر دے اور تمہارے مملوکوں میں سے جو مکاتبت کی درخواست کریں ان سے مکاتبت کر لو اگر تمہیں معلوم ہو کہ ان کے اندر بھلائی ہے، اور ان کو اُس مال میں سے دو جو اللہ نے تمہیں دیا ہے اور اپنی لونڈیوں کو ا پنے دنیوی فائدوں کی خاطر قحبہ گری پر مجبور نہ کرو جبکہ وہ خود پاکدامن رہنا چاہتی ہوں، اور جو کوئی اُن کو مجبور کرے تو اِس جبر کے بعد اللہ اُن کے لیے غفور و رحیم ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxv{ہم نے صاف صاف ہدایت دینے والی آیات تمہارے پاس بھیج دی ہیں، اور ان قوموں کی عبر ت ناک مثالیں بھی ہم تمہارے سامنے پیش کر چکے ہیں جو تم سے پہلے ہو گزری ہیں، اور وہ نصیحتیں ہم نے کر دی ہیں جو ڈرنے والوں کے لیے ہوتی ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvi{اللہ آسمانوں اور زمین کا نور ہے (کائنات میں) اس کے نور کی مثال ایسی ہے جیسے ایک طاق میں چراغ رکھا ہوا ہو، چراغ ایک فانوس میں ہو، فانوس کا حال یہ ہو کہ جیسے موتی کی طرح چمکتا ہوا تارا، اور وہ چراغ زیتون کے ایک ایسے مبارک درخت کے تیل سے روشن کیا جاتا ہو جو شرقی ہو نہ غربی، جس کا تیل آپ ہی آپ بھڑکا پڑتا ہو چاہے آگ اس کو نہ لگے، (اِس طرح) روشنی پر روشنی (بڑھنے کے تمام اسباب جمع ہو گئے ہوں) اللہ اپنے نور کی طرف جس کی چاہتا ہے رہنمائی فرماتا ہے، وہ لوگوں کو مثالوں سے بات سمجھاتا ہے، وہ ہر چیز سے خوب واقف ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvii{(اُس کے نور کی طرف ہدایت پانے والے) اُن گھروں میں پائے جاتے ہیں جنہیں بلند کرنے کا، اور جن میں اپنے نام کی یاد کا اللہ نے اذن دیا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxviii{اُن میں ایسے لوگ صبح و شام اُس کی تسبیح کرتے ہیں جنہیں تجارت اور خرید و فروخت اللہ کی یاد سے اور اقامت نماز و ادائے زکوٰۃ سے غافل نہیں کر دیتی وہ اُس دن سے ڈرتے رہتے ہیں جس میں دل الٹنے اور دیدے پتھرا جانے کی نوبت آ جائے گی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxix{(اور وہ یہ سب کچھ اس لیے کرتے ہیں) تاکہ اللہ ان کے بہترین اعمال کی جزا اُن کو دے اور مزید اپنے فضل سے نوازے، اللہ جسے چاہتا ہے بے حساب دیتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxx{(اس کے برعکس) جنہوں نے کفر کیا ان کے اعمال کی مثال ایسی ہے جیسے دشت بے آب میں سراب کہ پیاسا اُس کو پانی سمجھے ہوئے تھا، مگر جب وہاں پہنچا تو کچھ نہ پایا، بلکہ وہاں اس نے اللہ کو موجود پایا، جس نے اس کا پورا پورا حساب چکا دیا، اور اللہ کو حساب لیتے دیر نہیں لگتی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxi{یا پھر اس کی مثال ایسی ہے جیسے ایک گہرے سمندر میں اندھیرا، کہ اوپر ایک موج چھائی ہوئی ہے، اُس پر ایک اور موج، اور اس کے اوپر بادل، تاریکی پر تاریکی مسلط ہے، آدمی اپنا ہاتھ نکالے تو اسے بھی نہ دیکھنے پائے جسے اللہ نور نہ بخشے اُس کے لیے پھر کوئی نور نہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxii{کیا تم دیکھتے نہیں ہو کہ اللہ کی تسبیح کر رہے ہیں وہ سب جو آسمانوں اور زمین میں ہیں اور وہ پرندے جو پر پھیلا ئے اڑ رہے ہیں؟ ہر ایک اپنی نماز اور تسبیح کا طریقہ جانتا ہے، اور یہ سب جو کچھ کرتے ہیں اللہ اس سے باخبر رہتا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiii{آسمانوں اور زمین کی بادشاہی اللہ ہی کے لیے ہے اور اسی کی طرف سب کو پلٹنا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiv{کیا تم دیکھتے نہیں ہو کہ اللہ بادل کو آہستہ آہستہ چلاتا ہے، پھر اس کے ٹکڑوں کو باہم جوڑتا ہے، پھر اسے سمیٹ کر ایک کثیف ابر بنا دیتا ہے، پھر تم دیکھتے ہو کہ اس کے خول میں سے بارش کے قطرے ٹپکتے چلے آتے ہیں اور وہ آسمان سے، اُن پہاڑوں کی بدولت جو اس میں بلند ہیں، اولے برساتا ہے، پھر جسے چاہتا ہے ان کا نقصان پہنچاتا ہے اور جسے چاہتا ہے ان سے بچا لیتا ہے اُس کی بجلی کی چمک نگاہوں کو خیرہ کیے دیتی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxv{رات اور دن کا الٹ پھیر وہی کر رہا ہے اِس میں ایک سبق ہے آنکھوں والوں کے لیے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvi{اور اللہ نے ہر جاندار ایک طرح کے پانی سے پیدا کیا، کوئی پیٹ کے بل چل رہا ہے تو کوئی دو ٹانگوں پر اور کوئی چار ٹانگوں پر جو کچھ وہ چاہتا ہے پیدا کرتا ہے، وہ ہر چیز پر قادر ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvii{ہم نے صاف صاف حقیقت بتانے والی آیات نازل کر دی ہیں، آگے صراط مستقیم کی طرف ہدایت اللہ ہی جسے چاہتا ہے دیتا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxviii{یہ لوگ کہتے ہیں کہ ہم ایمان لائے اللہ اور رسولؐ پر اور ہم نے اطاعت قبول کی، مگر اس کے بعد ان میں سے ایک گروہ (اطاعت سے) منہ موڑ جاتا ہے ایسے لوگ ہرگز مومن نہیں ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxix{جب ان کو بلایا جاتا ہے اللہ اور رسول کی طرف، تاکہ رسول ان کے آپس کے مقدمے کا فیصلہ کرے تو ان میں سے ایک فریق کترا جاتا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcccxl{البتہ اگر حق ان کی موافقت میں ہو تو رسول کے پاس بڑے اطاعت کیش بن کر آ جاتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcccxli{کیا ان کے دلوں کو (منافقت کا) روگ لگا ہوا ہے؟ یا یہ شک میں پڑے ہوئے ہیں؟ یا ان کو یہ خوف ہے کہ اللہ اور اس کا رسول ان پر ظلم کرے گا؟ اصل بات یہ ہے کہ ظالم تو یہ لوگ خود ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlii{ایمان لانے والوں کا کام تو یہ ہے کہ جب وہ اللہ اور رسول کی طرف بلا ئے جائیں تاکہ رسول ان کے مقدمے کا فیصلہ کرے تو وہ کہیں کہ ہم نے سنا اور اطاعت کی ایسے ہی لوگ فلاح پانے والے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliii{اور کامیاب وہی ہیں جو اللہ اور رسول کی فرماں برداری کریں اور اللہ سے ڈریں اور اس کی نافرمانی سے بچیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliv{یہ (منافق) اللہ کے نام سے کڑی کڑی قسمیں کھا کر کہتے ہیں کہ ``آپ حکم دیں تو ہم گھروں سے نکل کھڑے ہوں" اِن سے کہو ``قسمیں نہ کھاؤ، تمہاری اطاعت کا حال معلوم ہے، تمہارے کرتوتوں سے اللہ بے خبر نہیں ہے"\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlv{کہو، ``اللہ کے مطیع بنو اور رسولؐ کے تابع فرمان بن کر رہو لیکن اگر تم منہ پھیرتے ہو تو خوب سمجھ لو کہ رسولؐ پر جس فرض کا بار رکھا گیا ہے اُس کا ذمہ دار وہ ہے اور تم پر جس فرض کا بار ڈالا گیا ہے اُس کے ذمہ دار تم ہو اُس کی اطاعت کرو گے تو خود ہی ہدایت پاؤ گے ورنہ رسول کی ذمہ داری اس سے زیادہ کچھ نہیں ہے کہ صاف صاف حکم پہنچا دے"\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvi{اللہ نے وعدہ فرمایا ہے تم میں سے اُن لوگوں کے ساتھ جو ایمان لائیں اور نیک عمل کریں کہ وہ ان کو اُسی طرح زمین میں خلیفہ بنائے گا جس طرح اُن سے پہلے گزرے ہوئے لوگوں کو بنا چکا ہے، اُن کے لیے اُن کے اُس دین کو مضبوط بنیادوں پر قائم کر دے گا جسے اللہ تعالیٰ نے اُن کے حق میں پسند کیا ہے، اور اُن کی (موجودہ) حالت خوف کو امن سے بدل دے گا، بس وہ میری بندگی کریں اور میرے ساتھ کسی کو شریک نہ کریں اور جو اس کے بعد کفر کرے تو ایسے ہی لوگ فاسق ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvii{نماز قائم کرو، زکوٰۃ دو، اور رسولؐ کی اطاعت کرو، امید ہے کہ تم پر رحم کیا جائے گا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlviii{جو لوگ کفر کر رہے ہیں ا ن کے متعلق اس غلط فہمی میں نہ رہو کہ وہ زمین میں اللہ کو عاجز کر دیں گے ان کا ٹھکانا دوزخ ہے اور وہ بڑا ہی برا ٹھکانا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlix{اے لوگو جو ایمان لائے ہو، لازم ہے کہ تمہارے مملوک اور تمہارے وہ بچے جو ابھی عقل کی حد کو نہیں پہنچے ہیں، تین اوقات میں اجازت لے کر تمہارے پاس آیا کریں: صبح کی نماز سے پہلے، اور دوپہر کو جبکہ تم کپڑے اتار کر رکھ دیتے ہو، اور عشاء کی نماز کے بعد یہ تین وقت تمہارے لیے پردے کے وقت ہیں اِن کے بعد وہ بلا اجازت آئیں تو نہ تم پر کوئی گناہ ہے نہ اُن پر، تمہیں ایک دوسرے کے پاس بار بار آنا ہی ہوتا ہے اس طرح اللہ تمہارے لیے اپنے ارشادات کی توضیح کرتا ہے، اور وہ علیم و حکیم ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcccl{اور جب تمہارے بچے عقل کی حد کو پہنچ جائیں تو چاہے کہ اُسی طرح اجازت لیکر آیا کریں جس طرح اُن کے بڑے اجازت لیتے رہے ہیں اِس طرح اللہ اپنی آیات تمہارے سامنے کھولتا ہے، اور وہ علیم و حکیم ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdcccli{اور جو عورتیں جوانی سے گزری بیٹھی ہوں، نکاح کی امیدوار نہ ہوں، وہ اگر اپنی چادریں اتار کر رکھ دیں تو اُن پر کوئی گناہ نہیں، بشرطیکہ زینت کی نمائش کرنے والی نہ ہوں تاہم وہ بھی حیاداری ہی برتیں تو اُن کے حق میں اچھا ہے، اور اللہ سب کچھ سنتا اور جانتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccclii{کوئی حرج نہیں اگر کوئی اندھا، یا لنگڑا، یا مریض (کسی کے گھر سے کھا لے) اور نہ تمہارے اوپر اِس میں کوئی مضائقہ ہے کہ اپنے گھروں سے کھاؤ یا اپنے باپ دادا کے گھروں سے، یا اپنی ماں نانی کے گھروں سے، یا اپنے بھائیوں کے گھروں سے، یا اپنی بہنوں کے گھروں سے، یا اپنے چچاؤں کے گھروں سے، یا اپنی پھوپھیوں کے گھروں سے، یا اپنے ماموؤں کے گھروں سے، یا اپنی خالاؤں کے گھروں سے، یا اُن گھروں سے جن کی کنجیاں تمہاری سپردگی میں ہوں، یا اپنے دوستوں کے گھروں سے اس میں بھی کوئی حرج نہیں کہ تم لوگ مل کر کھاؤ یا الگ الگ البتہ جب گھروں میں داخل ہوا کرو تو اپنے لوگوں کو سلام کیا کرو، دعا ئے خیر، اللہ کی طرف سے مقرر فر مائی ہوئی، بڑی بابرکت اور پاکیزہ اِس طرح اللہ تعالیٰ تمہارے سامنے آیات بیان کرتا ہے، توقع ہے کہ تم سمجھ بوجھ سے کام لو گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdcccliii{مومن تو اصل میں وہی ہیں جو اللہ اور اُس کے رسول کو دل سے مانیں اور جب کسی اجتماعی کام کے موقع پر رسولؐ کے ساتھ ہوں تو اُس سے اجازت لیے بغیر نہ جائیں جو لوگ تم سے اجازت مانگتے ہیں وہی اللہ اور رسول کے ماننے والے ہیں، پس جب وہ اپنے کسی کام سے اجازت مانگیں تو جسے تم چاہو اجازت دے دیا کرو اور ایسے لوگوں کے حق میں اللہ سے دعائے مغفرت کیا کرو، اللہ یقیناً غفور و رحیم ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdcccliv{مسلمانو، اپنے درمیان رسولؐ کے بلانے کو آپس میں ایک دوسرے کا سا بلانا نہ سمجھ بیٹھو اللہ اُن لوگوں کو خوب جانتا ہے جو تم میں ایسے ہیں کہ ایک دوسرے کی آڑ لیتے ہوئے چپکے سے سٹک جاتے ہیں رسولؐ کے حکم کی خلاف ورزی کرنے والوں کو ڈرنا چاہیے کہ وہ کسی فتنے میں گرفتار نہ ہو جائیں یا ان پر دردناک عذاب نہ آ جائے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccclv{خبردار رہو، آسمان و زمین میں جو کچھ ہے اللہ کا ہے تم جس روش پر بھی ہو اللہ اُس کو جانتا ہے جس روز لوگ اُس کی طرف پلٹیں گے وہ اُنہیں بتا دے گا کہ وہ کیا کچھ کر کے آئے ہیں وہ ہر چیز کا علم رکھتا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccclvi{\basmalahur نہایت متبرک ہے وہ جس نے یہ فرقان اپنے بندے پر نازل کیا تاکہ سارے جہان والوں کے لیے نذیر ہو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccclvii{وہ جو زمین اور آسمانوں کی بادشاہی کا مالک ہے، جس نے کسی کو بیٹا نہیں بنایا ہے، جس کے ساتھ بادشاہی میں کوئی شریک نہیں ہے، جس نے ہر چیز کو پیدا کیا پھر اس کی ایک تقدیر مقرر کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccclviii{لوگوں نے اُسے چھوڑ کر ایسے معبود بنا لیے جو کسی چیز کو پیدا نہیں کرتے بلکہ خود پیدا کیے جاتے ہیں، جو خود اپنے لیے بھی کسی نفع یا نقصان کا اختیار نہیں رکھتے، جو نہ مار سکتے ہیں نہ جِلا سکتے ہیں، نہ مرے ہوئے کو پھر اٹھا سکتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccclix{جن لوگوں نے نبیؐ کی بات ماننے سے انکار کر دیا ہے وہ کہتے ہیں کہ یہ فرقان ایک من گھڑت چیز ہے جسے اِس شخص نے آپ ہی گھڑ لیا ہے اور کچھ دوسرے لوگوں نے اِس کام میں اس کی مدد کی ہے بڑا ظلم اور سخت جھوٹ ہے جس پر یہ لوگ اتر آئے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccclx{کہتے ہیں یہ پرانے لوگوں کی لکھی ہوئی چیزیں ہیں جنہیں یہ شخص نقل کرتا ہے اور وہ اِسے صبح و شام سنائی جاتی ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccclxi{اے محمدؐ، ان سے کہو کہ ``اِسے نازل کیا ہے اُس نے جو زمین اور آسمانوں کا بھید جانتا ہے" حقیقت یہ ہے کہ وہ بڑا غفور رحیم ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccclxii{کہتے ہیں ``یہ کیسا رسول ہے جو کھانا کھاتا ہے اور بازاروں میں چلتا پھرتا ہے؟ کیوں نہ اس کے پاس کوئی فرشتہ بھیجا گیا جو اس کے ساتھ رہتا اور (نہ ماننے والوں کو) دھمکاتا؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiii{یا اور کچھ نہیں تو اِس کے لیے کوئی خزانہ ہی اتار دیا جاتا، یا اس کے پاس کوئی باغ ہی ہوتا جس سے یہ (اطمینان کی) روزی حاصل کرتا" اور ظالم کہتے ہیں ``تم لوگ تو ایک سحر زدہ آدمی کے پیچھے لگ گئے ہو"\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiv{دیکھو، کیسی کیسی عجیب حجتیں یہ لوگ تمہارے آگے پیش کر رہے ہیں، ایسے بہکے ہیں کہ کوئی ٹھکانے کی بات اِن کو نہیں سوجھتی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccclxv{بڑا بابرکت ہے وہ جو اگر چاہے تو ان کی تجویز کردہ چیزوں سے بھی زیادہ بڑھ چڑھ کر تم کو دے سکتا ہے، (ایک نہیں) بہت سے باغ جن کے نیچے نہریں بہتی ہوں، اور بڑے بڑے محل\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvi{اصل بات یہ ہے کہ یہ لوگ ``اُس گھڑی" کو جھٹلا چکے ہیں اور جو اُس گھڑی کو جھٹلائے اس کے لیے ہم نے بھڑکتی ہوئی آگ مہیا کر رکھی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvii{وہ جب دور سے اِن کو دیکھے گی تو یہ اُس کے غضب اور جوش کی آوازیں سن لیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccclxviii{اور جب یہ دست و پا بستہ اُس میں ایک تنگ جگہ ٹھونسے جائیں گے تو اپنی موت کو پکارنے لگیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdccclxix{(اُس وقت ان سے کہا جائے گا کہ) آج ایک موت کو نہیں بہت سی موتوں کو پکارو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdccclxx{اِن سے پوچھو، یہ انجام اچھا ہے یا وہ اَبدی جنت جس کا وعدہ خداترس پرہیزگاروں سے کیا گیا ہے؟ جو اُن کے اعمال کی جزا اور اُن کے سفر کی آخری منزل ہو گی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxi{جس میں اُن کی ہر خواہش پوری ہو گی، جس میں وہ ہمیشہ ہمیشہ رہیں گے، جس کا عطا کرنا تمہارے پروردگار کے ذمے ایک واجب الادا وعدہ ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxii{اور وہ وہی دن ہو گا جب کہ (تمہارا رب) اِن لوگوں کو بھی گھیر لائے گا اور ان کے اُن معبودوں کو بھی بُلا لے گا جنہیں آج یہ اللہ کو چھوڑ کر پوج رہے ہیں، پھر وہ اُن سے پوچھے گا ``کیا تم نے میرے اِن بندوں کر گمراہ کیا تھا؟ یا یہ خود راہِ راست سے بھٹک گئے تھے؟"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiii{وہ عرض کریں گے ``پاک ہے آپ کی ذات، ہماری تو یہ بھی مجال نہ تھی کہ آپ کے سوا کسی کو اپنا مولا بنائیں مگر آپ نے اِن کو اور ان کے باپ دادا کو خوب سامانِ زندگی دیا حتیٰ کہ یہ سبق بھول گئے اور شامت زدہ ہو کر رہے"\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiv{یوں جھٹلا دیں گے وہ (تمہارے معبود) تمہاری اُن باتوں کو جو آج تم کہہ رہے ہو، پھر تم نہ اپنی شامت ٹال سکو گے نہ کہیں سے مدد پا سکو گے اور جو بھی تم میں سے ظلم کرے اسے ہم سخت عذاب کا مزہ چکھائیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxv{اے محمدؐ، تم سے پہلے جو رسول بھی ہم نے بھیجے ہیں وہ سب بھی کھانا کھانے والے اور بازاروں میں چلنے پھرنے والے لوگ ہی تھے دراصل ہم نے تم لوگوں کو ایک دوسرے کے لیے آزمائش کا ذریعہ بنا دیا ہے کیا تم صبر کرتے ہو؟ تمہارا رب سب کچھ دیکھتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvi{جو لوگ ہمارے حضور پیش ہونے کا اندیشہ نہیں رکھتے وہ کہتے ہیں ``کیوں نہ فرشتے ہمارے پاس بھیجے جائیں؟ یا پھر ہم اپنے رب کو دیکھیں" بڑا گھمنڈ لے بیٹھے یہ اپنے نفس میں اور حد سے گزر گئے یہ اپنی سرکشی میں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvii{جس روز یہ فرشتوں کو دیکھیں گے وہ مجرموں کے لیے کسی بشارت کا دن نہ ہوگا، چیخ اٹھیں گے کہ پناہ بخدا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxviii{اور جو کچھ بھی ان کا کیا دھرا ہے اُسے لے کر ہم غبار کی طرح اڑا دیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxix{بس وہی لوگ جو جنت کے مستحق ہیں اُس دن اچھی جگہ ٹھیریں گے اور دوپہرگزارنے کو عمدہ مقام پائیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxx{آسمان کو چیرتا ہوا ایک بادل اس روز نمودار ہو گا اور فرشتوں کے پرے کے پرے اتار دیے جائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxi{اُس روز حقیقی بادشاہی صرف رحمان کی ہو گی اور وہ منکرین کے لیے بڑا سخت دن ہو گا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxii{ظالم انسان اپنا ہاتھ چبائے گا اور کہے گا ``کاش میں نے رسول کا ساتھ دیا ہوتا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiii{ہائے میری کم بختی، کاش میں نے فلاں شخص کو دوست نہ بنایا ہوتا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiv{اُس کے بہکائے میں آ کر میں نے وہ نصیحت نہ مانی جو میرے پاس آئی تھی، شیطان انسان کے حق میں بڑا ہی بے وفا نکلا"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxv{اور رسول کہے گا کہ ``اے میرے رب، میری قوم کے لوگوں نے اس قرآن کو نشانہ تضحیک بنا لیا تھا"\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvi{اے محمدؐ، ہم نے تو اسی طرح مجرموں کو ہر نبی کا دشمن بنایا ہے اور تمہارے لیے تمہارا رب ہی رہنمائی اور مدد کو کافی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvii{منکرین کہتے ہیں ``اِس شخص پر سارا قرآن ایک ہی وقت میں کیوں نہ اتار دیا گیا؟" ہاں، ایسا اس لیے کیا گیا ہے کہ اس کو اچھی طرح ہم تمہارے ذہن نشین کرتے رہیں اور (اسی غرض کے لیے) ہم نے اس کو ایک خاص ترتیب کے ساتھ الگ الگ اجزاء کی شکل دی ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxviii{اور (اس میں یہ مصلحت بھی ہے) کہ جب کبھی وہ تمہارے سامنے کوئی نرالی بات (یا عجیب سوال) لے کر آئے، اُس کا ٹھیک جواب بر وقت ہم نے تمہیں دے دیا اور بہترین طریقے سے بات کھول دی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxix{جو لوگ اوندھے منہ جہنم کی طرف دھکیلے جانے والے ہیں ان کا موقف بہت برا اور ان کی راہ حد درجہ غلط ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxc{ہم نے موسیٰؑ کو کتاب دی اور اس کے ساتھ اس کے بھائی ہارونؑ کو مددگار کے طور پر لگایا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxci{اور اُن سے کہا کہ جاؤ اُس قوم کی طرف جس نے ہماری آیات کو جھٹلا دیا ہے آخر کار اُن لوگوں کو ہم نے تباہ کر کے رکھ دیا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcii{یہی حال قوم نوحؑ کا ہوا جب انہوں نے رسولوں کی تکذیب کی ہم نے اُن کو غرق کر دیا اور دنیا بھر کے لوگوں کے لیے ایک نشان عبرت بنا دیا اور ان ظالموں کے لیے ایک دردناک عذاب ہم نے مہیا کر رکھا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciii{اِسی طرح عاد اور ثمود اور اصحاب الرس اور بیچ کی صدیوں کے بہت سے لوگ تباہ کیے گئے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciv{اور ان میں سے ہر ایک کو ہم نے (پہلے تباہ ہونے والوں کی) مثالیں دے دے کر سمجھایا اور آخرکار ہر ایک کو غارت کر دیا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcv{اور اُس بستی پر تو اِن کا گزر ہو چکا ہے جس پر بدترین بارش برسائی گئی تھی کیا انہوں نے اس کا حال دیکھا نہ ہو گا؟ مگر یہ موت کے بعد دوسری زندگی کی توقع ہی نہیں رکھتے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvi{یہ لوگ جب تمہیں دیکھتے ہیں تو تمہارا مذاق بنا لیتے ہیں (کہتے ہیں) ``کیا یہ شخص ہے جسے خدا نے رسول بنا کر بھیجا ہے؟\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvii{اِس نے تو ہمیں گمراہ کر کے اپنے معبودوں سے برگشتہ ہی کر دیا ہوتا اگر ہم اُن کی عقیدت پر جم نہ گئے ہوتے" اچھا، وہ وقت دور نہیں ہے جب عذاب دیکھ کر اِنہیں خود معلوم ہو جائے گا کہ کون گمراہی میں دور نکل گیا تھا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcviii{کبھی تم نے اُس شخص کے حال پر غور کیا ہے جس نے اپنی خواہش نفس کو اپنا خدا بنا لیا ہو؟ کیا تم ایسے شخص کو راہِ راست پر لانے کا ذمہ لے سکتے ہو؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcix{کیا تم سمجھتے ہو کہ ان میں سے اکثر لوگ سنتے اور سمجھتے ہیں؟ یہ تو جانوروں کی طرح ہیں، بلکہ اُن سے بھی گئے گزرے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcm{تم نے دیکھا نہیں کہ تمہارا رب کس طرح سایہ پھیلا دیتا ہے؟ اگر وہ چاہتا تو اسے دائمی سایہ بنا دیتا ہم نے سورج کو اُس پر دلیل بنایا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmi{پھر (جیسے جیسے سورج اٹھتا جاتا ہے) ہم اس سائے کو رفتہ رفتہ اپنی طرف سمیٹتے چلے جاتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmii{اور وہ اللہ ہی ہے جس نے رات کو تمہارے لیے لباس، اور نیند کو سکونِ موت، اور دن کو جی اٹھنے کا وقت بنایا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmiii{اور وہی ہے جو اپنی رحمت کے آگے آگے ہواؤں کو بشارت بنا کر بھیجتا ہے پھر آسمان سے پاک پانی نازل کرتا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmiv{تاکہ ایک مردہ علاقے کو اس کے ذریعے زندگی بخشے اور اپنی مخلوق میں سے بہت سے جانوروں اور انسانوں کو سیراب کرے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmv{اس کرشمے کو ہم بار بار ان کے سامنے لاتے ہیں تاکہ وہ کچھ سبق لیں، مگر اکثر لوگ کفر اور ناشکری کے سوا کوئی دوسرا رویہ اختیار کرنے سے انکار کر دیتے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmvi{اگر ہم چاہتے تو ایک ایک بستی میں ایک ایک نذیر اٹھا کھڑا کرتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmvii{پس اے نبیؐ، کافروں کی بات ہرگز نہ مانو اور اس قرآن کو لے کر ان کے ساتھ جہاد کبیر کرو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmviii{اور وہی ہے جس نے دو سمندروں کو ملا رکھا ہے ایک لذیذ و شیریں، دوسرا تلخ و شور اور دونوں کے درمیان ایک پردہ حائل ہے ایک رکاوٹ ہے جو انہیں گڈ مڈ ہونے سے روکے ہوئے ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmix{اور وہی ہے جس نے پانی سے ایک بشر پیدا کیا، پھر اس سے نسب اور سسرال کے دو الگ سلسلے چلائے تیرا رب بڑا ہی قدرت والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmx{اس خدا کو چھوڑ کر لوگ اُن کو پوج رہے ہیں جو نہ ان کو نفع پہنچا سکتے ہیں نہ نقصان، اور اوپر سے مزید یہ کہ کافر اپنے رب کے مقابلے میں ہر باغی کا مدد گار بنا ہوا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmxi{اے محمدؐ، تم کو تو ہم نے بس ایک مبشر اور نذیر بنا کر بھیجا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmxii{اِن سے کہہ دو کہ ``میں اس کام پر تم سے کوئی اُجرت نہیں مانگتا، میری اُجرت بس یہی ہے کہ جس کا جی چاہے وہ اپنے رب کا راستہ اختیار کر لے"\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxiii{اور اے محمدؐ، اُس خدا پر بھروسہ رکھو جو زندہ ہے اور کبھی مرنے والا نہیں اس کی حمد کے ساتھ اس کی تسبیح کرو اپنے بندوں کے گناہوں سے بس اُسی کا باخبر ہونا کافی ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxiv{وہ جس نے چھ دنوں میں زمین اور آسمان کو اور اُن ساری چیزوں کو بنا کر رکھ دیا جو آسمان و زمین کے درمیان ہیں، پھر آپ ہی (کائنات کے تخت سلطنت) ``عرش" پر جلوہ فرما ہوا رحمٰن، اس کی شان بس کسی جاننے والے سے پوچھو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxv{اِن لوگوں سے جب کہا جاتا ہے کہ اس رحمان کو سجدہ کرو تو کہتے ہیں ``رحمان کیا ہوتا ہے؟ کیا بس جسے تو کہہ دے اسی کو ہم سجدہ کرتے پھریں؟" یہ دعوت ان کی نفرت میں الٹا اور اضافہ کر دیتی ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxvi{بڑا متبرک ہے وہ جس نے آسمان میں برج بنائے اور اس میں ایک چراغ اور ایک چمکتا چاند روشن کیا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxvii{وہی ہے جس نے رات اور دن کو ایک دوسرے کا جانشین بنایا، ہر اس شخص کے لیے جو سبق لینا چاہے، یا شکر گزار ہونا چاہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxviii{رحمان کے (اصلی) بندے وہ ہیں جو زمین پر نرم چال چلتے ہیں اور جاہل ان کے منہ کو آئیں تو کہہ دیتے ہیں کہ تم کو سلام\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxix{جو اپنے رب کے حضور سجدے اور قیام میں راتیں گزارتے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxx{جو دعائیں کرتے ہیں کہ ``اے ہمارے رب، جہنم کے عذاب سے ہم کو بچا لے، اُس کا عذاب تو جان کا لاگو ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxxi{وہ بڑا ہی برا مستقر اور مقام ہے"\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxxii{جو خرچ کرتے ہیں تو نہ فضول خرچی کرتے ہیں نہ بخل، بلکہ ان کا خرچ دونوں انتہاؤں کے درمیان اعتدال پر قائم رہتا ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiii{جو اللہ کے سوا کسی اور معبود کو نہیں پکارتے، اللہ کی حرام کی ہوئی کسی جان کو ناحق ہلاک نہیں کرتے، اور نہ زنا کے مرتکب ہوتے ہیں یہ کام جو کوئی کرے وہ اپنے گناہ کا بدلہ پائے گا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiv{قیامت کے روز اس کو مکرّر عذاب دیا جائے گا اور اسی میں وہ ہمیشہ ذلت کے ساتھ پڑا رہے گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcmxxv{اِلّا یہ کہ کوئی (ان گناہوں کے بعد) توبہ کر چکا ہو اور ایمان لا کر عمل صالح کرنے لگا ہو ایسے لوگوں کی برائیوں کو اللہ بھلائیوں سے بدل دے گا اور وہ بڑا غفور رحیم ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvi{جو شخص توبہ کر کے نیک عملی اختیار کرتا ہے وہ تو اللہ کی طرف پلٹ آتا ہے جیسا کہ پلٹنے کا حق ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvii{(اور رحمٰن کے بندے وہ ہیں) جو جھوٹ کے گواہ نہیں بنتے اور کسی لغو چیز پر ان کا گزر ہو جائے تو شریف آدمیوں کی طرح گزر جاتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcmxxviii{جنہیں اگر اُن کے رب کی آیات سنا کر نصیحت کی جاتی ہے تو وہ اس پر اندھے اور بہرے بن کر نہیں رہ جاتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcmxxix{جو دعائیں مانگا کرتے ہیں کہ ``اے ہمارے رب، ہمیں اپنی بیویوں اور اپنی اولاد سے آنکھوں کی ٹھنڈک دے اور ہم کو پرہیز گاروں کا امام بنا"\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcmxxx{یہ ہیں وہ لوگ جو اپنے صبر کا پھل منزل بلند کی شکل میں پائیں گے آداب و تسلیمات سے اُن کا استقبال ہو گا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxi{وہ ہمیشہ ہمیشہ وہاں رہیں گے کیا ہی اچھا ہے وہ مستقر اور وہ مقام\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxii{اے محمدؐ، لوگوں سے کہو ``میرے رب کو تمہاری کیا حاجت پڑی ہے اگر تم اس کو نہ پکارو اب کہ تم نے جھٹلا دیا ہے، عنقریب وہ سزا پاؤ گے کہ جان چھڑانی محال ہو گی"\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiii{\basmalahur ط س م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiv{یہ کتاب مبین کی آیات ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxv{اے محمدؐ، شاید تم اس غم میں اپنی جان کھو دو گے کہ یہ لوگ ایمان نہیں لاتے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvi{ہم چاہیں تو آسمان سے ایسی نشانی نازل کر سکتے ہیں کہ اِن کی گردنیں اس کے آگے جھک جائیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvii{اِن لوگوں کے پاس رحمان کی طرف سے جو نئی نصیحت بھی آتی ہے یہ اس سے منہ موڑ لیتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxviii{اب کہ یہ جھٹلا چکے ہیں، عنقریب اِن کو اس چیز کی حقیقت (مختلف طریقوں سے) معلوم ہو جائے گی جس کا یہ مذاق اڑاتے رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxix{اور کیا انہوں نے کبھی زمین پر نگاہ نہیں ڈالی کہ ہم نے کتنی کثیر مقدار میں ہر طرح کی عمدہ نباتات اس میں پیدا کی ہیں؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcmxl{یقیناً اس میں ایک نشانی ہے، مگر ان میں سے اکثر ماننے والے نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcmxli{اور حقیقت یہ ہے کہ تیرا رب زبردست بھی ہے اور رحیم بھی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcmxlii{اِنہیں اس وقت کا قصہ سناؤ جب کہ تمہارے رب نے موسیٰؑ کو پکارا ``ظالم قوم کے پاس جا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcmxliii{فرعون کی قوم کے پاس، کیا وہ ڈرتے نہیں؟"\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcmxliv{اُس نے عرض کیا ``اے رب، مجھے خوف ہے کہ وہ مجھے جھٹلا دیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcmxlv{میرا سینہ گھٹتا ہے اور میری زبان نہیں چلتی آپ ہارونؑ کی طرف رسالت بھیجیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvi{اور مجھ پر اُن کے ہاں ایک جرم کا الزام بھی ہے، اس لیے ڈرتا ہوں کہ وہ مجھے قتل کر دیں گے"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvii{فرمایا ``ہرگز نہیں، تم دونوں جاؤ ہماری نشانیاں لے کر، ہم تمہارے ساتھ سب کچھ سنتے رہیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcmxlviii{فرعون کے پاس جاؤ اور اس سے کہو، ہم کو رب العٰلمین نے اس لیے بھیجا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcmxlix{کہ تو بنی اسرائیل کو ہمارے ساتھ جانے دے"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcml{فرعون نے کہا ``کیا ہم نے تجھ کو اپنے ہاں بچہ سا نہیں پالا تھا؟ تو نے اپنی عمر کے کئی سال ہمارے ہاں گزارے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcmli{اور اس کے بعد کر گیا جو کچھ کہ کر گیا، تو بڑا احسان فراموش آدمی ہے"\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcmlii{موسیٰؑ نے جواب دیا ``اُس وقت وہ کام میں نے نادانستگی میں کر دیا تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcmliii{پھر میں تمہارے خوف سے بھاگ گیا اس کے بعد میرے رب نے مجھ کو حکم عطا کیا اور مجھے رسولوں میں شامل کر لیا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcmliv{رہا تیرا احسان جو تو نے مجھ پر جتایا ہے تو اس کی حقیقت یہ ہے کہ تو نے بنی اسرائیل کو غلام بنا لیا تھا"\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcmlv{فرعون نے کہا ``اور یہ رب العالمین کیا ہوتا ہے؟"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcmlvi{موسیٰؑ نے جواب دیا ``آسمان اور زمین کا رب، اور اُن سب چیزوں کا رب جو آسمان اور زمین کے درمیان ہیں، اگر تم یقین لانے والے ہو"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcmlvii{فرعون نے اپنے گرد و پیش کے لوگوں سے کہا ``سُنتے ہو؟"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcmlviii{موسیٰؑ نے کہا ``تمہارا رب بھی اور تمہارے ان آباء و اجداد کا رب بھی جو گزر چکے ہیں"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcmlix{فرعون نے (حاضرین سے) کہا ``تمہارے یہ رسول صاحب جو تمہاری طرف بھیجے گئے ہیں، بالکل ہی پاگل معلوم ہوتے ہیں"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcmlx{موسیٰؑ نے کہا ``مشرق و مغرب اور جو کچھ ان کے درمیان ہے سب کا رب، اگر آپ لوگ کچھ عقل رکھتے ہیں"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcmlxi{فرعون نے کہا ``اگر تو نے میرے سوا کسی اور کو معبود بنایا تو تجھے میں اُن لوگوں میں شامل کر دوں گا جو قید خانوں میں پڑے سڑ رہے ہیں"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcmlxii{موسیٰؑ نے کہا ``اگرچہ میں لے آؤں تیرے سامنے ایک صریح چیز بھی؟"\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiii{فرعون نے کہا ``اچھا تو لے آ اگر تو سچا ہے"\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiv{(اس کی زبان سے یہ بات نکلتے ہی) موسیٰؑ نے اپنا عصا پھینکا اور یکایک وہ ایک صریح اژدھا تھا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcmlxv{پھر اُس نے اپنا ہاتھ (بغل سے) کھینچا اور وہ سب دیکھنے والوں کے سامنے چمک رہا تھا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvi{فرعون اپنے گرد و پیش کے سرداروں سے بولا ``یہ شخص یقیناً ایک ماہر جادوگر ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvii{چاہتا ہے کہ اپنے جادو کے زور سے تم کو ملک سے نکال دے اب بتاؤ تم کیا حکم دیتے ہو؟"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcmlxviii{انہوں نے کہا ``اسے اور اس کے بھائی کو روک لیجیے اور شہروں میں ہرکارے بھیج دیجیے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcmlxix{کہ ہر سیانے جادوگر کو آپ کے پاس لے آئیں"\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcmlxx{چنانچہ ایک روز مقرر وقت پر جادوگر اکٹھے کر لیے گئے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxi{اور لوگوں سے کہا گیا ``تم اجتماع میں چلو گے؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxii{شاید کہ ہم جادوگروں کے دین ہی پر رہ جائیں اگر وہ غالب رہے"\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiii{جب جادوگر میدان میں آ گئے تو انہوں نے فرعون سے کہا ``ہمیں انعام تو ملے گا اگر ہم غالب رہے؟"\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiv{اس نے کہا ``ہاں، اور تم تو اس وقت مقربین میں شامل ہو جاؤ گے"\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxv{موسیٰؑ نے کہا ``پھینکو جو تمہیں پھینکنا ہے"\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvi{انہوں نے فوراً اپنی رسیاں اور لاٹھیاں پھینک دیں اور بولے ``فرعون کے اقبال سے ہم ہی غالب رہیں گے"\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvii{پھر موسیٰؑ نے اپنا عصا پھینکا تو یکایک وہ ان کے جھوٹے کرشموں کو ہڑپ کرتا چلا جا رہا تھا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxviii{اس پر سارے جادوگر بے اختیار سجدے میں گر پڑے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxix{اور بول اٹھے کہ ``مان گئے ہم رب العالمین کو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxx{موسیٰؑ اور ہارونؑ کے رب کو"\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxi{فرعون نے کہا ``تم موسیٰؑ کی بات مان گئے قبل اس کے کہ میں تمہیں اجازت دیتا! ضرور یہ تمہارا بڑا ہے جس نے تمہیں جادو سکھایا ہے اچھا، ابھی تمہیں معلوم ہوا جاتا ہے، میں تمہارے ہاتھ پاؤں مخالف سمتوں میں کٹواؤں گا اور تم سب کو سولی چڑھا دوں گا"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxii{انہوں نے جواب دیا ``کچھ پرواہ نہیں، ہم اپنے رب کے حضور پہنچ جائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiii{اور ہمیں توقع ہے کہ ہمارا رب ہمارے گناہ معاف کر دے گا کیونکہ سب سے پہلے ہم ایمان لائے ہیں"\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiv{ہم نے موسیٰؑ کو وحی بھیجی کہ ``راتوں رات میرے بندوں کو لے کر نکل جاؤ، تمہارا پیچھا کیا جائے گا"\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxv{اس پر فرعون نے (فوجیں جمع کرنے کے لیے) شہروں میں نقیب بھیج دیے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvi{(اور کہلا بھیجا) کہ ``یہ کچھ مٹھی بھر لوگ ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvii{اور انہوں نے ہم کو بہت ناراض کیا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxviii{اور ہم ایک ایسی جماعت ہیں جس کا شیوہ ہر وقت چوکنا رہنا ہے"\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxix{اِس طرح ہم انہیں ان کے باغوں اور چشموں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxc{اور خزانوں اور ان کی بہترین قیام گاہوں سے نکال لائے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxci{یہ تو ہوا اُن کے ساتھ، اور (دوسری طرف) بنی اسرائیل کو ہم نے ان سب چیزوں کا وارث کر دیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxcii{صبح ہوتے ہی یہ لوگ اُن کے تعاقب میں چل پڑے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxciii{جب دونوں گروہوں کا آمنا سامنا ہوا تو موسیٰؑ کے ساتھی چیخ اٹھے کہ ``ہم تو پکڑے گئے"\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxciv{موسیٰؑ نے کہا ``ہرگز نہیں میرے ساتھ میرا رب ہے وہ ضرور میری رہنمائی فرمائے گا"\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxcv{ہم نے موسیٰؑ کو وحی کے ذریعہ سے حکم دیا کہ ``مار اپنا عصا سمندر پر" یکایک سمندر پھَٹ گیا اور اس کا ہر ٹکڑا ایک عظیم الشان پہاڑ کی طرح ہو گیا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvi{اُسی جگہ ہم دوسرے گروہ کو بھی قریب لے آئے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvii{موسیٰؑ اور اُن سب لوگوں کو جو اس کے ساتھ تھے، ہم نے بچا لیا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxcviii{اور دوسروں کو غرق کر دیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxcix{اس واقعہ میں ایک نشانی ہے، مگر اِن لوگوں میں سے اکثر ماننے والے نہیں ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmm{اور حقیقت یہ ہے کہ تیرا رب زبردست بھی ہے اور رحیم بھی\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmi{اور اِنہیں ابراہیمؑ کا قصہ سناؤ\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmii{جبکہ اس نے اپنے باپ اور اپنی قوم سے پوچھا تھا کہ ``یہ کیا چیزیں ہیں جن کو تم پوجتے ہو؟"\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmiii{انہوں نے جواب دیا ``کچھ بت ہیں جن کی ہم پوجا کرتے ہیں اور انہی کی سیوا میں ہم لگے رہتے ہیں"\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmiv{اس نے پوچھا ``کیا یہ تمہاری سنتے ہیں جب تم انہیں پکارتے ہو؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmv{یا یہ تمہیں کچھ نفع یا نقصان پہنچاتے ہیں؟"\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmvi{انہوں نے جواب دیا ``نہیں، بلکہ ہم نے اپنے باپ دادا کو ایسا ہی کرتے پایا ہے"\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmvii{اس پر ابراہیمؑ نے کہا ``کبھی تم نے (آنکھیں کھول کر) اُن چیزوں کو دیکھا بھی جن کی بندگی تم\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmviii{اور تمہارے پچھلے باپ دادا بجا لاتے رہے؟\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmix{میرے تو یہ سب دشمن ہیں، بجز ایک رب العالمین کے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmx{جس نے مجھے پیدا کیا، پھر وہی میری رہنمائی فرماتا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmxi{جو مجھے کھلاتا اور پلاتا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmxii{اور جب میں بیمار ہو جاتا ہوں تو وہی مجھے شفا دیتا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmxiii{جو مجھے موت دے گا اور پھر دوبارہ مجھ کو زندگی بخشے گا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmxiv{اور جس سے میں امید رکھتا ہوں کہ روزِ جزا میں وہ میری خطا معاف فرما دے گا"\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmxv{(اِس کے بعد ابراہیمؑ نے دعا کی) ``اے میرے رب، مجھے حکم عطا کر اور مجھ کو صالحوں کے ساتھ ملا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmxvi{اور بعد کے آنے والوں میں مجھ کو سچی ناموری عطا کر\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmxvii{اور مجھے جنتِ نعیم کے وارثوں میں شامل فرما\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmxviii{اور میرے باپ کو معاف کر دے کہ بے شک وہ گمراہ لوگوں میں سے ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmxix{اور مجھے اس دن رسوا نہ کر جبکہ سب لوگ زندہ کر کے اٹھائے جائیں گے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmxx{جبکہ نہ مال کوئی فائدہ دے گا نہ اولاد\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmxxi{بجز اس کے کہ کوئی شخص قلب سلیم لیے ہوئے اللہ کے حضور حاضر ہو"\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmxxii{(اس روز) جنت پرہیزگاروں کے قریب لے آئی جائے گی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmxxiii{اور دوزخ بہکے ہوئے لوگوں کے سامنے کھول دی جائے گی\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmxxiv{اور ان سے پوچھا جائے گا کہ ``اب کہاں ہیں وہ جن کی تم خدا کو چھوڑ کر عبادت کیا کرتے تھے؟\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmxxv{کیا وہ تمہاری کچھ مدد کر رہے ہیں یا خود اپنا بچاؤ کر سکتے ہیں؟"\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmxxvi{پھر وہ معبود اور یہ بہکے ہوئے لوگ\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmxxvii{اور ابلیس کے لشکر سب کے سب اس میں اُوپر تلے دھکیل دیے جائیں گے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmxxviii{وہاں یہ سب آپس میں جھگڑیں گے اور یہ بہکے ہوئے لوگ (اپنے معبودوں سے) کہیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmxxix{کہ ``خدا کی قسم، ہم تو صریح گمراہی میں مبتلا تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmxxx{جبکہ تم کو رب العالمین کی برابری کا درجہ دے رہے تھے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmxxxi{اور وہ مجرم لوگ ہی تھے جنہوں نے ہم کو اس گمراہی میں ڈالا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmxxxii{اب نہ ہمارا کوئی سفارشی ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiii{اور نہ کوئی جگری دوست\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiv{کاش ہمیں ایک دفعہ پھر پلٹنے کا موقع مل جائے تو ہم مومن ہوں"\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmxxxv{یقیناً اس میں ایک بڑی نشانی ہے، مگر ان میں سے اکثر لوگ ایمان لانے والے نہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvi{اور حقیقت یہ ہے کہ تیرا رب زبردست بھی ہے اور رحیم بھی\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvii{قوم نوحؑ نے رسولوں کو جھٹلایا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmxxxviii{یاد کرو جبکہ ان کے بھائی نوحؑ نے ان سے کہا تھا ``کیا تم ڈرتے نہیں ہو؟\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmxxxix{میں تمہارے لیے ایک امانت دار رسول ہوں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmxl{لہٰذا تم اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmxli{میں اس کام پر تم سے کسی اجر کا طالب نہیں ہوں میرا اجر تو رب العالمین کے ذمہ ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmxlii{پس تم اللہ سے ڈرو اور (بے کھٹکے) میری اطاعت کرو"\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmxliii{انہوں نے جواب دیا ``“کیا ہم تجھے مان لیں حالانکہ تیری پیروی رذیل ترین لوگوں نے اختیار کی ہے؟"\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmxliv{نوحؑ نے کہا ``میں کیا جانوں کہ ان کے عمل کیسے ہیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmxlv{ان کا حساب تو میرے رب کے ذمہ ہے، کاش تم کچھ شعور سے کام لو\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmxlvi{میرا یہ کام نہیں ہے کہ جو ایمان لائیں ان کو میں دھتکار دوں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmxlvii{میں تو بس ایک صاف صاف متنبہ کر دینے والا آدمی ہوں"\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmxlviii{انہوں نے کہا ``اے نوحؑ، اگر تو باز نہ آیا تو پھٹکارے ہوئے لوگوں میں شامل ہو کر رہے گا"\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmxlix{نوحؑ نے دعا کی ``“اے میرے رب، میری قوم نے مجھے جھٹلا دیا\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmml{اب میرے اور ان کے درمیان دو ٹوک فیصلہ کر دے اور مجھے اور جو مومن میرے ساتھ ہیں ان کو نجات دے"\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmli{آخرکار ہم نے اس کو اور اس کے ساتھیوں کو ایک بھری ہوئی کشتی میں بچا لیا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmlii{اور اس کے بعد باقی لوگوں کو غرق کر دیا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmliii{یقیناً اس میں ایک نشانی ہے، مگر ان میں سے اکثر لوگ ماننے والے نہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmliv{اور حقیقت یہ ہے کہ تیرا رب زبردست بھی ہے اور رحیم بھی\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmlv{عاد نے رسولوں کو جھٹلایا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmlvi{یاد کرو جبکہ ان کے بھائی ہودؑ نے ان سے کہا تھا ``کیا تم ڈرتے نہیں؟\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmlvii{میں تمہارے لیے ایک امانت دار رسول ہوں\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmlviii{لہٰذا تم اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmlix{میں اس کام پر تم سے کسی اجر کا طالب نہیں ہوں میرا اجر تو رب العالمین کے ذمہ ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmlx{یہ تمہارا کیا حال ہے کہ ہر اونچے مقام پر لا حاصل ایک یادگار عمارت بنا ڈالتے ہو\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmlxi{اور بڑے بڑے قصر تعمیر کرتے ہو گویا تمہیں ہمیشہ رہنا ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmlxii{اور جب کسی پر ہاتھ ڈالتے ہو جبّار بن کر ڈالتے ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmlxiii{پس تم لوگ اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmlxiv{ڈرو اُس سے جس نے وہ کچھ تمہیں دیا ہے جو تم جانتے ہو\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmlxv{تمہیں جانور دیے، اولادیں دیں\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmlxvi{باغ دیے اور چشمے دیے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmlxvii{مجھے تمہارے حق میں ایک بڑے دن کے عذاب کا ڈر ہے"\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmlxviii{انہوں نے جواب دیا ``تو نصیحت کر یا نہ کر، ہمارے لیے یکساں ہے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmlxix{یہ باتیں تو یوں ہی ہوتی چلی آئی ہیں\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmlxx{اور ہم عذاب میں مُبتلا ہونے والے نہیں ہیں"\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmlxxi{آخرکار انہوں نے اُسے جھٹلا دیا اور ہم نے ان کو ہلاک کر دیا یقیناً اس میں ایک نشانی ہے، مگر ان میں سے اکثر لوگ ماننے والے نہیں ہیں\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmlxxii{اور حقیقت یہ ہے کہ تیرا رب زبردست بھی ہے اور رحیم بھی\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiii{ثمود نے رسولوں کو جھٹلایا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiv{یاد کرو جبکہ ان کے بھائی صالحؑ نے ان سے کہا ``کیا تم ڈرتے نہیں؟\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmlxxv{میں تمہارے لیے ایک امانت دار رسول ہوں\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvi{لہٰذا تم اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvii{میں اس کام پر تم سے کسی اجر کا طالب نہیں، میرا اجر تو رب العالمین کے ذمہ ہے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmlxxviii{کیا تم اُن سب چیزوں کے درمیان، جو یہاں ہیں، بس یوں ہی اطمینان سے رہنے دیے جاؤ گے؟\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmlxxix{اِن باغوں اور چشموں میں؟\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmlxxx{اِن کھیتوں اور نخلستانوں میں جن کے خوشے رس بھرے ہیں؟\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxi{تم پہاڑ کھود کھود کر فخریہ اُن میں عمارتیں بناتے ہو\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxii{اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiii{اُن بے لگام لوگوں کی اطاعت نہ کرو\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiv{جو زمین میں فساد برپا کرتے ہیں اور کوئی اصلاح نہیں کرتے"\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxv{انہوں نے جواب دیا ``تو محض ایک سحر زدہ آدمی ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvi{تو ہم جیسے ایک انسان کے سوا اور کیا ہے لا کوئی نشانی اگر تو سچّا ہے"\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvii{صالحؑ نے کہا ``یہ اونٹنی ہے ایک دن اس کے پینے کا ہے اور ایک دن تم سب کے پانی لینے کا\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxviii{اس کو ہرگز نہ چھیڑنا ورنہ ایک بڑے دن کا عذاب تم کو آ لے گا"\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxix{مگر انہوں نے اس کی کوچیں کاٹ دیں اور آخرکار پچھتاتے رہ گئے\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmxc{عذاب نے انہیں آ لیا یقیناً اس میں ایک نشانی ہے، مگر ان میں سے اکثر ماننے والے نہیں\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmxci{اور حقیقت یہ ہے کہ تیرا رب زبردست بھی ہے اور رحیم بھی\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmxcii{لوطؑ کی قوم نے رسولوں کو جھٹلایا\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmxciii{یاد کرو جبکہ ان کے بھائی لوطؑ نے ان سے کہا تھا ``کیا تم ڈرتے نہیں؟\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmxciv{میں تمہارے لیے ایک امانت دار رسول ہوں\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmxcv{لہٰذا تم اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmxcvi{میں اس کام پر تم سے کسی اجر کا طالب نہیں ہوں، میرا اجر تو رب العالمین کے ذمہ ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmxcvii{کیا تم دنیا کی مخلوق میں سے مَردوں کے پاس جاتے ہو\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmxcviii{اور تمہاری بیویوں میں تمہارے رب نے تمہارے لیے جو کچھ پیدا کیا ہے اسے چھوڑ دیتے ہو؟ بلکہ تم لوگ تو حد سے ہی گزر گئے ہو"\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmxcix{انہوں نے کہا “اے لوطؑ، ``اگر تو اِن باتوں سے باز نہ آیا تو جو لوگ ہماری بستیوں سے نکالے گئے ہیں اُن میں تو بھی شامل ہو کر رہے گا"\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmc{اس نے کہا ``تمہارے کرتوتوں پر جو لوگ کُڑھ رہے ہیں میں اُن میں شامل ہوں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmci{اے پروردگار، مجھے اور میرے اہل و عیال کو ان کی بد کرداریوں سے نجات دے"\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcii{آخرکار ہم نے اسے اور اس کے سب اہل و عیال کو بچا لیا\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmciii{بجز ایک بڑھیا کے جو پیچھے رہ جانے والوں میں تھی\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmciv{پھر باقی ماندہ لوگوں کو ہم نے تباہ کر دیا\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcv{اور ان پر برسائی ایک برسات، بڑی ہی بُری بارش تھی جو اُن ڈرائے جانے والوں پر نازل ہوئی\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcvi{یقیناً اس میں ایک نشانی ہے، مگر اِن میں سے اکثر ماننے والے نہیں\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcvii{اور حقیقت یہ ہے کہ تیرا رب زبردست بھی ہے اور رحیم بھی\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcviii{اصحاب الاَیکہ نے رسولوں کو جھٹلایا\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcix{یاد کرو جبکہ شعیبؑ نے ان سے کہا تھا ``کیا تم ڈرتے نہیں؟\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcx{میں تمہارے لیے ایک امانت دار رسول ہوں\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcxi{لہٰذا تم اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcxii{میں اس کام پر تم سے کسی اجر کا طالب نہیں ہوں میرا اجر تو رب العالمین کے ذمہ ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcxiii{پیمانے ٹھیک بھرو اور کسی کو گھاٹا نہ دو\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcxiv{صحیح ترازو سے تولو\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcxv{اور لوگوں کو ان کی چیزیں کم نہ دو زمین میں فساد نہ پھیلاتے پھرو\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mmmcxvi{اور اُس ذات کا خوف کرو جس نے تمہیں اور گزشتہ نسلوں کو پیدا کیا ہے"\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mmmcxvii{انہوں نے کہا ``تو محض ایک سحرزدہ آدمی ہے\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mmmcxviii{اور تو کچھ نہیں مگر ایک انسان ہم ہی جیسا، اور ہم تو تجھے بالکل جھوٹا سمجھتے ہیں\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mmmcxix{اگر تو سچا ہے تو ہم پر آسمان کا کوئی ٹکڑا گرا دے"\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mmmcxx{شعیبؑ نے کہا ``میرا رب جانتا ہے جو کچھ تم کر رہے ہو"\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mmmcxxi{انہوں نے اسے جھٹلا دیا، آخرکار چھتری والے دن کا عذاب ان پر آ گیا، اور وہ بڑے ہی خوفناک دن کا عذاب تھا\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mmmcxxii{یقیناً اس میں ایک نشانی ہے، مگر ان میں سے اکثر لوگ ماننے والے نہیں\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiii{اور حقیقت یہ ہے کہ تیرا رب زبردست بھی ہے اور رحیم بھی\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiv{یہ رب العالمین کی نازل کردہ چیز ہے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mmmcxxv{اسے لے کر تیرے دل پر امانت دار روح اتری ہے\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvi{تاکہ تو اُن لوگوں میں شامل ہو جو (خدا کی طرف سے خلق خدا کو) متنبّہ کرنے والے ہیں\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvii{صاف صاف عربی زبان میں\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mmmcxxviii{اور اگلے لوگوں کی کتابوں میں بھی یہ موجود ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mmmcxxix{کیا اِن (اہلِ مکہ) کے لیے یہ کوئی نشانی نہیں ہے کہ اِسے علماء بنی اسرائیل جانتے ہیں؟\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mmmcxxx{(لیکن اِن کی ہٹ دھرمی کا حال یہ ہے کہ) اگر اہم اسے کسی عجمی پر بھی نازل کر دیتے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxi{اور یہ (فصیح عربی کلام) وہ ان کو پڑھ کر سناتا تب بھی یہ مان کر نہ دیتے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxii{اِسی طرح ہم نے اس (ذکر) کو مجرموں کے دلوں میں گزارا ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiii{وہ اس پر ایمان نہیں لاتے جب تک عذاب الیم نہ دیکھ لیں\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiv{پھر جب وہ بے خبری میں ان پر آ پڑتا ہے\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxv{اُس وقت وہ کہتے ہیں ``کہ “کیا اب ہمیں کچھ مُہلت مِل سکتی ہے؟"\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvi{تو کیا یہ لوگ ہمارے عذاب کے لیے جلدی مچا رہے ہیں؟\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvii{تم نے کچھ غور کیا، اگر ہم انہیں برسوں تک عیش کرنے کی مُہلت بھی دے دیں\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxviii{اور پھر وہی چیز ان پر آ جائے جس سے انہیں ڈرایا جا رہا ہے\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxix{تو وہ سامانِ زیست جو ان کو ملا ہوا ہے اِن کے کس کام آئے گا؟\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@mmmcxl{(دیکھو) ہم نے کبھی کسی بستی کو اِس کے بغیر ہلاک نہیں کیا کہ اُس کے لیے خبردار کرنے والے حق نصیحت ادا کرنے کو موجود تھے\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@mmmcxli{اور ہم ظالم نہ تھے\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@mmmcxlii{اِس (کتاب مبین) کو شیاطین لے کر نہیں اترے ہیں\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@mmmcxliii{نہ یہ کام ان کو سجتا ہے، اور نہ وہ ایسا کر ہی سکتے ہیں\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@mmmcxliv{وہ تو اس کی سماعت تک سے دُور رکھے گئے ہیں\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@mmmcxlv{پس اے محمدؐ، اللہ کے ساتھ کسی دُوسرے معبُود کو نہ پکارو، ورنہ تم بھی سزا پانے والوں میں شامل ہو جاؤ گے\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvi{اپنے قریب ترین رشتہ داروں کو ڈراؤ\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvii{اور ایمان لانے والوں میں سے جو لوگ تمہاری پیروی اختیار کریں ان کے ساتھ تواضع سے پیش آؤ\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@mmmcxlviii{لیکن اگر وہ تمہاری نافرمانی کریں تو ان سے کہو کہ جو کچھ تم کرتے ہو اس سے میں بری الذ مہ ہوں\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@mmmcxlix{اور اُس زبردست اور رحیم پر توکل کرو\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@mmmcl{جو تمہیں اس وقت دیکھ رہا ہوتا ہے جب تم اٹھتے ہو\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@mmmcli{اور سجدہ گزار لوگوں میں تمہاری نقل و حرکت پر نگاہ رکھتا ہے\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@mmmclii{وہ سب کچھ سننے اور جاننے والا ہے\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@mmmcliii{لوگو، کیا میں تمہیں بتاؤں کہ شیاطین کس پر اُترا کرتے ہیں؟\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@mmmcliv{وہ ہر جعل ساز بدکار پر اُترا کرتے ہیں\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@mmmclv{سُنی سُنائی باتیں کانوں میں پھونکتے ہیں، اور ان میں سے اکثر جھوٹے ہوتے ہیں\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@mmmclvi{رہے شعراء، تو ان کے پیچھے بہکے ہوئے لوگ چلا کرتے ہیں\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@mmmclvii{کیا تم دیکھتے نہیں ہو کہ وہ ہر وادی میں بھٹکتے ہیں\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@mmmclviii{اور ایسی باتیں کہتے ہیں جو کرتے نہیں\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@mmmclix{بجز اُن لوگوں کے جو ایمان لائے اور جنہوں نے نیک عمل کیے اور اللہ کو کثرت سے یاد کیا اور جب ان پر ظلم کیا گیا تو صرف بدلہ لے لیا، اور ظلم کرنے والوں کو عنقریب معلوم ہو جائے گا کہ وہ کس انجام سے دوچار ہوتے ہیں\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@mmmclx{\basmalahur ط س یہ آیات ہیں قرآن اور کتاب مبین کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmclxi{ہدایت اور بشارت اُن ایمان لانے والوں کے لیے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmclxii{جو نماز قائم کرتے اور زکوٰۃ دیتے ہیں، اور پھر وہ ایسے لوگ ہیں جو آخرت پر پورا یقین رکھتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmclxiii{حقیقت یہ ہے کہ جو لوگ آخرت کو نہیں مانتے ان کے لیے ہم نے اُن کے کرتوتوں کو خوشنما بنا دیا ہے، اس لیے وہ بھٹکتے پھر رہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmclxiv{یہ وہ لوگ ہیں جن کے لیے بُری سزا ہے اور آخرت میں یہی سب سے زیادہ خسارے میں رہنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmclxv{اور (اے محمدؐ) بلاشبہ تم یہ قرآن ایک حکیم و علیم ہستی کی طرف سے پا رہے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmclxvi{(اِنہیں اُس وقت کا قصہ سناؤ) جب موسیٰؑ نے اپنے گھر والوں سے کہا کہ ``مجھے ایک آگ سی نظر آئی ہے، میں ابھی یا تو وہاں سے کوئی خبر لے کر آتا ہوں یا کوئی انگارا چن لاتا ہوں تاکہ تم لوگ گرم ہو سکو"\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmclxvii{وہاں جو پہنچا تو ندا آئی کہ ``مبارک ہے وہ جو اس آگ میں ہے اور جو اس کے ماحول میں ہے پاک ہے اللہ، سب جہانوں کا پروردگار\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmclxviii{اے موسیٰؑ، یہ میں ہوں اللہ، زبردست اور دانا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmclxix{اور پھینک تو ذرا اپنی لاٹھی" جونہی کہ موسیٰؑ نے دیکھا لاٹھی سانپ کی طرح بل کھا رہی ہے تو پیٹھ پھیر کر بھاگا اور پیچھے مڑ کر بھی نہ دیکھا ``اے موسیٰؑ، ڈرو نہیں میرے حضور رسول ڈرا نہیں کرتے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmclxx{اِلّا یہ کہ کسی نے قصور کیا ہو پھر اگر برائی کے بعد اُس نے بھَلائی سے اپنے فعل کو بدل لیا تو میں معاف کرنے والا مہربان ہوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmclxxi{اور ذرا اپنا ہاتھ اپنے گریبان میں تو ڈالو چمکتا ہوا نکلے گا بغیر کسی تکلیف کے یہ (دو نشانیاں) نو نشانیوں میں سے ہیں فرعون اور اس کی قوم کی طرف (لے جانے کے لیے)، وہ بڑے بد کردار لوگ ہیں"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmclxxii{مگر جب ہماری کھلی کھلی نشانیاں اُن لوگوں کے سامنے آئیں تو انہوں نے کہا یہ تو کھلا جادو ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiii{انہوں نے سراسر ظلم اور غرور کی راہ سے ان نشانیوں کا انکار کیا حالانکہ دل ان کے قائل ہو چکے تھے اب دیکھ لو کہ ان مفسدوں کا انجام کیسا ہوا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiv{(دوسری طرف) ہم نے داؤدؑ و سلیمانؑ کو علم عطا کیا اور انہوں نے کہا کہ شکر ہے اُس خدا کا جس نے ہم کو اپنے بہت سے مومن بندوں پر فضیلت عطا کی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmclxxv{اور داؤدؑ کا وارث سلیمانؑ ہوا اور اس نے کہا ``“لوگو، ہمیں پرندوں کی بولیاں سکھائی گئی ہیں اور ہمیں ہر طرح کی چیزیں دی گئی ہیں، بیشک یہ (اللہ کا) نمایاں فضل ہے"\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvi{سلیمانؑ کے لیے جن اور انسانوں اور پرندوں کے لشکر جمع کیے گئے تھے اور وہ پورے ضبط میں رکھے جاتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvii{(ایک مرتبہ وہ ان کے ساتھ کوچ کر رہا تھا) یہاں تک کہ جب یہ سب چیونٹیوں کی وادی میں پہنچے تو ایک چیونٹی نے کہا ``“اے چیونٹیو، اپنے بلوں میں گھس جاؤ، کہیں ایسا نہ ہو کہ سلیمانؑ اور اس کے لشکر تمہیں کچل ڈالیں اور انہیں خبر بھی نہ ہو"\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmclxxviii{سلیمانؑ اس کی بات پر مُسکراتے ہوئے ہنس پڑا اور بولا ``اے میرے رب، مجھے قابو میں رکھ کہ میں تیرے اس احسان کا شکر ادا کرتا رہوں جو تو نے مجھ پر اور میرے والدین پر کیا ہے اور ایسا عمل صالح کروں جو تجھے پسند آئے اور اپنی رحمت سے مجھ کو اپنے صالح بندوں میں داخل کر"\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmclxxix{(ایک اور موقع پر) سلیمانؑ نے پرندوں کا جائزہ لیا اور کہا “کیا بات ہے کہ میں فلاں ہُد ہُد کو نہیں دیکھ رہا ہوں کیا وہ کہیں غائب ہو گیا ہے؟\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmclxxx{میں اسے سخت سزا دوں گا، یا ذبح کر دوں گا، ورنہ اسے میرے سامنے معقول وجہ پیش کرنی ہو گی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxi{کچھ زیادہ دیر نہ گزری تھی کہ اُس نے آ کر کہا ``“میں نے وہ معلومات حاصل کی ہیں جو آپ کے علم میں نہیں ہیں میں سَبا کے متعلق یقینی اطلاع لے کر آیا ہوں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxii{میں نے وہاں ایک عورت دیکھی جو اس قوم کی حکمران ہے اُس کو ہر طرح کا ساز و سامان بخشا گیا ہے اور اس کا تخت بڑا عظیم الشان ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiii{میں نے دیکھا ہے کہ وہ اور اس کی قوم اللہ کے بجائے سورج کے آگے سجدہ کرتی ہے" شیطان نے ان کے اعمال ان کے لیے خوشنما بنا دیے اور انہیں شاہراہ سے روک دیا، اس وجہ سے وہ یہ سیدھا راستہ نہیں پاتے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiv{کہ اُس خدا کو سجدہ کریں جو آسمانوں اور زمین کی پوشیدہ چیزیں نکالتا ہے اور وہ سب کچھ جانتا ہے جسے تم لوگ چھپاتے ہو اور ظاہر کرتے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxv{اللہ کہ جس کے سوا کوئی مستحقِ عبادت نہیں، جو عرش عظیم کا مالک ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvi{سلیمانؑ نے کہا ``ابھی ہم دیکھے لیتے ہیں کہ تو نے سچ کہا ہے یا تو جھوٹ بولنے والوں میں سے ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvii{میرا یہ خط لے جا اور اسے ان لوگوں کی طرف ڈال دے، پھر الگ ہٹ کر دیکھ کہ وہ کیا رد عمل ظاہر کرتے ہیں"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxviii{ملکہ بولی ``اے اہلِ دربار، میری طرف ایک بڑا اہم خط پھینکا گیا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxix{وہ سلیمانؑ کی جانب سے ہے اور اللہ رحمٰن و رحیم کے نام سے شروع کیا گیا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcxc{مضمون یہ ہے کہ “میرے مقابلے میں سرکشی نہ کرو اور مسلم ہو کر میرے پاس حاضر ہو جاؤ"\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcxci{(خط سُنا کر) ملکہ نے کہا ``“اے سردارانِ قوم میرے اس معاملے میں مجھے مشورہ دو، میں کسی معاملہ کا فیصلہ تمہارے بغیر نہیں کرتی ہوں"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcxcii{اُنہوں نے جواب دیا ``ہم طاقت ور اور لڑنے والے لوگ ہیں آگے فیصلہ آپ کے ہاتھ میں ہے آپ خود دیکھ لیں کہ آپ کو کیا حکم دینا ہے"\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcxciii{ملکہ نے کہا کہ ``بادشاہ جب کسی مُلک میں گھس آتے ہیں تو اسے خراب اور اس کے عزت والوں کو ذلیل کر دیتے ہیں یہی کچھ وہ کیا کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcxciv{میں اِن لوگوں کی طرف ایک ہدیہ بھیجتی ہوں، پھر دیکھتی ہوں کہ میرے ایلچی کیا جواب لے کر پلٹتے ہیں"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcxcv{جب وہ (ملکہ کا سفیر) سلیمانؑ کے ہاں پہنچا تو اس نے کہا ``کیا تم لوگ مال سے میری مدد کرنا چاہتے ہو؟ جو کچھ خدا نے مجھے دے رکھا ہے وہ اس سے بہت زیادہ ہے جو تمہیں دیا ہے تمہارا ہدیہ تمہی کو مبارک رہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvi{(اے سفیر) واپس جا اپنے بھیجنے والوں کی طرف ہم ان پر ایسے لشکر لے کر آئیں گے جن کا مقابلہ وہ نہ کر سکیں گے اور ہم انہیں ایسی ذلت کے ساتھ وہاں سے نکالیں گے کہ وہ خوار ہو کر رہ جائیں گے"\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvii{سلیمانؑ نے کہا ``“اے اہل دربار، تم میں سے کون اس کا تخت میرے پاس لاتا ہے قبل اس کے کہ وہ لوگ مطیع ہو کر میرے پاس حاضر ہوں؟"\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcxcviii{جنوں میں سے ایک قوی ہیکل نے عرض کیا ``میں اسے حاضر کر دوں گا قبل اس کے کہ آپ اپنی جگہ سے اٹھیں میں اس کی طاقت رکھتا ہوں اور امانتدار ہوں"\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcxcix{جس شخص کے پاس کتاب کا علم تھا وہ بولا ``میں آپ کی پلک جھپکنے سے پہلے اسے لائے دیتا ہوں" جونہی کہ سلیمانؑ نے وہ تخت اپنے پاس رکھا ہوا دیکھا، وہ پکار اٹھا ``یہ میرے رب کا فضل ہے تاکہ وہ مجھے آزمائے کہ میں شکر کرتا ہوں یا کافر نعمت بن جاتا ہوں اور جو کوئی شکر کرتا ہے اس کا شکر اس کے اپنے ہی لیے مفید ہے، ورنہ کوئی ناشکری کرے تو میرا رب بے نیاز اور اپنی ذات میں آپ بزرگ ہے"\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcc{سلیمانؑ نے کہا ``انجان طریقے سے اس کا تخت اس کے سامنے رکھ دو، دیکھیں وہ صحیح بات تک پہنچتی ہے یا اُن لوگوں میں سے ہے جو راہِ راست نہیں پاتے"\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcci{ملکہ جب حاضر ہوئی تو اس سے کہا گیا کیا تیرا تخت ایسا ہی ہے؟ وہ کہنے لگی ``یہ تو گویا وہی ہے ہم تو پہلے ہی جان گئے تھے اور ہم نے سرِ اطاعت جھکا دیا تھا (یا ہم مسلم ہو چکے تھے)"\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccii{اُس کو (ایمان لانے سے) جس چیز نے روک رکھا تھا وہ اُن معبودوں کی عبادت تھی جنہیں وہ اللہ کے سوا پوجتی تھی، کیونکہ وہ ایک کافر قوم سے تھی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcciii{اس سے کہا گیا کہ محل میں داخل ہو اس نے جو دیکھا تو سمجھی کہ پانی کا حوض ہے اور اترنے کے لیے اس نے اپنے پائنچے اٹھا لیے سلیمانؑ نے کہا یہ شیشے کا چکنا فرش ہے اس پر وہ پکار اٹھی ``اے میرے رب، (آج تک) میں اپنے نفس پر بڑا ظلم کرتی رہی، اور اب میں نے سلیمانؑ کے ساتھ اللہ رب العالمین کی اطاعت قبول کر لی"\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcciv{اور ثمود کی طرف ہم نے اُن کے بھائی صالح کو (یہ پیغام دے کر) بھیجا کہ اللہ کی بندگی کرو، تو یکایک وہ دو متخاصم فریق بن گئے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccv{صالحؑ نے کہا ``“اے میری قوم کے لوگو، بھلائی سے پہلے بُرائی کے لیے کیوں جلدی مچاتے ہو؟ کیوں نہیں اللہ سے مغفرت طلب کرتے؟ شاید کہ تم پر رحم فرمایا جائے؟"\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccvi{انہوں نے کہا ``ہم نے تو تم کو اور تمہارے ساتھیوں کو بد شگونی کا نشان پایا ہے" صالحؑ نے جواب دیا ``“تمہارے نیک و بد شگون کا سر رشتہ تو اللہ کے پاس ہے اصل بات یہ ہے کہ تم لوگوں کی آزمائش ہو رہی ہے"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccvii{اُس شہر میں نو جتھے دار تھے جو ملک میں فساد پھیلاتے اور کوئی اصلاح کا کام نہ کرتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccviii{انہوں نے آپس میں کہا ``خدا کی قسم کھا کر عہد کر لو کہ ہم صالحؑ اور اس کے گھر والوں پر شب خون ماریں گے اور پھر اس کے ولی سے کہہ دیں گے کہ ہم اس خاندان کی ہلاکت کے موقع پر موجود نہ تھے، ہم بالکل سچ کہتے ہیں"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmccix{یہ چال تو وہ چلے اور پھر ایک چال ہم نے چلی جس کی انہیں خبر نہ تھی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccx{اب دیکھ لو کہ ان کی چال کا انجام کیا ہوا ہم نے تباہ کر کے رکھ دیا اُن کو اور ان کی پوری قوم کو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccxi{وہ اُن کے گھر خالی پڑے ہیں اُس ظلم کی پاداش میں جو وہ کرتے تھے، اس میں ایک نشان عبرت ہے اُن لوگوں کے لیے جو علم رکھتے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmccxii{اور بچا لیا ہم نے اُن لوگوں کو جو ایمان لائے تھے اور نافرمانی سے پرہیز کرتے تھے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmccxiii{اور لوطؑ کو ہم نے بھیجا یاد کرو وہ وقت جب اس نے اپنی قوم سے کہا ``کیا تم آنکھوں دیکھتے بدکاری کرتے ہو؟\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmccxiv{کیا تمہارا یہی چلن ہے کہ عورتوں کو چھوڑ کر مردوں کے پاس شہوت رانی کے لیے جاتے ہو؟ حقیقت یہ ہے کہ تم لوگ سخت جہالت کا کام کرتے ہو"\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmccxv{مگر اُس کی قوم کا جواب اس کے سوا کچھ نہ تھا کہ انہوں نے کہا ``نکال دو لوطؑ کے گھر والوں کو اپنی بستی سے، یہ بڑے پاکباز بنتے ہیں"\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmccxvi{آخر کار ہم نے بچا لیا اُس کو اور اُس کے گھر والوں کو، بجز اُس کی بیوی کے جس کا پیچھے رہ جانا ہم نے طے کر دیا تھا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmccxvii{اور برسائی اُن لوگوں پر ایک برسات، بہت ہی بری برسات تھی وہ اُن لوگوں کے حق میں جو متنبہ کیے جا چکے تھے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmccxviii{(اے نبیؐ) کہو، حمد اللہ کے لیے اور سلام اس کے اُن بندوں پر جنہیں اس نے برگزیدہ کیا (اِن سے پوچھو) اللہ بہتر ہے یا وہ معبود جنہیں یہ لوگ اس کا شریک بنا رہے ہیں؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmccxix{بھلا وہ کون ہے جس نے آسمانوں اور زمین کو پیدا کیا اور تمہارے لیے آسمان سے پانی برسایا پھر اس کے ذریعہ سے وہ خوشنما باغ اگائے جن کے درختوں کا اگانا تمہارے بس میں نہ تھا؟ کیا اللہ کے ساتھ کوئی دوسرا خدا بھی (اِن کاموں میں شریک) ہے؟ (نہیں)، بلکہ یہی لوگ راہِ راست سے ہٹ کر چلے جا رہے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmccxx{اور وہ کون ہے جس نے زمین کو جائے قرار بنایا اور اس کے اندر دریا رواں کیے اور اس میں (پہاڑوں کی) میخیں گاڑ دیں اور پانی کے دو ذخیروں کے درمیان پردے حائل کر دیے؟ کیا اللہ کے ساتھ کوئی اور خدا بھی (اِن کاموں میں شریک) ہے؟ نہیں، بلکہ اِن میں سے اکثر لوگ نادان ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmccxxi{کون ہے جو بے قرار کی دعا سنتا ہے جبکہ وہ اُسے پکارے اور کون اس کی تکلیف رفع کرتا ہے؟ اور (کون ہے جو) تمہیں زمین کا خلیفہ بناتا ہے؟ کیا اللہ کے ساتھ کوئی اور خدا بھی (یہ کام کرنے والا) ہے؟ تم لوگ کم ہی سوچتے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmccxxii{اور وہ کون ہے جو خشکی اور سمندر کی تاریکیوں میں تم کو راستہ دکھاتا ہے اور کون اپنی رحمت کے آگے ہواؤں کو خوشخبری لے کر بھیجتا ہے؟ کیا اللہ کے ساتھ کوئی دُوسرا خدا بھی (یہ کام کرتا) ہے؟ بہت بالا و برتر ہے اللہ اس شرک سے جو یہ لوگ کرتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiii{اور کون ہے جو خلق کی ابتدا کرتا اور پھر اس کا اعادہ کرتا ہے؟ اور کون تم کو آسمان اور زمین سے رزق دیتا ہے؟ کیا اللہ کے ساتھ کوئی اور خدا بھی (اِن کاموں میں حصہ دار) ہے؟ کہو کہ لاؤ اپنی دلیل اگر تم سچے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiv{اِن سے کہو، اللہ کے سوا آسمانوں اور زمین میں کوئی غیب کا علم نہیں رکھتا، اور وہ نہیں جانتے کہ کب وہ اٹھائے جائیں گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmccxxv{بلکہ آخرت کا تو علم ہی اِن لوگوں سے گم ہو گیا ہے، بلکہ یہ اس کی طرف سے شک میں ہیں، بلکہ یہ اُس سے اندھے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvi{یہ منکرین کہتے ہیں ``کیا جب ہم اور ہمارے باپ دادا مٹی ہو چکے ہوں گے تو ہمیں واقعی قبروں سے نکالا جائے گا؟\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvii{یہ خبریں ہم کو بھی بہت دی گئی ہیں اور پہلے ہمارے آباء اجداد کو بھی دی جاتی رہی ہیں، مگر یہ بس افسانے ہی افسانے ہیں جو اگلے وقتوں سے سُنتے چلے آ رہے ہیں"\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmccxxviii{کہو ذرا زمین میں چل پھر کر دیکھو کہ مجرموں کا کیا انجام ہو چکا ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmccxxix{اے نبیؐ، اِن کے حال پر رنج نہ کرو اور نہ اِن کی چالوں پر دل تنگ ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmccxxx{وہ کہتے ہیں کہ ``یہ دھمکی کب پُوری ہو گی اگر تم سچے ہو؟"\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxi{کہو کیا عجب کہ جس عذاب کے لیے تم جلدی مچا رہے ہو اس کا ایک حصہ تمہارے قریب ہی آ لگا ہو\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxii{حقیقت یہ ہے کہ تیرا رب تو لوگوں پر بڑا فضل فرمانے والا ہے مگر اکثر لوگ شکر نہیں کرتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiii{بلا شبہ تیرا رب خُوب جانتا ہے جو کچھ ان کے سینے اپنے اندر چھپائے ہوئے ہیں اور جو کچھ وہ ظاہر کرتے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiv{آسمان و زمین کی کوئی پوشیدہ چیز ایسی نہیں ہے جو ایک واضح کتاب میں لکھی ہوئی موجود نہ ہو\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxv{یہ واقعہ ہے کہ یہ قرآن بنی اسرائیل کو اکثر اُن باتوں کی حقیقت بتاتا ہے جن میں وہ اختلاف رکھتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvi{اور یہ ہدایت اور رحمت ہے ایمان لانے والوں کے لیے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvii{یقیناً (اِسی طرح) تیرا رب اِن لوگوں کے درمیان بھی اپنے حکم سے فیصلہ کر دے گا اور وہ زبردست اور سب کچھ جاننے والا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxviii{پس اے نبیؐ، اللہ پر بھروسا رکھو، یقیناً تم صریح حق پر ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxix{تم مُردوں کو نہیں سنا سکتے، نہ اُن بہروں تک اپنی پکار پہنچا سکتے ہو جو پیٹھ پھیر کر بھاگے جا رہے ہوں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmccxl{اور نہ اندھوں کو راستہ بتا کر بھٹکنے سے بچا سکتے ہو تم تو اپنی بات اُنہی لوگوں کو سنا سکتے ہو جو ہماری آیات پر ایمان لاتے ہیں اور پھر فرمان بردار بن جاتے ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmccxli{اور جب ہماری بات پُوری ہونے کا وقت اُن پر آ پہنچے گا تو ہم ان کے لیے ایک جانور زمین سے نکالیں گے جو ان سے کلام کرے گا کہ لوگ ہماری آیات پر یقین نہیں کرتے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmccxlii{اور ذرا تصور کرو اُس دن کا جب ہم ہر امّت میں سے ایک فوج کی فوج اُن لوگوں کی گھیر لائیں گے جو ہماری آیات کو جھٹلایا کرتے تھے، پھر ان کو (ان کی اقسام کے لحاظ سے درجہ بدرجہ) مرتب کیا جائے گا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmccxliii{یہاں تک کہ جب سب آ جائیں گے تو (ان کا رب ان سے) پوچھے گا کہ ``تم نے میری آیات کو جھٹلا دیا حالانکہ تم نے ان کا علمی احاطہ نہ کیا تھا؟ اگر یہ نہیں تو اور تم کیا کر رہے تھے؟"\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmccxliv{اور ان کے ظلم کی وجہ سے عذاب کا وعدہ ان پر پورا ہو جائے گا، تب وہ کچھ بھی نہ بول سکیں گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmccxlv{کیا ان کو سُجھائی نہ دیتا تھا کہ ہم نے رات ان کے لیے سکون حاصل کرنے کو بنائی تھی اور دن کو روشن کیا تھا؟ اسی میں بہت نشانیاں تھیں ان لوگوں کے لیے جو ایمان لاتے تھے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvi{اور کیا گزرے گی اس روز جب کہ صُور پھونکا جائے گا اور ہَول کھا جائیں گے وہ سب جو آسمانوں اور زمین میں ہیں، سوائے اُن لوگوں کے جنہیں اللہ اس ہَول سے بچانا چاہے گا، اور سب کان دبائے اس کے حضور حاضر ہو جائیں گے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvii{آج تو پہاڑوں کو دیکھتا ہے اور سمجھتا ہے کہ خوب جمے ہوئے ہیں، مگر اُس وقت یہ بادلوں کی طرح اڑ رہے ہوں گے، یہ اللہ کی قدرت کا کرشمہ ہو گا جس نے ہر چیز کو حکمت کے ساتھ استوار کیا ہے وہ خوب جانتا ہے کہ تم لوگ کیا کرتے ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmccxlviii{جو شخص بھلائی لے کر آئیگا اسے اُس سے زیادہ بہتر صلہ ملے گا اور ایسے لوگ اُس دن کے ہَول سے محفوظ ہوں گے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmccxlix{اور جو بُرائی لیے ہوئے آئے گا، ایسے سب لوگ اوندھے منہ آگ میں پھینکے جائیں گے کیا تم لوگ اس کے سوا کوئی اور جزا پا سکتے ہو کہ جیسا کرو ویسا بھرو؟\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmccl{(اے محمدؐ، اِن سے کہو) ``مجھے تو یہی حکم دیا گیا ہے کہ اِس شہر کے رب کی بندگی کروں جس نے اِسے حرم بنایا ہے اور جو ہر چیز کا مالک ہے مجھے حکم دیا گیا ہے کہ میں مسلم بن کر رہوں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmccli{اور یہ قرآن پڑھ کر سناؤں" اب جو ہدایت اختیار کرے گا وہ اپنے ہی بھلے کے لیے ہدایت اختیار کرے گا اور جو گمراہ ہو اُس سے کہہ دو کہ میں تو بس خبردار کر دینے والا ہوں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmcclii{اِن سے کہو، تعریف اللہ ہی کے لیے ہے، عنقریب وہ تمہیں اپنی نشانیاں دکھا دے گا اور تم انہیں پہچان لو گے، اور تیرا رب بے خبر نہیں ہے اُن اعمال سے جو تم لوگ کرتے ہو\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmccliii{\basmalahur ط س م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmccliv{یہ کتاب مبین کی آیات ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcclv{ہم موسیٰؑ اور فرعون کا کچھ حال ٹھیک ٹھیک تمہیں سُناتے ہیں ایسے لوگوں کے فائدے کے لیے جو ایمان لائیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcclvi{واقعہ یہ ہے کہ فرعون نے زمین میں سرکشی کی اور اس کے باشندوں کو گروہوں میں تقسیم کر دیا ان میں سے ایک گروہ کو وہ ذلیل کرتا تھا، اس کے لڑکوں کو قتل کرتا اور اس کی لڑکیوں کو جیتا رہنے دیتا تھا فی الواقع وہ مفسد لوگوں میں سے تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcclvii{اور ہم یہ ارادہ رکھتے تھے کہ مہربانی کریں ان لوگوں پر جو زمین میں ذلیل کر کے رکھے گئے تھے اور انہیں پیشوا بنا دیں اور انہی کو وارث بنائیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcclviii{اور زمین میں ان کو اقتدار بخشیں اور ان سے فرعون و ہامان اور ان کے لشکروں کو وہی کچھ دکھلا دیں جس کا انہیں ڈر تھا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcclix{ہم نے موسیٰؑ کی ماں کو اشارہ کیا کہ ``اِس کو دودھ پلا، پھر جب تجھے اُس کی جان کا خطرہ ہو تو اسے دریا میں ڈال دے اور کچھ خوف اور غم نہ کر، ہم اسے تیرے ہی پاس واپس لے آئیں گے اور اس کو پیغمبروں میں شامل کریں گے"\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcclx{آ خرکار فرعون کے گھر والوں نے اسے (دریا سے) نکال لیا تاکہ وہ ان کا دشمن اور ان کے لیے سببِ رنج بنے، واقعی فرعون اور ہامان اور اس کے لشکر (اپنی تدبیر میں) بڑے غلط کار تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcclxi{فرعون کی بیوی نے (اس سے) کہا ``یہ میرے اور تیرے لیے آنکھوں کی ٹھنڈک ہے، اسے قتل نہ کرو، کیا عجب کہ یہ ہمارے لیے مفید ثابت ہو، یا ہم اسے بیٹا ہی بنا لیں" اور وہ (انجام سے) بے خبر تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcclxii{اُدھر موسیٰؑ کی ماں کا دل اڑا جا رہا تھا وہ اس راز کو فاش کر بیٹھتی اگر ہم اس کی ڈھارس نہ بندھا دیتے تاکہ وہ (ہمارے وعدے پر) ایمان لانے والوں میں سے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiii{اُس نے بچے کی بہن سے کہا اس کے پیچھے پیچھے جا چنانچہ وہ الگ سے اس کو اس طرح دیکھتی رہی کہ (دشمنوں کو) اس کا پتہ نہ چلا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiv{اور ہم نے بچّے پر پہلے ہی دُودھ پِلانے والیوں کی چھاتیاں حرام کر رکھی تھیں (یہ حالت دیکھ کر) اُس لڑکی نے اُن سے کہا ``میں تمہیں ایسے گھر کا پتہ بتاؤں جس کے لوگ اس کی پرورش کا ذمّہ لیں اور خیر خواہی کے ساتھ اسے رکھیں؟"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcclxv{اس طرح ہم موسیٰؑ کو اس کی ماں کے پاس پلٹا لائے تاکہ اس کی آنکھیں ٹھنڈی ہوں اور وہ غمگین نہ ہو اور جان لے کہ اللہ کا وعدہ سچا تھا، مگر اکثر لوگ اس بات کو نہیں جانتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvi{پھر جب موسیٰؑ اپنی پوری جوانی کو پہنچ گیا اور اس کا نشوونما مکمل ہو گیا تو ہم نے اسے حکم اور علم عطا کیا، ہم نیک لوگوں کو ایسی ہی جزا دیتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvii{(ایک روز) وہ شہر میں ایسے وقت میں داخل ہوا جبکہ اہلِ شہر غفلت میں تھے وہاں اس نے دیکھا کہ دو آدمی لڑ رہے ہیں ایک اس کی اپنی قوم کا تھا اور دُوسرا اس کی دشمن قوم سے تعلق رکھتا تھا اس کی قوم کے آدمی نے دشمن قوم والے کے خلاف اسے مدد کے لیے پکارا موسیٰؑ نے اس کو ایک گھونسا مارا اور اس کا کام تمام کر دیا (یہ حرکت سرزد ہوتے ہی) موسیٰؑ نے کہا ``یہ شیطان کی کارفرمائی ہے، وہ سخت دشمن اور کھلا گمراہ کن ہے"\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcclxviii{پھر وہ کہنے لگا ``اے میرے رب، مَیں نے اپنے نفس پر بڑا ظلم کر ڈالا، میری مغفرت فرما دے" چنانچہ اللہ نے اس کی مغفرت فرما دی، وہ غفور رحیم ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcclxix{موسیٰؑ نے عہد کیا کہ ``“اے میرے رب، یہ احسان جو تو نے مجھ پر کیا ہے اِس کے بعد اب میں کبھی مجرموں کا مدد گار نہ بنوں گا"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcclxx{دُوسرے روز وہ صبح سویرے ڈرتا اور ہر طرف سے خطرہ بھانپتا ہوا شہر میں جا رہا تھا کہ یکایک کیا دیکھتا ہے کہ وہی شخص جس نے کل اسے مدد کے لیے پکارا تھا آج پھر اسے پکار رہا ہے موسیٰؑ نے کہا ``تُو تو بڑا ہی بہکا ہُوا آدمی ہے"\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxi{پھر جب موسیٰؑ نے ارادہ کیا کہ دشمن قوم کے آدمی پر حملہ کرے تو وہ پکار اٹھا ``اے موسیٰؑ، کیا آج تو مجھے اُسی طرح قتل کرنے لگا ہے جس طرح کل ایک شخص کو قتل کر چکا ہے، تو اس ملک میں جبّار بن کر رہنا چاہتا ہے، اصلاح نہیں کرنا چاہتا"\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxii{اس کے بعد ایک آدمی شہر کے پرلے سِرے سے دَوڑتا ہوا آیا اور بولا ``موسیٰؑ، سرداروں میں تیرے قتل کے مشورے ہو رہے ہیں، یہاں سے نکل جا، میں تیرا خیر خواہ ہوں"\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiii{یہ خبر سنتے ہی موسیٰؑ ڈرتا اور سہمتا نکل کھڑا ہوا اور اس نے دعا کی کہ ``اے میرے رب، مجھے ظالموں سے بچا"\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiv{(مصر سے نکل کر) جب موسیٰؑ نے مَدیَن کا رُخ کیا تو اُس نے کہا ``اُمید ہے کہ میرا رب مجھے ٹھیک راستے پر ڈال دے گا"\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxv{اور جب وہ مَدیَن کے کنوئیں پر پہنچا تو اُس نے دیکھا کہ بہت سے لوگ اپنے جانوروں کو پانی پلا رہے ہیں اور ان سے الگ ایک طرف دو عورتیں اپنے جانوروں کو روک رہی ہیں موسیٰؑ نے اِن عورتوں سے پوچھا ``تمہیں کیا پریشانی ہے؟" انہوں نے کہا ``ہم اپنے جانوروں کو پانی نہیں پلا سکتیں جب تک یہ چرواہے اپنے جانور نکال کر نہ لے جائیں، اور ہمارے والد ایک بہت بوڑھے آدمی ہیں"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvi{یہ سن کو موسیٰؑ نے ان کے جانوروں کو پانی پلا دیا، پھر ایک سائے کی جگہ جا بیٹھا اور بولا ``پروردگار، جو خیر بھی تو مجھ پر نازل کر دے میں اس کا محتاج ہوں"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvii{(کچھ دیر نہ گزری تھی کہ) ان دونوں عورتوں میں سے ایک شرم و حیا سے چلتی ہوئی اس کے پاس آئی اور کہنے لگی ``میرے والد آپ کو بُلا رہے ہیں تاکہ آپ نے ہمارے جانوروں کو پانی جو پلایا ہے اس کا اجر آپ کو دیں" موسیٰؑ جب اس کے پاس پہنچا اور اپنا سارا قصہ اسے سُنایا تو اس نے کہا ``کچھ خوف نہ کرو، اب تم ظالموں سے بچ نکلے ہو"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxviii{ان دونوں عورتوں میں سے ایک نے اپنے باپ سے کہا ``ابّا جان، اس شخص کو نوکر رکھ لیجیے، بہترین آدمی جسے آپ ملازم رکھیں وہی ہو سکتا ہے جو مضبُوط اور امانت دار ہو"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxix{اس کے باپ نے (موسیٰؑ سے) کہا ``میں چاہتا ہوں کہ اپنی اِن دو بیٹیوں میں سے ایک کا نکاح تمہارے ساتھ کر دوں بشرطیکہ تم آٹھ سال تک میرے ہاں ملازمت کرو، اور اگر دس سال پُورے کر دو تو یہ تمہاری مرضی ہے میں تم پر سختی نہیں کرنا چاہتا تم اِن شاءاللہ مجھے نیک آدمی پاؤ گے"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxx{موسیٰ نے جواب دیا ``یہ بات میرے اور آپ کے درمیان طے ہو گئی ان دونوں مدتوں میں سے جو بھی میں پُوری کر دوں اُس کے بعد پھر کوئی زیادتی مجھ پر نہ ہو، اور جو کچھ قول قرار ہم کر رہے ہیں اللہ اس پر نگہبان ہے"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxi{جب موسیٰؑ نے مدت پوری کر دی اور وہ اپنے اہل و عیال کو لے کر چلا تو طُور کی جانب اس کو ایک آگ نظر آئی اُس نے اپنے گھر والوں سے کہا ``ٹھیرو، میں نے ایک آگ دیکھی ہے، شاید میں وہاں سے کوئی خبر لے آؤں یا اس آگ سے کوئی انگارہ ہی اُٹھا لاؤں جس سے تم تاپ سکو"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxii{وہاں پہنچا تو وادی کے داہنے کنارے پر مبارک خطے میں ایک درخت سے پکارا گیا کہ ``اے موسیٰؑ، میں ہی اللہ ہوں، سارے جہان والوں کا مالک"\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiii{اور (حکم دیا گیا کہ) پھینک دے اپنی لاٹھی جونہی کہ موسیٰؑ نے دیکھا کہ وہ لاٹھی سانپ کی طرح بل کھا رہی ہے تو وہ پیٹھ پھیر کر بھاگا اور اس نے مڑ کر بھی نہ دیکھا (ارشاد ہوا) ``موسیٰؑ، پلٹ آ اور خوف نہ کر، تو بالکل محفوظ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiv{اپنا ہاتھ گریبان میں ڈال، چمکتا ہوا نکلے گا بغیر کسی تکلیف کے اور خوف سے بچنے کے لیے اپنا بازو بھینچ لے یہ دو روشن نشانیاں ہیں تیرے رب کی طرف سے فرعون اور اس کے درباریوں کے سامنے پیش کرنے کے لیے، وہ بڑے ہی نافرمان لوگ ہیں"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxv{موسیٰؑ نے عرض کیا ``میرے آقا، میں تو ان کا ایک آدمی قتل کر چکا ہوں، ڈرتا ہوں کہ وہ مجھے مار ڈالیں گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvi{اور میرا بھائی ہارونؑ مجھے سے زیادہ زبان آور ہے، اسے میرے ساتھ مدد گار کے طور پر بھیج تاکہ وہ میری تائید کرے، مجھے اندیشہ ہے کہ وہ لوگ مجھے جھٹلائیں گے"\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvii{فرمایا ``ہم تیرے بھائی کے ذریعہ سے تیرا ہاتھ مضبوط کریں گے اور تم دونوں کو ایسی سطوت بخشیں گے کہ وہ تمہارا کچھ نہ بگاڑ سکیں گے ہماری نشانیوں کے زور سے غلبہ تمہارا اور تمہارے پیروؤں کا ہی ہو گا"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxviii{پھر جب موسیٰؑ اُن لوگوں کے پاس ہماری کھُلی کھُلی نشانیاں لے کر پہنچا تو انہوں نے کہا کہ یہ کچھ نہیں ہے مگر بناوٹی جادوگر اور یہ باتیں تو ہم نے اپنے باپ دادا کے زمانے میں کبھی سُنیں ہی نہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxix{موسیٰؑ نے جواب دیا ``میرا رب اُس شخص کے حال سے خوب واقف ہے جو اس کی طرف سے ہدایت لے کر آیا ہے اور وہی بہتر جانتا ہے کہ آخری انجام کس کا اچھا ہونا ہے، حق یہ ہے کہ ظالم کبھی فلاح نہیں پاتے"\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccxc{اور فرعون نے کہا ``اے اہل دربار میں تو اپنے سوا تمہارے کسی خدا کو نہیں جانتا ہامان، ذرا اینٹیں پکوا کر میرے لیے ایک اونچی عمارت تو بنوا، شاید کہ اس پر چڑھ کر میں موسیٰؑ کے خدا کو دیکھ سکوں، میں تو اسے جھُوٹا سمجھتا ہوں"\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccxci{اُس نے اور اس کے لشکروں نے زمین میں بغیر کسی حق کے اپنی بڑائی کا گھمنڈ کیا اور سمجھے کہ انہیں کبھی ہماری طرف پلٹنا نہیں ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccxcii{آخر کار ہم نے اسے اور اس کے لشکروں کو پکڑا اور سمندر میں پھینک دیا اب دیکھ لو کہ ان ظالموں کا کیسا انجام ہوا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccxciii{ہم نے انہیں جہنم کی طرف دعوت دینے والے پیش رو بنا دیا اور قیامت کے روز وہ کہیں سے کوئی مدد نہ پا سکیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccxciv{ہم نے اِس دنیا میں ان کے پیچھے لعنت لگا دی اور قیامت کے روز وہ بڑی قباحت میں مبتلا ہوں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccxcv{پچھلی نسلوں کو ہلاک کرنے کے بعد ہم نے موسیٰؑ کو کتاب عطا کی، لوگوں کے لیے بصیرتوں کا سامان بنا کر، تاکہ شاید لوگ سبق حاصل کریں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvi{(اے محمدؐ) تم اُس وقت مغربی گوشے میں موجود نہ تھے جب ہم نے موسیٰؑ کو یہ فرمان شریعت عطا کیا، اور نہ تم شاہدین میں شامل تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvii{بلکہ اس کے بعد (تمہارے زمانے تک) ہم بہت سی نسلیں اٹھا چکے ہیں اور ان پر بہت زمانہ گزر چکا ہے تم اہلِ مَدیَن کے درمیان بھی موجود نہ تھے کہ اُن کو ہماری آیات سُنا رہے ہوتے، مگر (اُس وقت کی یہ خبریں) بھیجنے والے ہم ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccxcviii{اور تم طور کے دامن میں بھی اُس وقت موجود نہ تھے جب ہم نے (موسیٰؑ کو پہلی مرتبہ) پکارا تھا، مگر یہ تمہارے رب کی رحمت ہے (کہ تم کو یہ معلومات دی جار ہی ہیں) تاکہ تم اُن لوگوں کو متنبّہ کر دو جن کے پاس تم سے پہلے کوئی متنبّہ کرنے والا نہیں آیا، شاید کہ وہ ہوش میں آئیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccxcix{(اور یہ ہم نے اس لیے کیا کہ) کہیں ایسا نہ ہو کہ اُن کے اپنے کیے کرتوتوں کی بدولت کوئی مصیبت جب اُن پر آئے تو وہ کہیں ``اے پروردگار، تُو نے کیوں نہ ہماری طرف کوئی رسول بھیجا کہ ہم تیری آیات کی پیروی کرتے اور اہلِ ایمان میں سے ہوتے"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccc{مگر جب ہمارے ہاں سے حق ان کے پاس آ گیا تو وہ کہنے لگے ``کیوں نہ دیا گیا اِس کو وہی کچھ جو موسیٰؑ کو دیا گیا تھا؟" کیا یہ لوگ اُس کا انکار نہیں کر چکے ہیں جو اس سے پہلے موسیٰؑ کو دیا گیا تھا؟ انہوں نے کہا ``دونوں جادوگر ہیں جو ایک دُوسرے کی مدد کرتے ہیں" اور کہا ``ہم کسی کو نہیں مانتے"\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccci{(اے نبیؐ،) ان سے کہو، ``اچھا تو لاؤ اللہ کی طرف سے کوئی کتاب جو اِن دونوں سے زیادہ ہدایت بخشنے والی ہو اگر تم سچے ہو، میں اسی کی پیروی اختیار کروں گا"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccii{اب اگر وہ تمہارا یہ مطالبہ پورا نہیں کرتے تو سمجھ لو کہ دراصل یہ اپنی خواہشات کے پیرو ہیں، اور اُس شخص سے بڑھ کر کون گمراہ ہو گا جو خدائی ہدایت کے بغیر بس اپنی خواہشات کی پیروی کرے؟ اللہ ایسے ظالموں کو ہرگز ہدایت نہیں بخشتا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccciii{اور (نصیحت کی) بات پے در پے ہم انہیں پہنچا چکے ہیں تاکہ وہ غفلت سے بیدار ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccciv{جن لوگوں کو اس سے پہلے ہم نے کتاب دی تھی وہ اِس (قرآن) پر ایمان لاتے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccv{اور جب یہ اُن کو سُنایا جاتا ہے تو وہ کہتے ہیں کہ ``ہم اِس پر ایمان لائے، یہ واقعی حق ہے ہمارے رب کی طرف سے، ہم تو پہلے ہی سے مسلم ہیں"\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccvi{یہ وہ لوگ ہیں جنہیں ان کا اجر دو بار دیا جائے گا اُس ثابت قدمی کے بدلے جو انہوں نے دکھائی وہ بُرائی کو بھَلائی سے دفع کرتے ہیں اور جو کچھ رزق ہم نے انہیں دیا ہے اس میں سے خرچ کرتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccvii{اور جب انہوں نے بیہودہ بات سنی تو یہ کہہ کر اس سے کنارہ کش ہو گئے کہ ``ہمارے اعمال ہمارے لیے اور تمہارے اعمال تمہارے لیے، تم کو سلام ہے، ہم جاہلوں کا سا طریقہ اختیار نہیں کرنا چاہتے"\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccviii{اے نبیؐ، تم جسے چاہو اسے ہدایت نہیں دے سکتے، مگر اللہ جسے چاہتا ہے ہدایت دیتا ہے اور وہ ان لوگوں کو خوب جانتا ہے جو ہدایت قبول کرنے والے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccix{وہ کہتے ہیں ``اگر ہم تمہارے ساتھ اِس ہدایت کی پیروی اختیار کر لیں تو اپنی زمین سے اُچک لیے جائیں گے" کیا یہ واقعہ نہیں ہے کہ ہم نے ایک پرامن حرم کو ان کے لیے جائے قیام بنا دیا جس کی طرف ہر طرح کے ثمرات کھچے چلے آتے ہیں، ہماری طرف سے رزق کے طور پر؟ مگر ان میں سے اکثر لوگ جانتے نہیں ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccx{اور کتنی ہی ایسی بستیاں ہم تباہ کر چکے ہیں جن کے لوگ اپنی معیشت پر اترا گئے تھے سو دیکھ لو، وہ ان کے مسکن پڑے ہوئے ہیں جن میں ان کے بعد کم ہی کوئی بسا ہے، آ خرکار ہم ہی وارث ہو کر رہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxi{اور تیرا رب بستیوں کو ہلاک کرنے والا نہ تھا جب تک کہ ان کے مرکز میں ایک رسُول نہ بھیج دیتا جو ان کو ہماری آیات سُناتا اور ہم بستیوں کو ہلاک کرنے والے نہ تھے جب تک کہ ان کے رہنے والے ظالم نہ ہو جاتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcccxii{تم لوگوں کو جو کچھ بھی دیا گیا ہے وہ محض دُنیا کی زندگی کا سامان اور اس کی زینت ہے، اور جو کچھ اللہ کے پاس ہے وہ اس سے بہتر اور باقی تر ہے کیا تم لوگ عقل سے کام نہیں لیتے؟\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiii{بھلا وہ شخص جس سے ہم نے اچھا وعدہ کیا ہو اور وہ اسے پانے والا ہو کبھی اس شخص کی طرح ہو سکتا ہے جسے ہم نے صرف حیات دنیا کا سروسامان دے دیا ہو اور پھر وہ قیامت کے روز سزا کے لیے پیش کیا جانے والا ہو؟\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiv{اور (بھول نہ جائیں یہ لوگ) اُس دن کو جب کہ وہ اِن کو پکارے گا اور پوچھے گا ``کہاں ہیں میرے وہ شریک جن کا تم گمان رکھتے تھے؟"\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcccxv{یہ قول جن پر چسپاں ہو گا وہ کہیں گے ``اے ہمارے رب، بے شک یہی لوگ ہیں جن کو ہم نے گمراہ کیا تھا، اِنہیں ہم نے اُسی طرح گمراہ کیا جیسے ہم خود گمراہ ہوئے ہم آپ کے سامنے براءت کا اظہار کرتے ہیں یہ ہماری تو بندگی نہیں کرتے تھے"\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvi{پھر اِن سے کہا جائے گا کہ پکارو اب اپنے ٹھیرائے ہوئے شریکوں کو یہ انہیں پکاریں گے مگر وہ اِن کو کوئی جواب نہ دیں گے اور یہ لوگ عذاب دیکھ لیں گے کاش یہ ہدایت اختیار کرنے والے ہوتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvii{اور (فراموش نہ کریں یہ لوگ) وہ دن جبکہ وہ اِن کو پکارے گا اور پوچھے گا کہ ``جو رسول بھیجے گئے تھے انہیں تم نے کیا جواب دیا تھا؟"\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcccxviii{اُس وقت کوئی جواب اِن کو نہ سُوجھے گا اور نہ یہ آپس میں ایک دُوسرے سے پوچھ ہی سکیں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcccxix{البتہ جس نے آج توبہ کر لی اور ایمان لے آیا اور نیک عمل کیے وہی یہ توقع کر سکتا ہے کہ وہاں فلاح پانے والوں میں سے ہو گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcccxx{تیرا رب پیدا کرتا ہے جو کچھ چاہتا ہے اور (وہ خود ہی اپنے کام کے لیے جسے چاہتا ہے) منتخب کر لیتا ہے، یہ انتخاب اِن لوگوں کے کرنے کا کام نہیں ہے، اللہ پاک ہے اور بہت بالاتر ہے اُس شرک سے جو یہ لوگ کرتے ہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxi{تیرا رب جانتا ہے جو کچھ یہ دلوں میں چھپائے ہوئے ہیں اور جو کچھ یہ ظاہر کرتے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxii{وہی ایک اللہ ہے جس کے سوا کوئی عبادت کا مستحق نہیں اسی کے لیے حمد ہے دنیا میں بھی اور آخرت میں بھی، فرماں روائی اسی کی ہے اور اسی کی طرف تم سب پلٹائے جانے والے ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiii{اے نبیؐ، اِن سے کہو کبھی تم لوگوں نے غور کیا کہ اگر اللہ قیامت تک تم پر ہمیشہ کے لیے رات طاری کر دے تو اللہ کے سوا وہ کونسا معبود ہے جو تمہیں روشنی لا دے؟ کیا تم سُنتے نہیں ہو؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiv{اِن سے پوچھو، کبھی تم نے سوچا کہ اگر اللہ قیامت تک تم پر ہمیشہ کے لیے دن طاری کر دے تو اللہ کے سوا وہ کونسا معبُود ہے جو تمہیں رات لا دے تاکہ تم اس میں سکون حاصل کر سکو؟ کیا تم کو سُوجھتا نہیں؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxv{یہ اسی کی رحمت ہے کہ اس نے تمہارے لیے رات اور دن بنائے تاکہ تم (رات میں) سکون حاصل کرو اور (دن کو) اپنے رب کا فضل تلاش کرو، شاید کہ تم شکر گزار بنو\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvi{(یاد رکھیں یہ لوگ) وہ دن جبکہ وہ انہیں پکارے گا پھر پوچھے گا ``کہاں ہیں میرے وہ شریک جن کا تم گمان رکھتے تھے؟"\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvii{اور ہم ہر امّت میں سے ایک گواہ نکال لائیں گے پھر کہیں گے کہ ``لاؤ اب اپنی دلیل" اس وقت انہیں معلوم ہو جائے گا کہ حق اللہ کی طرف سے ہے، اور گم ہو جائیں گے ان کے وہ سارے جھوٹ جو انہوں نے گھڑ رکھے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxviii{یہ ایک واقعہ ہے کہ قارون موسیٰؑ کی قوم کا ایک شخص تھا، پھر وہ اپنی قوم کے خلاف سرکش ہو گیا اور ہم نے اس کو اتنے خزانے دے رکھے تھے کہ ان کی کنجیاں طاقت ور آدمیوں کی ایک جماعت مشکل سے اُٹھا سکتی تھی ایک دفعہ جب اس کی قوم کے لوگوں نے اُس سے کہا ``پھول نہ جا، اللہ پھولنے والوں کو پسند نہیں کرتا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxix{جو مال اللہ نے تجھے دیا ہے اس سے آخرت کا گھر بنانے کی فکر کر اور دُنیا میں سے بھی اپنا حصہ فراموش نہ کر احسان کر جس طرح اللہ نے تیرے ساتھ احسان کیا ہے اور زمین میں فساد برپا کرنے کی کوشش نہ کر، اللہ مفسدوں کو پسند نہیں کرتا"\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxx{تو اُس نے کہا ``یہ سب کچھ تو مجھے اُس علم کی بنا پر دیا گیا ہے جو مجھ کو حاصل ہے" کیا اس کو علم نہ تھا کہ اللہ اس سے پہلے بہت سے ایسے لوگوں کو ہلاک کر چکا ہے جو اس سے زیادہ قوت اور جمعیت رکھتے تھے؟ مجرموں سے تو ان کے گناہ نہیں پوچھے جاتے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxi{ایک روز وہ اپنی قوم کے سامنے اپنے پُورے ٹھاٹھ میں نکلا جو لوگ حیات دنیا کے طالب تھے وہ اسے دیکھ کر کہنے لگے ``کاش ہمیں بھی وہی کچھ ملتا جو قارون کو دیا گیا ہے، یہ تو بڑا نصیبے والا ہے"\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxii{مگر جو لوگ علم رکھنے والے تھے وہ کہنے لگے ``افسوس تمہارے حال پر، اللہ کا ثواب بہتر ہے اُس شخص کے لیے جو ایمان لائے اور نیک عمل کرے، اور یہ دولت نہیں ملتی مگر صبر کرنے والوں کو"\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiii{آخر کار ہم نے اسے اور اس کے گھر کو زمین میں دَھنسا دیا پھر کوئی اس کے حامیوں کا گروہ نہ تھا جو اللہ کے مقابلہ میں اس کی مدد کو آتا اور نہ وہ خود اپنی مدد آپ کر سکا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiv{اب وہی لوگ جو کل اس کی منزلت کی تمنا کر رہے تھے کہنے لگے ``افسوس، ہم بھول گئے تھے کہ اللہ اپنے بندوں میں سے جس کا رزق چاہتا ہے کشادہ کرتا ہے اور جسے چاہتا ہے نَپا تلا دیتا ہے اگر اللہ نے ہم پر احسان نہ کیا ہوتا تو ہمیں بھی زمین میں دَھنسا دیتا افسوس ہم کو یاد نہ رہا کہ کافر فلاح نہیں پایا کرتے"\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxv{وہ آخرت کا گھر تو ہم اُن لوگوں کے لیے مخصوص کر دیں گے جو زمین میں اپنی بڑائی نہیں چاہتے اور نہ فساد کرنا چاہتے ہیں اور انجام کی بھَلائی متقین ہی کے لیے ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvi{جو کوئی بھَلائی لے کر آئے گا اس کے لیے اس سے بہتر بھَلائی ہے، اور جو بُرائی لے کر آئے تو بُرائیاں کرنے والوں کو ویسا ہی بدلہ ملے گا جیسے عمل وہ کرتے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvii{اے نبیؐ، یقین جانو کہ جس نے یہ قرآن تم پر فرض کیا ہے وہ تمہیں ایک بہترین انجام کو پہنچانے والا ہے اِن لوگوں سے کہہ دو کہ ``میرا رب خُوب جانتا ہے کہ ہدایت لے کر کون آیا ہے اور کھُلی گمراہی میں کون مُبتلا ہے"\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxviii{تم اس بات کے ہرگز امیدوار نہ تھے کہ تم پر کتاب نازل کی جائے گی، یہ تو محض تمہارے رب کی مہربانی سے (تم پر نازل ہوئی ہے)، پس تم کافروں کے مدد گار نہ بنو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxix{اور ایسا کبھی نہ ہونے پائے کہ اللہ کی آیات جب تم پر نازل ہوں تو کفّار تمہیں اُن سے باز رکھیں اپنے رب کی طرف دعوت دو اور ہرگز مشرکوں میں شامل نہ ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmcccxl{اور اللہ کے ساتھ کسی دُوسرے معبُود کو نہ پکارو اُس کے سوا کوئی معبُود نہیں ہے ہر چیز ہلاک ہونے والی ہے سوائے اُس کی ذات کے فرماں روائی اُسی کی ہے اور اُسی کی طرف تم سب پلٹائے جاؤ گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmcccxli{\basmalahur الف ل م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlii{کیا لوگوں نے یہ سمجھ رکھا ہے کہ وہ بس اتنا کہنے پر چھوڑ دیے جائیں گے کہ ``ہم ایمان لائے `` اور ان کو آزمایا نہ جائے گا؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliii{حالاں کہ ہم اُن سب لوگوں کی آزمائش کر چکے ہیں جو اِن سے پہلے گزرے ہیں اللہ کو تو ضرور یہ دیکھنا ہے کہ سچّے کون ہیں اور جھوٹے کون\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliv{اور کیا وہ لوگ جو بُری حرکتیں کر رہے ہیں یہ سمجھے بیٹھے ہیں کہ وہ ہم سے بازی لے جائیں گے؟ بڑا غلط حکم ہے جو وہ لگا رہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlv{جو کوئی اللہ سے ملنے کی توقع رکھتا ہو (اُسے معلوم ہونا چاہیے کہ) اللہ کا مقرر کیا ہوا وقت آنے ہی والا ہے، اور اللہ سب کچھ سُنتا اور جانتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvi{جو شخص بھی مجاہدہ کریگا اپنے ہی بھلے کے لیے کرے گا، اللہ یقیناً دنیا جہان والوں سے بے نیاز ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvii{اور جو لوگ ایمان لائیں گے اور نیک اعمال کریں گے اُن کی برائیاں ہم ان سے دُور کر دیں گے اور انہیں اُن کے بہترین اعمال کی جزا دیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlviii{ہم نے انسان کو ہدایت کی ہے کہ اپنے والدین کے ساتھ نیک سلوک کرے لیکن اگر وہ تجھ پر زور ڈالیں کہ تو میرے ساتھ کسی ایسے (معبُود) کو شریک ٹھیرائے جسے تو (میرے شریک کی حیثیت سے) نہیں جانتا تو ان کی اطاعت نہ کر میری ہی طرف تم سب کو پلٹ کر آنا ہے، پھر میں تم کو بتا دوں گا کہ تم کیا کرتے رہے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlix{اور جو لوگ ایمان لائے ہوں گے اور جنہوں نے نیک اعمال کیے ہوں گے اُن کو ہم ضرور صالحین میں داخل کریں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcccl{لوگوں میں سے کوئی ایسا ہے جو کہتا ہے کہ ہم ایمان لائے اللہ پر مگر جب وہ اللہ کے معاملہ میں ستایا گیا تو اس نے لوگوں کی ڈالی ہوئی آزمائش کو اللہ کے عذاب کی طرح سمجھ لیا اب اگر تیرے رب کی طرف سے فتح و نصرت آ گئی تو یہی شخص کہے گا کہ ``ہم تو تمہارے ساتھ تھے" کیا دنیا والوں کے دلوں کا حال اللہ کو بخوبی معلوم نہیں ہے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcccli{اور اللہ کو تو ضرور یہ دیکھنا ہی ہے کہ ایمان لانے والے کون ہیں اور منافق کون\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmccclii{یہ کافر لوگ ایمان لانے والوں سے کہتے ہیں کہ تم ہمارے طریقے کی پیروی کرو اور تمہاری خطاؤں کو ہم اپنے اُوپر لے لیں گے حالانکہ اُن کی خطاؤں میں سے کچھ بھی وہ اپنے اوپر لینے والے نہیں ہیں، وہ قطعاً جھوٹ کہتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcccliii{ہاں ضرور وہ اپنے بوجھ بھی اٹھائیں گے اور اپنے بوجھوں کے ساتھ بہت سے دوسرے بوجھ بھی اور قیامت کے روز یقیناً ان سے اِن افترا پردازیوں کی بازپرس ہو گی جو وہ کرتے رہے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcccliv{ہم نے نوحؑ کو اس کی قوم کی طرف بھیجا اور وہ پچاس کم ایک ہزار برس اُن کے درمیان رہا آخر کار اُن لوگوں کو طوفان نے آ گھیرا اس حال میں کہ وہ ظالم تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmccclv{پھر نوحؑ کو اور کشتی والوں کو ہم نے بچا لیا اور اُسے دنیا والوں کے لیے ایک نشان عبرت بنا کر رکھ دیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmccclvi{اور ابراہیمؑ کو بھیجا جبکہ اُس نے اپنی قوم سے کہا ``اللہ کی بندگی کرو اور اُس سے ڈرو یہ تمہارے لیے بہتر ہے اگر تم جانو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmccclvii{تم اللہ کو چھوڑ کر جنہیں پوج رہے ہو وہ تو محض بت ہیں اور تم ایک جھوٹ گھڑ رہے ہو در حقیقت اللہ کے سوا جن کی تم پرستش کرتے ہو وہ تمہیں کوئی رزق بھی دینے کا اختیار نہیں رکھتے اللہ سے رزق مانگو اور اُسی کی بندگی کرو اور اس کا شکر ادا کرو، اسی کی طرف تم پلٹائے جانے والے ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmccclviii{اور اگر تم جھٹلاتے ہو تو تم سے پہلے بہت سی قومیں جھٹلا چکی ہیں، اور رسول پر صاف صاف پیغام پہنچا دینے کے سوا کوئی ذمّہ داری نہیں ہے"\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmccclix{کیا اِن لوگوں نے کبھی دیکھا ہی نہیں ہے کہ اللہ کس طرح خلق کی ابتدا کرتا ہے، پھر اُس کا اعادہ کرتا ہے؟ یقیناً یہ (اعادہ تو) اللہ کے لیے آسان تر ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmccclx{ان سے کہو کہ زمین میں چلو پھرو اور دیکھو کہ اُس نے کس طرح خلق کی ابتدا کی ہے، پھر اللہ بار دیگر بھی زندگی بخشے گا یقیناً اللہ ہر چیز پر قادر ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmccclxi{جسے چاہے سزا دے اور جس پر چاہے رحم فرمائے، اُسی کی طرف تم پھیرے جانے والے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmccclxii{تم نہ زمین میں عاجز کرنے والے ہو نہ آسمان میں، اور اللہ سے بچانے والا کوئی سرپرست اور مدد گار تمہارے لیے نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiii{جن لوگوں نے اللہ کی آیات کا اور اس سے ملاقات کا انکار کیا ہے وہ میری رحمت سے مایوس ہو چکے ہیں اور ان کے لیے درد ناک سزا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiv{پھر اُس کی قوم کا جواب اِس کے سوا کچھ نہ تھا کہ انہوں نے کہا ``قتل کر دو اِسے یا جلا ڈالو اِس کو" آخر کار اللہ نے اسے آگ سے بچا لیا، یقیناً اس میں نشانیاں ہیں اُن لوگوں کے لیے جو ایمان لانے والے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmccclxv{اور اُس نے کہا ``تم نے دنیا کی زندگی میں تو اللہ کو چھوڑ کر بتوں کو اپنے درمیان محبت کا ذریعہ بنا لیا ہے مگر قیامت کے روز تم ایک دُوسرے کا انکار اور ایک دُوسرے پر لعنت کرو گے اور آگ تمہارا ٹھکانا ہو گی اور کوئی تمہارا مدد گار نہ ہو گا"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvi{اُس وقت لوطؑ نے اُس کو مانا اور ابراہیمؑ نے کہا میں اپنے رب کی طرف ہجرت کرتا ہوں، وہ زبردست ہے اور حکیم ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvii{اور ہم نے اسے اسحاقؑ اور یعقوبؑ (جیسی اولاد) عنایت فرمائی اور اس کی نسل میں نبوت اور کتاب رکھ دی، اور اسے دنیا میں اُس کا اجر عطا کیا اور آخرت میں وہ یقیناً صالحین میں سے ہو گا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmccclxviii{اور ہم نے لوطؑ کو بھیجا جبکہ اُس نے اپنی قوم سے کہا ``تم تو وہ فحش کام کرتے ہو جو تم سے پہلے دنیا والوں میں سے کسی نے نہیں کیا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmccclxix{کیا تمہارا حال یہ ہے کہ مَردوں کے پاس جاتے ہو، اور رہزنی کرتے ہو اور اپنی مجلسوں میں بُرے کام کرتے ہو؟" پھر کوئی جواب اس کی قوم کے پاس اس کے سوا نہ تھا کہ انہوں نے کہا ``لے آ اللہ کا عذاب اگر تو سچّا ہے"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmccclxx{لوطؑ نے کہا ``اے میرے رب، اِن مفسد لوگوں کے مقابلے میں میری مدد فرما"\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxi{اور جب ہمارے فرستادے ابراہیمؑ کے پاس بشارت لے کر پہنچے تو انہوں نے اُس سے کہا ``ہم اِس بستی کے لوگوں کو ہلاک کرنے والے ہیں، اس کے لوگ سخت ظالم ہو چکے ہیں"\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxii{ابراہیمؑ نے کہا ``وہاں تو لوطؑ موجود ہے" انہوں نے کہا ``ہم خوب جانتے ہیں کہ وہاں کون کون ہے ہم اُسے، اور اس کی بیوی کے سوا اس کے باقی گھر والوں کو بچا لیں گے" اس کی بیوی پیچھے رہ جانے والوں میں سے تھی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiii{پھر جب ہمارے فرستادے لوطؑ کے پاس پہنچے تو ان کی آمد پر وہ سخت پریشان اور دل تنگ ہوا اُنہوں نے کہا ``نہ ڈرو اور نہ رنج کرو ہم تمہیں اور تمہارے گھر والوں کو بچا لیں گے، سوائے تمہاری بیوی کے جو پیچھے رہ جانے والوں میں سے ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiv{ہم اس بستی کے لوگوں پر آسمان سے عذاب نازل کرنے والے ہیں اُس فسق کی بدولت جو یہ کرتے رہے ہیں"\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxv{اور ہم نے اُس بستی کی ایک کھُلی نشانی چھوڑ دی ہے اُن لوگوں کے لیے جو عقل سے کام لیتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvi{اور مَدیَن کی طرف ہم نے اُن کے بھائی شعیب کو بھیجا اُس نے کہا ``اے میری قوم کے لوگو، اللہ کی بندگی کرو اور روزِ آخر کے امیدوار رہو اور زمین میں مفسد بن کر زیادتیاں نہ کرتے پھرو"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvii{مگر انہوں نے اسے جھٹلا دیا آخر کار ایک سخت زلزلے نے انہیں آ لیا اور وہ اپنے گھروں میں پڑے کے پڑے رہ گئے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxviii{اور عاد و ثمود کو ہم نے ہلاک کیا، تم وہ مقامات دیکھ چکے ہو جہاں وہ رہتے تھے اُن کے اعمال کو شیطان نے اُن کے لیے خوشنما بنا دیا اور انہیں راہِ راست سے برگشتہ کر دیا حالانکہ وہ ہوش گوش رکھتے تھے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxix{اور قارون و فرعون و ہامان کو ہم نے ہلاک کیا موسیٰؑ اُن کے پاس بیّنات لے کر آیا مگر انہوں نے زمین میں اپنی بڑائی کا زعم کیا حالانکہ وہ سبقت لے جانے والے نہ تھے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxx{آخر کار ہر ایک کو ہم نے اس کے گناہ میں پکڑا، پھر ان میں سے کسی پر ہم نے پتھراؤ کرنے والی ہوا بھیجی، اور کسی کو ایک زبردست دھماکے نے آ لیا، اور کسی کو ہم نے زمین میں دھسا دیا، اور کسی کو غرق کر دیا اللہ اُن پر ظلم کرنے والا نہ تھا، مگر وہ خود ہی اپنے اوپر ظلم کر رہے تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxi{جن لوگوں نے اللہ کو چھوڑ کر دُوسرے سرپرست بنا لیے ہیں اُن کی مثال مکڑی جیسی ہے جو اپنا ایک گھر بناتی ہے اور سب گھروں سے زیادہ کمزور گھر مکڑی کا گھر ہی ہوتا ہے کاش یہ لوگ علم رکھتے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxii{یہ لوگ اللہ کو چھوڑ کر جس چیز کو بھی پکارتے ہیں اللہ اسے خوب جانتا ہے اور وہی زبردست اور حکیم ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiii{یہ مثالیں ہم لوگوں کی فہمائش کے لیے دیتے ہیں، مگر ان کو وہی لوگ سمجھتے ہیں جو علم رکھنے والے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiv{اللہ نے آسمانوں اور زمین کو برحق پیدا کیا ہے، در حقیقت اِس میں ایک نشانی ہے اہلِ ایمان کے لیے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxv{(اے نبیؐ) تلاوت کرو اس کتاب کی جو تمہاری طرف وحی کے ذریعہ سے بھیجی گئی ہے اور نماز قائم کرو، یقیناً نماز فحش اور بُرے کاموں سے روکتی ہے اور اللہ کا ذکر اس سے بھی زیادہ بڑی چیز ہے اللہ جانتا ہے جو کچھ تم لوگ کرتے ہو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvi{اور اہل کتاب سے بحث نہ کرو مگر عمدہ طریقہ سے، سوائے اُن لوگوں کے جو اُن میں سے ظالم ہوں، اور اُن سے کہو کہ ``ہم ایمان لائے ہیں اُس چیز پر بھی جو ہماری طرف بھیجی گئی ہے اور اُس چیز پر بھی جو تمہاری طرف بھیجی گئی تھی، ہمارا خدا اور تمہارا خدا ایک ہی ہے اور ہم اُسی کے مُسلم (فرماں بردار) ہیں"\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvii{(اے نبیؐ) ہم نے اِسی طرح تمہاری طرف کتاب نازل کی ہے، اس لیے وہ لوگ جن کو ہم نے پہلے کتاب دی تھی وہ اس پر ایمان لاتے ہیں، اور اِن لوگوں میں سے بھی بہت سے اس پر ایمان لا رہے ہیں، اور ہماری آیات کا انکار صرف کافر ہی کرتے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxviii{(اے نبیؐ) تم اس سے پہلے کوئی کتاب نہیں پڑھتے تھے اور نہ اپنے ہاتھ سے لکھتے تھے، اگر ایسا ہوتا تو باطل پرست لوگ شک میں پڑ سکتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxix{دراصل یہ روشن نشانیاں ہیں اُن لوگوں کے دلوں میں جنہیں عِلم بخشا گیا ہے، اور ہماری آیات کا انکار نہیں کرتے مگر وہ جو ظالم ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccxc{یہ لوگ کہتے ہیں کہ ``کیوں نہ اتاری گئی اس شخص پر نشانیاں اِس کے رب کی طرف سے؟" کہو، ``نشانیاں تو اللہ کے پاس ہیں اور میں صرف خبردار کرنے والا ہوں کھول کھول کر"\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcccxci{اور کیا اِن لوگوں کے لیے یہ (نشانی) کافی نہیں ہے کہ ہم نے تم پر کتاب نازل کی جو اِنہیں پڑھ کر سُنائی جاتی ہے؟ در حقیقت اِس میں رحمت ہے اور نصیحت ہے اُن لوگوں کے لیے جو ایمان لاتے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcii{(اے نبیؐ) کہو کہ ``میرے اور تمہارے درمیان اللہ گواہی کے لیے کافی ہے وہ آسمانوں اور زمین میں سب کچھ جانتا ہے جو لوگ باطل کو مانتے ہیں اور اللہ سے کفر کرتے ہیں وہی خسارے میں رہنے والے ہیں"\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciii{یہ لوگ تم سے عذاب جلدی لانے کا مطالبہ کرتے ہیں اگر ایک وقت مقرر نہ کر دیا گیا ہوتا تو ان پر عذاب آ چکا ہوتا اور یقیناً (اپنے وقت پر) وہ آ کر رہے گا اچانک، اس حال میں کہ انہیں خبر بھی نہ ہو گی\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciv{یہ تم سے عذاب جلدی لانے کا مطالبہ کرتے ہیں، حالانکہ جہنم ان کافروں کو گھیرے میں لے چکی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcv{(اور انہیں پتہ چلے گا) اُس روز جبکہ عذاب انہیں اُوپر سے بھی ڈھانک لے گا اور پاؤں کے نیچے سے بھی اور کہے گا کہ اب چکھو مزا ان کرتوتوں کا جو تم کرتے تھے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvi{اے میرے بندو جو ایمان لائے ہو، میری زمین وسیع ہے، پس تم میری بندگی بجا لاؤ\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvii{ہر متنفس کو موت کا مزا چکھنا ہے، پھر تم سب ہماری طرف ہی پلٹا کر لائے جاؤ گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcviii{جو لوگ ایمان لائے ہیں اور جنہوں نے نیک عمل کیے ہیں ان کو ہم جنت کی بلند و بالا عمارتوں میں رکھیں گے جن کے نیچے نہریں بہتی ہوں گی، وہاں وہ ہمیشہ رہیں گے، کیا ہی عمدہ اجر ہے عمل کرنے والوں کے لیے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcix{اُن لوگوں کے لیے جنہوں نے صبر کیا ہے اور جو اپنے رب پر بھروسہ کرتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcd{کتنے ہی جانور ہیں جو اپنا رزق اٹھائے نہیں پھرتے، اللہ اُن کو رزق دیتا ہے اور تمہارا رازق بھی وہی ہے، وہ سب کچھ سُنتا اور جانتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdi{اگر تم اِن لوگوں سے پُوچھو کہ زمین اور آسمانوں کو کس نے پیدا کیا ہے اور چاند اور سُورج کو کس نے مسخّر کر رکھا ہے تو ضرور کہیں گے کہ اللہ نے، پھر یہ کدھر سے دھوکا کھا رہے ہیں؟\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcdii{اللہ ہی ہے جو اپنے بندوں میں سے جس کا چاہتا ہے رزق کشادہ کرتا ہے اور جس کا چاہتا ہے تنگ کرتا ہے، یقیناً اللہ ہر چیز کا جاننے والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcdiii{اور اگر تم ان سے پوچھو کس نے آسمان سے پانی برسایا اور اِس کے ذریعہ سے مُردہ پڑی ہوئی زمین کو جِلا اٹھایا تو وہ ضرور کہیں گے اللہ نے کہو، الحمدللہ، مگر اکثر لوگ سمجھتے نہیں ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcdiv{اور یہ دنیا کی زندگی کچھ نہیں ہے مگر ایک کھیل اور دل کا بہلاوا اصل زندگی کا گھر تو دار آخرت ہے، کاش یہ لوگ جانتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcdv{جب یہ لوگ کشتی پر سوار ہوتے ہیں تو اپنے دین کو اللہ کے لیے خالص کر کے اُس سے دُعا مانگتے ہیں، پھر جب وہ اِنہیں بچا کر خشکی پر لے آتا ہے تو یکایک یہ شرک کرنے لگتے ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcdvi{تاکہ اللہ کی دی ہوئی نجات پر اس کا کفران نعمت کریں اور (حیات دنیا کے) مزے لوٹیں اچھا، عنقریب اِنہیں معلوم ہو جائے گا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcdvii{کیا یہ دیکھتے نہیں ہیں کہ ہم نے ایک پر امن حرم بنا دیا ہے حالانکہ اِن کے گرد و پیش لوگ اُچک لیے جاتے ہیں؟ کیا پھر بھی یہ لوگ باطل کو مانتے ہیں اور اللہ کی نعمت کا کفران کرتے ہیں؟\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcdviii{اُس شخص سے بڑا ظالم کون ہو گا جو اللہ پر جھوٹ باندھے یا حق کو جھُٹلائے جب کہ وہ اس کے سامنے آ چکا ہو؟ کیا ایسے کافروں کا ٹھکانہ جہنم ہی نہیں ہے؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcdix{جو لوگ ہماری خاطر مجاہدہ کریں گے انہیں ہم اپنے راستے دکھائیں گے، اور یقیناً اللہ نیکو کاروں ہی کے ساتھ ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcdx{\basmalahur ا ل م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdxi{رومی قریب کی سرزمین میں مغلوب ہو گئے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdxii{اور اپنی اِس مغلوبیت کے بعد چند سال کے اندر وہ غالب ہو جائیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiii{اللہ ہی کا اختیار ہے پہلے بھی اور بعد میں بھی اور وہ دن وہ ہو گا جبکہ اللہ کی بخشی ہوئی فتح پر مسلمان خوشیاں منائیں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiv{اللہ نصرت عطا فرماتا ہے جسے چاہتا ہے، اور وہ زبردست اور رحیم ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdxv{یہ وعدہ اللہ نے کیا ہے، اللہ کبھی اپنے وعدے کی خلاف ورزی نہیں کرتا، مگر اکثر لوگ نہیں جانتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvi{لوگ دُنیا کی زندگی کا بس ظاہری پہلو جانتے ہیں اور آخرت سے وہ خود ہی غافل ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvii{کیا انہوں نے کبھی اپنے آپ میں غور و فکر نہیں کیا؟ اللہ نے زمین اور آسمانوں کو اور اُن ساری چیزوں کو جو اُن کے درمیان ہیں برحق اور ایک مقرّر مدت ہی کے لیے پیدا کیا ہے مگر بہت سے لوگ اپنے رب کی ملاقات کے منکر ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdxviii{اور کیا یہ لوگ کبھی زمین میں چلے پھرے نہیں ہیں کہ اِنہیں اُن لوگوں کا انجام نظر آتا جو اِن سے پہلے گزر چکے ہیں؟ وہ اِن سے زیادہ طاقت رکھتے تھے، اُنہوں نے زمین کو خوب ادھیڑا تھا اور اُسے اتنا آباد کیا تھا جتنا اِنہوں نے نہیں کیا ہے اُن کے پاس ان کے رسول روشن نشانیاں لے کر آئے پھر اللہ ان پر ظلم کرنے والا نہ تھا، مگر وہ خود ہی اپنے اوپر ظلم کر رہے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdxix{آ خرکار جن لوگوں نے بُرائیاں کی تھیں ان کا انجام بہت برا ہوا، اس لیے کہ انہوں نے اللہ کی آیات کو جھٹلایا تھا اور وہ ان کا مذاق اڑاتے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdxx{اللہ ہی خلق کی ابتدا کرتا ہے، پھر وہی اس کا اعادہ کرے گا، پھر اسی کی طرف تم پلٹائے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxi{اور جب وہ ساعت برپا ہو گی اس دن مجرم ہَک دَک رہ جائیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxii{ان کے ٹھیرائے ہوئے شریکوں میں کوئی ان کا سفارشی نہ ہو گا اور وہ اپنے شریکوں کے منکر ہو جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiii{جس روز وہ ساعت برپا ہو گی، اس دن (سب انسان) الگ گروہوں میں بٹ جائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiv{جو لوگ ایمان لائے ہیں اور جنہوں نے نیک عمل کیے ہیں وہ ایک باغ میں شاداں و فرحاں رکھے جائیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxv{اور جنہوں نے کفر کیا ہے اور ہماری آیات کو اور آخرت کی ملاقات کو جھٹلایا ہے وہ عذاب میں حاضر رکھے جائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvi{پس تسبیح کرو اللہ کی جبکہ تم شام کرتے ہو اور جب صبح کرتے ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvii{آسمانوں اور زمین میں اُسی کے لیے حمد ہے اور (تسبیح کرو اس کی) تیسرے پہر اور جبکہ تم پر ظہر کا وقت آتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxviii{وہ زندہ میں سے مُردے کو نکالتا ہے اور مُردے میں سے زندہ کو نکالتا ہے اور زمین کو اس کی موت کے بعد زندگی بخشتا ہے اسی طرح تم لوگ بھی (حالت موت سے) نکال لیے جاؤ گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxix{اُس کی نشانیوں میں سے یہ ہے کہ اس نے تم کو مٹی سے پیدا کیا پھر یکایک تم بشر ہو کہ (زمین میں) پھیلتے چلے جا رہے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxx{اور اس کی نشانیوں میں سے یہ ہے کہ اس نے تمہارے لیے تمہاری ہی جنس سے بیویاں بنائیں تاکہ تم ان کے پاس سکون حاصل کرو اور تمہارے درمیان محبّت اور رحمت پیدا کر دی یقیناً اس میں بہت سی نشانیاں ہے اُن لوگوں کے لیے جو غور و فکر کرتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxi{اور اس کی نشانیوں میں سے آسمانوں اور زمین کی پیدائش، اور تمہاری زبانوں اور تمہارے رنگوں کا اختلاف ہے یقیناً اس میں بہت سی نشانیاں ہیں دانشمند لوگوں کے لیے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxii{اور اُس کی نشانیوں میں سے تمہارا رات اور دن کو سونا اور تمہارا اس کے فضل کو تلاش کرنا ہے یقیناً اِس میں بہت سی نشانیاں ہیں اُن لوگوں کے لیے جو (غور سے) سُنتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiii{اور اُس کی نشانیوں میں سے یہ ہے کہ وہ تمہیں بجلی کی چمک دکھاتا ہے خوف کے ساتھ بھی اور طمع کے ساتھ بھی اور آسمان سے پانی برساتا ہے، پھر اس کے ذریعہ سے زمین کو اس کی موت کے بعد زندگی بخشتا ہے یقیناً اِس میں بہت سی نشانیاں ہیں اُن لوگوں کے لیے جو عقل سے کام لیتے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiv{اور اُس کی نشانیوں میں سے یہ ہے کہ آسمان اور زمین اس کے حکم سے قائم ہیں پھر جونہی کہ اُس نے تمہیں زمین سے پکارا، بس ایک ہی پکار میں اچانک تم نکل آؤ گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxv{آسمانوں اور زمین میں جو بھی ہیں اُس کے بندے ہیں، سب کے سب اسی کے تابع فرمان ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvi{وہی ہے جو تخلیق کی ابتدا کرتا ہے، پھر وہی اس کا اعادہ کرے گا اور یہ اس کے لیے آسان تر ہے آسمانوں اور زمین میں اس کی صفت سب سے برتر ہے اور وہ زبردست اور حکیم ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvii{وہ تمہیں خود تمہاری اپنی ہی ذات سے ایک مثال دیتا ہے کیا تمہارے اُن غلاموں میں سے جو تمہاری ملکیت میں ہیں کچھ غلام ایسے بھی ہیں جو ہمارے دیے ہوئے مال و دولت میں تمہارے ساتھ برابر کے شریک ہوں اور تم اُن سے اُس طرح ڈرتے ہو جس طرح آپس میں اپنے ہمسروں سے ڈرتے ہو؟ اس طرح ہم آیات کھول کر پیش کرتے ہیں اُن لوگوں کے لیے جو عقل سے کام لیتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxviii{مگر یہ ظالم بے سمجھے بوجھے اپنے تخیلات کے پیچھے چل پڑے ہیں اب کون اُس شخص کو راستہ دکھا سکتا ہے جسے اللہ نے بھٹکا دیا ہو ایسے لوگوں کا تو کوئی مدد گار نہیں ہو سکتا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxix{پس (اے نبیؐ، اور نبیؐ کے پیروؤں) یک سُو ہو کر اپنا رُخ اِس دین کی سمت میں جما دو، قائم ہو جاؤ اُس فطرت پر جس پر اللہ تعالیٰ نے انسانوں کو پیدا کیا ہے، اللہ کی بنائی ہوئی ساخت بدلی نہیں جا سکتی، یہی بالکل راست اور درست دین ہے، مگر اکثر لوگ جانتے نہیں ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcdxl{(قائم ہو جاؤ اِس بات پر) اللہ کی طرف رجوع کرتے ہوئے، اور ڈرو اُس سے، اور نماز قائم کرو، اور نہ ہو جاؤ اُن مشرکین میں سے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcdxli{جنہوں نے اپنا اپنا دین الگ بنا لیا ہے اور گروہوں میں بٹ گئے ہیں، ہر ایک گروہ کے پاس جو کچھ ہے اسی میں وہ مگن ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlii{لوگوں کا حال یہ ہے کہ جب انہیں کوئی تکلیف پہنچتی ہے تو اپنے رب کی طرف رجوع کر کے اُسے پکارتے ہیں، پھر جب وہ کچھ اپنی رحمت کا ذائقہ انہیں چکھا دیتا ہے تو یکایک ان میں سے کچھ لوگ شرک کرنے لگتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliii{تاکہ ہمارے کیے ہوئے احسان کی ناشکری کریں اچھا، مزے کر لو، عنقریب تمہیں معلوم ہو جائے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliv{کیا ہم نے کوئی سند اور دلیل ان پر نازل کی ہے جو شہادت دیتی ہو اس شرک کی صداقت پر جو یہ کر رہے ہیں؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlv{جب ہم لوگوں کو رحمت کا ذائقہ چکھاتے ہیں تو وہ اس پر پھول جاتے ہیں، اور جب ان کے اپنے کیے کرتوتوں سے ان پر کوئی مصیبت آتی ہے تو یکایک وہ مایوس ہونے لگتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvi{کیا یہ لوگ دیکھتے نہیں ہیں کہ اللہ ہی رزق کشادہ کرتا ہے جس کا چاہتا ہے اور تنگ کرتا ہے (جس کا چاہتا ہے) یقیناً اس میں بہت سی نشانیاں ہیں اُن لوگوں کے لیے جو ایمان لاتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvii{پس (اے مومن) رشتہ دار کو اس کا حق دے اور مسکین و مسافر کو (اُس کا حق) یہ طریقہ بہتر ہے اُن لوگوں کے لیے جو اللہ کی خوشنودی چاہتے ہوں، اور وہی فلاح پانے والے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlviii{جو سُود تم دیتے ہو تاکہ لوگوں کے اموال میں شامل ہو کر وہ بڑھ جائے، اللہ کے نزدیک وہ نہیں بڑھتا، اور جو زکوٰۃ تم اللہ کی خوشنودی حاصل کرنے کے ارادے سے دیتے ہو، اسی کے دینے والے در حقیقت اپنے مال بڑھاتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlix{اللہ ہی ہے جس نے تم کو پیدا کیا، پھر تمہیں رزق دیا، پھر وہ تمہیں موت دیتا ہے، پھر وہ تمہیں زندہ کرے گا کیا تمہارے ٹھیرائے ہوئے شریکوں میں کوئی ایسا ہے جو ان میں سے کوئی کام بھی کرتا ہو؟ پاک ہے وہ اور بہت بالا و برتر ہے اُس شرک سے جو یہ لوگ کرتے ہیں؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcdl{خشکی اور تری میں فساد برپا ہو گیا ہے لوگوں کے اپنے ہاتھوں کی کمائی سے تاکہ مزا چکھائے اُن کو ان کے بعض اعمال کا، شاید کہ وہ باز آئیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcdli{(اے نبیؐ) اِن سے کہو کہ زمین میں چل پھر کر دیکھو پہلے گزرے ہوئے لوگوں کا کیا انجام ہو چکا ہے، ان میں سے اکثر مشرک ہی تھے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmcdlii{پس (اے نبیؐ) اپنا رُخ مضبوطی کے ساتھ جما دو اِس دین راست کی سمت میں قبل اس کے کہ وہ دن آئے جس کے ٹل جانے کی کوئی صورت اللہ کی طرف سے نہیں ہے اُس دن لوگ پھَٹ کر ایک دُوسرے سے الگ ہو جائیں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcdliii{جس نے کفر کیا ہے اس کے کفر کا وبال اسی پر ہے اور جن لوگوں نے نیک عمل کیا ہے وہ اپنے ہی لیے فلاح کا راستہ صاف کر رہے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcdliv{تاکہ اللہ ایمان لانے والوں اور عملِ صالح کرنے والوں کو اپنے فضل سے جزا دے یقیناً وہ کافروں کو پسند نہیں کرتا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmcdlv{اُس کی نشانیوں میں سے یہ ہے کہ وہ ہوائیں بھیجتا ہے بشارت دینے کے لیے اور تمہیں اپنی رحمت سے بہرہ مند کرنے کے لیے اور اس غرض کے لیے کہ کشتیاں اس کے حکم سے چلیں اور تم اس کا فضل تلاش کرو اور اس کے شکر گزار بنو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvi{اور ہم نے تم سے پہلے رسُولوں کو ان کی قوم کی طرف بھیجا اور وہ ان کے پاس روشن نشانیاں لے کر آئے، پھر جنہوں نے جرم کیا اُن سے ہم نے انتقام لیا اور ہم پر یہ حق تھا کہ ہم مومنوں کی مدد کریں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvii{اللہ ہی ہے جو ہواؤں کو بھیجتا ہے اور وہ بادل اٹھاتی ہیں، پھر وہ اِن بادلوں کو آسمان میں پھیلا دیتا ہے جس طرح چاہتا ہے اور انہیں ٹکڑیوں میں تقسیم کرتا ہے، پھر تُو دیکھتا ہے کہ بارش کے قطرے بادل سے ٹپکے چلے آتے ہیں یہ بارش جب وہ اپنے بندوں میں سے جن پر چاہتا ہے برساتا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmcdlviii{تو یکایک وہ خوش و خرم ہو جاتے ہیں حالانکہ اس کے نزول سے پہلے وہ مایوس ہو رہے تھے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcdlix{دیکھو اللہ کی رحمت کے اثرات کہ مُردہ پڑی ہوئی زمین کو وہ کس طرح جِلا اٹھاتا ہے، یقیناً وہ مُردوں کو زندگی بخشنے والا ہے اور وہ ہر چیز پر قادر ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcdlx{اور اگر ہم ایک ایسی ہوا بھیج دیں جس کے اثر سے وہ اپنی کھیتی کو زرد پائیں تو وہ کفر کرتے رہ جاتے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxi{(اے نبیؐ) تم مُردوں کو نہیں سنا سکتے، نہ اُن بہروں کو اپنی پکار سنا سکتے ہو جو پیٹھ پھیرے بھاگے چلے جا رہے ہوں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxii{اور نہ تم اندھوں کو ان کی گمراہی سے نکال کر راہِ راست دکھا سکتے ہو تم تو صرف انہی کو سنا سکتے ہو جو ہماری آیات پر ایمان لاتے اور سرِ تسلیم خم کر دیتے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiii{اللہ ہی تو ہے جس نے ضعف کی حالت میں تمہاری پیدائش کی ابتدا کی، پھر اس ضعف کے بعد تمہیں قوت بخشی، پھر اس قوت کے بعد تمہیں ضعیف اور بوڑھا کر دیا وہ جو کچھ چاہتا ہے پیدا کرتا ہے اور وہ سب کچھ جاننے والا، ہر چیز پر قدرت رکھنے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiv{اور جب وہ ساعت برپا ہو گی تو مجرم قسمیں کھا کھا کر کہیں گے کہ ہم ایک گھڑی بھر سے زیادہ نہیں ٹھیرے ہیں، اِسی طرح وہ دنیا کی زندگی میں دھوکا کھایا کرتے تھے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxv{مگر جو علم اور ایمان سے بہرہ مند کیے گئے تھے وہ کہیں گے کہ خدا کے نوشتے میں تو تم روزِ حشر تک پڑے رہے ہو، سو یہ وہی روزِ حشر ہے، لیکن تم جانتے نہ تھے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvi{پس وہ دن ہو گا جس میں ظالموں کو ان کی معذرت کوئی نفع نہ دے گی اور نہ ان سے معافی مانگنے کے لیے کہا جائے گا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvii{ہم نے اِس قرآن میں لوگوں کو طرح طرح سے سمجھایا ہے تم خواہ کوئی نشانی لے آؤ، جن لوگوں نے ماننے سے انکار کر دیا ہے وہ یہی کہیں گے کہ تم باطل پر ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxviii{اِس طرح ٹھپہ لگا دیتا ہے اللہ اُن لوگوں کے دلوں پر جو بے علم ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxix{پس (اے نبیؐ) صبر کرو، یقیناً اللہ کا وعدہ سچا ہے، اور ہرگز ہلکا نہ پائیں تم کو وہ لوگ جو یقین نہیں لاتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxx{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxi{یہ کتاب حکیم کی آیات ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxii{ہدایت اور رحمت نیکو کار لوگوں کے لیے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiii{جو نماز قائم کرتے ہیں، زکوٰۃ دیتے ہیں اور آخرت پر یقین رکھتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiv{یہی لوگ اپنے رب کی طرف سے راہِ راست پر ہیں اور یہی فلاح پانے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxv{اور انسانوں ہی میں سے کوئی ایسا بھی ہے جو کلام دلفریب خرید کر لاتا ہے تاکہ لوگوں کو اللہ کے راستہ سے علم کے بغیر بھٹکا دے اور اس راستے کی دعوت کو مذاق میں اڑا دے ایسے لوگوں کے لیے سخت ذلیل کرنے والا عذاب ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvi{اسے جب ہماری آیات سنائی جاتی ہیں تو وہ بڑے گھمنڈ کے ساتھ اس طرح رخ پھیر لیتا ہے گویا کہ اس نے انہیں سنا ہی نہیں، گویا کہ اس کے کان بہرے ہیں اچھا، مژدہ سُنا دو اسے ایک درد ناک عذاب کا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvii{البتہ جو لوگ ایمان لے آئیں اور نیک عمل کریں، اُن کے لیے نعمت بھری جنتیں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxviii{جن میں وہ ہمیشہ رہیں گے یہ اللہ کا پختہ وعدہ ہے اور وہ زبردست اور حکیم ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxix{اس نے آسمانوں کو پیدا کیا بغیر ستونوں کے جو تم کو نظر آئیں اُس نے زمین میں پہاڑ جما دیے تاکہ وہ تمہیں لے کر ڈھلک نہ جائے اس نے ہر طرح کے جانور زمین میں پھیلا دیے اور آسمان سے پانی برسایا اور زمین میں قسم قسم کی عمدہ چیزیں اگا دیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxx{یہ تو ہے اللہ کی تخلیق، اب ذرا مجھے دکھاؤ، ان دوسروں نے کیا پیدا کیا ہے؟ اصل بات یہ ہے کہ یہ ظالم لوگ صریح گمراہی میں پڑے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxi{ہم نے لقمان کو حکمت عطا کی تھی کہ اللہ کا شکر گزار ہو جو کوئی شکر کرے اُس کا شکر اُس کے اپنے ہی لیے مفید ہے اور جو کوئی کفر کرے تو حقیقت میں اللہ بے نیاز اور آپ سے آپ محمود ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxii{یاد کرو جب لقمان اپنے بیٹے کو نصیحت کر رہا تھا تو اس نے کہا ``بیٹا! خدا کے ساتھ کسی کو شریک نہ کرنا، حق یہ ہے کہ شرک بہت بڑا ظلم ہے"\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiii{اور حقیقت یہ ہے کہ ہم نے انسان کو اپنے والدین کا حق پہچاننے کی خود تاکید کی ہے اُس کی ماں نے ضعف پر ضعف اُٹھا کر اسے اپنے پیٹ میں رکھا اور دو سال اُس کا دودھ چھوٹنے میں لگے (اِسی لیے ہم نے اُس کو نصیحت کی کہ) میرا شکر کر اور اپنے والدین کا شکر بجا لا، میری ہی طرف تجھے پلٹنا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiv{لیکن اگر وہ تجھ پر دباؤ ڈالیں کہ میرے ساتھ تو کسی ایسے کو شریک کرے جسے تو نہیں جانتا تو ان کی بات ہرگز نہ مان دُنیا میں ان کے ساتھ نیک برتاؤ کرتا رہ مگر پیروی اُس شخص کے راستے کی کر جس نے میری طرف رجوع کیا ہے پھر تم سب کو پلٹنا میری ہی طرف ہے، اُس وقت میں تمہیں بتا دوں گا کہ تم کیسے عمل کرتے رہے ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxv{(اور لقمان نے کہا تھا کہ) ``بیٹا، کوئی چیز رائی کے دانہ برابر بھی ہو اور کسی چٹان میں یا آسمانوں یا زمین میں کہیں چھپی ہوئی ہو، اللہ اُسے نکال لائے گا وہ باریک بیں اور باخبر ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvi{بیٹا، نماز قائم کرنے کا حکم دے، بدی سے منع کر، اور جو مصیبت بھی پڑے اس پر صبر کر یہ وہ باتیں ہیں جن کی بڑی تاکید کی گئی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvii{اور لوگوں سے منہ پھیر کر بات نہ کر، نہ زمین میں اکڑ کر چل، اللہ کسی خود پسند اور فخر جتانے والے شخص کو پسند نہیں کرتا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxviii{اپنی چال میں اعتدال اختیار کر، اور اپنی آواز ذرا پست رکھ، سب آوازوں سے زیادہ بُری آواز گدھوں کی آواز ہوتی ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxix{کیا تم لوگ نہیں دیکھتے کہ اللہ نے زمین اور آسمانوں کی ساری چیزیں تمہارے لیے مسخر کر رکھی ہیں اور اپنی کھلی اور چھپی نعمتیں تم پر تمام کر دی ہیں؟ اِس پر حال یہ ہے کہ انسانوں میں سے کچھ لوگ ہیں جو اللہ کے بارے میں جھگڑتے ہیں بغیر اس کے کہ ان کے پاس کوئی عِلم ہو، یا ہدایت، یا کوئی روشنی دکھانے والی کتاب\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxc{اور جب ان سے کہا جاتا ہے کہ پیروی کرو اُس چیز کی جو اللہ نے نازل کی ہے تو کہتے ہیں کہ ہم تو اُس چیز کی پیروی کریں گے جس پر ہم نے اپنے باپ دادا کو پایا ہے کیا یہ انہی کی پیروی کریں گے خواہ شیطان اُن کو بھڑکتی ہوئی آگ ہی کی طرف کیوں نہ بلاتا رہا ہو؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxci{جو شخص اپنے آپ کو اللہ کے حوالہ کر دے اور عملاً وہ نیک ہو، اس نے فی الواقع ایک بھروسے کے قابل سہارا تھام لیا، اور سارے معاملات کا آخری فیصلہ اللہ ہی کے ہاتھ ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcii{اب جو کفر کرتا ہے اس کا کفر تمہیں غم میں مبتلا نہ کرے، انہیں پلٹ کر آنا تو ہماری ہی طرف ہے، پھر ہم انہیں بتا دیں گے کہ وہ کیا کچھ کر کے آئے ہیں یقیناً اللہ سینوں کے چھپے ہوئے راز تک جانتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciii{ہم تھوڑی مدت انہیں دُنیا میں مزے کرنے کا موقع دے رہے ہیں، پھر ان کو بے بس کر کے ایک سخت عذاب کی طرف کھینچ لے جائیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciv{اگر تم اِن سے پوچھو کہ زمین اور آسمانوں کو کس نے پیدا کیا ہے، تو یہ ضرور کہیں گے کہ اللہ نے کہو الحمدللہ مگر ان میں سے اکثر لوگ جانتے نہیں ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcv{آسمانوں اور زمین میں جو کچھ ہے اللہ ہی کا ہے، بے شک اللہ بے نیاز اور آپ سے آپ محمود ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvi{زمین میں جتنے درخت ہیں اگر وہ سب کے سب قلم بن جائیں اور سمندر (دوات بن جائے) جسے سات مزید سمندر روشنائی مہیا کریں تب بھی اللہ کی باتیں (لکھنے سے) ختم نہ ہوں گی بے شک اللہ زبردست اور حکیم ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvii{تم سارے انسانوں کو پیدا کرنا اور پھر دوبارہ جِلا اُٹھانا تو (اُس کے لیے) بس ایسا ہے جیسے ایک متنفس کو (پیدا کرنا اور جِلا اٹھانا) حقیقت یہ ہے کہ اللہ سب کچھ سُننے اور دیکھنے والا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcviii{کیا تم دیکھتے نہیں ہو کہ اللہ رات کو دن میں پروتا ہوا لے آتا ہے اور دن کو رات میں؟ اُس نے سُورج اور چاند کو مسخر کر رکھا ہے، سب ایک وقت مقرر تک چلے جا رہے ہیں، اور (کیا تم نہیں جانتے) کہ جو کچھ بھی تم کرتے ہو اللہ اُس سے باخبر ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcix{یہ سب کچھ اس وجہ سے ہے کہ اللہ ہی حق ہے اور اسے چھوڑ کر جن دُوسری چیزوں کو یہ لوگ پکارتے ہیں وہ سب باطل ہیں، اور (اس وجہ سے کہ) اللہ ہی بزرگ و برتر ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmd{کیا تم دیکھتے نہیں ہو کہ کشتی سمندر میں اللہ کے فضل سے چلتی ہے تاکہ وہ تمہیں اپنی کچھ نشانیاں دکھائے؟ در حقیقت اس میں بہت سی نشانیاں ہیں ہر اُس شخص کے لیے جو صبر اور شکر کرنے والا ہو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdi{اور جب (سمندر میں) اِن لوگوں پر ایک موج سائبانوں کی طرح چھا جاتی ہے تو یہ اللہ کو پکارتے ہیں اپنے دین کو بالکل اسی کے لیے خالص کر کے، پھر جب وہ بچا کر انہیں خشکی تک پہنچا دیتا ہے تو ان میں سے کوئی اقتصاد برتتا ہے، اور ہماری نشانیوں کا انکار نہیں کرتا مگر ہر وہ شخص جو غدّار اور ناشکرا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdii{لوگو، بچو اپنے رب کے غضب سے اور ڈرو اُس دن سے جبکہ کوئی باپ اپنے بیٹے کی طرف سے بدلہ نہ دے گا اور نہ کوئی بیٹا ہی اپنے باپ کی طرف سے کچھ بدلہ دینے والا ہوگا فی الواقع اللہ کا وعدہ سچا ہے پس یہ دنیا کی زندگی تمہیں دھوکے میں نہ ڈالے اور نہ دھوکہ باز تم کو اللہ کے معاملے میں دھوکا دینے پائے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdiii{اُس گھڑی کا علم اللہ ہی کے پاس ہے، وہی بارش برساتا ہے، وہی جانتا ہے کہ ماؤں کے پیٹوں میں کیا پرورش پا رہا ہے، کوئی متنفس نہیں جانتا کہ کل وہ کیا کمائی کرنے والا ہے اور نہ کسی شخص کو یہ خبر ہے کہ کس سرزمین میں اس کی موت آنی ہے، اللہ ہی سب کچھ جاننے والا اور باخبر ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdiv{\basmalahur ا ل م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdv{اِس کتاب کی تنزیل بلا شبہ رب العالمین کی طرف سے ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdvi{کیا یہ لوگ کہتے ہیں کہ اس شخص نے اِسے خود گھڑ لیا ہے؟ نہیں، بلکہ یہ حق ہے تیرے رب کی طرف سے تاکہ تو متنبہ کرے ایک ایسی قوم کو جس کے پاس تجھ سے پہلے کوئی متنبہ کرنے والا نہیں آیا، شاید کہ وہ ہدایت پا جائیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdvii{وہ اللہ ہی ہے جس نے آسمانوں اور زمین کو اور اُن ساری چیزوں کو جو ان کے درمیان ہیں چھ دنوں میں پیدا کیا اور اس کے بعد عرش پر جلوہ فرما ہوا، اُس کے سوا نہ تمہارا کوئی حامی و مدد گار ہے اور نہ کوئی اُس کے آگے سفارش کرنے والا، پھر کیا تم ہوش میں نہ آؤ گے؟\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdviii{وہ آسمان سے زمین تک دُنیا کے معاملات کی تدبیر کرتا ہے اور اس تدبیر کی روداد اُوپر اُس کے حضور جاتی ہے ایک ایسے دن میں جس کی مقدار تمہارے شمار سے ایک ہزار سال ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdix{وہی ہے ہر پوشیدہ اور ظاہر کا جاننے والا، زبردست، اور رحیم\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdx{جو چیز بھی اس نے بنائی خوب ہی بنائی اُ س نے انسان کی تخلیق کی ابتدا گارے سے کی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxi{پھر اُس کی نسل ایک ایسے ست سے چلائی جو حقیر پانی کی طرح کا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxii{پھر اس کو نِک سُک سے درست کیا اور اس کے اندر اپنی روح پھونک دی، اور تم کو کان دیے، آنکھیں دیں اور دِل دیے تم لوگ کم ہی شکر گزار ہوتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxiii{اور یہ لوگ کہتے ہیں: ``جب ہم مٹی میں رَل مِل چکے ہوں گے تو کیا ہم پھر نئے سرے سے پیدا کیے جائیں گے؟" اصل بات یہ ہے کہ یہ اپنے رب کی ملاقات کے منکر ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxiv{اِن سے کہو ``موت کا وہ فرشتہ جو تم پر مقرر کیا گیا ہے تم کو پورا کا پورا اپنے قبضے میں لے لے گا اور پھر تم اپنے رب کی طرف پلٹا لائے جاؤ گے"\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxv{کاش تم دیکھو وہ وقت جب یہ مجرم سر جھکائے اپنے رب کے حضور کھڑے ہوں گے (اُس وقت یہ کہہ رہے ہوں گے) ``اے ہمارے رب، ہم نے خوب دیکھ لیا اور سُن لیا اب ہمیں واپس بھیج دے تاکہ ہم نیک عمل کریں، ہمیں اب یقین آگیا ہے"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxvi{(جواب میں ارشاد ہو گا) ``اگر ہم چاہتے تو پہلے ہی ہر نفس کو اس کی ہدایت دے دیتے مگر میری وہ بات پُوری ہو گئی جو میں نے کہی تھی کہ میں جہنّم کو جنوں اور انسانوں سب سے بھر دوں گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxvii{پس اب چکھو مزا اپنی اِس حرکت کا کہ تم نے اس دن کی ملاقات کو فراموش کر دیا، ہم نے بھی اب تمہیں فراموش کر دیا ہے چکھو ہمیشگی کے عذاب کا مزا اپنے کرتوتوں کی پاداش میں"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxviii{ہماری آیات پر تو وہ لوگ ایمان لاتے ہیں جنہیں یہ آیات سنا کر جب نصیحت کی جاتی ہے تو سجدے میں گر پڑتے ہیں اور اپنے رب کی حمد کے ساتھ اس کی تسبیح کرتے ہیں اور تکبر نہیں کرتے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxix{اُن کی پیٹھیں بستروں سے الگ رہتی ہیں، اپنے رب کو خوف اور طمع کے ساتھ پکارتے ہیں، اور جو کچھ رزق ہم نے اُنہیں دیا ہے اس میں سے خرچ کرتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdxx{پھر جیسا کچھ آنکھوں کی ٹھنڈک کا سامان ان کے اعمال کی جزا میں ان کے لیے چھپا رکھا گیا ہے اس کی کسی متنفس کو خبر نہیں ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdxxi{بھلا کہیں یہ ہو سکتا ہے کہ جو شخص مومن ہو وہ اُس شخص کی طرح ہو جائے جو فاسق ہو؟ یہ دونوں برابر نہیں ہو سکتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdxxii{جو لوگ ایمان لائے ہیں اور جنہوں نے نیک عمل کیے ہیں اُن کے لیے تو جنتوں کی قیام گاہیں ہیں، ضیافت کے طور پر اُن کے اعمال کے بدلے میں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiii{اور جنہوں نے فسق اختیار کیا ہے اُن کا ٹھکانا دوزخ ہے جب کبھی وہ اس سے نکلنا چاہیں گے اسی میں دھکیل دیے جائیں گے اور ان سے کہا جائے گا کہ چکھو اب اُسی آگ کے عذاب کا مزا جس کو تم جھٹلایا کرتے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiv{اُس بڑے عذاب سے پہلے ہم اِسی دنیا میں (کسی نہ کسی چھوٹے) عذاب کا مزا اِنہیں چکھاتے رہیں گے، شاید کہ یہ (اپنی باغیانہ روش سے) باز آ جائیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdxxv{اور اُس سے بڑا ظالم کون ہو گا جسے اس کے رب کی آیات کے ذریعہ سے نصیحت کی جائے اور پھر وہ ان سے منہ پھیر لے ایسے مجرموں سے تو ہم انتقام لے کر رہیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvi{اِس سے پہلے ہم موسیٰؑ کو کتاب دے چکے ہیں، لہٰذا اُسی چیز کے ملنے پر تمہیں کوئی شک نہ ہونا چاہیے اُس کتاب کو ہم نے بنی اسرائیل کے لیے ہدایت بنایا تھا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvii{اور جب انہوں نے صبر کیا اور ہماری آیات پر یقین لاتے رہے تو ان کے اندر ہم نے ایسے پیشوا پیدا کیے جو ہمارے حکم سے رہنمائی کرتے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdxxviii{یقیناً تیرا رب ہی قیامت کے روز اُن باتوں کا فیصلہ کرے گا جن میں (بنی اسرائیل) باہم اختلاف کرتے رہے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdxxix{اور کیا اِن لوگوں کو (اِن تاریخی واقعات میں) کوئی ہدایت نہیں ملی کہ ان سے پہلے کتنی قوموں کو ہم ہلاک کر چکے ہیں جن کے رہنے کی جگہوں میں آج یہ چلتے پھرتے ہیں؟ اس میں بڑی نشانیاں ہیں، کیا یہ سنتے نہیں ہیں؟\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdxxx{اور کیا اِن لوگوں نے یہ منظر کبھی نہیں دیکھا کہ ہم ایک بے آب و گیاہ زمین کی طرف پانی بہا لاتے ہیں، اور پھر اسی زمین سے وہ فصل اُگاتے ہیں جس سے ان کے جانوروں کو بھی چارہ ملتا ہے اور یہ خود بھی کھاتے ہیں؟ تو کیا انہیں کچھ نہیں سوجھتا؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxi{یہ لوگ کہتے ہیں کہ ``یہ فیصلہ کب ہو گا اگر تم سچے ہو؟"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxii{ان سے کہو ``فیصلے کے دن ایمان لانا اُن لوگوں کے لیے کچھ بھی نافع نہ ہو گا جنہوں نے کفر کیا ہے اور پھر اُن کو کوئی مہلت نہ ملے گی"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiii{اچھا، اِنہیں ان کے حال پر چھوڑ دو اور انتظار کرو، یہ بھی منتظر ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiv{\basmalahur اے نبیؐ! اللہ سے ڈرو اور کفار و منافقین کی اطاعت نہ کرو، حقیقت میں علیم اور حکیم تو اللہ ہی ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxv{پیروی کرو اُس بات کی جس کا اشارہ تمہارے رب کی طرف سے تمہیں کیا جا رہا ہے، اللہ ہر اُس بات سے باخبر ہے جو تم لوگ کرتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvi{اللہ پر توکل کرو، اللہ ہی وکیل ہونے کے لیے کافی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvii{اللہ نے کسی شخص کے دھڑ میں دو دِل نہیں رکھے ہیں، نہ اس نے تم لوگوں کی اُن بیویوں کو جن سے تم ظہار کرتے ہو تمہاری ماں بنا دیا ہے، اور نہ اس نے تمہارے منہ بولے بیٹوں کو تمہارا حقیقی بیٹا بنایا ہے یہ تو وہ باتیں ہیں جو تم لوگ اپنے منہ سے نکال دیتے ہو، مگر اللہ وہ بات کہتا ہے جو مبنی بر حقیقت ہے، اور وہی صحیح طریقے کی طرف رہنمائی کرتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxviii{منہ بولے بیٹوں کو ان کے باپوں کی نسبت سے پکارو، یہ اللہ کے نزدیک زیادہ منصفانہ بات ہے اور اگر تمہیں معلوم نہ ہو کہ ان کے باپ کون ہیں تو وہ تمہارے دینی بھائی اور رفیق ہیں نا دانستہ جو بات تم کہو اس کے لیے تم پر کوئی گرفت نہیں ہے، لیکن اُس بات پر ضرور گرفت ہے جس کا تم دل سے ارادہ کرو اللہ درگزر کرنے والا اور رحیم ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxix{بلاشبہ نبی تو اہل ایمان کے لیے اُن کی اپنی ذات پر مقدم ہے، اور نبی کی بیویاں اُن کی مائیں ہیں، مگر کتاب اللہ کی رو سے عام مومنین و مہاجرین کی بہ نسبت رشتہ دار ایک دوسرے کے زیادہ حقدار ہیں، البتہ اپنے رفیقوں کے ساتھ تم کوئی بھلائی (کرنا چاہو تو) کر سکتے ہو یہ حکم کتاب الٰہی میں لکھا ہوا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdxl{اور (اے نبیؐ) یاد رکھو اُس عہد و پیمان کو جو ہم نے سب پیغمبروں سے لیا ہے، تم سے بھی اور نوحؑ اور ابراہیمؑ اور موسیٰؑ اور عیسیٰؑ ابن مریم سے بھی سب سے ہم پختہ عہد لے چکے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxli{تاکہ سچے لوگوں سے (ان کا رب) ان کی سچائی کے بارے میں سوال کرے، اور کافروں کے لیے تو اس نے درد ناک عذاب مہیا کر ہی رکھا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxlii{اے لوگو، جو ایمان لائے ہو، یاد کرو اللہ کے احسان کو جو (ابھی ابھی) اُس نے تم پر کیا ہے جب لشکر تم پر چڑھ آئے تو ہم نے اُن پر ایک سخت آندھی بھیج دی اور ایسی فوجیں روانہ کیں جو تم کو نظر نہ آتی تھیں اللہ وہ سب کچھ دیکھ رہا تھا جو تم لوگ اس وقت کر رہے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxliii{جب وہ اُوپر سے اور نیچے سے تم پر چڑھ آئے جب خوف کے مارے آنکھیں پتھرا گئیں، کلیجے منہ کو آ گئے، اور تم لوگ اللہ کے بارے میں طرح طرح کے گمان کرنے لگے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxliv{اُس وقت ایمان لانے والے خوب آزمائے گئے اور بُری طرح ہلا مارے گئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxlv{یاد کرو وہ وقت جب منافقین اور وہ سب لوگ جن کے دلوں میں روگ تھا صاف صاف کہہ رہے تھے کہ اللہ اور اُس کے رسولؐ نے جو وعدے ہم سے کیے تھے وہ فریب کے سوا کچھ نہ تھے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvi{جب اُن میں سے ایک گروہ نے کہا کہ ``اے یثرب کے لوگو، تمہارے لیے اب ٹھیرنے کا کوئی موقع نہیں ہے، پلٹ چلو" جب ان کا ایک فریق یہ کہہ کر نبیؐ سے رخصت طلب کر رہا تھا کہ ``ہمارے گھر خطرے میں ہیں،" حالانکہ وہ خطرے میں نہ تھے، دراصل وہ (محاذ جنگ سے) بھاگنا چاہتے تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvii{اگر شہر کے اطراف سے دشمن گھس آئے ہوتے اور اُس وقت انہیں فتنے کی طرف دعوت دی جاتی تو یہ اس میں جا پڑتے اور مشکل ہی سے انہیں شریک فتنہ ہونے میں کوئی تامل ہوتا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxlviii{ان لوگوں نے اس سے پہلے اللہ سے عہد کیا تھا کہ یہ پیٹھ نہ پھیریں گے، اور اللہ سے کیے ہوئے عہد کی باز پرس تو ہونی ہی تھی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxlix{اے نبیؐ! ان سے کہو، اگر تم موت یا قتل سے بھاگو تو یہ بھاگنا تمہارے لیے کچھ بھی نفع بخش نہ ہو گا اس کے بعد زندگی کے مزے لوٹنے کا تھوڑا ہی موقع تمہیں مل سکے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdl{اِن سے کہو، کون ہے جو تمہیں اللہ سے بچا سکتا ہو اگر وہ تمہیں نقصان پہنچانا چاہے؟ اور کون اس کی رحمت کو روک سکتا ہے اگر وہ تم پر مہربانی کرنا چاہے؟ اللہ کے مقابلے میں تو یہ لوگ کوئی حامی و مدد گار نہیں پا سکتے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdli{اللہ تم میں سے اُن لوگوں کو خوب جانتا ہے جو (جنگ کے کام میں) رکاوٹیں ڈالنے والے ہیں، جو اپنے بھائیوں سے کہتے ہیں کہ ``آؤ ہماری طرف" جو لڑائی میں حصہ لیتے بھی ہیں تو بس نام گنانے کو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdlii{جو تمہارا ساتھ دینے میں سخت بخیل ہیں خطرے کا وقت آ جائے تو اس طرح دیدے پھرا پھرا کر تمہاری طرف دیکھتے ہیں جیسے کسی مرنے والے پر غشی طاری ہو رہی ہو، مگر جب خطرہ گزر جاتا ہے تو یہی لوگ فائدوں کے حریص بن کر قینچی کی طرح چلتی ہوئی زبانیں لیے تمہارے استقبال کو آ جاتے ہیں یہ لوگ ہرگز ایمان نہیں لائے، اسی لیے اللہ نے ان کے سارے اعمال ضائع کر دیے اور ایسا کرنا اللہ کے لیے بہت آسان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdliii{یہ سمجھ رہے ہیں کہ حملہ آور گروہ ابھی گئے نہیں ہیں اور اگر وہ پھر حملہ آور ہو جائیں تو ان کا جی چاہتا ہے کہ اُس موقع پر یہ کہیں صحرا میں بدوؤں کے درمیان جا بیٹھیں اور وہیں سے تمہارے حالات پوچھتے رہیں تاہم اگر یہ تمہارے درمیان رہے بھی تو لڑائی میں کم ہی حصہ لیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdliv{در حقیقت تم لوگوں کے لیے اللہ کے رسولؐ میں ایک بہترین نمونہ تھا، ہر اُس شخص کے لیے جو اللہ اور یوم آخر کا امیدوار ہو اور کثرت سے اللہ کو یاد کرے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdlv{اور سچے مومنوں (کا حال اُس وقت یہ تھا کہ) جب انہوں نے حملہ آور لشکروں کو دیکھا تو پکار اٹھے کہ ``یہ وہی چیز ہے جس کا اللہ اور اس کے رسول نے ہم سے وعدہ کیا تھا، اللہ اور اُس کے رسولؐ کی بات بالکل سچّی تھی" اِس واقعہ نے اُن کے ایمان اور ان کی سپردگی کو اور زیادہ بڑھا دیا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdlvi{ایمان لانے والوں میں ایسے لوگ موجود ہیں جنہوں نے اللہ سے کیے ہوئے عہد کو سچا کر دکھایا ہے ان میں سے کوئی اپنی نذر پوری کر چکا اور کوئی وقت آنے کا منتظر ہے انہوں نے اپنے رویے میں کوئی تبدیلی نہیں کی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdlvii{(یہ سب کچھ اس لیے ہوا) تاکہ اللہ سچوں کو اُن کی سچائی کی جزا دے اور منافقوں کو چاہے تو سزا دے اور چاہے تو ان کی توبہ قبول کر لے، بے شک اللہ غفور و رحیم ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdlviii{اللہ نے کفار کا منہ پھیر دیا، وہ کوئی فائدہ حاصل کیے بغیر اپنے دل کی جلن لیے یونہی پلٹ گئے، اور مومنین کی طرف سے اللہ ہی لڑنے کے لیے کافی ہو گیا، اللہ بڑی قوت والا اور زبردست ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdlix{پھر اہل کتاب میں سے جن لوگوں نے ان حملہ آوروں کا ساتھ دیا تھا، اللہ ان کی گڑھیوں سے انہیں اتار لایا اور اُن کے دلوں میں اُس نے ایسا رُعب ڈال دیا کہ آج ان میں سے ایک گروہ کو تم قتل کر رہے ہو اور دوسرے گروہ کو قید کر رہے ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdlx{اس نے تم کو ان کی زمین اور ان کے گھروں اور ان کے اموال کا وارث بنا دیا اور وہ علاقہ تمہیں دیا جسے تم نے کبھی پامال نہ کیا تھا اللہ ہر چیز پر قادر ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdlxi{اے نبیؐ، اپنی بیویوں سے کہو، اگر تم دنیا اور اس کی زینت چاہتی ہو تو آؤ، میں تمہیں کچھ دے دلا کر بھلے طریقے سے رخصت کر دوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdlxii{اور اگر تم اللہ اور اس کے رسولؐ اور دار آخرت کی طالب ہو تو جان لو کہ تم میں سے جو نیکو کار ہیں اللہ نے ان کے لیے بڑا اجر مہیا کر رکھا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiii{نبیؐ کی بیویو، تم میں سے جو کسی صریح فحش حرکت کا ارتکاب کرے گی اسے دوہرا عذاب دیا جائے گا، اللہ کے لیے یہ بہت آسان کام ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiv{اور تم میں سے جو اللہ اور اُس کے رسولؐ کی اطاعت کرے گی اور نیک عمل کرے گی اس کو ہم دوہرا اجر دیں گے اور ہم نے اس کے لیے رزق کریم مہیا کر رکھا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdlxv{نبیؐ کی بیویو، تم عام عورتوں کی طرح نہیں ہو اگر تم اللہ سے ڈرنے والی ہو تو دبی زبان سے بات نہ کیا کرو کہ دل کی خرابی کا مُبتلا کوئی شخص لالچ میں پڑ جائے، بلکہ صاف سیدھی بات کرو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvi{اپنے گھروں میں ٹِک کر رہو اور سابق دور جاہلیت کی سی سج دھج نہ دکھاتی پھرو نماز قائم کرو، زکوٰۃ دو اور اللہ اور اُس کے رسولؐ کی اطاعت کرو اللہ تو یہ چاہتا ہے کہ اہلِ بیتِ نبیؐ سے گندگی کو دور کرے اور تمہیں پوری طرح پاک کر دے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvii{یاد رکھو اللہ کی آیات اور حکمت کی باتوں کو جو تمہارے گھروں میں سنائی جاتی ہیں بے شک اللہ لطیف اور باخبر ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdlxviii{بالیقین جو مرد اور جو عورتیں مسلم ہیں، مومن ہیں، مطیع فرمان ہیں، راست باز ہیں، صابر ہیں، اللہ کے آگے جھکنے والے ہیں، صدقہ دینے والے ہیں، روزہ رکھنے والے ہیں، اپنی شرمگاہوں کی حفاظت کرنے والے ہیں، اور اللہ کو کثرت سے یاد کرنے والے ہیں، اللہ نے ان کے لیے مغفرت اور بڑا اجر مہیا کر رکھا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdlxix{کسی مومن مرد اور کسی مومن عورت کو یہ حق نہیں ہے کہ جب اللہ اور اس کا رسولؐ کسی معاملے کا فیصلہ کر دے تو پھر اسے اپنے اُس معاملے میں خود فیصلہ کرنے کا اختیار حاصل رہے اور جو کوئی اللہ اور اس کے رسولؐ کی نافرمانی کرے تو وہ صریح گمراہی میں پڑ گیا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdlxx{اے نبیؐ، یاد کرو وہ موقع جب تم اس شخص سے کہہ رہے تھے جس پر اللہ نے اور تم نے احسان کیا تھا کہ ``اپنی بیوی کو نہ چھوڑ اور اللہ سے ڈر" اُس وقت تم اپنے دل میں وہ بات چھپائے ہوئے تھے جسے اللہ کھولنا چاہتا تھا، تم لوگوں سے ڈر رہے تھے، حالانکہ اللہ اس کا زیادہ حقدار ہے کہ تم اس سے ڈرو پھر جب زیدؓ اس سے اپنی حاجت پوری کر چکا تو ہم نے اس (مطلقہ خاتون) کا تم سے نکاح کر دیا تاکہ مومنوں پر اپنے منہ بولے بیٹوں کی بیویوں کے معاملہ میں کوئی تنگی نہ رہے جبکہ وہ ان سے اپنی حاجت پوری کر چکے ہوں اور اللہ کا حکم تو عمل میں آنا ہی چاہیے تھا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxi{نبی پر کسی ایسے کام میں کوئی رکاوٹ نہیں ہے جو اللہ نے اس کے لیے مقرر کر دیا ہو یہی اللہ کی سنت ان سب انبیاء کے معاملہ میں رہی ہے جو پہلے گزر چکے ہیں اور اللہ کا حکم ایک قطعی طے شدہ فیصلہ ہوتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxii{(یہ اللہ کی سنت ہے اُن لوگوں کے لیے) جو اللہ کے پیغامات پہنچاتے ہیں اور اُسی سے ڈرتے ہیں اور ایک خدا کے سوا کسی سے نہیں ڈرتے، اور محاسبہ کے لیے بس اللہ ہی کافی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiii{(لوگو) محمدؐ تمہارے مَردوں میں سے کسی کے باپ نہیں ہیں، مگر وہ اللہ کے رسول اور خاتم النبیین ہیں، اور اللہ ہر چیز کا علم رکھنے والا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiv{اے لوگو! جو ایمان لائے ہو، اللہ کو کثرت سے یاد کرو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxv{اور صبح و شام اس کی تسبیح کرتے رہو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvi{وہی ہے جو تم پر رحمت فرماتا ہے اور اس کے ملائکہ تمہارے لیے دعائے رحمت کرتے ہیں تاکہ وہ تمہیں تاریکیوں سے روشنی میں نکال لائے، وہ مومنوں پر بہت مہربان ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvii{جس روز وہ اس سے ملیں گے اُن کا استقبال سلام سے ہو گا اور اُن کے لیے اللہ نے بڑا با عزت اجر فراہم کر رکھا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxviii{اے نبیؐ، ہم نے تمہیں بھیجا ہے گواہ بنا کر، بشارت دینے والا اور ڈرانے والا بنا کر\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxix{اللہ کی اجازت سے اُس کی طرف دعوت دینے والا بنا کر اور روشن چراغ بنا کر\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxx{بشارت دے دو اُن لوگوں کو جو (تم پر) ایمان لائے ہیں کہ ان کے لیے اللہ کی طرف سے بڑا فضل ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxi{اور ہرگز نہ دبو کفار و منافقین سے، کوئی پرواہ نہ کرو ان کی اذیت رسانی کی اور بھروسہ کر لو اللہ پر، اللہ ہی اس کے لیے کافی ہے کہ آدمی اپنے معاملات اُس کے سپرد کر دے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxii{اَے لوگو جو ایمان لائے ہو، جب تم مومن عورتوں سے نکاح کرو اور پھر انہیں ہاتھ لگانے سے پہلے طلاق دے دو تو تمہاری طرف سے ان پر کوئی عدت لازم نہیں ہے جس کے پورے ہونے کا تم مطالبہ کر سکو لہٰذا انہیں کچھ مال دو اور بھلے طریقے سے رخصت کر دو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiii{اے نبیؐ، ہم نے تمہارے لیے حلال کر دیں تمہاری وہ بیویاں جن کے مہر تم نے ادا کیے ہیں، اور وہ عورتیں جو اللہ کی عطا کردہ لونڈیوں میں سے تمہاری ملکیت میں آئیں، اور تمہاری وہ چچا زاد اور پھوپھی زاد اور ماموں زاد اور خالہ زاد بہنیں جنہوں نے تمہارے ساتھ ہجرت کی ہے، اور وہ مومن عورت جس نے اپنے آپ کو نبیؐ کے لیے ہبہ کیا ہو اگر نبیؐ اسے نکاح میں لینا چاہے یہ رعایت خالصۃً تمہارے لیے ہے، دوسرے مومنوں کے لیے نہیں ہے ہم کو معلوم ہے کہ عام مومنوں پر ان کی بیویوں اور لونڈیوں کے بارے میں ہم نے کیا حدود عائد کیے ہیں (تمہیں ان حدود سے ہم نے اس لیے مستثنیٰ کیا ہے) تاکہ تمہارے اوپر کوئی تنگی نہ رہے، اور اللہ غفور و رحیم ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiv{تم کو اختیار دیا جاتا ہے کہ اپنی بیویوں میں سے جس کو چاہو اپنے سے الگ رکھو، جسے چاہو اپنے ساتھ رکھو اور جسے چاہو الگ رکھنے کے بعد اپنے پاس بلا لو اس معاملہ میں تم پر کوئی مضائقہ نہیں ہے اِس طرح زیادہ متوقع ہے کہ اُن کی آنکھیں ٹھنڈی رہیں گی اور وہ رنجیدہ نہ ہوں گی، اور جو کچھ بھی تم اُن کو دو گے اس پر وہ سب راضی رہیں گی اللہ جانتا ہے جو کچھ تم لوگوں کے دلوں میں ہے، اور اللہ علیم و حلیم ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxv{اس کے بعد تمہارے لیے دوسری عورتیں حلال نہیں ہیں، اور نہ اس کی اجازت ہے کہ ان کی جگہ اور بیویاں لے آؤ خواہ اُن کا حسن تمہیں کتنا ہی پسند ہو، البتہ لونڈیوں کی تمہیں اجازت ہے اللہ ہر چیز پر نگران ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvi{اے لوگو جو ایمان لائے ہو، نبیؐ کے گھروں میں بلا اجازت نہ چلے آیا کرو نہ کھانے کا وقت تاکتے رہو ہاں اگر تمہیں کھانے پر بلایا جائے تو ضرور آؤ مگر جب کھانا کھالو تو منتشر ہو جاؤ، باتیں کرنے میں نہ لگے رہو تمہاری یہ حرکتیں نبیؐ کو تکلیف دیتی ہیں، مگر وہ شرم کی وجہ سے کچھ نہیں کہتے اور اللہ حق بات کہنے میں نہیں شرماتا نبیؐ کی بیویوں سے اگر تمہیں کچھ مانگنا ہو تو پردے کے پیچھے سے مانگا کرو، یہ تمہارے اور ان کے دلوں کی پاکیزگی کے لیے زیادہ مناسب طریقہ ہے تمہارے لیے یہ ہرگز جائز نہیں کہ اللہ کے رسولؐ کو تکلیف دو، اور نہ یہ جائز ہے کہ ان کے بعد ان کی بیویوں سے نکاح کرو، یہ اللہ کے نزدیک بہت بڑا گناہ ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvii{تم خواہ کوئی بات ظاہر کرو یا چھپاؤ، اللہ کو ہر بات کا علم ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxviii{ازواج نبیؐ کے لیے اس میں کوئی مضائقہ نہیں ہے کہ ان کے باپ، ان کے بیٹے، ان کے بھائی، ان کے بھتیجے، ان کے بھانجے، ان کے میل جول کی عورتیں اور ان کے مملوک گھروں میں آئیں (اے عورتو) تمہیں اللہ کی نافرمانی سے پرہیز کرنا چاہیے اللہ ہر چیز پر نگاہ رکھتا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxix{اللہ اور اس کے ملائکہ نبیؐ پر درود بھیجتے ہیں، اے لوگو جو ایمان لائے ہو، تم بھی ان پر درود و سلام بھیجو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdxc{جو لوگ اللہ اور اس کے رسولؐ کو اذیت دیتے ہیں ان پر دنیا اور آخرت میں اللہ نے لعنت فرمائی ہے اور اُن کے لیے رسوا کن عذاب مہیا کر دیا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdxci{اور جو لوگ مومن مردوں اور عورتوں کو بے قصور اذیت دیتے ہیں اُنہوں نے ایک بڑے بہتان اور صریح گناہ کا وبال اپنے سر لے لیا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdxcii{اے نبیؐ، اپنی بیویوں اور بیٹیوں اور اہل ایمان کی عورتوں سے کہہ دو کہ اپنے اوپر اپنی چادروں کے پلو لٹکا لیا کریں یہ زیادہ مناسب طریقہ ہے تاکہ وہ پہچان لی جائیں اور نہ ستائی جائیں اللہ تعالیٰ غفور و رحیم ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdxciii{اگر منافقین، اور وہ لوگ جن کے دلوں میں خرابی ہے، اور وہ جو مدینہ میں ہیجان انگیز افواہیں پھیلانے والے ہیں، اپنی حرکتوں سے باز نہ آئے تو ہم ان کے خلاف کاروائی کرنے کے لیے تمہیں اُٹھا کھڑا کریں گے، پھر وہ اس شہر میں مشکل ہی سے تمہارے ساتھ رہ سکیں گے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdxciv{ان پر ہر طرف سے لعنت کی بوچھاڑ ہو گی، جہاں کہیں پائے جائیں گے پکڑے جائیں گے اور بُری طرح مارے جائیں گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdxcv{یہ اللہ کی سنت ہے جو ایسے لوگوں کے معاملے میں پہلے سے چلی آ رہی ہے، اور تم اللہ کی سنت میں کوئی تبدیلی نہ پاؤ گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvi{لوگ تم سے پوچھتے ہیں کہ قیامت کی گھڑی کب آئے گی کہو، اُس کا علم تو اللہ ہی کو ہے تمہیں کیا خبر، شاید کہ وہ قریب ہی آ لگی ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvii{بہرحال یہ یقینی امر ہے کہ اللہ نے کافروں پر لعنت کی ہے اور ان کے لیے بھڑکتی ہوئی آگ مہیا کر دی ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdxcviii{جس میں وہ ہمیشہ رہیں گے، کوئی حامی و مدد گار نہ پا سکیں گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdxcix{جس روز ان کے چہرے آگ پر الٹ پلٹ کیے جائیں گے اُس وقت وہ کہیں گے کہ ``کاش ہم نے اللہ اور رسولؐ کی اطاعت کی ہوتی"\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdc{اور کہیں گے ``اے رب ہمارے، ہم نے اپنے سرداروں اور اپنے بڑوں کی اطاعت کی اور انہوں نے ہمیں راہِ راست سے بے راہ کر دیا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdci{اے رب، ان کو دوہرا عذاب دے اور ان پر سخت لعنت کر"\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcii{اے لوگو جو ایمان لائے ہو، اُن لوگوں کی طرح نہ بن جاؤ جنہوں نے موسیٰؑ کو اذیتیں دی تھیں، پھر اللہ نے اُن کی بنائی ہوئی باتوں سے اُس کی برأت فرمائی اور وہ اللہ کے نزدیک با عزت تھا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdciii{اے ایمان لانے والو، اللہ سے ڈرو اور ٹھیک بات کیا کرو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdciv{اللہ تمہارے اعمال درست کر دے گا اور تمہارے قصوروں سے درگزر فرمائے گا جو شخص اللہ اور اس کے رسولؐ کی اطاعت کرے اُس نے بڑی کامیابی حاصل کی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcv{ہم نے اس امانت کو آسمانوں اور زمین اور پہاڑوں کے سامنے پیش کیا تو وہ اُسے اٹھانے کے لیے تیار نہ ہوئے اور اس سے ڈر گئے، مگر انسان نے اسے اٹھا لیا، بے شک وہ بڑا ظالم اور جاہل ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcvi{اِس بار امانت کو اٹھانے کا لازمی نتیجہ یہ ہے کہ اللہ منافق مردوں اور عورتوں، اور مشرک مردوں اور عورتوں کو سزا دے اور مومن مَردوں اور عورتوں کی توبہ قبول کرے، اللہ درگزر فرمانے والا اور رحیم ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcvii{\basmalahur حمد اُس خدا کے لیے ہے جو آسمانوں اور زمین کی ہر چیز کا مالک ہے اور آخرت میں بھی اسی کے لیے حمد ہے وہ دانا اور باخبر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdcviii{جو کچھ زمین میں جاتا ہے اور جو کچھ اُس سے نکلتا ہے اور جو کچھ آسمان سے اترتا ہے اور جو کچھ اُس میں چڑھتا ہے، ہر چیز کو وہ جانتا ہے، وہ رحیم اور غفور ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdcix{منکرین کہتے ہیں کہ کیا بات ہے کہ قیامت ہم پر نہیں آ رہی ہے! کہو، قسم ہے میرے عالم الغیب پروردگار کی، وہ تم پر آ کر رہے گی اُس سے ذرہ برابر کوئی چیز نہ آسمانوں میں چھپی ہوئی ہے نہ زمین میں نہ ذرے سے بڑی اور نہ اُس سے چھوٹی، سب کچھ ایک نمایاں دفتر میں درج ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdcx{اور یہ قیامت اس لئے آئے گی کہ جزا دے اللہ اُن لوگوں کو جو ایمان لائے ہیں اور نیک عمل کرتے رہے ہیں اُن کے لیے مغفرت ہے اور رزق کریم\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdcxi{اور جن لوگوں نے ہماری آیات کو نیچا دکھانے کے لیے زور لگایا ہے، ان کے لیے بدترین قسم کا دردناک عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdcxii{اے نبیؐ، علم رکھنے والے خوب جانتے ہیں کہ جو کچھ تمہارے رب کی طرف سے تم پر نازل کیا گیا ہے وہ سراسر حق ہے اور خدائے عزیز و حمید کا راستہ دکھاتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiii{منکرین لوگوں سے کہتے ہیں ``ہم بتائیں تمہیں ایسا شخص جو خبر دیتا ہے کہ جب تمہارے جسم کا ذرہ ذرہ منتشر ہو چکا ہو گا اس وقت تم نئے سرے سے پیدا کر دیے جاؤ گے؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiv{نہ معلوم یہ شخص اللہ کے نام سے جھوٹ گھڑتا ہے ہے یا اسے جنون لاحق ہے" نہیں، بلکہ جو لوگ آخرت کو نہیں مانتے وہ عذاب میں مبتلا ہونے والے ہیں اور و ہی بری طرح بہکے ہوئے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdcxv{کیا اِنہوں نے کبھی اُس آسمان و زمین کو نہیں دیکھا جو اِنہیں آگے اور پیچھے سے گھیرے ہوئے ہے؟ ہم چاہیں تو اِنہیں زمین میں دھسا دیں، یا آسمان کے کچھ ٹکڑے اِن پر گرا دیں در حقیقت اس میں ایک نشانی ہے ہر اُس بندے کے لیے جو خدا کی طرف رجوع کرنے والا ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvi{ہم نے داؤدؑ کو اپنے ہاں سے بڑا فضل عطا کیا تھا (ہم نے حکم دیا کہ) اے پہاڑو، اس کے ساتھ ہم آہنگی کرو (اور یہی حکم ہم نے) پرندوں کو دیا ہم نے لوہے کو اس کے لیے نرم کر دیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvii{اس ہدایت کے ساتھ کہ زرہیں بنا اور ان کے حلقے ٹھیک اندازے پر رکھ (اے آل داؤدؑ) نیک عمل کرو، جو کچھ تم کرتے ہو اُس کو میں دیکھ رہا ہوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdcxviii{اور سلیمانؑ کے لیے ہم نے ہوا کو مسخر کر دیا، صبح کے وقت اس کا چلنا ایک مہینے کی راہ تک اور شام کے وقت اس کا چلنا ایک مہینے کی راہ تک ہم نے اُس کے لیے پگھلے ہوئے تانبے کا چشمہ بہا دیا اور ایسے جن اس کے تابع کر دیے جو اپنے رب کے حکم سے اس کے آگے کام کرتے تھے اُن میں سے جو ہمارے حکم سے سرتابی کرتا اس کو ہم بھڑکتی ہوئی آگ کا مزہ چکھاتے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdcxix{وہ اُس کے لیے بناتے تھے جو کچھ وہ چاہتا، اونچی عمارتیں، تصویریں، بڑے بڑے حوض جیسے لگن اور اپنی جگہ سے نہ ہٹنے والی بھاری دیگیں اے آلِ داؤدؑ، عمل کرو شکر کے طریقے پر، میرے بندوں میں کم ہی شکر گزار ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcxx{پھر جب سلیمانؑ پر ہم نے موت کا فیصلہ نافذ کیا تو جنوں کو اس کی موت کا پتہ دینے والی کوئی چیز اُس گھن کے سوا نہ تھی جو اس کے عصا کو کھا رہا تھا اس طرح جب سلیمانؑ گر پڑا تو جنوں پر یہ بات کھل گئی کہ اگر وہ غیب کے جاننے والے ہوتے تو اس ذلت کے عذاب میں مبتلا نہ رہتے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxi{سبا کے لیے اُن کے اپنے مسکن ہی میں ایک نشانی موجود تھی، دو باغ دائیں اور بائیں کھاؤ اپنے رب کا دیا ہوا رزق اور شکر بجا لاؤ اُس کا، ملک ہے عمدہ و پاکیزہ اور پروردگار ہے بخشش فرمانے والا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxii{مگر وہ منہ موڑ گئے آخرکار ہم نے اُن پر بند توڑ سیلاب بھیج دیا اور ان کے پچھلے دو باغوں کی جگہ دو اور باغ انہیں دیے جن میں کڑوے کسیلے پھل اور جھاؤ کے درخت تھے اور کچھ تھوڑی سی بیریاں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiii{یہ تھا ان کے کفر کا بدلہ جو ہم نے ان کو دیا، اور ناشکرے انسان کے سوا ایسا بدلہ ہم اور کسی کو نہیں دیتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiv{اور ہم نے اُن کے اور اُن بستیوں کے درمیان، جن کو ہم نے برکت عطا کی تھی، نمایاں بستیاں بسا دی تھیں اور اُن میں سفر کی مسافتیں ایک اندازے پر رکھ دی تھیں چلو پھرو اِن راستوں میں رات دن پورے امن کے ساتھ\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxv{مگر انہوں نے کہا ``اے ہمارے رب، ہمارے سفر کی مسافتیں لمبی کر دے" انہوں نے اپنے اوپر آپ ظلم کیا آخرکار ہم نے انہیں افسانہ بنا کر رکھ دیا اور انہیں بالکل تتربتر کر ڈالا یقیناً اس میں نشانیاں ہیں ہر اُس شخص کے لیے جو بڑا صابر و شاکر ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvi{اُن کے معاملہ میں ابلیس نے اپنا گمان صحیح پایا اور انہوں نے اُسی کی پیروی کی، بجز ایک تھوڑے سے گروہ کے جو مومن تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvii{ابلیس کو اُن پر کوئی اقتدار حاصل نہ تھا مگر جو کچھ ہوا وہ اس لیے ہوا کہ ہم یہ دیکھنا چاہتے تھے کہ کون آخرت کا ماننے والا ہے اور کون اس کی طرف سے شک میں پڑا ہوا ہے تیرا رب ہر چیز پر نگران ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxviii{(اے نبیؐ، اِن مشرکین سے) کہو کہ پکار دیکھو اپنے اُن معبودوں کو جنہیں تم اللہ کے سوا اپنا معبود سمجھے بیٹھے ہو وہ نہ آسمانوں میں کسی ذرہ برابر چیز کے مالک ہیں نہ زمین میں وہ آسمان و زمین کی ملکیت میں شریک بھی نہیں ہیں ان میں سے کوئی اللہ کا مدد گار بھی نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxix{اور اللہ کے حضور کوئی شفاعت بھی کسی کے لیے نافع نہیں ہو سکتی بجز اُس شخص کے جس کے لیے اللہ نے سفارش کی اجازت دی ہو حتیٰ کہ جب لوگوں کے دلوں سے گھبراہٹ دور ہو گی تو وہ (سفارش کرنے والوں سے) پوچھیں گے کہ تمہارے رب نے کیا جواب دیا وہ کہیں گے کہ ٹھیک جواب ملا ہے اور وہ بزرگ و برتر ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxx{(اے نبیؐ) اِن سے پوچھو، ``کون تم کو آسمانوں اور زمین سے رزق دیتا ہے؟" کہو ``اللہ اب لامحالہ ہم میں اور تم میں سے کوئی ایک ہی ہدایت پر ہے یا کھلی گمراہی میں پڑا ہوا ہے"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxi{ان سے کہو، ``جو قصور ہم نے کیا ہو اس کی کوئی باز پرس تم سے نہ ہو گی اور جو کچھ تم کر رہے ہو اس کی کوئی جواب طلبی ہم سے نہیں کی جائے گی"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxii{کہو، ``ہمارا رب ہم کو جمع کرے گا، پھر ہمارے درمیان ٹھیک ٹھیک فیصلہ کر دے گا وہ ایسا زبردست حاکم ہے جو سب کچھ جانتا ہے"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiii{اِن سے کہو، ``ذرا مجھے دکھاؤ تو سہی وہ کون ہستیاں ہیں جنہیں تم نے اس کے ساتھ شریک لگا رکھا ہے" ہرگز نہیں، زبردست اور دانا تو بس وہ اللہ ہی ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiv{اور (اے نبیؐ،) ہم نے تم کو تمام ہی انسانوں کے لیے بشیر و نذیر بنا کر بھیجا ہے، مگر اکثر لوگ جانتے نہیں ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxv{یہ لوگ تم سے کہتے ہیں کہ وہ (قیامت کا) وعدہ کب پورا ہو گا اگر تم سچے ہو؟\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvi{کہو تمہارے لیے ایک ایسے دن کی میعاد مقرر ہے جس کے آنے میں نہ ایک گھڑی بھر کی تاخیر تم کر سکتے ہو اور نہ ایک گھڑی بھر پہلے اسے لا سکتے ہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvii{یہ کافر کہتے ہیں کہ ``ہم ہرگز اِس قرآن کو نہ مانیں گے اور نہ اس سے پہلے آئی ہوئی کسی کتاب کو تسلیم کریں گے" کاش تم دیکھو اِن کا حال اُس وقت جب یہ ظالم اپنے رب کے حضور کھڑے ہوں گے اُس وقت یہ ایک دوسرے پر الزام دھریں گے جو لوگ دنیا میں دبا کر رکھے گئے تھے وہ بڑے بننے والوں سے کہیں گے کہ ``اگر تم نہ ہوتے تو ہم مومن ہوتے"\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxviii{وہ بڑے بننے والے ان دبے ہوئے لوگوں کو جواب دیں گے ``کیا ہم نے تمہیں اُس ہدایت سے روکا تھا جو تمہارے پاس آئی تھی؟ نہیں، بلکہ تم خود مجرم تھے"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxix{وہ دبے ہوئے لوگ ان بڑے بننے والوں سے کہیں گے، ``نہیں، بلکہ شب و روز کی مکاری تھی جب تم ہم سے کہتے تھے کہ ہم اللہ سے کفر کریں اور دوسروں کو اس کا ہمسر ٹھیرائیں" آخرکار جب یہ لوگ عذاب دیکھیں گے تو اپنے دلوں میں پچھتائیں گے اور ہم اِن منکرین کے گلوں میں طوق ڈال دیں گے کیا لوگوں کو اِس کے سوا اور کوئی بدلہ دیا جا سکتا ہے کہ جیسے اعمال اُن کے تھے ویسی ہی جزا وہ پائیں؟\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxl{کبھی ایسا نہیں ہوا کہ ہم نے کسی بستی میں ایک خبردار کرنے والا بھیجا ہو اور اس بستی کے کھاتے پیتے لوگوں نے یہ نہ کہا ہو کہ جو پیغام تم لے کر آئے ہو اس کو ہم نہیں مانتے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxli{انہیں نے ہمیشہ یہی کہا کہ ہم تم سے زیادہ مال اولاد رکھتے ہیں اور ہم ہرگز سزا پانے والے نہیں ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlii{اے نبیؐ، اِن سے کہو میرا رب جسے چاہتا ہے کشادہ رزق دیتا ہے اور جسے چاہتا ہے نپا تلا عطا کرتا ہے، مگر اکثر لوگ اس کی حقیقت نہیں جانتے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliii{یہ تمہاری دولت اور تمہاری اولاد نہیں ہے جو تمہیں ہم سے قریب کرتی ہو ہاں مگر جو ایمان لائے اور نیک عمل کرے یہی لوگ ہیں جن کے لیے اُن کے عمل کی دہری جزا ہے، اور وہ بلند و بالا عمارتوں میں اطمینان سے رہیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliv{رہے وہ لوگ جو ہماری آیات کو نیچا دکھانے کے لیے دوڑ دھوپ کرتے ہیں، تو وہ عذاب میں مبتلا ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlv{اے نبیؐ، ان سے کہو، ``میرا رب اپنے بندوں میں سے جسے چاہتا ہے کھلا رزق دیتا ہے اور جسے چاہتا ہے نپا تلا دیتا ہے جو کچھ تم خرچ کر دیتے ہو اُس کی جگہ وہی تم کو اور دیتا ہے، وہ سب رازقوں سے بہتر رازق ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvi{اور جس دن وہ تمام انسانوں کو جمع کرے گا پھر فرشتوں سے پوچھے گا ``کیا یہ لوگ تمہاری ہی عبادت کیا کرتے تھے؟"\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvii{تو وہ جواب دیں گے کہ ``پاک ہے آپ کی ذات، ہمارا تعلق تو آپ سے ہے نہ کہ اِن لوگوں سے دراصل یہ ہماری نہیں بلکہ جنوں کی عبادت کرتے تھے، ان میں سے اکثر انہی پر ایمان لائے ہوئے تھے"\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlviii{(اُس وقت ہم کہیں گے کہ) آج تم میں سے کوئی نہ کسی کو فائدہ پہنچا سکتا ہے نہ نقصان اور ظالموں سے ہم کہہ دیں گے کہ اب چکھو اس عذاب جہنم کا مزہ جسے تم جھٹلایا کرتے تھے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlix{اِن لوگوں کو جب ہماری صاف صاف آیات سنائی جاتی ہیں تو یہ کہتے ہیں کہ ``یہ شخص تو بس یہ چاہتا ہے کہ تم کو اُن معبودوں سے برگشتہ کر دے جن کی عبادت تمہارے باپ دادا کرتے آئے ہیں" اور کہتے ہیں کہ ``یہ (قرآن) محض ایک جھوٹ ہے گھڑا ہوا" اِن کافروں کے سامنے جب حق آیا تو انہیں نے کہہ دیا کہ ``یہ تو صریح جادو ہے"\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcl{حالانکہ نہ ہم نے اِن لوگوں کو پہلے کوئی کتاب دی تھی کہ یہ اسے پڑھتے ہوں اور نہ تم سے پہلے ان کی طرف کوئی متنبہ کرنے والا بھیجا تھا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcli{اِن سے پہلے گزرے ہوئے لوگ جھٹلا چکے ہیں جو کچھ ہم نے اُنہیں دیا تھا اُس کے عشر عشیر کو بھی یہ نہیں پہنچے ہیں مگر جب انہوں نے میرے رسولوں کو جھٹلایا تو دیکھ لو کہ میری سزا کیسی سخت تھی\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdclii{اے نبیؐ، اِن سے کہو کہ ``میں تمہیں بس ایک بات کی نصیحت کرتا ہوں خدا کے لیے تم اکیلے اکیلے اور دو دو مل کر اپنا دماغ لڑاؤ اور سوچو، تمہارے صاحب میں آخر ایسی کونسی بات ہے جو جنون کی ہو؟ وہ تو ایک سخت عذاب کی آمد سے پہلے تم کو متنبہ کرنے والا ہے"\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcliii{اِن سے کہو، ``اگر میں نے تم سے کوئی اجر مانگا ہے تو وہ تم ہی کو مبارک رہے میرا اجر تو اللہ کے ذمہ ہے اور وہ ہر چیز پر گواہ ہے"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcliv{ان سے کہو ``میرا رب (مجھ پر) حق کا القا کرتا ہے اور وہ تمام پوشیدہ حقیقتوں کا جاننے والا ہے"\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdclv{کہو ``حق آگیا ہے اور اب باطل کے کیے کچھ نہیں ہو سکتا"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdclvi{کہو ``اگر میں گمراہ ہو گیا ہوں تو میری گمراہی کا وبال مجھ پر ہے، اور اگر میں ہدایت پر ہوں تو اُس وحی کی بنا پر ہوں جو میرا رب میرے اوپر نازل کرتا ہے، وہ سب کچھ سنتا ہے اور قریب ہی ہے"\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdclvii{کاش تم دیکھو اِنہیں اُس وقت جب یہ لوگ گھبرائے پھر رہے ہوں گے اور کہیں بچ کر نہ جا سکیں گے، بلکہ قریب ہی سے پکڑ لیے جائیں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdclviii{اُس وقت یہ کہیں گے کہ ہم اُس پر ایمان لے آئے حالانکہ اب دور نکلی ہوئی چیز کہاں ہاتھ آسکتی ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdclix{اِس سے پہلے یہ کفر کر چکے تھے اور بلا تحقیق دور دور کی کوڑیاں لایا کرتے تھے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdclx{اُس وقت جس چیز کی یہ تمنا کر رہے ہوں گے اس سے محروم کر دیے جائیں گے جس طرح اِن کے پیش رو ہم مشرب محروم ہو چکے ہوں گے یہ بڑے گمراہ کن شک میں پڑے ہوئے تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdclxi{\basmalahur تعریف اللہ ہی کے لیے ہے جو آسمانوں اور زمین کا بنانے والا اور فرشتوں کو پیغام رساں مقرر کر نے والا ہے، (ایسے فرشتے) جن کے دو دو اور تین تین اور چار چار بازو ہیں وہ اپنی مخلوق کی ساخت میں جیسا چاہتا ہے اضافہ کرتا ہے یقیناً اللہ ہر چیز پر قادر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdclxii{اللہ جس رحمت کا دروازہ بھی لوگوں کے لیے کھول دے اسے کوئی روکنے والا نہیں اور جسے وہ بند کر دے اسے اللہ کے بعد پھر کوئی دوسرا کھولنے والا نہیں وہ زبردست اور حکیم ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiii{لوگو، تم پر اللہ کے جو احسانات ہیں انہیں یاد رکھو کیا اللہ کے سوا کوئی اور خالق بھی ہے جو تمہیں آسمان اور زمین سے رزق دیتا ہو؟ کوئی معبود اُس کے سوا نہیں، آخر تم کہاں سے دھوکا کھا رہے ہو؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiv{اب اگر (اے نبیؐ) یہ لوگ تمہیں جھٹلاتے ہیں (تو یہ کوئی نئی بات نہیں)، تم سے پہلے بھی بہت سے رسول جھٹلائے جا چکے ہیں، اور سارے معاملات آخرکار اللہ ہی کی طرف رجوع ہونے والے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdclxv{لوگو، اللہ کا وعدہ یقیناً برحق ہے، لہٰذا دنیا کی زندگی تمہیں دھوکے میں نہ ڈالے اور نہ وہ بڑا دھوکے باز تمہیں اللہ کے بارے میں دھوکہ دینے پائے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvi{در حقیقت شیطان تمہارا دشمن ہے اس لیے تم بھی اسے اپنا دشمن ہی سمجھو وہ تو اپنے پیروؤں کو اپنی راہ پر اس لیے بلا رہا ہے کہ وہ دوزخیوں میں شامل ہو جائیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvii{جو لوگ کفر کریں گے اُن کے لیے سخت عذاب ہے اور جو ایمان لائیں گے اور نیک عمل کریں گے اُن کے لیے مغفرت اور بڑا اجر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdclxviii{(بھلا کچھ ٹھکانا ہے اُس شخص کی گمراہی کا) جس کے لیے اُس کا برا عمل خوشنما بنا دیا گیا ہو اور وہ اُسے اچھا سمجھ رہا ہو؟ حقیقت یہ ہے کہ اللہ جسے چاہتا ہے گمراہی میں ڈال دیتا ہے اور جسے چاہتا ہے راہ راست دکھا دیتا ہے پس (اے نبیؐ) خواہ مخواہ تمہاری جان ان لوگوں کی خاطر غم و افسوس میں نہ گھلے جو کچھ یہ کر رہے ہیں اللہ اُس کو خوب جانتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdclxix{وہ اللہ ہی تو ہے جو ہواؤں کو بھیجتا ہے، پھر وہ بادل اٹھاتی ہیں، پھر ہم اسے ایک اُجاڑ علاقے کی طرف لے جاتے ہیں اور اسی زمین کو جِلا اٹھاتے ہیں جو مری پڑی تھی مرے ہوئے انسانوں کا جی اٹھنا بھی اسی طرح ہوگا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdclxx{جو کوئی عزت چاہتا ہو اُسے معلوم ہونا چاہیے کہ عزت ساری کی ساری اللہ کی ہے اُس کے ہاں جو چیز اوپر چڑھتی ہے وہ صرف پاکیزہ قول ہے، اور عمل صالح اس کو اوپر چڑھاتا ہے رہے وہ لوگ جو بیہودہ چال بازیاں کرتے ہیں، اُن کے لیے سخت عذاب ہے اور اُن کا مکر خود ہی غارت ہونے والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxi{اللہ نے تم کو مٹی سے پیدا کیا، پھر نطفہ سے، پھر تمہارے جوڑے بنا دیے (یعنی مرد اور عورت) کوئی عورت حاملہ نہیں ہوتی اور نہ بچہ جنتی ہے مگر یہ سب کچھ اللہ کے علم میں ہوتا ہے کوئی عمر پانے والا عمر نہیں پاتا اور نہ کسی کی عمر میں کچھ کمی ہوتی ہے مگر یہ سب کچھ ایک کتاب میں لکھا ہوتا ہے اللہ کے لیے یہ بہت آسان کام ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxii{اور پانی کے دونوں ذخیرے یکساں نہیں ہیں ایک میٹھا اور پیاس بجھانے والا ہے، پینے میں خوشگوار، اور دوسرا سخت کھاری کہ حلق چھیل دے مگر دونوں سے تم تر و تازہ گوشت حاصل کرتے ہو، پہننے کے لیے زینت کا سامان نکالتے ہو، اور اسی پانی میں تم دیکھتے ہو کہ کشتیاں اُس کا سینہ چیرتی چلی جا رہی ہیں تاکہ تم اللہ کا فضل تلاش کرو اور اُس کے شکر گزار بنو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiii{وہ دن کے اندر رات کو اور رات کے اندر دن کو پروتا ہوا لے آتا ہے چاند اور سورج کو اُس نے مسخر کر رکھا ہے یہ سب کچھ ایک وقت مقرر تک چلے جا رہا ہے وہی اللہ (جس کے یہ سارے کام ہیں) تمہارا رب ہے بادشاہی اسی کی ہے اُسے چھوڑ کر جن دوسروں کو تم پکارتے ہو وہ ایک پرکاہ کے مالک بھی نہیں ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiv{انہیں پکارو تو وہ تمہاری دعائیں سن نہیں سکتے اور سن لیں تو ان کا تمہیں کوئی جواب نہیں دے سکتے اور قیامت کے روز وہ تمہارے شرک کا انکار کر دیں گے حقیقت حال کی ایسی صحیح خبر تمہیں ایک خبردار کے سوا کوئی نہیں دے سکتا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxv{لوگو، تم ہی اللہ کے محتاج ہو اور اللہ تو غنی و حمید ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvi{وہ چاہے تو تمہیں ہٹا کر کوئی نئی خلقت تمہاری جگہ لے آئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvii{ایسا کرنا اللہ کے لیے کچھ بھی دشوار نہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxviii{کوئی بوجھ اٹھانے والا کسی دوسرے کا بوجھ نہ اٹھائے گا اور اگر کوئی لدا ہوا نفس اپنا بوجھ اٹھانے کے لیے پکارے گا تو اس کے بار کا ایک ادنیٰ حصہ بھی بٹانے کے لیے کوئی نہ آئے گا چاہے وہ قریب ترین رشتہ دار ہی کیوں نہ ہو (اے نبیؐ) تم صرف انہی لوگوں کو متنبہ کر سکتے ہو جو بے دیکھے اپنے رب سے ڈرتے ہیں اور نماز قائم کرتے ہیں جو شخص بھی پاکیزگی اختیار کرتا ہے اپنی ہی بھلائی کے لیے کرتا ہے اور پلٹنا سب کو اللہ ہی کی طرف ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxix{اندھا اور آنکھوں والا برابر نہیں ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxx{نہ تاریکیاں اور روشنی یکساں ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxi{نہ ٹھنڈی چھاؤں اور دھوپ کی تپش ایک جیسی ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxii{اور نہ زندے اور مردے مساوی ہیں اللہ جسے چاہتا ہے سنواتا ہے، مگر (اے نبیؐ) تم اُن لوگوں کو نہیں سنا سکتے جو قبروں میں مدفون ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiii{تم تو بس ایک خبردار کرنے والے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiv{ہم نے تم کو حق کے ساتھ بھیجا ہے بشارت دینے والا اور ڈرانے والا بنا کر اور کوئی امت ایسی نہیں گزری ہے جس میں کوئی متنبہ کرنے والا نہ آیا ہو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxv{اب اگر یہ لوگ تمہیں جھٹلاتے ہیں تو اِن سے پہلے گزرے ہوئے لوگ بھی جھٹلا چکے ہیں اُن کے پاس ان کے رسول کھلے دلائل اور صحیفے اور روشن ہدایات دینے والی کتاب لے کر آئے تھے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvi{پھر جن لوگوں نے نہ مانا اُن کو میں نے پکڑ لیا اور دیکھ لو کہ میری سزا کیسی سخت تھی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvii{کیا تم دیکھتے نہیں ہو کہ اللہ آسمان سے پانی برساتا ہے اور پھر اس کے ذریعہ سے ہم طرح طرح کے پھل نکال لاتے ہیں جن کے رنگ مختلف ہوتے ہیں پہاڑوں میں بھی سفید، سرخ اور گہری سیاہ دھاریاں پائی جاتی ہیں جن کے رنگ مختلف ہوتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxviii{اور اسی طرح انسانوں اور جانوروں اور مویشیوں کے رنگ بھی مختلف ہیں حقیقت یہ ہے کہ اللہ کے بندوں میں سے صرف علم رکھنے والے لوگ ہی اُس سے ڈرتے ہیں بے شک اللہ زبردست اور درگزر فرمانے والا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxix{جو لوگ کتاب اللہ کی تلاوت کرتے ہیں اور نماز قائم کرتے ہیں، اور جو کچھ ہم نے اُنہیں رزق دیا ہے اس میں سے کھلے اور چھپے خرچ کرتے ہیں، یقیناً وہ ایک ایسی تجارت کے متوقع ہیں جس میں ہرگز خسارہ نہ ہوگا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxc{(اس تجارت میں انہوں نے اپنا سب کچھ اِس لیے کھپایا ہے) تاکہ اللہ اُن کے اجر پورے کے پورے اُن کو دے اور مزید اپنے فضل سے ان کو عطا فرمائے بے شک اللہ بخشنے والا اور قدردان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxci{(اے نبیؐ) جو کتاب ہم نے تمہاری طرف وحی کے ذریعہ سے بھیجی ہے وہی حق ہے، تصدیق کرتی ہوئی آئی ہے اُن کتابوں کی جو اِس سے پہلے آئی تھیں بے شک اللہ اپنے بندوں کے حال سے باخبر ہے اور ہر چیز پر نگاہ رکھنے والا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcii{پھر ہم نے اس کتاب کا وارث بنا دیا اُن لوگوں کو جنہیں ہم نے (اِس وراثت کے لیے) اپنے بندوں میں سے چن لیا اب کوئی تو ان میں سے اپنے نفس پر ظلم کرنے والا ہے، اور کوئی بیچ کی راس ہے، اور کوئی اللہ کے اذن سے نیکیوں میں سبقت کرنے والا ہے، یہی بہت بڑا فضل ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciii{ہمیشہ رہنے والی جنتیں ہیں جن میں یہ لوگ داخل ہوں گے وہاں انہیں سونے کے کنگنوں اور موتیوں سے آراستہ کیا جائے گا، وہاں ان کا لباس ریشم ہوگا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciv{اور وہ کہیں گے کہ شکر ہے اُس خدا کا جس نے ہم سے غم دور کر دیا، یقیناً ہمارا رب معاف کرنے والا اور قدر فرمانے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcv{جس نے ہمیں اپنے فضل سے ابدی قیام کی جگہ ٹھیرا دیا، اب یہاں نہ ہمیں کوئی مشقت پیش آتی ہے اور نہ تکان لاحق ہوتی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvi{اور جن لوگوں نے کفر کیا ہے اُن کے لیے جہنم کی آگ ہے نہ اُن کا قصہ پاک کر دیا جائے گا کہ مر جائیں اور نہ اُن کے لیے جہنم کے عذاب میں کوئی کمی کی جائے گی اِس طرح ہم بدلہ دیتے ہیں ہر اُس شخص کو جو کفر کرنے والا ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvii{وہ وہاں چیخ چیخ کر کہیں گے کہ ``اے ہمارے رب، ہمیں یہاں سے نکال لے تاکہ ہم نیک عمل کریں اُن اعمال سے مختلف جو پہلے کرتے رہے تھے" (انہیں جواب دیا جائے گا) ``کیا ہم نے تم کو اتنی عمر نہ دی تھی جس میں کوئی سبق لینا چاہتا تو سبق لے سکتاتھا؟ اور تمہارے پاس متنبہ کرنے والا بھی آ چکا تھا اب مزا چکھو ظالموں کا یہاں کوئی مددگار نہیں ہے"\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcviii{بے شک اللہ آسمانوں اور زمین کی ہر پوشیدہ چیز سے واقف ہے، وہ تو سینوں کے چھپے ہوئے راز تک جانتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcix{وہی تو ہے جس نے تم کو زمین میں خلیفہ بنایا ہے اب جو کوئی کفر کرتا ہے اس کے کفر کا وبال اُسی پر ہے، اور کافروں کو اُن کا کفر اِس کے سوا کوئی ترقی نہیں دیتا کہ ان کے رب کا غضب اُن پر زیادہ سے زیادہ بھڑکتا چلا جاتا ہے کافروں کے لیے خسارے میں اضافے کے سوا کوئی ترقی نہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcc{(اے نبیؐ) ان سے کہو، ``کبھی تم نے دیکھا بھی ہے اپنے اُن شریکوں کو جنہیں تم خدا کو چھوڑ کر پکارا کرتے ہو؟ مجھے بتاؤ، انہوں نے زمین میں کیا پیدا کیا ہے؟ یا آسمانوں میں ان کی کیا شرکت ہے ``؟ (اگر یہ نہیں بتا سکتے تو ان سے پوچھو) کیا ہم نے انہیں کوئی تحریر لکھ کر دی ہے جس کی بنا پر یہ (اپنے اس شرک کے لیے) کوئی صاف سند رکھتے ہوں؟ نہیں، بلکہ یہ ظالم ایک دوسرے کو محض فریب کے جھانسے دیے جا رہے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcci{حقیقت یہ ہے کہ اللہ ہی ہے جو آسمانوں اور زمین کو ٹل جانے سے روکے ہوئے ہے، اور اگر وہ ٹل جائیں تو اللہ کے بعد کوئی دوسرا انہیں تھامنے والا نہیں ہے بے شک اللہ بڑا حلیم اور درگزر فرمانے والا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccii{یہ لوگ کڑی کڑی قسمیں کھا کر کہا کرتے تھے کہ اگر کوئی خبردار کرنے والا ان کے ہاں آ گیا ہوتا تو یہ دنیا کی ہر دوسری قوم سے بڑھ کر راست رو ہوتے مگر جب خبردار کرنے والا ان کے پاس آگیا تو اس کی آمد نے اِن کے اندر حق سے فرار کے سوا کسی چیز میں اضافہ نہ کیا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcciii{یہ زمین میں اور زیادہ استکبار کرنے لگے اور بری بری چالیں چلنے لگے، حالانکہ بُری چالیں اپنے چلنے والوں ہی کو لے بیٹھتی ہیں اب کیا یہ لوگ اِس کا انتظار کر رہے ہیں کہ پچھلی قوموں کے ساتھ اللہ کا جو طریقہ رہا ہے وہی اِن کے ساتھ بھی برتا جائے؟ یہی بات ہے تو تم اللہ کے طریقے میں ہرگز کوئی تبدیلی نہ پاؤ گے اور تم کبھی نہ دیکھو گے کہ اللہ کی سنت کو اس کے مقرر راستے سے کوئی طاقت پھیر سکتی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcciv{کیا یہ لوگ زمین میں کبھی چلے پھرے نہیں ہیں کہ انہیں اُن لوگوں کا انجام نظر آتا جو اِن سے پہلے گزر چکے ہیں اور ان سے بہت زیادہ طاقت ور تھے؟ اللہ کو کوئی چیز عاجز کرنے والی نہیں ہے، نہ آسمانوں میں اور نہ زمین میں وہ سب کچھ جانتا ہے اور ہر چیز پر قدرت رکھتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccv{اگر کہیں وہ لوگوں کو اُن کے کیے کرتوتوں پر پکڑتا تو زمین پر کسی متنفس کو جیتا نہ چھوڑتا مگر وہ انہیں ایک مقرر وقت تک کے لیے مہلت دے رہا ہے پھر جب ان کا وقت آن پورا ہوگا تو اللہ اپنے بندوں کو دیکھ لے گا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccvi{\basmalahur یٰس\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccvii{قسم ہے قرآن حکیم کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccviii{کہ تم یقیناً رسولوں میں سے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccix{سیدھے راستے پر ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccx{(اور یہ قرآن) غالب اور رحیم ہستی کا نازل کردہ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxi{تاکہ تم خبردار کرو ایک ایسی قوم کو جس کے باپ دادا خبردار نہ کیے گئے تھے اور اس وجہ سے وہ غفلت میں پڑے ہوئے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxii{اِن میں سے اکثر لوگ فیصلہ عذاب کے مستحق ہو چکے ہیں، اسی لیے وہ ایمان نہیں لاتے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiii{ہم نے اُن کی گردنوں میں طوق ڈال دیے ہیں جن سے وہ ٹھوڑیوں تک جکڑے گئے ہیں، اس لیے وہ سر اٹھائے کھڑے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiv{ہم نے ایک دیوار اُن کے آگے کھڑی کر دی ہے اور ایک دیوار اُن کے پیچھے ہم نے انہیں ڈھانک دیا ہے، انہیں اب کچھ نہیں سوجھتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxv{ان کے لیے یکساں ہے، تم انہیں خبردار کرو یا نہ کرو، یہ نہ مانیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvi{تم تو اُسی شخص کو خبردار کر سکتے ہی جو نصیحت کی پیروی کرے اور بے دیکھے خدائے رحمان سے ڈرے اُسے مغفرت اور اجر کریم کی بشارت دے دو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvii{ہم یقیناً ایک روز مردوں کو زندہ کرنے والے ہیں جو کچھ افعال انہوں نے کیے ہیں وہ سب ہم لکھتے جا رہے ہیں، اور جو کچھ آثار انہوں نے پیچھے چھوڑے ہیں وہ بھی ہم ثبت کر رہے ہیں ہر چیز کو ہم نے ایک کھلی کتاب میں درج کر رکھا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccxviii{اِنہیں مثال کے طور پر اُس بستی والوں کا قصہ سناؤ جبکہ اُس میں رسول آئے تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdccxix{ہم نے ان کی طرف دو رسول بھیجے اور انہوں نے دونوں کو جھٹلا دیا پھر ہم نے تیسرا مدد کے لیے بھیجا اور ان سب نے کہا ``ہم تمہاری طرف رسول کی حیثیت سے بھیجے گئے ہیں"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccxx{بستی والوں نے کہا ``تم کچھ نہیں ہو مگر ہم جیسے چند انسان، اور خدائے رحمٰن نے ہرگز کوئی چیز نازل نہیں کی ہے، تم محض جھوٹ بولتے ہو"\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxi{رسولوں نے کہا ``ہمارا رب جانتا ہے کہ ہم ضرور تمہاری طرف رسول بنا کر بھیجے گئے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxii{اور ہم پر صاف صاف پیغام پہنچا دینے کے سوا کوئی ذمہ داری نہیں ہے"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiii{بستی والے کہنے لگے ``ہم تو تمہیں اپنے لیے فال بد سمجھتے ہیں اگر تم باز نہ آئے تو ہم تم کو سنگسار کر دیں گے اور ہم سے تم بڑی دردناک سزا پاؤ گے"\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiv{رسولوں نے جواب دیا ``تمہاری فال بد تو تمہارے اپنے ساتھ لگی ہوئی ہے کیا یہ باتیں تم اِس لیے کرتے ہو کہ تمہیں نصیحت کی گئی؟ اصل بات یہ ہے کہ تم حد سے گزرے ہوئے لوگ ہو"\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxv{اتنے میں شہر کے دُور دراز گوشے سے ایک شخص دوڑتا ہوا آیا اور بولا ``اے میری قوم کے لوگو، رسولوں کی پیروی اختیار کر لو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvi{پیروی کرو اُن لوگوں کی جو تم سے کوئی اجر نہیں چاہتے اور ٹھیک راستے پر ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvii{آخر کیوں نہ میں اُس ہستی کی بندگی کروں جس نے مجھے پیدا کیا ہے اور جس کی طرف تم سب کو پلٹ کر جانا ہے؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxviii{کیا میں اُسے چھوڑ کر دوسرے معبود بنا لوں؟ حالانکہ اگر خدائے رحمٰن مجھے کوئی نقصان پہنچانا چاہے تو نہ اُن کی شفاعت میرے کسی کام آ سکتی ہے اور نہ وہ مجھے چھڑا ہی سکتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxix{اگر میں ایسا کروں تو میں صریح گمراہی میں مبتلا ہو جاؤں گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxx{میں تو تمہارے رب پر ایمان لے آیا، تم بھی میری بات مان لو"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxi{(آخرکار ان لوگوں نے اسے قتل کر دیا اور) اس شخص سے کہہ دیا گیا کہ ``داخل ہو جا جنت میں" اُس نے کہا ``کاش میری قوم کو معلوم ہوتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxii{کہ میرے رب نے کس چیز کی بدولت میری مغفرت فرما دی اور مجھے با عزت لوگوں میں داخل فرمایا"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiii{اس کے بعد اُس کی قوم پر ہم نے آسمان سے کوئی لشکر نہیں اتارا ہمیں لشکر بھیجنے کی کوئی حاجت نہ تھی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiv{بس ایک دھماکہ ہوا اور یکایک وہ سب بجھ کر رہ گئے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxv{افسوس بندوں کے حال پر، جو رسول بھی ان کے پاس آیا اُس کا وہ مذاق ہی اڑاتے رہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvi{کیا انہوں نے دیکھا نہیں کہ ان سے پہلے کتنی ہی قوموں کو ہم ہلاک کر چکے ہیں اور اس کے بعد وہ پھر کبھی ان کی طرف پلٹ کر نہ آئے؟\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvii{ان سب کو ایک روز ہمارے سامنے حاضر کیا جانا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxviii{اِن لوگوں کے لئے بے جان زمین ایک نشانی ہے ہم نے اس کو زندگی بخشی اور اس سے غلہ نکالا جسے یہ کھاتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxix{ہم نے اس میں کھجوروں اور انگوروں کے باغ پیدا کیے اور اس کے اندر چشمے پھوڑ نکالے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdccxl{تاکہ یہ اس کے پھل کھائیں یہ سب کچھ ان کے اپنے ہاتھوں کا پیدا کیا ہوا نہیں ہے پھر کیا یہ شکر ادا نہیں کرتے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdccxli{پاک ہے وہ ذات جس نے جملہ اقسام کے جوڑے پیدا کیے خواہ وہ زمین کی نباتات میں سے ہوں یا خود اِن کی اپنی جنس (یعنی نوع انسانی) میں سے یا اُن اشیاء میں سے جن کو یہ جانتے تک نہیں ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlii{اِن کے لیے ایک اور نشانی رات ہے، ہم اُس کے اوپر سے دن ہٹا دیتے ہیں تو اِن پر اندھیرا چھا جاتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliii{اور سورج، وہ اپنے ٹھکانے کی طرف چلا جا رہا ہے یہ زبردست علیم ہستی کا باندھا ہوا حساب ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliv{اور چاند، اُس کے لیے ہم نے منزلیں مقرر کر دی ہیں یہاں تک کہ ان سے گزرتا ہوا وہ پھر کھجور کی سوکھی شاخ کے مانند رہ جاتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlv{نہ سورج کے بس میں یہ ہے کہ وہ چاند کو جا پکڑے اور نہ رات دن پر سبقت لے جا سکتی ہے سب ایک ایک فلک میں تیر رہے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvi{اِن کے لیے یہ بھی ایک نشانی ہے کہ ہم نے اِن کی نسل کو بھری ہوئی کشتی میں سوار کر دیا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvii{اور پھر اِن کے لیے ویسی ہی کشتیاں اور پیدا کیں جن پر یہ سوار ہوتے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlviii{ہم چاہیں تو اِن کو غرق کر دیں، کوئی اِن کی فریاد سننے والا نہ ہو اور کسی طرح یہ نہ بچائے جا سکیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlix{بس ہماری رحمت ہی ہے جو انہیں پار لگاتی اور ایک وقت خاص تک زندگی سے متمتع ہونے کا موقع دیتی ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccl{اِن لوگوں سے جب کہا جاتا ہے کہ بچو اُس انجام سے جو تمہارے آگے آ رہا ہے اور تمہارے پیچھے گزر چکا ہے، شاید کہ تم پر رحم کیا جائے (تو یہ سنی اَن سنی کر جاتے ہیں)\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccli{اِن کے سامنے اِن کے رب کی آیات میں سے جو آیت بھی آتی ہے یہ اس کی طرف التفات نہیں کرتے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcclii{اور جب اِن سے کہا جاتا ہے کہ اللہ نے جو رزق تمہیں عطا کیا ہے اُس میں سے کچھ اللہ کی راہ میں بھی خرچ کرو تو یہ لوگ جنہوں نے کفر کیا ہے ایمان لانے والوں کو جواب دیتے ہیں ``کیا ہم اُن کو کھلائیں جنہیں اگر اللہ چاہتا تو خود کھلا دیتا؟ تم تو بالکل ہی بہک گئے ہو"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdccliii{یہ لوگ کہتے ہیں کہ ``یہ قیامت کی دھمکی آخر کب پوری ہو گی؟ بتاؤ اگر تم سچے ہو"\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdccliv{دراصل یہ جس چیز کی راہ تک رہے ہیں وہ بس ایک دھماکا ہے جو یکایک اِنہیں عین اُس حالت میں دھر لے گا جب یہ (اپنے دنیوی معاملات میں) جھگڑ رہے ہوں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcclv{اور اُس وقت یہ وصیت تک نہ کر سکیں گے، نہ اپنے گھروں کو پلٹ سکیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvi{پھر ایک صور پھونکا جائے گا اور یکایک یہ اپنے رب کے حضور پیش ہونے کے لیے اپنی قبروں سے نکل پڑیں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvii{گھبرا کر کہیں گے: ``ارے، یہ کس نے ہمیں ہماری خواب گاہ سے اُٹھا کھڑا کیا؟" ``یہ وہی چیز ہے جس کا خدائے رحمان نے وعدہ کیا تھا اور رسولوں کی بات سچی تھی"\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcclviii{ایک ہی زور کی آواز ہو گی اور سب کے سب ہمارے سامنے حاضر کر دیے جائیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcclix{آج کسی پر ذرہ برابر ظلم نہ کیا جائے گا اور تمہیں ویسا ہی بدلہ دیا جائے گا جیسے عمل تم کرتے رہے تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcclx{آج جنتی لوگ مزے کرنے میں مشغول ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxi{وہ اور ان کی بیویاں گھنے سایوں میں ہیں مسندوں پر تکیے لگائے ہوئے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxii{ہر قسم کی لذیذ چیزیں کھانے پینے کو ان کے لیے وہاں موجود ہیں، جو کچھ وہ طلب کریں اُن کے لیے حاضر ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiii{رب رحیم کی طرف سے ان کو سلام کہا گیا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiv{اور اے مجرمو، آج تم چھٹ کر الگ ہو جاؤ\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxv{آدمؑ کے بچو، کیا میں نے تم کو ہدایت نہ کی تھی کہ شیطان کی بندگی نہ کرو، وہ تمہارا کھلا دشمن ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvi{اور میری ہی بندگی کرو، یہ سیدھا راستہ ہے؟\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvii{مگر اس کے باوجود اس نے تم میں سے ایک گروہ کثیر کو گمراہ کر دیا کیا تم عقل نہیں رکھتے تھے؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxviii{یہ وہی جہنم ہے جس سے تم کو ڈرایا جاتا رہا تھا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxix{جو کفر تم دنیا میں کرتے رہے ہو اُس کی پاداش میں اب اِس کا ایندھن بنو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxx{آج ہم اِن کے منہ بند کیے دیتے ہیں، اِن کے ہاتھ ہم سے بولیں گے اور ان کے پاؤں گواہی دیں گے کہ یہ دنیا میں کیا کمائی کرتے رہے ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxi{ہم چاہیں تو اِن کی آنکھیں موند دیں، پھر یہ راستے کی طرف لپک کر دیکھیں، کہاں سے اِنہیں راستہ سجھائی دے گا؟\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxii{ہم چاہیں تو اِنہیں اِن کی جگہ ہی پر اس طرح مسخ کر کے رکھ دیں کہ یہ نہ آگے چل سکیں نہ پیچھے پلٹ سکیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiii{جس شخص کو ہم لمبی عمر دیتے ہیں اس کی ساخت کو ہم الٹ ہی دیتے ہیں، کیا (یہ حالات دیکھ کر) انہیں عقل نہیں آتی؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiv{ہم نے اِس (نبی) کو شعر نہیں سکھایا ہے اور نہ شاعری اس کو زیب ہی دیتی ہے یہ تو ایک نصیحت ہے اور صاف پڑھی جانے والی کتاب\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxv{تاکہ وہ ہر اُس شخص کو خبردار کر دے جو زندہ ہو اور انکار کرنے والوں پر حجت قائم ہو جائے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvi{کیا یہ لوگ دیکھتے نہیں ہیں کہ ہم نے اپنے ہاتھوں کی بنائی ہوئی چیزوں میں سے اِن کے لیے مویشی پیدا کیے اور اب یہ ان کے مالک ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvii{ہم نے اُنہیں اس طرح اِن کے بس میں کر دیا ہے کہ اُن میں سے کسی پر یہ سوار ہوتے ہیں، کسی کا یہ گوشت کھاتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxviii{اور اُن کے اندر اِن کے لیے طرح طرح کے فوائد اور مشروبات ہیں پھر کیا یہ شکر گزار نہیں ہوتے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxix{یہ سب کچھ ہوتے ہوئے اِنہوں نے اللہ کے سوا دوسرے خدا بنا لیے ہیں اور یہ امید رکھتے ہیں کہ اِن کی مدد کی جائے گی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxx{وہ اِن کی کوئی مدد نہیں کر سکتے بلکہ یہ لوگ الٹے اُن کے لیے حاضر باش لشکر بنے ہوئے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxi{اچھا، جو باتیں یہ بنا رہے ہیں وہ تمہیں رنجیدہ نہ کریں، اِن کی چھپی اور کھلی سب باتوں کو ہم جانتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxii{کیا انسان دیکھتا نہیں ہے کہ ہم نے اسے نطفہ سے پیدا کیا اور پھر وہ صریح جھگڑالو بن کر کھڑا ہو گیا؟\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiii{اب وہ ہم پر مثالیں چسپاں کرتا ہے اور اپنی پیدائش کو بھول جاتا ہے کہتا ہے ``کون ان ہڈیوں کو زندہ کرے گا جبکہ یہ بوسیدہ ہو چکی ہوں؟"\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiv{اس سے کہو، اِنہیں وہی زندہ کرے گا جس نے پہلے انہیں پیدا کیا تھا، اور وہ تخلیق کا ہر کام جانتا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxv{وہی جس نے تمہارے لیے ہرے بھرے درخت سے آگ پیدا کر دی اور تم اس سے اپنے چولہے روشن کرتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvi{کیا وہ جس نے آسمانوں اور زمین کو پیدا کیا اِس پر قادر نہیں ہے کہ اِن جیسوں کو پیدا کر سکے؟ کیوں نہیں، جبکہ وہ ماہر خلاق ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvii{وہ تو جب کسی چیز کا ارادہ کرتا ہے تو اس کا کام بس یہ ہے کہ اسے حکم دے کہ ہو جا اور وہ ہو جاتی ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxviii{پاک ہے وہ جس کے ہاتھ میں ہر چیز کا مکمل اقتدار ہے، اور اسی کی طرف تم پلٹائے جانے والے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxix{\basmalahur قطار در قطار صف باندھنے والوں کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccxc{پھر اُن کی قسم جو ڈانٹنے پھٹکارنے والے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccxci{پھر اُن کی قسم جو کلام نصیحت سنانے والے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcii{تمہارا معبود حقیقی بس ایک ہی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciii{وہ جو زمین اور آسمانوں کا اور تمام اُن چیزوں کا مالک ہے جو زمین و آسمان میں ہیں، اور سارے مشرقوں کا مالک\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciv{ہم نے آسمان دنیا کو تاروں کی زینت سے آراستہ کیا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcv{اور ہر شیطان سرکش سے اس کو محفوظ کر دیا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvi{یہ شیاطین ملاء اعلیٰ کی باتیں نہیں سن سکتے، ہر طرف سے مارے اور ہانکے جاتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvii{اور ان کے لیے پیہم عذاب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcviii{تاہم اگر کوئی ان میں سے کچھ لے اڑے تو ایک تیز شعلہ اس کا پیچھا کرتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcix{اب اِن سے پوچھو، اِن کی پیدائش زیادہ مشکل ہے یا اُن چیزوں کی جو ہم نے پیدا کر رکھی ہیں؟ اِن کو تو ہم نے لیس دار گارے سے پیدا کیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccc{تم (اللہ کی قدرت کے کرشموں پر) حیران ہو اور یہ اس کا مذاق اڑا رہے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccci{سمجھایا جاتا ہے تو سمجھ کر نہیں دیتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcccii{کوئی نشانی دیکھتے ہیں تو اسے ٹھٹھوں میں اڑاتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccciii{اور کہتے ہیں ``یہ تو صریح جادو ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccciv{بھلا کہیں ایسا ہو سکتا ہے کہ جب ہم مر چکے ہوں اور مٹی بن جائیں اور ہڈیوں کا پنجر رہ جائیں اُس وقت ہم پھر زندہ کر کے اٹھا کھڑے کیے جائیں؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcccv{اور کیا ہمارے اگلے وقتوں کے آبا و اجداد بھی اٹھائے جائیں گے؟"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvi{اِن سے کہو ہاں، اور تم (خدا کے مقابلے میں) بے بس ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvii{بس ایک ہی جھڑکی ہو گی اور یکایک یہ اپنی آنکھوں سے (وہ سب کچھ جس کی خبر دی جا رہی ہے) دیکھ رہے ہوں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcccviii{اُس وقت یہ کہیں گے ``ہائے ہماری کم بختی، یہ تو یوم الجزا ہے"\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcccix{``یہ وہی فیصلے کا دن ہے جسے تم جھٹلایا کرتے تھے"\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcccx{(حکم ہو گا) گھیر لاؤ سب ظالموں اور ان کے ساتھیوں اور اُن معبودوں کو جن کی وہ خدا کو چھوڑ کر بندگی کیا کرتے تھے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxi{پھر ان سب کو جہنم کا راستہ دکھاؤ\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxii{اور ذرا اِنہیں ٹھیراؤ، اِن سے کچھ پوچھنا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiii{``کیا ہو گیا تمہیں، اب کیوں ایک دوسرے کی مدد نہیں کرتے؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiv{ارے، آج تو یہ اپنے آپ کو (اور ایک دوسرے کو) حوالے کیے دے رہے ہیں!"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxv{اس کے بعد یہ ایک دوسرے کی طرف مڑیں گے اور باہم تکرار شروع کر دیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvi{(پیروی کرنے والے اپنے پیشواؤں سے) کہیں گے، ``تم ہمارے پاس سیدھے رخ سے آتے تھے"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvii{وہ جواب دیں گے، ``نہیں بلکہ تم خود ایمان لانے والے نہ تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxviii{ہمارا تم پر کوئی زور نہ تھا، تم خود ہی سرکش لوگ تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxix{آخرکار ہم اپنے رب کے اِس فرمان کے مستحق ہو گئے کہ ہم عذاب کا مزا چکھنے والے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxx{سو ہم نے تم کو بہکا یا، ہم خود بہکے ہوئے تھے"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxi{اِس طرح وہ سب اُس روز عذاب میں مشترک ہوں گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxii{ہم مجرموں کے ساتھ یہی کچھ کیا کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiii{یہ وہ لوگ تھے کہ جب ان سے کہا جاتا ``اللہ کے سوا کوئی معبود بر حق نہیں ہے" تو یہ گھمنڈ میں آ جاتے تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiv{اور کہتے تھے ``کیا ہم ایک شاعر مجنون کی خاطر اپنے معبودوں کو چھوڑ دیں؟"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxv{حالانکہ وہ حق لے کر آیا تھا اور اس نے رسولوں کی تصدیق کی تھی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvi{(اب ان سے کہا جائے گا کہ) تم لازماً دردناک سزا کا مزا چکھنے والے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvii{اور تمہیں جو بدلہ بھی دیا جا رہا ہے اُنہی اعمال کا دیا جا رہا ہے جو تم کرتے رہے ہو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxviii{مگر اللہ کے چیدہ بندے (اس انجام بد سے) محفوظ ہوں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxix{ان کے لیے جانا بوجھا رزق ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxx{ہر طرح کی لذیذ چیزیں،\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxi{اور نعمت بھری جنتیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxii{جن میں وہ عزت کے ساتھ رکھے جائیں گے تختوں پر آمنے سامنے بیٹھیں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiii{شراب کے چشموں سے ساغر بھر بھر کر ان کے درمیان پھرائے جائیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiv{چمکتی ہوئی شراب، جو پینے والوں کے لیے لذّت ہو گی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxv{نہ ان کے جسم کو اس سے کوئی ضرر ہوگا اور نہ ان کی عقل اس سے خراب ہو گی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvi{اور ان کے پاس نگاہیں بچانے والی، خوبصورت آنکھوں والی عورتیں ہوں گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvii{ایسی نازک جیسے انڈے کے چھلکے کے نیچے چھپی ہوئی جھلی\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxviii{پھر وہ ایک دوسرے کی طرف متوجہ ہو کر حالات پوچھیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxix{ان میں سے ایک کہے گا، ``دنیا میں میرا ایک ہم نشین تھا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxl{جو مجھ سے کہا کرتا تھا، کیا تم بھی تصدیق کرنے والوں میں سے ہو؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxli{کیا واقعی جب ہم مر چکے ہوں گے اور مٹی ہو جائیں گے اور ہڈیوں کا پنجر بن کر رہ جائیں گے تو ہمیں جزا و سزا دی جائے گی؟\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlii{اب کیا آپ لوگ دیکھنا چاہتے ہیں کہ وہ صاحب اب کہاں ہیں؟"\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliii{یہ کہہ کر جونہی وہ جھکے گا تو جہنم کی گہرائی میں اس کو دیکھ لے گا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliv{اور اس سے خطاب کر کے کہے گا ``خدا کی قسم، تُو تو مجھے تباہ ہی کر دینے والا تھا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlv{میرے رب کا فضل شامل حال نہ ہوتا تو آج میں بھی اُن لوگوں میں سے ہوتا جو پکڑے ہوئے آئے ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvi{اچھا تو کیا اب ہم مرنے والے نہیں ہیں؟\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvii{موت جو ہمیں آنی تھی وہ بس پہلے آ چکی؟ اب ہمیں کوئی عذاب نہیں ہونا؟"\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlviii{یقیناً یہی عظیم الشان کامیابی ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlix{ایسی ہی کامیابی کے لیے عمل کرنے والوں کو عمل کرنا چاہیے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcccl{بولو، یہ ضیافت اچھی ہے یا زقوم کا درخت؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcccli{ہم نے اُس درخت کو ظالموں کے لیے فتنہ بنا دیا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdccclii{وہ ایک درخت ہے جو جہنم کی تہ سے نکلتا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliii{اُس کے شگوفے ایسے ہیں جیسے شیطانوں کے سر\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliv{جہنم کے لوگ اُسے کھائیں گے اور اسی سے پیٹ بھریں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdccclv{پھر اس پر پینے کے لیے کھولتا ہوا پانی ملے گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvi{اور اس کے بعد ان کی واپسی اُسی آتش دوزخ کی طرف ہو گی\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvii{یہ وہ لوگ ہیں جنہوں نے اپنے باپ دادا کو گمراہ پایا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdccclviii{اور انہی کے نقش قدم پر دوڑ چلے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdccclix{حالانکہ ان سے پہلے بہت سے لوگ گمراہ ہو چکے تھے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdccclx{اور اُن میں ہم نے تنبیہ کرنے والے رسول بھیجے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxi{اب دیکھ لو کہ اُن تنبیہ کیے جانے والوں کا کیا انجام ہوا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxii{اس بد انجامی سے بس اللہ کے وہی بندے بچے ہیں جنہیں اس نے اپنے لیے خالص کر لیا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiii{ہم کو (اِس سے پہلے) نوحؑ نے پکارا تھا، تو دیکھو کہ ہم کیسے اچھے جواب دینے والے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiv{ہم نے اُس کو اور اس کے گھر والوں کو کرب عظیم سے بچا لیا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxv{اور اسی کی نسل کو باقی رکھا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvi{اور بعد کی نسلوں میں اس کی تعریف و توصیف چھوڑ دی\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvii{سلام ہے نوحؑ پر تمام دنیا والوں میں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxviii{ہم نیکی کرنے والوں کو ایسی ہی جزا دیا کرتے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxix{در حقیقت وہ ہمارے مومن بندوں میں سے تھا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxx{پھر دوسرے گروہ کو ہم نے غرق کر دیا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxi{اور نوحؑ ہی کے طریقے پر چلنے والا ابراہیمؑ تھا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxii{جب وہ اپنے رب کے حضور قلب سلیم لے کر آیا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiii{جب اُس نے اپنے باپ اور اپنی قوم سے کہا ``یہ کیا چیزیں ہیں جن کی تم عبادت کر رہے ہو؟\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiv{کیا اللہ کو چھوڑ کر جھوٹ گھڑے ہوئے معبود چاہتے ہو؟\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxv{آخر اللہ ربّ العالمین کے بارے میں تمہارا کیا گمان ہے؟"\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvi{پھر اس نے تاروں پر ایک نگاہ ڈالی\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvii{اور کہا میری طبیعت خراب ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxviii{چنانچہ وہ لوگ اسے چھوڑ کر چلے گئے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxix{اُن کے پیچھے وہ چپکے سے اُن کے معبودوں کے مندر میں گھس گیا اور بولا `` آپ لوگ کھاتے کیوں نہیں ہیں؟\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxx{کیا ہو گیا، آپ لوگ بولتے بھی نہیں؟"\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxi{اس کے بعد وہ اُن پر پل پڑا اور سیدھے ہاتھ سے خوب ضربیں لگائیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxii{(واپس آ کر) وہ لوگ بھاگے بھاگے اس کے پاس آئے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiii{اس نے کہا ``کیا تم اپنی ہی تراشی ہوئی چیزوں کو پوجتے ہو؟\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiv{حالانکہ اللہ ہی نے تم کو بھی پیدا کیا ہے اور اُن چیزوں کو بھی جنہیں تم بناتے ہو"\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxv{انہوں نے آپس میں کہا ``اس کے لیے ایک الاؤ تیار کرو اور اسے دہکتی ہوئی آگ کے ڈھیر میں پھینک دو"\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvi{انہوں نے اس کے خلاف ایک کاروائی کرنی چاہی تھی، مگر ہم نے انہی کو نیچا دکھا دیا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvii{ابراہیمؑ نے کہا ``میں اپنے رب کی طرف جاتا ہوں، وہی میری رہنمائی کرے گا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxviii{اے پروردگار، مجھے ایک بیٹا عطا کر جو صالحوں میں سے ہو"\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxix{(اس دعا کے جواب میں) ہم نے اس کو ایک حلیم (بردبار) لڑکے کی بشارت دی\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxc{وہ لڑکا جب اس کے ساتھ دوڑ دھوپ کرنے کی عمر کو پہنچ گیا تو (ایک روز) ابراہیمؑ نے اس سے کہا، ``بیٹا، میں خواب میں دیکھتا ہوں کہ میں تجھے ذبح کر رہا ہوں، اب تو بتا، تیرا کیا خیال ہے؟" اُس نے کہا، ``ابا جان، جو کچھ آپ کو حکم دیا جا رہا ہے اسے کر ڈالیے، آپ انشاءاللہ مجھے صابروں میں سے پائیں گے"\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxci{آخر کو جب اِن دونوں نے سر تسلیم خم کر دیا اور ابراہیمؑ نے بیٹے کو ماتھے کے بل گرا دیا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcii{اور ہم نے ندا دی کہ ``اے ابراہیمؑ\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciii{تو نے خواب سچ کر دکھایا ہم نیکی کرنے والوں کو ایسی ہی جزا دیتے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciv{یقیناً یہ ایک کھلی آزمائش تھی"\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcv{اور ہم نے ایک بڑی قربانی فدیے میں دے کر اس بچے کو چھڑا لیا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvi{اور اس کی تعریف و توصیف ہمیشہ کے لیے بعد کی نسلوں میں چھوڑ دی\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvii{سلام ہے ابراہیمؑ پر\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcviii{ہم نیکی کرنے والوں کو ایسی ہی جزا دیتے ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcix{یقیناً وہ ہمارے مومن بندوں میں سے تھا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmcm{اور ہم نے اسے اسحاقؑ کی بشارت دی، ایک نبی صالحین میں سے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmcmi{اور اسے اور اسحاقؑ کو برکت دی اب ان دونوں کی ذریّت میں سے کوئی محسن ہے اور کوئی اپنے نفس پر صریح ظلم کرنے والا ہے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmcmii{اور ہم نے موسیٰؑ و ہارونؑ پر احسان کیا\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmcmiii{اُن کو اور ان کی قوم کو کرب عظیم سے نجات دی\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmcmiv{اُنہیں نصرت بخشی جس کی وجہ سے وہی غالب رہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmcmv{ان کو نہایت واضح کتاب عطا کی\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmmcmvi{انہیں راہ راست دکھائی\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmcmvii{اور بعد کی نسلوں میں ان کا ذکر خیر باقی رکھا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmcmviii{سلام ہے موسیٰؑ اور ہارونؑ پر\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmcmix{ہم نیکی کرنے والوں کو ایسی ہی جزا دیتے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmcmx{در حقیقت وہ ہمارے مومن بندوں میں سے تھے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmcmxi{اور الیاسؑ بھی یقیناً مرسلین میں سے تھا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmcmxii{یاد کرو جب اس نے اپنی قوم سے کہا تھا کہ ``تم لوگ ڈرتے نہیں ہو؟\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiii{کیا تم بعل کو پکارتے ہو اور احسن الخالقین کو چھوڑ دیتے ہو\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiv{اُس اللہ کو جو تمہارا اور تمہارے اگلے پچھلے آبا و اجداد کا رب ہے؟"\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmcmxv{مگر انہوں نے اسے جھٹلا دیا، سو اب یقیناً وہ سزا کے لیے پیش کیے جانے والے ہیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvi{بجز اُن بندگان خدا کے جن کو خالص کر لیا گیا تھا\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvii{اور الیاسؑ کا ذکر خیر ہم نے بعد کی نسلوں میں باقی رکھا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmcmxviii{سلام ہے الیاسؑ پر\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmcmxix{ہم نیکی کرنے والوں کو ایسی ہی جزا دیتے ہیں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmcmxx{واقعی وہ ہمارے مومن بندوں میں سے تھا\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxi{اور لوطؑ بھی انہی لوگوں میں سے تھا جو رسول بنا کر بھیجے گئے ہیں\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxii{یاد کرو جب ہم نے اس کو اور اس کے سب گھر والوں کو نجات دی\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiii{سوائے ایک بڑھیا کے جو پیچھے رہ جانے والوں میں سے تھی\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiv{پھر باقی سب کو تہس نہس کر دیا\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxv{آج تم شب و روز اُن کے اجڑے دیار پر سے گزرتے ہو\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvi{کیا تم کو عقل نہیں آتی؟\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvii{اور یقیناً یونسؑ بھی رسولوں میں سے تھا\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxviii{یاد کرو جب وہ ایک بھری کشتی کی طرف بھاگ نکلا\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxix{پھر قرعہ اندازی میں شریک ہوا اور اس میں مات کھائی\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxx{آخرکار مچھلی نے اسے نگل لیا اور وہ ملامت زدہ تھا\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxi{اب اگر وہ تسبیح کرنے والوں میں سے نہ ہوتا تو\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxii{روز قیامت تک اسی مچھلی کے پیٹ میں رہتا\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiii{آخرکار ہم نے اسے بڑی سقیم حالت میں ایک چٹیل زمین پر پھینک دیا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiv{اور اُس پر ایک بیل دار درخت اگا دیا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxv{اس کے بعد ہم نے اُسے ایک لاکھ، یا اس سے زائد لوگوں کی طرف بھیجا\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvi{وہ ایمان لائے اور ہم نے ایک وقت خاص تک انہیں باقی رکھا\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvii{پھر ذرا اِن لوگوں سے پوچھو، کیا (اِن کے دل کو یہ بات لگتی ہے کہ) تمہارے رب کے لیے تو ہوں بیٹیاں اور ان کے لیے ہوں بیٹے!\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxviii{کیا واقعی ہم نے ملائکہ کو عورتیں ہی بنا یا ہے اور یہ آنکھوں دیکھی بات کہہ رہے ہیں؟\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxix{خوب سن رکھو، دراصل یہ لوگ اپنی من گھڑت سے یہ بات کہتے ہیں\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmcmxl{کہ اللہ اولاد رکھتا ہے، اور فی الواقع یہ جھوٹے ہیں\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmcmxli{کیا اللہ نے بیٹوں کے بجائے بیٹیاں اپنے لیے پسند کر لیں؟\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlii{تمہیں کیا ہو گیا ہے، کیسے حکم لگا رہے ہو\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliii{کیا تمہیں ہوش نہیں آتا\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliv{یا پھر تمہارے پاس اپنی ان باتوں کے لیے کوئی صاف سند ہے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlv{تو لاؤ اپنی وہ کتاب اگر تم سچے ہو\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvi{اِنہوں نے اللہ اور ملائکہ کے درمیان نسب کا رشتہ بنا رکھا ہے، حالانکہ ملائکہ خوب جانتے ہیں کہ یہ لوگ مجرم کی حیثیت سے پیش ہونے والے ہیں\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvii{(اور وہ کہتے ہیں کہ) ``اللہ اُن صفات سے پاک ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlviii{جو اُس کے خالص بندوں کے سوا دوسرے لوگ اس کی طرف منسوب کرتے ہیں\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlix{پس تم اور تمہارے یہ معبود\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmcml{اللہ سے کسی کو پھیر نہیں سکتے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmcmli{مگر صرف اُس کو جو دوزخ کی بھڑکتی ہوئی آگ میں جھلسنے والا ہو\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmcmlii{اور ہمارا حال تو یہ ہے کہ ہم میں سے ہر ایک کا ایک مقام مقرر ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmcmliii{اور ہم صف بستہ خدمت گار ہیں\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmcmliv{اور تسبیح کرنے والے ہیں"\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmcmlv{یہ لوگ پہلے تو کہا کرتے تھے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvi{کہ کاش ہمارے پاس وہ ``ذکر" ہوتا جو پچھلی قوموں کو ملا تھا\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvii{تو ہم اللہ کے چیدہ بندے ہوتے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcmlviii{مگر (جب وہ آ گیا) تو انہوں نے اس کا انکار کر دیا اب عنقریب اِنہیں (اِس روش کا نتیجہ) معلوم ہو جائے گا\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmcmlix{اپنے بھیجے ہوئے بندوں سے ہم پہلے ہی وعدہ کر چکے ہیں\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmcmlx{کہ یقیناً ان کی مدد کی جائے گی\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxi{اور ہمارا لشکر ہی غالب ہو کر رہے گا\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxii{پس اے نبیؐ، ذرا کچھ مدّت تک انہیں اِن کے حال پر چھوڑ دو\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiii{اور دیکھتے رہو، عنقریب یہ خود بھی دیکھ لیں گے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiv{کیا یہ ہمارے عذاب کے لیے جلدی مچا رہے ہیں؟\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxv{جب وہ اِن کے صحن میں آ اترے گا تو وہ دن اُن لوگوں کے لیے بہت برا ہو گا جنہیں متنبہ کیا جا چکا ہے\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvi{بس ذرا اِنہیں کچھ مدت کے لیے چھوڑ دو\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvii{اور دیکھتے رہو، عنقریب یہ خود دیکھ لیں گے\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxviii{پاک ہے تیرا رب، عزت کا مالک، اُن تمام باتوں سے جو یہ لوگ بنا رہے ہیں\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxix{اور سلام ہے مرسلین پر\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxx{اور ساری تعریف اللہ ربّ العالمین ہی کے لیے ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxi{\basmalahur ص، قسم ہے نصیحت بھرے قرآن کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxii{بلکہ یہی لوگ، جنہوں نے ماننے سے انکار کیا ہے، سخت تکبر اور ضد میں مبتلا ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiii{اِن سے پہلے ہم ایسی کتنی ہی قوموں کو ہلاک کر چکے ہیں (اور جب اُن کی شامت آئی ہے) تو وہ چیخ اٹھے ہیں، مگر وہ وقت بچنے کا نہیں ہوتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiv{اِن لوگوں کو اس بات پر بڑا تعجب ہوا کہ ایک ڈرانے والا خود اِنہی میں سے آگیا منکرین کہنے لگے کہ ``یہ ساحرہے، سخت جھوٹا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxv{کیا اِس نے سارے خداؤں کی جگہ بس ایک ہی خدا بنا ڈالا؟ یہ تو بڑی عجیب بات ہے"\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvi{اور سرداران قوم یہ کہتے ہوئے نکل گئے کہ ``چلو اور ڈٹے رہو اپنے معبودوں کی عبادت پر یہ بات تو کسی اور ہی غرض سے کہی جا رہی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvii{یہ بات ہم نے زمانہ قریب کی ملت میں کسی سے نہیں سنی یہ کچھ نہیں ہے مگر ایک من گھڑت بات\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxviii{کیا ہمارے درمیان بس یہی ایک شخص رہ گیا تھا جس پر اللہ کا ذکر نازل کر دیا گیا؟" اصل بات یہ ہے کہ یہ میرے ``ذکر"پر شک کر رہے ہیں، اور یہ ساری باتیں اس لیے کر رہے ہیں کہ انہوں نے میرے عذاب کا مزا چکھا نہیں ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxix{کیا تیرے داتا اور غالب پروردگار کی رحمت کے خزانے اِن کے قبضے میں ہیں؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxx{کیا یہ آسمان و زمین اور ان کے درمیان کی چیزوں کے مالک ہیں؟ اچھا تو یہ عالم اسباب کی بلندیوں پر چڑھ کر دیکھیں!\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxi{یہ تو جتھوں میں سے ایک چھوٹا سا جتھا ہے جو اِسی جگہ شکست کھانے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxii{اِن سے پہلے نوحؑ کی قوم، اور عاد، اور میخوں والا فرعون\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiii{اور ثمود، اور قوم لوط، اور اَیکہ والے جھٹلا چکے ہیں جتھے وہ تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiv{ان میں سے ہر ایک نے رسولوں کو جھٹلایا اور میری عقوبت کا فیصلہ اس پر چسپاں ہو کر رہا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxv{یہ لوگ بھی بس ایک دھماکے کے منتظر ہیں جس کے بعد کوئی دوسرا دھماکا نہ ہوگا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvi{اور یہ کہتے ہیں کہ اے ہمارے رب، یوم الحساب سے پہلے ہی ہمارا حصہ ہمیں جلدی سے دے دے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvii{اے نبیؐ، صبر کرو اُن باتوں پر جو یہ لوگ بناتے ہیں، اور اِن کے سامنے ہمارے بندے داؤدؑ کا قصہ بیان کرو جو بڑی قوتوں کا مالک تھا ہر معاملہ میں اللہ کی طرف رجوع کرنے والا تھا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxviii{ہم نے پہاڑوں کو اس کے ساتھ مسخر کر رکھا تھا کہ صبح و شام وہ اس کے ساتھ تسبیح کرتے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxix{پرندے سمٹ آتے اور سب کے سب اُس کی تسبیح کی طرف متوجہ ہو جاتے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcmxc{ہم نے اس کی سلطنت مضبوط کر دی تھے، اس کو حکمت عطا کی تھے اور فیصلہ کن بات کہنے کی صلاحیت بخشی تھی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcmxci{پھر تمہیں کچھ خبر پہنچی ہے اُن مقدمے والوں کی جو دیوار چڑھ کر اُس کے بالا خانے میں گھس آئے تھے؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcii{جب وہ داؤدؑ کے پاس پہنچے تو وہ انہیں دیکھ کر گھبرا گیا انہوں نے کہا ``ڈریے نہیں، ہم دو فریق مقدمہ ہیں جن میں سے ایک نے دوسرے پر زیادتی کی ہے آپ ہمارے درمیان ٹھیک ٹھیک حق کے ساتھ فیصلہ کر دیجیے، بے انصافی نہ کیجیے اور ہمیں راہ راست بتائیے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciii{یہ میرا بھائی ہے، اِس کے پاس ننانوے دنبیاں ہیں اور میرے پاس صرف ایک ہی دُنبی ہے اِس نے مجھ سے کہا کہ یہ ایک دنبی بھی میرے حوالے کر دے اور اس نے گفتگو میں مجھے دبا لیا"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciv{داؤدؑ نے جواب دیا: ``اِس شخص نے اپنی دنبیوں کے ساتھ تیری دنبی ملا لینے کا مطالبہ کر کے یقیناً تجھ پر ظلم کیا، اور واقعہ یہ ہے کہ مل جل کر ساتھ رہنے والے لوگ اکثر ایک دوسرے پر زیادتیاں کرتے رہتے ہیں، بس وہی لوگ اس سے بچے ہوئے ہیں جو ایمان رکھتے اور عمل صالح کرتے ہیں، اور ایسے لوگ کم ہی ہیں" (یہ بات کہتے کہتے) داؤدؑ سمجھ گیا کہ یہ تو ہم نے دراصل اس کی آزمائش کی ہے، چنانچہ اس نے اپنے رب سے معافی مانگی اور سجدے میں گر گیا اور رجوع کر لیا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcv{تب ہم نے اس کا وہ قصور معاف کیا اور یقیناً ہمارے ہاں اس کے لیے تقرب کا مقام اور بہتر انجام ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvi{(ہم نے اس سے کہا) ``اے داؤدؑ، ہم نے تجھے زمین میں خلیفہ بنایا ہے، لہٰذا تو لوگوں کے درمیان حق کے ساتھ حکومت کر اور خواہش نفس کی پیروی نہ کر کہ وہ تجھے اللہ کی راہ سے بھٹکا دے گی جو لوگ اللہ کی راہ سے بھٹکتے ہیں یقیناً اُن کے لیے سخت سزا ہے کہ وہ یوم الحساب کو بھول گئے"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvii{ہم نے اس آسمان اور زمین کو، اور اس دنیا کو جو ان کے درمیان ہے، فضول پیدا نہیں کر دیا ہے یہ تو اُن لوگوں کا گمان ہے جنہوں نے کفر کیا ہے، اور ایسے کافروں کے لیے بربادی ہے جہنم کی آگ سے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcviii{کیا ہم اُن لوگوں کو جو ایمان لاتے ہیں اور نیک اعمال کرتے ہیں اور اُن کو جو زمین میں فساد کرنے والے ہیں یکساں کر دیں؟ کیا متقیوں کو ہم فاجروں جیسا کر دیں؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcix{یہ ایک بڑی برکت والی کتاب ہے جو (اے محمدؐ) ہم نے تمہاری طرف نازل کی ہے تاکہ یہ لوگ اس کی آیات پر غور کریں اور عقل و فکر رکھنے والے اس سے سبق لیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmm{اور داؤدؑ کو ہم نے سلیمانؑ (جیسا بیٹا) عطا کیا، بہترین بندہ، کثرت سے اپنے رب کی طرف رجوع کرنے والا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmi{قابل ذکر ہے وہ موقع جب شام کے وقت اس کے سامنے خوب سدھے ہوئے تیز رو گھوڑے پیش کیے گئے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmii{تو اس نے کہا ``میں نے اس مال کی محبت اپنے رب کی یاد کی وجہ سے اختیار کی ہے" یہاں تک کہ جب وہ گھوڑے نگاہ سے اوجھل ہو گئے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmiii{تو (اس نے حکم دیا کہ) انہیں میرے پاس واپس لاؤ، پھر لگا ان کی پنڈلیوں اور گردنوں پر ہاتھ پھیرنے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmiv{اور (دیکھو کہ) سلیمانؑ کو بھی ہم نے آزمائش میں ڈالا اور اس کی کرسی پر ایک جسد لا کر ڈال دیا پھر اس نے رجوع کیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmv{اور کہا کہ ``اے میرے رب، مجھے معاف کر دے اور مجھے وہ بادشاہی دے جو میرے بعد کسی کے لیے سزاوار نہ ہو، بیشک تو ہی اصل داتا ہے"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmvi{تب ہم نے اس کے لیے ہوا کو مسخر کر دیا جو اس کے حکم سے نرمی کے ساتھ چلتی تھی جدھر وہ چاہتا تھا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmvii{اور شیاطین کو مسخر کر دیا، ہر طرح کے معمار اور غوطہ خور\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmviii{اور دوسرے جو پابند سلاسل تھے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmix{(ہم نے اُس سے کہا) ``یہ ہماری بخشش ہے، تجھے اختیار ہے جسے چاہے دے اور جس سے چاہے روک لے، کوئی حساب نہیں"\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmx{یقیناً اُس کے لیے ہمارے ہاں تقرب کا مقام اور بہتر انجام ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxi{اور ہمارے بندے ایوبؑ کا ذکر کرو، جب اس نے اپنے رب کو پکارا کہ شیطان نے مجھے سخت تکلیف اور عذاب میں ڈال دیا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmxii{(ہم نے اُسے حکم دیا) اپنا پاؤں زمین پر مار، یہ ہے ٹھنڈا پانی نہانے کے لیے اور پینے کے لیے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmxiii{ہم نے اُسے اس کے اہل و عیال واپس دیے اور ان کے ساتھ اتنے ہی اور، اپنی طرف سے رحمت کے طور پر، اور عقل و فکر رکھنے والوں کے لیے درس کے طور پر\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmxiv{(اور ہم نے اس سے کہا) تنکوں کا ایک مٹھا لے اور اُس سے مار دے، اپنی قسم نہ توڑ ہم نے اُسے صابر پایا، بہترین بندہ، اپنے رب کی طرف بہت رجوع کرنے والا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmxv{اور ہمارے بندوں، ابراہیمؑ اور اسحاقؑ اور یعقوبؑ کا ذکر کرو بڑی قوت عمل رکھنے والے اور دیدہ ور لوگ تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmxvi{ہم نے اُن کو ایک خالص صفت کی بنا پر برگزیدہ کیا تھا، اور وہ دار آخرت کی یاد تھی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmxvii{یقیناً ہمارے ہاں ان کا شمار چنے ہوئے نیک اشخاص میں ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmxviii{اور اسماعیلؑ اور الیسع اور ذوالکفلؑ کا ذکر کرو، یہ سب نیک لوگوں میں سے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmxix{یہ ایک ذکر تھا (اب سنو کہ) متقی لوگوں کے لیے یقیناً بہترین ٹھکانا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmxx{ہمیشہ رہنے والی جنتیں جن کے دروازے اُن کے لیے کھلے ہوں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmxxi{ان میں وہ تکیے لگائے بیٹھے ہوں گے، خوب خوب فواکہ اور مشروبات طلب کر رہے ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmxxii{اور ان کے پاس شرمیلی ہم سن بیویاں ہوں گی\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiii{یہ وہ چیزیں ہیں جنہیں حساب کے دن عطا کرنے کا تم سے وعدہ کیا جا رہا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiv{یہ ہمارا رزق ہے جو کبھی ختم ہونے والا نہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmxxv{یہ تو ہے متقیوں کا انجام اور سرکشوں کے لیے بدترین ٹھکانا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvi{جہنم جس میں وہ جھلسے جائیں گے، بہت ہی بری قیام گاہ\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvii{یہ ہے اُن کے لیے، پس وہ مزا چکھیں کھولتے ہوئے پانی اور پیپ لہو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmxxviii{اور اسی قسم کی دوسری تلخیوں کا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmxxix{(وہ جہنم کی طرف اپنے پیروؤں کو آتے دیکھ کر آپس میں کہیں گے) ``یہ ایک لشکر تمہارے پاس گھسا چلا آ رہا ہے، کوئی خوش آمدید اِن کے لیے نہیں ہے، یہ آگ میں جھلسنے والے ہیں"\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmxxx{وہ اُن کو جواب دیں گے ``نہیں بلکہ تم ہی جھلسے جا رہے ہو، کوئی خیر مقدم تمہارے لیے نہیں تم ہی تو یہ انجام ہمارے آگے لائے ہو، کیسی بری ہے یہ جائے قرار"\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxi{پھر وہ کہیں گے ``اے ہمارے رب، جس نے ہمیں اس انجام کو پہنچانے کا بندوبست کیا اُس کو دوزخ کا دوہرا عذاب دے"\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxii{اور وہ آپس میں کہیں گے ``کیا بات ہے، ہم اُن لوگوں کو کہیں نہیں دیکھتے جنہیں ہم دنیا میں برا سمجھتے تھے؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiii{ہم نے یونہی ان کا مذاق بنا لیا تھا، یا وہ کہیں نظروں سے اوجھل ہیں؟"\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiv{بے شک یہ بات سچی ہے، اہل دوزخ میں یہی کچھ جھگڑے ہونے والے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxv{(اے نبیؐ) اِن سے کہو، ``میں تو بس خبردار کر دینے والا ہوں کوئی حقیقی معبود نہیں مگر اللہ، جو یکتا ہے، سب پر غالب\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvi{آسمانوں اور زمین کا مالک اور اُن ساری چیزوں کا مالک جو ان کے درمیان ہیں، زبردست اور درگزر کرنے والا"\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvii{اِن سے کہو ``یہ ایک بڑی خبر ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxviii{جس کو سن کر تم منہ پھیرتے ہو"\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxix{(ان سے کہو) ``مجھے اُس وقت کی کوئی خبر نہ تھی جب ملاء اعلیٰ میں جھگڑا ہو رہا تھا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmxl{مجھ کو تو وحی کے ذریعہ سے یہ باتیں صرف اس لیے بتائی جاتی ہیں کہ میں کھلا کھلا خبردار کرنے والا ہوں"\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmxli{جب تیرے رب نے فرشتوں سے کہا ``میں مٹی سے ایک بشر بنانے والا ہوں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmxlii{پھر جب میں اسے پوری طرح بنا دوں اور اس میں اپنی روح پھونک دوں تو تم اس کے آگے سجدے میں گر جاؤ"\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmxliii{اس حکم کے مطابق فرشتے سب کے سب سجدے میں گر گئے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmxliv{مگر ابلیس نے اپنی بڑائی کا گھمنڈ کیا اور وہ کافروں میں سے ہو گیا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmxlv{رب نے فرمایا ``اے ابلیس، تجھے کیا چیز اُس کو سجدہ کرنے سے مانع ہوئی جسے میں نے اپنے دونوں ہاتھوں سے بنایا ہے؟ تو بڑا بن رہا ہے یا تو ہے ہی کچھ اونچے درجے کی ہستیوں میں سے؟"\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvi{اُس نے جواب دیا ``میں اُس سے بہتر ہوں، آپ نے مجھ کو آگ سے پیدا کیا ہے اور اس کو مٹی سے"\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvii{فرمایا ``اچھا تو یہاں سے نکل جا، تو مردود ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmxlviii{اور تیرے اوپر یوم الجزاء تک میری لعنت ہے"\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmxlix{وہ بولا ``ا ے میرے رب، یہ بات ہے تو پھر مجھے اُس وقت تک کے لیے مہلت دے دے جب یہ لوگ دوبارہ اٹھائے جائیں گے"\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmml{فرمایا، ``اچھا، تجھے اُس روز تک کی مہلت ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmli{جس کا وقت مجھے معلوم ہے"\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmlii{اس نے کہا ``تیری عزت کی قسم، میں اِن سب لوگو ں کو بہکا کر رہوں گا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmliii{بجز تیرے اُن بندوں کے جنہیں تو نے خالص کر لیا ہے"\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmliv{فرمایا ``تو حق یہ ہے، اور میں حق ہی کہا کرتا ہوں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmlv{کہ میں جہنم کو تجھ سے اور اُن سب لوگوں سے بھر دوں گا جو اِن انسانوں میں سے تیری پیروی کریں گے"\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmlvi{(اے نبیؐ) اِن سے کہہ دو کہ میں اس تبلیغ پر تم سے کوئی اجر نہیں مانگتا، اور نہ میں بناوٹی لوگوں میں سے ہوں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmlvii{یہ تو ایک نصیحت ہے تمام جہان والوں کے لیے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmlviii{اور تھوڑی مدت ہی گزرے گی کہ تمہیں اس کا حال خود معلوم ہو جائے گا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmlix{\basmalahur اِس کتاب کا نزول اللہ زبردست اور دانا کی طرف سے ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmlx{(اے محمدؐ) یہ کتاب ہم نے تمہاری طرف برحق نازل کی ہے، لہٰذا تم اللہ ہی کی بندگی کرو دین کو اُسی کے لیے خالص کرتے ہوئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmlxi{خبردار، دین خالص اللہ کا حق ہے رہے وہ لوگ جنہوں نے اُس کے سوا دوسرے سرپرست بنا رکھے ہیں (اور اپنے اِس فعل کی توجیہ یہ کرتے ہیں کہ) ہم تو اُن کی عبادت صرف اس لیے کرتے ہیں کہ وہ اللہ تک ہماری رسائی کرا دیں، اللہ یقیناً اُن کے درمیان اُن تمام باتوں کا فیصلہ کر دے گا جن میں وہ اختلاف کر رہے ہیں اللہ کسی ایسے شخص کو ہدایت نہیں دیتا جو جھوٹا اور منکر حق ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmlxii{اگر اللہ کسی کو بیٹا بنانا چاہتا تو اپنی مخلوق میں سے جس کو چاہتا برگزیدہ کر لیتا، پاک ہے وہ اس سے (کہ کوئی اُس کا بیٹا ہو)، وہ اللہ ہے اکیلا اور سب پر غالب\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiii{اس نے آسمانوں اور زمین کو برحق پیدا کیا ہے وہی دن پر رات اور رات پر دن کو لپیٹتا ہے اُسی نے سورج اور چاند کو اس طرح مسخر کر رکھا ہے کہ ہر ایک ایک وقت مقرر تک چلے جا رہا ہے جان رکھو، وہ زبردست ہے اور درگزر کرنے والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiv{اُسی نے تم کو ایک جان سے پیدا کیا، پھر وہی ہے جس نے اُس جان سے اس کا جوڑا بنایا اور اسی نے تمہارے لیے مویشیوں میں سے آٹھ نر و مادہ پیدا کیے وہ تمہاری ماؤں کے پیٹوں میں تین تین تاریک پردوں کے اندر تمہیں ایک کے بعد ایک شکل دیتا چلا جاتا ہے یہی اللہ (جس کے یہ کام ہیں) تمہارا رب ہے، بادشاہی اسی کی ہے، کوئی معبود اس کے سوا نہیں ہے، پھر تم کدھر سے پھرائے جا رہے ہو؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmlxv{اگر تم کفر کرو تو اللہ تم سے بے نیاز ہے، لیکن وہ اپنے بندوں کے لیے کفر کو پسند نہیں کرتا، اور اگر تم شکر کر و تو اسے وہ تمہارے لیے پسند کرتا ہے کوئی بوجھ اٹھانے والا کسی دوسرے کا بوجھ نہ اٹھائے گا آخرکار تم سب کو اپنے رب کی طرف پلٹنا ہے، پھر وہ تمہیں بتا دے گا کہ تم کیا کرتے رہے ہو، وہ تو دلوں کا حال تک جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvi{انسان پر جب کوئی آفت آتی ہے تو وہ اپنے رب کی طرف رجوع کر کے اُسے پکارتا ہے پھر جب اس کا رب اسے اپنی نعمت سے نواز دیتا ہے تو وہ اُس مصیبت کو بھول جاتا ہے جس پر وہ پہلے پکار رہا تھا اور دوسروں کو اللہ کا ہمسر ٹھیراتا ہے تاکہ اُس کی راہ سے گمراہ کرے (اے نبیؐ) اُس سے کہو کہ تھوڑے دن اپنے کفر سے لطف اٹھا لے، یقیناً تو دوزخ میں جانے والا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvii{(کیا اِس شخص کی روش بہتر ہے یا اُس شخص کی) جو مطیع فرمان ہے، رات کی گھڑیوں میں کھڑا رہتا اور سجدے کرتا ہے، آخرت سے ڈرتا اور اپنے رب کی رحمت سے امید لگاتا ہے؟ اِن سے پوچھو، کیا جاننے والے اور نہ جاننے والے دونوں کبھی یکساں ہو سکتے ہیں؟ نصیحت تو عقل رکھنے والے ہی قبول کرتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmlxviii{(اے نبیؐ) کہو کہ اے میرے بندو جو ایمان لائے ہو، اپنے رب سے ڈرو جن لوگوں نے اِس دنیا میں نیک رویہ اختیار کیا ہے ان کے لیے بھلائی ہے اور خدا کی زمین وسیع ہے، صبر کرنے والوں کو تو ان کا اجر بے حساب دیا جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmlxix{(اے نبیؐ) اِن سے کہو، مجھے حکم دیا گیا ہے کہ دین کو اللہ کے لیے خالص کر کے اُس کی بندگی کروں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmlxx{اور مجھے حکم دیا گیا ہے کہ سب سے پہلے میں خود مسلم بنوں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxi{کہو، اگر میں اپنے رب کی نافرمانی کروں تو مجھے ایک بڑے دن کے عذاب کا خوف ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxii{کہہ دو کہ میں تو اپنے دین کو اللہ کے لیے خالص کر کے اُسی کی بندگی کروں گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiii{تم اُس کے سوا جس جس کی بندگی کرنا چاہو کرتے رہو کہو، اصل دیوالیے تو وہی ہیں جنہوں نے قیامت کے روز اپنے آپ کو اور اپنے اہل و عیال کو گھاٹے میں ڈال دیا خوب سن رکھو، یہی کھلا دیوالہ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiv{اُن پر آگ کی چھتریاں اوپر سے بھی چھائی ہوں گی اور نیچے سے بھی یہ وہ انجام ہے جس سے اللہ اپنے بندوں کو ڈراتا ہے، پس اے میرے بندو، میرے غضب سے بچو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxv{بخلاف اس کے جن لوگوں نے طاغوت کی بندگی سے اجتناب کیا اور اللہ کی طرف رجوع کر لیا اُن کے لیے خوشخبری ہے پس (اے نبیؐ) بشارت دے دو میرے اُن بندوں کو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvi{جو بات کو غور سے سنتے ہیں اور اس کے بہترین پہلو کی پیروی کرتے ہیں یہ وہ لوگ ہیں جن کو اللہ نے ہدایت بخشی ہے اور یہی دانشمند ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvii{(اے نبیؐ) اُس شخص کو کون بچا سکتا ہے جس پر عذاب کا فیصلہ چسپاں ہو چکا ہو؟ کیا تم اُسے بچا سکتے ہو جو آگ میں گر چکا ہو؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxviii{البتہ جو لوگ اپنے رب سے ڈر کر رہے اُن کے لیے بلند عمارتیں ہیں منزل پر منزل بنی ہوئی، جن کے نیچے نہریں بہہ رہی ہوں گی یہ اللہ کا وعدہ ہے، اللہ کبھی اپنے وعدے کی خلاف ورزی نہیں کرتا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxix{کیا تم نہیں دیکھتے کہ اللہ نے آسمان سے پانی برسایا، پھر اس کو سوتوں اور چشموں اور دریاؤں کی شکل میں زمین کے اندر جاری کیا، پھر اس پانی کے ذریعہ سے وہ طرح طرح کی کھیتیاں نکالتا ہے جن کی قسمیں مختلف ہیں، پھر وہ کھیتیاں پک کر سوکھ جاتی ہیں، پھر تم دیکھتے ہو کہ وہ زرد پڑ گئیں، پھر آخرکار اللہ اُن کو بھس بنا دیتا ہے در حقیقت اِس میں ایک سبق ہے عقل رکھنے والوں کے لیے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxx{اب کیا وہ شخص جس کا سینہ اللہ نے اسلام کے لیے کھول دیا اور وہ اپنے رب کی طرف سے ایک روشنی پر چل رہا ہے (اُس شخص کی طرح ہو سکتا ہے جس نے اِن باتوں سے کوئی سبق نہ لیا؟) تباہی ہے اُن لوگوں کے لیے جن کے دل اللہ کی نصیحت سے اور زیادہ سخت ہو گئے وہ کھلی گمراہی میں پڑے ہوئے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxi{اللہ نے بہترین کلام اتارا ہے، ایک ایسی کتاب جس کے تمام اجزاء ہم رنگ ہیں اور جس میں بار بار مضامین دہرائے گئے ہیں اُسے سن کر اُن لوگوں کے رونگٹے کھڑے ہو جاتے ہیں جو اپنے رب سے ڈرنے والے ہیں، اور پھر ان کے جسم اور ان کے دل نرم ہو کر اللہ کے ذکر کی طرف راغب ہو جاتے ہیں یہ اللہ کی ہدایت ہے جس سے وہ راہ راست پر لے آتا ہے جسے چاہتا ہے اور جسے اللہ ہی ہدایت نہ دے اس کے لیے پھر کوئی ہادی نہیں ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxii{اب اُس شخص کی بد حالی کا تم کیا اندازہ کر سکتے ہو جو قیامت کے روز عذاب کی سخت مار اپنے منہ پر لے گا؟ ایسے ظالموں سے تو کہہ دیا جائے گا کہ اب چکھو مزہ اُس کمائی کا جو تم کرتے رہے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiii{اِن سے پہلے بھی بہت سے لوگ اسی طرح جھٹلا چکے ہیں آخر اُن پر عذاب ایسے رخ سے آیا جدھر ان کا خیال بھی نہ جا سکتا تھا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiv{پھر اللہ نے ان کو دنیا ہی کی زندگی میں رسوائی کا مزہ چکھایا، اور آخرت کا عذاب تو اس سے شدید تر ہے، کاش یہ لوگ جانتے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxv{ہم نے اِس قرآن میں لوگوں کو طرح طرح کی مثالیں دی ہیں کہ یہ ہوش میں آئیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvi{ایسا قرآن جو عربی زبان میں ہے، جس میں کوئی ٹیڑھ نہیں ہے، تاکہ یہ برے انجام سے بچیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvii{اللہ ایک مثال دیتا ہے ایک شخص تو وہ ہے جس کی ملکیت میں بہت سے کج خلق آقا شریک ہیں جو اسے اپنی اپنی طرف کھینچتے ہیں اور دوسرا شخص پورا کا پورا ایک ہی آقا کا غلام ہے کیا ان دونوں کا حال یکساں ہو سکتاہے؟ الحمدللہ، مگر اکثر لوگ نادانی میں پڑے ہوئے ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxviii{(اے نبیؐ) تمہیں بھی مرنا ہے اور اِن لوگوں کو بھی مرنا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxix{آخرکار قیامت کے روز تم سب اپنے رب کے حضور اپنا اپنا مقدمہ پیش کرو گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmxc{پھر اُس شخص سے بڑا ظالم اور کون ہو گا جس نے اللہ پر جھوٹ باندھا اور جب سچائی اس کے سامنے آئی تو اُسے جھٹلا دیا کیا ایسے کافروں کے لیے جہنم میں کوئی ٹھکانا نہیں ہے؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmxci{اور جو شخص سچائی لے کر آیا اور جنہوں نے اس کو سچ مانا، وہی عذاب سے بچنے والے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmxcii{انہیں اپنے رب کے ہاں وہ سب کچھ ملے گا جس کی وہ خواہش کریں گے یہ ہے نیکی کرنے والوں کی جزا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmxciii{تاکہ جو بد ترین اعمال انہوں نے کیے تھے انہیں اللہ ان کے حساب سے ساقط کر دے اور جو بہترین اعمال وہ کرتے رہے اُن کے لحاظ سے اُن کو اجر عطا فرمائے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmxciv{(اے نبیؐ) کیا اللہ اپنے بندے کے لیے کافی نہیں ہے؟ یہ لوگ اُس کے سوا دوسروں سے تم کو ڈراتے ہیں حالانکہ اللہ جسے گمراہی میں ڈال دے اُسے کوئی راستہ دکھانے والا نہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmxcv{اور جسے وہ ہدایت دے اُسے بھٹکانے والا بھی کوئی نہیں، کیا اللہ زبردست اور انتقام لینے والا نہیں ہے؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvi{اِن لوگوں سے اگر تم پوچھو کہ زمین اور آسمانوں کو کس نے پیدا کیا ہے تو یہ خود کہیں گے کہ اللہ نے اِن سے کہو، جب حقیقت یہ ہے تو تمہارا کیا خیال ہے کہ اگر اللہ مجھے کوئی نقصان پہنچانا چاہے تو کیا تمہاری یہ دیویاں، جنہیں تم اللہ کو چھوڑ کر پکارتے ہو، مجھے اُس کے پہنچائے ہوئے نقصان سے بچا لیں گی؟ یا اللہ مجھ پر مہربانی کرنا چاہے تو کیا یہ اس کی رحمت کو روک سکیں گی؟ بس ان سے کہہ دو کہ میرے لیے اللہ ہی کافی ہے، بھروسہ کرنے والے اُسی پر بھروسہ کرتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvii{ان سے صاف کہو کہ ``اے میری قوم کے لوگو، تم اپنی جگہ اپنا کام کیے جاؤ، میں اپنا کام کرتا رہوں گا، عنقریب تمہیں معلوم ہو جائے گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmxcviii{کہ کس پر رسوا کن عذاب آتا ہے اور کسے وہ سزا ملتی ہے جو کبھی ٹلنے والی نہیں"\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxcix{(اے نبیؐ) ہم نے سب انسانوں کے لیے یہ کتاب برحق تم پر نازل کر دی ہے اب جو سیدھا راستہ اختیار کرے گا اپنے لیے کرے گا اور جو بھٹکے گا اُس کے بھٹکنے کا وبال اُسی پر ہوگا، تم اُن کے ذمہ دار نہیں ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmc{وہ اللہ ہی ہے جو موت کے وقت روحیں قبض کرتا ہے اور جو ابھی نہیں مرا ہے اُس کی روح نیند میں قبض کر لیتا ہے، پھر جس پر وہ موت کا فیصلہ نافذ کرتا ہے اُسے روک لیتا ہے اور دوسروں کی روحیں ایک وقت مقرر کے لیے واپس بھیج دیتا ہے اِس میں بڑی نشانیاں ہیں اُن لوگوں کے لیے جو غور و فکر کرنے والے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmci{کیا اُس خدا کو چھوڑ کر اِن لوگوں نے دوسروں کو شفیع بنا رکھا ہے؟ ان سے کہو، کیا وہ شفاعت کریں گے خواہ اُن کے اختیار میں کچھ نہ ہو اور وہ سمجھتے بھی نہ ہوں؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcii{کہو، شفاعت ساری کی ساری اللہ کے اختیار میں ہے آسمانوں اور زمین کی بادشاہی کا وہی مالک ہے پھر اُسی کی طرف تم پلٹائے جانے والے ہو\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmciii{جب اکیلے اللہ کا ذکر کیا جاتا ہے تو آخرت پر ایمان نہ رکھنے والوں کے دل کڑھنے لگتے ہیں، اور جب اُس کے سوا دوسروں کا ذکر ہوتا ہے تو یکایک وہ خوشی سے کھل اٹھتے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmciv{کہو، خدایا! آسمانوں اور زمین کے پیدا کرنے والے، حاضر و غائب کے جاننے والے، تو ہی اپنے بندوں کے درمیان اُس چیز کا فیصلہ کرے گا جس میں وہ اختلاف کرتے رہے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcv{اگر اِن ظالموں کے پاس زمین کی ساری دولت بھی ہو، اور اتنی ہی اور بھی، تو یہ روز قیامت کے برے عذاب سے بچنے کے لیے سب کچھ فدیے میں دینے کے لیے تیار ہو جائیں گے وہاں اللہ کی طرف سے ان کے سامنے وہ کچھ آئے گا جس کا انہوں نے کبھی اندازہ ہی نہیں کیا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcvi{وہاں اپنی کمائی کے سارے برے نتائج ان پر کھل جائیں گے اور وہی چیز ان پر مسلط ہو جائے گی جس کا یہ مذاق اڑاتے رہے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcvii{یہی انسان جب ذرا سی مصیبت اِسے چھو جاتی ہے تو ہمیں پکارتا ہے، اور جب ہم اسے اپنی طرف سے نعمت دے کر اپھار دیتے ہیں تو کہتا ہے کہ یہ تو مجھے علم کی بنا پر دیا گیا ہے! نہیں، بلکہ یہ آزمائش ہے، مگر ان میں سے اکثر لوگ جانتے نہیں ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcviii{یہی بات ان سے پہلے گزرے ہوئے لوگ بھی کہہ چکے ہیں، مگر جو کچھ وہ کماتے تھے وہ ان کے کسی کام نہ آیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcix{پھر اپنی کمائی کے برے نتائج انہوں نے بھگتے، اور اِن لوگوں میں سے بھی جو ظالم ہیں وہ عنقریب اپنی کمائی کے برے نتائج بھگتیں گے، یہ ہمیں عاجز کر دینے والے نہیں ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcx{اور کیا انہیں معلوم نہیں ہے کہ اللہ جس کا چاہتا ہے رزق کشادہ کر دیتا ہے اور جس کا چاہتا ہے تنگ کر دیتا ہے؟ اس میں نشانیاں ہیں اُن لوگوں کے لیے جو ایمان لاتے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcxi{(اے نبیؐ) کہہ دو کہ اے میرے بندو، جنہوں نے اپنی جانوں پر زیادتی کی ہے، اللہ کی رحمت سے مایوس نہ ہو جاؤ، یقیناً اللہ سارے گناہ معاف کر دیتا ہے، وہ تو غفور و رحیم ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcxii{پلٹ آؤ اپنے رب کی طرف اور مطیع بن جاؤ اُس کے قبل اِس کے کہ تم پر عذاب آ جائے اور پھر کہیں سے تمہیں مدد نہ مل سکے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiii{اور پیروی اختیار کر لو اپنے رب کی بھیجی ہوئی کتاب کے بہترین پہلو کی، قبل اِس کے کہ تم پر اچانک عذاب آئے اور تم کو خبر بھی نہ ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiv{کہیں ایسا نہ ہو کہ بعد میں کوئی شخص کہے ``افسوس میری اُس تقصیر پر جو میں اللہ کی جناب میں کرتا رہا، بلکہ میں تو الٹا مذاق اڑانے والوں میں شامل تھا"\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxv{یا کہے ``کاش اللہ نے مجھے ہدایت بخشی ہوتی تو میں بھی متقیوں میں سے ہوتا"\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvi{یا عذاب دیکھ کر کہے ``کاش مجھے ایک موقع اور مل جائے اور میں بھی نیک عمل کرنے والوں میں شامل ہو جاؤں"\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvii{(اور اُس وقت اسے یہ جواب ملے کہ) ``کیوں نہیں، میری آیات تیرے پاس آ چکی تھیں، پھر تو نے انہیں جھٹلایا اور تکبر کیا اور تو کافروں میں سے تھا"\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxviii{آج جن لوگوں نے خدا پر جھوٹ باندھے ہیں قیامت کے روز تم دیکھو گے کہ ان کے منہ کالے ہوں گے کیا جہنم میں متکبروں کے لیے کافی جگہ نہیں ہے؟\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxix{اس کے برعکس جن لوگوں نے یہاں تقویٰ کیا ہے ان کے اسباب کامیابی کی وجہ سے اللہ ان کو نجات دے گا، ان کو نہ کوئی گزند پہنچے گا اور نہ وہ غمگین ہوں گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxx{اللہ ہر چیز کا خالق ہے اور وہی ہر چیز پر نگہبان ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxi{زمین اور آسمانوں کے خزانوں کی کنجیاں اُسی کے پاس ہیں اور جو لوگ اللہ کی آیات سے کفر کرتے ہیں وہی گھاٹے میں رہنے والے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxii{(اے نبیؐ) اِن سے کہو ``پھر کیا اے جاہلو، تم اللہ کے سوا کسی اور کی بندگی کرنے کے لیے مجھ سے کہتے ہو؟"\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiii{(یہ بات تمہیں ان سے صاف کہہ دینی چاہیے کیونکہ) تمہاری طرف اور تم سے پہلے گزرے ہوئے تمام انبیاء کی طرف یہ وحی بھیجی جا چکی ہے کہ اگر تم نے شرک کیا تو تمہارا عمل ضائع ہو جائے گا اور تم خسارے میں رہو گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiv{لہٰذا (اے نبیؐ) تم بس اللہ ہی کی بندگی کرو اور شکر گزار بندوں میں سے ہو جاؤ\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxv{اِن لوگوں نے اللہ کی قدر ہی نہ کی جیسا کہ اس کی قدر کرنے کا حق ہے (اس کی قدرت کاملہ کا حال تو یہ ہے کہ) قیامت کے روز پوری زمین اُس کی مٹھی میں ہو گی اور آسمان اس کے دست راست میں لپٹے ہوئے ہوں گے پاک اور بالاتر ہے وہ اس شرک سے جو یہ لوگ کرتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvi{اور اُس روز صور پھونکا جائے گا اور وہ سب مر کر گر جائیں گے جو آسمانوں اور زمین میں ہیں سوائے اُن کے جنہیں اللہ زندہ رکھنا چاہے پھر ایک دوسرا صور پھونکا جائے گا اور یکایک سب کے سب اٹھ کر دیکھنے لگیں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvii{زمین اپنے رب کے نور سے چمک اٹھے گی، کتاب اعمال لا کر رکھ دی جائے گی، انبیاء اور تمام گواہ حاضر کر دیے جائیں گے، لوگوں کے درمیان ٹھیک ٹھیک حق کے ساتھ فیصلہ کر دیا جائے گا اور اُن پر کوئی ظلم نہ ہوگا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxviii{اور ہر متنفس کو جو کچھ بھی اُس نے عمل کیا تھا اُس کا پورا پورا بدلہ دے دیا جائے گا لوگ جو کچھ بھی کرتے ہیں اللہ اس کو خوب جانتا ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxix{(اِس فیصلہ کے بعد) وہ لوگ جنہوں نے کفر کیا تھا جہنم کی طرف گروہ در گروہ ہانکے جائیں گے، یہاں تک کہ جب وہ وہاں پہنچیں گے تو اس کے دروازے کھولے جائیں گے اور اُس کے کارندے ان سے کہیں گے ``کیا تمہارے پاس تمہارے اپنے لوگوں میں سے ایسے رسول نہیں آئے تھے، جنہوں نے تم کو تمہارے رب کی آیات سنائی ہوں اور تمہیں اس بات سے ڈرایا ہو کہ ایک وقت تمہیں یہ دن بھی دیکھنا ہوگا؟" وہ جواب دیں گے ``ہاں، آئے تھے، مگر عذاب کا فیصلہ کافروں پر چپک گیا"\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxx{کہا جائے گا، داخل ہو جاؤ جہنم کے دروازوں میں، یہاں اب تمہیں ہمیشہ رہنا ہے، بڑا ہی برا ٹھکانا ہے یہ متکبروں کے لیے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxi{اور جو لوگ اپنے رب کی نافرمانی سے پرہیز کرتے تھے انہیں گروہ در گروہ جنت کی طرف لے جایا جائے گا یہاں تک کہ جب وہ وہاں پہنچیں گے، اور اس کے دروازے پہلے ہی کھولے جا چکے ہوں گے، تو اُس کے منتظمین ان سے کہیں گے کہ ``سلام ہو تم پر، بہت اچھے رہے، داخل ہو جاؤ اس میں ہمیشہ کے لیے"\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxii{اور وہ کہیں گے ``شکر ہے اُس خدا کا جس نے ہمارے ساتھ اپنا وعدہ سچ کر دکھایا اور ہم کو زمین کا وارث بنا دیا، اب ہم جنت میں جہاں چاہیں اپنی جگہ بنا سکتے ہیں" پس بہترین اجر ہے عمل کرنے والوں کے لیے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiii{اور تم دیکھو گے کہ فرشتے عرش کے گرد حلقہ بنائے ہوئے اپنے رب کی حمد اور تسبیح کر رہے ہوں گے، اور لوگوں کے درمیان ٹھیک ٹھیک حق کے ساتھ فیصلہ چکا دیا جائے گا، اور پکار دیا جائے گا کہ حمد ہے اللہ ربّ العالمین کے لیے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiv{\basmalahur ح م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxv{اِس کتاب کا نزول اللہ کی طرف سے ہے جو زبردست ہے، سب کچھ جاننے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvi{گناہ معاف کرنے والا اور توبہ قبول کرنے والا ہے، سخت سزا دینے والا اور بڑا صاحب فضل ہے کوئی معبود اس کے سوا نہیں، اُسی کی طرف سب کو پلٹنا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvii{اللہ کی آیات میں جھگڑے نہیں کرتے مگر صرف وہ لوگ جنہوں نے کفر کیا ہے اِس کے بعد دنیا کے ملکوں میں اُن کی چلت پھرت تمہیں کسی دھوکے میں نہ ڈالے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxviii{اِن سے پہلے نوحؑ کی قوم بھی جھٹلا چکی ہے، اور اُس کے بعد بہت سے دوسرے جتھوں نے بھی یہ کام کیا ہے ہر قوم اپنے رسول پر جھپٹی تاکہ اُسے گرفتار کرے اُن سب نے باطل کے ہتھیاروں سے حق کو نیچا دکھانے کی کوشش کی مگر آخر کار میں نے ان کو پکڑ لیا، پھر دیکھ لو کہ میری سزا کیسی سخت تھی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxix{اِسی طرح تیرے رب کا یہ فیصلہ بھی اُن سب لوگوں پر چسپاں ہو چکا ہے جو کفر کے مرتکب ہوئے ہیں کہ وہ واصل بجہنم ہونے والے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcxl{عرش الٰہی کے حامل فرشتے اور وہ جو عرش کے گرد و پیش حاضر رہتے ہیں، سب اپنے رب کی حمد کے ساتھ اس کی تسبیح کر رہے ہیں وہ اس پر ایمان رکھتے ہیں اور ایمان لانے والوں کے حق میں دعائے مغفرت کرتے ہیں وہ کہتے ہیں: ``اے ہمارے رب، تو اپنی رحمت اور اپنے علم کے ساتھ ہر چیز پر چھایا ہوا ہے، پس معاف کر دے اور عذاب دوزخ سے بچا لے اُن لوگوں کو جنہوں نے توبہ کی ہے اور تیرا راستہ اختیار کر لیا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcxli{اے ہمارے رب، اور داخل کر اُن کو ہمیشہ رہنے والی اُن جنتوں میں جن کا تو نے اُن سے وعدہ کیا ہے، اور اُن کے والدین اور بیویوں اور اولاد میں سے جو صالح ہوں (اُن کو بھی وہاں اُن کے ساتھ پہنچا دے) تو بلا شبہ قادر مطلق اور حکیم ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlii{اور بچا دے اُن کو برائیوں سے جس کو تو نے قیامت کے دن برائیوں سے بچا دیا اُس پر تو نے بڑا رحم کیا، یہی بڑی کامیابی ہے"\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliii{جن لوگوں نے کفر کیا ہے، قیامت کے روز اُن کو پکار کر کہا جائے گا ``آج تمہیں جتنا شدید غصہ اپنے اوپر آ رہا ہے، اللہ تم پر اُس سے زیادہ غضب ناک اُس وقت ہوتا تھا جب تمہیں ایمان کی طرف بلایا جاتا تھا اور تم کفر کرتے تھے"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliv{وہ کہیں گے ``اے ہمارے رب، تو نے واقعی ہمیں دو دفعہ موت اور دو دفعہ زندگی دے دی، اب ہم اپنے قصوروں کا اعتراف کرتے ہیں، کیا اب یہاں سے نکلنے کی بھی کوئی سبیل ہے؟"\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlv{(جواب ملے گا) ``یہ حالت جس میں تم مبتلا ہو، اِس وجہ سے ہے کہ جب اکیلے اللہ کی طرف بلایا جاتا تھا تو تم ماننے سے انکار کر دیتے تھے اور جب اُس کے ساتھ دوسروں کو ملایا جاتا تو تم مان لیتے تھے اب فیصلہ اللہ بزرگ و برتر کے ہاتھ ہے"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvi{وہی ہے جو تم کو اپنی نشانیاں دکھاتا ہے اور آسمان سے تمہارے لیے رزق نازل کرتا ہے، مگر (اِن نشانیوں کے مشاہدے سے) سبق صرف وہی شخص لیتا ہے جو اللہ کی طرف رجوع کرنے والا ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvii{(پس اے رجوع کرنے والو) اللہ ہی کو پکارو اپنے دین کو اُس کے لیے خالص کر کے، خواہ تمہارا یہ فعل کافروں کو کتنا ہی ناگوار ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlviii{وہ بلند درجوں والا، مالک عرش ہے اپنے بندوں میں سے جس پر چاہتا ہے اپنے حکم سے روح نازل کر دیتا ہے تاکہ وہ ملاقات کے دن سے خبردار کر دے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlix{وہ دن جبکہ سب لوگ بے پردہ ہوں گے، اللہ سے ان کی کوئی بات بھی چھپی ہوئی نہ ہو گی (اُس روز پکار کر پوچھا جائے گا) آج بادشاہی کس کی ہے؟ (سارا عالم پکار اٹھے گا) اللہ واحد قہار کی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcl{(کہا جائے گا) آج ہر متنفس کو اُس کمائی کا بدلہ دیا جائے گا جو اس نے کی تھی آج کسی پر کوئی ظلم نہ ہو گا اور اللہ حساب لینے میں بہت تیز ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcli{اے نبیؐ، ڈرا دو اِن لوگوں کو اُس دن سے جو قریب آ لگا ہے جب کلیجے منہ کو آ رہے ہوں گے اور لوگ چپ چاپ غم کے گھونٹ پیے کھڑے ہونگے ظالموں کا نہ کوئی مشفق دوست ہو گا اور نہ کوئی شفیع جس کی بات مانی جائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmclii{اللہ نگاہوں کی چوری تک سے واقف ہے اور وہ راز تک جانتا ہے جو سینوں نے چھپا رکھے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcliii{اور اللہ ٹھیک ٹھیک بے لاگ فیصلہ کریگا رہے وہ جن کو (یہ مشرکین) اللہ کو چھوڑ کر پکارتے ہیں، وہ کسی چیز کا بھی فیصلہ کرنے والے نہیں ہیں بلاشبہ اللہ ہی سب کچھ سننے اور دیکھنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcliv{کیا یہ لوگ کبھی زمین میں چلے پھرے نہیں ہیں کہ انہیں اُن لوگوں کا انجام نظر آتا جو اِن سے پہلے گزر چکے ہیں؟ وہ اِن زیادہ طاقت ور تھے اور ان سے زیادہ زبردست آثار زمین میں چھوڑ گئے ہیں مگر اللہ نے ان کے گناہوں پر انہیں پکڑ لیا اور اُن کو اللہ سے بچانے والا کوئی نہ تھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmclv{یہ ان کا انجام اس لیے ہوا کہ ان کے پاس اُن کے رسول بینات لے کر آئے اور انہوں نے ماننے سے انکار کر دیا آخر کار اللہ نے ان کو پکڑ لیا، یقیناً وہ بڑی قوت والا اور سزا دینے میں بہت سخت ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmclvi{ہم نے موسیٰؑ کو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmclvii{فرعون اور ہامان اور قارون کی طرف اپنے نشانیوں اور نمایاں سندِ ماموریت کے ساتھ بھیجا، مگر انہوں نے کہا ``ساحر ہے، کذاب ہے"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmclviii{پھر جب وہ ہماری طرف سے حق ان کے سامنے لے آیا تو انہوں نے کہا ``جو لوگ ایمان لا کر اس کے ساتھ شامل ہوئے ہیں ان سب کے لڑکوں کو قتل کرو اور لڑکیاں کو جیتا چھوڑ دو" مگر کافروں کی چال اکارت ہی گئی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmclix{ایک روز فرعون نے اپنے درباریوں سے کہا ``چھوڑو مجھے، میں اِس موسیٰؑ کو قتل کیے دیتا ہوں، اور پکار دیکھے یہ اپنے رب کو مجھے اندیشہ ہے کہ یہ تمہارا دین بدل ڈالے گا، یا ملک میں فساد برپا کرے گا"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmclx{موسیٰؑ نے کہا ``میں نے تو ہر اُس متکبر کے مقابلے میں جو یَوم الحساب پر ایمان نہیں رکھتا اپنے ر ب اور تمہارے رب کی پناہ لے لی ہے"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmclxi{اس موقع پر آل فرعون میں سے ایک مومن شخص، جو اپنا ایمان چھپائے ہوئے تھا، بول اٹھا: ``کیا تم ایک شخص کو صرف اِس بنا پر قتل کر دو گے کہ وہ کہتا ہے میرا رب اللہ ہے؟ حالانکہ وہ تمہارے رب کی طرف سے تمہارے پاس بینات لے آیا اگر وہ جھوٹا ہے تو اس کا جھوٹ خود اسی پر پلٹ پڑے گا لیکن اگر وہ سچا ہے تو جن ہولناک نتائج کا وہ تم کو خوف دلاتا ہے ان میں سے کچھ تو تم پر ضرور ہی آ جائیں گے اللہ کسی شخص کو ہدایت نہیں دیتا جو حد سے گزر جانے والا اور کذاب ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmclxii{اے میری قوم کے لوگو! آج تمہیں بادشاہی حاصل ہے اور زمین میں تم غالب ہو، لیکن اگر خدا کا عذاب ہم پر آ گیا تو پھر کون ہے جو ہماری مدد کر سکے گا" فرعون نے کہا ``میں تو تم لوگوں کو وہی رائے دے رہا ہوں جو مجھے مناسب نظر آتی ہے اور میں اُسی راستے کی طرف تمہاری رہنمائی کرتا ہوں جو ٹھیک ہے"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiii{وہ شخص جو ایمان لایا تھا اُس نے کہا ``اے میری قوم کے لوگو، مجھے خوف ہے کہ کہیں تم پر بھی وہ دن نہ آ جائے جو اس سے پہلے بہت سے جتھوں پر آ چکا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiv{جیسا دن قوم نوحؑ اور عاد اور ثمود اور ان کے بعد والی قوموں پر آیا تھا اور یہ حقیقت ہے کہ اللہ اپنے بندوں پر ظلم کا کوئی ارادہ نہیں رکھتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmclxv{اے قوم، مجھے ڈر ہے کہ کہیں تم پر فریاد و فغاں کا دن نہ آ جائے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvi{جب تم ایک دوسرے کو پکارو گے اور بھاگے بھاگے پھرو گے، مگر اُس وقت اللہ سے بچانے والا کوئی نہ ہو گا سچ یہ ہے کہ جسے اللہ بھٹکا دے اُسے پھر کوئی راستہ دکھانے والا نہیں ہوتا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvii{اس سے پہلے یوسفؑ تمہارے پاس بینات لے کر آئے تھے مگر تم اُن کی لائی ہوئی تعلیم کی طرف سے شک ہی میں پڑے رہے پھر جب اُن کا انتقال ہو گیا تو تم نے کہا اب اُن کے بعد اللہ کوئی رسول ہرگز نہ بھیجے گا" اِسی طرح اللہ اُن سب لوگوں کو گمراہی میں ڈال دیتا ہے جو حد سے گزرنے والے اور شکی ہوتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmclxviii{اور اللہ کی آیات میں جھگڑے کرتے ہیں بغیر اس کے کہ ان کے پاس کوئی سند یا دلیل آئی ہو یہ رویہ اللہ اور ایمان لانے والوں کے نزدیک سخت مبغوض ہے اِسی طرح اللہ ہر متکر و جبار کے دل پر ٹھپہ لگا دیتا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmclxix{فرعون نے کہا ``اے ہامان، میرے لیے ایک بلند عمارت بنا تاکہ میں راستوں تک پہنچ سکوں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmclxx{آسمانوں کے راستوں تک، اور موسیٰؑ کے خدا کو جھانک کر دیکھوں مجھے تو یہ موسیٰؑ جھوٹا ہی معلوم ہوتا ہے" اس طرح فرعون کے لیے اس کی بد عملی خوشنما بنا دی گئی اور وہ راہ راست سے روک دیا گیا فرعون کی ساری چال بازی (اُس کی اپنی) تباہی کے راستہ ہی میں صرف ہوئی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxi{وہ شخص جو ایمان لایا تھا، بولا ``اے میری قوم کے لوگو، میری بات مانو، میں تمہیں صحیح راستہ بتاتا ہوں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxii{اے قوم، یہ دنیا کی زندگی تو چند روزہ ہے، ہمیشہ کے قیام کی جگہ آخرت ہی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiii{جو برائی کرے گا اُس کو اتنا ہی بدلہ ملے گا جتنی اُس نے برائی کی ہو گی اور جو نیک عمل کرے گا، خواہ وہ مرد ہو یا عورت، بشرطیکہ ہو وہ مومن، ایسے سب لوگ جنت میں داخل ہوں گے جہاں اُن کو بے حساب رزق دیا جائے گا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiv{اے قوم، آخر یہ کیا ماجرا ہے کہ میں تو تم لوگوں کو نجات کی طرف بلاتا ہوں اور تم لوگ مجھے آگ کی طرف دعوت دیتے ہو!\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxv{تم مجھے اس بات کی دعوت دیتے ہو کہ میں اللہ سے کفر کروں اور اس کے ساتھ اُن ہستیوں کو شریک ٹھیراؤں جنہیں میں نہیں جانتا، حالانکہ میں تمہیں اُس زبردست مغفرت کرنے والے خدا کی طرف بلا رہا ہوں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvi{نہیں، حق یہ ہے اور اِس کے خلاف نہیں ہو سکتا کہ جن کی طرف تم مجھے بلا رہے ہو اُن کے لیے نہ دنیا میں کوئی دعوت ہے نہ آخرت میں، اور ہم سب کو پلٹنا اللہ ہی کی طرف ہے، اور حد سے گزرنے والے آگ میں جانے والے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvii{آج جو کچھ میں کہہ رہا ہوں، عنقریب وہ وقت آئے گا جب تم اُسے یاد کرو گے اور اپنا معاملہ میں اللہ کے سپرد کرتا ہوں، وہ اپنے بندوں کا نگہبان ہے"\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxviii{آخرکار اُن لوگوں نے جو بری سے بری چالیں اُس مومن کے خلاف چلیں، اللہ نے اُن سب سے اُس کو بچا لیا، اور فرعون کے ساتھی خود بدترین عذاب کے پھیر میں آ گئے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxix{دوزخ کی آگ ہے جس کے سامنے صبح و شام وہ پیش کیے جاتے ہیں، اور جب قیامت کی گھڑی آ جائے گی تو حکم ہو گا کہ آل فرعون کو شدید تر عذاب میں داخل کرو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxx{پھر ذرا خیال کرو اُس وقت کا جب یہ لوگ دوزخ میں ایک دوسرے سے جھگڑ رہے ہوں گے دنیا میں جو لوگ کمزور تھے وہ بڑے بننے والوں سے کہیں گے کہ ``ہم تمہارے تابع تھے، اب کیا یہاں تم نار جہنم کی تکلیف کے کچھ حصے سے ہم کو بچا لو گے؟"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxi{وہ بڑے بننے والے جواب دیں گے ``ہم سب یہاں ایک حال میں ہیں، اور اللہ بندوں کے درمیان فیصلہ کر چکا ہے"\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxii{پھر یہ دوزخ میں پڑے ہوئے لوگ جہنم کے اہل کاروں سے کہیں گے ``اپنے رب سے دعا کرو کہ ہمارے عذاب میں بس ایک دن کی تخفیف کر دے"\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiii{وہ پوچھیں گے ``کیا تمہارے پاس تمہارے رسول بینات لے کر نہیں آتے رہے تھے؟" وہ کہیں گے ``ہاں"جہنم کے اہل کار بولیں گے: ``پھر تو تم ہی دعا کرو، اور کافروں کی دعا اکارت ہی جانے والی ہے"\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiv{یقین جانو کہ ہم اپنے رسولوں اور ایمان لانے والوں کی مدد اِس دنیا کی زندگی میں بھی لازماً کرتے ہیں، اور اُس روز بھی کریں گے جب گواہ کھڑے ہوں گے،\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxv{جب ظالموں کو ان کی معذرت کچھ بھی فائدہ نہ دے گی اور اُن پر لعنت پڑے گی اور بد ترین ٹھکانا اُن کے حصے میں آئے گا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvi{آخر دیکھ لو کہ موسیٰؑ کی ہم نے رہنمائی کی اور بنی اسرائیل کو اس کتاب کا وارث بنا دیا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvii{جو عقل و دانش رکھنے والوں کے لیے ہدایت و نصیحت تھی\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxviii{پس اے نبیؐ، صبر کرو، اللہ کا وعدہ بر حق ہے، اپنے قصور کی معافی چاہو اور صبح و شام اپنے رب کی حمد کے ساتھ اس کی تسبیح کرتے رہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxix{حقیقت یہ ہے کہ جو لوگ کسی سند و حجت کے بغیر جو اُن کے پاس آئی ہو، اللہ کی آیات میں جھگڑے کر رہے ہیں اُن کے دلوں میں کبر بھرا ہوا ہے، مگر وہ اُس بڑائی کو پہنچنے والے نہیں ہیں جس کا وہ گھمنڈ رکھتے ہیں بس اللہ کی پناہ مانگ لو، وہ سب کچھ دیکھتا اور سنتا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxc{آسمانوں اور زمین کا پیدا کرنا انسانوں کو پیدا کرنے کی بہ نسبت یقیناً زیادہ بڑا کام ہے، مگر اکثر لوگ جانتے نہیں ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxci{اور یہ نہیں ہو سکتا کہ اندھا اور بینا یکساں ہو جائے اور ایماندار و صالح اور بد کار برابر ٹھیریں مگر تم لوگ کم ہی کچھ سمجھتے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcii{یقیناً قیامت کی گھڑی آنے والی ہے، اس کے آنے میں کوئی شک نہیں، مگر اکثر لوگ نہیں مانتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciii{تمہارا رب کہتا ہے ``مجھے پکارو، میں تمہاری دعائیں قبول کروں گا، جو لوگ گھمنڈ میں آ کر میری عبادت سے منہ موڑتے ہیں، ضرور وہ ذلیل و خوار ہو کر جہنم میں داخل ہوں گے"\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciv{وہ اللہ ہی تو ہے جس نے تمہارے لیے رات بنائی تاکہ اس میں سکون حاصل کرو، اور دن کو روشن کیا حقیقت یہ ہے کہ اللہ لوگوں پر بڑا فضل فرمانے والا ہے مگر اکثر لوگ شکر ادا نہیں کرتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcv{وہی اللہ (جس نے تمہارے لیے یہ کچھ کیا ہے) تمہارا رب ہے ہر چیز کا خالق اس کے سوا کوئی معبود نہیں پھر تم کدھر سے بہکائے جا رہے ہو؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvi{اِسی طرح وہ سب لوگ بہکائے جاتے رہے ہیں جو اللہ کی آیات کا انکار کرتے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvii{وہ اللہ ہی تو ہے جس نے تمہارے لیے زمین کو جائے قرار بنایا اور اوپر آسمان کا گنبد بنا دیا جس نے تمہاری صورت بنائی اور بڑی ہی عمدہ بنائی جس نے تمہیں پاکیزہ چیزوں کا رزق دیا وہی اللہ (جس کے یہ کام ہیں) تمہارا رب ہے بے حساب برکتوں والا ہے وہ کائنات کا رب\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcviii{وہی زندہ ہے اُس کے سوا کوئی معبود نہیں اُسی کو تم پکارو اپنے دین کو اس کے لیے خالص کر کے ساری تعریف اللہ ربّ العالمین ہی کے لیے ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcix{اے نبیؐ، اِن لوگوں سے کہہ دو کہ مجھے تو اُن ہستیوں کی عبادت سے منع کر دیا گیا ہے جنہیں تم اللہ کو چھوڑ کر پکارتے ہو (میں یہ کام کیسے کر سکتا ہوں) جبکہ میرے پاس میرے رب کی طرف سے بینات آ چکی ہیں مجھے حکم دیا گیا ہے کہ میں رب العالمین کے آگے سرِ تسلیم خم کر دوں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcc{وہی تو ہے جس نے تم کو مٹی سے پیدا کیا، پھر نطفے سے، پھر خون کے لوتھڑے سے، پھر وہ تمہیں بچے کی شکل میں نکالتا ہے، پھر تمہیں بڑھاتا ہے تاکہ تم اپنی پوری طاقت کو پہنچ جاؤ، پھر اور بڑھاتا ہے تاکہ تم بڑھاپے کو پہنچو اور تم میں سے کوئی پہلے ہی واپس بلا لیا جاتا ہے یہ سب کچھ اس لیے کیا جاتا ہے تاکہ تم اپنے مقرر وقت تک پہنچ جاؤ، اور اس لیے کہ تم حقیقت کو سمجھو\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcci{وہی ہے زندگی دینے والا، اور وہی موت دینے والا ہے وہ جس بات کا بھی فیصلہ کرتا ہے، بس ایک حکم دیتا ہے کہ وہ ہو جائے اور وہ ہو جاتی ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmccii{تم نے دیکھا اُن لوگوں کو جو اللہ کی آیات میں جھگڑے کرتے ہیں، کہاں سے وہ پھرائے جا رہے ہیں؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcciii{یہ لوگ جو اِس کتاب کو اور اُن ساری کتابوں کو جھٹلاتے ہیں جو ہم نے اپنے رسولوں کے ساتھ بھیجی تھیں؟عنقریب انہیں معلوم ہو جائے گا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcciv{جب طوق ان کی گردنوں میں ہوں گے، اور زنجیریں، جن سے پکڑ کر\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmccv{وہ کھولتے ہوئے پانی کی طرف کھینچے جائیں گے اور پھر دوزخ کی آگ میں جھونک دیے جائیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmccvi{پھر اُن سے پوچھا جائے گا کہ اب کہاں ہیں اللہ کے سوا وہ دوسرے خدا جن کو تم شریک کرتے تھے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmccvii{وہ جواب دیں گے ``کھوئے گئے وہ ہم سے، بلکہ ہم اس سے پہلے کسی چیز کو نہ پکارتے تھے" اِس طرح اللہ کافروں کا گمراہ ہونا متحقق کر دے گا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmccviii{اُن سے کہا جائے گا ``یہ تمہارا انجام اس لیے ہوا ہے کہ تم زمین میں غیر حق پر مگن تھے اور پھر اُس پر اتراتے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmccix{اب جاؤ، جہنم کے دروازوں میں داخل ہو جاؤ ہمیشہ تم کو وہیں رہنا ہے، بہت ہی برا ٹھکانا ہے متکبرین کا"\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmccx{پس اے نبیؐ، صبر کرو، اللہ کا وعدہ برحق ہے اب خواہ ہم تمہارے سامنے ہی اِن کو اُن برے نتائج کا کوئی حصہ دکھا دیں جن سے ہم اِنہیں ڈرا رہے ہیں، یا (اُس سے پہلے) تمہیں دنیا سے اٹھا لیں، پلٹ کر آنا تو اِنہیں ہماری ہی طرف ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmccxi{اے نبیؐ، تم سے پہلے ہم بہت سے رسول بھیج چکے ہیں جن میں سے بعض کے حالات ہم نے تم کو بتائے ہیں اور بعض کے نہیں بتائے کسی رسول کی بھی یہ طاقت نہ تھی کہ اللہ کے اذن کے بغیر خود کوئی نشانی لے آتا پھر جب اللہ کا حکم آگیا تو حق کے مطابق فیصلہ کر دیا گیا اور اُس وقت غلط کار لوگ خسارے میں پڑ گئے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmccxii{اللہ ہی نے تمہارے لیے یہ مویشی جانور بنائے ہیں تاکہ ان میں سے کسی پر تم سوار ہو اور کسی کا گوشت کھاؤ\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiii{ان کے اندر تمہارے لیے اور بھی بہت سے منافع ہیں وہ اس کام بھی آتے ہیں کہ تمہارے دلوں میں جہاں جانے کی حاجت ہو وہاں تم اُن پر پہنچ سکو اُن پر بھی اور کشتیوں پر بھی تم سوار کیے جاتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiv{اللہ اپنی یہ نشانیاں تمہیں دکھا رہا ہے، آخر تم اُس کی کن کن نشانیوں کا انکار کرو گے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmccxv{پھر کیا یہ زمین میں چلے پھرے نہیں ہیں کہ اِن کو اُن لوگوں کا انجام نظر آتا جو اِن سے پہلے گزر چکے ہیں؟ وہ اِن سے تعداد میں زیادہ تھے، اِن سے بڑھ کر طاقتور تھے، اور زمین میں اِن سے زیادہ شاندار آثار چھوڑ گئے ہیں جو کچھ کمائی اُنہوں نے کی تھی، آخر وہ اُن کے کس کام آئی؟\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvi{جب ان کے رسول ان کے پاس بینات لے کر آئے تو وہ اُسی علم میں مگن رہے جو ان کے اپنے پاس تھا، اور پھر اُسی چیز کے پھیر میں آ گئے جس کا وہ مذاق اڑاتے تھے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvii{جب انہوں نے ہمارا عذاب دیکھ لیا تو پکار اٹھے کہ ہم نے مان لیا اللہ وحدہُ لا شریک کو اور ہم انکار کرتے ہیں اُن سب معبودوں کا جنہیں ہم شریک ٹھیراتے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmccxviii{مگر ہمارا عذاب دیکھ لینے کے بعد ان کا ایمان اُن کے لیے کچھ بھی نافع نہ ہو سکتا تھا، کیونکہ یہی اللہ کا مقرر ضابطہ ہے جو ہمیشہ اس کے بندوں میں جاری رہا ہے، اور اس وقت کافر لوگ خسارے میں پڑ گئے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmccxix{\basmalahur ح م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmccxx{یہ خدائے رحمان و رحیم کی طرف سے نازل کردہ چیز ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxi{ایک ایسی کتاب جس کی آیات خوب کھول کر بیان کی گئی ہیں، عربی زبان کا قرآن، اُن لوگوں کے لیے جو علم رکھتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxii{بشارت دینے والا اور ڈرا دینے والا مگر اِن لوگوں میں سے اکثر نے اس سے رو گردانی کی اور وہ سن کر نہیں دیتے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiii{کہتے ہیں ``جس چیز کی طرف تو ہمیں بلا رہا ہے اس کے لیے ہمارے دلوں پر غلاف چڑھے ہوئے ہیں، ہمارے کان بہرے ہو گئے ہیں، اور ہمارے اور تیرے درمیان ایک حجاب حائل ہو گیا ہے تو اپنا کام کر، ہم اپنا کام کیے جائیں گے"\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiv{اے نبیؐ، اِن سے کہو، میں تو ایک بشر ہوں تم جیسا مجھے وحی کے ذریعہ سے بتایا جاتا ہے کہ تمہارا خدا تو بس ایک ہی خدا ہے، لہٰذا تم سیدھے اُسی کا رخ اختیار کرو اور اس سے معافی چاہو تباہی ہے اُن مشرکوں کے لیے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxv{جو زکوٰۃ نہیں دیتے اور آخرت کے منکر ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvi{رہے وہ لوگ جنہوں نے مان لیا اور نیک اعمال کیے، اُن کے لیے یقیناً ایسا اجر ہے جس کا سلسلہ کبھی ٹوٹنے والا نہیں ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvii{اے نبیؐ! اِن سے کہو، کیا تم اُس خدا سے کفر کرتے ہو اور دوسروں کو اُس کا ہمسر ٹھیراتے ہو جس نے زمین کو دو دنوں میں بنا دیا؟ وہی تو سارے جہان والوں کا رب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxviii{اُس نے (زمین کو وجود میں لانے کے بعد) اوپر سے اس پر پہاڑ جما دیے اور اس میں برکتیں رکھ دیں اور اس کے اندر سب مانگنے والوں کے لیے ہر ایک کی طلب و حاجت کے مطابق ٹھیک اندازے سے خوراک کا سامان مہیا کر دیا یہ سب کام چار دن میں ہو گئے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxix{پھر وہ آسمان کی طرف متوجہ ہوا جو اُس وقت محض دھواں تھا اُس نے آسمان اور زمین سے کہا ``وجود میں آ جاؤ، خواہ تم چاہو یا نہ چاہو" دونوں نے کہا ``ہم آ گئے فرمانبرداروں کی طرح"\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxx{تب اُس نے دو دن کے اندر سات آسمان بنا دیے، اور ہر آسمان میں اُس کا قانون وحی کر دیا اور آسمان دنیا کو ہم نے چراغوں سے آراستہ کیا اور اسے خوب محفوظ کر دیا یہ سب کچھ ایک زبردست علیم ہستی کا منصوبہ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxi{اب اگر یہ لوگ منہ موڑتے ہیں تو اِن سے کہہ دو کہ میں تم کو اُسی طرح کے ایک اچانک ٹوٹ پڑنے والے عذاب سے ڈراتا ہوں جیسا عاد اور ثمود پر نازل ہوا تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxii{جب خدا کے رسول اُن کے پاس آگے اور پیچھے، ہر طرف سے آئے اور انہیں سمجھایا کہ اللہ کے سوا کسی کی بندگی نہ کرو تو انہوں نے کہا ``ہمارا رب چاہتا تو فرشتے بھیجتا، لہٰذا ہم اُس بات کو نہیں مانتے جس کے لیے تم بھیجے گئے ہو"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiii{عاد کا حال یہ تھا کہ وہ زمین میں کسی حق کے بغیر بڑے بن بیٹھے اور کہنے لگے ``کون ہے ہم سے زیادہ زور آور" اُن کو یہ نہ سوجھا کہ جس خدا نے ان کو پیدا کیا ہے وہ ان سے زیادہ زور آور ہے؟ وہ ہماری آیات کا انکار ہی کرتے رہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiv{آخرکار ہم نے چند منحوس دنوں میں سخت طوفانی ہوا ان پر بھیج دی تاکہ انہیں دنیا ہی کی زندگی میں ذلت و رسوائی کے عذاب کا مزا چکھا دیں، اور آخرت کا عذاب تو اس سے بھی زیادہ رسوا کن ہے، وہاں کوئی ان کی مدد کرنے والا نہ ہو گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxv{رہے ثمود، تو ان کے سامنے ہم نے راہ راست پیش کی مگر انہوں نے راستہ دیکھنے کے بجائے اندھا بنا رہنا پسند کیا آخر اُن کے کرتوتوں کی بدولت ذلت کا عذاب اُن پر ٹوٹ پڑا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvi{اور ہم نے اُن لوگوں کو بچا لیا جو ایمان لائے تھے اور گمراہی و بد عملی سے پرہیز کرتے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvii{اور ذرا اُس وقت کا خیال کرو جب اللہ کے یہ دشمن دوزخ کی طرف جانے کے لیے گھیر لائے جائیں گے اُن کے اگلوں کو پچھلوں کے آنے تک روک رکھا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxviii{پھر جب سب وہاں پہنچ جائیں گے تو ان کے کان اور ان کی آنکھیں اور ان کے جسم کی کھالیں ان پر گواہی دیں گی کہ وہ دنیا میں کیا کچھ کرتے رہے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxix{وہ اپنے جسم کی کھالوں سے کہیں گے ``تم نے ہمارے خلاف کیوں گواہی دی؟"وہ جواب دیں گی ``ہمیں اُسی خدا نے گویائی دی ہے جس نے ہر چیز کو گویا کر دیا ہے اُسی نے تم کو پہلی مرتبہ پیدا کیا تھا اور اب اُسی کی طرف تم واپس لائے جا رہے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxl{تم دنیا میں جرائم کرتے وقت جب چھپتے تھے تو تمہیں یہ خیال نہ تھا کہ کبھی تمہارے اپنے کان اور تمہاری آنکھیں اور تمہارے جسم کی کھالیں تم پر گواہی دیں گی بلکہ تم نے تو یہ سمجھا تھا کہ تمہارے بہت سے اعمال کی اللہ کو بھی خبر نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxli{تمہارا یہی گمان جو تم نے اپنے رب کے ساتھ کیا تھا، تمہیں لے ڈوبا اور اسی کی بدولت تم خسارے میں پڑ گئے"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlii{اس حالت میں وہ صبر کریں (یا نہ کریں) آگ ہی ان کا ٹھکانا ہو گی، اور اگر رجوع کا موقع چاہیں گے تو کوئی موقع انہیں نہ دیا جائے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliii{ہم نے ان پر ایسے ساتھی مسلط کر دیے تھے جو انہیں آگے اور پیچھے ہر چیز خوشنما بنا کر دکھاتے تھے، آخر کار اُن پر بھی وہی فیصلہ عذاب چسپاں ہو کر رہا جو ان سے پہلے گزرے ہوئے جنوں اور انسانوں کے گروہوں پر چسپاں ہو چکا تھا، یقیناً وہ خسارے میں رہ جانے والے تھے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliv{یہ منکرین حق کہتے ہیں ``اِس قرآن کو ہرگز نہ سنو اور جب یہ سنایا جائے تو اس میں خلل ڈالو، شاید کہ اس طرح تم غالب آ جاؤ"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlv{اِن کافروں کو ہم سخت عذاب کا مزا چکھا کر رہیں گے اور جو بدترین حرکات یہ کرتے رہے ہیں ان کا پورا پورا بدلہ اِنہیں دیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvi{وہ دوزخ ہے جو اللہ کے دشمنوں کو بدلے میں ملے گی اُسی میں ہمیشہ ہمیشہ کے لیے اِن کا گھر ہو گا یہ ہے سزا اِس جرم کی کہ وہ ہماری آیات کا انکار کرتے رہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvii{وہاں یہ کافر کہیں گے کہ ``اے ہمارے رب، ذرا ہمیں دکھا دے اُن جنوں اور انسانوں کو جنہوں نے ہمیں گمراہ کیا تھا، ہم انہیں پاؤں تلے روند ڈالیں گے تاکہ وہ خوب ذلیل و خوار ہوں"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlviii{جن لوگوں نے کہا کہ اللہ ہمارا رب ہے اور پھر وہ اس پر ثابت قدم رہے، یقیناً اُن پر فرشتے نازل ہوتے ہیں اور ان سے کہتے ہیں کہ ``نہ ڈرو، نہ غم کرو، اور خوش ہو جاؤ اُس جنت کی بشارت سے جس کا تم سے وعدہ کیا گیا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlix{ہم اِس دنیا کی زندگی میں بھی تمہارے ساتھی ہیں اور آخرت میں بھی، وہاں جو کچھ تم چاہو گے تمہیں ملے گا اور ہر چیز جس کی تم تمنا کرو گے وہ تمہاری ہوگی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccl{یہ ہے سامان ضیافت اُس ہستی کی طرف سے جو غفور اور رحیم ہے"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccli{اور اُس شخص کی بات سے اچھی بات اور کس کی ہو گی جس نے اللہ کی طرف بلایا اور نیک عمل کیا اور کہا کہ میں مسلمان ہوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcclii{اور اے نبیؐ، نیکی اور بدی یکساں نہیں ہیں تم بدی کو اُس نیکی سے دفع کرو جو بہترین ہو تم دیکھو گے کہ تمہارے ساتھ جس کی عداوت پڑی ہوئی تھی وہ جگری دوست بن گیا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccliii{یہ صفت نصیب نہیں ہوتی مگر اُن لوگوں کو جو صبر کرتے ہیں، اور یہ مقام حاصل نہیں ہوتا مگر اُن لوگوں کو جو بڑے نصیبے والے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccliv{اور اگر تم شیطان کی طرف سے کوئی اکساہٹ محسوس کرو تو اللہ کی پناہ مانگ لو، وہ سب کچھ سنتا اور جانتا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcclv{اللہ کی نشانیوں میں سے ہیں یہ رات اور دن اور سورج اور چاند سورج اور چاند کو سجدہ نہ کرو بلکہ اُس خدا کو سجدہ کرو جس نے انہیں پیدا کیا ہے اگر فی الواقع تم اُسی کی عبادت کرنے والے ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvi{لیکن اگر یہ لوگ غرور میں آ کر اپنی ہی بات پر اڑے رہیں تو پروا نہیں، جو فرشتے تیرے رب کے مقرب ہیں وہ شب و روز اس کی تسبیح کر رہے ہیں اور کبھی نہیں تھکتے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvii{اور اللہ کی نشانیوں میں سے ایک یہ ہے کہ تم دیکھتے ہو زمین سونی پڑی ہوئی ہے، پھر جونہی کہ ہم نے اس پر پانی برسایا، یکایک وہ پھبک اٹھتی ہے اور پھول جاتی ہے یقیناً جو خدا اس مری ہوئی زمین کو جلا اٹھاتا ہے وہ مُردوں کو بھی زندگی بخشنے والا ہے یقیناً وہ ہر چیز پر قدرت رکھتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcclviii{جو لوگ ہماری آیات کو الٹے معنی پہناتے ہیں وہ ہم سے کچھ چھپے ہوئے نہیں ہیں خود ہی سوچ لو کہ آیا وہ شخص بہتر ہے جو آگ میں جھونکا جانے والا ہے یا وہ جو قیامت کے روز امن کی حالت میں حاضر ہو گا؟ کرتے رہو جو کچھ تم چاہو، تمہاری ساری حرکتوں کو اللہ دیکھ رہا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcclix{یہ وہ لوگ ہیں جن کے سامنے کلام نصیحت آیا تو انہوں نے اسے ماننے سے انکار کر دیا مگر حقیقت یہ ہے کہ یہ ایک زبردست کتاب ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcclx{باطل نہ سامنے سے اس پر آ سکتا ہے نہ پیچھے سے، یہ ایک حکیم و حمید کی نازل کردہ چیز ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxi{اے نبیؐ، تم سے جو کچھ کہا جا رہا ہے اس میں کوئی چیز بھی ایسی نہیں ہے جو تم سے پہلے گزرے ہوئے رسولوں سے نہ کہی جاچکی ہو بے شک تمہارا رب بڑا درگزر کرنے والا ہے، اور اس کے ساتھ بڑی دردناک سزا دینے والا بھی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxii{اگر ہم اِس کو عجمی قرآن بنا کر بھیجتے تو یہ لوگ کہتے ``کیوں نہ اس کی آیات کھول کر بیان کی گئیں؟ کیا عجیب بات ہے کہ کلام عجمی ہے اور مخاطب عربی" اِن سے کہو یہ قرآن ایمان لانے والوں کے لیے تو ہدایت اور شفا ہے، مگر جو لوگ ایمان نہیں لاتے اُن کے لیے یہ کانوں کی ڈاٹ اور آنکھوں کی پٹی ہے اُن کا حال تو ایسا ہے جیسے اُن کو دور سے پکارا جا رہا ہو\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiii{اِس سے پہلے ہم نے موسیٰؑ کو کتاب دی تھی اور اس کے معاملے میں بھی یہی اختلاف ہوا تھا اگر تیرے رب نے پہلے ہی ایک بات طے نہ کر دی ہوتی تو ان اختلاف کرنے والوں کے درمیان فیصلہ چکا دیا جاتا اور حقیقت یہ ہے کہ یہ لوگ اُس کی طرف سے سخت اضطراب انگیز شک میں پڑے ہوئے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiv{جو کوئی نیک عمل کرے گا اپنے ہی لیے اچھا کرے گا، جو بدی کرے گا اس کا وبال اُسی پر ہوگا، اور تیرا رب اپنے بندوں کے حق میں ظالم نہیں ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxv{اُس ساعت کا علم اللہ ہی کی طرف راجع ہوتا ہے، وہی اُن سارے پھلوں کو جانتا ہے جو اپنے شگوفوں میں سے نکلتے ہیں، اسی کو معلوم ہے کہ کونسی مادہ حاملہ ہوئی ہے اور کس نے بچہ جنا ہے پھر جس روز وہ اِن لوگوں کو پکارے گا کہ کہاں ہیں میرے وہ شریک؟ یہ کہیں گے، ``ہم عرض کر چکے ہیں، آج ہم میں سے کوئی اِس کی گواہی دینے والا نہیں ہے"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvi{اُس وقت وہ سارے معبود اِن سے گم ہو جائیں گے جنہیں یہ اس سے پہلے پکارتے تھے، اور یہ لوگ سمجھ لیں گے کہ اِن کے لیے اب کوئی جائے پناہ نہیں ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvii{انسان کبھی بھلائی کی دعا مانگتے نہیں تھکتا، اور جب کوئی آفت اِس پر آ جاتی ہے تو مایوس و دل شکستہ ہو جاتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxviii{مگر جو ں ہی کہ سخت وقت گزر جانے کے بعد ہم اِسے اپنی رحمت کا مزا چکھاتے ہیں، یہ کہتا ہے کہ ``میں اِسی کا مستحق ہوں، اور میں نہیں سمجھتا کہ قیامت کبھی آئے گی، لیکن اگر واقعی میں اپنے رب کی طرف پلٹایا گیا تو وہاں بھی مزے کروں گا" حالانکہ کفر کرنے والوں کو لازماً ہم بتا کر رہیں گے کہ وہ کیا کر کے آئے ہیں اور انہیں ہم بڑے گندے عذاب کا مزا چکھائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxix{انسان کو جب ہم نعمت دیتے ہیں تو وہ منہ پھیرتا ہے اور اکڑ جاتا ہے اور جب اسے کوئی آفت چھو جاتی ہے تو لمبی چوڑی دعائیں کرنے لگتا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxx{اے نبیؐ، اِن سے کہو، کبھی تم نے یہ بھی سوچا کہ اگر واقعی یہ قرآن خدا ہی کی طرف سے ہوا اور تم اِس کا انکار کرتے رہے تو اُس شخص سے بڑھ کر بھٹکا ہوا اور کون ہوگا جو اِس کی مخالفت میں دور تک نکل گیا ہو؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxi{عنقریب ہم اِن کو اپنی نشانیاں آفاق میں بھی دکھائیں گے اور ان کے اپنے نفس میں بھی یہاں تک کہ اِن پر یہ بات کھل جائے گی کہ یہ قرآن واقعی برحق ہے کیا یہ بات کافی نہیں ہے کہ تیرا رب ہر چیز کا شاہد ہے؟\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxii{آگاہ رہو، یہ لوگ اپنے رب کی ملاقات میں شک رکھتے ہیں سن رکھو، وہ ہر چیز پر محیط ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiii{\basmalahur ح م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiv{ع س ق\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxv{اِسی طرح اللہ غالب و حکیم تمہاری طرف اور تم سے پہلے گزرے ہوئے (رسولوں) کی طرف وحی کرتا رہا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvi{آسمانوں اور زمین میں جو کچھ بھی ہے اُسی کا ہے، وہ برتر اور عظیم ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvii{قریب ہے کہ آسمان اوپر سے پھٹ پڑیں فرشتے اپنے رب کی حمد کے ساتھ اُس کی تسبیح کر رہے ہیں اور زمین والوں کے حق میں درگزر کی درخواستیں کیے جاتے ہیں آگاہ رہو، حقیقت میں اللہ غفور و رحیم ہی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxviii{جن لوگوں نے اُس کو چھوڑ کر اپنے کچھ دوسرے سرپرست بنا رکھے ہیں، اللہ ہی اُن پر نگراں ہے، تم ان کے حوالہ دار نہیں ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxix{ہاں، اِسی طرح اے نبیؐ، یہ قرآن عربی ہم نے تمہاری طرف وحی کیا ہے تاکہ تم بستیوں کے مرکز (شہر مکہ) اور اُس کے گرد و پیش رہنے والوں کو خبردار کر دو، اور جمع ہونے کے دن سے ڈرا دو جن کے آنے میں کوئی شک نہیں ایک گروہ کو جنت میں جانا ہے اور دوسرے گروہ کو دوزخ میں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxx{اگر اللہ چاہتا تو اِن سب کو ایک ہی امت بنا دیتا، مگر وہ جسے چاہتا ہے اپنی رحمت میں داخل کرتا ہے، اور ظالموں کا نہ کوئی ولی ہے نہ مدد گار\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxi{کیا یہ (ایسے نادان ہیں کہ) اِنہوں نے اُسے چھوڑ کر دوسرے ولی بنا رکھے ہیں؟ ولی تو اللہ ہی ہے، وہی مُردوں کو زندہ کرتا ہے، اور وہ ہر چیز پر قادر ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxii{تمہارے درمیان جس معاملہ میں بھی اختلاف ہو، اُس کا فیصلہ کرنا اللہ کا کام ہے وہی اللہ میرا رب ہے، اُسی پر میں نے بھروسہ کیا، اور اُسی کی طرف میں رجوع کرتا ہوں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiii{آسمانوں اور زمین کا بنانے والا، جس نے تمہاری اپنی جنس سے تمہارے لیے جوڑے پیدا کیے، اور اسی طرح جانوروں میں بھی (اُنہی کے ہم جنس) جوڑے بنائے، اور اِس طریقہ سے وہ تمہاری نسلیں پھیلاتا ہے کائنات کی کوئی چیز اس کے مشابہ نہیں، وہ سب کچھ سننے اور دیکھنے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiv{آسمانوں اور زمین کے خزانوں کی کنجیاں اُسی کے پاس ہیں، جسے چاہتا ہے کھلا رزق دیتا ہے اور جسے چاہتا ہے نپا تلا دیتا ہے، اُسے ہر چیز کا علم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxv{اُس نے تمہارے لیے دین کا وہی طریقہ مقرر کیا ہے جس کا حکم اُس نے نوحؑ کو دیا تھا، اور جسے (اے محمدؐ) اب تمہاری طرف ہم نے وحی کے ذریعہ سے بھیجا ہے، اور جس کی ہدایت ہم ابراہیمؑ اور موسیٰؑ اور عیسیٰؑ کو دے چکے ہیں، اِس تاکید کے ساتھ کہ قائم کرو اِس دین کو اور اُس میں متفرق نہ ہو جاؤ یہی بات اِن مشرکین کو سخت ناگوار ہوئی ہے جس کی طرف اے محمدؐ تم انہیں دعوت دے رہے ہو اللہ جسے چاہتا ہے اپنا کر لیتا ہے، اور وہ اپنی طرف آنے کا راستہ اُسی کو دکھاتا ہے جو اُس کی طرف رجوع کرے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvi{لوگوں میں جو تفرقہ رو نما ہوا وہ اِس کے بعد ہوا کہ اُن کے پاس علم آ چکا تھا، اور اس بنا پر ہوا کہ وہ آپس میں ایک دوسرے پر زیادتی کرنا چاہتے تھے اگر تیرا رب پہلے ہی یہ نہ فرما چکا ہوتا کہ ایک وقت مقرر تک فیصلہ ملتوی رکھا جائے گا تو ان کا قضیہ چکا دیا گیا ہوتا اور حقیقت یہ ہے کہ اگلوں کے بعد جو لوگ کتاب کے وارث بنائے گئے وہ اُس کی طرف سے بڑے اضطراب انگیز شک میں پڑے ہوئے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvii{چونکہ یہ حالت پیدا ہو چکی ہے اس لیے اے محمدؐ، اب تم اُسی دین کی طرف دعوت دو، اور جس طرح تمہیں حکم دیا گیا ہے اُس پر مضبوطی کے ساتھ قائم ہو جاؤ، اور اِن لوگو ں کی خواہشات کا اتباع نہ کرو، اور اِن سے کہہ دو کہ: ``اللہ نے جو کتاب بھی نازل کی ہے میں اُس پر ایمان لایا مجھے حکم دیا گیا ہے کہ میں تمہارے درمیان انصاف کروں اللہ ہی ہمارا رب بھی ہے اور تمہارا رب بھی ہمارے اعمال ہمارے لیے ہیں اور تمہارے اعمال تمہارے لیے ہمارے اور تمہارے درمیان کوئی جھگڑا نہیں اللہ ایک روز ہم سب کو جمع کرے گا اور اُسی کی طرف سب کو جانا ہے"\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxviii{اللہ کی دعوت پر لبیک کہے جانے کے بعد جو لوگ (لبیک کہنے والوں سے) اللہ کے دین کے معاملہ میں جھگڑے کرتے ہیں، اُن کی حجت بازی اُن کے رب کے نزدیک باطل ہے، اور اُن پر اس کا غضب ہے اور اُن کے لیے سخت عذاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxix{وہ اللہ ہی ہے جس نے حق کے ساتھ یہ کتاب اور میزان نازل کی ہے اور تمہیں کیا خبر، شاید کہ فیصلے کی گھڑی قریب ہی آ لگی ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxc{جو لوگ اس کے آنے پر ایمان نہیں رکھتے وہ تو اس کے لیے جلدی مچاتے ہیں، مگر جو اس پر ایمان رکھتے ہیں وہ اس سے ڈرتے ہیں اور جانتے ہیں کہ یقیناً وہ آنے والی ہے خوب سن لو، جو لوگ اُس گھڑی کے آنے میں شک ڈالنے والی بحثیں کرتے ہیں وہ گمراہی میں بہت دور نکل گئے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxci{اللہ اپنے بندوں پر بہت مہربان ہے جسے جو کچھ چاہتا ہے دیتا ہے، وہ بڑی قوت والا اور زبردست ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcii{جو کوئی آخرت کی کھیتی چاہتا ہے اُس کی کھیتی کو ہم بڑھاتے ہیں، اور جو دنیا کی کھیتی چاہتا ہے اُسے دنیا ہی میں سے دیتے ہیں مگر آخرت میں اُس کا کوئی حصہ نہیں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciii{کیا یہ لوگ کچھ ایسے شریک خدا رکھتے ہیں جنہوں نے اِن کے لیے دین کی نوعیت رکھنے والا ایک ایسا طریقہ مقرر کر دیا ہے جس کا اللہ نے اِذن نہیں دیا؟ اگر فیصلے کی بات پہلے طے نہ ہو گئی ہوتی تو ان کا قضیہ چکا دیا گیا ہوتا یقیناً اِن ظالموں کے لیے درد ناک عذاب ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciv{تم دیکھو گے کہ یہ ظالم اُس وقت اپنے کیے کے انجام سے ڈر رہے ہوں گے اور وہ اِن پر آ کر رہے گا بخلاف اِس کے جو لوگ ایمان لے آئے ہیں اور جنہوں نے نیک عمل کیے ہیں وہ جنت کے گلستانوں میں ہوں گے، جو کچھ بھی وہ چاہیں گے اپنے رب کے ہاں پائیں گے، یہی بڑا فضل ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcv{یہ ہے وہ چیز جس کی خوش خبری اللہ اپنے اُن بندوں کو دیتا ہے جنہوں نے مان لیا اور نیک عمل کیے اے نبیؐ، اِن لوگوں سے کہہ دو کہ میں اِس کام پر تم سے کسی اجر کا طالب نہیں ہوں، البتہ قرابت کی محبت ضرور چاہتا ہوں جو کوئی بھلائی کمائے گا ہم اس کے لیے اس بھلائی میں خوبی کا اضافہ کر دیں گے بے شک اللہ بڑا در گزر کرنے والا اور قدر دان ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvi{کیا یہ لوگ کہتے ہیں کہ اِس شخص نے اللہ پر جھوٹا بہتان گھڑ لیا ہے؟ اگر اللہ چاہے تو تمہارے دل پر مہر کر دے وہ باطل کو مٹا دیتا ہے اور حق کو اپنے فرمانوں سے حق کر دکھاتا ہے وہ سینوں کے چھپے ہوئے راز جانتا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvii{وہی ہے جو اپنے بندوں سے توبہ قبول کرتا ہے اور برائیوں سے درگزر کرتا ہے، حالانکہ تم لوگوں کے سب افعال کا اُ سے علم ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcviii{وہ ایمان لانے والوں اور نیک عمل کرنے والوں کی دعا قبول کرتا ہے اور اپنے فضل سے ان کو اور زیادہ دیتا ہے رہے انکار کرنے والے، تو ان کے لیے دردناک سزا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcix{اگر اللہ اپنے سب بندوں کو کھلا رزق دے دیتا تو وہ زمین میں سرکشی کا طوفان برپا کر دیتے، مگر وہ ایک حساب سے جتنا چاہتا ہے نازل کرتا ہے، یقیناً وہ اپنے بندوں سے با خبر ہے اور اُن پر نگاہ رکھتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccc{وہی ہے جو لوگوں کے مایوس ہو جانے کے بعد مینہ برساتا ہے اور اپنی رحمت پھیلا دیتا ہے، اور وہی قابل تعریف ولی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccci{اُس کی نشانیوں میں سے ہے یہ زمین اور آسمانوں کی پیدائش، اور یہ جاندار مخلوقات جو اُس نے دونوں جگہ پھیلا رکھی ہیں وہ جب چاہے انہیں اکٹھا کر سکتا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcccii{تم پر جو مصیبت بھی آئی ہے، تمہارے اپنے ہاتھوں کی کمائی سے آئی ہے، اور بہت سے قصوروں سے وہ ویسے ہی در گزر کر جاتا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccciii{تم زمین میں اپنے خدا کو عاجز کر دینے والے نہیں ہو، اور اللہ کے مقابلے میں تم کوئی حامی و ناصر نہیں رکھتے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccciv{اُس کی نشانیوں میں سے ہیں یہ جہاز جو سمندر میں پہاڑوں کی طرح نظر آتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcccv{اللہ جب چاہے ہوا کو ساکن کر دے اور یہ سمندر کی پیٹھ پر کھڑے کے کھڑے رہ جائیں اِس میں بڑی نشانیاں ہیں ہر اُس شخص کے لیے جو کمال درجہ صبر و شکر کرنے والا ہو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvi{یا (اُن پر سوار ہونے والوں کے) بہت سے گناہوں سے در گزر کرتے ہوئے ان کے چند ہی کرتوتوں کی پاداش میں انہیں ڈبو دے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvii{اور اُس وقت ہماری آیات میں جھگڑے کرنے والوں کو پتہ چل جائے کہ ان کے لیے کوئی جائے پناہ نہیں ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcccviii{جو کچھ بھی تم لوگوں کو دیا گیا ہے وہ محض دنیا کی چند روزہ زندگی کا سر و سامان ہے، اور جو کچھ اللہ کے ہاں ہے وہ بہتر بھی ہے اور پائدار بھی وہ اُن لوگوں کے لیے ہے جو ایمان لائے ہیں اور اپنے رب پر بھروسہ کرتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcccix{جو بڑے بڑے گناہوں اور بے حیائی کے کاموں سے پرہیز کرتے ہیں اور اگر غصہ آ جائے تو درگزر کر جا تے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcccx{جو اپنے رب کا حکم مانتے ہیں، نماز قائم کرتے ہیں، اپنے معاملات آپس کے مشورے سے چلاتے ہیں، ہم نے جو کچھ بھی رزق انہیں دیا ہے اُس میں سے خرچ کرتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxi{اور جب ان پر زیادتی کی جاتی ہے تو اس کا مقابلہ کرتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxii{برائی کا بدلہ ویسی ہی برائی ہے، پھر جو کوئی معاف کر دے اور اصلاح کرے اُس کا اجر اللہ کے ذمہ ہے، اللہ ظالموں کو پسند نہیں کرتا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiii{اور جو لوگ ظلم ہونے کے بعد بدلہ لیں اُن کو ملامت نہیں کی جا سکتی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiv{ملامت کے مستحق تو وہ ہیں جو دوسروں پر ظلم کرتے ہیں اور زمین میں ناحق زیادتیاں کرتے ہیں ایسے لوگوں کے لیے دردناک عذاب ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxv{البتہ جو شخص صبر سے کام لے اور درگزر کرے، تو یہ بڑی اولوالعزمی کے کاموں میں سے ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvi{جس کو اللہ ہی گمراہی میں پھینک دے اُس کا کوئی سنبھالنے والا اللہ کے بعد نہیں ہے تم دیکھو گے کہ یہ ظالم جب عذاب دیکھیں گے تو کہیں گے اب پلٹنے کی بھی کوئی سبیل ہے؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvii{اور تم دیکھو گے کہ یہ جہنم کے سامنے جب لائے جائیں گے تو ذلت کے مارے جھکے جا رہے ہوں گے اور اُس کو نظر بچا بچا کر کن آنکھیوں سے دیکھیں گے اُس وقت وہ لوگ جو ایمان لائے تھے کہیں گے کہ واقعی اصل زیاں کار وہی ہیں جنہوں نے آج قیامت کے دن اپنے آپ کو اور اپنے متعلقین کو خسارے میں ڈال دیا خبردار رہو، ظالم لوگ مستقل عذاب میں ہوں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxviii{اور ان کے کوئی حامی و سرپرست نہ ہوں گے جو اللہ کے مقابلے میں ان کی مدد کو آئیں جسے اللہ گمراہی میں پھینک دے اس کے لیے بچاؤ کی کوئی سبیل نہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxix{مان لو اپنے رب کی بات قبل اس کے کہ وہ دن آئے جس کے ٹلنے کی کوئی صورت اللہ کی طرف سے نہیں ہے اُس دن تمہارے لیے کوئی جائے پناہ نہ ہوگی اور نہ کوئی تمہارے حال کو بدلنے کی کوشش کرنے والا ہو گا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxx{اب اگر یہ لوگ منہ موڑتے ہیں تو اے نبیؐ، ہم نے تم کو ان پر نگہبان بنا کر تو نہیں بھیجا ہے تم پر تو صرف بات پہنچا دینے کی ذمہ داری ہے انسان کا حال یہ ہے کہ جب ہم اسے اپنی رحمت کا مزا چکھاتے ہیں تو اُس پر پھول جاتا ہے، اور اگر اس کے اپنے ہاتھوں کا کیا دھرا کسی مصیبت کی شکل میں اُس پر الٹ پڑتا ہے تو سخت ناشکرا بن جاتا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxi{اللہ زمین اور آسمانوں کی بادشاہی کا مالک ہے، جو کچھ چاہتا ہے پیدا کرتا ہے، جسے چاہتا ہے لڑکیاں دیتا ہے، جسے چاہتا ہے لڑکے دیتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxii{جسے چاہتا ہے لڑکے اور لڑکیاں ملا جلا کر دیتا ہے، اور جسے چاہتا ہے بانجھ کر دیتا ہے وہ سب کچھ جانتا اور ہر چیز پر قادر ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiii{کسی بشر کا یہ مقام نہیں ہے کہ اللہ اُس سے روبرو بات کرے اُس کی بات یا تو وحی (اشارے) کے طور پر ہوتی ہے، یا پردے کے پیچھے سے، یا پھر وہ کوئی پیغام بر (فرشتہ) بھیجتا ہے اور وہ اُس کے حکم سے جو کچھ وہ چاہتا ہے، وحی کرتا ہے، وہ برتر اور حکیم ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiv{اور اِسی طرح (اے محمدؐ) ہم نے اپنے حکم سے ایک روح تمہاری طرف وحی کی ہے تمہیں کچھ پتہ نہ تھا کہ کتاب کیا ہوتی ہے اور ایمان کیا ہوتا ہے، مگر اُس روح کو ہم نے ایک روشنی بنا دیا جس سے ہم راہ دکھاتے ہیں اپنے بندوں میں سے جسے چاہتے ہیں یقیناً تم سیدھے راستے کی طرف رہنمائی کر رہے ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxv{اُس خدا کے راستے کی طرف جو زمین اور آسمانوں کی ہر چیز کا مالک ہے خبردار رہو، سارے معاملات اللہ ہی کی طرف رجوع کرتے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvi{\basmalahur ح م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvii{قسم ہے اِس واضح کتاب کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxviii{کہ ہم نے اِسے عربی زبان کا قرآن بنایا ہے تاکہ تم لوگ اِسے سمجھو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxix{اور در حقیقت یہ ام الکتاب میں ثبت ہے، ہمارے ہاں بڑی بلند مرتبہ اور حکمت سے لبریز کتاب\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxx{اب کیا ہم تم سے بیزار ہو کر یہ درس نصیحت تمہارے ہاں بھیجنا چھوڑ دیں صرف اِس لیے کہ تم حد سے گزرے ہوئے لوگ ہو؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxi{پہلے گزری ہوئی قوموں میں بھی بارہا ہم نے نبی بھیجے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxii{کبھی ایسا نہیں ہوا کہ کوئی نبی اُن کے ہاں آیا ہو اور انہوں نے اُس کا مذاق نہ اڑایا ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiii{پھر جو لوگ اِن سے بدرجہا زیادہ طاقتور تھے اُنہیں ہم نے ہلاک کر دیا، پچھلی قوموں کی مثالیں گزر چکی ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiv{اگر تم اِن لوگوں سے پوچھو کہ زمین اور آسمانوں کو کس نے پیدا کیا ہے تو یہ خود کہیں گے کہ انہیں اُسی زبردست علیم ہستی نے پیدا کیا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxv{وہی نا جس نے تمہارے لیے اس زمین کو گہوارہ بنایا اور اس میں تمہاری خاطر راستے بنا دیے تاکہ تم اپنی منزل مقصود کی راہ پاسکو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvi{جس نے ایک خاص مقدار میں آسمان سے پانی اتارا اور اس کے ذریعہ سے مردہ زمین کو جلا اٹھایا، اِسی طرح ایک روز تم زمین سے برآمد کیے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvii{وہی جس نے یہ تمام جوڑے پیدا کیے، اور جس نے تمہارے لیے کشتیوں اور جانوروں کو سواری بنایا تاکہ تم اُن کی پشت پر چڑھو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxviii{اور جب اُن پر بیٹھو تو اپنے رب کا احسان یاد کرو اور کہو کہ ``پاک ہے وہ جس نے ہمارے لیے اِن چیزوں کو مسخر کر دیا ورنہ ہم انہیں قابو میں لانے کی طاقت نہ رکھتے تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxix{اور ایک روز ہمیں اپنے رب کی طرف پلٹنا ہے"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxl{(یہ سب کچھ جانتے اور مانتے ہوئے بھی) اِن لوگوں نے اُس کے بندوں میں سے بعض کو اس کا جز بنا ڈالا، حقیقت یہ ہے کہ انسان کھلا احسان فراموش ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxli{کیا اللہ نے اپنی مخلوق میں سے اپنے لیے بیٹیاں انتخاب کیں اور تمہیں بیٹوں سے نوازا؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlii{اور حال یہ ہے کہ جس اولاد کو یہ لوگ اُس خدائے رحمان کی طرف منسوب کرتے ہیں اُس کی ولادت کا مژدہ جب خود اِن میں سے کسی کو دیا جاتا ہے تو اُس کے منہ پر سیاہی چھا جاتی ہے اور وہ غم سے بھر جاتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliii{کیا اللہ کے حصے میں وہ اولاد آئی جو زیوروں میں پالی جاتی ہے اور بحث و حجت میں اپنا مدعا پوری طرح واضح بھی نہیں کر سکتی؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliv{انہوں نے فرشتوں کو، جو خدائے رحمان کے خاص بندے ہیں، عورتیں قرار دے لیا کیا اُن کے جسم کی ساخت اِنہوں نے دیکھی ہے؟ اِن کی گواہی لکھ لی جائے گی اور انہیں اس کی جوابدہی کرنی ہو گی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlv{یہ کہتے ہیں ``اگر خدائے رحمٰن چاہتا (کہ ہم اُن کی عبادت نہ کریں) تو ہم کبھی اُن کو نہ پوجتے" یہ اس معاملے کی حقیقت کو قطعی نہیں جانتے، محض تیر تکے لڑاتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvi{کیا ہم نے اِس سے پہلے کوئی کتاب اِن کو دی تھی جس کی سند (اپنی اِس ملائکہ پرستی کے لیے) یہ اپنے پاس رکھتے ہوں؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvii{نہیں، بلکہ یہ کہتے ہیں کہ ہم نے اپنے باپ دادا کو ایک طریقے پر پایا ہے اور ہم اُنہی کے نقش قدم پر چل رہے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlviii{اِسی طرح تم سے پہلے جس بستی میں بھی ہم نے کوئی نذیر بھیجا، اُس کے کھاتے پیتے لوگوں نے یہی کہا کہ ہم نے اپنے باپ دادا کو ایک طریقے پر پایا ہے اور ہم اُنہی کے نقش قدم کی پیروی کر رہے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlix{ہر نبی نے ان سے پوچھا، کیا تم اُسی ڈگر پر چلے جاؤ گے خواہ میں اُس راستے سے زیادہ صحیح راستہ تمہیں بتاؤں جس پر تم نے اپنے باپ دادا کو پایا ہے؟ انہوں نے سارے رسولوں کو یہی جواب دیا کہ جس دین کی طرف بلانے کے لیے تم بھیجے گئے ہو ہم اُس کے کافر ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcccl{آخر کار ہم نے اُن کی خبر لے ڈالی اور دیکھ لو کہ جھٹلانے والوں کا کیا انجام ہوا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcccli{یاد کرو وہ وقت جب ابراہیمؑ نے اپنے باپ اور اپنی قوم سے کہا تھا کہ ``تم جن کی بندگی کرتے ہو میرا اُن سے کوئی تعق نہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccclii{میرا تعلق صرف اُس سے ہے جس نے مجھے پیدا کیا، وہی میری رہنمائی کرے گا"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliii{اور ابراہیمؑ یہی کلمہ اپنے پیچھے اپنی اولاد میں چھوڑ گیا تاکہ وہ اِس کی طرف رجوع کریں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliv{(اس کے باوجود جب یہ لوگ دوسروں کی بندگی کرنے لگے تو میں نے ان کو مٹا نہیں دیا) بلکہ میں اِنہیں اور اِن کے باپ دادا کو متاع حیات دیتا رہا یہاں تک کہ اِن کے پاس حق، اور کھول کھول کر بیان کرنے والا رسول آگیا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccclv{مگر جب وہ حق اِن کے پاس آیا تو اِنہوں نے کہہ دیا کہ یہ تو جادو ہے اور ہم اس کو ماننے سے انکار کرتے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvi{کہتے ہیں، یہ قرآن دونوں شہروں کے بڑے آدمیوں میں سے کسی پر کیوں نہ نازل کیا گیا؟\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvii{کیا تیرے رب کی رحمت یہ لوگ تقسیم کرتے ہیں؟ دنیا کی زندگی میں اِن کی گزر بسر کے ذرائع تو ہم نے اِن کے درمیان تقسیم کیے ہیں، اور اِن میں سے کچھ لوگوں کو کچھ دوسرے لوگوں پر ہم نے بدرجہا فوقیت دی ہے تاکہ یہ ایک دوسرے سے خدمت لیں اور تیرے رب کی رحمت اُس دولت سے زیادہ قیمتی ہے جو (اِن کے رئیس) سمیٹ رہے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccclviii{اگر یہ اندیشہ نہ ہوتا کہ سارے لوگ ایک ہی طریقے کے ہو جائیں گے تو خدائے رحمان سے کفر کرنے والوں کے گھروں کی چھتیں، اور ان کی سیڑھیاں جن سے وہ اپنے بالا خانوں پر چڑھتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmccclix{اور اُن کے دروازے، اور ان کے تخت جن پر وہ تکیے لگا کر بیٹھتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccclx{سب چاندی اور سونے کے بنوا دیتے یہ تو محض حیات دنیا کی متاع ہے، اور آخرت تیرے رب کے ہا ں صرف متقین کے لیے ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxi{جو شخص رحمان کے ذکر سے تغافل برتتا ہے، ہم اس پر ایک شیطان مسلط کر دیتے ہیں اور وہ اُس کا رفیق بن جاتا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxii{یہ شیاطین ایسے لوگو ں کو راہ راست پر آنے سے روکتے ہیں، اور وہ اپنی جگہ یہ سمجھتے ہیں کہ ہم ٹھیک جا رہے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiii{آخر کار جب یہ شخص ہمارے ہاں پہنچے گا تو اپنے شیطان سے کہے گا، ``کاش میرے اور تیرے درمیان مشرق و مغرب کا بُعد ہوتا، تُو تو بد ترین ساتھی نکلا"\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiv{اُس وقت اِن لوگوں سے کہا جائے گا کہ جب تم ظلم کر چکے تو آج یہ بات تمہارے لیے کچھ بھی نافع نہیں ہے کہ تم اور تمہارے شیاطین عذاب میں مشترک ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxv{اب کیا اے نبیؐ، تم بہروں کو سناؤ گے؟ یا اندھوں اور صریح گمراہی میں پڑے ہوئے لوگوں کو راہ دکھاؤ گے؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvi{اب تو ہمیں اِن کو سزا دینی ہے خواہ تمہیں دنیا سے اٹھا لیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvii{یا تم کو آنکھوں سے اِن کا وہ انجام دکھا دیں جس کا ہم نے اِن سے وعدہ کیا ہے، ہمیں اِن پر پوری قدرت حاصل ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxviii{تم بہر حال اُس کتاب کو مضبوطی سے تھامے رہو جو وحی کے ذریعہ سے تمہارے پاس بھیجی گئی ہے، یقیناً تم سیدھے راستے پر ہو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxix{حقیقت یہ ہے کہ یہ کتاب تمہارے لیے اور تمہاری قوم کے لیے ایک بہت بڑا شرف ہے اور عنقریب تم لوگوں کو اس کی جواب دہی کرنی ہو گی\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxx{تم سے پہلے ہم نے جتنے رسول بھیجے تھے اُن سب سے پوچھ دیکھو، کیا ہم نے خدائے رحمان کے سوا کچھ دوسرے معبود بھی مقرر کیے تھے کہ اُن کی بندگی کی جائے؟\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxi{ہم نے موسیٰؑ کو اپنی نشانیوں کے ساتھ فرعون اور اُس کے اعیان سلطنت کے پاس بھیجا، اور اس نے جا کر کہا کہ میں رب العالمین کا رسول ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxii{پھر جب اُس نے ہماری نشانیاں ان کے سامنے پیش کیں تو وہ ٹھٹھے مارنے لگے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiii{ہم ایک پر ایک ایسی نشانی اُن کو دکھاتے چلے گئے جو پہلی سے بڑھ چڑھ کر تھی، اور ہم نے اُن کو عذاب میں دھر لیا تاکہ وہ اپنی روش سے باز آئیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiv{ہر عذاب کے موقع پر وہ کہتے، اے ساحر، اپنے رب کی طرف سے جو منصب تجھے حاصل ہے اُس کی بنا پر ہمارے لیے اُس سے دعا کر، ہم ضرور راہ راست پر آ جائیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxv{مگر جوں ہی کہ ہم ان پر سے عذاب ہٹا دیتے وہ اپنی بات سے پھر جاتے تھے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvi{ایک روز فرعون نے اپنی قوم کے درمیان پکار کر کہا، ``لوگو، کیا مصر کی بادشاہی میری نہیں ہے، اور یہ نہریں میرے نیچے نہیں بہہ رہی ہیں؟ کیا تم لوگوں کو نظر نہیں آتا؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvii{میں بہتر ہوں یا یہ شخص جو ذلیل و حقیر ہے اور اپنی بات بھی کھول کر بیان نہیں کر سکتا؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxviii{کیوں نہ اس پر سونے کے کنگن اتارے گئے؟ یا فرشتوں کا ایک دستہ اس کی اردلی میں نہ آیا؟"\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxix{اُس نے اپنی قوم کو ہلکا سمجھا اور انہوں نے اس کی اطاعت کی، در حقیقت وہ تھے ہی فاسق لوگ\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxx{آخر کار جب انہوں نے ہمیں غضب ناک کر دیا تو ہم نے ان سے انتقام لیا اور ان کو اکٹھا غرق کر دیا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxi{اور بعد والوں کے لیے پیش رو اور نمونہ عبرت بنا کر رکھ دیا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxii{اور جونہی کہ ابن مریم کی مثال دی گئی، تمہاری قوم کے لوگوں نے اس پر غل مچا دیا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiii{اور لگے کہنے کہ ہمارے معبود اچھے ہیں یا وہ؟ یہ مثال وہ تمہارے سامنے محض کج بحثی کے لیے لائے ہیں، حقیقت یہ ہے کہ یہ ہیں ہی جھگڑالو لوگ\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiv{ابن مریمؑ اِس کے سوا کچھ نہ تھا کہ ایک بندہ تھا جس پر ہم نے انعام کیا اور بنی اسرائیل کے لیے اپنی قدرت کا ایک نمونہ بنا دیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxv{ہم چاہیں تو تم سے فرشتے پیدا کر دیں جو زمین میں تمہارے جانشین ہوں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvi{اور وہ دراصل قیامت کی ایک نشانی ہے، پس تم اُس میں شک نہ کرو اور میری بات مان لو، یہی سیدھا راستہ ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvii{ایسا نہ ہو شیطان تم کو اُس سے روک دے کہ وہ تمہارا کھلا دشمن ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxviii{اور جب عیسیٰؑ صریح نشانیاں لیے ہوئے آیا تھا تو اس نے کہا تھا کہ ``میں تم لوگوں کے پاس حکمت لے کر آیا ہوں، اور اس لیے آیا ہوں کہ تم پر بعض اُن باتوں کی حقیقت کھول دوں جن میں تم اختلاف کر رہے ہو، لہٰذا تم اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxix{حقیقت یہ ہے کہ اللہ ہی میرا رب بھی ہے اور تمہارا رب بھی اُسی کی تم عبادت کرو، یہی سیدھا راستہ ہے"\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxc{مگر (اُس کی اِس صاف تعلیم کے باوجود) گروہوں نے آپس میں اختلاف کیا، پس تباہی ہے اُن لوگوں کے لیے جنہوں نے ظلم کیا ایک دردناک دن کے عذاب سے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxci{کیا یہ لوگ اب بس اِسی چیز کے منتظر ہیں کہ اچانک اِن پر قیامت آ جائے اور انہیں خبر بھی نہ ہو؟\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcii{وہ دن جب آئے گا تو متقین کو چھوڑ کر باقی سب دوست ایک دوسرے کے دشمن ہو جائیں گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciii{اُس روز اُن لوگوں سے جو ہماری آیات پر ایمان لائے تھے اور مطیع فرمان بن کر رہے تھے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciv{کہا جائے گا کہ ``اے میرے بندو، آج تمہارے لیے کوئی خوف نہیں اور نہ تمہیں کوئی غم لاحق ہوگا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcv{داخل ہو جاؤ جنت میں تم اور تمہاری بیویاں، تمہیں خوش کر دیا جائے گا"\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvi{اُن کے آگے سونے کے تھال اور ساغر گردش کرائے جائیں گے اور ہر من بھاتی اور نگاہوں کو لذت دینے والی چیز وہاں موجود ہو گی ان سے کہا جائے گا، ``تم اب یہاں ہمیشہ رہو گے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvii{تم اِس جنت کے وارث اپنے اُن اعمال کی وجہ سے ہوئے ہو جو تم دنیا میں کرتے رہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcviii{تمہارے لیے یہاں بکثرت فواکہ موجود ہیں جنہیں تم کھاؤ گے"\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcix{رہے مجرمین، تو وہ ہمیشہ جہنم کے عذاب میں مبتلا رہیں گے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcd{کبھی اُن کے عذاب میں کمی نہ ہو گی، اور وہ اس میں مایوس پڑے ہوں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcdi{ان پر ہم نے ظلم نہیں کیا بلکہ وہ خود ہی اپنے اوپر ظلم کرتے رہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcdii{وہ پکاریں گے، ``اے مالک، تیرا رب ہمارا کام ہی تمام کر دے تو اچھا ہے" وہ جواب دے گا، ``تم یوں ہی پڑے رہو گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiii{ہم تمہارے پاس حق لے کر آئے تھے مگر تم میں سے اکثر کو حق ہی ناگوار تھا"\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiv{کیا اِن لوگوں نے کوئی اقدام کرنے کا فیصلہ کر لیا ہے؟ اچھا تو ہم بھی پھر ایک فیصلہ کیے لیتے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmcdv{کیا اِنہوں نے یہ سمجھ رکھا ہے کہ ہم اِن کی راز کی باتیں اور اِن کی سرگوشیاں سنتے نہیں ہیں؟ ہم سب کچھ سن رہے ہیں اور ہمارے فرشتے اِن کے پاس ہی لکھ رہے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvi{اِن سے کہو، ``اگر واقعی رحمان کی کوئی اولاد ہوتی تو سب سے پہلے عبادت کرنے والا میں ہوتا"\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvii{پاک ہے آسمانوں اور زمین کا فرماں روا عرش کا مالک، اُن ساری باتوں سے جو یہ لوگ اُس کی طرف منسوب کرتے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmcdviii{اچھا، اِنہیں اپنے باطل خیالات میں غرق اور اپنے کھیل میں منہمک رہنے دو، یہاں تک کہ یہ اپنا وہ دن دیکھ لیں جس کا اِنہیں خوف دلایا جا رہا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmcdix{وہی ایک آسمان میں بھی خدا ہے اور زمین میں بھی خدا، اور وہی حکیم و علیم ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmcdx{بہت بالا و برتر ہے وہ جس کے قبضے میں زمین اور آسمانوں اور ہر اُس چیز کی بادشاہی ہے جو زمین و آسمان کے درمیان پائی جاتی ہے اور وہی قیامت کی گھڑی کا علم رکھتا ہے، اور اسی کی طرف تم سب پلٹائے جانے والے ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxi{اُس کو چھوڑ کر یہ لوگ جنہیں پکارتے ہیں وہ کسی شفاعت کا اختیار نہیں رکھتے، الا یہ کہ کوئی علم کی بنا پر حق کی شہادت دے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxii{اور اگر تم اِن سے پوچھو کہ اِنہیں کس نے پیدا کیا ہے تو یہ خود کہیں گے کہ اللہ نے پھر کہاں سے یہ دھوکا کھا رہے ہیں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiii{قسم ہے رسولؐ کے اِس قول کی کہ اے رب، یہ وہ لوگ ہیں جو مان کر نہیں دیتے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiv{اچھا، اے نبیؐ، اِن سے درگزر کرو اور کہہ دو کہ سلام ہے تمہیں، عنقریب اِنہیں معلوم ہو جائے گا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxv{\basmalahur ح م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvi{قسم ہے اِس کتاب مبین کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvii{کہ ہم نے اِسے ایک بڑی خیر و برکت والی رات میں نازل کیا ہے، کیونکہ ہم لوگوں کو متنبہ کرنے کا ارادہ رکھتے تھے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxviii{یہ وہ رات تھی جس میں ہر معاملہ کا حکیمانہ فیصلہ\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxix{ہمارے حکم سے صادر کیا جاتا ہے ہم ایک رسول بھیجنے والے تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxx{تیرے رب کی رحمت کے طور پر یقیناً وہی سب کچھ سننے اور جاننے والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxi{آسمانوں اور زمین کا رب اور ہر اُس چیز کا رب جو آسمان و زمین کے درمیان ہے اگر تم لوگ واقعی یقین رکھنے والے ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxii{کوئی معبود اُس کے سوا نہیں ہے وہی زندگی عطا کرتا ہے اور وہی موت دیتا ہے تمہارا رب اور تمہارے اُن اسلاف کا رب جو پہلے گزر چکے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiii{(مگر فی الواقع اِن لوگوں کو یقین نہیں ہے) بلکہ یہ اپنے شک میں پڑے کھیل رہے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiv{اچھا انتظار کرو اُس دن کا جب آسمان صریح دھواں لیے ہوئے آئے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxv{اور وہ لوگوں پر چھا جائے گا، یہ ہے درد ناک سزا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvi{(اب کہتے ہیں کہ) `` پروردگار، ہم پر سے یہ عذاب ٹال دے، ہم ایمان لاتے ہیں"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvii{اِن کی غفلت کہاں دور ہوتی ہے؟ اِن کا حال تو یہ ہے کہ اِن کے پاس رسول مبین آ گیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxviii{پھر بھی یہ اُس کی طرف ملتفت نہ ہوئے اور کہا کہ ``یہ تو سکھایا پڑھایا باولا ہے"\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxix{ہم ذرا عذاب ہٹائے دیتے ہیں، تم لوگ پھر وہی کچھ کرو گے جو پہلے کر رہے تھے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxx{جس روز ہم بڑی ضرب لگائیں گے وہ دن ہوگا جب ہم تم سے انتقام لیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxi{ہم اِن سے پہلے فرعون کی قوم کو اِسی آزمائش میں ڈال چکے ہیں اُن کے پاس ایک نہایت شریف رسول آیا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxii{اور اس نے کہا ``اللہ کے بندوں کو میرے حوالے کرو، میں تمہارے لیے ایک امانت دار رسول ہوں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiii{اللہ کے مقابلے میں سرکشی نہ کرو میں تمہارے سامنے (اپنی ماموریت کی) صریح سند پیش کرتا ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiv{اور میں اپنے رب اور تمہارے رب کی پناہ لے چکا ہوں اِس سے کہ تم مجھ پر حملہ آور ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxv{اگر تم میری بات نہیں مانتے تو مجھ پر ہاتھ ڈالنے سے باز رہو"\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvi{آخرکار اُس نے اپنے رب کو پکارا کہ یہ لوگ مجرم ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvii{(جواب دیا گیا) اچھا تو راتوں رات میرے بندوں کو لے کر چل پڑ تم لوگوں کا پیچھا کیا جائے گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxviii{سمندر کو اُس کے حال پر کھلا چھوڑ دے یہ سارا لشکر غرق ہونے والا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxix{`` کتنے ہی باغ اور چشمے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxl{اور کھیت اور شاندار محل تھے جو وہ چھوڑ گئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxli{کتنے ہی عیش کے سر و سامان، جن میں وہ مزے کر رہے تھے اُن کے پیچھے دھرے رہ گئے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlii{یہ ہوا اُن کا انجام، اور ہم نے دوسروں کو اِن چیزوں کا وارث بنا دیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliii{پھر نہ آسمان اُن پر رویا نہ زمین، اور ذرا سی مہلت بھی ان کو نہ دی گئی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliv{اِس طرح بنی اسرائیل کو ہم نے سخت ذلت کے عذاب\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlv{فرعون سے نجات دی جو حد سے گزر جانے والوں میں فی الواقع بڑے اونچے درجے کا آدمی تھا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvi{اور اُن کی حالت جانتے ہوئے، اُن کو دنیا کی دوسری قوموں پر ترجیح دی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvii{اور اُنہیں ایسی نشانیاں دکھائیں جن میں صریح آزمائش تھی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlviii{یہ لوگ کہتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlix{``ہماری پہلی موت کے سوا اور کچھ نہیں اُس کے بعد ہم دوبارہ اٹھائے جانے والے نہیں ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcdl{اگر تم سچے ہو تو اٹھا لاؤ ہمارے باپ دادا کو"\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcdli{یہ بہتر ہیں یا تبع کی قوم اور اُس سے پہلے کے لوگ؟ ہم نے ان کو اِسی بنا پر تباہ کیا کہ وہ مجرم ہوگئے تھے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlii{یہ آسمان و زمین اور اِن کے درمیان کی چیزیں ہم نے کچھ کھیل کے طور پر نہیں بنا دی ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliii{اِن کو ہم نے برحق پیدا کیا ہے، مگر اکثر لوگ جانتے نہیں ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliv{اِن سب کے اٹھائے جانے کے لیے طے شدہ وقت فیصلے کا دن ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlv{وہ دن جب کوئی عزیز قریب اپنے کسی عزیز قریب کے کچھ بھی کام نہ آئے گا، اور نہ کہیں سے انہیں کوئی مدد پہنچے گی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvi{سوائے اِس کے کہ اللہ ہی کسی پر رحم کرے، وہ زبردست اور رحیم ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvii{زقوم کا درخت\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlviii{گناہ گار کا کھاجا ہوگا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlix{تیل کی تلچھٹ جیسا، پیٹ میں اِس طرح جوش کھائے گا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlx{جیسے کھولتا ہوا پانی جوش کھاتا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxi{`` پکڑو اِسے اور رگیدتے ہوئے لے جاؤ اِس کو جہنم کے بیچوں بیچ\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxii{اور انڈیل دو اِس کے سر پر کھولتے پانی کا عذاب\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiii{چکھ اس کا مزا، بڑا زبردست عزت دار آدمی ہے تُو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiv{یہ وہی چیز ہے جس کے آنے میں تم لوگ شک رکھتے تھے"\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxv{خدا ترس لوگ امن کی جگہ میں ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvi{باغوں اور چشموں میں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvii{حریر و دیبا کے لباس پہنے، آمنے سامنے بیٹھے ہوں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxviii{یہ ہوگی ان کی شان اور ہم گوری گوری آہو چشم عورتیں ان سے بیاہ دیں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxix{وہاں وہ اطمینان سے ہر طرح کی لذیذ چیزیں طلب کریں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxx{وہاں موت کا مزہ وہ کبھی نہ چکھیں گے، بس دنیا میں جو موت آ چکی سو آ چکی اور اللہ اپنے فضل سے،\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxi{ان کو جہنم کے عذاب سے بچا دے گا یہی بڑی کامیابی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxii{اے نبیؐ، ہم نے اِس کتاب کو تمہاری زبان میں سہل بنا دیا ہے تاکہ یہ لوگ نصیحت حاصل کریں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiii{اب تم بھی انتظار کرو، یہ بھی منتظر ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiv{\basmalahur ح م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxv{اِس کتاب کا نزول اللہ کی طرف سے ہے جو زبردست اور حکیم ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvi{حقیقت یہ ہے کہ آسمانوں اور زمین میں بے شمار نشانیاں ہیں ایمان لانے والوں کے لیے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvii{اور تمہاری اپنی پیدائش میں، اور اُن حیوانات میں جن کو اللہ (زمین میں) پھیلا رہا ہے، بڑی نشانیاں ہیں اُن لوگوں کے لیے جو یقین لانے والے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxviii{اور شب و روز کے فرق و اختلاف میں، اور اُس رزق میں جسے اللہ آسمان سے نازل فرماتا ہے پھر اس کے ذریعہ سے مردہ زمین کو جِلا اٹھاتا ہے، اور ہواؤں کی گردش میں بہت نشانیاں ہیں اُن لوگوں کے لیے جو عقل سے کام لیتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxix{یہ اللہ کی نشانیاں ہیں جنہیں ہم تمہارے سامنے ٹھیک ٹھیک بیان کر رہے ہیں اب آخر اللہ اور اس کی آیات کے بعد اور کون سی بات ہے جس پر یہ لوگ ایمان لائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxx{تباہی ہے ہر اُس جھوٹے بد اعمال شخص کے لیے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxi{جس کے سامنے اللہ کی آیات پڑھی جاتی ہیں، اور وہ اُن کو سنتا ہے، پھر پورے استکبار کے ساتھ اپنے کفر پر اِس طرح اڑا رہتا ہے کہ گویا اس نے اُن کو سنا ہی نہیں ایسے شخص کو درد ناک عذاب کا مژدہ سنا دو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxii{ہماری آیات میں سے کوئی بات جب اس کے علم میں آتی ہے تو وہ اُن کا مذاق بنا لیتا ہے ایسے سب لوگوں کے لیے ذلت کا عذاب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiii{اُن کے آگے جہنم ہے جو کچھ بھی انہوں نے دنیا میں کمایا ہے اس میں سے کوئی چیز اُن کے کسی کام نہ آئے گی، نہ اُن کے وہ سرپرست ہی اُن کے لیے کچھ کر سکیں گے جنہیں اللہ کو چھوڑ کر انہوں نے اپنا ولی بنا رکھا ہے اُن کے لیے بڑا عذاب ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiv{یہ قرآن سراسر ہدایت ہے، اور اُن لوگوں کے لیے بلا کا درد ناک عذاب ہے جنہوں نے اپنے رب کی آیات کو ماننے سے انکار کیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxv{وہ اللہ ہی تو ہے جس نے تمہارے لیے سمندر کو مسخر کیا تاکہ اس کے حکم سے کشتیاں اُس میں چلیں اور تم اس کا فضل تلاش کرو اور شکر گزار ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvi{اس نے زمین اور آسمانوں کی ساری ہی چیزوں کو تمہارے لیے مسخر کر دیا، سب کچھ اپنے پاس سے اِس میں بڑی نشانیاں ہیں اُن لوگوں کے لیے جو غور و فکر کرنے والے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvii{اے نبیؐ، ایمان لانے والوں سے کہہ دو کہ جو لوگ اللہ کی طرف سے برے دن آنے کا کوئی اندیشہ نہیں رکھتے، اُن کی حرکتوں پر درگزر سے کام لیں تاکہ اللہ خود ایک گروہ کو اس کی کمائی کا بدلہ دے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxviii{جو کوئی نیک عمل کرے گا اپنے ہی لیے کرے گا، اور جو برائی کرے گا وہ آپ ہی اس کا خمیازہ بھگتے گا پھر جانا تو سب کو اپنے رب ہی کی طرف ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxix{اِس سے پہلے بنی اسرائیل کو ہم نے کتاب اور حکم اور نبوت عطا کی تھی اُن کو ہم نے عمدہ سامان زیست سے نوازا، دنیا بھر کے لوگوں پر انہیں فضیلت عطا کی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxc{اور دین کے معاملہ میں اُنہیں واضح ہدایات دے دیں پھر جو اختلاف اُن کے درمیان رو نما ہوا وہ (نا واقفیت کی وجہ سے نہیں بلکہ) علم آ جانے کے بعد ہوا اور اس بنا پر ہوا کہ وہ آپس میں ایک دوسرے پر زیادتی کرنا چاہتے تھے اللہ قیامت کے روز اُن معاملات کا فیصلہ فرما دے گا جن میں وہ اختلاف کرتے رہے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxci{اس کے بعد اب اے نبیؐ، ہم نے تم کو دین کے معاملہ میں ایک صاف شاہراہ (شریعت) پر قائم کیا ہے لہٰذا تم اسی پر چلو اور اُن لوگوں کی خواہشات کا اتباع نہ کرو جو علم نہیں رکھتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcii{اللہ کے مقابلے میں وہ تمہارے کچھ بھی کام نہیں آ سکتے ظالم لوگ ایک دوسرے کے ساتھی ہیں، اور متقیوں کا ساتھی اللہ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciii{یہ بصیرت کی روشنیاں ہیں سب لوگوں کے لیے اور ہدایت اور رحمت اُن لوگوں کے لیے جو یقین لائیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciv{کیا وہ لوگ جنہوں نے برائیوں کا ارتکاب کیا ہے یہ سمجھے بیٹھے ہیں کہ ہم اُنہیں اور ایمان لانے والوں اور نیک عمل کرنے والوں کو ایک جیسا کر دیں گے کہ ان کا جینا اور مرنا یکساں ہو جائے؟ بہت بُرے حکم ہیں جو یہ لوگ لگاتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcv{اللہ نے تو آسمانوں اور زمین کو برحق پیدا کیا ہے اور اس لیے کیا ہے کہ ہر متنفس کو اُس کی کمائی کا بدلہ دیا جائے لوگوں پر ظلم ہرگز نہ کیا جائے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvi{پھر کیا تم نے کبھی اُس شخص کے حال پر بھی غور کیا جس نے اپنی خواہش نفس کو اپنا خدا بنا لیا اور اللہ نے علم کے باوجود اُسے گمراہی میں پھینک دیا اور اُس کے دل اور کانوں پر مہر لگا دی اور اُس کی آنکھوں پر پردہ ڈال دیا؟ اللہ کے بعد اب اور کون ہے جو اُسے ہدایت دے؟ کیا تم لوگ کوئی سبق نہیں لیتے؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvii{یہ لوگ کہتے ہیں کہ ``زندگی بس یہی ہماری دنیا کی زندگی ہے، یہیں ہمارا مرنا اور جینا ہے اور گردش ایام کے سوا کوئی چیز نہیں جو ہمیں ہلاک کرتی ہو" در حقیقت اِس معاملہ میں اِن کے پاس کوئی علم نہیں ہے یہ محض گمان کی بنا پر یہ باتیں کرتے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcviii{اور جب ہماری واضح آیات انہیں سنائی جاتی ہیں تو اِن کے پاس کوئی حجت اس کے سوا نہیں ہوتی کہ اٹھا لاؤ ہمارے باپ دادا کو اگر تم سچے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcix{اے نبیؐ، اِن سے کہو اللہ ہی تمہیں زندگی بخشتا ہے، پھر وہی تمہیں موت دیتا ہے، پھر وہی تم کو اُس قیامت کے دن جمع کرے گا جس کے آنے میں کوئی شک نہیں، مگر اکثر لوگ جانتے نہیں ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmd{زمین اور آسمانوں کی بادشاہی اللہ ہی کی ہے، اور جس روز قیامت کی گھڑی آ کھڑی ہو گی اُس دن باطل پرست خسارے میں پڑ جائیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdi{اُس وقت تم ہر گروہ کو گھٹنوں کے بل گرا دیکھو گے ہر گروہ کو پکارا جائے گا کہ آئے اور اپنا نامۂ اعمال دیکھے اُن سے کہا جائے گا: ``آج تم لوگوں کو اُن اعمال کا بدلہ دیا جائے گا جو تم کرتے رہے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdii{یہ ہمارا تیار کرایا ہوا اعمال نامہ ہے جو تمہارے اوپر ٹھیک ٹھیک شہادت دے رہا ہے، جو کچھ بھی تم کرتے تھے اُسے ہم لکھواتے جا رہے تھے"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdiii{پھر جو لوگ ایمان لائے تھے اور نیک عمل کرتے رہے تھے انہیں ان کا رب اپنی رحمت میں داخل کرے گا اور یہی صریح کامیابی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdiv{اور جن لوگوں نے کفر کیا تھا اُن سے کہا جائے گا ``کیا میری آیات تم کو نہیں سنائی جاتی تھیں؟ مگر تم نے تکبر کیا اور مجرم بن کر رہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdv{اور جب کہا جاتا تھا کہ اللہ کا وعدہ برحق ہے اور قیامت کے آنے میں کوئی شک نہیں، تو تم کہتے تھے کہ ہم نہیں جانتے قیامت کیا ہوتی ہے، ہم تو بس ایک گمان سا رکھتے ہیں، یقین ہم کو نہیں ہے"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdvi{اُس وقت اُن پر ان کے اعمال کی برائیاں کھل جائیں گی اور وہ اُسی چیز کے پھیر میں آ جائیں گے جس کا وہ مذاق اڑایا کرتے تھے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdvii{اور ان سے کہہ دیا جائے گا کہ ``آج ہم بھی اُسی طرح تمہیں بھلائے دیتے ہیں جس طرح تم اِس دن کی ملاقات کو بھول گئے تھے تمہارا ٹھکانا اب دوزخ ہے اور کوئی تمہاری مدد کرنے والا نہیں ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdviii{یہ تمہارا انجام اس لیے ہوا ہے کہ تم نے اللہ کی آیات کا مذاق بنا لیا تھا اور تمہیں دنیا کی زندگی نے دھوکے میں ڈال دیا تھا لہٰذا آج نہ یہ لوگ دوزخ سے نکالے جائیں گے اور نہ ان سے کہا جائے گا کہ معافی مانگ کر اپنے رب کو راضی کرو"\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdix{پس تعریف اللہ ہی کے لیے ہے جو زمین اور آسمانوں کا مالک اور سارے جہان والوں کا پروردگار ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdx{زمین اور آسمانوں میں بڑائی اُسی کے لیے ہے اور وہی زبردست اور دانا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdxi{\basmalahur ح م\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxii{اِس کتاب کا نزول اللہ زبردست اور دانا کی طرف سے ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiii{ہم نے زمین اور آسمانوں کو اور اُن ساری چیزوں کو جو اُن کے درمیان ہیں برحق، اور ایک مدت خاص کے تعین کے ساتھ پیدا کیا ہے مگر یہ کافر لوگ اُس حقیقت سے منہ موڑے ہوئے ہیں جس سے ان کو خبردار کیا گیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiv{اے نبیؐ، اِن سے کہو، ``کبھی تم نے آنکھیں کھول کر دیکھا بھی کہ وہ ہستیاں ہیں کیا جنہیں تم خدا کو چھوڑ کر پکارتے ہو؟ ذرا مجھے دکھاؤ تو سہی کہ زمین میں انہوں نے کیا پیدا کیا ہے، یا آسمانوں کی تخلیق و تدبیر میں ان کا کیا حصہ ہے اِس سے پہلے آئی ہوئی کتاب یا علم کا کوئی بقیہ (اِن عقائد کے ثبوت میں) تمہارے پاس ہو تو وہی لے آؤ اگر تم سچے ہو"\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdxv{آخر اُس شخص سے زیادہ بہکا ہوا انسان اور کون ہو گا جو اللہ کو چھوڑ کر اُن کو پکارے جو قیامت تک اسے جواب نہیں دے سکتے بلکہ اِس سے بھی بے خبر ہیں کہ پکارنے والے اُن کو پکار رہے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvi{اور جب تمام انسان جمع کیے جائیں گے اُس وقت وہ اپنے پکارنے والوں کے دشمن اور ان کی عبادت کے منکر ہوں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvii{اِن لوگوں کو جب ہماری صاف صاف آیات سنائی جاتی ہیں اور حق اِن کے سامنے آ جاتا ہے تو یہ کافر لوگ اُس کے متعلق کہتے ہیں کہ یہ تو کھلا جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxviii{کیا اُن کا کہنا یہ ہے کہ رسول نے اِسے خود گھڑ لیا ہے؟ ان سے کہو، ``اگر میں نے اِسے خود گھڑ لیا ہے تو تم مجھے خدا کی پکڑ سے کچھ بھی نہ بچا سکو گے، جو باتیں تم بناتے ہو اللہ ان کو خوب جانتا ہے، میرے اور تمہارے درمیان وہی گواہی دینے کے لیے کافی ہے، اور وہ بڑا درگزر کرنے والا اور رحیم ہے"\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxix{اِن سے کہو، ``میں کوئی نرالا رسول تو نہیں ہوں، میں نہیں جانتا کہ کل تمہارے ساتھ کیا ہونا ہے اور میرے ساتھ کیا، میں تو صرف اُس وحی کی پیروی کرتا ہوں جو میرے پاس بھیجی جاتی ہے اور میں ایک صاف صاف خبردار کر دینے والے کے سوا اور کچھ نہیں ہوں"\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxx{اے نبیؐ، ان سے کہو ``کبھی تم نے سوچا بھی کہ اگر یہ کلام اللہ ہی کی طرف سے ہوا اور تم نے اِس کا انکار کر دیا (تو تمہارا کیا انجام ہوگا)؟ اور اِس جیسے ایک کلام پر تو بنی اسرائیل کا ایک گواہ شہادت بھی دے چکا ہے وہ ایمان لے آیا اور تم اپنے گھمنڈ میں پڑے رہے ایسے ظالموں کو اللہ ہدایت نہیں دیا کرتا"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxi{جن لوگوں نے ماننے سے انکار کر دیا ہے وہ ایمان لانے والوں کے متعلق کہتے ہیں کہ اگر اس کتاب کو مان لینا کوئی اچھا کام ہوتا تو یہ لوگ اس معاملے میں ہم سے سبقت نہ لے جا سکتے تھے چونکہ اِنہوں نے اُس سے ہدایت نہ پائی اس لیے اب یہ ضرور کہیں گے کہ یہ تو پرانا جھوٹ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxii{حالانکہ اِس سے پہلے موسیٰؑ کی کتاب رہنما اور رحمت بن کر آ چکی ہے، اور یہ کتاب اُس کی تصدیق کرنے والی زبان عربی میں آئی ہے تاکہ ظالموں کو متنبہ کر دے اور نیک روش اختیار کرنے والوں کو بشارت دے دے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiii{یقیناً جن لوگوں نے کہہ دیا کہ اللہ ہی ہمارا رب ہے، پھر اُس پر جم گئے، اُن کے لیے نہ کوئی خوف ہے اور نہ وہ غمگین ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiv{ایسے سب لوگ جنت میں جانے والے ہیں جہاں وہ ہمیشہ رہیں گے اپنے اُن اعمال کے بدلے جو وہ دنیا میں کرتے رہے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxv{ہم نے انسان کو ہدایت کی کہ وہ اپنے والدین کے ساتھ نیک بر تاؤ کرے اُس کی ماں نے مشقت اٹھا کر اسے پیٹ میں رکھا اور مشقت اٹھا کر ہی اس کو جنا، اور اس کے حمل اور دودھ چھڑانے میں تیس مہینے لگ گئے یہاں تک کہ جب وہ اپنی پوری طاقت کو پہنچا اور چالیس سال کا ہو گیا تو اس نے کہا ``اے میرے رب، مجھے توفیق دے کہ میں تیری اُن نعمتوں کا شکر ادا کروں جو تو نے مجھے اور میرے والدین کو عطا فرمائیں، اور ایسا نیک عمل کروں جس سے تو راضی ہو، اور میری اولاد کو بھی نیک بنا کر مجھے سُکھ دے، میں تیرے حضور توبہ کرتا ہوں اور تابع فرمان (مسلم) بندوں میں سے ہوں"\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvi{اِس طرح کے لوگوں سے ہم اُن کے بہترین اعمال کو قبول کرتے ہیں اور ان کی برائیوں سے درگزر کر جاتے ہیں یہ جنتی لوگوں میں شامل ہوں گے اُس سچے وعدے کے مطابق جو ان سے کیا جاتا رہا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvii{اور جس شخص نے اپنے والدین سے کہا ``اُف، تنگ کر دیا تم نے، کیا تم مجھے یہ خوف دلاتے ہو کہ میں مرنے کے بعد پھر قبر سے نکالا جاؤں گا حالانکہ مجھ سے پہلے بہت سی نسلیں گزر چکی ہیں (اُن میں سے تو کوئی اٹھ کر نہ آیا)" ماں اور باپ اللہ کی دوہائی دے کر کہتے ہیں ``ارے بدنصیب، مان جا، اللہ کا وعدہ سچا ہے" مگر وہ کہتا ہے ``یہ سب اگلے وقتوں کی فرسودہ کہانیاں ہیں"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxviii{یہ وہ لوگ ہیں جن پر عذاب کا فیصلہ چسپاں ہو چکا ہے اِن سے پہلے جنوں اور انسانوں کے جو ٹولے (اِسی قماش کے) ہو گزرے ہیں اُنہی میں یہ بھی جا شامل ہوں گے بے شک یہ گھاٹے میں رہ جانے والے لوگ ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxix{دونوں گروہوں میں سے ہر ایک کے درجے ان کے اعمال کے لحاظ سے ہیں تاکہ اللہ ان کے کیے کا پورا پورا بدلہ ان کو دے ان پر ظلم ہرگز نہ کیا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxx{پھر جب یہ کافر آگ کے سامنے لا کھڑے کیے جائیں گے تو ان سے کہا جائے گا: ``تم اپنے حصے کی نعمتیں اپنی دنیا کی زندگی میں ختم کر چکے اور ان کا لطف تم نے اٹھا لیا، اب جو تکبر تم زمین میں کسی حق کے بغیر کرتے رہے اور جو نافرمانیاں تم نے کیں اُن کی پاداش میں آج تم کو ذلت کا عذاب دیا جائے گا"\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxi{ذرا اِنہیں عاد کے بھائی (ہودؑ) کا قصہ سناؤ جبکہ اُس نے احقاف میں اپنی قوم کو خبردار کیا تھا اور ایسے خبردار کرنے والے اُس سے پہلے بھی گزر چکے تھے اور اس کے بعد بھی آتے رہے کہ ``اللہ کے سوا کسی کی بندگی نہ کرو، مجھے تمہارے حق میں ایک بڑے ہولناک دن کے عذاب کا اندیشہ ہے"\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxii{انہوں نے کہا ``کیا تو اِس لیے آیا ہے کہ ہمیں بہکا کر ہمارے معبودوں سے برگشتہ کر دے؟ اچھا تو لے آ اپنا وہ عذاب جس سے تو ہمیں ڈراتا ہے اگر واقعی تو سچا ہے"\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiii{اُس نے کہا کہ ``اِس کا علم تو اللہ کو ہے، میں صرف وہ پیغام تمہیں پہنچا رہا ہوں جسے دے کر مجھے بھیجا گیا ہے مگر میں دیکھ رہا ہوں کہ تم لوگ جہالت برت رہے ہو"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiv{پھر جب انہوں نے اُس عذاب کو اپنی وادیوں کی طرف آتے دیکھا تو کہنے لگے ``یہ بادل ہے جو ہم کو سیراب کر دے گا" ``نہیں، بلکہ یہ وہی چیز ہے جس کے لیے تم جلدی مچا رہے تھے یہ ہوا کا طوفان ہے جس میں دردناک عذاب چلا آ رہا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxv{اپنے رب کے حکم سے ہر چیز کو تباہ کر ڈالے گا" آخرکار اُن کا حال یہ ہوا کہ اُن کے رہنے کی جگہوں کے سوا وہاں کچھ نظر نہ آتا تھا اِس طرح ہم مجرموں کو بدلہ دیا کرتے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvi{اُن کو ہم نے وہ کچھ دیا تھا جو تم لوگوں کو نہیں دیا ہے اُن کو ہم نے کان، آنکھیں اور دل، سب کچھ دے رکھے تھے، مگر نہ وہ کان اُن کے کسی کام آئے، نہ آنکھیں، نہ دل، کیونکہ وہ اللہ کی آیات کا انکار کرتے تھے، اور اُسی چیز کے پھیر میں وہ آ گئے جس کا وہ مذاق اڑاتے تھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvii{تمہارے گرد و پیش کے علاقوں میں بہت سی بستیوں کو ہم ہلاک کر چکے ہیں ہم نے اپنی آیات بھیج کر بار بار طرح طرح سے اُن کو سمجھایا، شاید کہ وہ باز آ جائیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxviii{پھر کیوں نہ اُن ہستیوں نے اُن کی مدد کی جنہیں اللہ کو چھوڑ کر انہوں نے تقرب الی اللہ کا ذریعہ سمجھتے ہوئے معبود بنا لیا تھا؟ بلکہ وہ تو ان سے کھوئے گئے، اور یہ تھا اُن کے جھوٹ اور اُن بناوٹی عقیدوں کا انجام جو انہوں نے گھڑ رکھے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxix{(اور وہ واقعہ بھی قابل ذکر ہے) جب ہم جنوں کے ایک گروہ کو تمہاری طرف لے آئے تھے تاکہ قرآن سنیں جب وہ اُس جگہ پہنچے (جہاں تم قرآن پڑھ رہے تھے) تو انہوں نے آپس میں کہا خاموش ہو جاؤ پھر جب وہ پڑھا جا چکا تو وہ خبردار کرنے والے بن کر اپنی قوم کی طرف پلٹے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdxl{انہوں نے جا کر کہا، ``اے ہماری قوم کے لوگو، ہم نے ایک کتاب سنی ہے جو موسیٰؑ کے بعد نازل کی گئی ہے، تصدیق کرنے والی ہے اپنے سے پہلے آئی ہوئی کتابوں کی، رہنمائی کرتی ہے حق اور راہ راست کی طرف\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdxli{اے ہماری قوم کے لوگو، اللہ کی طرف بلانے والے کی دعوت قبول کر لو اور اس پر ایمان لے آؤ، اللہ تمہارے گناہوں سے درگزر فرمائے گا اور تمہیں عذاب الیم سے بچا دے گا"\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlii{اور جو کوئی اللہ کے داعی کی بات نہ مانے وہ نہ زمین میں خود کوئی بل بوتا رکھتا ہے کہ اللہ کو زچ کر دے، اور نہ اس کے کوئی ایسے حامی و سرپرست ہیں کہ اللہ سے اس کو بچا لیں ایسے لوگ کھلی گمراہی میں پڑ ے ہوئے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliii{اور کیا اِن لوگوں کو یہ سجھائی نہیں دیتا کہ جس خدا نے یہ زمین اور آسمان پیدا کیے ہیں اور ان کو بناتے ہوئے جو نہ تھکا، وہ ضرور اس پر قادر ہے کہ مُردوں کو جلا اٹھائے؟ کیوں نہیں، یقیناً وہ ہر چیز کی قدرت رکھتا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliv{جس روز یہ کافر آگ کے سامنے لائے جائیں گے، اُس وقت اِن سے پوچھا جائے گا ``کیا یہ حق نہیں ہے؟" یہ کہیں گے ``ہاں، ہمارے رب کی قسم (یہ واقعی حق ہے)" اللہ فرمائے گا، ``اچھا تو اب عذاب کا مزا چکھو اپنے اُس انکار کی پاداش میں جو تم کرتے رہے تھے"\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlv{پس اے نبیؐ، صبر کرو جس طرح اولوالعزم رسولوں نے صبر کیا ہے، اور ان کے معاملہ میں جلدی نہ کرو جس روز یہ لوگ اُس چیز کو دیکھ لیں گے جس کا اِنہیں خوف دلایا جا رہا ہے تو اِنہیں یوں معلوم ہو گا کہ جیسے دنیا میں دن کی ایک گھڑی بھر سے زیادہ نہیں رہے تھے بات پہنچا دی گئی، اب کیا نافرمان لوگوں کے سوا اور کوئی ہلاک ہو گا؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvi{\basmalahur جن لوگوں نے کفر کیا اور اللہ کے راستے سے روکا، اللہ نے ان کے اعمال کو رائیگاں کر دیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvii{اور جو لوگ ایمان لائے اور جنہوں نے نیک عمل کیے اور اُس چیز کو مان لیا جو محمدؐ پر نازل ہوئی ہے اور ہے وہ سراسر حق اُن کے رب کی طرف سے اللہ نے ان کی برائیاں اُن سے دور کر دیں اور ان کا حال درست کر دیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlviii{یہ اس لیے کہ کفر کرنے والوں نے باطل کی پیروی کی اور ایمان لانے والوں نے اُس حق کی پیروی کی جو ان کے رب کی طرف سے آیا ہے اِس طرح اللہ لوگوں کو اُن کی ٹھیک ٹھیک حیثیت بتائے دیتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlix{پس جب اِن کافروں سے تمہاری مڈ بھیڑ ہو تو پہلا کام گردنیں مارنا ہے، یہاں تک کہ جب تم ان کو اچھی طرح کچل دو تب قیدیوں کو مضبوط باندھو، اس کے بعد (تمہیں اختیار ہے) احسان کرو یا فدیے کا معاملہ کر لو، تا آنکہ لڑائی اپنے ہتھیار ڈال دے یہ ہے تمہارے کرنے کا کام اللہ چاہتا تو خود ہی اُن سے نمٹ لیتا، مگر (یہ طریقہ اُس نے اس لیے اختیار کیا ہے) تاکہ تم لوگوں کو ایک دوسرے کے ذریعہ سے آزمائے اور جو لوگ اللہ کی راہ میں مارے جائیں گے اللہ ان کے اعمال کو ہرگز ضائع نہ کرے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdl{وہ ان کی رہنمائی فرمائے گا، ان کا حال درست کر دے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdli{اور ان کو اس جنت میں داخل کرے گا جس سے وہ ان کو واقف کرا چکا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdlii{اے لوگو جو ایمان لائے ہو، اگر تم اللہ کی مدد کرو گے تو وہ تمہاری مدد کرے گا اور تمہارے قدم مضبوط جما دے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdliii{رہے وہ لوگ جنہوں نے کفر کیا ہے، تو اُن کے لیے ہلاکت ہے اور اللہ نے ان کے اعمال کو بھٹکا دیا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdliv{کیونکہ انہوں نے اُس چیز کو ناپسند کیا جسے اللہ نے نازل کیا ہے، لہٰذا اللہ نے اُن کے اعمال ضائع کر دیے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdlv{کیا وہ زمین میں چلے پھرے نہ تھے کہ اُن لوگوں کا انجام دیکھتے جو ان سے پہلے گزر چکے ہیں؟ اللہ نے اُن کا سب کچھ اُن پر الٹ دیا، اور ایسے نتائج اِن کافروں کے لیے مقدر ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvi{یہ اس لیے کہ ایمان لانے والوں کا حامی و ناصر اللہ ہے اور کافروں کا حامی و ناصر کوئی نہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvii{ایمان لانے والوں اور نیک عمل کرنے والوں کو اللہ اُن جنتوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہیں، اور کفر کرنے والے بس دنیا کی چند روزہ زندگی کے مزے لوٹ رہے ہیں، جانوروں کی طرح کھا پی رہے ہیں، اور اُن کا آخری ٹھکانا جہنم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdlviii{اے نبیؐ، کتنی ہی بستیاں ایسی گزر چکی ہیں جو تمہاری اُس بستی سے بہت زیادہ زور آور تھیں جس نے تمہیں نکال دیا ہے اُنہیں ہم نے اِس طرح ہلاک کر دیا کہ کوئی ان کا بچانے والا نہ تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdlix{بھلا کہیں ایسا ہو سکتا ہے کہ جو اپنے رب کی طرف سے ایک صاف و صریح ہدایت پر ہو، وہ اُن لوگوں کی طرح ہو جائے جن کے لیے اُن کا برا عمل خوشنما بنا دیا گیا ہے اور وہ اپنی خواہشات کے پیرو بن گئے ہیں؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdlx{پرہیز گاروں کے لیے جس جنت کا وعدہ کیا گیا ہے اس کی شان تو یہ ہے کہ اس میں نہریں بہہ رہی ہوں گی نتھرے ہوئے پانی کی، نہریں بہہ رہی ہوں گی ایسے دودھ کی جس کے مزے میں ذرا فرق نہ آیا ہو گا، نہریں بہہ رہی ہوں گی ایسی شراب کی جو پینے والوں کے لیے لذیذ ہوگی، نہریں بہہ رہی ہوں گی صاف شفاف شہد کی اُس میں اُن کے لیے ہر طرح کے پھل ہوں گے اور اُن کے رب کی طرف سے بخشش (کیا وہ شخص جس کے حصہ میں یہ جنت آنے والی ہے) اُن لوگوں کی طرح ہو سکتا ہے جو جہنم میں ہمیشہ رہیں گے اور جنہیں ایسا گرم پانی پلایا جائے گا جو ان کی آنتیں تک کاٹ دے گا؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxi{اِن میں سے کچھ لوگ ایسے ہیں جو کان لگا کر تمہاری بات سنتے ہیں اور پھر جب تمہارے پاس سے نکلتے ہیں تو اُن لوگوں سے جنہیں علم کی نعمت بخشی گئی ہے پوچھتے ہیں کہ ابھی ابھی اِنہوں نے کیا کہا تھا؟ یہ وہ لوگ ہیں جن کے دلوں پر اللہ نے ٹھپہ لگا دیا ہے اور یہ اپنی خواہشات کے پیرو بنے ہوئے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxii{رہے وہ لوگ جنہوں نے ہدایت پائی ہے، اللہ اُن کو اور زیادہ ہدایت دیتا ہے اور انہیں اُن کے حصے کا تقویٰ عطا فرماتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiii{اب کیا یہ لوگ بس قیامت ہی کے منتظر ہیں کہ وہ اچانک اِن پر آ جائے؟ اُس کی علامات تو آ چکی ہیں جب وہ خود آ جائے گی تو اِن کے لیے نصیحت قبول کرنے کا کونسا موقع باقی رہ جائے گا؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiv{پس اے نبیؐ، خوب جان لو کہ اللہ کے سوا کوئی عبادت کا مستحق نہیں ہے، اور معافی مانگو اپنے قصور کے لیے بھی اور مومن مردوں اور عورتوں کے لیے بھی اللہ تمہاری سرگرمیوں کو بھی جانتا ہے اور تمہارے ٹھکانے سے بھی واقف ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxv{جو لوگ ایمان لائے ہیں وہ کہہ رہے تھے کہ کوئی سورت کیوں نہیں نازل کی جاتی (جس میں جنگ کا حکم دیا جائے) مگر جب ایک محکم سورت نازل کر دی گئی جس میں جنگ کا ذکر تھا تو تم نے دیکھا کہ جن کے دلوں میں بیماری تھی وہ تمہاری طرف اس طرح دیکھ رہے ہیں جیسے کسی پر موت چھا گئی ہو افسوس اُن کے حال پر\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvi{(اُن کی زبان پر ہے) اطاعت کا اقرار اور اچھی اچھی باتیں مگر جب قطعی حکم دے دیا گیا اُس وقت وہ اللہ سے اپنے عہد میں سچے نکلتے تو انہی کے لئے اچھا تھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvii{اب کیا تم لوگوں سے اِس کے سوا کچھ اور توقع کی جا سکتی ہے کہ اگر تم الٹے منہ پھر گئے تو زمین میں پھر فساد برپا کرو گے اور آپس میں ایک دوسرے کے گلے کاٹو گے؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxviii{یہ لوگ ہیں جن پر اللہ نے لعنت کی اور ان کو اندھا اور بہرا بنا دیا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxix{کیا ان لوگوں نے قرآن پر غور نہیں کیا، یا دلوں پر اُن کے قفل چڑھے ہوئے ہیں؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxx{حقیقت یہ ہے کہ جو لوگ ہدایت واضح ہو جانے کے بعد اُس سے پھر گئے اُن کے لیے شیطان نے اِس روش کو سہل بنا دیا ہے اور جھوٹی توقعات کا سلسلہ اُن کے لیے دراز کر رکھا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxi{اِسی لیے انہوں نے اللہ کے نازل کردہ دین کو ناپسند کرنے والوں سے کہہ دیا کہ بعض معاملات میں ہم تمہاری مانیں گے اللہ اُن کی یہ خفیہ باتیں خوب جانتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxii{پھر اس وقت کیا حال ہوگا جب فرشتے ان کی روحیں قبض کریں گے اور اِن کے منہ اور پیٹھوں پر مارتے ہوئے انہیں لے جائیں گے؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiii{یہ اسی لیے تو ہوگا کہ انہوں نے اُس طریقے کی پیروی کی جو اللہ کو ناراض کرنے والا ہے اور اُس کی رضا کا راستہ اختیار کرنا پسند نہ کیا اِسی بنا پر اُس نے ان کے سب اعمال ضائع کر دیے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiv{کیا وہ لوگ جن کے دلوں میں بیماری ہے یہ سمجھے بیٹھے ہیں کہ اللہ ان کے دلوں کے کھوٹ ظاہر نہیں کرے گا؟\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxv{ہم چاہیں تو انہیں تم کو آنکھوں سے دکھا دیں اور اُن کے چہروں سے تم ان کو پہچان لو مگر ان کے انداز کلام سے تو تم ان کو جان ہی لو گے اللہ تم سب کے اعمال سے خوب واقف ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvi{ہم ضرور تم لوگوں کو آزمائش میں ڈالیں گے تاکہ تمہارے حالات کی جانچ کریں اور دیکھ لیں کہ تم میں مجاہد اور ثابت قدم کون ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvii{جن لوگوں نے کفر کیا اور اللہ کی راہ سے روکا اور رسول سے جھگڑا کیا جبکہ ان پر راہ راست واضح ہو چکی تھی، در حقیقت وہ اللہ کا کوئی نقصان بھی نہیں کر سکتے، بلکہ اللہ ہی ان کا سب کیا کرایا غارت کر دے گا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxviii{اے لوگو جو ایمان لائے ہو، تم اللہ کی اطاعت کرو اور رسول کی اطاعت کرو اور اپنے اعمال کو برباد نہ کر لو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxix{کفر کرنے والوں اور راہ خدا سے روکنے والوں اور مرتے دم تک کفر پر جمے رہنے والوں کو تو اللہ ہرگز معاف نہ کرے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxx{پس تم بودے نہ بنو اور صلح کی درخواست نہ کرو تم ہی غالب رہنے والے ہو اللہ تمہارے ساتھ ہے اور تمہارے اعمال کو وہ ہرگز ضائع نہ کرے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxi{یہ دنیا کی زندگی تو ایک کھیل اور تماشا ہے اگر تم ایمان رکھو اور تقویٰ کی روش پر چلتے رہو تو اللہ تمہارے اجر تم کو دے گا اور وہ تمہارے مال تم سے نہ مانگے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxii{اگر کہیں وہ تمہارے مال تم سے مانگ لے اور سب کے سب تم سے طلب کر لے تو تم بخل کرو گے اور وہ تمہارے کھوٹ ابھار لائے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiii{دیکھو، تم لوگوں کو دعوت دی جا رہی ہے کہ اللہ کی راہ میں مال خرچ کرو اِس پر تم میں سے کچھ لوگ ہیں جو بخل کر رہے ہیں، حالانکہ جو بخل کرتا ہے وہ در حقیقت اپنے آپ ہی سے بخل کر رہا ہے اللہ تو غنی ہے، تم ہی اس کے محتاج ہو اگر تم منہ موڑو گے تو اللہ تمہاری جگہ کسی اور قوم کو لے آئے گا اور وہ تم جیسے نہ ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiv{\basmalahur اے نبیؐ، ہم نے تم کو کھلی فتح عطا کر دی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxv{تاکہ اللہ تمہاری اگلی پچھلی ہر کوتاہی سے درگزر فرمائے اور تم پر اپنی نعمت کی تکمیل کر دے اور تمہیں سیدھا راستہ دکھائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvi{اور تم کو زبردست نصرت بخشے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvii{وہی ہے جس نے مومنوں کے دلوں میں سکینت نازل فرمائی تاکہ اپنے ایمان کے ساتھ وہ ایک ایمان اور بڑھا لیں زمین اور آسمانوں کے سب لشکر اللہ کے قبضہ قدرت میں ہیں اور وہ علیم و حکیم ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxviii{(اُس نے یہ کام اِس لیے کیا ہے) تاکہ مومن مردوں اور عورتوں کو ہمیشہ رہنے کے لیے ایسی جنتوں میں داخل فرمائے جن کے نیچے نہریں بہہ رہی ہوں گی اور اُن کی برائیاں اُن سے دور کر دے اللہ کے نزدیک یہ بڑی کامیابی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxix{اور اُن منافق مردوں اور عورتوں اور مشرک مردوں اور عورتوں کو سزا دے جو اللہ کے متعلق برے گمان رکھتے ہیں برائی کے پھیر میں وہ خود ہی آ گئے، اللہ کا غضب ان پر ہوا اور اس نے ان پر لعنت کی اور ان کے لیے جہنم مہیا کر دی جو بہت ہی برا ٹھکانا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxc{زمین اور آسمانوں کے لشکر اللہ ہی کے قبضہ قدرت میں ہیں اور وہ زبردست اور حکیم ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxci{اے نبیؐ، ہم نے تم کو شہادت دینے والا، بشارت دینے والا اور خبردار کر دینے والا بنا کر بھیجا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcii{تاکہ اے لوگو، تم اللہ اور اس کے رسول پر ایمان لاؤ اور اُس کا ساتھ دو، اس کی تعظیم و توقیر کرو اور صبح و شام اس کی تسبیح کرتے رہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciii{اے نبیؐ، جو لوگ تم سے بیعت کر رہے تھے وہ دراصل اللہ سے بیعت کر رہے تھے ان کے ہاتھ پر اللہ کا ہاتھ تھا اب جو اس عہد کو توڑے گا اُس کی عہد شکنی کا وبال اس کی اپنی ہی ذات پر ہوگا، اور جو اُس عہد کو وفا کرے گا جو اس نے اللہ سے کیا ہے، اللہ عنقریب اس کو بڑا اجر عطا فرمائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciv{اے نبیؐ، بدوی عربوں میں سے جو لوگ پیچھے چھوڑ دیے گئے تھے اب وہ آ کر ضرور تم سے کہیں گے کہ ``ہمیں اپنے اموال اور بال بچوں کی فکر نے مشغول کر رکھا تھا، آپ ہمارے لیے مغفرت کی دعا فرمائیں" یہ لوگ اپنی زبانوں سے وہ باتیں کہتے ہیں جو ان کے دلوں میں نہیں ہوتیں ان سے کہنا ``اچھا، یہی بات ہے تو کون تمہارے معاملہ میں اللہ کے فیصلے کو روک دینے کا کچھ بھی اختیار رکھتا ہے اگر وہ تمہیں کوئی نقصان پہنچانا چاہے یا نفع بخشنا چاہے؟ تمہارے اعمال سے تو اللہ ہی باخبر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcv{(مگر اصل بات وہ نہیں ہے جو تم کہہ رہے ہو) بلکہ تم نے یوں سمجھا کہ رسول اور مومنین اپنے گھر والوں میں ہرگز پلٹ کر نہ آ سکیں گے اور یہ خیال تمہارے دلوں کو بہت بھلا لگا اور تم نے بہت برے گمان کیے اور تم سخت بد باطن لوگ ہو"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvi{اللہ اور اس کے رسول پر جو لوگ ایمان نہ رکھتے ہوں ایسے کافروں کے لیے ہم نے بھڑکتی ہوئی آگ مہیا کر رکھی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvii{آسمانوں اور زمین کی بادشاہی کا مالک اللہ ہی ہے جسے چاہے معاف کرے اور جسے چاہے سزا دے، اور وہ غفور و رحیم ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcviii{جب تم مال غنیمت حاصل کرنے کے لیے جانے لگو گے تو یہ پیچھے چھوڑے جانے والے لوگ تم سے ضرور کہیں گے کہ ہمیں بھی اپنے ساتھ چلنے دو یہ چاہتے ہیں کہ اللہ کے فرمان کو بدل دیں اِن سے صاف کہہ دینا کہ ``تم ہرگز ہمارے ساتھ نہیں چل سکتے، اللہ پہلے ہی یہ فرما چکا ہے" یہ کہیں گے کہ ``نہیں، بلکہ تم لوگ ہم سے حسد کر رہے ہو" (حالانکہ بات حسد کی نہیں ہے) بلکہ یہ لوگ صحیح بات کو کم ہی سمجھتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcix{اِن پیچھے چھوڑے جانے والے بدوی عربوں سے کہنا کہ ``عنقریب تمہیں ایسے لوگوں سے لڑنے کے لیے بلایا جائے گا جو بڑے زور آور ہیں تم کو ان سے جنگ کرنی ہوگی یا وہ مطیع ہو جائیں گے اُس وقت اگر تم نے حکم جہاد کی اطاعت کی تو اللہ تمہیں اچھا اجر دے گا، اور اگر تم پھر اُسی طرح منہ موڑ گئے جس طرح پہلے موڑ چکے ہو تو اللہ تم کو دردناک سزا دے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdc{اگر اندھا اور لنگڑا اور مریض جہاد کے لیے نہ آئے تو کوئی حرج نہیں جو کوئی اللہ اور اس کے رسول کی اطاعت کرے گا اللہ اسے اُن جنتوں میں داخل کرے گا جن کے نیچے نہریں بہہ رہی ہوں گی، اور جو منہ پھیرے گا اسے وہ دردناک عذاب دے گا"\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdci{اللہ مومنوں سے خوش ہو گیا جب وہ درخت کے نیچے تم سے بیعت کر رہے تھے ان کے دلوں کا حال اُس کو معلوم تھا، اس لیے اس نے ان پر سکینت نازل فرمائی، ان کو انعام میں قریبی فتح بخشی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcii{اور بہت سا مال غنیمت انہیں عطا کر دیا جسے وہ (عنقریب) حاصل کریں گے اللہ زبردست اور حکیم ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdciii{اللہ تم سے بکثرت اموال غنیمت کا وعدہ کرتا ہے جنہیں تم حاصل کرو گے فوری طور پر تو یہ فتح اس نے تمہیں عطا کر دی اور لوگوں کے ہاتھ تمہارے خلاف اٹھنے سے روک دیے، تاکہ یہ مومنوں کے لیے ایک نشانی بن جائے اور اللہ سیدھے راستے کی طرف تمہیں ہدایت بخشے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdciv{اِس کے علاوہ دوسرے اور غنیمتوں کا بھی وہ تم سے وعدہ کرتا ہے جن پر تم ابھی تک قادر نہیں ہوئے ہو اور اللہ نے ان کو گھیر رکھا ہے، اللہ ہر چیز پر قادر ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcv{یہ کافر لوگ اگر اِس وقت تم سے لڑ گئے ہوتے تو یقیناً پیٹھ پھیر جاتے اور کوئی حامی و مددگار نہ پاتے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvi{یہ اللہ کی سنت ہے جو پہلے سے چلی آ رہی ہے اور تم اللہ کی سنت میں کوئی تبدیلی نہ پاؤ گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvii{وہی ہے جس نے مکہ کی وادی میں اُن کے ہاتھ تم سے اور تمہارے ہاتھ اُن سے روک دیے، حالانکہ وہ اُن پر تمہیں غلبہ عطا کر چکا تھا اور جو کچھ تم کر رہے تھے اللہ اسے دیکھ رہا تھا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcviii{وہی لوگ تو ہیں جنہوں نے کفر کیا اور تم کو مسجد حرام سے روکا اور ہدی کے اونٹوں کو اُن کی قربانی کی جگہ نہ پہنچنے دیا اگر (مکہ میں) ایسے مومن مرد و عورت موجود نہ ہوتے جنہیں تم نہیں جانتے، اور یہ خطرہ نہ ہوتا کہ نادانستگی میں تم انہیں پامال کر دو گے اور اس سے تم پر حرف آئے گا (تو جنگ نہ روکی جاتی روکی وہ اس لیے گئی) تاکہ اللہ اپنی رحمت میں جس کو چاہے داخل کر لے وہ مومن الگ ہو گئے ہوتے تو (اہل مکہ میں سے) جو کافر تھے ان کو ہم ضرور سخت سزا دیتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcix{(یہی وجہ ہے کہ) جب ان کافروں نے اپنے دلوں میں جاہلانہ حمیت بٹھا لی تو اللہ نے اپنے رسول اور مومنوں پر سکینت نازل فرمائی اور مومنوں کو تقویٰ کی بات کا پابند رکھا کہ وہی اُس کے زیادہ حق دار اور اُس کے اہل تھے اللہ ہر چیز کا علم رکھتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcx{فی الواقع اللہ نے اپنے رسول کو سچا خواب دکھا یا تھا جو ٹھیک ٹھیک حق کے مطابق تھا انشاءاللہ تم ضرور مسجد حرام میں پورے امن کے ساتھ داخل ہو گے، اپنے سر منڈواؤ گے اور بال ترشواؤ گے، اور تمہیں کوئی خوف نہ ہو گا وہ اُس بات کو جانتا تھا جسے تم نہ جانتے تھے اس لیے وہ خواب پورا ہونے سے پہلے اُس نے یہ قریبی فتح تم کو عطا فرما دی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxi{وہ اللہ ہی ہے جس نے اپنے رسول کو ہدایت اور دین حق کے ساتھ بھیجا ہے تاکہ اُس کو پوری جنس دین پر غالب کر دے اور اِس حقیقت پر اللہ کی گواہی کافی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxii{محمدؐ اللہ کے رسول ہیں، اور جو لوگ ان کے ساتھ ہیں وہ کفار پر سخت اور آپس میں رحیم ہیں تم جب دیکھو گے اُنہیں رکوع و سجود، اور اللہ کے فضل اور اس کی خوشنودی کی طلب میں مشغول پاؤ گے سجود کے اثرات ان کے چہروں پر موجود ہیں جن سے وہ الگ پہچانے جاتے ہیں یہ ہے ان کی صفت توراۃ میں اور انجیل میں اُن کی مثال یوں دی گئی ہے کہ گویا ایک کھیتی ہے جس نے پہلے کونپل نکالی، پھر اس کو تقویت دی، پھر وہ گدرائی، پھر اپنے تنے پر کھڑی ہو گئی کاشت کرنے والوں کو وہ خوش کرتی ہے تاکہ کفار ان کے پھلنے پھولنے پر جلیں اِس گروہ کے لوگ جو ایمان لائے ہیں اور جنہوں نے نیک عمل کیے ہیں اللہ نے ان سے مغفرت اور بڑے اجر کا وعدہ فرمایا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiii{\basmalahur اے لوگو جو ایمان لائے ہو، اللہ اور اس کے رسول کے آگے پیش قدمی نہ کرو اور اللہ سے ڈرو، اللہ سب کچھ سننے اور جاننے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiv{اے لوگو جو ایمان لائے ہو، اپنی آواز نبیؐ کی آواز سے بلند نہ کرو، اور نہ نبیؐ کے ساتھ اونچی آواز سے بات کیا کرو جس طرح تم آپس میں ایک دوسرے سے کرتے ہو، کہیں ایسا نہ ہو کہ تمہارا کیا کرایا سب غارت ہو جائے اور تمہیں خبر بھی نہ ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxv{جو لوگ رسول خدا کے حضور بات کرتے ہوئے اپنی آواز پست رکھتے ہیں وہ در حقیقت وہی لوگ ہیں جن کے دلوں کو اللہ نے تقویٰ کے لیے جانچ لیا ہے، اُن کے لیے مغفرت ہے اور اجر عظیم\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvi{اے نبیؐ، جو لوگ تمہیں حجروں کے باہر سے پکارتے ہیں ان میں سے اکثر بے عقل ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvii{اگر وہ تمہارے برآمد ہونے تک صبر کرتے تو انہی کے لیے بہتر تھا، اللہ درگزر کرنے والا اور رحیم ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxviii{اے لوگو جو ایمان لائے ہو، اگر کوئی فاسق تمہارے پاس کوئی خبر لے کر آئے تو تحقیق کر لیا کرو، کہیں ایسا نہ ہو کہ تم کسی گروہ کو نادانستہ نقصان پہنچا بیٹھو اور پھر اپنے کیے پر پشیمان ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxix{خوب جان رکھو کہ تمہارے درمیان اللہ کا رسول موجود ہے اگر وہ بہت سے معاملات میں تمہاری بات مان لیا کرے تو تم خود ہی مشکلات میں مبتلا ہو جاؤ مگر اللہ نے تم کو ایمان کی محبت دی اور اس کو تمہارے لیے دل پسند بنا دیا، اور کفر و فسق اور نافرمانی سے تم کو متنفر کر دیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxx{ایسے ہی لوگ اللہ کے فضل و احسان سے راست رو ہیں اور اللہ علیم و حکیم ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxi{اور اگر اہل ایمان میں سے دو گروہ آپس میں لڑ جائیں تو ان کے درمیان صلح کراؤ پھر اگر ان میں سے ایک گروہ دوسرے گروہ سے زیادتی کرے تو زیادتی کرنے والے سے لڑو یہاں تک کہ وہ اللہ کے حکم کی طرف پلٹ آئے پھر اگر وہ پلٹ آئے تو ان کے درمیان عدل کے ساتھ صلح کرا دو اور انصاف کرو کہ اللہ انصاف کرنے والوں کو پسند کرتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxii{مومن تو ایک دوسرے کے بھائی ہیں، لہٰذا اپنے بھائیوں کے درمیان تعلقات کو درست کرو اور اللہ سے ڈرو، امید ہے کہ تم پر رحم کیا جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiii{اے لوگو جو ایمان لائے ہو، نہ مرد دوسرے مردوں کا مذاق اڑائیں، ہو سکتا ہے کہ وہ ان سے بہتر ہوں، اور نہ عورتیں دوسری عورتوں کا مذاق اڑائیں، ہو سکتا ہے کہ وہ ان سے بہتر ہوں آپس میں ایک دوسرے پر طعن نہ کرو اور نہ ایک دوسرے کو برے القاب سے یاد کرو ایمان لانے کے بعد فسق میں نام پیدا کرنا بہت بری بات ہے جو لوگ اس روش سے باز نہ آئیں وہی ظالم ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiv{اے لوگو جو ایمان لائے ہو، بہت گمان کرنے سے پرہیز کرو کہ بعض گمان گناہ ہوتے ہیں تجسس نہ کرو اور تم میں سے کوئی کسی کی غیبت نہ کرے کیا تمہارے اندر کوئی ایسا ہے جو اپنے مرے ہوئے بھائی کا گوشت کھانا پسند کرے گا؟ دیکھو، تم خود اس سے گھن کھاتے ہو اللہ سے ڈرو، اللہ بڑا توبہ قبول کرنے والا اور رحیم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxv{لوگو، ہم نے تم کو ایک مرد اور ایک عورت سے پیدا کیا اور پھر تمہاری قومیں اور برادریاں بنا دیں تاکہ تم ایک دوسرے کو پہچانو در حقیقت اللہ کے نزدیک تم میں سب سے زیادہ عزت والا وہ ہے جو تمہارے اندر سب سے زیادہ پرہیز گار ہے یقیناً اللہ سب کچھ جاننے والا اور باخبر ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvi{یہ بدوی کہتے ہیں کہ ``ہم ایمان لائے" اِن سے کہو، تم ایمان نہیں لائے، بلکہ یوں کہو کہ ``ہم مطیع ہو گئے" ایمان ابھی تمہارے دلوں میں داخل نہیں ہوا ہے اگر تم اللہ اور اس کے رسول کی فرماں برداری اختیار کر لو تو وہ تمہارے اعمال کے اجر میں کوئی کمی نہ کرے گا، یقیناً اللہ بڑا در گزر کرنے والا اور رحیم ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvii{حقیقت میں تو مومن وہ ہیں جو اللہ اور اُس کے رسول پر ایمان لائے پھر انہوں نے کوئی شک نہ کیا اور اپنی جانوں اور مالوں سے اللہ کی راہ میں جہاد کیا وہی سچے لوگ ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxviii{اے نبیؐ، اِن (مدعیان ایمان) سے کہو، کیا تم اللہ کو اپنے دین کی اطلاع دے رہے ہو؟ حالانکہ اللہ زمین اور آسمانوں کی ہر چیز کو جانتا ہے اور وہ ہر شے کا علم رکھتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxix{یہ لوگ تم پر احسان جتاتے ہیں کہ اِنہوں نے اسلام قبول کر لیا اِن سے کہو اپنے اسلام کا احسان مجھ پر نہ رکھو، بلکہ اللہ تم پر اپنا احسان رکھتا ہے کہ اس نے تمہیں ایمان کی ہدایت دی اگر تم واقعی اپنے دعوائے ایمان میں سچے ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxx{اللہ زمین اور آسمانوں کی ہر پوشیدہ چیز کا علم رکھتا ہے اور جو کچھ تم کرتے ہو وہ سب اس کی نگاہ میں ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxi{\basmalahur ق، قسم ہے قرآن مجید کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxii{بلکہ اِن لوگوں کو تعجب اس بات پر ہوا کہ ایک خبردار کرنے والا خود اِنہی میں سے اِن کے پاس آگیا پھر منکرین کہنے لگے ``یہ تو عجیب بات ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiii{کیا جب ہم مر جائیں گے اور خاک ہو جائیں گے (تو دوبارہ اٹھائے جائیں گے)؟ یہ واپسی تو عقل سے بعید ہے"\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiv{زمین ان کے جسم میں سے جو کچھ کھاتی ہے وہ سب ہمارے علم میں ہے اور ہمارے پاس ایک کتاب ہے جس میں سب کچھ محفوظ ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxv{بلکہ اِن لوگوں نے تو جس وقت حق اِن کے پاس آیا اُسی وقت اُسے صاف جھٹلا دیا اِسی وجہ سے اب یہ الجھن میں پڑے ہوئے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvi{اچھا، تو کیا اِنہوں نے کبھی اپنے اوپر آسمان کی طرف نہیں دیکھا؟ کس طرح ہم نے اسے بنایا اور آراستہ کیا، اور اس میں کہیں کوئی رخنہ نہیں ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvii{اور زمین کو ہم نے بچھایا اور اس میں پہاڑ جمائے اور اُس کے اندر ہر طرح کی خوش منظر نباتات اگا دیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxviii{یہ ساری چیزیں آنکھیں کھولنے والی اور سبق دینے والی ہیں ہر اُس بندے کے لیے جو (حق کی طرف) رجوع کرنے والا ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxix{اور آسمان سے ہم نے برکت والا پانی نازل کیا، پھر اس سے باغ اور فصل کے غلے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxl{اور بلند و بالا کھجور کے درخت پیدا کر دیے جن پر پھلوں سے لدے ہوئے خوشے تہ بر تہ لگتے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxli{یہ انتظام ہے بندوں کو رزق دینے کا اِس پانی سے ہم ایک مُردہ زمین کو زندگی بخش دیتے ہیں (مرے ہوئے انسانوں کا زمین سے) نکلنا بھی اِسی طرح ہو گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlii{اِن سے پہلے نوحؑ کی قوم، اور اصحاب الرس، اور ثمود\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliii{اور عاد، اور فرعون، اور لوطؑ کے بھائی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliv{اور ایکہ والے، اور تبع کی قوم کے لوگ بھی جھٹلا چکے ہیں ہر ایک نے رسولوں کو جھٹلایا، اور آخر کار میری وعید اُن پر چسپاں ہو گئی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlv{کیا پہلی بار کی تخلیق سے ہم عاجز تھے؟ مگر ایک نئی تخلیق کی طرف سے یہ لوگ شک میں پڑے ہوئے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvi{ہم نے انسان کو پیدا کیا ہے اور اس کے دل میں ابھرنے والے وسوسوں تک کو ہم جانتے ہیں ہم اس کی رگ گردن سے بھی زیادہ اُس سے قریب ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvii{(اور ہمارے اس براہ راست علم کے علاوہ) دو کاتب اس کے دائیں اور بائیں بیٹھے ہر چیز ثبت کر رہے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlviii{کوئی لفظ اس کی زبان سے نہیں نکلتا جسے محفوظ کرنے کے لیے ایک حاضر باش نگراں موجود نہ ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlix{پھر دیکھو، وہ موت کی جاں کنی حق لے کر آ پہنچی، یہ وہی چیز ہے جس سے تو بھاگتا تھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcl{اور پھر صور پھونکا گیا، یہ ہے وہ دن جس کا تجھے خوف دلایا جاتا تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcli{ہر شخص اِس حال میں آ گیا کہ اُس کے ساتھ ایک ہانک کر لانے والا ہے اور ایک گواہی دینے والا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdclii{اِس چیز کی طرف سے تو غفلت میں تھا، ہم نے وہ پردہ ہٹا دیا جو تیرے آگے پڑا ہوا تھا اور آج تیری نگاہ خوب تیز ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliii{اُس کے ساتھی نے عرض کیا یہ جو میری سپردگی میں تھا حاضر ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliv{حکم دیا گیا ``پھینک دو جہنم میں ہر گٹے کافر کو جو حق سے عناد رکھتا تھا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdclv{خیر کو روکنے والا اور حد سے تجاوز کرنے والا تھا، شک میں پڑا ہوا تھا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvi{اور اللہ کے ساتھ کسی دوسرے کو خدا بنائے بیٹھا تھا ڈال دو اُسے سخت عذاب میں"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvii{اُس کے ساتھی نے عرض کیا ``خداوندا، میں نے اِس کو سرکش نہیں بنایا بلکہ یہ خود ہی پرلے درجے کی گمراہی میں پڑا ہوا تھا"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdclviii{جواب میں ارشاد ہوا ``میرے حضور جھگڑا نہ کرو، میں تم کو پہلے ہی انجام بد سے خبردار کر چکا تھا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdclix{میرے ہاں بات پلٹی نہیں جاتی اور میں اپنے بندوں پر ظلم توڑنے والا نہیں ہوں"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdclx{وہ دن جبکہ ہم جہنم سے پوچھیں گے کیا تو بھر گئی؟ اور وہ کہے گی کیا اور کچھ ہے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxi{اور جنت متقین کے قریب لے آئی جائے گی، کچھ بھی دور نہ ہوگی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxii{ارشاد ہوگا ``یہ ہے وہ چیز جس کا تم سے وعدہ کیا جاتا تھا، ہر اُس شخص کے لیے جو بہت رجوع کرنے والا اور بڑی نگہداشت کرنے والا تھا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiii{جو بے دیکھے رحمٰن سے ڈرتا تھا، اور جو دل گرویدہ لیے ہوئے آیا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiv{داخل ہو جاؤ جنت میں سلامتی کے ساتھ" وہ دن حیات ابدی کا دن ہوگا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxv{وہاں ان کے لیے وہ سب کچھ ہوگا جو وہ چاہیں گے، اور ہمارے پاس اس سے زیادہ بھی بہت کچھ ان کے لیے ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvi{ہم ان سے پہلے بہت سی قوموں کو ہلاک کر چکے ہیں جو ان سے بہت زیادہ طاقتور تھیں اور دنیا کے ملکوں کو انہوں نے چھان مارا تھا پھر کیا وہ کوئی جائے پناہ پا سکے؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvii{اِس تاریخ میں عبرت کا سبق ہے ہر اس شخص کے لیے جو دل رکھتا ہو، یا جو توجہ سے بات کو سنے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxviii{ہم نے زمین اور آسمانوں کو اور اُن کے درمیان کی ساری چیزوں کو چھ دنوں میں پیدا کر دیا اور ہمیں کوئی تکان لاحق نہ ہوئی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxix{پس اے نبیؐ، جو باتیں یہ لوگ بناتے ہیں ان پر صبر کرو، اور اپنے رب کی حمد کے ساتھ اس کی تسبیح کرتے رہو، طلوع آفتاب اور غروب آفتاب سے پہلے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxx{اور رات کے وقت پھر اُس کی تسبیح کرو اور سجدہ ریزیوں سے فارغ ہونے کے بعد بھی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxi{اور سنو، جس دن منادی کرنے والا (ہر شخص کے) قریب ہی سے پکارے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxii{جس دن سب لوگ آوازۂ حشر کو ٹھیک ٹھیک سن رہے ہوں گے، وہ زمین سے مُردوں کے نکلنے کا دن ہو گا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiii{ہم ہی زندگی بخشتے ہیں اور ہم ہی موت دیتے ہیں، اور ہماری طرف ہی اُس دن سب کو پلٹنا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiv{جب زمین پھٹے گی اور لوگ اس کے اندر سے نکل کر تیز تیز بھاگے جا رہے ہوں گے یہ حشر ہمارے لیے بہت آسان ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxv{اے نبیؐ، جو باتیں یہ لوگ بنا رہے ہیں انہیں ہم خوب جانتے ہیں، اور تمہارا کام ان سے جبراً بات منوانا نہیں ہے بس تم اِس قرآن کے ذریعہ سے ہر اُس شخص کو نصیحت کر دو جو میری تنبیہ سے ڈرے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvi{\basmalahur قسم ہے اُن ہواؤں کی جو گرد اڑانے والی ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvii{پھر پانی سے لدے ہوئے بادل اٹھانے والی ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxviii{پھر سبک رفتاری کے ساتھ چلنے والی ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxix{پھر ایک بڑے کام (بارش) کی تقسیم کرنے والی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxx{حق یہ ہے کہ جس چیز کا تمہیں خوف دلایا جا رہا ہے وہ سچی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxi{اور جزائے اعمال ضرور پیش آنی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxii{قسم ہے متفرق شکلوں والے آسمان کی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiii{(آخرت کے بارے میں) تمہاری بات ایک دوسرے سے مختلف ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiv{اُس سے وہی برگشتہ ہوتا ہے جو حق سے پھرا ہوا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxv{مارے گئے قیاس و گمان سے حکم لگانے والے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvi{جو جہالت میں غرق اور غفلت میں مدہوش ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvii{پوچھتے ہیں آخر وہ روز جزاء کب آئے گا؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxviii{وہ اُس روز آئے گا جب یہ لوگ آگ پر تپائے جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxix{(اِن سے کہا جائے گا) اب چکھو مزا اپنے فتنے کا یہ وہی چیز ہے جس کے لیے تم جلدی مچا رہے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxc{البتہ متقی لوگ اُس روز باغوں اور چشموں میں ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxci{جو کچھ اُن کا رب انہیں دے گا اسے خوشی خوشی لے رہے ہوں گے وہ اُس دن کے آنے سے پہلے نیکو کار تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcii{راتوں کو کم ہی سوتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciii{پھر وہی رات کے پچھلے پہروں میں معافی مانگتے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciv{اور اُن کے مالوں میں حق تھا سائل اور محروم کے لیے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcv{زمین میں بہت سی نشانیاں ہیں یقین لانے والوں کے لیے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvi{اور خود تمہارے اپنے وجود میں ہیں کیا تم کو سوجھتا نہیں؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvii{آسمان ہی میں ہے تمہارا رزق بھی اور وہ چیز بھی جس کا تم سے وعدہ کیا جا رہا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcviii{پس قسم ہے آسمان اور زمین کے مالک کی، یہ بات حق ہے، ایسی ہی یقینی جیسے تم بول رہے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcix{اے نبیؐ، ابراہیمؑ کے معزز مہمانوں کی حکایت بھی تمہیں پہنچی ہے؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcc{جب وہ اُس کے ہاں آئے تو کہا آپ کو سلام ہے اُس نے کہا ``آپ لوگوں کو بھی سلام ہے کچھ نا آشنا سے لوگ ہیں"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcci{پھر وہ چپکے سے اپنے گھر والوں کے پاس گیا، اور ایک موٹا تازہ بچھڑا لا کر\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccii{مہمانوں کے آگے پیش کیا اُس نے کہا آپ حضرات کھاتے نہیں؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciii{پھر وہ اپنے دل میں ان سے ڈرا انہوں نے کہا ڈریے نہیں، اور اُسے ایک ذی علم لڑکے کی پیدائش کا مژدہ سنایا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciv{یہ سن کر اُس کی بیوی چیختی ہوئی آگے بڑھی اور اس نے اپنا منہ پیٹ لیا اور کہنے لگی، ``بوڑھی، بانجھ!"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccv{انہوں نے کہا ``یہی کچھ فرمایا ہے تیرے رب نے، وہ حکیم ہے اور سب کچھ جانتا ہے"\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvi{ابراہیمؑ نے کہا ``اے فرستادگان الٰہی، کیا مہم آپ کو در پیش ہے؟\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvii{انہوں نے کہا ``ہم ایک مجرم قوم کی طرف بھیجے گئے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccviii{تاکہ اُس پر پکی ہوئی مٹی کے پتھر برسا دیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccix{جو آپ کے رب کے ہاں حد سے گزر جانے والوں کے لیے نشان زدہ ہیں"\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccx{پھر ہم نے اُن سب لوگوں کو نکال لیا جو اُس بستی میں مومن تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxi{اور وہاں ہم نے ایک گھر کے سوا مسلمانوں کا کوئی گھر نہ پایا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxii{اس کے بعد ہم نے وہاں بس ایک نشانی اُن لوگوں کے لیے چھوڑ دی جو درد ناک عذاب سے ڈرتے ہوں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiii{اور (تمہارے لیے نشانی ہے) موسیٰؑ کے قصے میں جب ہم نے اُسے صریح سند کے ساتھ فرعون کے پاس بھیجا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiv{تو وہ اپنے بل بوتے پر اکڑ گیا اور بولا یہ جادوگر ہے یا مجنوں ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxv{آخر کار ہم نے اُسے اور اس کے لشکروں کو پکڑا اور سب کو سمندر میں پھینک دیا اور وہ ملامت زدہ ہو کر رہ گیا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvi{اور (تمہارے لیے نشانی ہے) عاد میں، جبکہ ہم نے ان پر ایک ایسی بے خیر ہوا بھیج دی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvii{کہ جس چیز پر بھی وہ گزر گئی اسے بوسیدہ کر کے رکھ دیا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxviii{اور (تمہارے لیے نشانی ہے) ثمود میں، جب اُن سے کہا گیا تھا کہ ایک خاص وقت تک مزے کر لو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxix{مگر اس تنبیہ پر بھی انہوں نے اپنے رب کے حکم سے سرتابی کی آخر کار ان کے دیکھتے دیکھتے ایک اچانک ٹوٹ پڑنے والے عذاب نے اُن کو آ لیا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxx{پھر نہ اُن میں اٹھنے کی سکت تھی اور نہ وہ اپنا بچاؤ کر سکتے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxi{اور ان سب سے پہلے ہم نے نوحؑ کی قوم کو ہلاک کیا کیونکہ وہ فاسق لوگ تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxii{آسمان کو ہم نے اپنے زور سے بنایا ہے اور ہم اِس کی قدرت رکھتے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiii{زمین کو ہم نے بچھایا ہے اور ہم بڑے اچھے ہموار کرنے والے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiv{اور ہر چیز کے ہم نے جوڑے بنائے ہیں، شاید کہ تم اس سے سبق لو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxv{تو دوڑو اللہ کی طرف، میں تمہارے لیے اس کی طرف سے صاف صاف خبردار کرنے والا ہوں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvi{اور نہ بناؤ اللہ کے ساتھ کوئی دوسرا معبود، میں تمہارے لیے اُس کی طرف سے صاف صاف خبردار کرنے والا ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvii{یونہی ہوتا رہا ہے، اِن سے پہلے کی قوموں کے پاس بھی کوئی رسول ایسا نہیں آیا جسے انہوں نے یہ نہ کہا ہو کہ یہ ساحر ہے یا مجنون\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxviii{کیا اِن سب نے آپس میں اِس پر کوئی سمجھوتہ کر لیا ہے؟ نہیں، بکہ یہ سب سرکش لوگ ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxix{پس اے نبیؐ، ان سے رخ پھیر لو، تم پر کچھ ملامت نہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxx{البتہ نصیحت کرتے رہو، کیونکہ نصیحت ایمان لانے والوں کے لیے نافع ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxi{میں نے جن اور انسانوں کو اِس کے سوا کسی کام کے لیے پیدا نہیں کیا ہے کہ وہ میری بندگی کریں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxii{میں اُن سے کوئی رزق نہیں چاہتا اور نہ یہ چاہتا ہوں کہ وہ مجھے کھلائیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiii{اللہ تو خود ہی رزاق ہے، بڑی قوت والا اور زبردست\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiv{پس جن لوگوں نے ظلم کیا ہے ان کے حصے کا بھی ویسا ہی عذاب تیار ہے جیسا اِنہی جیسے لوگوں کو اُن کے حصے کا مل چکا ہے، اس کے لیے یہ لوگ جلدی نہ مچائیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxv{آخر کو تباہی ہے کفر کرنے والوں کے لیے اُس روز جس کا انہیں خوف دلایا جا رہا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvi{\basmalahur قسم ہے طور کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvii{اور ایک ایسی کھلی کتاب کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxviii{جو رقیق جلد میں لکھی ہوئی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxix{اور آباد گھر کی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxl{اور اونچی چھت کی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxli{اور موجزن سمندر کی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlii{کہ تیرے رب کا عذاب ضرور واقع ہونے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliii{جسے کوئی دفع کرنے والا نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliv{وہ اُس روز واقع ہوگا جب آسمان بری طرح ڈگمگائے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlv{اور پہاڑ اڑے اڑے پھریں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvi{تباہی ہے اُس روز اُن جھٹلانے والوں کے لیے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvii{جو آج کھیل کے طور پر اپنی حجت بازیوں میں لگے ہوئے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlviii{جس دن انہیں دھکے مار مار کر نار جہنم کی طرف لے چلا جائے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlix{اُس وقت اُن سے کہا جائے گا کہ ``یہ وہی آگ ہے جسے تم جھٹلایا کرتے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccl{اب بتاؤ یہ جادو ہے یا تمہیں سوجھ نہیں رہا ہے؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccli{جاؤ اب جھلسو اِس کے اندر، تم خواہ صبر کرو یا نہ کرو، تمہارے لیے یکساں ہے، تمہیں ویسا ہی بدلہ دیا جا رہا ہے جیسے تم عمل کر رہے تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclii{متقی لوگ وہاں باغوں اور نعمتوں میں ہوں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliii{لطف لے رہے ہوں گے اُن چیزوں سے جو اُن کا رب انہیں دے گا، اور اُن کا رب اُنہیں دوزخ کے عذاب سے بچا لے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliv{(ان سے کہا جائے گا) کھاؤ اور پیو مزے سے اپنے اُن اعمال کے صلے میں جو تم کرتے رہے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclv{وہ آمنے سامنے بچھے ہوئے تختوں پر تکیے لگائے بیٹھے ہوں گے اور ہم خوبصورت آنکھوں والی حوریں اُن سے بیاہ دیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvi{جو لوگ ایمان لائے ہیں اور اُن کی اولاد بھی کسی درجہ ایمان میں ان کے نقش قدم پر چلی ہے ان کی اُس اولاد کو بھی ہم (جنت میں) اُن کے ساتھ ملا دیں گے اور اُن کے عمل میں کوئی گھاٹا ان کو نہ دیں گے ہر شخص اپنے کسب کے عوض رہن ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvii{ہم اُن کو ہر طرح کے پھل اور گوشت، جس چیز کو بھی ان کا جی چاہے گا، خوب دیے چلے جائیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclviii{وہاں وہ ایک دوسرے سے جام شراب لپک لپک کر لے رہے ہوں گے جس میں نہ یاوہ گوئی ہوگی نہ بد کرداری\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclix{اور اُن کی خدمت میں وہ لڑکے دوڑتے پھر رہے ہوں گے جو انہی کے لیے مخصوص ہوں گے ایسے خوبصورت جیسے چھپا کر رکھے ہوئے موتی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclx{یہ لوگ آپس میں ایک دوسرے سے (دنیا میں گزرے ہوئے) حالات پوچھیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxi{یہ کہیں گے کہ ہم پہلے اپنے گھر والوں میں ڈرتے ہوئے زندگی بسر کرتے تھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxii{آخر کار اللہ نے ہم پر فضل فرمایا اور ہمیں جھلسا دینے والی ہوا کے عذاب سے بچا لیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiii{ہم پچھلی زندگی میں اُسی سے دعائیں مانگتے تھے، وہ واقعی بڑا ہی محسن اور رحیم ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiv{پس اے نبیؐ، تم نصیحت کیے جاؤ، اپنے رب کے فضل سے نہ تم کاہن ہو اور نہ مجنون\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxv{کیا یہ لوگ کہتے ہیں کہ یہ شخص شاعر ہے جس کے حق میں ہم گردش ایام کا انتظار کر رہے ہیں؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvi{اِن سے کہو اچھا انتظار کرو، میں بھی تمہارے ساتھ انتظار کرتا ہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvii{کیا اِن کی عقلیں اِنہیں ایسی ہی باتیں کرنے کے لیے کہتی ہیں؟ یا در حقیقت یہ عناد میں حد سے گزرے ہوئے لوگ ہیں؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxviii{کیا یہ کہتے ہیں کہ اِس شخص نے یہ قرآن خود گھڑ لیا ہے؟ اصل بات یہ ہے کہ یہ ایمان نہیں لانا چاہتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxix{اگر یہ اپنے اِس قول میں سچے ہیں تو اِسی شان کا ایک کلام بنا لائیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxx{کیا یہ کسی خالق کے بغیر خود پیدا ہو گئے ہیں؟ یا یہ خود اپنے خالق ہیں؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxi{یا زمین اور آسمانوں کو اِنہوں نے پیدا کیا ہے؟ اصل بات یہ ہے کہ یہ یقین نہیں رکھتے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxii{کیا تیرے رب کے خزانے اِن کے قبضے میں ہیں؟ یا اُن پر اِنہی کا حکم چلتا ہے؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiii{کیا اِن کے پاس کوئی سیڑھی ہے جس پر چڑھ کر یہ عالم بالا کی سن گن لیتے ہیں؟ اِن میں سے جس نے سن گن لی ہو وہ لائے کوئی کھلی دلیل\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiv{کیا اللہ کے لیے تو ہیں بیٹیاں اور تم لوگوں کے لیے ہیں بیٹے؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxv{کیا تم اِن سے کوئی اجر مانگتے ہو کہ یہ زبردستی پڑی ہوئی چٹی کے بوجھ تلے دبے جاتے ہیں؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvi{کیا اِن کے پاس غیب کے حقائق کا علم ہے کہ اُس کی بنا پر یہ لکھ رہے ہوں؟\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvii{کیا یہ کوئی چال چلنا چاہتے ہیں؟ (اگر یہ بات ہے) تو کفر کرنے والوں پر ان کی چال الٹی ہی پڑے گی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxviii{کیا اللہ کے سوا یہ کوئی اور معبود رکھتے ہیں؟ اللہ پاک ہے اُس شرک سے جو یہ لوگ کر رہے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxix{یہ لوگ آسمان کے ٹکڑے بھی گرتے ہوئے دیکھ لیں تو کہیں گے یہ بادل ہیں جو امڈے چلے آ رہے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxx{پس اے نبیؐ، اِنہیں اِن کے حال پر چھوڑ دو یہاں تک کہ یہ اپنے اُس دن کو پہنچ جائیں جس میں یہ مار گرائے جائیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxi{جس دن نہ اِن کی اپنی کوئی چال اِن کے کسی کام آئے گی نہ کوئی اِن کی مدد کو آئے گا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxii{اور اُس وقت کے آنے سے پہلے بھی ظالموں کے لیے ایک عذاب ہے، مگر اِن میں سے اکثر جانتے نہیں ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiii{اے نبیؐ، اپنے رب کا فیصلہ آنے تک صبر کرو، تم ہماری نگاہ میں ہو تم جب اٹھو تو اپنے رب کی حمد کے ساتھ اس کی تسبیح کرو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiv{رات کو بھی اس کی تسبیح کیا کرو اور ستارے جب پلٹتے ہیں اُس وقت بھی\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxv{\basmalahur قسم ہے تارے کی جبکہ وہ غروب ہوا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvi{تمہارا رفیق نہ بھٹکا ہے نہ بہکا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvii{وہ اپنی خواہش نفس سے نہیں بولتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxviii{یہ تو ایک وحی ہے جو اُس پر نازل کی جاتی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxix{اُسے زبردست قوت والے نے تعلیم دی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxc{جو بڑا صاحب حکمت ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxci{وہ سامنے آ کھڑا ہوا جبکہ وہ بالائی افق پر تھا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcii{پھر قریب آیا اور اوپر معلق ہو گیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciii{یہاں تک کہ دو کمانوں کے برابر یا اس سے کچھ کم فاصلہ رہ گیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciv{تب اُس نے اللہ کے بندے کو وحی پہنچائی جو وحی بھی اُسے پہنچانی تھی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcv{نظر نے جو کچھ دیکھا، دل نے اُس میں جھوٹ نہ ملایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvi{اب کیا تم اُس چیز پر اُس سے جھگڑتے ہو جسے وہ آنکھوں سے دیکھتا ہے؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvii{اور ایک مرتبہ پھر اُس نے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcviii{سدرۃالمنتہیٰ کے پاس اُس کو دیکھا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcix{جہاں پاس ہی جنت الماویٰ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccc{اُس وقت سدرہ پر چھا رہا تھا جو کچھ کہ چھا رہا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccci{نگاہ نہ چوندھیائی نہ حد سے متجاوز ہوئی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccii{اور اس نے اپنے رب کی بڑی بڑی نشانیاں دیکھیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciii{اب ذرا بتاؤ، تم نے کبھی اِس لات، اور اِس عزیٰ\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciv{اور تیسری ایک اور دیوی منات کی حقیقت پر کچھ غور بھی کیا؟\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccv{کیا بیٹے تمہارے لیے ہیں اور بیٹیاں خدا کے لیے؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvi{یہ تو بڑی دھاندلی کی تقسیم ہوئی!\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvii{دراصل یہ کچھ نہیں ہیں مگر بس چند نام جو تم نے اور تمہارے باپ دادا نے رکھ لیے ہیں اللہ نے اِن کے لیے کوئی سند نازل نہیں کی حقیقت یہ ہے کہ لوگ محض وہم و گمان کی پیروی کر رہے ہیں اور خواہشات نفس کے مرید بنے ہوئے ہیں حالانکہ اُن کے رب کی طرف سے اُن کے پاس ہدایت آ چکی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccviii{کیا انسان جو کچھ چاہے اس کے لیے وحی حق ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccix{دنیا اور آخرت کا مالک تو اللہ ہی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccx{آسمانوں میں کتنے ہی فرشتے موجود ہیں، اُن کی شفاعت کچھ بھی کام نہیں آ سکتی جب تک کہ اللہ کسی ایسے شخص کے حق میں اُس کی اجازت نہ دے جس کے لیے وہ کوئی عرضداشت سننا چاہے اور اس کو پسند کرے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxi{مگر جو لوگ آخرت کو نہیں مانتے وہ فرشتوں کو دیویوں کے ناموں سے موسوم کرتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxii{حالانکہ اس معاملہ کا کوئی علم انہیں حاصل نہیں ہے، وہ محض گمان کی پیروی کر رہے ہیں، اور گمان حق کی جگہ کچھ بھی کام نہیں دے سکتا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiii{پس اے نبیؐ، جو شخص ہمارے ذکر سے منہ پھیرتا ہے، اور دنیا کی زندگی کے سوا جسے کچھ مطلوب نہیں ہے، اُسے اس کے حال پر چھوڑ دو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiv{اِن لوگوں کا مبلغ علم بس یہی کچھ ہے، یہ بات تیرا رب ہی زیادہ جانتا ہے کہ اُس کے راستے سے کون بھٹک گیا ہے اور کون سیدھے راستے پر ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxv{اور زمین اور آسمانوں کی ہر چیز کا مالک اللہ ہی ہے تاکہ اللہ برائی کرنے والوں کو ان کے عمل کا بدلہ دے اور اُن لوگوں کو اچھی جزا سے نوازے جنہوں نے نیک رویہ اختیار کیا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvi{جو بڑے بڑے گناہوں اور کھلے کھلے قبیح افعال سے پرہیز کرتے ہیں، الا یہ کہ کچھ قصور اُن سے سرزد ہو جائے بلاشبہ تیرے رب کا دامن مغفرت بہت وسیع ہے وہ تمھیں اُس وقت سے خوب جانتا ہے جب اُس نے زمین سے تمہیں پیدا کیا اور جب تم اپنی ماؤں کے پیٹوں میں ابھی جنین ہی تھے پس اپنے نفس کی پاکی کے دعوے نہ کرو، وہی بہتر جانتا ہے کہ واقعی متقی کون ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvii{پھر اے نبیؐ، تم نے اُس شخص کو بھی دیکھا جو راہ خدا سے پھر گیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxviii{اور تھوڑا سا دے کر رک گیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxix{کیا اس کے پاس غیب کا علم ہے کہ وہ حقیقت کو دیکھ رہا ہے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxx{کیا اُسے اُن باتوں کی کوئی خبر نہیں پہنچی جو موسیٰؑ کے صحیفوں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxi{اور اُس ابراہیمؑ کے صحیفوں میں بیان ہوئی ہیں جس نے وفا کا حق ادا کر دیا؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxii{``یہ کہ کوئی بوجھ اٹھانے والا دوسرے کا بوجھ نہیں اٹھائے گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiii{اور یہ کہ انسان کے لیے کچھ نہیں ہے مگر وہ جس کی اُس نے سعی کی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiv{اور یہ کہ اس کی سعی عنقریب دیکھی جائے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxv{اور اس کی پوری جزا اسے دی جائے گی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvi{اور یہ کہ آخر کار پہنچنا تیرے رب ہی کے پاس ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvii{اور یہ کہ اُسی نے ہنسایا اور اُسی نے رلایا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxviii{اور یہ کہ اُسی نے موت دی اور اُسی نے زندگی بخشی\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxix{اور یہ کہ اُسی نے نر اور مادہ کا جوڑا پیدا کیا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxx{ایک بوند سے جب وہ ٹپکائی جاتی ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxi{اور یہ کہ دوسری زندگی بخشنا بھی اُسی کے ذمہ ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxii{اور یہ کہ اُسی نے غنی کیا اور جائداد بخشی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiii{اور یہ کہ وہی شعریٰ کا رب ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiv{اور یہ کہ اُسی نے عاد اولیٰ کو ہلاک کیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxv{اور ثمود کو ایسا مٹایا کہ ان میں سے کسی کو باقی نہ چھوڑا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvi{اور اُن سے پہلے قوم نوحؑ کو تباہ کیا کیونکہ وہ تھے ہی سخت ظالم و سرکش لوگ\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvii{اور اوندھی گرنے والی بستیوں کو اٹھا پھینکا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxviii{پھر چھا دیا اُن پر وہ کچھ جو (تم جانتے ہی ہو کہ) کیا چھا دیا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxix{پس اے مخاطب، اپنے رب کی کن کن نعمتوں میں تو شک کرے گا؟"\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxl{یہ ایک تنبیہ ہے پہلے آئی ہوئی تنبیہات میں سے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxli{آنے والی گھڑی قریب آ لگی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlii{اللہ کے سوا کوئی اُس کو ہٹا نے والا نہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliii{اب کیا یہی وہ باتیں ہیں جن پر تم اظہار تعجب کرتے ہو؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliv{ہنستے ہو اور روتے نہیں ہو؟\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlv{اور گا بجا کر انہیں ٹالتے ہو؟\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvi{جھک جاؤ اللہ کے آگے اور بندگی بجا لاؤ\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvii{\basmalahur قیامت کی گھڑی قریب آ گئی اور چاند پھٹ گیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlviii{مگر اِن لوگوں کا حال یہ ہے کہ خواہ کوئی نشانی دیکھ لیں منہ موڑ جاتے ہیں اور کہتے ہیں یہ تو چلتا ہوا جادو ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlix{اِنہوں نے (اس کو بھی) جھٹلا دیا اور اپنی خواہشات نفس ہی کی پیروی کی ہر معاملہ کو آخر کار ایک انجام پر پہنچ کر رہنا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccl{اِن لوگوں کے سامنے (پچھلی قوموں کے) وہ حالات آ چکے ہیں جن میں سرکشی سے باز رکھنے کے لیے کافی سامان عبرت ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccli{اور ایسی حکمت جو نصیحت کے مقصد کو بدرجہ اتم پورا کرتی ہے مگر تنبیہات اِن پر کارگر نہیں ہوتیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclii{پس اے نبیؐ، اِن سے رخ پھیر لو جس روز پکارنے والا ایک سخت ناگوار چیز کی طرف پکارے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliii{لوگ سہمی ہوئی نگاہوں کے ساتھ اپنی قبروں سے اِس طرح نکلیں گے گویا وہ بکھری ہوئی ٹڈیاں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliv{پکارنے والے کی طرف دوڑے جا رہے ہوں گے اور وہی منکرین (جو دنیا میں اس کا انکار کرتے تھے) اُس وقت کہیں گے کہ یہ دن تو بڑا کٹھن ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclv{اِن سے پہلے نوحؑ کی قوم جھٹلا چکی ہے اُنہوں نے ہمارے بندے کو جھوٹا قرار دیا اور کہا کہ یہ دیوانہ ہے، اور وہ بری طرح جھڑکا گیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvi{آخر کار اُس نے اپنے رب کو پکارا کہ ``میں مغلوب ہو چکا، اب تو اِن سے انتقام لے"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvii{تب ہم نے موسلا دھار بارش سے آسمان کے دروازے کھول دیے اور زمین کو پھاڑ کر چشموں میں تبدیل کر دیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclviii{اور یہ سارا پانی اُس کام کو پورا کرنے لیے مل گیا جو مقدر ہو چکا تھا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclix{اور نوحؑ کو ہم نے ایک تختوں اور کیلوں والی پر سوار کر دیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclx{جو ہماری نگرانی میں چل رہی تھی یہ تھا بدلہ اُس شخص کی خاطر جس کی نا قدری کی گئی تھی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxi{اُس کشتی کو ہم نے ایک نشانی بنا کر چھوڑ دیا، پھر کوئی ہے نصیحت قبول کرنے والا؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxii{دیکھ لو، کیسا تھا میرا عذاب اور کیسی تھیں میری تنبیہات\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiii{ہم نے اِس قرآن کو نصیحت کے لیے آسان ذریعہ بنا دیا ہے، پھر کیا ہے کوئی نصیحت قبول کرنے والا؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiv{عاد نے جھٹلایا، تو دیکھ لو کہ کیسا تھا میرا عذاب اور کیسی تھیں میری تنبیہات\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxv{ہم نے ایک پیہم نحوست کے دن سخت طوفانی ہوا اُن پر بھیج دی جو لوگوں کو اٹھا اٹھا کر اس طرح پھینک رہی تھی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvi{جیسے وہ جڑ سے اکھڑے ہوئے کھجور کے تنے ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvii{پس دیکھ لو کہ کیسا تھا میرا عذاب اور کیسی تھیں میری تنبیہات\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxviii{ہم نے اِس قرآن کو نصیحت کے لیے آسان ذریعہ بنا دیا ہے، پھر کیا ہے کوئی نصیحت قبول کرنے والا؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxix{ثمود نے تنبیہات کو جھٹلایا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxx{اور کہنے لگے ``ایک اکیلا آدمی جو ہم ہی میں سے ہے کیا اب ہم اُس کے پیچھے چلیں؟ اِس کا اتباع ہم قبول کر لیں تو اِس کے معنی یہ ہوں گے کہ ہم بہک گئے ہیں اور ہماری عقل ماری گئی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxi{کیا ہمارے درمیان بس یہی ایک شخص تھا جس پر خدا کا ذکر نازل کیا گیا؟ نہیں، بلکہ یہ پرلے درجے کا جھوٹا اور بر خود غلط ہے"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxii{(ہم نے اپنے پیغمبر سے کہا) ``کل ہی اِنہیں معلوم ہوا جاتا ہے کہ کون پرلے درجے کا جھوٹا اور بر خود غلط ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiii{ہم اونٹنی کو اِن کے لیے فتنہ بنا کر بھیج رہے ہیں اب ذرا صبر کے ساتھ دیکھ کہ اِن کا کیا انجام ہوتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiv{اِن کو جتا دے کہ پانی اِن کے اور اونٹنی کے درمیان تقسیم ہوگا اور ہر ایک اپنی باری کے دن پانی پر آئے گا"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxv{آخر کار اُن لوگوں نے اپنے آدمی کو پکارا اور اُس نے اِس کام کا بیڑا اٹھایا اور اونٹنی کو مار ڈالا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvi{پھر دیکھ لو کہ کیسا تھا میرا عذاب اور کیسی تھیں میری تنبیہات\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvii{ہم نے اُن پر بس ایک ہی دھماکا چھوڑا اور وہ باڑے والے کی روندی ہوئی باڑھ کی طرح بھس ہو کر رہ گئے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxviii{ہم نے اِس قرآن کو نصیحت کے لیے آسان ذریعہ بنا دیا ہے، اب ہے کوئی نصیحت قبول کرنے والا؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxix{لوطؑ کی قوم نے تنبیہات کو جھٹلایا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxx{اور ہم نے پتھراؤ کرنے والی ہوا اس پر بھیج دی صرف لوطؑ کے گھر والے اُس سے محفوظ رہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxi{اُن کو ہم نے اپنے فضل سے رات کے پچھلے پہر بچا کر نکال دیا یہ جزا دیتے ہیں ہم ہر اُس شخص کو جو شکر گزار ہوتا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxii{لوطؑ نے اپنی قوم کے لوگوں کو ہماری پکڑ سے خبردار کیا مگر وہ ساری تنبیہات کو مشکوک سمجھ کر باتوں میں اڑاتے رہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiii{پھر انہوں نے اُسے اپنے مہمانوں کی حفاظت سے باز رکھنے کی کوشش کی آخر کار ہم نے اُن کی آنکھیں موند دیں کہ چکھو اب میرے عذاب اور میری تنبیہات کا مزا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiv{صبح سویرے ہی ایک اٹل عذاب نے ان کو آ لیا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxv{چکھو مزا اب میرے عذاب کا اور میری تنبیہات کا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvi{ہم نے اِس قرآن کو نصیحت کے لیے آسان ذریعہ بنا دیا ہے، پس ہے کوئی نصیحت قبول کرنے والا؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvii{اور آل فرعون کے پاس بھی تنبیہات آئی تھیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxviii{مگر انہوں نے ہماری ساری نشانیوں کو جھٹلا دیا آخر کو ہم نے انہیں پکڑا جس طرح کوئی زبردست قدرت والا پکڑتا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxix{کیا تمہارے کفار کچھ اُن لوگوں سے بہتر ہیں؟ یا آسمانی کتابوں میں تمہارے لیے کوئی معافی لکھی ہوئی ہے؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxc{یا اِن لوگوں کا کہنا یہ ہے کہ ہم ایک مضبوط جتھا ہیں، اپنا بچاؤ کر لیں گے؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxci{عنقریب یہ جتھا شکست کھا جائے گا اور یہ سب پیٹھ پھیر کر بھاگتے نظر آئیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcii{بلکہ اِن سے نمٹنے کے لیے اصل وعدے کا وقت تو قیامت ہے اور وہ بڑی آفت اور زیادہ تلخ ساعت ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciii{یہ مجرم لوگ در حقیقت غلط فہمی میں میں مبتلا ہیں اور اِن کی عقل ماری گئی ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciv{جس روز یہ منہ کے بل آگ میں گھسیٹے جائیں گے اُس روز اِن سے کہا جائے گا کہ اب چکھو جہنم کی لپٹ کا مزا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcv{ہم نے ہر چیز ایک تقدیر کے ساتھ پیدا کی ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvi{اور ہمارا حکم بس ایک ہی حکم ہوتا ہے اور پلک جھپکاتے وہ عمل میں آ جاتا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvii{تم جیسے بہت سوں کو ہم ہلاک کر چکے ہیں، پھر ہے کوئی نصیحت قبول کرنے والا؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcviii{جو کچھ اِنہوں نے کیا ہے وہ سب دفتروں میں درج ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcix{اور ہر چھوٹی بڑی بات لکھی ہوئی موجود ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcm{نافرمانی سے پرہیز کرنے والے یقیناً باغوں اور نہروں میں ہوں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmi{سچی عزت کی جگہ، بڑے ذی اقتدار بادشاہ کے قریب\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmii{\basmalahur رحمٰن نے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiii{اِس قرآن کی تعلیم دی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiv{اُسی نے انسان کو پیدا کیا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmv{اور اسے بولنا سکھایا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvi{سورج اور چاند ایک حساب کے پابند ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvii{اور تارے اور درخت سب سجدہ ریز ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmviii{آسمان کو اُس نے بلند کیا اور میزان قائم کر دی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmix{اِس کا تقاضا یہ ہے کہ تم میزان میں خلل نہ ڈالو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmx{انصاف کے ساتھ ٹھیک ٹھیک تولو اور ترازو میں ڈنڈی نہ مارو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxi{زمین کو اس نے سب مخلوقات کے لیے بنایا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxii{اس میں ہر طرح کے بکثرت لذیذ پھل ہیں کھجور کے درخت ہیں جن کے پھل غلافوں میں لپٹے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiii{طرح طرح کے غلے ہیں جن میں بھوسا بھی ہوتا ہے اور دانہ بھی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiv{پس اے جن و انس، تم اپنے رب کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxv{انسان کو اُس نے ٹھیکری جیسے سوکھے سڑے ہوئے گارے سے بنایا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvi{اور جن کو آگ کی لپٹ سے پیدا کیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvii{پس اے جن و انس، تم اپنے رب کے کن کن عجائب قدرت کو جھٹلاؤ گے؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxviii{دونوں مشرق اور دونوں مغرب، سب کا مالک و پروردگار وہی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxix{پس اے جن و انس، تم اپنے رب کی کن کن قدرتوں کو جھٹلاؤ گے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxx{دو سمندروں کو اس نے چھوڑ دیا کہ باہم مل جائیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxi{پھر بھی اُن کے درمیان ایک پردہ حائل ہے جس سے وہ تجاوز نہیں کرتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxii{پس اے جن و انس، تم اپنے رب کی قدرت کے کن کن کرشموں کو جھٹلاؤ گے؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiii{اِن سمندروں سے موتی اور مونگے نکلتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiv{پس اے جن و انس، تم اپنے رب کی قدرت کے کن کن کمالات کو جھٹلاؤ گے؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxv{اور یہ جہاز اُسی کے ہیں جو سمندر میں پہاڑوں کی طرح اونچے اٹھے ہوئے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvi{پس اے جن و انس، تم اپنے رب کے کن کن احسانات کو جھٹلاؤ گے؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvii{ہر چیز جو اس زمین پر ہے فنا ہو جانے والی ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxviii{اور صرف تیرے رب کی جلیل و کریم ذات ہی باقی رہنے والی ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxix{پس اے جن و انس، تم اپنے رب کے کن کن کمالات کو جھٹلاؤ گے؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxx{زمین اور آسمانوں میں جو بھی ہیں سب اپنی حاجتیں اُسی سے مانگ رہے ہیں ہر آن وہ نئی شان میں ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxi{پس اے جن و انس، تم اپنے رب کی کن کن صفات حمیدہ کو جھٹلاؤ گے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxii{اے زمین کے بوجھو، عنقریب ہم تم سے باز پرس کرنے کے لیے فارغ ہوئے جاتے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiii{(پھر دیکھ لیں گے کہ) تم اپنے رب کے کن کن احسانات کو جھٹلاتے ہو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiv{اے گروہ جن و انس، گر تم زمین اور آسمانوں کی سرحدوں سے نکل کر بھاگ سکتے ہو تو بھاگ دیکھو نہیں بھاگ سکتے اِس کے لیے بڑا زور چاہیے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxv{اپنے رب کی کن کن قدرتوں کو تم جھٹلاؤ گے؟\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvi{(بھاگنے کی کوشش کرو گے تو) تم پر آگ کا شعلہ اور دھواں چھوڑ دیا جائے گا جس کا تم مقابلہ نہ کر سکو گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvii{اے جن و انس، تم اپنے رب کی کن کن قدرتوں کا انکار کرو گے؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxviii{پھر (کیا بنے گی اُس وقت) جب آسمان پھٹے گا اور لال چمڑے کی طرح سرخ ہو جائے گا؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxix{اے جن و انس (اُس وقت) تم اپنے رب کی کن کن قدرتوں کو جھٹلاؤ گے؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxl{اُس روز کسی انسان اور کسی جن سے اُس کا گناہ پوچھنے کی ضرورت نہ ہوگی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxli{پھر (دیکھ لیا جائے گا کہ) تم دونوں گروہ اپنے رب کے کن کن احسانات کا انکار کرتے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlii{مجرم وہاں اپنے چہروں سے پہچان لیے جائیں گے اور انہیں پیشانی کے بال اور پاؤں پکڑ پکڑ کر گھسیٹا جائے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliii{اُس وقت تم اپنے رب کی کن کن قدرتوں کو جھٹلاؤ گے؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliv{(اُس وقت کہا جائے گا) یہ وہی جہنم ہے جس کو مجرمین جھوٹ قرار دیا کرتے تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlv{اُسی جہنم اور کھولتے ہوئے پانی کے درمیان وہ گردش کرتے رہیں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvi{پھر اپنے رب کی کن کن قدرتوں کو تم جھٹلاؤ گے؟\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvii{اور ہر اُس شخص کے لیے جو اپنے رب کے حضور پیش ہونے کا خوف رکھتا ہو، دو باغ ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlviii{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlix{ہری بھری ڈالیوں سے بھرپور\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcml{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcmli{دونوں باغوں میں دو چشمے رواں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlii{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliii{دونوں باغوں میں ہر پھل کی دو قسمیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliv{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlv{جنتی لوگ ایسے فرشوں پر تکیے لگا کے بیٹھیں گے جن کے استر دبیز ریشم کے ہوں گے، اور باغوں کی ڈالیاں پھلوں سے جھکی پڑ رہی ہوں گی\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvi{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvii{اِن نعمتوں کے درمیان شرمیلی نگاہوں والیاں ہوں گی جنہیں اِن جنتیوں سے پہلے کسی انسان یا جن نے چھوا نہ ہوگا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlviii{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlix{ایسی خوبصورت جیسے ہیرے اور موتی\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlx{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxi{نیکی کا بدلہ نیکی کے سوا اور کیا ہو سکتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxii{پھر اے جن و انس، اپنے رب کے کن کن اوصاف حمیدہ کا تم انکار کرو گے؟\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiii{اور اُن دو باغوں کے علاوہ دو باغ اور ہوں گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiv{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxv{گھنے سرسبز و شاداب باغ\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvi{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvii{دونوں باغوں میں دو چشمے فواروں کی طرح ابلتے ہوئے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxviii{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxix{اُن میں بکثرت پھل اور کھجوریں اور انار\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxx{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxi{اِن نعمتوں کے درمیان خوب سیرت اور خوبصورت بیویاں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxii{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiii{خیموں میں ٹھیرائی ہوئی حوریں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiv{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxv{اِن جنتیوں سے پہلے کبھی انسان یا جن نے اُن کو نہ چھوا ہوگا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvi{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvii{وہ جنتی سبز قالینوں اور نفیس و نادر فرشوں پر تکیے لگا کے بیٹھیں گے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxviii{اپنے رب کے کن کن انعامات کو تم جھٹلاؤ گے؟\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxix{بڑی برکت والا ہے تیرے رب جلیل و کریم کا نام\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxx{\basmalahur جب وہ ہونے والا واقعہ پیش آ جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxi{تو کوئی اس کے وقوع کو جھٹلانے والا نہ ہوگا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxii{وہ تہ و بالا کر دینے والی آفت ہوگی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiii{زمین اس وقت یکبارگی ہلا ڈالی جائے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiv{اور پہاڑ اس طرح ریزہ ریزہ کر دیے جائیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxv{کہ پراگندہ غبار بن کر رہ جائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvi{تم لوگ اُس وقت تین گروہوں میں تقسیم ہو جاؤ گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvii{دائیں بازو والے، سو دائیں بازو والوں (کی خوش نصیبی) کا کیا کہنا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxviii{اور بائیں بازو والے، تو بائیں بازو والوں (کی بد نصیبی کا) کا کیا ٹھکانا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxix{اور آگے والے تو پھر آگے وا لے ہی ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxc{وہی تو مقرب لوگ ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxci{نعمت بھری جنتوں میں رہیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcii{اگلوں میں سے بہت ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciii{اور پچھلوں میں سے کم\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciv{مرصع تختوں پر\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcv{تکیے لگا ئے آمنے سامنے بیٹھیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvi{اُن کی مجلسوں میں ابدی لڑکے شراب چشمہ جاری سے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvii{لبریز پیالے کنٹر اور ساغر لیے دوڑتے پھرتے ہونگے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcviii{جسے پی کر نہ اُن کا سر چکرائے گا نہ ان کی عقل میں فتور آئے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcix{اور وہ اُن کے سامنے طرح طرح کے لذیذ پھل پیش کریں گے جسے چاہیں چن لیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmm{اور پرندوں کے گوشت پیش کریں گے کہ جس پرندے کا چاہیں استعمال کریں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmi{اور ان کے لیے خوبصورت آنکھوں والی حوریں ہونگی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmii{ایسی حسین جیسے چھپا کر رکھے ہوئے موتی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmiii{یہ سب کچھ اُن اعمال کی جزا کے طور پر انہیں ملے گا جو وہ دنیا میں کرتے رہے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmiv{وہاں وہ کوئی بیہودہ کلام یا گناہ کی بات نہ سنیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmv{جو بات بھی ہوگی ٹھیک ٹھیک ہوگی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmvi{اور دائیں بازو والے، دائیں بازو والوں کی خوش نصیبی کا کیا کہنا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmvii{وہ بے خار بیریوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmviii{اور تہ بر تہ چڑھے ہوئے کیلوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmix{اور دور تک پھیلی ہوئی چھاؤں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmx{اور ہر دم رواں پانی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmxi{اور کبھی ختم نہ ہونے والے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmxii{اور بے روک ٹوک ملنے والے بکثرت پھلوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiii{اور اونچی نشست گاہوں میں ہوں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiv{ان کی بیویوں کو ہم خاص طور پر نئے سرے سے پیدا کریں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmxv{اور انہیں با کرہ بنا دیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvi{اپنے شوہروں کی عاشق اور عمر میں ہم سن\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvii{یہ کچھ دائیں بازو والوں کے لیے ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmxviii{وہ اگلوں میں سے بہت ہوں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmxix{اور پچھلوں میں سے بھی بہت\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmxx{اور بائیں بازو والے، بائیں بازو والوں کی بد نصیبی کا کیا پوچھنا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxi{وہ لو کی لپٹ اور کھولتے ہوئے پانی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxii{اور کالے دھوئیں کے سائے میں ہوں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiii{جو نہ ٹھنڈا ہوگا نہ آرام دہ\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiv{یہ وہ لوگ ہوں گے جو اِس انجام کو پہنچنے سے پہلے خوشحال تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxv{اور گناہ عظیم پر اصرار کرتے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvi{کہتے تھے ``کیا جب ہم مر کر خاک ہو جائیں گے اور ہڈیوں کا پنجر رہ جائیں گے تو پھر اٹھا کھڑے کیے جائیں گے؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvii{اور کیا ہمارے وہ باپ دادا بھی اٹھائے جائیں گے جو پہلے گزر چکے ہیں؟"\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxviii{اے نبیؐ، اِن لوگوں سے کہو، یقیناً اگلے اور پچھلے سب\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxix{ایک دن ضرور جمع کیے جانے والے ہیں جس کا وقت مقرر کیا جا چکا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxx{پھر اے گمراہو اور جھٹلانے والو!\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxi{تم شجر زقوم کی غذا کھانے والے ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxii{اُسی سے تم پیٹ بھرو گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiii{اور اوپر سے کھولتا ہوا پانی\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiv{تونس لگے ہوئے اونٹ کی طرح پیو گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxv{یہ ہے بائیں والوں کی ضیافت کا سامان روز جزا میں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvi{ہم نے تمہیں پیدا کیا ہے پھر کیوں تصدیق نہیں کرتے؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvii{کبھی تم نے غور کیا، یہ نطفہ جو تم ڈالتے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxviii{اس سے بچہ تم بناتے ہو یا اس کے بنانے والے ہم ہیں؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxix{ہم نے تمہارے درمیان موت کو تقسیم کیا ہے، اور ہم اِس سے عاجز نہیں ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmmxl{کہ تمہاری شکلیں بدل دیں اور کسی ایسی شکل میں تمہیں پیدا کر دیں جس کو تم نہیں جانتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmmxli{اپنی پہلی پیدائش کو تو تم جانتے ہو، پھر کیوں سبق نہیں لیتے؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlii{کبھی تم نے سوچا، یہ بیج جو تم بوتے ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliii{اِن سے کھیتیاں تم اگاتے ہو یا اُن کے اگانے والے ہم ہیں؟\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliv{ہم چاہیں تو ان کھیتیوں کو بھس بنا کر رکھ دیں اور تم طرح طرح کی باتیں بناتے رہ جاؤ\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlv{کہ ہم پر تو الٹی چٹی پڑ گئی\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvi{بلکہ ہمارے تو نصیب ہی پھوٹے ہوئے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvii{کبھی تم نے آنکھیں کھول کر دیکھا، یہ پانی جو تم پیتے ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlviii{اِسے تم نے بادل سے برسایا ہے یا اِس کے برسانے والے ہم ہیں؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlix{ہم چاہیں تو اسے سخت کھاری بنا کر رکھ دیں، پھر کیوں تم شکر گزار نہیں ہوتے؟\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmml{کبھی تم نے خیال کیا، یہ آگ جو تم سلگاتے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmmli{اِس کا درخت تم نے پیدا کیا ہے، یا اس کے پیدا کرنے والے ہم ہیں؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmmlii{ہم نے اُس کو یاد دہانی کا ذریعہ اور حاجت مندوں کے لیے سامان زیست بنایا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmmliii{پس اے نبیؐ، اپنے رب عظیم کے نام کی تسبیح کرو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmmliv{پس نہیں، میں قسم کھاتا ہوں تاروں کے مواقع کی\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmmlv{اور اگر تم سمجھو تو یہ بہت بڑی قسم ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvi{کہ یہ ایک بلند پایہ قرآن ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvii{ایک محفوظ کتاب میں ثبت\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmmlviii{جسے مطہرین کے سوا کوئی چھو نہیں سکتا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmmlix{یہ رب العالمین کا نازل کردہ ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmmlx{پھر کیا اس کلام کے ساتھ تم بے اعتنائی برتتے ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxi{اور اِس نعمت میں اپنا حصہ تم نے یہ رکھا ہے کہ اِسے جھٹلاتے ہو؟\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxii{تو جب مرنے والے کی جان حلق تک پہنچ چکی ہوتی ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiii{اور تم آنکھوں سے دیکھ رہے ہوتے ہو کہ وہ مر رہا ہے،\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiv{اُس وقت تمہاری بہ نسبت ہم اُس کے زیادہ قریب ہوتے ہیں مگر تم کو نظر نہیں آتے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxv{اب اگر تم کسی کے محکوم نہیں ہو اور اپنے اِس خیال میں سچے ہو،\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvi{اُس وقت اُس کی نکلتی ہوئی جان کو واپس کیوں نہیں لے آتے؟\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvii{پھر وہ مرنے والا اگر مقربین میں سے ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxviii{تو اس کے لیے راحت اور عمدہ رزق اور نعمت بھری جنت ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxix{اور اگر وہ اصحاب یمین میں سے ہو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxx{تو اس کا استقبال یوں ہوتا ہے کہ سلام ہے تجھے، تو اصحاب الیمین میں سے ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxi{اور اگر وہ جھٹلانے والے گمراہ لوگوں میں سے ہو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxii{تو اس کی تواضع کے لیے کھولتا ہوا پانی ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiii{اور جہنم میں جھونکا جانا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiv{یہ سب کچھ قطعی حق ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxv{پس اے نبیؐ، اپنے رب عظیم کے نام کی تسبیح کرو\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvi{\basmalahur اللہ کی تسبیح کی ہے ہر اُس چیز نے جو زمین اور آسمانوں میں ہے، اور وہی زبردست دانا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvii{زمین اور آسمانوں کی سلطنت کا مالک وہی ہے، زندگی بخشتا ہے اور موت دیتا ہے، اور ہر چیز پر قدرت رکھتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxviii{وہی اول بھی ہے اور آخر بھی، ظاہر بھی ہے اور مخفی بھی، اور وہ ہر چیز کا علم رکھتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxix{وہی ہے جس نے آسمانوں اور زمین کو چھ دنوں میں پیدا کیا اور پھر عرش پر جلوہ فرما ہوا اُس کے علم میں ہے جو کچھ زمین میں جاتا ہے اور جو کچھ اس سے نکلتا ہے اور جو کچھ آسمان سے اترتا ہے اور جو کچھ اُس میں چڑھتا ہے وہ تمہارے ساتھ ہے جہاں بھی تم ہو جو کام بھی کرتے ہو اسے وہ دیکھ رہا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxx{وہی زمین اور آسمانوں کی بادشاہی کا مالک ہے اور تمام معاملات فیصلے کے لیے اُسی کی طرف رجوع کیے جاتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxi{وہی رات کو دن میں اور دن کو رات میں داخل کرتا ہے، اور دلوں کے چھپے ہوئے راز تک جانتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxii{ایمان لاؤ اللہ اور اس کے رسول پر اور خرچ کرو اُن چیزوں میں سے جن پر اس نے تم کو خلیفہ بنایا ہے جو لوگ تم میں سے ایمان لائیں گے اور مال خرچ کریں گے ان کے لیے بڑا اجر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiii{تمہیں کیا ہو گیا ہے کہ تم اللہ پر ایمان نہیں لاتے حالانکہ رسول تمہیں اپنے رب پر ایمان لانے کی دعوت دے رہا ہے اور وہ تم سے عہد لے چکا ہے اگر تم واقعی ماننے والے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiv{وہ اللہ ہی تو ہے جو اپنے بندے پر صاف صاف آیتیں نازل کر رہا ہے تاکہ تمہیں تاریکیوں سے نکال کر روشنی میں لے آئے، اور حقیقت یہ ہے کہ اللہ تم پر نہایت شفیق اور مہربان ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxv{آخر کیا وجہ ہے کہ تم اللہ کی راہ میں خرچ نہیں کرتے حالانکہ زمین اور آسمانوں کی میراث اللہ ہی کے لیے ہے تم میں سے جو لوگ فتح کے بعد خرچ اور جہاد کریں گے وہ کبھی اُن لوگوں کے برابر نہیں ہو سکتے جنہوں نے فتح سے پہلے خرچ اور جہاد کیا ہے اُن کا درجہ بعد میں خرچ اور جہاد کرنے والوں سے بڑھ کر ہے اگرچہ اللہ نے دونوں ہی سے اچھے وعدے فرمائے ہیں جو کچھ تم کرتے ہو اللہ اس سے با خبر ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvi{کون ہے جو اللہ کو قرض دے؟ اچھا قرض، تاکہ اللہ اسے کئی گنا بڑھا کر واپس دے، اور اُس کے لیے بہترین اجر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvii{اُس دن جبکہ تم مومن مردوں اور عورتوں کو دیکھو گے کہ ان کا نور اُن کے آگے آگے اور ان کے دائیں جانب دوڑ رہا ہوگا (ان سے کہا جائے گا کہ) ``آج بشارت ہے تمہارے لیے" جنتیں ہونگی جن کے نیچے نہریں بہہ رہی ہونگی، جن میں وہ ہمیشہ رہیں گے یہی ہے بڑی کامیابی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxviii{اُس روز منافق مردوں اور عورتوں کا حال یہ ہوگا کہ وہ مومنوں سے کہیں گے ذرا ہماری طرف دیکھو تاکہ ہم تمہارے نور سے کچھ فائدہ اٹھائیں، مگر ان سے کہا جائے گا پیچھے ہٹ جاؤ، اپنا نور کہیں اور تلاش کرو پھر ان کے درمیان ایک دیوار حائل کر دی جائے گی جس میں ایک دروازہ ہوگا اُس دروازے کے اندر رحمت ہوگی اور باہر عذاب\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxix{وہ مومنوں سے پکار پکار کر کہیں گے کیا ہم تمہارے ساتھ نہ تھے؟ مومن جواب دیں گے ہاں، مگر تم نے اپنے آپ کو خود فتنے میں ڈالا، موقع پرستی کی، شک میں پڑے رہے، اور جھوٹی توقعات تمہیں فریب دیتی رہیں، یہاں تک کہ اللہ کا فیصلہ آ گیا، اور آخر وقت تک وہ بڑا دھوکے باز تمہیں اللہ کے معاملہ میں دھوکا دیتا رہا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmxc{لہٰذا آج نہ تم سے کوئی فدیہ قبول کیا جائے گا اور نہ اُن لوگوں سے جنہوں نے کھلا کھلا کفر کیا تھا تمہارا ٹھکانا جہنم ہے، وہی تمہاری خبر گیری کرنے والی ہے اور یہ بدترین انجام ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmxci{کیا ایمان لانے والوں کے لیے ابھی وہ وقت نہیں آیا کہ اُن کے دل اللہ کے ذکر سے پگھلیں اور اُس کے نازل کردہ حق کے آگے جھکیں اور وہ اُن لوگوں کی طرح نہ ہو جائیں جنہیں پہلے کتاب دی گئی تھی، پھر ایک لمبی مدت اُن پر گزر گئی تو ان کے دل سخت ہو گئے اور آج ان میں سے اکثر فاسق بنے ہوئے ہیں؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcii{خوب جان لو کہ، اللہ زمین کو اُس کی موت کے بعد زندگی بخشتا ہے، ہم نے نشانیاں تم کو صاف صاف دکھا دی ہیں، شاید کہ تم عقل سے کام لو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciii{مردوں اور عورتوں میں سے جو لوگ صدقات دینے والے ہیں اور جنہوں نے اللہ کو قرض حسن دیا ہے، اُن کو یقیناً کئی گنا بڑھا کر دیا جائے گا اور ان کے لیے بہترین اجر ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciv{اور جو لوگ اللہ اور اس کے رسولوں پر ایمان لائے ہیں وہی اپنے رب کے نزدیک صدیق اور شہید ہیں، اُن کے لیے اُن کا اجر اور اُن کا نور ہے اور جن لوگوں نے کفر کیا ہے اور ہماری آیات کو جھٹلایا ہے وہ دوزخی ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcv{خوب جان لو کہ یہ دنیا کی زندگی اس کے سوا کچھ نہیں کہ ایک کھیل اور دل لگی اور ظاہری ٹیپ ٹاپ اور تمہارا آپس میں ایک دوسرے پر فخر جتانا اور مال و اولاد میں ایک دوسرے سے بڑھ جانے کی کوشش کرنا ہے اس کی مثال ایسی ہے جیسے ایک بارش ہو گئی تو اس سے پیدا ہونے والی نباتات کو دیکھ کر کاشت کار خوش ہو گئے پھر وہی کھیتی پک جاتی ہے اور تم دیکھتے ہو کہ وہ زرد ہو گئی پھر وہ بھس بن کر رہ جاتی ہے اِس کے برعکس آخرت وہ جگہ ہے جہاں سخت عذاب ہے اور اللہ کی مغفرت اور اس کی خوشنودی ہے دنیا کی زندگی ایک دھوکے کی ٹٹی کے سوا کچھ نہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvi{دوڑو اور ایک دوسرے سے آگے بڑھنے کی کوشش کرو اپنے رب کی مغفرت اور اُس کی جنت کی طرف جس کی وسعت آسمان و زمین جیسی ہے، جو مہیا کی گئی ہے اُن لوگوں کے لیے جو اللہ اور اُس کے رسولوں پر ایمان لائے ہوں یہ اللہ کا فضل ہے، جسے چاہتا ہے عطا فرماتا ہے، اور اللہ بڑے فضل والا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvii{کوئی مصیبت ایسی نہیں ہے جو زمین میں یا تمہارے اپنے نفس پر نازل ہوتی ہو اور ہم نے اس کو پیدا کرنے سے پہلے ایک کتاب میں لکھ نہ رکھا ہو ایسا کرنا اللہ کے لیے بہت آسان کام ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcviii{(یہ سب کچھ اس لیے ہے) تاکہ جو کچھ بھی نقصان تمہیں ہو اس پر تم دل شکستہ نہ ہو اور جو کچھ اللہ تمہیں عطا فرمائے اس پر پھول نہ جاؤ اللہ ایسے لوگوں کو پسند نہیں کرتا جو اپنے آپ کو بڑی چیز سمجھتے ہیں اور فخر جتاتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcix{جو خود بخل کرتے ہیں اور دوسروں کو بخل پر اکساتے ہیں اب اگر کوئی رو گردانی کرتا ہے تو اللہ بے نیاز اور ستودہ صفات ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmc{ہم نے اپنے رسولوں کو صاف صاف نشانیوں اور ہدایات کے ساتھ بھیجا، اور اُن کے ساتھ کتاب اور میزان نازل کی تاکہ لوگ انصاف پر قائم ہوں، اور لوہا اتارا جس میں بڑا زور ہے اور لوگوں کے لیے منافع ہیں یہ اس لیے کیا گیا ہے کہ اللہ کو معلوم ہو جائے کہ کون اُس کو دیکھے بغیر اس کی اور اُس کے رسولوں کی مدد کرتا ہے یقیناً اللہ بڑی قوت والا اور زبردست ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmci{ہم نے نوحؑ اور ابراہیمؑ کو بھیجا اور اُن دونوں کی نسل میں نبوت اور کتاب رکھ دی پھر ان کی اولاد میں سے کسی نے ہدایت اختیار کی اور بہت سے فاسق ہو گئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcii{اُن کے بعد ہم نے پے در پے اپنے رسول بھیجے، اور ان سب کے بعد عیسیٰؑ ابن مریم کو مبعوث کیا اور اُس کو انجیل عطا کی اور جن لوگوں نے اس کی پیروی اختیار کی اُن کے دلوں میں ہم نے ترس اور رحم ڈال دیا اور رہبانیت انہوں نے خود ایجاد کرلی، ہم نے اُسے اُن پر فرض نہیں کیا تھا، مگر اللہ کی خوشنودی کی طلب میں انہوں نے آپ ہی یہ بدعت نکالی اور پھر اس کی پابندی کرنے کا جو حق تھا اسے ادا نہ کیا اُن میں سے جو لوگ ایمان لائے ہوئے تھے اُن کا اجر ہم نے ان کو عطا کیا، مگر ان میں سے اکثر لوگ فاسق ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmciii{اے لوگو جو ایمان لائے ہو، اللہ سے ڈرو اور اس کے رسولؐ پر ایمان لاؤ، اللہ تمہیں اپنی رحمت کا دوہرا حصہ عطا فرمائے گا اور تمہیں وہ نور بخشے گا جس کی روشنی میں تم چلو گے، اور تمہارے قصور معاف کر دے گا، اللہ بڑا معاف کرنے والا اور مہربان ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmciv{(تم کو یہ روش اختیار کرنی چاہیے) تاکہ اہل کتاب کو معلوم ہو جائے کہ اللہ کے فضل پر اُن کا کوئی اجارہ نہیں ہے، اور یہ کہ اللہ کا فضل اس کے اپنے ہی ہاتھ میں ہے، جسے چاہتا ہے عطا فرماتا ہے، اور وہ بڑے فضل والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcv{\basmalahur اللہ نے سن لی اُس عورت کی بات جو ا پنے شوہر کے معاملہ میں تم سے تکرار کر رہی ہے اور اللہ سے فریاد کیے جاتی ہے اللہ تم دونوں کی گفتگو سن رہا ہے، وہ سب کچھ سننے اور دیکھنے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvi{تم میں سے جو لوگ اپنی بیویوں سے ظہار کرتے ہیں ان کی بیویاں ان کی مائیں نہیں ہیں، ان کی مائیں تو وہی ہیں جنہوں نے ان کو جنا ہے یہ لوگ ایک سخت ناپسندیدہ اور جھوٹی بات کہتے ہیں، اور حقیقت یہ ہے کہ اللہ بڑا معاف کرنے والا اور درگزر فرمانے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvii{جو لوگ اپنی بیویوں سے ظہار کریں پھر اپنی اُس بات سے رجوع کریں جو انہوں نے کہی تھی، تو قبل اس کے کہ دونوں ایک دوسرے کو ہاتھ لگائیں، ایک غلام آزاد کرنا ہوگا اِس سے تم کو نصیحت کی جاتی ہے، اور جو کچھ تم کرتے ہو اللہ اس سے باخبر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcviii{اور جو شخص غلام نہ پائے وہ دو مہینے کے پے در پے روزے رکھے قبل اس کے کہ دونوں ایک دوسرے کو ہاتھ لگائیں اور جو اس پر بھی قادر نہ ہو وہ ۶۰ مسکینوں کو کھانا کھلائے یہ حکم اس لیے دیا جا رہا ہے کہ تم اللہ اور اُس کے رسول پر ایمان لاؤ یہ اللہ کی مقرر کی ہوئی حدیں ہیں، اور کافروں کے لیے دردناک سزا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcix{جو لوگ اللہ اور اس کے رسول کی مخالفت کرتے ہیں وہ اسی طرح ذلیل و خوار کر دیے جائیں گے جس طرح ان سے پہلے کے لوگ ذلیل و خوار کیے جا چکے ہیں ہم نے صاف صاف آیات نازل کر دی ہیں، اور کافروں کے لیے ذلت کا عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcx{اُس دن (یہ ذلت کا عذاب ہونا ہے) جب اللہ ان سب کو پھر سے زندہ کر کے اٹھائے گا اور انہیں بتا دے گا کہ وہ کیا کچھ کر کے آئے ہیں وہ بھول گئے ہیں مگر اللہ نے ان سب کا کیا دھرا گن گن کر محفوظ کر رکھا ہے اور اللہ ایک ایک چیز پر شاہد ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxi{کیا تم کو خبر نہیں ہے کہ زمین اور آسمانوں کی ہر چیز کا اللہ کو علم ہے؟ کبھی ایسا نہیں ہوتا کہ تین آدمیوں میں کوئی سرگوشی ہو اور ان کے درمیان چوتھا اللہ نہ ہو، یا پانچ آدمیوں میں سرگوشی ہو اور ان کے اندر چھٹا اللہ نہ ہو خفیہ بات کرنے والا خواہ اِس سے کم ہوں یا زیادہ، جہاں کہیں بھی وہ ہوں، اللہ ان کے ساتھ ہوتا ہے پھر قیامت کے روز وہ ان کو بتا دے گا کہ انہوں نے کیا کچھ کیا ہے اللہ ہر چیز کا علم رکھتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxii{کیا تم نے دیکھا نہیں اُن لوگوں کو جنہیں سرگوشیاں کرنے سے منع کر دیا گیا تھا پھر بھی وہ وہی حرکت کیے جاتے ہیں جس سے انہیں منع کیا گیا تھا؟ یہ لوگ چھپ چھپ کر آپس میں گناہ اور زیادتی اور رسول کی نافرمانی کی باتیں کرتے ہیں، اور جب تمہارے پاس آتے ہیں تو تمہیں اُس طریقے سے سلام کرتے ہیں جس طرح اللہ نے تم پر سلام نہیں کیا ہے اور اپنے دلوں میں کہتے ہیں کہ ہماری اِن باتوں پر اللہ ہمیں عذاب کیوں نہیں دیتا اُن کے لیے جہنم ہی کافی ہے اُسی کا وہ ایندھن بنیں گے بڑا ہی برا انجام ہے اُن کا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiii{اے لوگو جو ایمان لائے ہو، جب تم آپس میں پوشیدہ بات کرو تو گناہ اور زیادتی اور رسول کی نافرمانی کی باتیں نہیں بلکہ نیکی اور تقویٰ کی باتیں کرو اور اُس خدا سے ڈرتے رہو جس کے حضور تمہیں حشر میں پیش ہونا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiv{کانا پھوسی تو ایک شیطانی کام ہے، اور وہ اس لیے کی جاتی ہے کہ ایمان لانے والے لوگ اُس سے رنجیدہ ہوں، حالانکہ بے اذن خدا وہ انہیں کچھ بھی نقصان نہیں پہنچا سکتی، اور مومنوں کو اللہ ہی پر بھروسہ رکھنا چاہیے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxv{اے لوگو جو ایمان لائے ہو، جب تم سے کہا جائے کہ اپنی مجلسوں میں کشادگی پیدا کرو تو جگہ کشادہ کر دیا کرو، اللہ تمہیں کشادگی بخشے گا اور جب تم سے کہا جائے کہ اٹھ جاؤ تو اٹھ جایا کرو تم میں سے جو لوگ ایمان رکھنے والے ہیں اور جن کو علم بخشا گیا ہے، اللہ ان کو بلند درجے عطا فرمائے گا، اور جو کچھ تم کرتے ہو اللہ کو اس کی خبر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvi{اے لوگو جو ایمان لائے ہو، جب تم رسول سے تخلیہ میں بات کرو تو بات کرنے سے پہلے کچھ صدقہ دو یہ تمہارے لیے بہتر اور پاکیزہ تر ہے البتہ اگر تم صدقہ دینے کے لیے کچھ نہ پاؤ تو اللہ غفور و رحیم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvii{کیا تم ڈر گئے اس بات سے کہ تخلیہ میں گفتگو کرنے سے پہلے تمہیں صدقات دینے ہونگے؟ اچھا، اگر تم ایسا نہ کرو اور اللہ نے تم کو اس سے معاف کر دیا تو نماز قائم کرتے رہو، زکوٰۃ دیتے رہو اور اللہ اور اس کے رسول کی اطاعت کرتے رہو تم جو کچھ کرتے ہو اللہ اس سے باخبر ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxviii{کیا تم نے دیکھا نہیں اُن لوگوں کو جنہوں نے دوست بنایا ہے ایک ایسے گروہ کو جو اللہ کا مغضوب ہے؟ وہ نہ تمہارے ہیں نہ اُن کے، اور وہ جان بوجھ کر جھوٹی بات پر قسمیں کھاتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxix{اللہ نے ان کے لیے سخت عذاب مہیا کر رکھا ہے، بڑے ہی برے کرتوت ہیں جو وہ کر رہے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxx{اُنہوں نے اپنی قسموں کو ڈھال بنا رکھا ہے جس کی آڑ میں وہ اللہ کی راہ سے لوگوں کو روکتے ہیں، اِس پر ان کے لیے ذلت کا عذاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxi{اللہ سے بچانے کے لیے نہ ان کے مال کچھ کام آئیں گے نہ ان کی اولاد وہ دوزخ کے یار ہیں، اسی میں وہ ہمیشہ رہیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxii{جس روز اللہ ان سب کو اٹھائے گا، وہ اس کے سامنے بھی اُسی طرح قسمیں کھائیں گے جس طرح تمہارے سامنے کھاتے ہیں اور اپنے نزدیک یہ سمجھیں گے کہ اس سے ان کا کچھ کام بن جائے گا خوب جان لو، وہ پرلے درجے کے جھوٹے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiii{شیطان اُن پر مسلط ہو چکا ہے اور ا ُس نے خدا کی یاد اُن کے دل سے بھلا دی ہے وہ شیطان کی پارٹی کے لوگ ہیں خبردار ہو، شیطان کی پارٹی والے ہی خسارے میں رہنے والے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiv{یقیناً ذلیل ترین مخلوقات میں سے ہیں وہ لوگ جو اللہ اور اس کے رسول کا مقابلہ کرتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxv{اللہ نے لکھ دیا ہے کہ میں اور میرے رسول غالب ہو کر رہیں گے فی الواقع اللہ زبردست اور زور آور ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvi{تم کبھی یہ نہ پاؤ گے کہ جو لوگ اللہ اور آخرت پر ایمان رکھنے والے ہیں وہ اُن لوگوں سے محبت کرتے ہوں جنہوں نے اللہ اور اس کے رسول کی مخالفت کی ہے، خواہ وہ اُن کے باپ ہوں، یا اُن کے بیٹے، یا اُن کے بھائی یا اُن کے اہل خاندان یہ وہ لوگ ہیں جن کے دلوں میں اللہ نے ایمان ثبت کر دیا ہے اور اپنی طرف سے ایک روح عطا کر کے ان کو قوت بخشی ہے وہ ان کو ایسی جنتوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی ان میں وہ ہمیشہ رہیں گے اللہ ان سے راضی ہوا اور وہ اللہ سے راضی ہوئے وہ اللہ کی پارٹی کے لوگ ہیں خبردار رہو، اللہ کی پارٹی والے ہی فلاح پانے والے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvii{\basmalahur اللہ ہی کی تسبیح کی ہے ہر اُس چیز نے جو آسمانوں اور زمین میں ہے، اور وہی غالب اور حکیم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxviii{وہی ہے جس نے اہل کتاب کافروں کو پہلے ہی حملے میں اُن کے گھروں سے نکال باہر کیا تمہیں ہرگز یہ گمان نہ تھا کہ وہ نکل جائیں گے، اور وہ بھی یہ سمجھے بیٹھے تھے کہ اُن کی گڑھیاں انہیں اللہ سے بچا لیں گی مگر اللہ ایسے رخ سے اُن پر آیا جدھر اُن کا خیال بھی نہ گیا تھا اُس نے اُن کے دلوں میں رعب ڈال دیا نتیجہ یہ ہوا کہ وہ خود اپنے ہاتھوں سے بھی اپنے گھروں کو برباد کر رہے تھے اور مومنوں کے ہاتھوں بھی برباد کروا رہے تھے پس عبرت حاصل کرو اے دیدہ بینا رکھنے والو!\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxix{اگر اللہ نے اُن کے حق میں جلا وطنی نہ لکھ دی ہوتی تو دنیا ہی میں وہ انہیں عذاب دے ڈالتا، اور آخرت میں تو ان کے لیے دوزخ کا عذاب ہے ہی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxx{یہ سب کچھ اس لیے ہوا کہ انہوں نے اللہ اور اس کے رسول کا مقابلہ کیا، اور جو بھی اللہ کا مقابلہ کرے اللہ اس کو سزا دینے میں بہت سخت ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxi{تم لوگوں نے کھجوروں کے جو درخت کاٹے یا جن کو اپنی جڑوں پر کھڑا رہنے دیا، یہ سب اللہ ہی کے اذن سے تھا اور (اللہ نے یہ اذن اس لیے دیا) تاکہ فاسقوں کو ذلیل و خوار کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxii{اور جو مال اللہ نے اُن کے قبضے سے نکال کر اپنے رسول کی طرف پلٹا دیے، وہ ایسے مال نہیں ہیں جن پر تم نے اپنے گھوڑے اور اونٹ دوڑائے ہوں، بلکہ اللہ اپنے رسولوں کو جس پر چاہتا ہے تسلط عطا فرما دیتا ہے، اور اللہ ہر چیز پر قادر ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiii{جو کچھ بھی اللہ اِن بستیوں کے لوگوں سے اپنے رسول کی طرف پلٹا دے وہ اللہ اور رسول اور رشتہ داروں اور یتامیٰ اور مساکین اور مسافروں کے لیے ہے تاکہ وہ تمہارے مالداروں ہی کے درمیان گردش نہ کرتا رہے جو کچھ رسولؐ تمھیں دے وہ لے لو اور جس چیز سے وہ تم کو روک دے اس سے رک جاؤ اللہ سے ڈرو، اللہ سخت سزا دینے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiv{(نیز وہ مال) اُن غریب مہاجرین کے لیے ہے جو اپنے گھروں اور جائدادوں سے نکال باہر کیے گئے ہیں یہ لوگ اللہ کا فضل اور اس کی خوشنودی چاہتے ہیں اور اللہ اور اُس کے رسولؐ کی حمایت پر کمر بستہ رہتے ہیں یہی راستباز لوگ ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxv{(اور وہ اُن لوگوں کے لیے بھی ہے) جو اِن مہاجرین کی آمد سے پہلے ہی ایمان لا کر دارالحجرت میں مقیم تھے یہ اُن لوگوں سے محبت کرتے ہیں جو ہجرت کر کے اِن کے پاس آئے ہیں اور جو کچھ بھی اُن کو دیدیا جائے اُس کی کوئی حاجت تک یہ اپنے دلوں میں محسوس نہیں کرتے اور اپنی ذات پر دوسروں کو ترجیح دیتے ہیں خواہ اپنی جگہ خود محتاج ہوں حقیقت یہ ہے کہ جو لوگ اپنے دل کی تنگی سے بچا لیے گئے وہی فلاح پانے والے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvi{(اور وہ اُن لوگوں کے لیے بھی ہے) جو اِن اگلوں کے بعد آئے ہیں، جو کہتے ہیں کہ ``اے ہمارے رب، ہمیں اور ہمارے اُن سب بھائیوں کو بخش دے جو ہم سے پہلے ایمان لائے ہیں اور ہمارے دلوں میں اہل ایمان کے لیے کوئی بغض نہ رکھ، اے ہمارے رب، تو بڑا مہربان اور رحیم ہے"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvii{تم نے دیکھا نہیں اُن لوگوں کو جنہوں نے منافقت کی روش اختیار کی ہے؟ یہ اپنے کافر اہل کتاب بھائیوں سے کہتے ہیں ``اگر تمہیں نکالا گیا تو ہم تمہارے ساتھ نکلیں گے، اور تمہارے معاملہ میں ہم کسی کی بات ہرگز نہ مانیں گے، اور اگر تم سے جنگ کی گئی تو ہم تمہاری مدد کریں گے" مگر اللہ گواہ ہے کہ یہ لوگ قطعی جھوٹے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxviii{اگر وہ نکالے گئے تو یہ ان کے ساتھ ہرگز نہ نکلیں گے، اور اگر اُن سے جنگ کی گئی تو یہ اُن کی ہرگز مدد نہ کریں گے، اور اگر یہ ان کی مدد کریں بھی تو پیٹھ پھیر جائیں گے اور پھر کہیں سے کوئی مدد نہ پائیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxix{اِن کے دلوں میں اللہ سے بڑھ کر تمہارا خوف ہے، اس لیے کہ یہ ایسے لوگ ہیں جو سمجھ بوجھ نہیں رکھتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxl{یہ کبھی اکٹھے ہو کر (کھلے میدان میں) تمہارا مقابلہ نہ کریں گے، لڑیں گے بھی تو قلعہ بند بستیوں میں بیٹھ کر یا دیواروں کے پیچھے چھپ کر یہ آپس کی مخالفت میں بڑے سخت ہیں تم اِنہیں اکٹھا سمجھتے ہو مگر ان کے دل ایک دوسرے سے پھٹے ہوئے ہیں اِن کا یہ حال اِس لیے ہے کہ یہ بے عقل لوگ ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxli{یہ اُنہی لوگوں کے مانند ہیں جو اِن سے تھوڑی ہی مدت پہلے اپنے کیے کا مزا چکھ چکے ہیں اور اِن کے لیے دردناک عذاب ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlii{اِن کی مثال شیطان کی سی ہے کہ پہلے وہ انسان سے کہتا ہے کہ کفر کر، اور جب انسان کفر کر بیٹھتا ہے تو وہ کہتا ہے کہ میں تجھ سے بری الذمہ ہوں، مجھے تو اللہ رب العالمین سے ڈر لگتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliii{پھر دونوں کا انجام یہ ہونا ہے کہ ہمیشہ کے لیے جہنم میں جائیں، اور ظالموں کی یہی جزا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliv{اے لوگو جو ایمان لائے ہو، اللہ سے ڈرو، اور ہر شخص یہ دیکھے کہ اُس نے کل کے لیے کیا سامان کیا ہے اللہ سے ڈرتے رہو، اللہ یقیناً تمہارے اُن سب اعمال سے باخبر ہے جو تم کرتے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlv{اُن لوگوں کی طرح نہ ہو جاؤ جو اللہ کو بھول گئے تو اللہ نے اُنہیں خود اپنا نفس بھلا دیا، یہی لوگ فاسق ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvi{دوزخ میں جانے والے اور جنت میں جانے والے کبھی یکساں نہیں ہو سکتے جنت میں جانے والے ہی اصل میں کامیاب ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvii{اگر ہم نے یہ قرآن کسی پہاڑ پر بھی اتار دیا ہوتا تو تم دیکھتے کہ وہ اللہ کے خوف سے دبا جا رہا ہے اور پھٹا پڑتا ہے یہ مثالیں ہم لوگوں کے سامنے اس لیے بیان کرتے ہیں کہ وہ (اپنی حالت پر) غور کریں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlviii{وہ اللہ ہی ہے جس کے سوا کوئی معبود نہیں، غائب اور ظاہر ہر چیز کا جاننے والا، وہی رحمٰن اور رحیم ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlix{وہ اللہ ہی ہے جس کے سوا کوئی معبود نہیں وہ بادشاہ ہے نہایت مقدس، سراسر سلامتی، امن دینے والا، نگہبان، سب پر غالب، اپنا حکم بزور نافذ کرنے والا، اور بڑا ہی ہو کر رہنے والا پاک ہے اللہ اُس شرک سے جو لوگ کر رہے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcl{وہ اللہ ہی ہے جو تخلیق کا منصوبہ بنانے والا اور اس کو نافذ کرنے والا اور اس کے مطابق صورت گری کرنے والا ہے اس کے لیے بہترین نام ہیں ہر چیز جو آسمانوں اور زمین میں ہے اُس کی تسبیح کر رہی ہے، اور وہ زبردست اور حکیم ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcli{\basmalahur اے لوگو جو ایمان لائے ہو، اگر تم میری راہ میں جہاد کرنے کے لیے اور میری رضا جوئی کی خاطر (وطن چھوڑ کر گھروں سے) نکلے ہو تو میرے اور اپنے دشمنوں کو دوست نہ بناؤ تم اُن کے ساتھ دوستی کی طرح ڈالتے ہو، حالانکہ جو حق تمہارے پاس آیا ہے اُس کو ماننے سے وہ انکار کر چکے ہیں اور اُن کی روش یہ ہے کہ رسول کو اور خود تم کو صرف اِس قصور پر جلا وطن کرتے ہیں کہ تم اپنے رب، اللہ پر ایمان لائے ہو تم چھپا کر اُن کو دوستانہ پیغام بھیجتے ہو، حالانکہ جو کچھ تم چھپا کر کرتے ہو اور جو علانیہ کرتے ہو، ہر چیز کو میں خوب جانتا ہوں جو شخص بھی تم میں سے ایسا کرے وہ یقیناً راہ راست سے بھٹک گیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclii{اُن کا رویہ تو یہ ہے کہ اگر تم پر قابو پا جائیں تو تمہارے ساتھ دشمنی کریں اور ہاتھ اور زبان سے تمہیں آزار دیں وہ تو یہ چاہتے ہیں کہ تم کسی طرح کافر ہو جاؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliii{قیامت کے دن نہ تمہاری رشتہ داریاں کسی کام آئیں گی نہ تمہاری اولاد اُس روز اللہ تمہارے درمیان جدائی ڈال دے گا، اور و ہی تمہارے اعمال کا دیکھنے والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliv{تم لوگوں کے لیے ابراہیمؑ اور اُس کے ساتھیوں میں ایک اچھا نمونہ ہے کہ اُنہوں نے اپنی قوم سے صاف کہہ دیا ``ہم تم سے اور تمہارے اِن معبودوں سے جن کو تم خدا کو چھوڑ کر پوجتے ہو قطعی بیزار ہیں، ہم نے تم سے کفر کیا اور ہمارے اور تمہارے درمیان ہمیشہ کے لیے عداوت ہو گئی اور بیر پڑ گیا جب تک تم اللہ واحد پر ایمان نہ لاؤ" مگر ابراہیمؑ کا اپنے باپ سے یہ کہنا (اِس سے مستثنیٰ ہے) کہ ``میں آپ کے لیے مغفرت کی درخواست ضرور کروں گا، اور اللہ سے آپ کے لیے کچھ حاصل کر لینا میرے بس میں نہیں ہے" (اور ابراہیمؑ و اصحاب ابراہیمؑ کی دعا یہ تھی کہ) ``اے ہمارے رب، تیرے ہی اوپر ہم نے بھروسا کیا اور تیری ہی طرف ہم نے رجوع کر لیا اور تیرے ہی حضور ہمیں پلٹنا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclv{اے ہمارے رب، ہمیں کافروں کے لیے فتنہ نہ بنا دے اور اے ہمارے رب، ہمارے قصوروں سے درگزر فرما، بے شک تو ہی زبردست اور دانا ہے"\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvi{اِنہی لوگوں کے طرز عمل میں تمہارے لیے اور ہر اُس شخص کے لیے اچھا نمونہ ہے جو اللہ اور روز آخر کا امیدوار ہو اِس سے کوئی منحرف ہو تو اللہ بے نیاز اور اپنی ذات میں آپ محمود ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvii{بعید نہیں کہ اللہ کبھی تمہارے اور اُن لوگوں کے درمیان محبت ڈال دے جن سے آج تم نے دشمنی مول لی ہے اللہ بڑی قدرت رکھتا ہے اور وہ غفور و رحیم ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclviii{اللہ تمیں اس بات سے نہیں روکتا کہ تم ان لوگوں کے ساتھ نیکی اور انصاف کا برتاؤ کرو جنہوں نے دین کے معاملہ میں تم سے جنگ نہیں کی ہے اور تمہیں تمہارے گھروں سے نہیں نکالا ہے اللہ انصاف کرنے والوں کو پسند کرتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclix{وہ تمہیں جس بات سے روکتا ہے وہ تو یہ ہے کہ تم اُن لوگوں سے دوستی کرو جنہوں نے تم سے دین کے معاملہ میں جنگ کی ہے اور تمہیں تمہارے گھروں سے نکالا ہے اور تمہارے اخراج میں ایک دوسرے کی مدد کی ہے اُن سے جو لوگ دوستی کریں وہی ظالم ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclx{اے لوگو جو ایمان لائے ہو، جب مومن عورتیں ہجرت کر کے تمہارے پاس آئیں تو (ان کے مومن ہونے کی) جانچ پڑتال کر لو، اور ان کے ایمان کی حقیقت اللہ ہی بہتر جانتا ہے پھر جب تمہیں معلوم ہو جائے کہ وہ مومن ہیں تو انہیں کفار کی طرف واپس نہ کرو نہ وہ کفار کے لیے حلال ہیں اور نہ کفار ان کے لیے حلال ان کے کافر شوہروں نے جو مہر اُن کو دیے تھے وہ انہیں پھیر دو اور ان سے نکاح کر لینے میں تم پر کوئی گناہ نہیں جبکہ تم اُن کے مہر اُن کو ادا کر دو اور تم خود بھی کافر عورتوں کو اپنے نکاح میں نہ روکے رہو جو مہر تم نے اپنی کافر بیویوں کو دیے تھے وہ تم واپس مانگ لو اور جو مہر کافروں نے اپنی مسلمان بیویوں کو دیے تھے انہیں وہ واپس مانگ لیں یہ اللہ کا حکم ہے، وہ تمہارے درمیان فیصلہ کرتا ہے اور اللہ علیم و حکیم ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxi{اور اگر تمہاری کافر بیویوں کے مہروں میں سے کچھ تمہیں کفار سے واپس نہ ملے اور پھر تمہاری نوبت آئے تو جن لوگوں کی بیویاں ادھر رہ گئی ہیں اُن کو اتنی رقم ادا کر دو جو اُن کے دیے ہوئے مہروں کے برابر ہو اور اُس خدا سے ڈر تے رہو جس پر تم ایمان لائے ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxii{اے نبیؐ، جب تمہارے پاس مومن عورتیں بیعت کرنے کے لیے آئیں اور اس بات کا عہد کریں کہ وہ اللہ کے ساتھ کسی چیز کو شریک نہ کریں گی، چوری نہ کریں گی، زنا نہ کریں گی، اپنی اولاد کو قتل نہ کریں گی، اپنے ہاتھ پاؤں کے آگے کوئی بہتان گھڑ کر نہ لائیں گی، اور کسی امر معروف میں تمہاری نافرمانی نہ کریں گی، تو ان سے بیعت لے لو اور اُن کے حق میں اللہ سے دعائے مغفرت کرو، یقیناً اللہ درگزر فرمانے والا اور رحم کرنے والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiii{اے لوگو جو ایمان لائے ہو، اُن لوگوں کو دوست نہ بناؤ جن پر اللہ نے غضب فرمایا ہے، جو آخرت سے اسی طرح مایوس ہیں جس طرح قبروں میں پڑے ہوئے کافر مایوس ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiv{\basmalahur اللہ کی تسبیح کی ہے ہر اُس چیز نے جو آسمانوں اور زمین میں ہے، اور وہ غالب اور حکیم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxv{اے لوگو جو ایمان لائے ہو، تم کیوں وہ بات کہتے ہو جو کرتے نہیں ہو؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvi{اللہ کے نزدیک یہ سخت ناپسندیدہ حرکت ہے کہ تم کہو وہ بات جو کرتے نہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvii{اللہ کو تو پسند وہ لوگ ہیں جو اس کی راہ میں اس طرح صف بستہ ہو کر لڑتے ہیں گویا کہ وہ ایک سیسہ پلائی ہوئی دیوار ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxviii{اور یاد کرو موسیٰؑ کی وہ بات جو اس نے اپنی قوم سے کہی تھی ``اے میری قوم کے لوگو، تم کیوں مجھے اذیت دیتے ہو حالانکہ تم خوب جانتے ہو کہ میں تمہاری طرف اللہ کا بھیجا ہوا رسول ہوں؟" پھر جب انہوں نے ٹیڑھ اختیار کی تو اللہ نے ان کے دل ٹیڑھے کر دیے، اللہ فاسقوں کو ہدایت نہیں دیتا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxix{اور یاد کرو عیسیٰؑ ابن مریمؑ کی وہ بات جو اس نے کہی تھی کہ ``اے بنی اسرائیل، میں تمہاری طرف اللہ کا بھیجا ہوا رسول ہوں، تصدیق کرنے والا ہوں اُس توراۃ کی جو مجھ سے پہلے آئی ہوئی موجود ہے، اور بشارت دینے والا ہوں ایک رسول کی جو میرے بعد آئے گا جس کا نام احمد ہوگا مگر جب وہ ان کے پاس کھلی کھلی نشانیاں لے کر آیا تو انہوں نے کہا یہ تو صریح دھوکا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxx{اب بھلا اُس شخص سے بڑا ظالم اور کون ہوگا جو اللہ پر جھوٹے بہتان باندھے حالانکہ اسے اسلام (اللہ کے آگے سر اطاعت جھکا دینے) کی دعوت دی جا رہی ہو؟ ایسے ظالموں کو اللہ ہدایت نہیں دیا کرتا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxi{یہ لوگ اپنے منہ کی پھونکوں سے اللہ کے نور کو بجھانا چاہتے ہیں، اور اللہ کا فیصلہ یہ ہے کہ وہ اپنے نور کو پوا پھیلا کر رہے گا خواہ کافروں کو یہ کتنا ہی ناگوار ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxii{وہی تو ہے جس نے اپنے رسول کو ہدایت اور دین حق کے ساتھ بھیجا ہے تاکہ اسے پورے کے پورے دین پر غالب کر دے خواہ مشرکین کو یہ کتنا ہی ناگوار ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiii{اے لوگو جو ایمان لائے ہو، میں بتاؤں تم کو وہ تجارت جو تمہیں عذاب الیم سے بچا دے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiv{ایمان لاؤ اللہ اور اس کے رسول پر، اور جہاد کرو اللہ کی راہ میں اپنے مالوں سے اور اپنی جانوں سے یہی تمہارے لیے بہتر ہے اگر تم جانو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxv{اللہ تمہارے گناہ معاف کر دے گا، اور تم کو ایسے باغوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی، اور ابدی قیام کی جنتوں میں بہترین گھر تمہیں عطا فرمائے گا یہ ہے بڑی کامیابی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvi{اور وہ دوسری چیز جو تم چاہتے ہو وہ بھی تمہیں دے گا، اللہ کی طرف سے نصرت اور قریب ہی میں حاصل ہو جانے والی فتح اے نبیؐ، اہل ایمان کو اِس کی بشارت دے دو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvii{اے لوگو جو ایمان لائے ہو، اللہ کے مددگار بنو، جس طرح عیسیٰ ابن مریمؑ نے حواریوں کو خطاب کر کے کہا تھا: ``کون ہے اللہ کی طرف (بلانے) میں میرا مددگار؟" اور حواریوں نے جواب دیا تھا: ``ہم ہیں اللہ کے مددگار" اُس وقت بنی اسرائیل کا ایک گروہ ایمان لایا اور دوسرے گروہ نے انکار کیا پھر ہم نے ایمان لانے والوں کی اُن کے دشمنوں کے مقابلے میں تائید کی اور وہی غالب ہو کر رہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxviii{\basmalahur اللہ کی تسبیح کر رہی ہے ہر وہ چیز جو آسمانوں میں ہے اور ہر وہ چیز جو زمین میں ہے بادشاہ ہے، قدوس ہے، زبردست اور حکیم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxix{وہی ہے جس نے امیوں کے اندر ایک رسول خود اُنہی میں سے اٹھایا، جو اُنہیں اُس کی آیات سناتا ہے، اُن کی زندگی سنوارتا ہے، اور اُن کو کتاب اور حکمت کی تعلیم دیتا ہے حالانکہ اِس سے پہلے وہ کھلی گمراہی میں پڑے ہوئے تھے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxx{اور (اس رسول کی بعثت) اُن دوسرے لوگوں کے لیے بھی ہے جو ابھی اُن سے نہیں ملے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxi{اللہ زبردست اور حکیم ہے یہ اس کا فضل ہے، جسے چاہتا ہے دیتا ہے، اور وہ بڑا فضل فرمانے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxii{جن لوگوں کو توراۃ کا حامل بنایا گیا تھا مگر انہوں نے اس کا بار نہ اٹھا یا، اُن کی مثال اُس گدھے کی سی ہے جس پر کتابیں لدی ہوئی ہوں اِس سے بھی زیادہ بری مثال ہے اُن لوگوں کی جنہوں نے اللہ کی آیات کو جھٹلا دیا ہے ایسے ظالموں کو اللہ ہدایت نہیں دیا کرتا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiii{اِن سے کہو، ``اے لوگو جو یہودی بن گئے ہو، اگر تمہیں یہ گھمنڈ ہے کہ باقی سب لوگوں کو چھوڑ کر بس تم ہی اللہ کے چہیتے ہو تو موت کی تمنا کرو اگر تم اپنے اِس زعم میں سچے ہو"\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiv{لیکن یہ ہرگز اس کی تمنا نہ کریں گے اپنے کرتوتوں کی وجہ سے جو یہ کر چکے ہیں، اور اللہ اِن ظالموں کو خوب جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxv{اِن سے کہو، ``جس موت سے تم بھاگتے ہو وہ تو تمہیں آ کر رہے گی پھر تم اس کے سامنے پیش کیے جاؤ گے جو پوشیدہ و ظاہر کا جاننے والا ہے، اور وہ تمہیں بتا دے گا کہ تم کیا کچھ کرتے رہے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvi{اے لوگو جو ایمان لائے ہو، جب پکارا جائے نماز کے لیے جمعہ کے دن تو اللہ کے ذکر کی طرف دوڑو اور خرید و فروخت چھوڑ دو، یہ تمہارے لیے زیادہ بہتر ہے اگر تم جانو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvii{پھر جب نماز پوری ہو جائے تو زمین میں پھیل جاؤ اور اللہ کا فضل تلاش کرو اور اللہ کو کثرت سے یاد کرتے رہو، شاید کہ تمہیں فلاح نصیب ہو جائے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxviii{اور جب انہوں نے تجارت اور کھیل تماشا ہوتے دیکھا تو اس کی طرف لپک گئے اور تمہیں کھڑا چھوڑ دیا ان سے کہو، جو کچھ اللہ کے پاس ہے وہ کھیل تماشے اور تجارت سے بہتر ہے اور اللہ سب سے بہتر رزق دینے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxix{\basmalahur اے نبیؐ، جب یہ منافق تمہارے پاس آتے ہیں تو کہتے ہیں ``ہم گواہی دیتے ہیں کہ آ پ یقیناً اللہ کے رسول ہیں" ہاں، اللہ جانتا ہے کہ تم ضرور اُس کے رسول ہو، مگر اللہ گواہی دیتا ہے کہ یہ منافق قطعی جھوٹے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxc{انہوں نے اپنی قسموں کو ڈھال بنا رکھا ہے اور اِس طرح یہ اللہ کے راستے سے خود رکتے اور دنیا کو روکتے ہیں کیسی بری حرکتیں ہیں جو یہ لوگ کر رہے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxci{یہ سب کچھ اس وجہ سے ہے کہ ان لوگوں نے ایمان لا کر پھر کفر کیا اس لیے ان کے دلوں پر مہر لگا دی گئی، اب یہ کچھ نہیں سمجھتے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcii{اِنہیں دیکھو تو اِن کے جثے تمہیں بڑے شاندار نظر آئیں بولیں تو تم ان کی باتیں سنتے رہ جاؤ مگر اصل میں یہ گویا لکڑی کے کندے ہیں جو دیوار کے ساتھ چن کر رکھ دیے گئے ہوں ہر زور کی آواز کو یہ اپنے خلاف سمجھتے ہیں یہ پکے دشمن ہیں، ان سے بچ کر رہو، اللہ کی مار ان پر، یہ کدھر الٹے پھرائے جا رہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciii{اور جب اِن سے کہا جاتا ہے کہ آؤ تاکہ اللہ کا رسول تمہارے لیے مغفرت کی دعا کرے، تو سر جھٹکتے ہیں اور تم دیکھتے ہو کہ وہ بڑے گھمنڈ کے ساتھ آنے سے رکتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciv{اے نبیؐ، تم چاہے ان کے لیے مغفرت کی دعا کرو یا نہ کرو، ان کے لیے یکساں ہے، اللہ ہرگز انہیں معاف نہ کرے گا، اللہ فاسق لوگوں کو ہرگز ہدایت نہیں دیتا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcv{یہ وہی لوگ ہیں جو کہتے ہیں کہ رسول کے ساتھیوں پر خرچ کرنا بند کر دو تاکہ یہ منتشر ہو جائیں حالانکہ زمین اور آسمانوں کے خزانوں کا مالک اللہ ہی ہے، مگر یہ منافق سمجھتے نہیں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvi{یہ کہتے ہیں کہ ہم مدینے واپس پہنچ جائیں تو جو عزت والا ہے وہ ذلیل کو وہاں سے نکال باہر کرے گا حالانکہ عزت تو اللہ اور اس کے رسولؐ اور مومنین کے لیے ہے، مگر یہ منافق جانتے نہیں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvii{اے لوگو جو ایمان لائے ہو، تمہارے مال اور تمہاری اولادیں تم کو اللہ کی یاد سے غافل نہ کر دیں جو لوگ ایسا کریں وہی خسارے میں رہنے والے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcviii{جو رزق ہم نے تمہیں دیا ہے اس میں سے خرچ کرو قبل اس کے کہ تم میں سے کسی کی موت کا وقت آ جائے اور اُس وقت وہ کہے کہ ``اے میرے رب، کیوں نہ تو نے مجھے تھوڑی سی مہلت اور دے دی کہ میں صدقہ دیتا اور صالح لوگوں میں شامل ہو جاتا"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcix{حالانکہ جب کسی کی مہلت عمل پوری ہونے کا وقت آ جاتا ہے تو اللہ اُس کو ہرگز مزید مہلت نہیں دیتا، اور جو کچھ تم کرتے ہو، اللہ اس سے باخبر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcc{\basmalahur اللہ کی تسبیح کر رہی ہے ہر وہ چیز جو آسمانوں میں ہے اور ہر وہ چیز جو زمین میں ہے اسی کی بادشاہی ہے اور اسی کے لیے تعریف ہے اور وہ ہر چیز پر قادر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcci{وہی ہے جس نے تم کو پیدا کیا، پھر تم میں سے کوئی کافر ہے اور کوئی مومن، اور اللہ وہ سب کچھ دیکھ رہا ہے جو تم کرتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccii{اس نے زمین اور آسمانوں کو برحق پیدا کیا ہے، اور تمہاری صورت بنائی اور بڑی عمدہ بنائی ہے، اور اسی کی طرف آخرکار تمہیں پلٹنا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciii{زمین اور آسمانوں کی ہر چیز کا اسے علم ہے جو کچھ تم چھپاتے ہو اور جو کچھ تم ظاہر کرتے ہو سب اس کو معلوم ہے، اور وہ دلوں کا حال تک جانتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciv{کیا تمہیں اُن لوگوں کی کوئی خبر نہیں پہنچی جنہوں نے اِس سے پہلے کفر کیا اور پھر اپنی شامت اعمال کا مزہ چکھ لیا؟ اور آگے اُن کے لیے ایک دردناک عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccv{اِس انجام کے مستحق وہ اس لیے ہوئے کہ اُن کے پاس اُن کے رسول کھلی کھلی دلیلیں اور نشانیاں لے کر آتے رہے، مگر اُنہوں نے کہا ``کیا انسان ہمیں ہدایت دیں گے؟" اس طرح انہوں نے ماننے سے انکار کر دیا اور منہ پھیر لیا، تب اللہ بھی ان سے بے پروا ہو گیا اور اللہ تو ہے ہی بے نیاز اور اپنی ذات میں آپ محمود\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvi{منکرین نے بڑے دعوے سے کہا ہے کہ وہ مرنے کے بعد ہرگز دوبارہ نہ اٹھائے جائیں گے ان سے کہو ``نہیں، میرے رب کی قسم تم ضرور اٹھائے جاؤ گے، پھر ضرور تمہیں بتایا جائے گا کہ تم نے (دنیا میں) کیا کچھ کیا ہے، اور ایسا کرنا اللہ کے لیے بہت آسان ہے"\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvii{پس ایمان لاؤ اللہ پر، اور اُس کے رسول پر، اور اُس روشنی پر جو ہم نے نازل کی ہے جو کچھ تم کرتے ہو اللہ اس سے باخبر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccviii{(اِس کا پتا تمہیں اس روز چل جائے گا) جب اجتماع کے دن وہ تم سب کو اکٹھا کرے گا وہ دن ہوگا ایک دوسرے کے مقابلے میں لوگوں کی ہار جیت کا جو اللہ پر ایمان لایا ہے اور نیک عمل کرتا ہے، اللہ اس کے گناہ جھاڑ دے گا اور اسے ایسی جنتوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی یہ لوگ ہمیشہ ہمیشہ ان میں رہیں گے یہ بڑی کامیابی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccix{اور جن لوگوں نے کفر کیا ہے اور ہماری آیات کو جھٹلایا ہے وہ دوزخ کے باشندے ہوں گے جس میں وہ ہمیشہ رہیں گے اور وہ بدترین ٹھکانا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccx{کوئی مصیبت کبھی نہیں آتی مگر اللہ کے اذن ہی سے آتی ہے جو شخص اللہ پر ایمان رکھتا ہو اللہ اس کے دل کو ہدایت بخشتا ہے، اور اللہ کو ہر چیز کا علم ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxi{اللہ کی اطاعت کرو اور رسول کی طاعت کرو لیکن اگر تم اطاعت سے منہ موڑتے ہو تو ہمارے رسول پر صاف صاف حق پہنچا دینے کے سوا کوئی ذمہ داری نہیں ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxii{اللہ وہ ہے جس کے سوا کوئی خدا نہیں، لہٰذا ایمان لانے والوں کو اللہ ہی پر بھروسا رکھنا چاہیے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiii{اے لوگو جو ایمان لائے ہو، تمہاری بیویوں اور تمہاری اولاد میں سے بعض تمہارے دشمن ہیں، ان سے ہوشیار رہو اور اگر تم عفو و درگزر سے کام لو اور معاف کر دو تو اللہ غفور و رحیم ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiv{تمہارے مال اور تمہاری اولاد تو ایک آزمائش ہیں، اور اللہ ہی ہے جس کے پاس بڑا اجر ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxv{لہٰذا جہاں تک تمہارے بس میں ہو اللہ سے ڈرتے رہو، اور سنو اور اطاعت کرو، اور اپنے مال خرچ کرو، یہ تمہارے ہی لیے بہتر ہے جو اپنے دل کی تنگی سے محفوظ رہ گئے بس وہی فلاح پانے والے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvi{اگر تم اللہ کو قرض حسن دو تو وہ تمہیں کئی گنا بڑھا کر دے گا اور تمہارے قصوروں سے درگزر فرمائے گا، اللہ بڑا قدردان اور بردبار ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvii{حاضر اور غائب ہر چیز کو جانتا ہے، زبردست اور دانا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxviii{\basmalahur اے نبیؐ، جب تم لوگ عورتوں کو طلاق دو تو اُنہیں اُن کی عدت کے لیے طلاق دیا کرو اور عدت کے زمانے کا ٹھیک ٹھیک شمار کرو، اور اللہ سے ڈرو جو تمہارا رب ہے (زمانہ عدت میں) نہ تم اُنہیں اُن کے گھروں سے نکالو اور نہ وہ خود نکلیں، الا یہ کہ وہ کسی صریح برائی کی مرتکب ہوں یہ اللہ کی مقرر کردہ حدیں ہیں، اور جو کوئی اللہ کی حدوں سے تجاوز کرے گا وہ اپنے اوپر خود ظلم کرے گا تم نہیں جانتے، شاید اس کے بعد اللہ (موافقت کی) کوئی صورت پیدا کر دے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxix{پھر جب وہ اپنی (عدت کی) مدت کے خاتمہ پر پہنچیں تو یا انہیں بھلے طریقے سے (اپنے نکاح میں) روک ر کھو، یا بھلے طریقے پر اُن سے جدا ہو جاؤ اور دو ایسے آدمیوں کو گواہ بنا لو جو تم میں سے صاحب عدل ہوں اور (اے گواہ بننے والو) گواہی ٹھیک ٹھیک اللہ کے لیے ادا کرو یہ باتیں ہیں جن کی تم لوگوں کو نصیحت کی جاتی ہے، ہر اُس شخص کو جو اللہ اور آخرت کے دن پر ایمان رکھتا ہو جو کوئی اللہ سے ڈرتے ہوئے کام کرے گا اللہ اُس کے لیے مشکلات سے نکلنے کا کوئی راستہ پیدا کر دے گا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxx{اور اسے ایسے راستے سے رزق دے گا جدھر اُس کا گمان بھی نہ جاتا ہو جو اللہ پر بھروسا کرے اس کے لیے وہ کافی ہے اللہ اپنا کام پورا کر کے رہتا ہے اللہ نے ہر چیز کے لیے ایک تقدیر مقرر کر رکھی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxi{اور تمہاری عورتوں میں سے جو حیض سے مایوس ہو چکی ہوں ان کے معاملہ میں اگر تم لوگوں کو کوئی شک لاحق ہے تو (تمہیں معلوم ہو کہ) ان کی عدت تین مہینے ہے اور یہی حکم اُن کا ہے جنہیں ابھی حیض نہ آیا ہو اور حاملہ عورتوں کی عدت کی حد یہ ہے کہ اُن کا وضع حمل ہو جائے جو شخص اللہ سے ڈرے اُس کے معاملہ میں وہ سہولت پیدا کر دیتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxii{یہ اللہ کا حکم ہے جو اُس نے تمہاری طرف نازل کیا ہے جو اللہ سے ڈرے گا اللہ اس کی برائیوں کو اس سے دور کر دے گا اور اس کو بڑا اجر دے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiii{اُن کو (زمانہ عدت میں) اُسی جگہ رکھو جہاں تم رہتے ہو، جیسی کچھ بھی جگہ تمہیں میسر ہو اور انہیں تنگ کرنے کے لیے ان کو نہ ستاؤ اور اگر وہ حاملہ ہوں تو ان پر اُس وقت تک خرچ کرتے رہو جب تک ان کا وضع حمل نہ ہو جائے پھر اگر وہ تمہارے لیے (بچے کو) دودھ پلائیں تو ان کی اجرت انہیں دو، اور بھلے طریقے سے (اجرت کا معاملہ) باہمی گفت و شنید سے طے کر لو لیکن اگر تم نے (اجرت طے کرنے میں) ایک دوسرے کو تنگ کیا تو بچے کو کوئی اور عورت دودھ پلا لے گی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiv{خوشحال آدمی اپنی خوشحالی کے مطابق نفقہ دے، اور جس کو رزق کم دیا گیا ہو وہ اُسی مال میں سے خرچ کرے جو اللہ نے اسے دیا ہے اللہ نے جس کو جتنا کچھ دیا ہے اس سے زیادہ کا وہ اُسے مکلف نہیں کرتا بعید نہیں کہ اللہ تنگ دستی کے بعد فراخ دستی بھی عطا فرما دے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxv{کتنی ہی بستیاں ہیں جنہوں نے اپنے رب اور اس کے رسولوں کے حکم سے سرتابی کی تو ہم نے ان سے سخت محاسبہ کیا اور ان کو بری طرح سزا دی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvi{انہوں نے اپنے کیے کا مزا چکھ لیا اور اُن کا انجام کار گھاٹا ہی گھاٹا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvii{اللہ نے (آخرت میں) ان کے لیے سخت عذاب مہیا کر رکھا ہے پس اللہ سے ڈرو اے صاحب عقل لوگو جو ایمان لائے ہو اللہ نے تمہاری طرف ایک نصیحت نازل کر دی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxviii{ایک ایسا رسو ل جو تم کو اللہ کی صاف صاف ہدایت دینے والی آیات سناتا ہے تاکہ ایمان لانے والوں اور نیک عمل کرنے والوں کو تاریکیوں سے نکال کر روشنی میں لے آئے جو کوئی اللہ پر ایمان لائے اور نیک عمل کرے، اللہ اُسے ایسی جنتوں میں داخل کرے گا جن کے نیچے نہریں بہتی ہوں گی یہ لوگ ان میں ہمیشہ ہمیشہ رہیں گے اللہ نے ایسے شخص کے لیے بہترین رزق رکھا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxix{اللہ وہ ہے جس نے سات آسمان بنائے اور زمین کی قسم سے بھی اُنہی کے مانند ان کے درمیان حکم نازل ہوتا رہتا ہے (یہ بات تمہیں اس لیے بتائی جا رہی ہے) تاکہ تم جان لو کہ اللہ ہر چیز پر قدرت رکھتا ہے، اور یہ کہ اللہ کا علم ہر چیز پر محیط ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxx{\basmalahur اے نبیؐ، تم کیوں اُس چیز کو حرام کرتے ہو جو اللہ نے تمہارے لیے حلال کی ہے؟ (کیا اس لیے کہ) تم اپنی بیویوں کی خوشی چاہتے ہو؟ اللہ معاف کرنے والا اور رحم فرمانے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxi{اللہ نے تم لوگوں کے لیے اپنی قسموں کی پابندی سے نکلنے کا طریقہ مقرر کر دیا ہے اللہ تمہارا مولیٰ ہے، اور وہی علیم و حکیم ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxii{(اور یہ معاملہ بھی قابل توجہ ہے کہ) نبیؐ نے ایک بات اپنی ایک بیوی سے راز میں کہی تھی پھر جب اُس بیوی نے (کسی اور پر) وہ راز ظاہر کر دیا، اور اللہ نے نبیؐ کو اِس (افشائے راز) کی اطلاع دے دی، تو نبیؐ نے اس پر کسی حد تک (اُس بیوی کو) خبردار کیا اور کسی حد تک اس سے درگزر کیا پھر جب نبیؐ نے اُسے (افشائے راز کی) یہ بات بتائی تو اُس نے پوچھا آپ کو اِس کی کس نے خبر دی؟ نبیؐ نے کہا، ``مجھے اُس نے خبر دی جو سب کچھ جانتا ہے اور خوب باخبر ہے"\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiii{اگر تم دونوں اللہ سے توبہ کرتی ہو (تو یہ تمہارے لیے بہتر ہے) کیونکہ تمہارے دل سیدھی راہ سے ہٹ گئے ہیں، اور اگر نبی کے مقابلہ میں تم نے باہم جتھہ بندی کی تو جان رکھو کہ اللہ اُس کا مولیٰ ہے اور اُس کے بعد جبریل اور تمام صالح اہل ایمان اور سب ملائکہ اس کے ساتھی اور مددگار ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiv{بعید نہیں کہ اگر نبیؐ تم سب بیویوں کو طلاق دیدے تو اللہ اسے ایسی بیویاں تمہارے بدلے میں عطا فرما دے جو تم سے بہتر ہوں، سچی مسلمان، با ایمان، اطاعت گزار، توبہ گزار، عبادت گزار، اور روزہ دار، خواہ شوہر دیدہ ہوں یا باکرہ\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxv{اے لوگو جو ایمان لائے ہو، بچاؤ اپنے آپ کو اور اپنے اہل و عیال کو اُس آگ سے جس کا ایندھن انسان اور پتھر ہوں گے جس پر نہایت تند خو اور سخت گیر فرشتے مقرر ہوں گے جو کبھی اللہ کے حکم کی نافرمانی نہیں کرتے اور جو حکم بھی انہیں دیا جاتا ہے اسے بجا لاتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvi{(اُس وقت کہا جائے گا کہ) اے کافرو، آج معذرتیں پیش نہ کرو، تہیں تو ویسا ہی بدلہ دیا جا رہا ہے جیسے تم عمل کر رہے تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvii{اے لوگو جو ایمان لائے ہو، اللہ سے توبہ کرو، خالص توبہ، بعید نہیں کہ اللہ تمہاری برائیاں تم سے دور کر دے اور تمہیں ایسی جنتوں میں داخل فرما دے جن کے نیچے نہریں بہہ رہی ہوں گی یہ وہ دن ہوگا جب اللہ اپنے نبی کو اور اُن لوگوں جو اس کے ساتھ ایمان لائے ہیں رسوا نہ کرے گا اُن کا نور اُن کے آگے آگے اور ان کے دائیں جانب دوڑ رہا ہوگا اور وہ کہہ رہے ہوں گے کہ اے ہمارے رب، ہمارا نور ہمارے لیے مکمل کر دے اور ہم سے درگزر فرما، تو ہر چیز پر قدرت رکھتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxviii{اے نبیؐ، کفار اور منافقین سے جہاد کرو اور ان کے ساتھ سختی سے پیش آؤ ان کا ٹھکانا جہنم ہے اور وہ بہت برا ٹھکانا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxix{اللہ کافروں کے معاملے میں نوحؑ اور لوطؑ کی بیویوں کو بطور مثال پیش کرتا ہے وہ ہمارے دو صالح بندوں کی زوجیت میں تھیں، مگر انہوں نے اپنے ان شوہروں سے خیانت کی اور وہ اللہ کے مقابلہ میں ان کے کچھ بھی نہ کام آ سکے دونوں سے کہہ دیا گیا کہ جاؤ آگ میں جانے والوں کے ساتھ تم بھی چلی جاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxl{اور اہل ایمان کے معاملہ میں اللہ فرعون کی بیوی کی مثال پیش کرتا ہے جبکہ اس نے دعا کی ``اے میرے رب، میرے لیے اپنے ہاں جنت میں ایک گھر بنا دے اور مجھے فرعون اور اس کے عمل سے بچا لے اور ظالم قوم سے مجھ کو نجات دے"\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxli{اور عمران کی بیٹی مریمؑ کی مثال دیتا ہے جس نے اپنی شرمگاہ کی حفاظت کی تھی، پھر ہم نے اس کے اندر اپنی طرف سے روح پھونک دی، اور اس نے اپنے رب کے ارشادات اور اس کی کتابوں کی تصدیق کی اور وہ اطاعت گزار لوگوں میں سے تھی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlii{\basmalahur نہایت بزرگ و برتر ہے وہ جس کے ہاتھ میں کائنات کی سلطنت ہے، اور وہ ہر چیز پر قدرت رکھتا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliii{جس نے موت اور زندگی کو ایجاد کیا تاکہ تم لوگوں کو آزما کر دیکھے تم میں سے کون بہتر عمل کرنے والا ہے، اور وہ زبردست بھی ہے اور درگزر فرمانے والا بھی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliv{جس نے تہ بر تہ سات آسمان بنائے تم رحمان کی تخلیق میں کسی قسم کی بے ربطی نہ پاؤ گے پھر پلٹ کر دیکھو، کہیں تمہیں کوئی خلل نظر آتا ہے؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlv{بار بار نگاہ دوڑاؤ تمہاری نگاہ تھک کر نامراد پلٹ آئے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvi{ہم نے تمہارے قریب کے آسمان کو عظیم الشان چراغوں سے آراستہ کیا ہے اور اُنہیں شیاطین کو مار بھگانے کا ذریعہ بنا دیا ہے اِن شیطانوں کے لیے بھڑکتی ہوئی آگ ہم نے مہیا کر رکھی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvii{جن لوگوں نے اپنے رب سے کفر کیا ان کے لیے جہنم کا عذاب ہے اور وہ بہت ہی برا ٹھکانا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlviii{جب وہ اُس میں پھینکے جائیں گے تو اسکے دھاڑنے کی ہولناک آواز سنیں گے اور وہ جوش کھا رہی ہوگی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlix{شدت غضب سے پھٹی جاتی ہو گی ہر بار جب کوئی انبوہ اس میں ڈالا جائے گا، اُس کے کارندے اُن لوگوں سے پوچھیں گے ``کیا تمہارے پاس کوئی خبردار کرنے والا نہیں آیا تھا؟"\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccl{وہ جواب دیں گے ``ہاں، خبردار کرنے والا ہمارے پاس آیا تھا، مگر ہم نے اسے جھٹلا دیا اور کہا اللہ نے کچھ بھی نازل نہیں کیا ہے، تم بڑی گمراہی میں پڑے ہوئے ہو"\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccli{اور وہ کہیں گے ``کاش ہم سنتے یا سمجھتے تو آج اِس بھڑکتی ہوئی آگ کے سزا واروں میں نہ شامل ہوتے"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclii{اس طرح وہ اپنے قصور کا خود اعتراف کر لیں گے، لعنت ہے ان دوزخیوں پر\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliii{جو لوگ بے دیکھے اپنے رب سے ڈرتے ہیں، یقیناً اُن کے لیے مغفرت ہے اور بڑا اجر\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliv{تم خواہ چپکے سے بات کرو یا اونچی آواز سے (اللہ کے لیے یکساں ہے)، وہ تو دلوں کا حال تک جانتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclv{کیا وہی نہ جانے گا جس نے پیدا کیا ہے؟ حالانکہ وہ باریک بیں اور باخبر ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvi{وہی تو ہے جس نے تمہارے لیے زمین کو تابع کر رکھا ہے، چلو اُس کی چھاتی پر اور کھاؤ خدا کا رزق، اُسی کے حضور تمہیں دوبارہ زندہ ہو کر جانا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvii{کیا تم اِس سے بے خوف ہو کہ وہ جو آسمان میں ہے تمہیں زمین میں دھنسا دے اور یکایک یہ زمین جھکولے کھانے لگے؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclviii{کیا تم اِس سے بے خوف ہو کہ وہ جو آسمان میں ہے تم پر پتھراؤ کرنے والی ہوا بھیج دے؟ پھر تمہیں معلوم ہو جائے گا کہ میری تنبیہ کیسی ہوتی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclix{اِن سے پہلے گزرے ہوئے لوگ جھٹلا چکے ہیں پھر دیکھ لو کہ میری گرفت کیسی سخت تھی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclx{کیا یہ لو گ اپنے اوپر اڑنے والے پرندوں کو پر پھیلائے اور سکیڑتے نہیں دیکھتے؟ رحمان کے سوا کوئی نہیں جو انہیں تھامے ہوئے ہو وہی ہر چیز کا نگہبان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxi{بتاؤ، آخر وہ کونسا لشکر تمہارے پاس ہے جو رحمان کے مقابلے میں تمہاری مدد کر سکتا ہے؟ حقیقت یہ ہے کہ منکرین دھوکے میں پڑے ہوئے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxii{یا پھر بتاؤ، کون ہے جو تمہیں رزق دے سکتا ہے اگر رحمان اپنا رزق روک لے؟ دراصل یہ لوگ سر کشی اور حق سے گریز پر اڑے ہوئے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiii{بھلا سوچو، جو شخص منہ اوندھائے چل رہا ہو وہ زیادہ صحیح راہ پانے والا ہے یا وہ جو سر اٹھائے سیدھا ایک ہموار سڑک پر چل رہا ہو؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiv{اِن سے کہو اللہ ہی ہے جس نے تمہیں پیدا کیا، تم کو سننے اور دیکھنے کی طاقتیں دیں اور سوچنے سمجھنے والے دل دیے، مگر تم کم ہی شکر ادا کرتے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxv{اِن سے کہو، اللہ ہی ہے جس نے تمہیں زمین میں پھیلایا اور اسی کی طرف تم سمیٹے جاؤ گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvi{یہ کہتے ہیں ``اگر تم سچے ہو تو بتاؤ یہ وعدہ کب پورا ہوگا؟"\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvii{کہو، ``اِس کا علم تو اللہ کے پاس ہے، میں تو بس صاف صاف خبردار کر دینے والا ہوں"\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxviii{پھر جب یہ اُس چیز کو قریب دیکھ لیں گے تو اُن سب لوگوں کے چہرے بگڑ جائیں گے جنہوں نے انکار کیا ہے، اور اُس وقت ان سے کہا جائے گا کہ یہی ہے وہ چیز جس کے لیے تم تقاضے کر رہے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxix{اِن سے کہو، کبھی تم نے یہ بھی سوچا کہ اللہ خواہ مجھے اور میرے ساتھیوں کو ہلاک کر دے یا ہم پر رحم کرے، کافروں کو دردناک عذاب سے کون بچا لے گا؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxx{اِن سے کہو، وہ بڑا رحیم ہے، اسی پر ہم ایمان لائے ہیں، اور اُسی پر ہمارا بھروسا ہے، عنقریب تمہیں معلوم ہو جائے گا کہ صریح گمراہی میں پڑا ہوا کون ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxi{اِن سے کہو، کبھی تم نے یہ بھی سوچا کہ اگر تمہارے کنوؤں کا پانی زمین میں اتر جائے تو کون ہے جو اِس پانی کی بہتی ہوئی سوتیں تمہیں نکال کر لا دے گا؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxii{\basmalahur ن، قسم ہے قلم کی اور اُس چیز کی جسے لکھنے والے لکھ رہے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiii{تم اپنے رب کے فضل سے مجنوں نہیں ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiv{اور یقیناً تمہارے لیے ایسا اجر ہے جس کا سلسلہ کبھی ختم ہونے والا نہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxv{اور بیشک تم اخلاق کے بڑے مرتبے پر ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvi{عنقریب تم بھی دیکھ لو گے اور وہ بھی دیکھ لیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvii{کہ تم میں سے کون جنون میں مبتلا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxviii{تمہارا رب اُن لوگوں کو بھی خوب جانتا ہے جو اس کی راہ سے بھٹکے ہوئے ہیں، اور وہی ان کو بھی اچھی طرح جانتا ہے جو راہ راست پر ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxix{لہٰذا تم اِن جھٹلانے والوں کے دباؤ میں ہرگز نہ آؤ\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxx{یہ تو چاہتے ہیں کہ کچھ تم مداہنت کرو تو یہ بھی مداہنت کریں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxi{ہرگز نہ دبو کسی ایسے شخص سے جو بہت قسمیں کھانے والا بے وقعت آدمی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxii{طعنے دیتا ہے، چغلیاں کھاتا پھرتا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiii{بھلائی سے روکتا ہے، ظلم و زیادتی میں حد سے گزر جانے والا ہے، سخت بد اعمال ہے، جفا کار ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiv{اور اَن سب عیوب کے ساتھ بد اصل ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxv{اِس بنا پر کہ وہ بہت مال و اولاد رکھتا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvi{جب ہماری آیات اُس کو سنائی جاتی ہیں تو کہتا ہے یہ تو اگلے وقتوں کے افسانے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvii{عنقریب ہم اس کی سونڈ پر داغ لگائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxviii{ہم نے اِن (اہل مکہ) کو اُسی طرح آزمائش میں ڈالا ہے جس طرح ایک باغ کے مالکوں کو آزمائش میں ڈالا تھا، جب اُنہوں نے قسم کھائی کہ صبح سویرے ضرور اپنے باغ کے پھل توڑیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxix{اور وہ کوئی استثناء نہیں کر رہے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxc{رات کو وہ سوئے پڑے تھے کہ تمہارے رب کی طرف سے ایک بلا اس باغ پر پھر گئی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxci{اور اُس کا حال ایسا ہو گیا جیسے کٹی ہوئی فصل ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcii{صبح اُن لوگوں نے ایک دوسرے کو پکارا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciii{کہ اگر پھل توڑنے ہیں تو سویرے سویرے اپنی کھیتی کی طرف نکل چلو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciv{چنانچہ وہ چل پڑے اور آپس میں چپکے چپکے کہتے جاتے تھے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcv{کہ آج کوئی مسکین تمہارے پاس باغ میں نہ آنے پائے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvi{وہ کچھ نہ دینے کا فیصلہ کیے ہوئے صبح سویرے جلدی جلدی اِس طرح وہاں گئے جیسے کہ وہ (پھل توڑنے پر) قادر ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvii{مگر جب باغ کو دیکھا تو کہنے لگے ``ہم راستہ بھول گئے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcviii{نہیں، بلکہ ہم محروم رہ گئے"\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcix{اُن میں جو سب سے بہتر آدمی تھا اُس نے کہا ``میں نے تم سے کہا نہ تھا کہ تم تسبیح کیوں نہیں کرتے؟"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccc{و ہ پکار اٹھے پاک ہے ہمارا رب، واقعی ہم گناہ گار تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmccci{پھر اُن میں سے ہر ایک دوسرے کو ملامت کرنے لگا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccii{آخر کو انہوں نے کہا ``افسوس ہمارے حال پر، بے شک ہم سرکش ہو گئے تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciii{بعید نہیں کہ ہمارا رب ہمیں بدلے میں اِس سے بہتر باغ عطا فرمائے، ہم اپنے رب کی طرف رجوع کرتے ہیں"\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciv{ایسا ہوتا ہے عذاب اور آخرت کا عذاب اِس سے بھی بڑا ہے، کاش یہ لوگ اِس کو جانتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccv{یقیناً خدا ترس لوگوں کے لیے اُن کے رب کے ہاں نعمت بھری جنتیں ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvi{کیا ہم فرماں برداروں کا حال مجرموں کا سا کر دیں؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvii{تم لوگوں کو کیا ہو گیا ہے، تم کیسے حکم لگاتے ہو؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccviii{کیا تمہارے پاس کوئی کتاب ہے جس میں تم یہ پڑھتے ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccix{کہ تمہارے لیے ضرور وہاں وہی کچھ ہے جو تم اپنے لیے پسند کرتے ہو؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccx{یا پھر کیا تمہارے لیے روز قیامت تک ہم پر کچھ عہد و پیمان ثابت ہیں کہ تمہیں وہی کچھ ملے گا جس کا تم حکم لگاؤ؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxi{اِن سے پوچھو تم میں سے کون اِس کا ضامن ہے؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxii{یا پھر اِن کے ٹھیرائے ہوئے کچھ شریک ہیں (جنہوں نے اِس کا ذمہ لیا ہو)؟ یہ بات ہے تو لائیں اپنے شریکوں کو اگر یہ سچے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiii{جس روز سخت وقت آ پڑے گا اور لوگوں کو سجدہ کرنے کے لیے بلایا جائے گا تو یہ لوگ سجدہ نہ کر سکیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiv{اِن کی نگاہیں نیچی ہوں گی، ذلت اِن پر چھا رہی ہوگی یہ جب صحیح و سالم تھے اُس وقت اِنہیں سجدے کے لیے بلایا جاتا تھا (اور یہ انکار کرتے تھے)\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxv{پس اے نبیؐ، تم اِس کلام کے جھٹلانے والوں کا معاملہ مجھ پر چھوڑ دو ہم ایسے طریقہ سے اِن کو بتدریج تباہی کی طرف لے جائیں گے کہ اِن کو خبر بھی نہ ہوگی\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvi{میں اِن کی رسی دراز کر رہا ہوں، میری چال بڑی زبردست ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvii{کیا تم اِن سے کوئی اجر طلب کر رہے ہو کہ یہ اس چٹی کے بوجھ تلے دبے جا رہے ہوں؟\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxviii{کیا اِن کے پاس غیب کا علم ہے جسے یہ لکھ رہے ہوں؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxix{پس اپنے رب کا فیصلہ صادر ہونے تک صبر کرو اور مچھلی والے (یونس علیہ اسلام) کی طرح نہ ہو جاؤ، جب اُس نے پکارا تھا اور وہ غم سے بھرا ہوا تھا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxx{اگر اس کے رب کی مہربانی اُس کے شامل حال نہ ہو جاتی تو وہ مذموم ہو کر چٹیل میدان میں پھینک دیا جاتا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxi{آخرکار اُس کے رب نے اسے برگزیدہ فرما لیا اور اِسے صالح بندوں میں شامل کر دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxii{جب یہ کافر لوگ کلام نصیحت (قرآن) سنتے ہیں تو تمہیں ایسی نظروں سے دیکھتے ہیں کہ گویا تمہارے قدم اکھاڑ دیں گے، اور کہتے ہیں یہ ضرور دیوانہ ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiii{حالانکہ یہ تو سارے جہان والوں کے لیے ایک نصیحت ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiv{\basmalahur ہونی شدنی!\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxv{کیا ہے وہ ہونی شدنی؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvi{اور تم کیا جانو کہ وہ کیا ہے ہونی شدنی؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvii{ثمود اور عاد نے اُس اچانک ٹوٹ پڑنے والی آفت کو جھٹلایا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxviii{تو ثمود ایک سخت حادثہ میں ہلاک کیے گئے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxix{اور عاد ایک بڑی شدید طوفانی آندھی سے تباہ کر دیے گئے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxx{اللہ تعالیٰ نے اُس کو مسلسل سات رات اور آٹھ دن اُن پر مسلط رکھا (تم وہاں ہوتے تو) دیکھتے کہ وہ وہاں اِس طرح پچھڑے پڑے ہیں جیسے وہ کھجور کے بوسیدہ تنے ہوں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxi{اب کیا اُن میں سے کوئی تمہیں باقی بچا نظر آتا ہے؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxii{اور اِسی خطائے عظیم کا ارتکاب فرعون اور اُس سے پہلے کے لوگوں نے اور تل پٹ ہو جانے والی بستیوں نے کیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiii{ان سب نے اپنے رب کے رسول کی بات نہ مانی تو اُس نے اُن کو بڑی سختی کے ساتھ پکڑا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiv{جب پانی کا طوفان حد سے گزر گیا تو ہم نے تم کو کشتی میں سوار کر دیا تھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxv{تاکہ اِس واقعہ کو تمہارے لیے ایک سبق آموز یادگار بنا دیں اور یاد رکھنے والے کان اس کی یاد محفوظ رکھیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvi{پھر جب ایک دفعہ صور میں پھونک مار دی جائے گی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvii{اور زمین اور پہاڑوں کو اٹھا کر ایک ہی چوٹ میں ریزہ ریزہ کر دیا جائے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxviii{اُس روز وہ ہونے والا واقعہ پیش آ جائے گا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxix{اُس دن آسمان پھٹے گا اور اس کی بندش ڈھیلی پڑ جائے گی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxl{فرشتے اس کے اطراف و جوانب میں ہوں گے اور آٹھ فرشتے اُس روز تیرے رب کا عرش اپنے اوپر اٹھائے ہوئے ہوں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxli{وہ دن ہوگا جب تم لوگ پیش کیے جاؤ گے، تمہارا کوئی راز بھی چھپا نہ رہ جائے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlii{اُس وقت جس کا نامہ اعمال اُس کے سیدھے ہاتھ میں دیا جائے گا وہ کہے گا ``لو دیکھو، پڑھو میرا نامہ اعمال\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliii{میں سمجھتا تھا کہ مجھے ضرور اپنا حساب ملنے والا ہے"\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliv{پس وہ دل پسند عیش میں ہوگا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlv{عالی مقام جنت میں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvi{جس کے پھلوں کے گچھے جھکے پڑ رہے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvii{(ایسے لوگوں سے کہا جائے گا) مزے سے کھاؤ اور پیو اپنے اُن اعمال کے بدلے جو تم نے گزرے ہوئے دنوں میں کیے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlviii{اور جس کا نامہ اعمال اُس کے بائیں ہاتھ میں دیا جائے گا وہ کہے گا ``کاش میرا اعمال نامہ مجھے نہ دیا گیا ہوتا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlix{اور میں نہ جانتا کہ میرا حساب کیا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccl{کاش میری وہی موت (جو دنیا میں آئی تھی) فیصلہ کن ہوتی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccli{آج میرا مال میرے کچھ کام نہ آیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclii{میرا سارا اقتدار ختم ہو گیا"\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliii{(حکم ہو گا) پکڑو اِسے اور اِس کی گردن میں طوق ڈال دو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliv{پھر اِسے جہنم میں جھونک دو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclv{پھر اِس کو ستر ہاتھ لمبی زنجیر میں جکڑ دو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvi{یہ نہ اللہ بزرگ و برتر پر ایمان لاتا تھا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvii{اور نہ مسکین کو کھانا کھلانے کی ترغیب دیتا تھا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclviii{لہٰذا آج نہ یہاں اِس کا کوئی یار غم خوار ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclix{اور نہ زخموں کے دھوون کے سوا اِس کے لیے کوئی کھانا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclx{جسے خطا کاروں کے سوا کوئی نہیں کھاتا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxi{پس نہیں، میں قسم کھاتا ہوں اُن چیزوں کی بھی جو تم دیکھتے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxii{اور اُن کی بھی جنہیں تم نہیں دیکھتے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiii{یہ ایک رسول کریم کا قول ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiv{کسی شاعر کا قول نہیں ہے، تم لوگ کم ہی ایمان لاتے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxv{اور نہ یہ کسی کاہن کا قول ہے، تم لوگ کم ہی غور کرتے ہو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvi{یہ رب العالمین کی طرف سے نازل ہوا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvii{اور اگر اس (نبی) نے خود گھڑ کر کوئی بات ہماری طرف منسوب کی ہوتی\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxviii{تو ہم اِس کا دایاں ہاتھ پکڑ لیتے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxix{اور اِس کی رگ گردن کاٹ ڈالتے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxx{پھر تم میں سے کوئی (ہمیں) اس کام سے روکنے والا نہ ہوتا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxi{درحقیقت یہ پرہیزگار لوگوں کے لیے ایک نصیحت ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxii{اور ہم جانتے ہیں کہ تم میں سے کچھ لوگ جھٹلانے والے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiii{ایسے کافروں کے لیے یقیناً یہ موجب حسرت ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiv{اور یہ بالکل یقینی حق ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxv{پس اے نبیؐ، اپنے رب عظیم کے نام کی تسبیح کرو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvi{\basmalahur مانگنے والے نے عذاب مانگا ہے، (وہ عذاب) جو ضرور واقع ہونے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvii{کافروں کے لیے ہے، کوئی اُسے دفع کرنے والا نہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxviii{اُس خدا کی طرف سے ہے جو عروج کے زینوں کا مالک ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxix{ملائکہ اور روح اُس کے حضور چڑھ کر جاتے ہیں ایک ایسے دن میں جس کی مقدار پچاس ہزار سال ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxx{پس اے نبیؐ، صبر کرو، شائستہ صبر\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxi{یہ لوگ اُسے دور سمجھتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxii{اور ہم اسے قریب دیکھ رہے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiii{(وہ عذاب اُس روز ہوگا) جس روز آسمان پگھلی ہوئی چاندی کی طرح ہو جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiv{اور پہاڑ رنگ برنگ کے دھنکے ہوئے اون جیسے ہو جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxv{اور کوئی جگری دوست اپنے جگری دوست کو نہ پوچھے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvi{حالانکہ وہ ایک دوسرے کو دکھائے جائیں گے مجرم چاہے گا کہ اس دن کے عذاب سے بچنے کے لیے اپنی اولاد کو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvii{اپنی بیوی کو، اپنے بھائی کو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxviii{اپنے قریب ترین خاندان کو جو اسے پناہ دینے والا تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxix{اور روئے زمین کے سب لوگوں کو فدیہ میں دیدے اور یہ تدبیر اُسے نجات دلا دے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxc{ہرگز نہیں وہ تو بھڑکتی ہوئی آگ کی لپٹ ہوگی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxci{جو گوشت پوست کو چاٹ جائے گی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcii{پکار پکار کر اپنی طرف بلائے گی ہر اُس شخص کو جس نے حق سے منہ موڑا اور پیٹھ پھیری\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciii{اور مال جمع کیا اور سینت سینت کر رکھا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciv{انسان تھڑدلا پیدا کیا گیا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcv{جب اس پر مصیبت آتی ہے تو گھبرا اٹھتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvi{اور جب اسے خوشحالی نصیب ہوتی ہے تو بخل کرنے لگتا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvii{مگر وہ لوگ (اِس عیب سے بچے ہوئے ہیں) جو نماز پڑھنے والے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcviii{جو اپنی نماز کی ہمیشہ پابندی کرتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcix{جن کے مالوں میں،\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcd{سائل اور محروم کا ایک حق مقرر ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdi{جو روز جزا کو برحق مانتے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdii{جو اپنے رب کے عذاب سے ڈرتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiii{کیونکہ اُن کے رب کا عذاب ایسی چیز نہیں ہے جس سے کوئی بے خوف ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiv{جو اپنی شرمگاہوں کی حفاظت کرتے ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdv{بجز اپنی بیویوں یا اپنی مملوکہ عورتوں کے جن سے محفوظ نہ رکھنے میں ان پر کوئی ملامت نہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvi{البتہ جو اس کے علاوہ کچھ اور چاہیں وہی حد سے تجاوز کرنے والے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvii{جو اپنی امانتوں کی حفاظت اور اپنے عہد کا پاس کرتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdviii{جو اپنی گواہیوں میں راست بازی پر قائم رہتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdix{اور جو اپنی نماز کی حفاظت کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdx{یہ لوگ عزت کے ساتھ جنت کے باغوں میں رہیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxi{پس اے نبیؐ، کیا بات ہے کہ یہ منکرین دائیں اور بائیں سے،\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxii{گروہ در گروہ تمہاری طرف دوڑے چلے آ رہے ہیں؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiii{کیا اِن میں سے ہر ایک یہ لالچ رکھتا ہے کہ وہ نعمت بھری جنت میں داخل کر دیا جائے گا؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiv{ہرگز نہیں ہم نے جس چیز سے اِن کو پیدا کیا ہے اُسے یہ خود جانتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxv{پس نہیں، میں قسم کھاتا ہوں مشرقوں اور مغربوں کے مالک کی، ہم اِس پر قادر ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvi{کہ اِن کی جگہ اِن سے بہتر لوگ لے آئیں اور کوئی ہم سے بازی لے جانے والا نہیں ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvii{لہٰذا اِنہیں اپنی بیہودہ باتوں اور اپنے کھیل میں پڑا رہنے دو یہاں تک کہ یہ اپنے اُس دن تک پہنچ جائیں جس کا ان سے وعدہ کیا جا رہا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxviii{جب یہ اپنی قبروں سے نکل کر اِس طرح دوڑے جا رہے ہوں گے جیسے اپنے بتوں کے استھانوں کی طرف دوڑ رہے ہوں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxix{اِن کی نگاہیں جھکی ہوئی ہوں گی، ذلت اِن پر چھا رہی ہوگی وہ دن ہے جس کا اِن سے وعدہ کیا جا رہا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxx{\basmalahur ہم نے نوحؑ کو اس کی قوم کی طرف بھیجا (اس ہدایت کے ساتھ) کہ اپنی قوم کے لوگوں کو خبردار کر دے قبل اس کے کہ ان پر ایک دردناک عذاب آئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxi{ا س نے کہا ``اے میری قوم کے لوگو، میں تمہارے لیے ایک صاف صاف خبردار کردینے والا (پیغمبر) ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxii{(تم کو آگاہ کرتا ہوں) کہ اللہ کی بندگی کرو اور اس سے ڈرو اور میری اطاعت کرو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiii{اللہ تمہارے گناہوں سے درگزر فرمائے گا اور تمہیں ایک وقت مقرر تک باقی رکھے گا حقیقت یہ ہے کہ اللہ کا مقرر کیا ہوا وقت جب آ جاتا ہے تو پھر ٹالا نہیں جاتا کاش تمہیں اِس کا علم ہو"\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiv{اُس نے عرض کیا ``اے میرے رب، میں نے اپنی قوم کے لوگوں کو شب و روز پکارا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxv{مگر میری پکار نے اُن کے فرار ہی میں اضافہ کیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvi{اور جب بھی میں نے اُن کو بلایا تاکہ تو اُنہیں معاف کر دے، انہوں نے کانوں میں انگلیاں ٹھونس لیں اور اپنے کپڑوں سے منہ ڈھانک لیے اور اپنی روش پر اڑ گئے اور بڑا تکبر کیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvii{پھر میں نے ان کو ہانکے پکارے دعوت دی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxviii{پھر میں نے علانیہ بھی ان کو تبلیغ کی اور چپکے چپکے بھی سمجھایا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxix{میں نے کہا اپنے رب سے معافی مانگو، بے شک وہ بڑا معاف کرنے والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxx{وہ تم پر آسمان سے خوب بارشیں برسائے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxi{تمہیں مال اور اولاد سے نوازے گا، تمہارے لیے باغ پیدا کرے گا اور تمہارے لیے نہریں جاری کر دے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxii{تمہیں کیا ہو گیا ہے کہ اللہ کے لیے تم کسی وقار کی توقع نہیں رکھتے؟\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiii{حالانکہ اُس نے طرح طرح سے تمہیں بنایا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiv{کیا دیکھتے نہیں ہو کہ اللہ نے کس طرح سات آسمان تہ بر تہ بنائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxv{اور اُن میں چاند کو نور اور سورج کو چراغ بنایا؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvi{اور اللہ نے تم کو زمین سے عجیب طرح اگایا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvii{پھر وہ تمہیں اِسی زمین میں واپس لے جائے گا اور اِس سے یکایک تم کو نکال کھڑا کرے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxviii{اور اللہ نے زمین کو تمہارے لیے فرش کی طرح بچھا دیا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxix{تاکہ تم اس کے اندر کھلے راستوں میں چلو"\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxl{نوحؑ نے کہا، ``میرے رب، اُنہوں نے میری بات رد کر دی اور اُن (رئیسوں) کی پیروی کی جو مال اور اولاد پا کر اور زیادہ نامراد ہو گئے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxli{اِن لوگوں نے بڑا بھاری مکر کا جال پھیلا رکھا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlii{اِنہوں نے کہا ہرگز نہ چھوڑو اپنے معبودوں کو، اور نہ چھوڑو وَدّ اور سُواع کو، اور نہ یَغُوث اور یَعُوق اور نَسر کو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliii{انہوں نے بہت لوگوں کو گمراہ کیا ہے، اور تو بھی اِن ظالموں کو گمراہی کے سوا کسی چیز میں ترقی نہ دے"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliv{اپنی خطاؤں کی بنا پر ہی وہ غرق کیے گئے اور آگ میں جھونک دیے گئے، پھر انہوں نے اپنے لیے اللہ سے بچانے والا کوئی مددگار نہ پایا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlv{اور نوحؑ نے کہا، ``میرے رب، اِن کافروں میں سے کوئی زمین پر بسنے والا نہ چھوڑ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvi{اگر تو نے اِن کو چھوڑ دیا تو یہ تیرے بندوں کو گمراہ کریں گے اور اِن کی نسل سے جو بھی پیدا ہوگا بدکار اور سخت کافر ہی ہوگا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvii{میرے رب، مجھے اور میرے والدین کو اور ہر اس شخص کو جو میرے گھر میں مومن کی حیثیت سے داخل ہوا ہے، اور سب مومن مردوں اور عورتوں کو معاف فرما دے، اور ظالموں کے لیے ہلاکت کے سوا کسی چیز میں اضافہ نہ کر"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlviii{\basmalahur اے نبیؐ، کہو، میری طرف وحی بھیجی گئی ہے کہ جنوں کے ایک گروہ نے غور سے سنا پھر (جا کر اپنی قوم کے لوگوں سے) کہا: ``ہم نے ایک بڑا ہی عجیب قرآن سنا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlix{جو راہ راست کی طرف رہنمائی کرتا ہے اِس لیے ہم اُس پر ایمان لے آئے ہیں اور اب ہم ہرگز اپنے رب کے ساتھ کسی کو شریک نہیں کریں گے"\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdl{اور یہ کہ ``ہمارے رب کی شان بہت اعلیٰ و ارفع ہے، اُس نے کسی کو بیوی یا بیٹا نہیں بنایا ہے"\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdli{اور یہ کہ ``ہمارے نادان لوگ اللہ کے بارے میں بہت خلاف حق باتیں کہتے رہے ہیں"\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlii{اور یہ کہ ``ہم نے سمجھا تھا کہ انسان اور جن کبھی خدا کے بارے میں جھوٹ نہیں بول سکتے"\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliii{اور یہ کہ ``انسانوں میں سے کچھ لوگ جنوں میں سے کچھ لوگوں کی پناہ مانگا کرتے تھے، اِس طرح اُنہوں نے جنوں کا غرور اور زیادہ بڑھا دیا"\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliv{اور یہ کہ ``انسانوں نے بھی وہی گمان کیا جیسا تمہارا گمان تھا کہ اللہ کسی کو رسول بنا کر نہ بھیجے گا"\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlv{اور یہ کہ ``ہم نے آسمان کو ٹٹولا تو دیکھا کہ وہ پہرے داروں سے پٹا پڑا ہے اور شہابوں کی بارش ہو رہی ہے"\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvi{اور یہ کہ ``پہلے ہم سن گن لینے کے لیے آسمان میں بیٹھنے کی جگہ پا لیتے تھے، مگر اب جو چوری چھپے سننے کی کوشش کرتا ہے وہ اپنے لیے گھات میں ایک شہاب ثاقب لگا ہوا پاتا ہے"\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvii{اور یہ کہ ``ہماری سمجھ میں نہ آتا تھا کہ آیا زمین والوں کے ساتھ کوئی برا معاملہ کرنے کا ارادہ کیا گیا ہے یا اُن کا رب اُنہیں راہ راست دکھانا چاہتا ہے"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlviii{اور یہ کہ ``ہم میں سے کچھ لوگ صالح ہیں اور کچھ اس سے فروتر ہیں، ہم مختلف طریقوں میں بٹے ہوئے ہیں"\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlix{اور یہ کہ ``ہم سمجھتے تھے کہ نہ زمین میں ہم اللہ کو عاجز کر سکتے ہیں اور نہ بھاگ کر اُسے ہرا سکتے ہیں"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlx{اور یہ کہ ``ہم نے جب ہدایت کی تعلیم سنی تو ہم اس پر ایمان لے آئے اب جو کوئی بھی اپنے رب پر ایمان لے آئے گا اسے کسی حق تلفی یا ظلم کا خوف نہ ہوگا"\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxi{اور یہ کہ ``ہم میں سے کچھ مسلم (اللہ کے اطاعت گزار) ہیں اور کچھ حق سے منحرف تو جنہوں نے اسلام (اطاعت کا راستہ) اختیار کر لیا انہوں نے نجات کی راہ ڈھونڈ لی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxii{اور جو حق سے منحرف ہیں وہ جہنم کا ایندھن بننے والے ہیں"\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiii{اور (اے نبیؐ، کہو، مجھ پر یہ وحی بھی کی گئی ہے کہ) لوگ اگر راہ راست پر ثابت قدمی سے چلتے تو ہم اُنہیں خوب سیراب کرتے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiv{تاکہ اس نعمت سے ان کی آزمائش کریں اور جو اپنے رب کے ذکر سے منہ موڑے گا اس کا رب اسے سخت عذاب میں مبتلا کر دے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxv{اور یہ کہ مسجدیں اللہ کے لئے ہیں، لہٰذا اُن میں اللہ کے ساتھ کسی اور کو نہ پکارو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvi{اور یہ کہ جب اللہ کا بندہ اُس کو پکارنے کے لئے کھڑا ہوا تو لوگ اُس پر ٹوٹ پڑنے کے لئے تیار ہو گئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvii{اے نبیؐ، کہو کہ ``میں تو اپنے رب کو پکارتا ہوں اور اس کے ساتھ کسی کو شریک نہیں کرتا"\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxviii{کہو، ``میں تم لوگوں کے لئے نہ کسی نقصان کا اختیار رکھتا ہوں نہ کسی بھلائی کا"\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxix{کہو، ``مجھے اللہ کی گرفت سے کوئی نہیں بچا سکتا اور نہ میں اُس کے دامن کے سوا کوئی جائے پناہ پا سکتا ہوں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxx{میرا کام اس کے سوا کچھ نہیں ہے کہ اللہ کی بات اور اس کے پیغامات پہنچا دوں اب جو بھی اللہ اور اس کے رسول کی بات نہ مانے گا اس کے لیے جہنم کی آگ ہے اور ایسے لوگ اس میں ہمیشہ رہیں گے"\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxi{(یہ لوگ اپنی اِس روش سے باز نہ آئیں گے) یہاں تک کہ جب اُس چیز کو دیکھ لیں گے جس کا اِن سے وعدہ کیا جا رہا ہے تو انہیں معلوم ہو جائے گا کہ کس کے مددگار کمزور ہیں اور کس کا جتھا تعداد میں کم ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxii{کہو، ``میں نہیں جانتا کہ جس چیز کا وعدہ تم سے کیا جا رہا ہے وہ قریب ہے یا میرا رب اس کے لیے کوئی لمبی مدت مقرر فرماتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiii{وہ عالم الغیب ہے، اپنے غیب پر کسی کو مطلع نہیں کرتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiv{سوائے اُس رسول کے جسے اُس نے (غیب کا کوئی علم دینے کے لیے) پسند کر لیا ہو، تو اُس کے آگے اور پیچھے وہ محافظ لگا دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxv{تاکہ وہ جان لے کہ انہوں نے اپنے رب کے پیغامات پہنچا دیے، اور وہ اُن کے پورے ماحول کا احاطہ کیے ہوئے ہے اور ایک ایک چیز کو اس نے گن رکھا ہے"\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvi{\basmalahur اے اوڑھ لپیٹ کر سونے والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvii{رات کو نماز میں کھڑے رہا کرو مگر کم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxviii{آدھی رات،\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxix{یا اس سے کچھ کم کر لو یا اس سے کچھ زیادہ بڑھا دو، اور قرآن کو خوب ٹھیر ٹھیر کر پڑھو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxx{ہم تم پر ایک بھاری کلام نازل کرنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxi{درحقیقت رات کا اٹھنا نفس پر قابو پانے کے لیے بہت کارگر اور قرآن ٹھیک پڑھنے کے لیے زیادہ موزوں ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxii{دن کے اوقات میں تو تمہارے لیے بہت مصروفیات ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiii{اپنے رب کے نام کا ذکر کیا کرو اور سب سے کٹ کر اسی کے ہو رہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiv{وہ مشرق و مغرب کا مالک ہے، اُس کے سوا کوئی خدا نہیں ہے، لہٰذا اُسی کو اپنا وکیل بنا لو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxv{اور جو باتیں لوگ بنا رہے ہیں ان پر صبر کرو اور شرافت کے ساتھ اُن سے الگ ہو جاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvi{اِن جھٹلانے والے خوشحال لوگوں سے نمٹنے کا کام تم مجھ پر چھوڑ دو اور اِنہیں ذرا کچھ دیر اِسی حالت پر رہنے دو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvii{ہمارے پاس (ان کے لیے) بھاری بیڑیاں ہیں اور بھڑکتی ہوئی آگ\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxviii{اور حلق میں پھنسنے والا کھانا اور دردناک عذاب\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxix{یہ اُس دن ہوگا جب زمین اور پہاڑ لرز اٹھیں گے اور پہاڑوں کا حال ایسا ہو جائے گا جیسے ریت کے ڈھیر ہیں جو بکھرے جا رہے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxc{تم لوگوں کے پاس ہم نے اُسی طرح ایک رسول تم پر گواہ بنا کر بھیجا ہے جس طرح ہم نے فرعون کی طرف ایک رسول بھیجا تھا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxci{(پھر دیکھ لو کہ جب) فرعون نے اُس رسول کی بات نہ مانی تو ہم نے اس کو بڑی سختی کے ساتھ پکڑ لیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcii{اگر تم ماننے سے انکار کرو گے تو اُس دن کیسے بچ جاؤ گے جو بچوں کو بوڑھا کر دے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciii{اور جس کی سختی سے آسمان پھٹا جا رہا ہوگا؟ اللہ کا وعدہ تو پورا ہو کر ہی رہنا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciv{یہ ایک نصیحت ہے، اب جس کا جی چاہے اپنے رب کی طرف جانے کا راستہ اختیار کر لے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcv{اے نبیؐ، تمہارا رب جانتا ہے کہ تم کبھی دو تہائی رات کے قریب اور کبھی آدھی رات اور کبھی ایک تہائی رات عبادت میں کھڑے رہتے ہو، اور تمہارے ساتھیوں میں سے بھی ایک گروہ یہ عمل کرتا ہے اللہ ہی رات اور دن کے اوقات کا حساب رکھتا ہے، اُسے معلوم ہے کہ تم لوگ اوقات کا ٹھیک شمار نہیں کر سکتے، لہٰذا اس نے تم پر مہربانی فرمائی، اب جتنا قرآن آسانی سے پڑھ سکتے ہو پڑھ لیا کرو اُسے معلوم ہے کہ تم میں کچھ مریض ہونگے، کچھ دوسرے لوگ اللہ کے فضل کی تلاش میں سفر کرتے ہیں، اور کچھ اور لوگ اللہ کی راہ میں جنگ کرتے ہیں پس جتنا قرآن بآسانی پڑھا جا سکے پڑھ لیا کرو، نماز قائم کرو، زکوٰۃ دو اور اللہ کو اچھا قرض دیتے رہو جو کچھ بھلائی تم اپنے لیے آگے بھیجو گے اسے اللہ کے ہاں موجود پاؤ گے، وہی زیادہ بہتر ہے اور اس کا اجر بہت بڑا ہے اللہ سے مغفرت مانگتے رہو، بے شک اللہ بڑا غفور و رحیم ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvi{\basmalahur اے اوڑھ لپیٹ کر لیٹنے والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvii{اٹھو اور خبردار کرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcviii{اور اپنے رب کی بڑائی کا اعلان کرو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcix{اور اپنے کپڑے پاک رکھو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmd{اور گندگی سے دور رہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdi{اور احسان نہ کرو زیادہ حاصل کرنے کے لیے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdii{اور اپنے رب کی خاطر صبر کرو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiii{اچھا، جب صور میں پھونک ماری جائے گی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiv{وہ دن بڑا ہی سخت دن ہوگا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdv{کافروں کے لیے ہلکا نہ ہوگا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvi{چھوڑ دو مجھے اور اُس شخص کو جسے میں نے اکیلا پیدا کیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvii{بہت سا مال اُس کو دیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdviii{اس کے ساتھ حاضر رہنے والے بیٹے دیے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdix{اور اس کے لیے ریاست کی راہ ہموار کی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdx{پھر وہ طمع رکھتا ہے کہ میں اسے اور زیادہ دوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxi{ہرگز نہیں، وہ ہماری آیات سے عناد رکھتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxii{میں تو اسے عنقریب ایک کٹھن چڑھائی چڑھواؤں گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiii{اس نے سوچا اور کچھ بات بنانے کی کوشش کی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiv{تو خدا کی مار اس پر، کیسی بات بنانے کی کوشش کی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxv{ہاں، خدا کی مار اُس پر، کیسی بات بنانے کی کوشش کی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvi{پھر (لوگوں کی طرف) دیکھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvii{پھر پیشانی سیکڑی اور منہ بنایا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxviii{پھر پلٹا اور تکبر میں پڑ گیا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxix{آخرکار بولا کہ یہ کچھ نہیں ہے مگر ایک جادو جو پہلے سے چلا آ رہا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxx{یہ تو یہ ایک انسانی کلام ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxi{عنقریب میں اسے دوزخ میں جھونک دوں گا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxii{اور تم کیا جانو کہ کیا ہے وہ دوزخ؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiii{نہ باقی رکھے نہ چھوڑے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiv{کھال جھلس دینے والی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxv{انیس کارکن اُس پر مقرر ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvi{ہم نے دوزخ کے یہ کارکن فرشتے بنائے ہیں، اور ان کی تعداد کو کافروں کے لیے فتنہ بنا دیا ہے، تاکہ اہل کتاب کو یقین آ جائے اور ایمان لانے والوں کا ایمان بڑھے، اور اہل کتاب اور مومنین کسی شک میں نہ رہیں، اور دل کے بیمار اور کفار یہ کہیں کہ بھلا اللہ کا اِس عجیب بات سے کیا مطلب ہو سکتا ہے اِس طرح اللہ جسے چاہتا ہے گمراہ کر دیتا ہے اور جسے چاہتا ہے ہدایت بخش دیتا ہے اور تیرے رب کے لشکروں کو خود اُس کے سوا کوئی نہیں جانتا اور اس دوزخ کا ذکر اِس کے سوا کسی غرض کے لیے نہیں کیا گیا ہے کہ لوگوں کو اس سے نصیحت ہو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvii{ہرگز نہیں، قسم ہے چاند کی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxviii{اور رات کی جبکہ وہ پلٹتی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxix{اور صبح کی جبکہ وہ روشن ہوتی ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxx{یہ دوزخ بھی بڑی چیزوں میں سے ایک ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxi{انسانوں کے لیے ڈراوا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxii{تم میں سے ہر اُس شخص کے لیے ڈراوا جو آگے بڑھنا چاہے یا پیچھے رہ جانا چاہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiii{ہر متنفس، اپنے کسب کے بدلے رہن ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiv{دائیں بازو والوں کے سوا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxv{جو جنتوں میں ہوں گے وہاں وہ،\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvi{مجرموں سے پوچھیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvii{``تمہیں کیا چیز دوزخ میں لے گئی؟"\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxviii{وہ کہیں گے ``ہم نماز پڑھنے والوں میں سے نہ تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxix{اور مسکین کو کھانا نہیں کھلاتے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxl{اور حق کے خلاف باتیں بنانے والوں کے ساتھ مل کر ہم بھی باتیں بنانے لگتے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxli{اور روز جزا کو جھوٹ قرار دیتے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlii{یہاں تک کہ ہمیں اُس یقینی چیز سے سابقہ پیش آ گیا"\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliii{اُس وقت سفارش کرنے والوں کی سفارش ان کے کسی کام نہ آئے گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliv{آخر اِن لوگوں کو کیا ہو گیا ہے کہ یہ اِس نصیحت سے منہ موڑ رہے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlv{گویا یہ جنگلی گدھے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvi{جو شیر سے ڈر کر بھاگ پڑے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvii{بلکہ اِن میں سے تو ہر ایک یہ چاہتا ہے کہ اُس کے نام کھلے خط بھیجے جائیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlviii{ہرگز نہیں، اصل بات یہ ہے کہ یہ آخرت کا خوف نہیں رکھتے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlix{ہرگز نہیں، یہ تو ایک نصیحت ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmdl{اب جس کا جی چاہے اس سے سبق حاصل کر لے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmdli{اور یہ کوئی سبق حاصل نہ کریں گے الا یہ کہ اللہ ہی ایسا چاہے وہ اس کا حق دار ہے کہ اُس سے تقویٰ کیا جائے اور وہ اس کا اہل ہے کہ (تقویٰ کرنے والوں کو) بخش دے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlii{\basmalahur نہیں، میں قسم کھاتا ہوں قیامت کے دن کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliii{اور نہیں، میں قسم کھاتا ہوں ملامت کرنے والے نفس کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliv{کیا انسان یہ سمجھ رہا ہے کہ ہم اُس کی ہڈیوں کو جمع نہ کر سکیں گے؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlv{ہم تو اس کی انگلیوں کی پور پور تک ٹھیک بنا دینے پر قادر ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvi{مگر انسان چاہتا یہ ہے کہ آگے بھی بد اعمالیاں کرتا رہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvii{پوچھتا ہے ``آخر کب آنا ہے وہ قیامت کا دن؟"\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlviii{پھر جب دیدے پتھرا جائیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlix{اور چاند بے نور ہو جائیگا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlx{اور چاند سورج ملا کر ایک کر دیے جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxi{اُس وقت یہی انسان کہے گا ``کہاں بھاگ کر جاؤں؟"\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxii{ہرگز نہیں، وہاں کوئی جائے پناہ نہ ہوگی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiii{اُس روز تیرے رب ہی کے سامنے جا کر ٹھیرنا ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiv{اُس روز انسان کو اس کا سب اگلا پچھلا کیا کرایا بتا دیا جائے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxv{بلکہ انسان خود ہی اپنے آپ کو خوب جانتا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvi{چاہے وہ کتنی ہی معذرتیں پیش کرے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvii{اے نبیؐ، اِس وحی کو جلدی جلدی یاد کرنے کے لیے اپنی زبان کو حرکت نہ دو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxviii{اِس کو یاد کرا دینا اور پڑھوا دینا ہمارے ذمہ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxix{لہٰذا جب ہم اِسے پڑھ رہے ہوں اُس وقت تم اِس کی قرات کو غور سے سنتے رہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxx{پھر اس کا مطلب سمجھا دینا بھی ہمارے ذمہ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxi{ہرگز نہیں، اصل بات یہ ہے کہ تم لوگ جلدی حاصل ہونے والی چیز (یعنی دنیا) سے محبت رکھتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxii{اور آخرت کو چھوڑ دیتے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiii{اُس روز کچھ چہرے تر و تازہ ہونگے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiv{اپنے رب کی طرف دیکھ رہے ہونگے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxv{اور کچھ چہرے اداس ہوں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvi{اور سمجھ رہے ہوں گے کہ اُن کے ساتھ کمر توڑ برتاؤ ہونے والا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvii{ہرگز نہیں، جب جان حلق تک پہنچ جائے گی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxviii{اور کہا جائے گا کہ ہے کوئی جھاڑ پھونک کرنے والا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxix{اور آدمی سمجھ لے گا کہ یہ دنیا سے جدائی کا وقت ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxx{اور پنڈلی سے پنڈلی جڑ جائے گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxi{وہ دن ہوگا تیرے رب کی طرف روانگی کا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxii{مگر اُس نے نہ سچ مانا، اور نہ نماز پڑھی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiii{بلکہ جھٹلایا اور پلٹ گیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiv{پھر اکڑتا ہوا اپنے گھر والوں کی طرف چل دیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxv{یہ روش تیرے ہی لیے سزاوار ہے اور تجھی کو زیب دیتی ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvi{ہاں یہ روش تیرے ہی لیے سزاوار ہے اور تجھی کو زیب دیتی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvii{کیا انسان نے یہ سمجھ رکھا ہے کہ وہ یونہی مہمل چھوڑ دیا جائے گا؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxviii{کیا وہ ایک حقیر پانی کا نطفہ نہ تھا جو (رحم مادر میں) ٹپکایا جاتا ہے؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxix{پھر وہ ایک لوتھڑا بنا، پھر اللہ نے اس کا جسم بنایا اور اس کے اعضا درست کیے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxc{پھر اس سے مرد اور عورت کی دو قسمیں بنائیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxci{کیا وہ اِس پر قادر نہیں ہے کہ مرنے والوں کو پھر زندہ کر دے؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcii{\basmalahur کیا انسان پر لا متناہی زمانے کا ایک وقت ایسا بھی گزرا ہے جب وہ کوئی قابل ذکر چیز نہ تھا؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciii{ہم نے انسان کو ایک مخلوط نطفے سے پیدا کیا تاکہ اس کا امتحان لیں اور اِس غرض کے لیے ہم نے اسے سننے اور دیکھنے والا بنایا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciv{ہم نے اسے راستہ دکھا دیا، خواہ شکر کرنے والا بنے یا کفر کرنے والا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcv{کفر کرنے والوں کے لیے ہم نے زنجیریں اور طوق اور بھڑکتی ہوئی آگ مہیا کر رکھی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvi{نیک لوگ (جنت میں) شراب کے ایسے ساغر پئیں گے جن میں آب کافور کی آمیزش ہوگی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvii{یہ ایک بہتا چشمہ ہوگا جس کے پانی کے ساتھ اللہ کے بندے شراب پئیں گے اور جہاں چاہیں گے بسہولت اس کی شاخیں لیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcviii{یہ وہ لوگ ہونگے جو (دنیا میں) نذر پوری کرتے ہیں، اور اُس دن سے ڈرتے ہیں جس کی آفت ہر طرف پھیلی ہوئی ہوگی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcix{اور اللہ کی محبت میں مسکین اور یتیم اور قیدی کو کھانا کھلاتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdc{(اور اُن سے کہتے ہیں کہ) ہم تمہیں صرف اللہ کی خاطر کھلا رہے ہیں، ہم تم سے نہ کوئی بدلہ چاہتے ہیں نہ شکریہ\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdci{ہمیں تو اپنے رب سے اُس دن کے عذاب کا خوف لاحق ہے جو سخت مصیبت کا انتہائی طویل دن ہوگا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcii{پس اللہ تعالیٰ انہیں اُس دن کے شر سے بچا لے گا اور انہیں تازگی اور سرور بخشے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciii{اور اُن کے صبر کے بدلے میں اُنہیں جنت اور ریشمی لباس عطا کریگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciv{وہاں وہ اونچی مسندوں پر تکیے لگائے بیٹھے ہونگے نہ اُنہیں دھوپ کی گرمی ستائے گی نہ جاڑے کی ٹھر\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcv{جنت کی چھاؤں ان پر جھکی ہوئی سایہ کر رہی ہوگی، اور اُس کے پھل ہر وقت ان کے بس میں ہوں گے (کہ جس طرح چاہیں انہیں توڑ لیں)\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvi{اُن کے آگے چاندی کے برتن اور شیشے کے پیالے گردش کرائے جا رہے ہونگے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvii{شیشے بھی وہ جو چاندی کی قسم کے ہونگے، اور ان کو (منتظمین جنت نے) ٹھیک اندازے کے مطابق بھرا ہوگا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcviii{ان کو وہاں ایسی شراب کے جام پلائے جائیں گے جس میں سونٹھ کی آمیزش ہوگی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcix{یہ جنت کا ایک چشمہ ہوگا جسے سلسبیل کہا جاتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcx{ان کی خدمت کے لیے ایسے لڑکے دوڑتے پھر رہے ہوں گے جو ہمیشہ لڑکے ہی رہیں گے تم انہیں دیکھو تو سمجھو کہ موتی ہیں جو بکھیر دیے گئے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxi{وہاں جدھر بھی تم نگاہ ڈالو گے نعمتیں ہی نعمتیں اور ایک بڑی سلطنت کا سر و سامان تمہیں نظر آئے گا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxii{اُن کے اوپر باریک ریشم کے سبز لباس اور اطلس و دیبا کے کپڑے ہوں گے، ان کو چاندی کے کنگن پہنا ئے جائیں گے، اور ان کا رب ان کو نہایت پاکیزہ شراب پلائے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiii{یہ ہے تمہاری جزا اور تمہاری کارگزاری قابل قدر ٹھیری ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiv{اے نبیؐ، ہم نے ہی تم پر یہ قرآن تھوڑا تھوڑا کر کے نازل کیا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxv{لہٰذا تم اپنے رب کے حکم پر صبر کرو، اور اِن میں سے کسی بد عمل یا منکر حق کی بات نہ مانو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvi{اپنے رب کا نام صبح و شام یاد کرو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvii{رات کو بھی اس کے حضور سجدہ ریز ہو، اور رات کے طویل اوقات میں اُس کی تسبیح کرتے رہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxviii{یہ لوگ تو جلدی حاصل ہونے والی چیز (دنیا) سے محبت رکھتے ہیں اور آگے جو بھاری دن آنے والا ہے اسے نظر انداز کر دیتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxix{ہم نے ہی اِن کو پیدا کیا ہے اور ان کے جوڑ بند مضبوط کیے ہیں، اور ہم جب چاہیں اِن کی شکلوں کو بدل کر رکھ دیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxx{یہ ایک نصیحت ہے، اب جس کا جی چاہے اپنے رب کی طرف جانے کا راستہ اختیار کر لے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxi{اور تمہارے چاہنے سے کچھ نہیں ہوتا جب تک اللہ نہ چاہے یقیناً اللہ بڑا علیم و حکیم ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxii{اپنی رحمت میں جس کو چاہتا ہے داخل کرتا ہے، اور ظالموں کے لیے اس نے دردناک عذاب تیار کر رکھا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiii{\basmalahur قسم ہے اُن (ہواؤں) کی جو پے در پے بھیجی جاتی ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiv{پھر طوفانی رفتار سے چلتی ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxv{اور (بادلوں کو) اٹھا کر پھیلاتی ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvi{پھر (اُن کو) پھاڑ کر جدا کرتی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvii{پھر (دلوں میں خدا کی) یاد ڈالتی ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxviii{عذر کے طور پر یا ڈراوے کے طور پر\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxix{جس چیز کا تم سے وعدہ کیا جا رہا ہے وہ ضرور واقع ہونے والی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxx{پھر جب ستارے ماند پڑ جائیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxi{اور آسمان پھاڑ دیا جائے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxii{اور پہاڑ دھنک ڈالے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiii{اور رسولوں کی حاضری کا وقت آ پہنچے گا (اس روز وہ چیز واقع ہو جائے گی)\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiv{کس روز کے لیے یہ کام اٹھا رکھا گیا ہے؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxv{فیصلے کے روز کے لیے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvi{اور تمہیں کیا خبر کہ وہ فیصلے کا دن کیا ہے؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvii{تباہی ہے اُس دن جھٹلانے والوں کے لیے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxviii{کیا ہم نے اگلوں کو ہلاک نہیں کیا؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxix{پھر اُنہی کے پیچھے ہم بعد والوں کو چلتا کریں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxl{مجرموں کے ساتھ ہم یہی کچھ کیا کرتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxli{تباہی ہے اُس دن جھٹلانے والوں کے لیے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlii{کیا ہم نے ایک حقیر پانی سے تمہیں پیدا نہیں کیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliii{اور ایک مقررہ مدت تک،\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliv{اُسے ایک محفوظ جگہ ٹھیرائے رکھا؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlv{تو دیکھو، ہم اِس پر قادر تھے، پس ہم بہت اچھی قدرت رکھنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvi{تباہی ہے اُس روز جھٹلانے والوں کے لیے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvii{کیا ہم نے زمین کو سمیٹ کر رکھنے والی نہیں بنایا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlviii{زندوں کے لیے بھی اور مُردوں کے لیے بھی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlix{اور اس میں بلند و بالا پہاڑ جمائے، اور تمہیں میٹھا پانی پلایا؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcl{تباہی ہے اُس روز جھٹلانے والوں کے لیے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcli{چلو اب اُسی چیز کی طرف جسے تم جھٹلایا کرتے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclii{چلو اُس سائے کی طرف جو تین شاخوں والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliii{نہ ٹھنڈک پہنچانے والا اور نہ آگ کی لپٹ سے بچانے والا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliv{وہ آگ محل جیسی بڑی بڑی چنگاریاں پھینکے گی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclv{(جو اچھلتی ہوئی یوں محسوس ہوں گی) گویا کہ وہ زرد اونٹ ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvi{تباہی ہے اُس روز جھٹلانے والوں کے لیے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvii{یہ وہ دن ہے جس میں وہ نہ کچھ بولیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclviii{اور نہ اُنہیں موقع دیا جائے گا کہ کوئی عذر پیش کریں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclix{تباہی ہے اُس دن جھٹلانے والوں کے لیے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclx{یہ فیصلے کا دن ہے ہم نے تمہیں اور تم سے پہلے گزرے ہوئے لوگوں کو جمع کر دیا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxi{اب اگر کوئی چال تم چل سکتے ہو تو میرے مقابلہ میں چل دیکھو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxii{تباہی ہے اُس دن جھٹلانے والوں کے لیے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiii{متقی لوگ آج سایوں اور چشموں میں ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiv{اور جو پھل وہ چاہیں (اُن کے لیے حاضر ہیں)\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxv{کھاؤ اور پیو مزے سے اپنے اُن اعمال کے صلے میں جو تم کرتے رہے ہو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvi{ہم نیک لوگوں کو ایسی ہی جزا دیتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvii{تباہی ہے اُس روز جھٹلانے والوں کے لیے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxviii{کھا لو اور مزے کر لو تھوڑے دن حقیقت میں تم لوگ مجرم ہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxix{تباہی ہے اُس روز جھٹلانے والوں کے لیے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxx{جب اِن سے کہا جاتا ہے کہ (اللہ کے آگے) جھکو تو نہیں جھکتے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxi{تباہی ہے اُس روز جھٹلانے والوں کے لیے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxii{اب اِس (قرآن) کے بعد اور کونسا کلام ایسا ہو سکتا ہے جس پر یہ ایمان لائیں؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiii{\basmalahur یہ لوگ کس چیز کے بارے میں پوچھ گچھ کر رہے ہیں؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiv{کیا اُس بڑی خبر کے بارے میں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxv{جس کے متعلق یہ مختلف چہ میگوئیاں کرنے میں لگے ہوئے ہیں؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvi{ہرگز نہیں، عنقریب اِنہیں معلوم ہو جائیگا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvii{ہاں، ہرگز نہیں، عنقریب اِنہیں معلوم ہو جائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxviii{کیا یہ واقعہ نہیں ہے کہ ہم نے زمین کو فرش بنایا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxix{اور پہاڑوں کو میخوں کی طرح گاڑ دیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxx{اور تمہیں (مَردوں اور عورتوں کے) جوڑوں کی شکل میں پیدا کیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxi{اور تمہاری نیند کو باعث سکون بنایا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxii{اور رات کو پردہ پوش\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiii{اور دن کو معاش کا وقت بنایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiv{اور تمہارے اوپر سات مضبوط آسمان قائم کیے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxv{اور ایک نہایت روشن اور گرم چراغ پیدا کیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvi{اور بادلوں سے لگاتار بارش برسائی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvii{تاکہ اس کے ذریعہ سے غلہ اور سبزی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxviii{اور گھنے باغ اگائیں؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxix{بے شک فیصلے کا دن ایک مقرر وقت ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxc{جس روز صور میں پھونک مار دی جائے گی، تم فوج در فوج نکل آؤ گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxci{اور آسمان کھول دیا جائے گا حتیٰ کہ وہ دروازے ہی دروازے بن کر رہ جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcii{اور پہاڑ چلائے جائیں گے یہاں تک کہ وہ سراب ہو جائیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciii{درحقیقت جہنم ایک گھات ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciv{سرکشوں کا ٹھکانا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcv{جس میں وہ مدتوں پڑے رہیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvi{اُس کے اندر کسی ٹھنڈک اور پینے کے قابل کسی چیز کا مزہ وہ نہ چکھیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvii{کچھ ملے گا تو بس گرم پانی اور زخموں کا دھوون\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcviii{(اُن کے کرتوتوں) کا بھرپور بدلہ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcix{وہ کسی حساب کی توقع نہ رکھتے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcc{اور ہماری آیات کو انہوں نے بالکل جھٹلا دیا تھا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcci{اور حال یہ تھا کہ ہم نے ہر چیز گن گن کر لکھ رکھی تھی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccii{اب چکھو مزہ، ہم تمہارے لیے عذاب کے سوا کسی چیز میں ہرگز اضافہ نہ کریں گے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciii{یقیناً متقیوں کے لیے کامرانی کا ایک مقام ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciv{باغ اور انگور\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccv{اور نوخیر ہم سن لڑکیاں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvi{اور چھلکتے ہوئے جام\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvii{وہاں کوئی لغو اور جھوٹی بات وہ نہ سنیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccviii{جزا اور کافی انعام تمہارے رب کی طرف سے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccix{اُس نہایت مہربان خدا کی طرف سے جو زمین اور آسمانوں کا اور ان کے درمیان کی ہر چیز کا مالک ہے جس کے سامنے کسی کو بولنے کا یارا نہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccx{جس روز روح اور ملائکہ صف بستہ کھڑے ہونگے، کوئی نہ بولے گا سوائے اُس کے جسے رحمٰن اجازت دے اور جو ٹھیک بات کہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxi{وہ دن برحق ہے، اب جس کا جی چاہے اپنے رب کی طرف پلٹنے کا راستہ اختیار کر لے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxii{ہم نے تم لوگوں کو اُس عذاب سے ڈرا دیا ہے جو قریب آ لگا ہے جس روز آدمی وہ سب کچھ دیکھ لے گا جو اس کے ہاتھوں نے آگے بھیجا ہے، اور کافر پکار اٹھے گا کہ کاش میں خاک ہوتا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiii{\basmalahur قسم ہے اُن (فرشتوں کی) جو ڈوب کر کھینچتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiv{اور آہستگی سے نکال لے جاتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxv{اور (اُن فرشتوں کی جو کائنات میں) تیزی سے تیرتے پھرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvi{پھر (حکم بجا لانے میں) سبقت کرتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvii{پھر (احکام الٰہی کے مطابق) معاملات کا انتظام چلاتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxviii{جس روز ہلا مارے گا زلزلے کا جھٹکا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxix{اور اس کے پیچھے ایک اور جھٹکا پڑے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxx{کچھ دل ہوں گے جو اُس روز خوف سے کانپ رہے ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxi{نگاہیں اُن کی سہمی ہوئی ہوں گی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxii{یہ لوگ کہتے ہیں ``کیا واقعی ہم پلٹا کر پھر واپس لائے جائیں گے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiii{کیا جب ہم کھوکھلی بوسیدہ ہڈیاں بن چکے ہوں گے؟"\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiv{کہنے لگے ``یہ واپسی تو پھر بڑے گھاٹے کی ہوگی!"\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxv{حالانکہ یہ بس اتنا کام ہے کہ ایک زور کی ڈانٹ پڑے گی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvi{اور یکایک یہ کھلے میدان میں موجود ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvii{کیا تمہیں موسیٰؑ کے قصے کی خبر پہنچی ہے؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxviii{جب اس کے رب نے اُسے طویٰ کی مقدس وادی میں پکارا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxix{کہ ``فرعون کے پاس جا، وہ سرکش ہو گیا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxx{اور اس سے کہہ کیا تو اِس کے لیے تیار ہے کہ پاکیزگی اختیار کرے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxi{اور میں تیرے رب کی طرف تیری رہنمائی کروں تو (اُس کا) خوف تیرے اندر پیدا ہو؟"\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxii{پھر موسیٰؑ نے (فرعون کے پاس جا کر) اُس کو بڑی نشانی دکھائی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiii{مگر اُس نے جھٹلا دیا اور نہ مانا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiv{پھر چالبازیاں کرنے کے لیے پلٹا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxv{اور لوگوں کو جمع کر کے اس نے پکار کر کہا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvi{``میں تمہارا سب سے بڑا رب ہوں"\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvii{آخرکار اللہ نے اسے آخرت اور دنیا کے عذاب میں پکڑ لیا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxviii{درحقیقت اِس میں بڑی عبرت ہے ہر اُس شخص کے لیے جو ڈرے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxix{کیا تم لوگوں کی تخلیق زیادہ سخت کام ہے یا آسمان کی؟ اللہ نے اُس کو بنایا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxl{اُس کی چھت خوب اونچی اٹھائی پھر اُس کا توازن قائم کیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxli{اور اُس کی رات ڈھانکی اور اُس کا دن نکالا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlii{اِس کے بعد زمین کو اس نے بچھایا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliii{اُس کے اندر سے اُس کا پانی اور چارہ نکالا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliv{اور پہاڑ اس میں گاڑ دیے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlv{سامان زیست کے طور پر تمہارے لیے اور تمہارے مویشیوں کے لیے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvi{پھر جب وہ ہنگامہ عظیم برپا ہوگا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvii{جس روز انسان اپنا سب کیا دھرا یاد کرے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlviii{اور ہر دیکھنے والے کے سامنے دوزخ کھول کر رکھ دی جائے گی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlix{تو جس نے سرکشی کی تھی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccl{اور دنیا کی زندگی کو ترجیح دی تھی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccli{دوزخ ہی اس کا ٹھکانا ہوگی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclii{اور جس نے اپنے رب کے سامنے کھڑے ہونے کا خوف کیا تھا اور نفس کو بری خواہشات سے باز رکھا تھا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliii{جنت اس کا ٹھکانا ہوگی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliv{یہ لوگ تم سے پوچھتے ہیں کہ ``آخر وہ گھڑی کب آ کر ٹھیرے گی؟"\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclv{تمہارا کیا کام کہ اس کا وقت بتاؤ\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvi{اس کا علم تو اللہ پر ختم ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvii{تم صرف خبردار کرنے والے ہو ہر اُس شخص کو جو اُس کا خوف کرے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclviii{جس روز یہ لوگ اسے دیکھ لیں گے تو انہیں یوں محسوس ہوگا کہ (یہ دنیا میں یا حالت موت میں) بس ایک دن کے پچھلے پہر یا اگلے پہر تک ٹھیرے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclix{\basmalahur ترش رو ہوا، اور بے رخی برتی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclx{اِس بات پر کہ وہ اندھا اُس کے پاس آ گیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxi{تمہیں کیا خبر، شاید وہ سدھر جائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxii{یا نصیحت پر دھیان دے، اور نصیحت کرنا اس کے لیے نافع ہو؟\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiii{جو شخص بے پروائی برتتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiv{اس کی طرف تو تم توجہ کرتے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxv{حالانکہ اگر وہ نہ سدھرے تو تم پر اس کی کیا ذمہ داری ہے؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvi{اور جو خود تمہارے پاس دوڑا آتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvii{اور وہ ڈر رہا ہوتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxviii{اس سے تم بے رخی برتتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxix{ہرگز نہیں، یہ تو ایک نصیحت ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxx{جس کا جی چاہے اِسے قبول کرے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxi{یہ ایسے صحیفوں میں درج ہے جو مکرم ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxii{بلند مرتبہ ہیں، پاکیزہ ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiii{معزز اور نیک کاتبوں کے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiv{ہاتھوں میں رہتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxv{لعنت ہو انسان پر، کیسا سخت منکر حق ہے یہ\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvi{کس چیز سے اللہ نے اِسے پیدا کیا ہے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvii{نطفہ کی ایک بوند سے اللہ نے اِسے پیدا کیا، پھر اِس کی تقدیر مقرر کی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxviii{پھر اِس کے لیے زندگی کی راہ آسان کی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxix{پھر اِسے موت دی اور قبر میں پہنچایا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxx{پھر جب چاہے وہ اِسے دوبارہ اٹھا کھڑا کرے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxi{ہرگز نہیں، اِس نے وہ فرض ادا نہیں کیا جس کا اللہ نے اِسے حکم دیا تھا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxii{پھر ذرا انسان اپنی خوراک کو دیکھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiii{ہم نے خوب پانی لنڈھایا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiv{پھر زمین کو عجیب طرح پھاڑا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxv{پھر اُس کے اندر اگائے غلے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvi{اور انگور اور ترکاریاں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvii{اور زیتون اور کھجوریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxviii{اور گھنے باغ\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxix{اور طرح طرح کے پھل، اور چارے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxc{تمہارے لیے اور تمہارے مویشیوں کے لیے سامان زیست کے طور پر\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxci{آخرکار جب وہ کان بہرے کر دینے والی آواز بلند ہوگی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcii{اُس روز آدمی اپنے بھائی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciii{اور اپنی ماں اور اپنے باپ\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciv{اور اپنی بیوی اور اپنی اولاد سے بھاگے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcv{ان میں سے ہر شخص پر اس دن ایسا وقت آ پڑے گا کہ اسے اپنے سوا کسی کا ہوش نہ ہوگا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvi{کچھ چہرے اُس روز دمک رہے ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvii{ہشاش بشاش اور خوش و خرم ہوں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcviii{اور کچھ چہروں پر اس روز خاک اڑ رہی ہوگی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcix{اور کلونس چھائی ہوئی ہوگی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccc{یہی کافر و فاجر لوگ ہوں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccci{\basmalahur جب سورج لپیٹ دیا جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccii{اور جب تارے بکھر جائیں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciii{اور جب پہاڑ چلائے جائیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciv{اور جب دس مہینے کی حاملہ اونٹنیاں اپنے حال پر چھوڑ دی جائیں گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccv{اور جب جنگلی جانور سمیٹ کر اکٹھے کر دیے جائیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvi{اور جب سمندر بھڑکا دیے جائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvii{اور جب جانیں (جسموں سے) جوڑ دی جائیں گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccviii{اور جب زندہ گاڑی ہوئی لڑکی سے پوچھا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccix{کہ وہ کس قصور میں ماری گئی؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccx{اور جب اعمال نامے کھولے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxi{اور جب آسمان کا پردہ ہٹا دیا جائے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxii{اور جب جہنم دہکائی جائے گی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiii{اور جب جنت قریب لے آئی جائے گی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiv{اُس وقت ہر شخص کو معلوم ہو جائے گا کہ وہ کیا لے کر آیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxv{پس نہیں، میں قسم کھاتا ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvi{پلٹنے اور چھپ جانے والے تاروں کی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvii{اور رات کی جبکہ وہ رخصت ہوئی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxviii{اور صبح کی جبکہ اس نے سانس لیا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxix{یہ فی الواقع ایک بزرگ پیغام بر کا قول ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxx{جو بڑی توانائی رکھتا ہے، عرش والے کے ہاں بلند مرتبہ ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxi{وہاں اُس کا حکم مانا جاتا ہے، وہ با اعتماد ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxii{اور (اے اہل مکہ) تمہارا رفیق مجنون نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiii{اُس نے اُس پیغام بر کو روشن افق پر دیکھا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiv{اور وہ غیب (کے اِس علم کو لوگوں تک پہنچانے) کے معاملے میں بخیل نہیں ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxv{اور یہ کسی شیطان مردود کا قول نہیں ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvi{پھر تم لوگ کدھر چلے جا رہے ہو؟\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvii{یہ تو سارے جہان والوں کے لیے ایک نصیحت ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxviii{تم میں سے ہر اُس شخص کے لیے جو راہ راست پر چلنا چاہتا ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxix{اور تمہارے چاہنے سے کچھ نہیں ہوتا جب تک اللہ رب العالمین نہ چاہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxx{\basmalahur جب آسمان پھٹ جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxi{اور جب تارے بکھر جائیں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxii{اور جب سمندر پھاڑ دیے جائیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiii{اور جب قبریں کھول دی جائیں گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiv{اُس وقت ہر شخص کو اُس کا اگلا پچھلا سب کیا دھرا معلوم ہو جائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxv{اے انسان، کس چیز نے تجھے اپنے اُس رب کریم کی طرف سے دھوکے میں ڈال دیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvi{جس نے تجھے پیدا کیا، تجھے نک سک سے درست کیا، تجھے متناسب بنایا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvii{اور جس صورت میں چاہا تجھ کو جوڑ کر تیار کیا؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxviii{ہرگز نہیں، بلکہ (اصل بات یہ ہے کہ) تم لوگ جزا و سزا کو جھٹلاتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxix{حالانکہ تم پر نگراں مقرر ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxl{ایسے معزز کاتب\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxli{جو تمہارے ہر فعل کو جانتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlii{یقیناً نیک لوگ مزے میں ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliii{اور بے شک بدکار لوگ جہنم میں جائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliv{جزا کے دن وہ اس میں داخل ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlv{اور اُس سے ہرگز غائب نہ ہو سکیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvi{اور تم کیا جانتے ہو کہ وہ جزا کا دن کیا ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvii{ہاں، تمہیں کیا خبر کہ وہ جزا کا دن کیا ہے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlviii{یہ وہ دن ہے جب کسی شخص کے لیے کچھ کرنا کسی کے بس میں نہ ہوگا، فیصلہ اُس دن بالکل اللہ کے اختیار میں ہوگا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlix{\basmalahur تباہی ہے ڈنڈی مارنے والوں کے لیے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccl{جن کا حال یہ ہے کہ جب لوگوں سے لیتے ہیں تو پورا پورا لیتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccli{اور جب ان کو ناپ کر یا تول کر دیتے ہیں تو انہیں گھاٹا دیتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclii{کیا یہ لوگ نہیں سمجھتے کہ ایک بڑے دن،\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliii{یہ اٹھا کر لائے جانے والے ہیں؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliv{اُس دن جبکہ سب لوگ رب العالمین کے سامنے کھڑے ہوں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclv{ہرگز نہیں، یقیناً بد کاروں کا نامہ اعمال قید خانے کے دفتر میں ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvi{اور تمہیں کیا معلوم کہ وہ قید خانے کا دفتر کیا ہے؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvii{ایک کتاب ہے لکھی ہوئی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclviii{تباہی ہے اُس روز جھٹلانے والوں کے لیے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclix{جو روز جزا کو جھٹلاتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclx{اور اُسے نہیں جھٹلاتا مگر ہر وہ شخص جو حد سے گزر جانے والا بد عمل ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxi{اُسے جب ہماری آیات سنائی جاتی ہیں تو کہتا ہے یہ تو اگلے وقتوں کی کہانیاں ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxii{ہرگز نہیں، بلکہ دراصل اِن لوگوں کے دلوں پر اِن کے برے اعمال کا زنگ چڑھ گیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiii{ہرگز نہیں، بالیقین اُس روز یہ اپنے رب کی دید سے محروم رکھے جائیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiv{پھر یہ جہنم میں جا پڑیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxv{پھر اِن سے کہا جائے گا کہ یہ وہی چیز ہے جسے تم جھٹلایا کرتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvi{ہرگز نہیں، بے شک نیک آدمیوں کا نامہ اعمال بلند پایہ لوگوں کے دفتر میں ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvii{اور تمہیں کیا خبر کہ کیا ہے وہ بلند پایہ لوگوں کا دفتر؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxviii{ایک لکھی ہوئی کتاب ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxix{جس کی نگہداشت مقرب فرشتے کرتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxx{بے شک نیک لوگ بڑے مزے میں ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxi{اونچی مسندوں پر بیٹھے نظارے کر رہے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxii{ان کے چہروں پر تم خوشحالی کی رونق محسوس کرو گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiii{ان کو نفیس ترین سر بند شراب پلائی جائے گی جس پر مشک کی مہر لگی ہوگی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiv{جو لوگ دوسروں پر بازی لے جانا چاہتے ہوں وہ اِس چیز کو حاصل کرنے میں بازی لے جانے کی کوشش کریں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxv{اُس شراب میں تسنیم کی آمیزش ہوگی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvi{یہ ایک چشمہ ہے جس کے پانی کے ساتھ مقرب لوگ شراب پئیں گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvii{مجرم لوگ دنیا میں ایمان لانے والوں کا مذاق اڑاتے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxviii{جب اُن کے پاس سے گزرتے تو آنکھیں مار مار کر اُن کی طرف اشارے کرتے تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxix{اپنے گھروں کی طرف پلٹتے تو مزے لیتے ہوئے پلٹتے تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxx{اور جب انہیں دیکھتے تو کہتے تھے کہ یہ بہکے ہوئے لوگ ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxi{حالانکہ وہ اُن پر نگراں بنا کر نہیں بھیجے گئے تھے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxii{آج ایمان لانے والے کفار پر ہنس رہے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiii{مسندوں پر بیٹھے ہوئے ان کا حال دیکھ رہے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiv{مل گیا نا کافروں کو اُن حرکتوں کا ثواب جو وہ کیا کرتے تھے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxv{\basmalahur جب آسمان پھٹ جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvi{اور اپنے رب کے فرمان کی تعمیل کرے گا اور اُس کے لیے حق یہی ہے (کہ اپنے رب کا حکم مانے)\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvii{اور جب زمین پھیلا دی جائے گی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxviii{اور جو کچھ اس کے اندر ہے اُسے باہر پھینک کر خالی ہو جائے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxix{اور اپنے رب کے حکم کی تعمیل کرے گی اور اُس کے لیے حق یہی ہے (کہ اس کی تعمیل کرے)\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxc{اے انسان، تو کشاں کشاں اپنے رب کی طرف چلا جا رہا ہے، اور اُس سے ملنے والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxci{پھر جس کا نامہ اعمال اُس کے سیدھے ہاتھ میں دیا گیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcii{اُس سے ہلکا حساب لیا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciii{اور وہ اپنے لوگوں کی طرف خوش خوش پلٹے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciv{رہا وہ شخص جس کا نامہ اعمال اُس کی پیٹھ کے پیچھے دیا جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcv{تو وہ موت کو پکارے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvi{اور بھڑکتی ہوئی آگ میں جا پڑے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvii{وہ اپنے گھر والوں میں مگن تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcviii{اُس نے سمجھا تھا کہ اسے کبھی پلٹنا نہیں ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcix{پلٹنا کیسے نہ تھا، اُس کا رب اُس کے کرتوت دیکھ رہا تھا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcm{پس نہیں، میں قسم کھاتا ہوں شفق کی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmi{اور رات کی اور جو کچھ وہ سمیٹ لیتی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmii{اور چاند کی جب کہ وہ ماہ کامل ہو جاتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiii{تم کو ضرور درجہ بدرجہ ایک حالت سے دوسری حالت کی طرف گزرتے چلے جانا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiv{پھر اِن لوگوں کو کیا ہو گیا ہے کہ یہ ایمان نہیں لاتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmv{اور جب قرآن اِن کے سامنے پڑھا جاتا ہے تو سجدہ نہیں کرتے؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvi{بلکہ یہ منکرین تو الٹا جھٹلاتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvii{حالانکہ جو کچھ یہ (اپنے نامہ اعمال میں) جمع کر رہے ہیں اللہ اُسے خوب جانتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmviii{لہٰذا اِن کو دردناک عذاب کی بشارت دے دو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmix{البتہ جو لوگ ایمان لے آئے ہیں اور جنہوں نے نیک عمل کیے ہیں ان کے لیے کبھی ختم نہ ہونے والا اجر ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmx{\basmalahur قسم ہے مضبوط قلعوں والے آسمان کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxi{اور اُس دن کی جس کا وعدہ کیا گیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxii{اور دیکھنے والے کی اور دیکھی جانے والی چیز کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiii{کہ مارے گئے گڑھے والے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiv{(اُس گڑھے والے) جس میں خوب بھڑکتے ہوئے ایندھن کی آگ تھی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxv{جبکہ وہ اُس گڑھے کے کنارے بیٹھے ہوئے تھے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvi{اور جو کچھ وہ ایمان لانے والوں کے ساتھ کر رہے تھے اُسے دیکھ رہے تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvii{اور اُن اہل ایمان سے اُن کی دشمنی اِس کے سوا کسی وجہ سے نہ تھی کہ وہ اُس خدا پر ایمان لے آئے تھے جو زبردست اور اپنی ذات میں آپ محمود ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxviii{جو آسمانوں اور زمین کی سلطنت کا مالک ہے، اور وہ خدا سب کچھ دیکھ رہا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxix{جن لوگوں نے مومن مردوں اور عورتوں پر ظلم و ستم توڑا اور پھر اس سے تائب نہ ہوئے، یقیناً اُن کے لیے جہنم کا عذاب ہے اور ان کے لیے جلائے جانے کی سزا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxx{جو لوگ ایمان لائے اور جنہوں نے نیک عمل کیے، یقیناً اُن کے لیے جنت کے باغ ہیں جن کے نیچے نہریں بہتی ہوں گی، یہ ہے بڑی کامیابی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxi{درحقیقت تمہارے رب کی پکڑ بڑی سخت ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxii{وہی پہلی بار پیدا کرتا ہے اور وہی دوبارہ پیدا کرے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiii{اور وہ بخشنے والا ہے، محبت کرنے والا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiv{عرش کا مالک ہے، بزرگ و برتر ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxv{اور جو کچھ چاہے کر ڈالنے والا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvi{کیا تمہیں لشکروں کی خبر پہنچی ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvii{فرعون اور ثمود (کے لشکروں) کی؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxviii{مگر جنہوں نے کفر کیا ہے وہ جھٹلانے میں لگے ہوئے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxix{حالانکہ اللہ نے ان کو گھیرے میں لے رکھا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxx{(اُن کے جھٹلانے سے اِس قرآن کا کچھ نہیں بگڑتا) بلکہ یہ قرآن بلند پایہ ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxi{اُس لوح میں (نقش ہے) جو محفوظ ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxii{\basmalahur قسم ہے آسمان کی اور رات کو نمودار ہونے والے کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiii{اور تم کیا جانو کہ وہ رات کو نمودار ہونے والا کیا ہے؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiv{چمکتا ہوا تارا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxv{کوئی جان ایسی نہیں ہے جس کے اوپر کوئی نگہبان نہ ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvi{پھر ذرا انسان یہی دیکھ لے کہ وہ کس چیز سے پیدا کیا گیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvii{ایک اچھلنے والے پانی سے پیدا کیا گیا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxviii{جو پیٹھ اور سینے کی ہڈیوں کے درمیان سے نکلتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxix{یقیناً وہ (خالق) اُسے دوبارہ پیدا کرنے پر قادر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxl{جس روز پوشیدہ اسرار کی جانچ پڑتال ہوگی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxli{اُس وقت انسان کے پاس نہ خود اپنا کوئی زور ہوگا اور نہ کوئی اس کی مدد کرنے والا ہوگا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlii{قسم ہے بارش برسانے والے آسمان کی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliii{اور (نباتات اگتے وقت) پھٹ جانے والی زمین کی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliv{یہ ایک جچی تلی بات ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlv{ہنسی مذاق نہیں ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvi{یہ لوگ چالیں چل رہے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvii{اور میں بھی ایک چال چل رہا ہوں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlviii{پس چھوڑ دو اے نبیؐ، اِن کافروں کو اک ذرا کی ذرا اِن کے حال پر چھوڑ دو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlix{\basmalahur (اے نبیؐ) اپنے رب برتر کے نام کی تسبیح کرو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcml{جس نے پیدا کیا اور تناسب قائم کیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmli{جس نے تقدیر بنائی پھر راہ دکھائی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlii{جس نے نباتات اگائیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliii{پھر اُن کو سیاہ کوڑا کرکٹ بنا دیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliv{ہم تمہیں پڑھوا دیں گے، پھر تم نہیں بھولو گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlv{سوائے اُس کے جو اللہ چاہے، وہ ظاہر کو بھی جانتا ہے اور جو کچھ پوشیدہ ہے اُس کو بھی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvi{اور ہم تمہیں آسان طریقے کی سہولت دیتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvii{لہٰذا تم نصیحت کرو اگر نصیحت نافع ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlviii{جو شخص ڈرتا ہے وہ نصیحت قبول کر لے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlix{اور اس سے گریز کریگا وہ انتہائی بد بخت\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlx{جو بڑی آگ میں جائے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxi{پھر نہ اس میں مرے گا نہ جیے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxii{فلاح پا گیا وہ جس نے پاکیزگی اختیار کی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiii{اور اپنے رب کا نام یاد کیا پھر نماز پڑھی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiv{مگر تم لوگ دنیا کی زندگی کو ترجیح دیتے ہو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxv{حالانکہ آخرت بہتر ہے اور باقی رہنے والی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvi{یہی بات پہلے آئے ہوئے صحیفوں میں بھی کہی گئی تھی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvii{ابراہیمؑ اور موسیٰؑ کے صحیفوں میں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxviii{\basmalahur کیا تمہیں اُس چھا جانے والی آفت کی خبر پہنچی ہے؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxix{کچھ چہرے اُس روز خوف زدہ ہونگے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxx{سخت مشقت کر رہے ہونگے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxi{تھکے جاتے ہونگے، شدید آگ میں جھلس رہے ہونگے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxii{کھولتے ہوئے چشمے کا پانی انہیں پینے کو دیا جائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiii{خار دار سوکھی گھاس کے سوا کوئی کھانا اُن کے لیے نہ ہوگا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiv{جو نہ موٹا کرے نہ بھوک مٹائے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxv{کچھ چہرے اُس روز با رونق ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvi{اپنی کار گزاری پر خوش ہونگے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvii{عالی مقام جنت میں ہوں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxviii{کوئی بیہودہ بات وہاں نہ سنیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxix{اُس میں چشمے رواں ہونگے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxx{اُس کے اندر اونچی مسندیں ہوں گی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxi{ساغر رکھے ہوئے ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxii{گاؤ تکیوں کی قطاریں لگی ہوں گی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiii{اور نفیس فرش بچھے ہوئے ہوں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiv{(یہ لوگ نہیں مانتے) تو کیا یہ اونٹوں کو نہیں دیکھتے کہ کیسے بنائے گئے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxv{آسمان کو نہیں دیکھتے کہ کیسے اٹھایا گیا؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvi{پہاڑوں کو نہیں دیکھتے کہ کیسے جمائے گئے؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvii{اور زمین کو نہیں دیکھتے کہ کیسے بچھائی گئی؟\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxviii{اچھا تو (اے نبیؐ) نصیحت کیے جاؤ، تم بس نصیحت ہی کرنے والے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxix{کچھ ان پر جبر کرنے والے نہیں ہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxc{البتہ جو شخص منہ موڑے گا اور انکار کرے گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxci{تو اللہ اس کو بھاری سزا دے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcii{اِن لوگوں کو پلٹنا ہماری طرف ہی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciii{پھر اِن کا حساب لینا ہمارے ہی ذمہ ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciv{\basmalahur قسم ہے فجر کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcv{اور دس راتوں کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvi{اور جفت اور طاق کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvii{اور رات کی جبکہ وہ رخصت ہو رہی ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcviii{کیا اِس میں کسی صاحب عقل کے لیے کوئی قسم ہے؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcix{تم نے دیکھا نہیں کہ تمہارے رب نے کیا برتاؤ کیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmm{اونچے ستونوں والے عاد ارم کے ساتھ\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmi{جن کے مانند کوئی قوم دنیا کے ملکوں میں پیدا نہیں کی گئی تھی؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmii{اور ثمود کے ساتھ جنہوں نے وادی میں چٹانیں تراشی تھیں؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiii{اور میخوں والے فرعون کے ساتھ؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiv{یہ وہ لوگ تھے جنہوں نے دنیا کے ملکوں میں بڑی سرکشی کی تھی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmv{اور ان میں بہت فساد پھیلایا تھا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvi{آخرکار تمہارے رب نے ان پر عذاب کا کوڑا برسا دیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvii{حقیقت یہ ہے کہ تمہارا رب گھات لگائے ہوئے ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmviii{مگر انسان کا حال یہ ہے کہ اس کا رب جب اُس کو آزمائش میں ڈالتا ہے اور اُسے عزت اور نعمت دیتا ہے تو وہ کہتا ہے کہ میرے رب نے مجھے عزت دار بنا دیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmix{اور جب وہ اُس کو آزمائش میں ڈالتا ہے اور اُس کا رزق اُس پر تنگ کر دیتا ہے تو وہ کہتا ہے کہ میرے رب نے مجھے ذلیل کر دیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmx{ہرگز نہیں، بلکہ تم یتیم سے عزت کا سلوک نہیں کرتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxi{اور مسکین کو کھانا کھلانے پر ایک دوسرے کو نہیں اکساتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxii{اور میراث کا سارا مال سمیٹ کر کھا جاتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiii{اور مال کی محبت میں بری طرح گرفتار ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiv{ہرگز نہیں، جب زمین پے در پے کوٹ کوٹ کر ریگ زار بنا دی جائے گی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxv{اور تمہارا رب جلوہ فرما ہوگا اِس حال میں کہ فرشتے صف در صف کھڑے ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvi{اور جہنم اُس روز سامنے لے آئی جائے گی، اُس دن انسان کو سمجھ آئے گی اور اس وقت اُس کے سمجھنے کا کیا حاصل؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvii{وہ کہے گا کہ کاش میں نے اپنی اِس زندگی کے لیے کچھ پیشگی سامان کیا ہوتا!\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxviii{پھر اُس دن اللہ جو عذاب دے گا ویسا عذاب دینے والا کوئی نہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxix{اور اللہ جیسا باندھے گا ویسا باندھنے والا کوئی نہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxx{(دوسری طرف ارشاد ہوگا) اے نفس مطمئن!\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxi{چل اپنے رب کی طرف، اِس حال میں کہ تو (اپنے انجام نیک سے) خوش (اور اپنے رب کے نزدیک) پسندیدہ ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxii{شامل ہو جا میرے (نیک) بندوں میں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiii{اور داخل ہو جا میری جنت میں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiv{\basmalahur نہیں، میں قسم کھاتا ہوں اِس شہر کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxv{اور حال یہ ہے کہ (اے نبیؐ) اِس شہر میں تم کو حلال کر لیا گیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvi{اور قسم کھاتا ہوں باپ کی اور اس اولاد کی جو اس سے پیدا ہوئی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvii{درحقیقت ہم نے انسان کو مشقت میں پیدا کیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxviii{کیا اُس نے یہ سمجھ رکھا ہے کہ اُس پر کوئی قابو نہ پا سکے گا؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxix{کہتا ہے کہ میں نے ڈھیروں مال اڑا دیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxx{کیا وہ سمجھتا ہے کہ کسی نے اُس کو نہیں دیکھا؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxi{کیا ہم نے اُسے دو آنکھیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxii{اور ایک زبان اور دو ہونٹ نہیں دیے؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiii{اور دونوں نمایاں راستے اُسے (نہیں) دکھا دیے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiv{مگر اس نے دشوار گزار گھاٹی سے گزرنے کی ہمت نہ کی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxv{اور تم کیا جانو کہ کیا ہے وہ دشوار گزار گھاٹی؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvi{کسی گردن کو غلامی سے چھڑانا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvii{یا فاقے کے دن\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxviii{کسی قریبی یتیم\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxix{یا خاک نشین مسکین کو کھانا کھلانا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxl{پھر (اس کے ساتھ یہ کہ) آدمی اُن لوگوں میں شامل ہو جو ایمان لائے اور جنہوں نے ایک دوسرے کو صبر اور (خلق خدا پر) رحم کی تلقین کی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxli{یہ لوگ ہیں دائیں بازو والے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlii{اور جنہوں نے ہماری آیات کو ماننے سے انکار کیا وہ بائیں بازو والے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliii{ان پر آگ چھائی ہوئی ہوگی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliv{\basmalahur سورج اور اُس کی دھوپ کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlv{اور چاند کی قسم جبکہ وہ اُس کے پیچھے آتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvi{اور دن کی قسم جبکہ وہ (سورج کو) نمایاں کر دیتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvii{اور رات کی قسم جبکہ وہ (سورج کو) ڈھانک لیتی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlviii{اور آسمان کی اور اُس ذات کی قسم جس نے اُسے قائم کیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlix{اور زمین کی اور اُس ذات کی قسم جس نے اُسے بچھایا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmml{اور نفس انسانی کی اور اُس ذات کی قسم جس نے اُسے ہموار کیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmli{پھر اُس کی بدی اور اُس کی پرہیز گاری اس پر الہام کر دی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlii{یقیناً فلاح پا گیا وہ جس نے نفس کا تزکیہ کیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliii{اور نامراد ہوا وہ جس نے اُس کو دبا دیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliv{ثمود نے اپنی سرکشی کی بنا پر جھٹلایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlv{جب اُس قوم کا سب سے زیادہ شقی آدمی بپھر کر اٹھا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvi{تو اللہ کے رسول نے اُن لوگوں سے کہا کہ خبردار، اللہ کی اونٹنی کو (ہاتھ نہ لگانا) اوراُس کے پانی پینے (میں مانع نہ ہونا)\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvii{مگر انہوں نے اُس کی بات کو جھوٹا قرار دیا اور اونٹنی کو مار ڈالا آخرکار اُن کے گناہ کی پاداش میں ان کے رب نے ان پر ایسی آفت توڑی کہ ایک ساتھ سب کو پیوند خاک کر دیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlviii{اور اسے (اپنے ا س فعل کے) کسی برے نتیجے کا کوئی خوف نہیں ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlix{\basmalahur قسم ہے رات کی جبکہ وہ چھا جائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlx{اور دن کی جبکہ وہ روشن ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxi{اور اُس ذات کی جس نے نر اور مادہ کو پیدا کیا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxii{درحقیقت تم لوگوں کی کوششیں مختلف قسم کی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiii{تو جس نے (راہ خدا میں) مال دیا اور (خدا کی نافرمانی سے) پرہیز کیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiv{اور بھلائی کو سچ مانا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxv{اس کو ہم آسان راستے کے لیے سہولت دیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvi{اور جس نے بخل کیا اور (اپنے خدا سے) بے نیازی برتی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvii{اور بھلائی کو جھٹلایا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxviii{اس کو ہم سخت راستے کے لیے سہولت دیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxix{اور اُس کا مال آخر اُس کے کس کام آئے گا جبکہ وہ ہلاک ہو جائے؟\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxx{بے شک راستہ بتانا ہمارے ذمہ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxi{اور درحقیقت آخرت اور دنیا، دونوں کے ہم ہی مالک ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxii{پس میں نے تم کو خبردار کر دیا ہے بھڑکتی ہوئی آگ سے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiii{اُس میں نہیں جھلسے گا مگر وہ انتہائی بد بخت\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiv{جس نے جھٹلایا اور منہ پھیرا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxv{اور اُس سے دور رکھا جائیگا وہ نہایت پرہیزگار\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvi{جو پاکیزہ ہونے کی خاطر اپنا مال دیتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvii{اُس پر کسی کا کوئی احسان نہیں ہے جس کا بدلہ اُسے دینا ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxviii{وہ تو صرف اپنے رب برتر کی رضا جوئی کے لیے یہ کام کرتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxix{اور ضرور وہ (اُس سے) خوش ہوگا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxx{\basmalahur قسم ہے روز روشن کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxi{اور رات کی جبکہ وہ سکون کے ساتھ طاری ہو جائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxii{(اے نبیؐ) تمہارے رب نے تم کو ہرگز نہیں چھوڑا اور نہ وہ ناراض ہوا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiii{اور یقیناً تمہارے لیے بعد کا دور پہلے دور سے بہتر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiv{اور عنقریب تمہارا رب تم کو اتنا دے گا کہ تم خوش ہو جاؤ گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxv{کیا اس نے تم کو یتیم نہیں پایا اور پھر ٹھکانا فراہم کیا؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvi{اور تمہیں ناواقف راہ پایا اور پھر ہدایت بخشی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvii{اور تمہیں نادار پایا اور پھر مالدار کر دیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxviii{لہٰذا یتیم پر سختی نہ کرو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxix{اور سائل کو نہ جھڑکو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxc{اور اپنے رب کی نعمت کا اظہار کرو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxci{\basmalahur (اے نبیؐ) کیا ہم نے تمہارا سینہ تمہارے لیے کھول نہیں دیا؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcii{اور تم پر سے وہ بھاری بوجھ اتار دیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciii{جو تمہاری کمر توڑے ڈال رہا تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciv{اور تمہاری خاطر تمہارے ذکر کا آوازہ بلند کر دیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcv{پس حقیقت یہ ہے کہ تنگی کے ساتھ فراخی بھی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvi{بے شک تنگی کے ساتھ فراخی بھی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvii{لہٰذا جب تم فارغ ہو تو عبادت کی مشقت میں لگ جاؤ\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcviii{اور اپنے رب ہی کی طرف راغب ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcix{\basmalahur قسم ہے انجیر اور زیتون کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmc{اور طور سینا کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmci{اور اِس پرامن شہر (مکہ) کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcii{ہم نے انسان کو بہترین ساخت پر پیدا کیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciii{پھر اُسے الٹا پھیر کر ہم نے سب نیچوں سے نیچ کر دیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciv{سوائے اُن لوگوں کے جو ایمان لائے اور نیک عمل کرتے رہے کہ ان کے لیے کبھی ختم نہ ہونے والا اجر ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcv{پس (اے نبیؐ) اس کے بعد کون جزا و سزا کے معاملہ میں تم کو جھٹلا سکتا ہے؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvi{کیا اللہ سب حاکموں سے بڑا حاکم نہیں ہے؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvii{\basmalahur پڑھو (اے نبیؐ) اپنے رب کے نام کے ساتھ جس نے پیدا کیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcviii{جمے ہوئے خون کے ایک لوتھڑے سے انسان کی تخلیق کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcix{پڑھو، اور تمہارا رب بڑا کریم ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcx{جس نے قلم کے ذریعہ سے علم سکھایا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxi{انسان کو وہ علم دیا جسے وہ نہ جانتا تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxii{ہرگز نہیں، انسان سرکشی کرتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiii{اِس بنا پر کہ وہ اپنے آپ کو بے نیاز دیکھتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiv{پلٹنا یقیناً تیرے رب ہی کی طرف ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxv{تم نے دیکھا اُس شخص کو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvi{جو ایک بندے کو منع کرتا ہے جبکہ وہ نماز پڑھتا ہو؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvii{تمہارا کیا خیال ہے اگر (وہ بندہ) راہ راست پر ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxviii{یا پرہیزگاری کی تلقین کرتا ہو؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxix{تمہارا کیا خیال ہے اگر (یہ منع کرنے والا شخص حق کو) جھٹلاتا اور منہ موڑتا ہو؟\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxx{کیا وہ نہیں جانتا کہ اللہ دیکھ رہا ہے؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxi{ہرگز نہیں، اگر وہ باز نہ آیا تو ہم اس کی پیشانی کے بال پکڑ کر اسے کھینچیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxii{اُس پیشانی کو جو جھوٹی اور سخت خطا کار ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiii{وہ بلا لے اپنے حامیوں کی ٹولی کو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiv{ہم بھی عذاب کے فرشتوں کو بلا لیں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxv{ہرگز نہیں، اُس کی بات نہ مانو اور سجدہ کرو اور (اپنے رب کا) قرب حاصل کرو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvi{\basmalahur ہم نے اِس (قرآن) کو شب قدر میں نازل کیا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvii{اور تم کیا جانو کہ شب قدر کیا ہے؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxviii{شب قدر ہزار مہینوں سے زیادہ بہتر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxix{فرشتے اور روح اُس میں اپنے رب کے اذن سے ہر حکم لے کر اترتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxx{وہ رات سراسر سلامتی ہے طلوع فجر تک\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxi{\basmalahur اہل کتاب اور مشرکین میں سے جو لوگ کافر تھے (وہ اپنے کفر سے) باز آنے والے نہ تھے جب تک کہ ان کے پاس دلیل روشن نہ آ جائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxii{(یعنی) اللہ کی طرف سے ایک رسول جو پاک صحیفے پڑھ کر سنائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiii{جن میں بالکل راست اور درست تحریریں لکھی ہوئی ہوں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiv{پہلے جن لوگوں کو کتاب دی گئی تھی اُن میں تفرقہ برپا نہیں ہوا مگر اِس کے بعد کہ اُن کے پاس (راہ راست) کا بیان واضح آ چکا تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxv{اور اُن کو اِس کے سوا کوئی علم نہیں دیا گیا تھا کہ اللہ کی بندگی کریں اپنے دین کو اُس کے لیے خالص کر کے، بالکل یکسو ہو کر، اور نماز قائم کریں اور زکوٰۃ دیں یہی نہایت صحیح و درست دین ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvi{اہل کتاب اور مشرکین میں سے جن لوگوں نے کفر کیا ہے وہ یقیناً جہنم کی آگ میں جائیں گے اور ہمیشہ اس میں رہیں گے، یہ لوگ بد ترین خلائق ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvii{جو لوگ ایمان لے آئے اور جنہوں نے نیک عمل کیے، وہ یقیناً بہترین خلائق ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxviii{اُن کی جزا اُن کے رب کے ہاں دائمی قیام کی جنتیں ہیں جن کے نیچے نہریں بہ رہی ہوں گی، وہ ان میں ہمیشہ ہمیشہ رہیں گے اللہ ان سے راضی ہوا اور وہ اللہ سے راضی ہوئے یہ کچھ ہے اُس شخص کے لیے جس نے اپنے رب کا خوف کیا ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxix{\basmalahur جب زمین اپنی پوری شدت کے ساتھ ہلا ڈالی جائے گی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxl{اور زمین اپنے اندر کے سارے بوجھ نکال کر باہر ڈال دے گی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxli{اور انسان کہے گا کہ یہ اِس کو کیا ہو رہا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlii{اُس روز وہ اپنے (اوپر گزرے ہوئے) حالات بیان کرے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliii{کیونکہ تیرے رب نے اُسے (ایساکرنے کا) حکم دیا ہوگا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliv{اُس روز لوگ متفرق حالت میں پلٹیں گے تاکہ اُن کے اعمال اُن کو دکھائے جائیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlv{پھر جس نے ذرہ برابر نیکی کی ہوگی وہ اس کو دیکھ لے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvi{اور جس نے ذرہ برابر بدی کی ہوگی وہ اس کو دیکھ لے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvii{\basmalahur قسم ہے اُن (گھوڑوں) کی جو پھنکارے مارتے ہوئے دوڑتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlviii{پھر (اپنی ٹاپوں سے) چنگاریاں جھاڑتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlix{پھر صبح سویرے چھاپہ مارتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcl{پھر اس موقع پر گرد و غبار اڑاتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcli{پھر اِسی حالت میں کسی مجمع کے اندر جا گھستے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclii{حقیقت یہ ہے کہ انسان اپنے رب کا بڑا ناشکرا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliii{اور وہ خود اِس پر گواہ ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliv{اور وہ مال و دولت کی محبت میں بری طرح مبتلا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclv{تو کیا وہ اُس حقیقت کو نہیں جانتا جب قبروں میں جو کچھ (مدفون) ہے اُسے نکال لیا جائے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvi{اور سینوں میں جو کچھ (مخفی) ہے اُسے برآمد کر کے اس کی جانچ پڑتال کی جائے گی؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvii{یقیناً اُن کا رب اُس روز اُن سے خوب باخبر ہوگا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclviii{\basmalahur عظیم حادثہ!\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclix{کیا ہے وہ عظیم حادثہ؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclx{تم کیا جانو کہ وہ عظیم حادثہ کیا ہے؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxi{وہ دن جب لوگ بکھرے ہوئے پروانوں کی طرح\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxii{اور پہاڑ رنگ برنگ کے دھنکے ہوئے اون کی طرح ہوں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiii{پھر جس کے پلڑے بھاری ہوں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiv{وہ دل پسند عیش میں ہوگا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxv{اور جس کے پلڑے ہلکے ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvi{اس کی جائے قرار گہری کھائی ہوگی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvii{اور تمہیں کیا خبر کہ وہ کیا چیز ہے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxviii{بھڑکتی ہوئی آگ\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxix{\basmalahur تم لوگوں کو زیادہ سے زیادہ اور ایک دوسرے سے بڑھ کر دنیا حاصل کرنے کی دھن نے غفلت میں ڈال رکھا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxx{یہاں تک کہ (اسی فکر میں) تم لب گور تک پہنچ جاتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxi{ہرگز نہیں، عنقریب تم کو معلوم ہو جائے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxii{پھر (سن لو کہ) ہرگز نہیں، عنقریب تم کو معلوم ہو جائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiii{ہرگز نہیں، اگر تم یقینی علم کی حیثیت سے (اِس روش کے انجام کو) جانتے ہوتے (تو تمہارا یہ طرز عمل نہ ہوتا)\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiv{تم دوزخ دیکھ کر رہو گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxv{پھر (سن لو کہ) تم بالکل یقین کے ساتھ اُسے دیکھ لو گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvi{پھر ضرور اُس روز تم سے اِن نعمتوں کے بارے میں جواب طلبی کی جائے گی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvii{\basmalahur زمانے کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxviii{انسان درحقیقت بڑے خسارے میں ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxix{سوائے اُن لوگوں کے جو ایمان لائے، اور نیک اعمال کرتے رہے، اور ایک دوسرے کو حق کی نصیحت اور صبر کی تلقین کرتے رہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxx{\basmalahur تباہی ہے ہر اُس شخص کے لیے جو (منہ در منہ) لوگوں پر طعن اور (پیٹھ پیچھے) برائیاں کرنے کا خوگر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxi{جس نے مال جمع کیا اور اُسے گن گن کر رکھا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxii{وہ سمجھتا ہے کہ اُس کا مال ہمیشہ اُس کے پاس رہے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiii{ہرگز نہیں، وہ شخص تو چکنا چور کر دینے والی جگہ میں پھینک دیا جائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiv{اور تم کیا جانو کہ کیا ہے وہ چکنا چور کر دینے والی جگہ؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxv{اللہ کی آگ، خوب بھڑکائی ہوئی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvi{جو دلوں تک پہنچے گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvii{وہ اُن پر ڈھانک کر بند کر دی جائے گی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxviii{(اِس حالت میں کہ وہ) اونچے اونچے ستونوں میں (گھرے ہوئے ہوں گے)\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxix{\basmalahur تم نے دیکھا نہیں کہ تمہارے رب نے ہاتھی والوں کے ساتھ کیا کیا؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxc{کیا اُس نے اُن کی تدبیر کو اکارت نہیں کر دیا؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxci{اور اُن پر پرندوں کے جھنڈ کے جھنڈ بھیج دیے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcii{جو اُن پر پکی ہوئی مٹی کے پتھر پھینک رہے تھے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciii{پھر اُن کا یہ حال کر دیا جیسے جانوروں کا کھایا ہوا بھوسا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciv{\basmalahur چونکہ قریش مانوس ہوئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcv{(یعنی) جاڑے اور گرمی کے سفروں سے مانوس\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvi{لہٰذا اُن کو چاہیے کہ اِس گھر کے رب کی عبادت کریں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvii{جس نے اُنہیں بھوک سے بچا کر کھانے کو دیا اور خوف سے بچا کر امن عطا کیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcviii{\basmalahur تم نے دیکھا اُس شخص کو جو آخرت کی جزا و سزا کو جھٹلاتا ہے؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcix{وہی تو ہے جو یتیم کو دھکے دیتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcc{اور مسکین کو کھانا دینے پر نہیں اکساتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcci{پھر تباہی ہے اُن نماز پڑھنے والوں کے لیے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccii{جو اپنی نماز سے غفلت برتتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciii{جو ریا کاری کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciv{اور معمولی ضرورت کی چیزیں (لوگوں کو) دینے سے گریز کرتے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccv{\basmalahur (اے نبیؐ) ہم نے تمہیں کوثر عطا کر دیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvi{پس تم اپنے رب ہی کے لیے نماز پڑھو اور قربانی کرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvii{تمہارا دشمن ہی جڑ کٹا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccviii{\basmalahur کہہ دو کہ اے کافرو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccix{میں اُن کی عبادت نہیں کرتا جن کی عبادت تم کرتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccx{اور نہ تم اُس کی عبادت کرنے والے ہو جس کی عبادت میں کرتا ہوں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxi{اور نہ میں اُن کی عبادت کرنے والا ہوں جن کی عبادت تم نے کی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxii{اور نہ تم اُس کی عبادت کرنے والے ہو جس کی عبادت میں کرتا ہوں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiii{تمہارے لیے تمہارا دین ہے اور میرے لیے میرا دین\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiv{\basmalahur جب اللہ کی مدد آ جائے اور فتح نصیب ہو جائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxv{اور (اے نبیؐ) تم دیکھ لو کہ لوگ فوج در فوج اللہ کے دین میں داخل ہو رہے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvi{تو اپنے رب کی حمد کے ساتھ اُس کی تسبیح کرو، اور اُس سے مغفرت کی دعا مانگو، بے شک وہ بڑا توبہ قبول کرنے والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvii{\basmalahur ٹوٹ گئے ابولہب کے ہاتھ اور نامراد ہو گیا وہ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxviii{اُس کا مال اور جو کچھ اس نے کمایا وہ اُس کے کسی کام نہ آیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxix{ضرور وہ شعلہ زن آگ میں ڈالا جائے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxx{اور (اُس کے ساتھ) اُس کی جورو بھی، لگائی بجھائی کرنے والی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxi{اُس کی گردن میں مونجھ کی رسی ہوگی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxii{\basmalahur کہو، وہ اللہ ہے، یکتا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiii{اللہ سب سے بے نیاز ہے اور سب اس کے محتاج ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiv{نہ اس کی کوئی اولاد ہے اور نہ وہ کسی کی اولاد\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxv{اور کوئی اس کا ہمسر نہیں ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvi{\basmalahur کہو، میں پناہ مانگتا ہوں صبح کے رب کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvii{ہر اُس چیز کے شر سے جو اُس نے پیدا کی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxviii{اور رات کی تاریکی کے شر سے جب کہ وہ چھا جائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxix{اور گرہوں میں پھونکنے والوں (یا والیوں) کے شر سے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxx{اور حاسد کے شر سے جب کہ وہ حسد کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxi{\basmalahur کہو، میں پناہ مانگتا ہوں انسانوں کے رب\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxii{انسانوں کے بادشاہ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiii{انسانوں کے حقیقی معبود کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiv{اُس وسوسہ ڈالنے والے کے شر سے جو بار بار پلٹ کر آتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxv{جو لوگوں کے دلوں میں وسوسے ڈالتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxvi{خواہ وہ جنوں میں سے ہو یا انسانوں میں سے\qt@no{(6)}}%
%% End of file `qurantext-urvi.translation.def'.
